// Copyright 2025 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

/*eslint-disable block-scoped-var, id-length, no-control-regex, no-magic-numbers, no-prototype-builtins, no-redeclare, no-shadow, no-var, sort-vars*/
(function(global, factory) { /* global define, require, module */

    /* AMD */ if (typeof define === 'function' && define.amd)
        define(["protobufjs/minimal"], factory);

    /* CommonJS */ else if (typeof require === 'function' && typeof module === 'object' && module && module.exports)
        module.exports = factory(require("google-gax/build/src/protobuf").protobufMinimal);

})(this, function($protobuf) {
    "use strict";

    // Common aliases
    var $Reader = $protobuf.Reader, $Writer = $protobuf.Writer, $util = $protobuf.util;
    
    // Exported root namespace
    var $root = $protobuf.roots._google_cloud_dialogflow_protos || ($protobuf.roots._google_cloud_dialogflow_protos = {});
    
    $root.google = (function() {
    
        /**
         * Namespace google.
         * @exports google
         * @namespace
         */
        var google = {};
    
        google.cloud = (function() {
    
            /**
             * Namespace cloud.
             * @memberof google
             * @namespace
             */
            var cloud = {};
    
            cloud.dialogflow = (function() {
    
                /**
                 * Namespace dialogflow.
                 * @memberof google.cloud
                 * @namespace
                 */
                var dialogflow = {};
    
                dialogflow.v2 = (function() {
    
                    /**
                     * Namespace v2.
                     * @memberof google.cloud.dialogflow
                     * @namespace
                     */
                    var v2 = {};
    
                    v2.Agents = (function() {
    
                        /**
                         * Constructs a new Agents service.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an Agents
                         * @extends $protobuf.rpc.Service
                         * @constructor
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         */
                        function Agents(rpcImpl, requestDelimited, responseDelimited) {
                            $protobuf.rpc.Service.call(this, rpcImpl, requestDelimited, responseDelimited);
                        }
    
                        (Agents.prototype = Object.create($protobuf.rpc.Service.prototype)).constructor = Agents;
    
                        /**
                         * Creates new Agents service using the specified rpc implementation.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.Agents
                         * @static
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         * @returns {Agents} RPC service. Useful where requests and/or responses are streamed.
                         */
                        Agents.create = function create(rpcImpl, requestDelimited, responseDelimited) {
                            return new this(rpcImpl, requestDelimited, responseDelimited);
                        };
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Agents|getAgent}.
                         * @memberof google.cloud.dialogflow.v2.Agents
                         * @typedef GetAgentCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.Agent} [response] Agent
                         */
    
                        /**
                         * Calls GetAgent.
                         * @function getAgent
                         * @memberof google.cloud.dialogflow.v2.Agents
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IGetAgentRequest} request GetAgentRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Agents.GetAgentCallback} callback Node-style callback called with the error, if any, and Agent
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Agents.prototype.getAgent = function getAgent(request, callback) {
                            return this.rpcCall(getAgent, $root.google.cloud.dialogflow.v2.GetAgentRequest, $root.google.cloud.dialogflow.v2.Agent, request, callback);
                        }, "name", { value: "GetAgent" });
    
                        /**
                         * Calls GetAgent.
                         * @function getAgent
                         * @memberof google.cloud.dialogflow.v2.Agents
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IGetAgentRequest} request GetAgentRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.Agent>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Agents|setAgent}.
                         * @memberof google.cloud.dialogflow.v2.Agents
                         * @typedef SetAgentCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.Agent} [response] Agent
                         */
    
                        /**
                         * Calls SetAgent.
                         * @function setAgent
                         * @memberof google.cloud.dialogflow.v2.Agents
                         * @instance
                         * @param {google.cloud.dialogflow.v2.ISetAgentRequest} request SetAgentRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Agents.SetAgentCallback} callback Node-style callback called with the error, if any, and Agent
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Agents.prototype.setAgent = function setAgent(request, callback) {
                            return this.rpcCall(setAgent, $root.google.cloud.dialogflow.v2.SetAgentRequest, $root.google.cloud.dialogflow.v2.Agent, request, callback);
                        }, "name", { value: "SetAgent" });
    
                        /**
                         * Calls SetAgent.
                         * @function setAgent
                         * @memberof google.cloud.dialogflow.v2.Agents
                         * @instance
                         * @param {google.cloud.dialogflow.v2.ISetAgentRequest} request SetAgentRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.Agent>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Agents|deleteAgent}.
                         * @memberof google.cloud.dialogflow.v2.Agents
                         * @typedef DeleteAgentCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.protobuf.Empty} [response] Empty
                         */
    
                        /**
                         * Calls DeleteAgent.
                         * @function deleteAgent
                         * @memberof google.cloud.dialogflow.v2.Agents
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IDeleteAgentRequest} request DeleteAgentRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Agents.DeleteAgentCallback} callback Node-style callback called with the error, if any, and Empty
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Agents.prototype.deleteAgent = function deleteAgent(request, callback) {
                            return this.rpcCall(deleteAgent, $root.google.cloud.dialogflow.v2.DeleteAgentRequest, $root.google.protobuf.Empty, request, callback);
                        }, "name", { value: "DeleteAgent" });
    
                        /**
                         * Calls DeleteAgent.
                         * @function deleteAgent
                         * @memberof google.cloud.dialogflow.v2.Agents
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IDeleteAgentRequest} request DeleteAgentRequest message or plain object
                         * @returns {Promise<google.protobuf.Empty>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Agents|searchAgents}.
                         * @memberof google.cloud.dialogflow.v2.Agents
                         * @typedef SearchAgentsCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.SearchAgentsResponse} [response] SearchAgentsResponse
                         */
    
                        /**
                         * Calls SearchAgents.
                         * @function searchAgents
                         * @memberof google.cloud.dialogflow.v2.Agents
                         * @instance
                         * @param {google.cloud.dialogflow.v2.ISearchAgentsRequest} request SearchAgentsRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Agents.SearchAgentsCallback} callback Node-style callback called with the error, if any, and SearchAgentsResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Agents.prototype.searchAgents = function searchAgents(request, callback) {
                            return this.rpcCall(searchAgents, $root.google.cloud.dialogflow.v2.SearchAgentsRequest, $root.google.cloud.dialogflow.v2.SearchAgentsResponse, request, callback);
                        }, "name", { value: "SearchAgents" });
    
                        /**
                         * Calls SearchAgents.
                         * @function searchAgents
                         * @memberof google.cloud.dialogflow.v2.Agents
                         * @instance
                         * @param {google.cloud.dialogflow.v2.ISearchAgentsRequest} request SearchAgentsRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.SearchAgentsResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Agents|trainAgent}.
                         * @memberof google.cloud.dialogflow.v2.Agents
                         * @typedef TrainAgentCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.longrunning.Operation} [response] Operation
                         */
    
                        /**
                         * Calls TrainAgent.
                         * @function trainAgent
                         * @memberof google.cloud.dialogflow.v2.Agents
                         * @instance
                         * @param {google.cloud.dialogflow.v2.ITrainAgentRequest} request TrainAgentRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Agents.TrainAgentCallback} callback Node-style callback called with the error, if any, and Operation
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Agents.prototype.trainAgent = function trainAgent(request, callback) {
                            return this.rpcCall(trainAgent, $root.google.cloud.dialogflow.v2.TrainAgentRequest, $root.google.longrunning.Operation, request, callback);
                        }, "name", { value: "TrainAgent" });
    
                        /**
                         * Calls TrainAgent.
                         * @function trainAgent
                         * @memberof google.cloud.dialogflow.v2.Agents
                         * @instance
                         * @param {google.cloud.dialogflow.v2.ITrainAgentRequest} request TrainAgentRequest message or plain object
                         * @returns {Promise<google.longrunning.Operation>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Agents|exportAgent}.
                         * @memberof google.cloud.dialogflow.v2.Agents
                         * @typedef ExportAgentCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.longrunning.Operation} [response] Operation
                         */
    
                        /**
                         * Calls ExportAgent.
                         * @function exportAgent
                         * @memberof google.cloud.dialogflow.v2.Agents
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IExportAgentRequest} request ExportAgentRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Agents.ExportAgentCallback} callback Node-style callback called with the error, if any, and Operation
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Agents.prototype.exportAgent = function exportAgent(request, callback) {
                            return this.rpcCall(exportAgent, $root.google.cloud.dialogflow.v2.ExportAgentRequest, $root.google.longrunning.Operation, request, callback);
                        }, "name", { value: "ExportAgent" });
    
                        /**
                         * Calls ExportAgent.
                         * @function exportAgent
                         * @memberof google.cloud.dialogflow.v2.Agents
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IExportAgentRequest} request ExportAgentRequest message or plain object
                         * @returns {Promise<google.longrunning.Operation>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Agents|importAgent}.
                         * @memberof google.cloud.dialogflow.v2.Agents
                         * @typedef ImportAgentCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.longrunning.Operation} [response] Operation
                         */
    
                        /**
                         * Calls ImportAgent.
                         * @function importAgent
                         * @memberof google.cloud.dialogflow.v2.Agents
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IImportAgentRequest} request ImportAgentRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Agents.ImportAgentCallback} callback Node-style callback called with the error, if any, and Operation
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Agents.prototype.importAgent = function importAgent(request, callback) {
                            return this.rpcCall(importAgent, $root.google.cloud.dialogflow.v2.ImportAgentRequest, $root.google.longrunning.Operation, request, callback);
                        }, "name", { value: "ImportAgent" });
    
                        /**
                         * Calls ImportAgent.
                         * @function importAgent
                         * @memberof google.cloud.dialogflow.v2.Agents
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IImportAgentRequest} request ImportAgentRequest message or plain object
                         * @returns {Promise<google.longrunning.Operation>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Agents|restoreAgent}.
                         * @memberof google.cloud.dialogflow.v2.Agents
                         * @typedef RestoreAgentCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.longrunning.Operation} [response] Operation
                         */
    
                        /**
                         * Calls RestoreAgent.
                         * @function restoreAgent
                         * @memberof google.cloud.dialogflow.v2.Agents
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IRestoreAgentRequest} request RestoreAgentRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Agents.RestoreAgentCallback} callback Node-style callback called with the error, if any, and Operation
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Agents.prototype.restoreAgent = function restoreAgent(request, callback) {
                            return this.rpcCall(restoreAgent, $root.google.cloud.dialogflow.v2.RestoreAgentRequest, $root.google.longrunning.Operation, request, callback);
                        }, "name", { value: "RestoreAgent" });
    
                        /**
                         * Calls RestoreAgent.
                         * @function restoreAgent
                         * @memberof google.cloud.dialogflow.v2.Agents
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IRestoreAgentRequest} request RestoreAgentRequest message or plain object
                         * @returns {Promise<google.longrunning.Operation>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Agents|getValidationResult}.
                         * @memberof google.cloud.dialogflow.v2.Agents
                         * @typedef GetValidationResultCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.ValidationResult} [response] ValidationResult
                         */
    
                        /**
                         * Calls GetValidationResult.
                         * @function getValidationResult
                         * @memberof google.cloud.dialogflow.v2.Agents
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IGetValidationResultRequest} request GetValidationResultRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Agents.GetValidationResultCallback} callback Node-style callback called with the error, if any, and ValidationResult
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Agents.prototype.getValidationResult = function getValidationResult(request, callback) {
                            return this.rpcCall(getValidationResult, $root.google.cloud.dialogflow.v2.GetValidationResultRequest, $root.google.cloud.dialogflow.v2.ValidationResult, request, callback);
                        }, "name", { value: "GetValidationResult" });
    
                        /**
                         * Calls GetValidationResult.
                         * @function getValidationResult
                         * @memberof google.cloud.dialogflow.v2.Agents
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IGetValidationResultRequest} request GetValidationResultRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.ValidationResult>} Promise
                         * @variation 2
                         */
    
                        return Agents;
                    })();
    
                    v2.Agent = (function() {
    
                        /**
                         * Properties of an Agent.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IAgent
                         * @property {string|null} [parent] Agent parent
                         * @property {string|null} [displayName] Agent displayName
                         * @property {string|null} [defaultLanguageCode] Agent defaultLanguageCode
                         * @property {Array.<string>|null} [supportedLanguageCodes] Agent supportedLanguageCodes
                         * @property {string|null} [timeZone] Agent timeZone
                         * @property {string|null} [description] Agent description
                         * @property {string|null} [avatarUri] Agent avatarUri
                         * @property {boolean|null} [enableLogging] Agent enableLogging
                         * @property {google.cloud.dialogflow.v2.Agent.MatchMode|null} [matchMode] Agent matchMode
                         * @property {number|null} [classificationThreshold] Agent classificationThreshold
                         * @property {google.cloud.dialogflow.v2.Agent.ApiVersion|null} [apiVersion] Agent apiVersion
                         * @property {google.cloud.dialogflow.v2.Agent.Tier|null} [tier] Agent tier
                         */
    
                        /**
                         * Constructs a new Agent.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an Agent.
                         * @implements IAgent
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IAgent=} [properties] Properties to set
                         */
                        function Agent(properties) {
                            this.supportedLanguageCodes = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * Agent parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.Agent
                         * @instance
                         */
                        Agent.prototype.parent = "";
    
                        /**
                         * Agent displayName.
                         * @member {string} displayName
                         * @memberof google.cloud.dialogflow.v2.Agent
                         * @instance
                         */
                        Agent.prototype.displayName = "";
    
                        /**
                         * Agent defaultLanguageCode.
                         * @member {string} defaultLanguageCode
                         * @memberof google.cloud.dialogflow.v2.Agent
                         * @instance
                         */
                        Agent.prototype.defaultLanguageCode = "";
    
                        /**
                         * Agent supportedLanguageCodes.
                         * @member {Array.<string>} supportedLanguageCodes
                         * @memberof google.cloud.dialogflow.v2.Agent
                         * @instance
                         */
                        Agent.prototype.supportedLanguageCodes = $util.emptyArray;
    
                        /**
                         * Agent timeZone.
                         * @member {string} timeZone
                         * @memberof google.cloud.dialogflow.v2.Agent
                         * @instance
                         */
                        Agent.prototype.timeZone = "";
    
                        /**
                         * Agent description.
                         * @member {string} description
                         * @memberof google.cloud.dialogflow.v2.Agent
                         * @instance
                         */
                        Agent.prototype.description = "";
    
                        /**
                         * Agent avatarUri.
                         * @member {string} avatarUri
                         * @memberof google.cloud.dialogflow.v2.Agent
                         * @instance
                         */
                        Agent.prototype.avatarUri = "";
    
                        /**
                         * Agent enableLogging.
                         * @member {boolean} enableLogging
                         * @memberof google.cloud.dialogflow.v2.Agent
                         * @instance
                         */
                        Agent.prototype.enableLogging = false;
    
                        /**
                         * Agent matchMode.
                         * @member {google.cloud.dialogflow.v2.Agent.MatchMode} matchMode
                         * @memberof google.cloud.dialogflow.v2.Agent
                         * @instance
                         */
                        Agent.prototype.matchMode = 0;
    
                        /**
                         * Agent classificationThreshold.
                         * @member {number} classificationThreshold
                         * @memberof google.cloud.dialogflow.v2.Agent
                         * @instance
                         */
                        Agent.prototype.classificationThreshold = 0;
    
                        /**
                         * Agent apiVersion.
                         * @member {google.cloud.dialogflow.v2.Agent.ApiVersion} apiVersion
                         * @memberof google.cloud.dialogflow.v2.Agent
                         * @instance
                         */
                        Agent.prototype.apiVersion = 0;
    
                        /**
                         * Agent tier.
                         * @member {google.cloud.dialogflow.v2.Agent.Tier} tier
                         * @memberof google.cloud.dialogflow.v2.Agent
                         * @instance
                         */
                        Agent.prototype.tier = 0;
    
                        /**
                         * Creates a new Agent instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.Agent
                         * @static
                         * @param {google.cloud.dialogflow.v2.IAgent=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.Agent} Agent instance
                         */
                        Agent.create = function create(properties) {
                            return new Agent(properties);
                        };
    
                        /**
                         * Encodes the specified Agent message. Does not implicitly {@link google.cloud.dialogflow.v2.Agent.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.Agent
                         * @static
                         * @param {google.cloud.dialogflow.v2.IAgent} message Agent message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        Agent.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.displayName != null && Object.hasOwnProperty.call(message, "displayName"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.displayName);
                            if (message.defaultLanguageCode != null && Object.hasOwnProperty.call(message, "defaultLanguageCode"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.defaultLanguageCode);
                            if (message.supportedLanguageCodes != null && message.supportedLanguageCodes.length)
                                for (var i = 0; i < message.supportedLanguageCodes.length; ++i)
                                    writer.uint32(/* id 4, wireType 2 =*/34).string(message.supportedLanguageCodes[i]);
                            if (message.timeZone != null && Object.hasOwnProperty.call(message, "timeZone"))
                                writer.uint32(/* id 5, wireType 2 =*/42).string(message.timeZone);
                            if (message.description != null && Object.hasOwnProperty.call(message, "description"))
                                writer.uint32(/* id 6, wireType 2 =*/50).string(message.description);
                            if (message.avatarUri != null && Object.hasOwnProperty.call(message, "avatarUri"))
                                writer.uint32(/* id 7, wireType 2 =*/58).string(message.avatarUri);
                            if (message.enableLogging != null && Object.hasOwnProperty.call(message, "enableLogging"))
                                writer.uint32(/* id 8, wireType 0 =*/64).bool(message.enableLogging);
                            if (message.matchMode != null && Object.hasOwnProperty.call(message, "matchMode"))
                                writer.uint32(/* id 9, wireType 0 =*/72).int32(message.matchMode);
                            if (message.classificationThreshold != null && Object.hasOwnProperty.call(message, "classificationThreshold"))
                                writer.uint32(/* id 10, wireType 5 =*/85).float(message.classificationThreshold);
                            if (message.apiVersion != null && Object.hasOwnProperty.call(message, "apiVersion"))
                                writer.uint32(/* id 14, wireType 0 =*/112).int32(message.apiVersion);
                            if (message.tier != null && Object.hasOwnProperty.call(message, "tier"))
                                writer.uint32(/* id 15, wireType 0 =*/120).int32(message.tier);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified Agent message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.Agent.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.Agent
                         * @static
                         * @param {google.cloud.dialogflow.v2.IAgent} message Agent message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        Agent.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an Agent message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.Agent
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.Agent} Agent
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        Agent.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.Agent();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.displayName = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.defaultLanguageCode = reader.string();
                                        break;
                                    }
                                case 4: {
                                        if (!(message.supportedLanguageCodes && message.supportedLanguageCodes.length))
                                            message.supportedLanguageCodes = [];
                                        message.supportedLanguageCodes.push(reader.string());
                                        break;
                                    }
                                case 5: {
                                        message.timeZone = reader.string();
                                        break;
                                    }
                                case 6: {
                                        message.description = reader.string();
                                        break;
                                    }
                                case 7: {
                                        message.avatarUri = reader.string();
                                        break;
                                    }
                                case 8: {
                                        message.enableLogging = reader.bool();
                                        break;
                                    }
                                case 9: {
                                        message.matchMode = reader.int32();
                                        break;
                                    }
                                case 10: {
                                        message.classificationThreshold = reader.float();
                                        break;
                                    }
                                case 14: {
                                        message.apiVersion = reader.int32();
                                        break;
                                    }
                                case 15: {
                                        message.tier = reader.int32();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an Agent message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.Agent
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.Agent} Agent
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        Agent.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an Agent message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.Agent
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        Agent.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.displayName != null && message.hasOwnProperty("displayName"))
                                if (!$util.isString(message.displayName))
                                    return "displayName: string expected";
                            if (message.defaultLanguageCode != null && message.hasOwnProperty("defaultLanguageCode"))
                                if (!$util.isString(message.defaultLanguageCode))
                                    return "defaultLanguageCode: string expected";
                            if (message.supportedLanguageCodes != null && message.hasOwnProperty("supportedLanguageCodes")) {
                                if (!Array.isArray(message.supportedLanguageCodes))
                                    return "supportedLanguageCodes: array expected";
                                for (var i = 0; i < message.supportedLanguageCodes.length; ++i)
                                    if (!$util.isString(message.supportedLanguageCodes[i]))
                                        return "supportedLanguageCodes: string[] expected";
                            }
                            if (message.timeZone != null && message.hasOwnProperty("timeZone"))
                                if (!$util.isString(message.timeZone))
                                    return "timeZone: string expected";
                            if (message.description != null && message.hasOwnProperty("description"))
                                if (!$util.isString(message.description))
                                    return "description: string expected";
                            if (message.avatarUri != null && message.hasOwnProperty("avatarUri"))
                                if (!$util.isString(message.avatarUri))
                                    return "avatarUri: string expected";
                            if (message.enableLogging != null && message.hasOwnProperty("enableLogging"))
                                if (typeof message.enableLogging !== "boolean")
                                    return "enableLogging: boolean expected";
                            if (message.matchMode != null && message.hasOwnProperty("matchMode"))
                                switch (message.matchMode) {
                                default:
                                    return "matchMode: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                    break;
                                }
                            if (message.classificationThreshold != null && message.hasOwnProperty("classificationThreshold"))
                                if (typeof message.classificationThreshold !== "number")
                                    return "classificationThreshold: number expected";
                            if (message.apiVersion != null && message.hasOwnProperty("apiVersion"))
                                switch (message.apiVersion) {
                                default:
                                    return "apiVersion: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                    break;
                                }
                            if (message.tier != null && message.hasOwnProperty("tier"))
                                switch (message.tier) {
                                default:
                                    return "tier: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                    break;
                                }
                            return null;
                        };
    
                        /**
                         * Creates an Agent message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.Agent
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.Agent} Agent
                         */
                        Agent.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.Agent)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.Agent();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.displayName != null)
                                message.displayName = String(object.displayName);
                            if (object.defaultLanguageCode != null)
                                message.defaultLanguageCode = String(object.defaultLanguageCode);
                            if (object.supportedLanguageCodes) {
                                if (!Array.isArray(object.supportedLanguageCodes))
                                    throw TypeError(".google.cloud.dialogflow.v2.Agent.supportedLanguageCodes: array expected");
                                message.supportedLanguageCodes = [];
                                for (var i = 0; i < object.supportedLanguageCodes.length; ++i)
                                    message.supportedLanguageCodes[i] = String(object.supportedLanguageCodes[i]);
                            }
                            if (object.timeZone != null)
                                message.timeZone = String(object.timeZone);
                            if (object.description != null)
                                message.description = String(object.description);
                            if (object.avatarUri != null)
                                message.avatarUri = String(object.avatarUri);
                            if (object.enableLogging != null)
                                message.enableLogging = Boolean(object.enableLogging);
                            switch (object.matchMode) {
                            default:
                                if (typeof object.matchMode === "number") {
                                    message.matchMode = object.matchMode;
                                    break;
                                }
                                break;
                            case "MATCH_MODE_UNSPECIFIED":
                            case 0:
                                message.matchMode = 0;
                                break;
                            case "MATCH_MODE_HYBRID":
                            case 1:
                                message.matchMode = 1;
                                break;
                            case "MATCH_MODE_ML_ONLY":
                            case 2:
                                message.matchMode = 2;
                                break;
                            }
                            if (object.classificationThreshold != null)
                                message.classificationThreshold = Number(object.classificationThreshold);
                            switch (object.apiVersion) {
                            default:
                                if (typeof object.apiVersion === "number") {
                                    message.apiVersion = object.apiVersion;
                                    break;
                                }
                                break;
                            case "API_VERSION_UNSPECIFIED":
                            case 0:
                                message.apiVersion = 0;
                                break;
                            case "API_VERSION_V1":
                            case 1:
                                message.apiVersion = 1;
                                break;
                            case "API_VERSION_V2":
                            case 2:
                                message.apiVersion = 2;
                                break;
                            case "API_VERSION_V2_BETA_1":
                            case 3:
                                message.apiVersion = 3;
                                break;
                            }
                            switch (object.tier) {
                            default:
                                if (typeof object.tier === "number") {
                                    message.tier = object.tier;
                                    break;
                                }
                                break;
                            case "TIER_UNSPECIFIED":
                            case 0:
                                message.tier = 0;
                                break;
                            case "TIER_STANDARD":
                            case 1:
                                message.tier = 1;
                                break;
                            case "TIER_ENTERPRISE":
                            case 2:
                                message.tier = 2;
                                break;
                            case "TIER_ENTERPRISE_PLUS":
                            case 3:
                                message.tier = 3;
                                break;
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an Agent message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.Agent
                         * @static
                         * @param {google.cloud.dialogflow.v2.Agent} message Agent
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        Agent.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.supportedLanguageCodes = [];
                            if (options.defaults) {
                                object.parent = "";
                                object.displayName = "";
                                object.defaultLanguageCode = "";
                                object.timeZone = "";
                                object.description = "";
                                object.avatarUri = "";
                                object.enableLogging = false;
                                object.matchMode = options.enums === String ? "MATCH_MODE_UNSPECIFIED" : 0;
                                object.classificationThreshold = 0;
                                object.apiVersion = options.enums === String ? "API_VERSION_UNSPECIFIED" : 0;
                                object.tier = options.enums === String ? "TIER_UNSPECIFIED" : 0;
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.displayName != null && message.hasOwnProperty("displayName"))
                                object.displayName = message.displayName;
                            if (message.defaultLanguageCode != null && message.hasOwnProperty("defaultLanguageCode"))
                                object.defaultLanguageCode = message.defaultLanguageCode;
                            if (message.supportedLanguageCodes && message.supportedLanguageCodes.length) {
                                object.supportedLanguageCodes = [];
                                for (var j = 0; j < message.supportedLanguageCodes.length; ++j)
                                    object.supportedLanguageCodes[j] = message.supportedLanguageCodes[j];
                            }
                            if (message.timeZone != null && message.hasOwnProperty("timeZone"))
                                object.timeZone = message.timeZone;
                            if (message.description != null && message.hasOwnProperty("description"))
                                object.description = message.description;
                            if (message.avatarUri != null && message.hasOwnProperty("avatarUri"))
                                object.avatarUri = message.avatarUri;
                            if (message.enableLogging != null && message.hasOwnProperty("enableLogging"))
                                object.enableLogging = message.enableLogging;
                            if (message.matchMode != null && message.hasOwnProperty("matchMode"))
                                object.matchMode = options.enums === String ? $root.google.cloud.dialogflow.v2.Agent.MatchMode[message.matchMode] === undefined ? message.matchMode : $root.google.cloud.dialogflow.v2.Agent.MatchMode[message.matchMode] : message.matchMode;
                            if (message.classificationThreshold != null && message.hasOwnProperty("classificationThreshold"))
                                object.classificationThreshold = options.json && !isFinite(message.classificationThreshold) ? String(message.classificationThreshold) : message.classificationThreshold;
                            if (message.apiVersion != null && message.hasOwnProperty("apiVersion"))
                                object.apiVersion = options.enums === String ? $root.google.cloud.dialogflow.v2.Agent.ApiVersion[message.apiVersion] === undefined ? message.apiVersion : $root.google.cloud.dialogflow.v2.Agent.ApiVersion[message.apiVersion] : message.apiVersion;
                            if (message.tier != null && message.hasOwnProperty("tier"))
                                object.tier = options.enums === String ? $root.google.cloud.dialogflow.v2.Agent.Tier[message.tier] === undefined ? message.tier : $root.google.cloud.dialogflow.v2.Agent.Tier[message.tier] : message.tier;
                            return object;
                        };
    
                        /**
                         * Converts this Agent to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.Agent
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        Agent.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for Agent
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.Agent
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        Agent.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.Agent";
                        };
    
                        /**
                         * MatchMode enum.
                         * @name google.cloud.dialogflow.v2.Agent.MatchMode
                         * @enum {number}
                         * @property {number} MATCH_MODE_UNSPECIFIED=0 MATCH_MODE_UNSPECIFIED value
                         * @property {number} MATCH_MODE_HYBRID=1 MATCH_MODE_HYBRID value
                         * @property {number} MATCH_MODE_ML_ONLY=2 MATCH_MODE_ML_ONLY value
                         */
                        Agent.MatchMode = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "MATCH_MODE_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "MATCH_MODE_HYBRID"] = 1;
                            values[valuesById[2] = "MATCH_MODE_ML_ONLY"] = 2;
                            return values;
                        })();
    
                        /**
                         * ApiVersion enum.
                         * @name google.cloud.dialogflow.v2.Agent.ApiVersion
                         * @enum {number}
                         * @property {number} API_VERSION_UNSPECIFIED=0 API_VERSION_UNSPECIFIED value
                         * @property {number} API_VERSION_V1=1 API_VERSION_V1 value
                         * @property {number} API_VERSION_V2=2 API_VERSION_V2 value
                         * @property {number} API_VERSION_V2_BETA_1=3 API_VERSION_V2_BETA_1 value
                         */
                        Agent.ApiVersion = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "API_VERSION_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "API_VERSION_V1"] = 1;
                            values[valuesById[2] = "API_VERSION_V2"] = 2;
                            values[valuesById[3] = "API_VERSION_V2_BETA_1"] = 3;
                            return values;
                        })();
    
                        /**
                         * Tier enum.
                         * @name google.cloud.dialogflow.v2.Agent.Tier
                         * @enum {number}
                         * @property {number} TIER_UNSPECIFIED=0 TIER_UNSPECIFIED value
                         * @property {number} TIER_STANDARD=1 TIER_STANDARD value
                         * @property {number} TIER_ENTERPRISE=2 TIER_ENTERPRISE value
                         * @property {number} TIER_ENTERPRISE_PLUS=3 TIER_ENTERPRISE_PLUS value
                         */
                        Agent.Tier = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "TIER_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "TIER_STANDARD"] = 1;
                            values[valuesById[2] = "TIER_ENTERPRISE"] = 2;
                            values[valuesById[3] = "TIER_ENTERPRISE_PLUS"] = 3;
                            return values;
                        })();
    
                        return Agent;
                    })();
    
                    v2.GetAgentRequest = (function() {
    
                        /**
                         * Properties of a GetAgentRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IGetAgentRequest
                         * @property {string|null} [parent] GetAgentRequest parent
                         */
    
                        /**
                         * Constructs a new GetAgentRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a GetAgentRequest.
                         * @implements IGetAgentRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IGetAgentRequest=} [properties] Properties to set
                         */
                        function GetAgentRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GetAgentRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.GetAgentRequest
                         * @instance
                         */
                        GetAgentRequest.prototype.parent = "";
    
                        /**
                         * Creates a new GetAgentRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.GetAgentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetAgentRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.GetAgentRequest} GetAgentRequest instance
                         */
                        GetAgentRequest.create = function create(properties) {
                            return new GetAgentRequest(properties);
                        };
    
                        /**
                         * Encodes the specified GetAgentRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.GetAgentRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.GetAgentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetAgentRequest} message GetAgentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetAgentRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GetAgentRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.GetAgentRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GetAgentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetAgentRequest} message GetAgentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetAgentRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GetAgentRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.GetAgentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.GetAgentRequest} GetAgentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetAgentRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.GetAgentRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GetAgentRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GetAgentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.GetAgentRequest} GetAgentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetAgentRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GetAgentRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.GetAgentRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GetAgentRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a GetAgentRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.GetAgentRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.GetAgentRequest} GetAgentRequest
                         */
                        GetAgentRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.GetAgentRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.GetAgentRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GetAgentRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.GetAgentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.GetAgentRequest} message GetAgentRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GetAgentRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.parent = "";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            return object;
                        };
    
                        /**
                         * Converts this GetAgentRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.GetAgentRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GetAgentRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GetAgentRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.GetAgentRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GetAgentRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.GetAgentRequest";
                        };
    
                        return GetAgentRequest;
                    })();
    
                    v2.SetAgentRequest = (function() {
    
                        /**
                         * Properties of a SetAgentRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ISetAgentRequest
                         * @property {google.cloud.dialogflow.v2.IAgent|null} [agent] SetAgentRequest agent
                         * @property {google.protobuf.IFieldMask|null} [updateMask] SetAgentRequest updateMask
                         */
    
                        /**
                         * Constructs a new SetAgentRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a SetAgentRequest.
                         * @implements ISetAgentRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ISetAgentRequest=} [properties] Properties to set
                         */
                        function SetAgentRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SetAgentRequest agent.
                         * @member {google.cloud.dialogflow.v2.IAgent|null|undefined} agent
                         * @memberof google.cloud.dialogflow.v2.SetAgentRequest
                         * @instance
                         */
                        SetAgentRequest.prototype.agent = null;
    
                        /**
                         * SetAgentRequest updateMask.
                         * @member {google.protobuf.IFieldMask|null|undefined} updateMask
                         * @memberof google.cloud.dialogflow.v2.SetAgentRequest
                         * @instance
                         */
                        SetAgentRequest.prototype.updateMask = null;
    
                        /**
                         * Creates a new SetAgentRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.SetAgentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISetAgentRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.SetAgentRequest} SetAgentRequest instance
                         */
                        SetAgentRequest.create = function create(properties) {
                            return new SetAgentRequest(properties);
                        };
    
                        /**
                         * Encodes the specified SetAgentRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.SetAgentRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.SetAgentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISetAgentRequest} message SetAgentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SetAgentRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.agent != null && Object.hasOwnProperty.call(message, "agent"))
                                $root.google.cloud.dialogflow.v2.Agent.encode(message.agent, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.updateMask != null && Object.hasOwnProperty.call(message, "updateMask"))
                                $root.google.protobuf.FieldMask.encode(message.updateMask, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SetAgentRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.SetAgentRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SetAgentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISetAgentRequest} message SetAgentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SetAgentRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SetAgentRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.SetAgentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.SetAgentRequest} SetAgentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SetAgentRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.SetAgentRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.agent = $root.google.cloud.dialogflow.v2.Agent.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.updateMask = $root.google.protobuf.FieldMask.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SetAgentRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SetAgentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.SetAgentRequest} SetAgentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SetAgentRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SetAgentRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.SetAgentRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SetAgentRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.agent != null && message.hasOwnProperty("agent")) {
                                var error = $root.google.cloud.dialogflow.v2.Agent.verify(message.agent);
                                if (error)
                                    return "agent." + error;
                            }
                            if (message.updateMask != null && message.hasOwnProperty("updateMask")) {
                                var error = $root.google.protobuf.FieldMask.verify(message.updateMask);
                                if (error)
                                    return "updateMask." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a SetAgentRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.SetAgentRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.SetAgentRequest} SetAgentRequest
                         */
                        SetAgentRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.SetAgentRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.SetAgentRequest();
                            if (object.agent != null) {
                                if (typeof object.agent !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.SetAgentRequest.agent: object expected");
                                message.agent = $root.google.cloud.dialogflow.v2.Agent.fromObject(object.agent);
                            }
                            if (object.updateMask != null) {
                                if (typeof object.updateMask !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.SetAgentRequest.updateMask: object expected");
                                message.updateMask = $root.google.protobuf.FieldMask.fromObject(object.updateMask);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SetAgentRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.SetAgentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.SetAgentRequest} message SetAgentRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SetAgentRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.agent = null;
                                object.updateMask = null;
                            }
                            if (message.agent != null && message.hasOwnProperty("agent"))
                                object.agent = $root.google.cloud.dialogflow.v2.Agent.toObject(message.agent, options);
                            if (message.updateMask != null && message.hasOwnProperty("updateMask"))
                                object.updateMask = $root.google.protobuf.FieldMask.toObject(message.updateMask, options);
                            return object;
                        };
    
                        /**
                         * Converts this SetAgentRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.SetAgentRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SetAgentRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SetAgentRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.SetAgentRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SetAgentRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.SetAgentRequest";
                        };
    
                        return SetAgentRequest;
                    })();
    
                    v2.DeleteAgentRequest = (function() {
    
                        /**
                         * Properties of a DeleteAgentRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IDeleteAgentRequest
                         * @property {string|null} [parent] DeleteAgentRequest parent
                         */
    
                        /**
                         * Constructs a new DeleteAgentRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a DeleteAgentRequest.
                         * @implements IDeleteAgentRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IDeleteAgentRequest=} [properties] Properties to set
                         */
                        function DeleteAgentRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * DeleteAgentRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.DeleteAgentRequest
                         * @instance
                         */
                        DeleteAgentRequest.prototype.parent = "";
    
                        /**
                         * Creates a new DeleteAgentRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.DeleteAgentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDeleteAgentRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.DeleteAgentRequest} DeleteAgentRequest instance
                         */
                        DeleteAgentRequest.create = function create(properties) {
                            return new DeleteAgentRequest(properties);
                        };
    
                        /**
                         * Encodes the specified DeleteAgentRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.DeleteAgentRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.DeleteAgentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDeleteAgentRequest} message DeleteAgentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteAgentRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified DeleteAgentRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.DeleteAgentRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.DeleteAgentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDeleteAgentRequest} message DeleteAgentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteAgentRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a DeleteAgentRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.DeleteAgentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.DeleteAgentRequest} DeleteAgentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteAgentRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.DeleteAgentRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a DeleteAgentRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.DeleteAgentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.DeleteAgentRequest} DeleteAgentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteAgentRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a DeleteAgentRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.DeleteAgentRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        DeleteAgentRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a DeleteAgentRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.DeleteAgentRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.DeleteAgentRequest} DeleteAgentRequest
                         */
                        DeleteAgentRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.DeleteAgentRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.DeleteAgentRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a DeleteAgentRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.DeleteAgentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.DeleteAgentRequest} message DeleteAgentRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        DeleteAgentRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.parent = "";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            return object;
                        };
    
                        /**
                         * Converts this DeleteAgentRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.DeleteAgentRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        DeleteAgentRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for DeleteAgentRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.DeleteAgentRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        DeleteAgentRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.DeleteAgentRequest";
                        };
    
                        return DeleteAgentRequest;
                    })();
    
                    v2.SearchAgentsRequest = (function() {
    
                        /**
                         * Properties of a SearchAgentsRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ISearchAgentsRequest
                         * @property {string|null} [parent] SearchAgentsRequest parent
                         * @property {number|null} [pageSize] SearchAgentsRequest pageSize
                         * @property {string|null} [pageToken] SearchAgentsRequest pageToken
                         */
    
                        /**
                         * Constructs a new SearchAgentsRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a SearchAgentsRequest.
                         * @implements ISearchAgentsRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ISearchAgentsRequest=} [properties] Properties to set
                         */
                        function SearchAgentsRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SearchAgentsRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.SearchAgentsRequest
                         * @instance
                         */
                        SearchAgentsRequest.prototype.parent = "";
    
                        /**
                         * SearchAgentsRequest pageSize.
                         * @member {number} pageSize
                         * @memberof google.cloud.dialogflow.v2.SearchAgentsRequest
                         * @instance
                         */
                        SearchAgentsRequest.prototype.pageSize = 0;
    
                        /**
                         * SearchAgentsRequest pageToken.
                         * @member {string} pageToken
                         * @memberof google.cloud.dialogflow.v2.SearchAgentsRequest
                         * @instance
                         */
                        SearchAgentsRequest.prototype.pageToken = "";
    
                        /**
                         * Creates a new SearchAgentsRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.SearchAgentsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISearchAgentsRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.SearchAgentsRequest} SearchAgentsRequest instance
                         */
                        SearchAgentsRequest.create = function create(properties) {
                            return new SearchAgentsRequest(properties);
                        };
    
                        /**
                         * Encodes the specified SearchAgentsRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.SearchAgentsRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.SearchAgentsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISearchAgentsRequest} message SearchAgentsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SearchAgentsRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.pageSize != null && Object.hasOwnProperty.call(message, "pageSize"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.pageSize);
                            if (message.pageToken != null && Object.hasOwnProperty.call(message, "pageToken"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.pageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SearchAgentsRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.SearchAgentsRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SearchAgentsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISearchAgentsRequest} message SearchAgentsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SearchAgentsRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SearchAgentsRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.SearchAgentsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.SearchAgentsRequest} SearchAgentsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SearchAgentsRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.SearchAgentsRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.pageSize = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.pageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SearchAgentsRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SearchAgentsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.SearchAgentsRequest} SearchAgentsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SearchAgentsRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SearchAgentsRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.SearchAgentsRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SearchAgentsRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                if (!$util.isInteger(message.pageSize))
                                    return "pageSize: integer expected";
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                if (!$util.isString(message.pageToken))
                                    return "pageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a SearchAgentsRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.SearchAgentsRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.SearchAgentsRequest} SearchAgentsRequest
                         */
                        SearchAgentsRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.SearchAgentsRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.SearchAgentsRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.pageSize != null)
                                message.pageSize = object.pageSize | 0;
                            if (object.pageToken != null)
                                message.pageToken = String(object.pageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SearchAgentsRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.SearchAgentsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.SearchAgentsRequest} message SearchAgentsRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SearchAgentsRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.pageSize = 0;
                                object.pageToken = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                object.pageSize = message.pageSize;
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                object.pageToken = message.pageToken;
                            return object;
                        };
    
                        /**
                         * Converts this SearchAgentsRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.SearchAgentsRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SearchAgentsRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SearchAgentsRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.SearchAgentsRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SearchAgentsRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.SearchAgentsRequest";
                        };
    
                        return SearchAgentsRequest;
                    })();
    
                    v2.SearchAgentsResponse = (function() {
    
                        /**
                         * Properties of a SearchAgentsResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ISearchAgentsResponse
                         * @property {Array.<google.cloud.dialogflow.v2.IAgent>|null} [agents] SearchAgentsResponse agents
                         * @property {string|null} [nextPageToken] SearchAgentsResponse nextPageToken
                         */
    
                        /**
                         * Constructs a new SearchAgentsResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a SearchAgentsResponse.
                         * @implements ISearchAgentsResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ISearchAgentsResponse=} [properties] Properties to set
                         */
                        function SearchAgentsResponse(properties) {
                            this.agents = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SearchAgentsResponse agents.
                         * @member {Array.<google.cloud.dialogflow.v2.IAgent>} agents
                         * @memberof google.cloud.dialogflow.v2.SearchAgentsResponse
                         * @instance
                         */
                        SearchAgentsResponse.prototype.agents = $util.emptyArray;
    
                        /**
                         * SearchAgentsResponse nextPageToken.
                         * @member {string} nextPageToken
                         * @memberof google.cloud.dialogflow.v2.SearchAgentsResponse
                         * @instance
                         */
                        SearchAgentsResponse.prototype.nextPageToken = "";
    
                        /**
                         * Creates a new SearchAgentsResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.SearchAgentsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISearchAgentsResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.SearchAgentsResponse} SearchAgentsResponse instance
                         */
                        SearchAgentsResponse.create = function create(properties) {
                            return new SearchAgentsResponse(properties);
                        };
    
                        /**
                         * Encodes the specified SearchAgentsResponse message. Does not implicitly {@link google.cloud.dialogflow.v2.SearchAgentsResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.SearchAgentsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISearchAgentsResponse} message SearchAgentsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SearchAgentsResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.agents != null && message.agents.length)
                                for (var i = 0; i < message.agents.length; ++i)
                                    $root.google.cloud.dialogflow.v2.Agent.encode(message.agents[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.nextPageToken != null && Object.hasOwnProperty.call(message, "nextPageToken"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.nextPageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SearchAgentsResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.SearchAgentsResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SearchAgentsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISearchAgentsResponse} message SearchAgentsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SearchAgentsResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SearchAgentsResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.SearchAgentsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.SearchAgentsResponse} SearchAgentsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SearchAgentsResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.SearchAgentsResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.agents && message.agents.length))
                                            message.agents = [];
                                        message.agents.push($root.google.cloud.dialogflow.v2.Agent.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 2: {
                                        message.nextPageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SearchAgentsResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SearchAgentsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.SearchAgentsResponse} SearchAgentsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SearchAgentsResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SearchAgentsResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.SearchAgentsResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SearchAgentsResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.agents != null && message.hasOwnProperty("agents")) {
                                if (!Array.isArray(message.agents))
                                    return "agents: array expected";
                                for (var i = 0; i < message.agents.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.Agent.verify(message.agents[i]);
                                    if (error)
                                        return "agents." + error;
                                }
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                if (!$util.isString(message.nextPageToken))
                                    return "nextPageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a SearchAgentsResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.SearchAgentsResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.SearchAgentsResponse} SearchAgentsResponse
                         */
                        SearchAgentsResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.SearchAgentsResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.SearchAgentsResponse();
                            if (object.agents) {
                                if (!Array.isArray(object.agents))
                                    throw TypeError(".google.cloud.dialogflow.v2.SearchAgentsResponse.agents: array expected");
                                message.agents = [];
                                for (var i = 0; i < object.agents.length; ++i) {
                                    if (typeof object.agents[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.SearchAgentsResponse.agents: object expected");
                                    message.agents[i] = $root.google.cloud.dialogflow.v2.Agent.fromObject(object.agents[i]);
                                }
                            }
                            if (object.nextPageToken != null)
                                message.nextPageToken = String(object.nextPageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SearchAgentsResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.SearchAgentsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.SearchAgentsResponse} message SearchAgentsResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SearchAgentsResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.agents = [];
                            if (options.defaults)
                                object.nextPageToken = "";
                            if (message.agents && message.agents.length) {
                                object.agents = [];
                                for (var j = 0; j < message.agents.length; ++j)
                                    object.agents[j] = $root.google.cloud.dialogflow.v2.Agent.toObject(message.agents[j], options);
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                object.nextPageToken = message.nextPageToken;
                            return object;
                        };
    
                        /**
                         * Converts this SearchAgentsResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.SearchAgentsResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SearchAgentsResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SearchAgentsResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.SearchAgentsResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SearchAgentsResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.SearchAgentsResponse";
                        };
    
                        return SearchAgentsResponse;
                    })();
    
                    v2.TrainAgentRequest = (function() {
    
                        /**
                         * Properties of a TrainAgentRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ITrainAgentRequest
                         * @property {string|null} [parent] TrainAgentRequest parent
                         */
    
                        /**
                         * Constructs a new TrainAgentRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a TrainAgentRequest.
                         * @implements ITrainAgentRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ITrainAgentRequest=} [properties] Properties to set
                         */
                        function TrainAgentRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * TrainAgentRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.TrainAgentRequest
                         * @instance
                         */
                        TrainAgentRequest.prototype.parent = "";
    
                        /**
                         * Creates a new TrainAgentRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.TrainAgentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ITrainAgentRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.TrainAgentRequest} TrainAgentRequest instance
                         */
                        TrainAgentRequest.create = function create(properties) {
                            return new TrainAgentRequest(properties);
                        };
    
                        /**
                         * Encodes the specified TrainAgentRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.TrainAgentRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.TrainAgentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ITrainAgentRequest} message TrainAgentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        TrainAgentRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified TrainAgentRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.TrainAgentRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.TrainAgentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ITrainAgentRequest} message TrainAgentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        TrainAgentRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a TrainAgentRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.TrainAgentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.TrainAgentRequest} TrainAgentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        TrainAgentRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.TrainAgentRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a TrainAgentRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.TrainAgentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.TrainAgentRequest} TrainAgentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        TrainAgentRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a TrainAgentRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.TrainAgentRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        TrainAgentRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a TrainAgentRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.TrainAgentRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.TrainAgentRequest} TrainAgentRequest
                         */
                        TrainAgentRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.TrainAgentRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.TrainAgentRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a TrainAgentRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.TrainAgentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.TrainAgentRequest} message TrainAgentRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        TrainAgentRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.parent = "";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            return object;
                        };
    
                        /**
                         * Converts this TrainAgentRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.TrainAgentRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        TrainAgentRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for TrainAgentRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.TrainAgentRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        TrainAgentRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.TrainAgentRequest";
                        };
    
                        return TrainAgentRequest;
                    })();
    
                    v2.ExportAgentRequest = (function() {
    
                        /**
                         * Properties of an ExportAgentRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IExportAgentRequest
                         * @property {string|null} [parent] ExportAgentRequest parent
                         * @property {string|null} [agentUri] ExportAgentRequest agentUri
                         */
    
                        /**
                         * Constructs a new ExportAgentRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an ExportAgentRequest.
                         * @implements IExportAgentRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IExportAgentRequest=} [properties] Properties to set
                         */
                        function ExportAgentRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ExportAgentRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.ExportAgentRequest
                         * @instance
                         */
                        ExportAgentRequest.prototype.parent = "";
    
                        /**
                         * ExportAgentRequest agentUri.
                         * @member {string} agentUri
                         * @memberof google.cloud.dialogflow.v2.ExportAgentRequest
                         * @instance
                         */
                        ExportAgentRequest.prototype.agentUri = "";
    
                        /**
                         * Creates a new ExportAgentRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ExportAgentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IExportAgentRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ExportAgentRequest} ExportAgentRequest instance
                         */
                        ExportAgentRequest.create = function create(properties) {
                            return new ExportAgentRequest(properties);
                        };
    
                        /**
                         * Encodes the specified ExportAgentRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.ExportAgentRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ExportAgentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IExportAgentRequest} message ExportAgentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ExportAgentRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.agentUri != null && Object.hasOwnProperty.call(message, "agentUri"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.agentUri);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ExportAgentRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ExportAgentRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ExportAgentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IExportAgentRequest} message ExportAgentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ExportAgentRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an ExportAgentRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ExportAgentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ExportAgentRequest} ExportAgentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ExportAgentRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ExportAgentRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.agentUri = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an ExportAgentRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ExportAgentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ExportAgentRequest} ExportAgentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ExportAgentRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an ExportAgentRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ExportAgentRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ExportAgentRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.agentUri != null && message.hasOwnProperty("agentUri"))
                                if (!$util.isString(message.agentUri))
                                    return "agentUri: string expected";
                            return null;
                        };
    
                        /**
                         * Creates an ExportAgentRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ExportAgentRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ExportAgentRequest} ExportAgentRequest
                         */
                        ExportAgentRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ExportAgentRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ExportAgentRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.agentUri != null)
                                message.agentUri = String(object.agentUri);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an ExportAgentRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ExportAgentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ExportAgentRequest} message ExportAgentRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ExportAgentRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.agentUri = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.agentUri != null && message.hasOwnProperty("agentUri"))
                                object.agentUri = message.agentUri;
                            return object;
                        };
    
                        /**
                         * Converts this ExportAgentRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ExportAgentRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ExportAgentRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ExportAgentRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ExportAgentRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ExportAgentRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ExportAgentRequest";
                        };
    
                        return ExportAgentRequest;
                    })();
    
                    v2.ExportAgentResponse = (function() {
    
                        /**
                         * Properties of an ExportAgentResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IExportAgentResponse
                         * @property {string|null} [agentUri] ExportAgentResponse agentUri
                         * @property {Uint8Array|null} [agentContent] ExportAgentResponse agentContent
                         */
    
                        /**
                         * Constructs a new ExportAgentResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an ExportAgentResponse.
                         * @implements IExportAgentResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IExportAgentResponse=} [properties] Properties to set
                         */
                        function ExportAgentResponse(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ExportAgentResponse agentUri.
                         * @member {string|null|undefined} agentUri
                         * @memberof google.cloud.dialogflow.v2.ExportAgentResponse
                         * @instance
                         */
                        ExportAgentResponse.prototype.agentUri = null;
    
                        /**
                         * ExportAgentResponse agentContent.
                         * @member {Uint8Array|null|undefined} agentContent
                         * @memberof google.cloud.dialogflow.v2.ExportAgentResponse
                         * @instance
                         */
                        ExportAgentResponse.prototype.agentContent = null;
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * ExportAgentResponse agent.
                         * @member {"agentUri"|"agentContent"|undefined} agent
                         * @memberof google.cloud.dialogflow.v2.ExportAgentResponse
                         * @instance
                         */
                        Object.defineProperty(ExportAgentResponse.prototype, "agent", {
                            get: $util.oneOfGetter($oneOfFields = ["agentUri", "agentContent"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new ExportAgentResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ExportAgentResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IExportAgentResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ExportAgentResponse} ExportAgentResponse instance
                         */
                        ExportAgentResponse.create = function create(properties) {
                            return new ExportAgentResponse(properties);
                        };
    
                        /**
                         * Encodes the specified ExportAgentResponse message. Does not implicitly {@link google.cloud.dialogflow.v2.ExportAgentResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ExportAgentResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IExportAgentResponse} message ExportAgentResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ExportAgentResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.agentUri != null && Object.hasOwnProperty.call(message, "agentUri"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.agentUri);
                            if (message.agentContent != null && Object.hasOwnProperty.call(message, "agentContent"))
                                writer.uint32(/* id 2, wireType 2 =*/18).bytes(message.agentContent);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ExportAgentResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ExportAgentResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ExportAgentResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IExportAgentResponse} message ExportAgentResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ExportAgentResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an ExportAgentResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ExportAgentResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ExportAgentResponse} ExportAgentResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ExportAgentResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ExportAgentResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.agentUri = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.agentContent = reader.bytes();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an ExportAgentResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ExportAgentResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ExportAgentResponse} ExportAgentResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ExportAgentResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an ExportAgentResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ExportAgentResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ExportAgentResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.agentUri != null && message.hasOwnProperty("agentUri")) {
                                properties.agent = 1;
                                if (!$util.isString(message.agentUri))
                                    return "agentUri: string expected";
                            }
                            if (message.agentContent != null && message.hasOwnProperty("agentContent")) {
                                if (properties.agent === 1)
                                    return "agent: multiple values";
                                properties.agent = 1;
                                if (!(message.agentContent && typeof message.agentContent.length === "number" || $util.isString(message.agentContent)))
                                    return "agentContent: buffer expected";
                            }
                            return null;
                        };
    
                        /**
                         * Creates an ExportAgentResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ExportAgentResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ExportAgentResponse} ExportAgentResponse
                         */
                        ExportAgentResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ExportAgentResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ExportAgentResponse();
                            if (object.agentUri != null)
                                message.agentUri = String(object.agentUri);
                            if (object.agentContent != null)
                                if (typeof object.agentContent === "string")
                                    $util.base64.decode(object.agentContent, message.agentContent = $util.newBuffer($util.base64.length(object.agentContent)), 0);
                                else if (object.agentContent.length >= 0)
                                    message.agentContent = object.agentContent;
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an ExportAgentResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ExportAgentResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.ExportAgentResponse} message ExportAgentResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ExportAgentResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (message.agentUri != null && message.hasOwnProperty("agentUri")) {
                                object.agentUri = message.agentUri;
                                if (options.oneofs)
                                    object.agent = "agentUri";
                            }
                            if (message.agentContent != null && message.hasOwnProperty("agentContent")) {
                                object.agentContent = options.bytes === String ? $util.base64.encode(message.agentContent, 0, message.agentContent.length) : options.bytes === Array ? Array.prototype.slice.call(message.agentContent) : message.agentContent;
                                if (options.oneofs)
                                    object.agent = "agentContent";
                            }
                            return object;
                        };
    
                        /**
                         * Converts this ExportAgentResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ExportAgentResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ExportAgentResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ExportAgentResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ExportAgentResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ExportAgentResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ExportAgentResponse";
                        };
    
                        return ExportAgentResponse;
                    })();
    
                    v2.ImportAgentRequest = (function() {
    
                        /**
                         * Properties of an ImportAgentRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IImportAgentRequest
                         * @property {string|null} [parent] ImportAgentRequest parent
                         * @property {string|null} [agentUri] ImportAgentRequest agentUri
                         * @property {Uint8Array|null} [agentContent] ImportAgentRequest agentContent
                         */
    
                        /**
                         * Constructs a new ImportAgentRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an ImportAgentRequest.
                         * @implements IImportAgentRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IImportAgentRequest=} [properties] Properties to set
                         */
                        function ImportAgentRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ImportAgentRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.ImportAgentRequest
                         * @instance
                         */
                        ImportAgentRequest.prototype.parent = "";
    
                        /**
                         * ImportAgentRequest agentUri.
                         * @member {string|null|undefined} agentUri
                         * @memberof google.cloud.dialogflow.v2.ImportAgentRequest
                         * @instance
                         */
                        ImportAgentRequest.prototype.agentUri = null;
    
                        /**
                         * ImportAgentRequest agentContent.
                         * @member {Uint8Array|null|undefined} agentContent
                         * @memberof google.cloud.dialogflow.v2.ImportAgentRequest
                         * @instance
                         */
                        ImportAgentRequest.prototype.agentContent = null;
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * ImportAgentRequest agent.
                         * @member {"agentUri"|"agentContent"|undefined} agent
                         * @memberof google.cloud.dialogflow.v2.ImportAgentRequest
                         * @instance
                         */
                        Object.defineProperty(ImportAgentRequest.prototype, "agent", {
                            get: $util.oneOfGetter($oneOfFields = ["agentUri", "agentContent"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new ImportAgentRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ImportAgentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IImportAgentRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ImportAgentRequest} ImportAgentRequest instance
                         */
                        ImportAgentRequest.create = function create(properties) {
                            return new ImportAgentRequest(properties);
                        };
    
                        /**
                         * Encodes the specified ImportAgentRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.ImportAgentRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ImportAgentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IImportAgentRequest} message ImportAgentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ImportAgentRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.agentUri != null && Object.hasOwnProperty.call(message, "agentUri"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.agentUri);
                            if (message.agentContent != null && Object.hasOwnProperty.call(message, "agentContent"))
                                writer.uint32(/* id 3, wireType 2 =*/26).bytes(message.agentContent);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ImportAgentRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ImportAgentRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ImportAgentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IImportAgentRequest} message ImportAgentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ImportAgentRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an ImportAgentRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ImportAgentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ImportAgentRequest} ImportAgentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ImportAgentRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ImportAgentRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.agentUri = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.agentContent = reader.bytes();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an ImportAgentRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ImportAgentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ImportAgentRequest} ImportAgentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ImportAgentRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an ImportAgentRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ImportAgentRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ImportAgentRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.agentUri != null && message.hasOwnProperty("agentUri")) {
                                properties.agent = 1;
                                if (!$util.isString(message.agentUri))
                                    return "agentUri: string expected";
                            }
                            if (message.agentContent != null && message.hasOwnProperty("agentContent")) {
                                if (properties.agent === 1)
                                    return "agent: multiple values";
                                properties.agent = 1;
                                if (!(message.agentContent && typeof message.agentContent.length === "number" || $util.isString(message.agentContent)))
                                    return "agentContent: buffer expected";
                            }
                            return null;
                        };
    
                        /**
                         * Creates an ImportAgentRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ImportAgentRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ImportAgentRequest} ImportAgentRequest
                         */
                        ImportAgentRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ImportAgentRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ImportAgentRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.agentUri != null)
                                message.agentUri = String(object.agentUri);
                            if (object.agentContent != null)
                                if (typeof object.agentContent === "string")
                                    $util.base64.decode(object.agentContent, message.agentContent = $util.newBuffer($util.base64.length(object.agentContent)), 0);
                                else if (object.agentContent.length >= 0)
                                    message.agentContent = object.agentContent;
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an ImportAgentRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ImportAgentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ImportAgentRequest} message ImportAgentRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ImportAgentRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.parent = "";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.agentUri != null && message.hasOwnProperty("agentUri")) {
                                object.agentUri = message.agentUri;
                                if (options.oneofs)
                                    object.agent = "agentUri";
                            }
                            if (message.agentContent != null && message.hasOwnProperty("agentContent")) {
                                object.agentContent = options.bytes === String ? $util.base64.encode(message.agentContent, 0, message.agentContent.length) : options.bytes === Array ? Array.prototype.slice.call(message.agentContent) : message.agentContent;
                                if (options.oneofs)
                                    object.agent = "agentContent";
                            }
                            return object;
                        };
    
                        /**
                         * Converts this ImportAgentRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ImportAgentRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ImportAgentRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ImportAgentRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ImportAgentRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ImportAgentRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ImportAgentRequest";
                        };
    
                        return ImportAgentRequest;
                    })();
    
                    v2.RestoreAgentRequest = (function() {
    
                        /**
                         * Properties of a RestoreAgentRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IRestoreAgentRequest
                         * @property {string|null} [parent] RestoreAgentRequest parent
                         * @property {string|null} [agentUri] RestoreAgentRequest agentUri
                         * @property {Uint8Array|null} [agentContent] RestoreAgentRequest agentContent
                         */
    
                        /**
                         * Constructs a new RestoreAgentRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a RestoreAgentRequest.
                         * @implements IRestoreAgentRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IRestoreAgentRequest=} [properties] Properties to set
                         */
                        function RestoreAgentRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * RestoreAgentRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.RestoreAgentRequest
                         * @instance
                         */
                        RestoreAgentRequest.prototype.parent = "";
    
                        /**
                         * RestoreAgentRequest agentUri.
                         * @member {string|null|undefined} agentUri
                         * @memberof google.cloud.dialogflow.v2.RestoreAgentRequest
                         * @instance
                         */
                        RestoreAgentRequest.prototype.agentUri = null;
    
                        /**
                         * RestoreAgentRequest agentContent.
                         * @member {Uint8Array|null|undefined} agentContent
                         * @memberof google.cloud.dialogflow.v2.RestoreAgentRequest
                         * @instance
                         */
                        RestoreAgentRequest.prototype.agentContent = null;
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * RestoreAgentRequest agent.
                         * @member {"agentUri"|"agentContent"|undefined} agent
                         * @memberof google.cloud.dialogflow.v2.RestoreAgentRequest
                         * @instance
                         */
                        Object.defineProperty(RestoreAgentRequest.prototype, "agent", {
                            get: $util.oneOfGetter($oneOfFields = ["agentUri", "agentContent"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new RestoreAgentRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.RestoreAgentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IRestoreAgentRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.RestoreAgentRequest} RestoreAgentRequest instance
                         */
                        RestoreAgentRequest.create = function create(properties) {
                            return new RestoreAgentRequest(properties);
                        };
    
                        /**
                         * Encodes the specified RestoreAgentRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.RestoreAgentRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.RestoreAgentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IRestoreAgentRequest} message RestoreAgentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        RestoreAgentRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.agentUri != null && Object.hasOwnProperty.call(message, "agentUri"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.agentUri);
                            if (message.agentContent != null && Object.hasOwnProperty.call(message, "agentContent"))
                                writer.uint32(/* id 3, wireType 2 =*/26).bytes(message.agentContent);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified RestoreAgentRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.RestoreAgentRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.RestoreAgentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IRestoreAgentRequest} message RestoreAgentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        RestoreAgentRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a RestoreAgentRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.RestoreAgentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.RestoreAgentRequest} RestoreAgentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        RestoreAgentRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.RestoreAgentRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.agentUri = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.agentContent = reader.bytes();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a RestoreAgentRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.RestoreAgentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.RestoreAgentRequest} RestoreAgentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        RestoreAgentRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a RestoreAgentRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.RestoreAgentRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        RestoreAgentRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.agentUri != null && message.hasOwnProperty("agentUri")) {
                                properties.agent = 1;
                                if (!$util.isString(message.agentUri))
                                    return "agentUri: string expected";
                            }
                            if (message.agentContent != null && message.hasOwnProperty("agentContent")) {
                                if (properties.agent === 1)
                                    return "agent: multiple values";
                                properties.agent = 1;
                                if (!(message.agentContent && typeof message.agentContent.length === "number" || $util.isString(message.agentContent)))
                                    return "agentContent: buffer expected";
                            }
                            return null;
                        };
    
                        /**
                         * Creates a RestoreAgentRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.RestoreAgentRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.RestoreAgentRequest} RestoreAgentRequest
                         */
                        RestoreAgentRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.RestoreAgentRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.RestoreAgentRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.agentUri != null)
                                message.agentUri = String(object.agentUri);
                            if (object.agentContent != null)
                                if (typeof object.agentContent === "string")
                                    $util.base64.decode(object.agentContent, message.agentContent = $util.newBuffer($util.base64.length(object.agentContent)), 0);
                                else if (object.agentContent.length >= 0)
                                    message.agentContent = object.agentContent;
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a RestoreAgentRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.RestoreAgentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.RestoreAgentRequest} message RestoreAgentRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        RestoreAgentRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.parent = "";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.agentUri != null && message.hasOwnProperty("agentUri")) {
                                object.agentUri = message.agentUri;
                                if (options.oneofs)
                                    object.agent = "agentUri";
                            }
                            if (message.agentContent != null && message.hasOwnProperty("agentContent")) {
                                object.agentContent = options.bytes === String ? $util.base64.encode(message.agentContent, 0, message.agentContent.length) : options.bytes === Array ? Array.prototype.slice.call(message.agentContent) : message.agentContent;
                                if (options.oneofs)
                                    object.agent = "agentContent";
                            }
                            return object;
                        };
    
                        /**
                         * Converts this RestoreAgentRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.RestoreAgentRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        RestoreAgentRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for RestoreAgentRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.RestoreAgentRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        RestoreAgentRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.RestoreAgentRequest";
                        };
    
                        return RestoreAgentRequest;
                    })();
    
                    v2.GetValidationResultRequest = (function() {
    
                        /**
                         * Properties of a GetValidationResultRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IGetValidationResultRequest
                         * @property {string|null} [parent] GetValidationResultRequest parent
                         * @property {string|null} [languageCode] GetValidationResultRequest languageCode
                         */
    
                        /**
                         * Constructs a new GetValidationResultRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a GetValidationResultRequest.
                         * @implements IGetValidationResultRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IGetValidationResultRequest=} [properties] Properties to set
                         */
                        function GetValidationResultRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GetValidationResultRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.GetValidationResultRequest
                         * @instance
                         */
                        GetValidationResultRequest.prototype.parent = "";
    
                        /**
                         * GetValidationResultRequest languageCode.
                         * @member {string} languageCode
                         * @memberof google.cloud.dialogflow.v2.GetValidationResultRequest
                         * @instance
                         */
                        GetValidationResultRequest.prototype.languageCode = "";
    
                        /**
                         * Creates a new GetValidationResultRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.GetValidationResultRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetValidationResultRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.GetValidationResultRequest} GetValidationResultRequest instance
                         */
                        GetValidationResultRequest.create = function create(properties) {
                            return new GetValidationResultRequest(properties);
                        };
    
                        /**
                         * Encodes the specified GetValidationResultRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.GetValidationResultRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.GetValidationResultRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetValidationResultRequest} message GetValidationResultRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetValidationResultRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.languageCode != null && Object.hasOwnProperty.call(message, "languageCode"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.languageCode);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GetValidationResultRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.GetValidationResultRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GetValidationResultRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetValidationResultRequest} message GetValidationResultRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetValidationResultRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GetValidationResultRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.GetValidationResultRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.GetValidationResultRequest} GetValidationResultRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetValidationResultRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.GetValidationResultRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.languageCode = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GetValidationResultRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GetValidationResultRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.GetValidationResultRequest} GetValidationResultRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetValidationResultRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GetValidationResultRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.GetValidationResultRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GetValidationResultRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                if (!$util.isString(message.languageCode))
                                    return "languageCode: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a GetValidationResultRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.GetValidationResultRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.GetValidationResultRequest} GetValidationResultRequest
                         */
                        GetValidationResultRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.GetValidationResultRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.GetValidationResultRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.languageCode != null)
                                message.languageCode = String(object.languageCode);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GetValidationResultRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.GetValidationResultRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.GetValidationResultRequest} message GetValidationResultRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GetValidationResultRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.languageCode = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                object.languageCode = message.languageCode;
                            return object;
                        };
    
                        /**
                         * Converts this GetValidationResultRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.GetValidationResultRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GetValidationResultRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GetValidationResultRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.GetValidationResultRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GetValidationResultRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.GetValidationResultRequest";
                        };
    
                        return GetValidationResultRequest;
                    })();
    
                    v2.ValidationError = (function() {
    
                        /**
                         * Properties of a ValidationError.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IValidationError
                         * @property {google.cloud.dialogflow.v2.ValidationError.Severity|null} [severity] ValidationError severity
                         * @property {Array.<string>|null} [entries] ValidationError entries
                         * @property {string|null} [errorMessage] ValidationError errorMessage
                         */
    
                        /**
                         * Constructs a new ValidationError.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a ValidationError.
                         * @implements IValidationError
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IValidationError=} [properties] Properties to set
                         */
                        function ValidationError(properties) {
                            this.entries = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ValidationError severity.
                         * @member {google.cloud.dialogflow.v2.ValidationError.Severity} severity
                         * @memberof google.cloud.dialogflow.v2.ValidationError
                         * @instance
                         */
                        ValidationError.prototype.severity = 0;
    
                        /**
                         * ValidationError entries.
                         * @member {Array.<string>} entries
                         * @memberof google.cloud.dialogflow.v2.ValidationError
                         * @instance
                         */
                        ValidationError.prototype.entries = $util.emptyArray;
    
                        /**
                         * ValidationError errorMessage.
                         * @member {string} errorMessage
                         * @memberof google.cloud.dialogflow.v2.ValidationError
                         * @instance
                         */
                        ValidationError.prototype.errorMessage = "";
    
                        /**
                         * Creates a new ValidationError instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ValidationError
                         * @static
                         * @param {google.cloud.dialogflow.v2.IValidationError=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ValidationError} ValidationError instance
                         */
                        ValidationError.create = function create(properties) {
                            return new ValidationError(properties);
                        };
    
                        /**
                         * Encodes the specified ValidationError message. Does not implicitly {@link google.cloud.dialogflow.v2.ValidationError.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ValidationError
                         * @static
                         * @param {google.cloud.dialogflow.v2.IValidationError} message ValidationError message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ValidationError.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.severity != null && Object.hasOwnProperty.call(message, "severity"))
                                writer.uint32(/* id 1, wireType 0 =*/8).int32(message.severity);
                            if (message.entries != null && message.entries.length)
                                for (var i = 0; i < message.entries.length; ++i)
                                    writer.uint32(/* id 3, wireType 2 =*/26).string(message.entries[i]);
                            if (message.errorMessage != null && Object.hasOwnProperty.call(message, "errorMessage"))
                                writer.uint32(/* id 4, wireType 2 =*/34).string(message.errorMessage);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ValidationError message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ValidationError.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ValidationError
                         * @static
                         * @param {google.cloud.dialogflow.v2.IValidationError} message ValidationError message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ValidationError.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ValidationError message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ValidationError
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ValidationError} ValidationError
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ValidationError.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ValidationError();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.severity = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        if (!(message.entries && message.entries.length))
                                            message.entries = [];
                                        message.entries.push(reader.string());
                                        break;
                                    }
                                case 4: {
                                        message.errorMessage = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ValidationError message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ValidationError
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ValidationError} ValidationError
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ValidationError.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ValidationError message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ValidationError
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ValidationError.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.severity != null && message.hasOwnProperty("severity"))
                                switch (message.severity) {
                                default:
                                    return "severity: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                case 4:
                                    break;
                                }
                            if (message.entries != null && message.hasOwnProperty("entries")) {
                                if (!Array.isArray(message.entries))
                                    return "entries: array expected";
                                for (var i = 0; i < message.entries.length; ++i)
                                    if (!$util.isString(message.entries[i]))
                                        return "entries: string[] expected";
                            }
                            if (message.errorMessage != null && message.hasOwnProperty("errorMessage"))
                                if (!$util.isString(message.errorMessage))
                                    return "errorMessage: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ValidationError message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ValidationError
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ValidationError} ValidationError
                         */
                        ValidationError.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ValidationError)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ValidationError();
                            switch (object.severity) {
                            default:
                                if (typeof object.severity === "number") {
                                    message.severity = object.severity;
                                    break;
                                }
                                break;
                            case "SEVERITY_UNSPECIFIED":
                            case 0:
                                message.severity = 0;
                                break;
                            case "INFO":
                            case 1:
                                message.severity = 1;
                                break;
                            case "WARNING":
                            case 2:
                                message.severity = 2;
                                break;
                            case "ERROR":
                            case 3:
                                message.severity = 3;
                                break;
                            case "CRITICAL":
                            case 4:
                                message.severity = 4;
                                break;
                            }
                            if (object.entries) {
                                if (!Array.isArray(object.entries))
                                    throw TypeError(".google.cloud.dialogflow.v2.ValidationError.entries: array expected");
                                message.entries = [];
                                for (var i = 0; i < object.entries.length; ++i)
                                    message.entries[i] = String(object.entries[i]);
                            }
                            if (object.errorMessage != null)
                                message.errorMessage = String(object.errorMessage);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ValidationError message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ValidationError
                         * @static
                         * @param {google.cloud.dialogflow.v2.ValidationError} message ValidationError
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ValidationError.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.entries = [];
                            if (options.defaults) {
                                object.severity = options.enums === String ? "SEVERITY_UNSPECIFIED" : 0;
                                object.errorMessage = "";
                            }
                            if (message.severity != null && message.hasOwnProperty("severity"))
                                object.severity = options.enums === String ? $root.google.cloud.dialogflow.v2.ValidationError.Severity[message.severity] === undefined ? message.severity : $root.google.cloud.dialogflow.v2.ValidationError.Severity[message.severity] : message.severity;
                            if (message.entries && message.entries.length) {
                                object.entries = [];
                                for (var j = 0; j < message.entries.length; ++j)
                                    object.entries[j] = message.entries[j];
                            }
                            if (message.errorMessage != null && message.hasOwnProperty("errorMessage"))
                                object.errorMessage = message.errorMessage;
                            return object;
                        };
    
                        /**
                         * Converts this ValidationError to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ValidationError
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ValidationError.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ValidationError
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ValidationError
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ValidationError.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ValidationError";
                        };
    
                        /**
                         * Severity enum.
                         * @name google.cloud.dialogflow.v2.ValidationError.Severity
                         * @enum {number}
                         * @property {number} SEVERITY_UNSPECIFIED=0 SEVERITY_UNSPECIFIED value
                         * @property {number} INFO=1 INFO value
                         * @property {number} WARNING=2 WARNING value
                         * @property {number} ERROR=3 ERROR value
                         * @property {number} CRITICAL=4 CRITICAL value
                         */
                        ValidationError.Severity = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "SEVERITY_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "INFO"] = 1;
                            values[valuesById[2] = "WARNING"] = 2;
                            values[valuesById[3] = "ERROR"] = 3;
                            values[valuesById[4] = "CRITICAL"] = 4;
                            return values;
                        })();
    
                        return ValidationError;
                    })();
    
                    v2.ValidationResult = (function() {
    
                        /**
                         * Properties of a ValidationResult.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IValidationResult
                         * @property {Array.<google.cloud.dialogflow.v2.IValidationError>|null} [validationErrors] ValidationResult validationErrors
                         */
    
                        /**
                         * Constructs a new ValidationResult.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a ValidationResult.
                         * @implements IValidationResult
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IValidationResult=} [properties] Properties to set
                         */
                        function ValidationResult(properties) {
                            this.validationErrors = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ValidationResult validationErrors.
                         * @member {Array.<google.cloud.dialogflow.v2.IValidationError>} validationErrors
                         * @memberof google.cloud.dialogflow.v2.ValidationResult
                         * @instance
                         */
                        ValidationResult.prototype.validationErrors = $util.emptyArray;
    
                        /**
                         * Creates a new ValidationResult instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ValidationResult
                         * @static
                         * @param {google.cloud.dialogflow.v2.IValidationResult=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ValidationResult} ValidationResult instance
                         */
                        ValidationResult.create = function create(properties) {
                            return new ValidationResult(properties);
                        };
    
                        /**
                         * Encodes the specified ValidationResult message. Does not implicitly {@link google.cloud.dialogflow.v2.ValidationResult.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ValidationResult
                         * @static
                         * @param {google.cloud.dialogflow.v2.IValidationResult} message ValidationResult message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ValidationResult.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.validationErrors != null && message.validationErrors.length)
                                for (var i = 0; i < message.validationErrors.length; ++i)
                                    $root.google.cloud.dialogflow.v2.ValidationError.encode(message.validationErrors[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ValidationResult message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ValidationResult.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ValidationResult
                         * @static
                         * @param {google.cloud.dialogflow.v2.IValidationResult} message ValidationResult message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ValidationResult.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ValidationResult message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ValidationResult
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ValidationResult} ValidationResult
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ValidationResult.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ValidationResult();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.validationErrors && message.validationErrors.length))
                                            message.validationErrors = [];
                                        message.validationErrors.push($root.google.cloud.dialogflow.v2.ValidationError.decode(reader, reader.uint32()));
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ValidationResult message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ValidationResult
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ValidationResult} ValidationResult
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ValidationResult.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ValidationResult message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ValidationResult
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ValidationResult.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.validationErrors != null && message.hasOwnProperty("validationErrors")) {
                                if (!Array.isArray(message.validationErrors))
                                    return "validationErrors: array expected";
                                for (var i = 0; i < message.validationErrors.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.ValidationError.verify(message.validationErrors[i]);
                                    if (error)
                                        return "validationErrors." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates a ValidationResult message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ValidationResult
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ValidationResult} ValidationResult
                         */
                        ValidationResult.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ValidationResult)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ValidationResult();
                            if (object.validationErrors) {
                                if (!Array.isArray(object.validationErrors))
                                    throw TypeError(".google.cloud.dialogflow.v2.ValidationResult.validationErrors: array expected");
                                message.validationErrors = [];
                                for (var i = 0; i < object.validationErrors.length; ++i) {
                                    if (typeof object.validationErrors[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.ValidationResult.validationErrors: object expected");
                                    message.validationErrors[i] = $root.google.cloud.dialogflow.v2.ValidationError.fromObject(object.validationErrors[i]);
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ValidationResult message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ValidationResult
                         * @static
                         * @param {google.cloud.dialogflow.v2.ValidationResult} message ValidationResult
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ValidationResult.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.validationErrors = [];
                            if (message.validationErrors && message.validationErrors.length) {
                                object.validationErrors = [];
                                for (var j = 0; j < message.validationErrors.length; ++j)
                                    object.validationErrors[j] = $root.google.cloud.dialogflow.v2.ValidationError.toObject(message.validationErrors[j], options);
                            }
                            return object;
                        };
    
                        /**
                         * Converts this ValidationResult to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ValidationResult
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ValidationResult.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ValidationResult
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ValidationResult
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ValidationResult.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ValidationResult";
                        };
    
                        return ValidationResult;
                    })();
    
                    v2.AnswerRecords = (function() {
    
                        /**
                         * Constructs a new AnswerRecords service.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an AnswerRecords
                         * @extends $protobuf.rpc.Service
                         * @constructor
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         */
                        function AnswerRecords(rpcImpl, requestDelimited, responseDelimited) {
                            $protobuf.rpc.Service.call(this, rpcImpl, requestDelimited, responseDelimited);
                        }
    
                        (AnswerRecords.prototype = Object.create($protobuf.rpc.Service.prototype)).constructor = AnswerRecords;
    
                        /**
                         * Creates new AnswerRecords service using the specified rpc implementation.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.AnswerRecords
                         * @static
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         * @returns {AnswerRecords} RPC service. Useful where requests and/or responses are streamed.
                         */
                        AnswerRecords.create = function create(rpcImpl, requestDelimited, responseDelimited) {
                            return new this(rpcImpl, requestDelimited, responseDelimited);
                        };
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.AnswerRecords|listAnswerRecords}.
                         * @memberof google.cloud.dialogflow.v2.AnswerRecords
                         * @typedef ListAnswerRecordsCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.ListAnswerRecordsResponse} [response] ListAnswerRecordsResponse
                         */
    
                        /**
                         * Calls ListAnswerRecords.
                         * @function listAnswerRecords
                         * @memberof google.cloud.dialogflow.v2.AnswerRecords
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IListAnswerRecordsRequest} request ListAnswerRecordsRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.AnswerRecords.ListAnswerRecordsCallback} callback Node-style callback called with the error, if any, and ListAnswerRecordsResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(AnswerRecords.prototype.listAnswerRecords = function listAnswerRecords(request, callback) {
                            return this.rpcCall(listAnswerRecords, $root.google.cloud.dialogflow.v2.ListAnswerRecordsRequest, $root.google.cloud.dialogflow.v2.ListAnswerRecordsResponse, request, callback);
                        }, "name", { value: "ListAnswerRecords" });
    
                        /**
                         * Calls ListAnswerRecords.
                         * @function listAnswerRecords
                         * @memberof google.cloud.dialogflow.v2.AnswerRecords
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IListAnswerRecordsRequest} request ListAnswerRecordsRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.ListAnswerRecordsResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.AnswerRecords|updateAnswerRecord}.
                         * @memberof google.cloud.dialogflow.v2.AnswerRecords
                         * @typedef UpdateAnswerRecordCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.AnswerRecord} [response] AnswerRecord
                         */
    
                        /**
                         * Calls UpdateAnswerRecord.
                         * @function updateAnswerRecord
                         * @memberof google.cloud.dialogflow.v2.AnswerRecords
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IUpdateAnswerRecordRequest} request UpdateAnswerRecordRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.AnswerRecords.UpdateAnswerRecordCallback} callback Node-style callback called with the error, if any, and AnswerRecord
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(AnswerRecords.prototype.updateAnswerRecord = function updateAnswerRecord(request, callback) {
                            return this.rpcCall(updateAnswerRecord, $root.google.cloud.dialogflow.v2.UpdateAnswerRecordRequest, $root.google.cloud.dialogflow.v2.AnswerRecord, request, callback);
                        }, "name", { value: "UpdateAnswerRecord" });
    
                        /**
                         * Calls UpdateAnswerRecord.
                         * @function updateAnswerRecord
                         * @memberof google.cloud.dialogflow.v2.AnswerRecords
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IUpdateAnswerRecordRequest} request UpdateAnswerRecordRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.AnswerRecord>} Promise
                         * @variation 2
                         */
    
                        return AnswerRecords;
                    })();
    
                    v2.AnswerRecord = (function() {
    
                        /**
                         * Properties of an AnswerRecord.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IAnswerRecord
                         * @property {string|null} [name] AnswerRecord name
                         * @property {google.cloud.dialogflow.v2.IAnswerFeedback|null} [answerFeedback] AnswerRecord answerFeedback
                         * @property {google.cloud.dialogflow.v2.IAgentAssistantRecord|null} [agentAssistantRecord] AnswerRecord agentAssistantRecord
                         */
    
                        /**
                         * Constructs a new AnswerRecord.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an AnswerRecord.
                         * @implements IAnswerRecord
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IAnswerRecord=} [properties] Properties to set
                         */
                        function AnswerRecord(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * AnswerRecord name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2.AnswerRecord
                         * @instance
                         */
                        AnswerRecord.prototype.name = "";
    
                        /**
                         * AnswerRecord answerFeedback.
                         * @member {google.cloud.dialogflow.v2.IAnswerFeedback|null|undefined} answerFeedback
                         * @memberof google.cloud.dialogflow.v2.AnswerRecord
                         * @instance
                         */
                        AnswerRecord.prototype.answerFeedback = null;
    
                        /**
                         * AnswerRecord agentAssistantRecord.
                         * @member {google.cloud.dialogflow.v2.IAgentAssistantRecord|null|undefined} agentAssistantRecord
                         * @memberof google.cloud.dialogflow.v2.AnswerRecord
                         * @instance
                         */
                        AnswerRecord.prototype.agentAssistantRecord = null;
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * AnswerRecord record.
                         * @member {"agentAssistantRecord"|undefined} record
                         * @memberof google.cloud.dialogflow.v2.AnswerRecord
                         * @instance
                         */
                        Object.defineProperty(AnswerRecord.prototype, "record", {
                            get: $util.oneOfGetter($oneOfFields = ["agentAssistantRecord"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new AnswerRecord instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.AnswerRecord
                         * @static
                         * @param {google.cloud.dialogflow.v2.IAnswerRecord=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.AnswerRecord} AnswerRecord instance
                         */
                        AnswerRecord.create = function create(properties) {
                            return new AnswerRecord(properties);
                        };
    
                        /**
                         * Encodes the specified AnswerRecord message. Does not implicitly {@link google.cloud.dialogflow.v2.AnswerRecord.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.AnswerRecord
                         * @static
                         * @param {google.cloud.dialogflow.v2.IAnswerRecord} message AnswerRecord message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        AnswerRecord.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            if (message.answerFeedback != null && Object.hasOwnProperty.call(message, "answerFeedback"))
                                $root.google.cloud.dialogflow.v2.AnswerFeedback.encode(message.answerFeedback, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.agentAssistantRecord != null && Object.hasOwnProperty.call(message, "agentAssistantRecord"))
                                $root.google.cloud.dialogflow.v2.AgentAssistantRecord.encode(message.agentAssistantRecord, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified AnswerRecord message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.AnswerRecord.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.AnswerRecord
                         * @static
                         * @param {google.cloud.dialogflow.v2.IAnswerRecord} message AnswerRecord message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        AnswerRecord.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an AnswerRecord message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.AnswerRecord
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.AnswerRecord} AnswerRecord
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        AnswerRecord.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.AnswerRecord();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.answerFeedback = $root.google.cloud.dialogflow.v2.AnswerFeedback.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 4: {
                                        message.agentAssistantRecord = $root.google.cloud.dialogflow.v2.AgentAssistantRecord.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an AnswerRecord message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.AnswerRecord
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.AnswerRecord} AnswerRecord
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        AnswerRecord.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an AnswerRecord message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.AnswerRecord
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        AnswerRecord.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            if (message.answerFeedback != null && message.hasOwnProperty("answerFeedback")) {
                                var error = $root.google.cloud.dialogflow.v2.AnswerFeedback.verify(message.answerFeedback);
                                if (error)
                                    return "answerFeedback." + error;
                            }
                            if (message.agentAssistantRecord != null && message.hasOwnProperty("agentAssistantRecord")) {
                                properties.record = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2.AgentAssistantRecord.verify(message.agentAssistantRecord);
                                    if (error)
                                        return "agentAssistantRecord." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates an AnswerRecord message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.AnswerRecord
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.AnswerRecord} AnswerRecord
                         */
                        AnswerRecord.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.AnswerRecord)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.AnswerRecord();
                            if (object.name != null)
                                message.name = String(object.name);
                            if (object.answerFeedback != null) {
                                if (typeof object.answerFeedback !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.AnswerRecord.answerFeedback: object expected");
                                message.answerFeedback = $root.google.cloud.dialogflow.v2.AnswerFeedback.fromObject(object.answerFeedback);
                            }
                            if (object.agentAssistantRecord != null) {
                                if (typeof object.agentAssistantRecord !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.AnswerRecord.agentAssistantRecord: object expected");
                                message.agentAssistantRecord = $root.google.cloud.dialogflow.v2.AgentAssistantRecord.fromObject(object.agentAssistantRecord);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an AnswerRecord message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.AnswerRecord
                         * @static
                         * @param {google.cloud.dialogflow.v2.AnswerRecord} message AnswerRecord
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        AnswerRecord.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.name = "";
                                object.answerFeedback = null;
                            }
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            if (message.answerFeedback != null && message.hasOwnProperty("answerFeedback"))
                                object.answerFeedback = $root.google.cloud.dialogflow.v2.AnswerFeedback.toObject(message.answerFeedback, options);
                            if (message.agentAssistantRecord != null && message.hasOwnProperty("agentAssistantRecord")) {
                                object.agentAssistantRecord = $root.google.cloud.dialogflow.v2.AgentAssistantRecord.toObject(message.agentAssistantRecord, options);
                                if (options.oneofs)
                                    object.record = "agentAssistantRecord";
                            }
                            return object;
                        };
    
                        /**
                         * Converts this AnswerRecord to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.AnswerRecord
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        AnswerRecord.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for AnswerRecord
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.AnswerRecord
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        AnswerRecord.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.AnswerRecord";
                        };
    
                        return AnswerRecord;
                    })();
    
                    v2.ListAnswerRecordsRequest = (function() {
    
                        /**
                         * Properties of a ListAnswerRecordsRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IListAnswerRecordsRequest
                         * @property {string|null} [parent] ListAnswerRecordsRequest parent
                         * @property {string|null} [filter] ListAnswerRecordsRequest filter
                         * @property {number|null} [pageSize] ListAnswerRecordsRequest pageSize
                         * @property {string|null} [pageToken] ListAnswerRecordsRequest pageToken
                         */
    
                        /**
                         * Constructs a new ListAnswerRecordsRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a ListAnswerRecordsRequest.
                         * @implements IListAnswerRecordsRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IListAnswerRecordsRequest=} [properties] Properties to set
                         */
                        function ListAnswerRecordsRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListAnswerRecordsRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.ListAnswerRecordsRequest
                         * @instance
                         */
                        ListAnswerRecordsRequest.prototype.parent = "";
    
                        /**
                         * ListAnswerRecordsRequest filter.
                         * @member {string} filter
                         * @memberof google.cloud.dialogflow.v2.ListAnswerRecordsRequest
                         * @instance
                         */
                        ListAnswerRecordsRequest.prototype.filter = "";
    
                        /**
                         * ListAnswerRecordsRequest pageSize.
                         * @member {number} pageSize
                         * @memberof google.cloud.dialogflow.v2.ListAnswerRecordsRequest
                         * @instance
                         */
                        ListAnswerRecordsRequest.prototype.pageSize = 0;
    
                        /**
                         * ListAnswerRecordsRequest pageToken.
                         * @member {string} pageToken
                         * @memberof google.cloud.dialogflow.v2.ListAnswerRecordsRequest
                         * @instance
                         */
                        ListAnswerRecordsRequest.prototype.pageToken = "";
    
                        /**
                         * Creates a new ListAnswerRecordsRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ListAnswerRecordsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListAnswerRecordsRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ListAnswerRecordsRequest} ListAnswerRecordsRequest instance
                         */
                        ListAnswerRecordsRequest.create = function create(properties) {
                            return new ListAnswerRecordsRequest(properties);
                        };
    
                        /**
                         * Encodes the specified ListAnswerRecordsRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.ListAnswerRecordsRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ListAnswerRecordsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListAnswerRecordsRequest} message ListAnswerRecordsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListAnswerRecordsRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.filter != null && Object.hasOwnProperty.call(message, "filter"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.filter);
                            if (message.pageSize != null && Object.hasOwnProperty.call(message, "pageSize"))
                                writer.uint32(/* id 3, wireType 0 =*/24).int32(message.pageSize);
                            if (message.pageToken != null && Object.hasOwnProperty.call(message, "pageToken"))
                                writer.uint32(/* id 4, wireType 2 =*/34).string(message.pageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListAnswerRecordsRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ListAnswerRecordsRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListAnswerRecordsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListAnswerRecordsRequest} message ListAnswerRecordsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListAnswerRecordsRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListAnswerRecordsRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ListAnswerRecordsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ListAnswerRecordsRequest} ListAnswerRecordsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListAnswerRecordsRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ListAnswerRecordsRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.filter = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.pageSize = reader.int32();
                                        break;
                                    }
                                case 4: {
                                        message.pageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListAnswerRecordsRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListAnswerRecordsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ListAnswerRecordsRequest} ListAnswerRecordsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListAnswerRecordsRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListAnswerRecordsRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ListAnswerRecordsRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListAnswerRecordsRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.filter != null && message.hasOwnProperty("filter"))
                                if (!$util.isString(message.filter))
                                    return "filter: string expected";
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                if (!$util.isInteger(message.pageSize))
                                    return "pageSize: integer expected";
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                if (!$util.isString(message.pageToken))
                                    return "pageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListAnswerRecordsRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ListAnswerRecordsRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ListAnswerRecordsRequest} ListAnswerRecordsRequest
                         */
                        ListAnswerRecordsRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ListAnswerRecordsRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ListAnswerRecordsRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.filter != null)
                                message.filter = String(object.filter);
                            if (object.pageSize != null)
                                message.pageSize = object.pageSize | 0;
                            if (object.pageToken != null)
                                message.pageToken = String(object.pageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListAnswerRecordsRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ListAnswerRecordsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ListAnswerRecordsRequest} message ListAnswerRecordsRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListAnswerRecordsRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.filter = "";
                                object.pageSize = 0;
                                object.pageToken = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.filter != null && message.hasOwnProperty("filter"))
                                object.filter = message.filter;
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                object.pageSize = message.pageSize;
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                object.pageToken = message.pageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListAnswerRecordsRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ListAnswerRecordsRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListAnswerRecordsRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListAnswerRecordsRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ListAnswerRecordsRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListAnswerRecordsRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ListAnswerRecordsRequest";
                        };
    
                        return ListAnswerRecordsRequest;
                    })();
    
                    v2.ListAnswerRecordsResponse = (function() {
    
                        /**
                         * Properties of a ListAnswerRecordsResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IListAnswerRecordsResponse
                         * @property {Array.<google.cloud.dialogflow.v2.IAnswerRecord>|null} [answerRecords] ListAnswerRecordsResponse answerRecords
                         * @property {string|null} [nextPageToken] ListAnswerRecordsResponse nextPageToken
                         */
    
                        /**
                         * Constructs a new ListAnswerRecordsResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a ListAnswerRecordsResponse.
                         * @implements IListAnswerRecordsResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IListAnswerRecordsResponse=} [properties] Properties to set
                         */
                        function ListAnswerRecordsResponse(properties) {
                            this.answerRecords = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListAnswerRecordsResponse answerRecords.
                         * @member {Array.<google.cloud.dialogflow.v2.IAnswerRecord>} answerRecords
                         * @memberof google.cloud.dialogflow.v2.ListAnswerRecordsResponse
                         * @instance
                         */
                        ListAnswerRecordsResponse.prototype.answerRecords = $util.emptyArray;
    
                        /**
                         * ListAnswerRecordsResponse nextPageToken.
                         * @member {string} nextPageToken
                         * @memberof google.cloud.dialogflow.v2.ListAnswerRecordsResponse
                         * @instance
                         */
                        ListAnswerRecordsResponse.prototype.nextPageToken = "";
    
                        /**
                         * Creates a new ListAnswerRecordsResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ListAnswerRecordsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListAnswerRecordsResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ListAnswerRecordsResponse} ListAnswerRecordsResponse instance
                         */
                        ListAnswerRecordsResponse.create = function create(properties) {
                            return new ListAnswerRecordsResponse(properties);
                        };
    
                        /**
                         * Encodes the specified ListAnswerRecordsResponse message. Does not implicitly {@link google.cloud.dialogflow.v2.ListAnswerRecordsResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ListAnswerRecordsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListAnswerRecordsResponse} message ListAnswerRecordsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListAnswerRecordsResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.answerRecords != null && message.answerRecords.length)
                                for (var i = 0; i < message.answerRecords.length; ++i)
                                    $root.google.cloud.dialogflow.v2.AnswerRecord.encode(message.answerRecords[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.nextPageToken != null && Object.hasOwnProperty.call(message, "nextPageToken"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.nextPageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListAnswerRecordsResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ListAnswerRecordsResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListAnswerRecordsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListAnswerRecordsResponse} message ListAnswerRecordsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListAnswerRecordsResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListAnswerRecordsResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ListAnswerRecordsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ListAnswerRecordsResponse} ListAnswerRecordsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListAnswerRecordsResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ListAnswerRecordsResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.answerRecords && message.answerRecords.length))
                                            message.answerRecords = [];
                                        message.answerRecords.push($root.google.cloud.dialogflow.v2.AnswerRecord.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 2: {
                                        message.nextPageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListAnswerRecordsResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListAnswerRecordsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ListAnswerRecordsResponse} ListAnswerRecordsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListAnswerRecordsResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListAnswerRecordsResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ListAnswerRecordsResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListAnswerRecordsResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.answerRecords != null && message.hasOwnProperty("answerRecords")) {
                                if (!Array.isArray(message.answerRecords))
                                    return "answerRecords: array expected";
                                for (var i = 0; i < message.answerRecords.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.AnswerRecord.verify(message.answerRecords[i]);
                                    if (error)
                                        return "answerRecords." + error;
                                }
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                if (!$util.isString(message.nextPageToken))
                                    return "nextPageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListAnswerRecordsResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ListAnswerRecordsResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ListAnswerRecordsResponse} ListAnswerRecordsResponse
                         */
                        ListAnswerRecordsResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ListAnswerRecordsResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ListAnswerRecordsResponse();
                            if (object.answerRecords) {
                                if (!Array.isArray(object.answerRecords))
                                    throw TypeError(".google.cloud.dialogflow.v2.ListAnswerRecordsResponse.answerRecords: array expected");
                                message.answerRecords = [];
                                for (var i = 0; i < object.answerRecords.length; ++i) {
                                    if (typeof object.answerRecords[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.ListAnswerRecordsResponse.answerRecords: object expected");
                                    message.answerRecords[i] = $root.google.cloud.dialogflow.v2.AnswerRecord.fromObject(object.answerRecords[i]);
                                }
                            }
                            if (object.nextPageToken != null)
                                message.nextPageToken = String(object.nextPageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListAnswerRecordsResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ListAnswerRecordsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.ListAnswerRecordsResponse} message ListAnswerRecordsResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListAnswerRecordsResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.answerRecords = [];
                            if (options.defaults)
                                object.nextPageToken = "";
                            if (message.answerRecords && message.answerRecords.length) {
                                object.answerRecords = [];
                                for (var j = 0; j < message.answerRecords.length; ++j)
                                    object.answerRecords[j] = $root.google.cloud.dialogflow.v2.AnswerRecord.toObject(message.answerRecords[j], options);
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                object.nextPageToken = message.nextPageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListAnswerRecordsResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ListAnswerRecordsResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListAnswerRecordsResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListAnswerRecordsResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ListAnswerRecordsResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListAnswerRecordsResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ListAnswerRecordsResponse";
                        };
    
                        return ListAnswerRecordsResponse;
                    })();
    
                    v2.UpdateAnswerRecordRequest = (function() {
    
                        /**
                         * Properties of an UpdateAnswerRecordRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IUpdateAnswerRecordRequest
                         * @property {google.cloud.dialogflow.v2.IAnswerRecord|null} [answerRecord] UpdateAnswerRecordRequest answerRecord
                         * @property {google.protobuf.IFieldMask|null} [updateMask] UpdateAnswerRecordRequest updateMask
                         */
    
                        /**
                         * Constructs a new UpdateAnswerRecordRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an UpdateAnswerRecordRequest.
                         * @implements IUpdateAnswerRecordRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IUpdateAnswerRecordRequest=} [properties] Properties to set
                         */
                        function UpdateAnswerRecordRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * UpdateAnswerRecordRequest answerRecord.
                         * @member {google.cloud.dialogflow.v2.IAnswerRecord|null|undefined} answerRecord
                         * @memberof google.cloud.dialogflow.v2.UpdateAnswerRecordRequest
                         * @instance
                         */
                        UpdateAnswerRecordRequest.prototype.answerRecord = null;
    
                        /**
                         * UpdateAnswerRecordRequest updateMask.
                         * @member {google.protobuf.IFieldMask|null|undefined} updateMask
                         * @memberof google.cloud.dialogflow.v2.UpdateAnswerRecordRequest
                         * @instance
                         */
                        UpdateAnswerRecordRequest.prototype.updateMask = null;
    
                        /**
                         * Creates a new UpdateAnswerRecordRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.UpdateAnswerRecordRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IUpdateAnswerRecordRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.UpdateAnswerRecordRequest} UpdateAnswerRecordRequest instance
                         */
                        UpdateAnswerRecordRequest.create = function create(properties) {
                            return new UpdateAnswerRecordRequest(properties);
                        };
    
                        /**
                         * Encodes the specified UpdateAnswerRecordRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.UpdateAnswerRecordRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.UpdateAnswerRecordRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IUpdateAnswerRecordRequest} message UpdateAnswerRecordRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UpdateAnswerRecordRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.answerRecord != null && Object.hasOwnProperty.call(message, "answerRecord"))
                                $root.google.cloud.dialogflow.v2.AnswerRecord.encode(message.answerRecord, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.updateMask != null && Object.hasOwnProperty.call(message, "updateMask"))
                                $root.google.protobuf.FieldMask.encode(message.updateMask, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified UpdateAnswerRecordRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.UpdateAnswerRecordRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.UpdateAnswerRecordRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IUpdateAnswerRecordRequest} message UpdateAnswerRecordRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UpdateAnswerRecordRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an UpdateAnswerRecordRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.UpdateAnswerRecordRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.UpdateAnswerRecordRequest} UpdateAnswerRecordRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UpdateAnswerRecordRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.UpdateAnswerRecordRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.answerRecord = $root.google.cloud.dialogflow.v2.AnswerRecord.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.updateMask = $root.google.protobuf.FieldMask.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an UpdateAnswerRecordRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.UpdateAnswerRecordRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.UpdateAnswerRecordRequest} UpdateAnswerRecordRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UpdateAnswerRecordRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an UpdateAnswerRecordRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.UpdateAnswerRecordRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        UpdateAnswerRecordRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.answerRecord != null && message.hasOwnProperty("answerRecord")) {
                                var error = $root.google.cloud.dialogflow.v2.AnswerRecord.verify(message.answerRecord);
                                if (error)
                                    return "answerRecord." + error;
                            }
                            if (message.updateMask != null && message.hasOwnProperty("updateMask")) {
                                var error = $root.google.protobuf.FieldMask.verify(message.updateMask);
                                if (error)
                                    return "updateMask." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates an UpdateAnswerRecordRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.UpdateAnswerRecordRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.UpdateAnswerRecordRequest} UpdateAnswerRecordRequest
                         */
                        UpdateAnswerRecordRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.UpdateAnswerRecordRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.UpdateAnswerRecordRequest();
                            if (object.answerRecord != null) {
                                if (typeof object.answerRecord !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.UpdateAnswerRecordRequest.answerRecord: object expected");
                                message.answerRecord = $root.google.cloud.dialogflow.v2.AnswerRecord.fromObject(object.answerRecord);
                            }
                            if (object.updateMask != null) {
                                if (typeof object.updateMask !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.UpdateAnswerRecordRequest.updateMask: object expected");
                                message.updateMask = $root.google.protobuf.FieldMask.fromObject(object.updateMask);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an UpdateAnswerRecordRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.UpdateAnswerRecordRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.UpdateAnswerRecordRequest} message UpdateAnswerRecordRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        UpdateAnswerRecordRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.answerRecord = null;
                                object.updateMask = null;
                            }
                            if (message.answerRecord != null && message.hasOwnProperty("answerRecord"))
                                object.answerRecord = $root.google.cloud.dialogflow.v2.AnswerRecord.toObject(message.answerRecord, options);
                            if (message.updateMask != null && message.hasOwnProperty("updateMask"))
                                object.updateMask = $root.google.protobuf.FieldMask.toObject(message.updateMask, options);
                            return object;
                        };
    
                        /**
                         * Converts this UpdateAnswerRecordRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.UpdateAnswerRecordRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        UpdateAnswerRecordRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for UpdateAnswerRecordRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.UpdateAnswerRecordRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        UpdateAnswerRecordRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.UpdateAnswerRecordRequest";
                        };
    
                        return UpdateAnswerRecordRequest;
                    })();
    
                    v2.AnswerFeedback = (function() {
    
                        /**
                         * Properties of an AnswerFeedback.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IAnswerFeedback
                         * @property {google.cloud.dialogflow.v2.AnswerFeedback.CorrectnessLevel|null} [correctnessLevel] AnswerFeedback correctnessLevel
                         * @property {google.cloud.dialogflow.v2.IAgentAssistantFeedback|null} [agentAssistantDetailFeedback] AnswerFeedback agentAssistantDetailFeedback
                         * @property {boolean|null} [clicked] AnswerFeedback clicked
                         * @property {google.protobuf.ITimestamp|null} [clickTime] AnswerFeedback clickTime
                         * @property {boolean|null} [displayed] AnswerFeedback displayed
                         * @property {google.protobuf.ITimestamp|null} [displayTime] AnswerFeedback displayTime
                         */
    
                        /**
                         * Constructs a new AnswerFeedback.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an AnswerFeedback.
                         * @implements IAnswerFeedback
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IAnswerFeedback=} [properties] Properties to set
                         */
                        function AnswerFeedback(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * AnswerFeedback correctnessLevel.
                         * @member {google.cloud.dialogflow.v2.AnswerFeedback.CorrectnessLevel} correctnessLevel
                         * @memberof google.cloud.dialogflow.v2.AnswerFeedback
                         * @instance
                         */
                        AnswerFeedback.prototype.correctnessLevel = 0;
    
                        /**
                         * AnswerFeedback agentAssistantDetailFeedback.
                         * @member {google.cloud.dialogflow.v2.IAgentAssistantFeedback|null|undefined} agentAssistantDetailFeedback
                         * @memberof google.cloud.dialogflow.v2.AnswerFeedback
                         * @instance
                         */
                        AnswerFeedback.prototype.agentAssistantDetailFeedback = null;
    
                        /**
                         * AnswerFeedback clicked.
                         * @member {boolean} clicked
                         * @memberof google.cloud.dialogflow.v2.AnswerFeedback
                         * @instance
                         */
                        AnswerFeedback.prototype.clicked = false;
    
                        /**
                         * AnswerFeedback clickTime.
                         * @member {google.protobuf.ITimestamp|null|undefined} clickTime
                         * @memberof google.cloud.dialogflow.v2.AnswerFeedback
                         * @instance
                         */
                        AnswerFeedback.prototype.clickTime = null;
    
                        /**
                         * AnswerFeedback displayed.
                         * @member {boolean} displayed
                         * @memberof google.cloud.dialogflow.v2.AnswerFeedback
                         * @instance
                         */
                        AnswerFeedback.prototype.displayed = false;
    
                        /**
                         * AnswerFeedback displayTime.
                         * @member {google.protobuf.ITimestamp|null|undefined} displayTime
                         * @memberof google.cloud.dialogflow.v2.AnswerFeedback
                         * @instance
                         */
                        AnswerFeedback.prototype.displayTime = null;
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * AnswerFeedback detailFeedback.
                         * @member {"agentAssistantDetailFeedback"|undefined} detailFeedback
                         * @memberof google.cloud.dialogflow.v2.AnswerFeedback
                         * @instance
                         */
                        Object.defineProperty(AnswerFeedback.prototype, "detailFeedback", {
                            get: $util.oneOfGetter($oneOfFields = ["agentAssistantDetailFeedback"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new AnswerFeedback instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.AnswerFeedback
                         * @static
                         * @param {google.cloud.dialogflow.v2.IAnswerFeedback=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.AnswerFeedback} AnswerFeedback instance
                         */
                        AnswerFeedback.create = function create(properties) {
                            return new AnswerFeedback(properties);
                        };
    
                        /**
                         * Encodes the specified AnswerFeedback message. Does not implicitly {@link google.cloud.dialogflow.v2.AnswerFeedback.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.AnswerFeedback
                         * @static
                         * @param {google.cloud.dialogflow.v2.IAnswerFeedback} message AnswerFeedback message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        AnswerFeedback.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.correctnessLevel != null && Object.hasOwnProperty.call(message, "correctnessLevel"))
                                writer.uint32(/* id 1, wireType 0 =*/8).int32(message.correctnessLevel);
                            if (message.agentAssistantDetailFeedback != null && Object.hasOwnProperty.call(message, "agentAssistantDetailFeedback"))
                                $root.google.cloud.dialogflow.v2.AgentAssistantFeedback.encode(message.agentAssistantDetailFeedback, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.clicked != null && Object.hasOwnProperty.call(message, "clicked"))
                                writer.uint32(/* id 3, wireType 0 =*/24).bool(message.clicked);
                            if (message.displayed != null && Object.hasOwnProperty.call(message, "displayed"))
                                writer.uint32(/* id 4, wireType 0 =*/32).bool(message.displayed);
                            if (message.clickTime != null && Object.hasOwnProperty.call(message, "clickTime"))
                                $root.google.protobuf.Timestamp.encode(message.clickTime, writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                            if (message.displayTime != null && Object.hasOwnProperty.call(message, "displayTime"))
                                $root.google.protobuf.Timestamp.encode(message.displayTime, writer.uint32(/* id 6, wireType 2 =*/50).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified AnswerFeedback message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.AnswerFeedback.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.AnswerFeedback
                         * @static
                         * @param {google.cloud.dialogflow.v2.IAnswerFeedback} message AnswerFeedback message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        AnswerFeedback.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an AnswerFeedback message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.AnswerFeedback
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.AnswerFeedback} AnswerFeedback
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        AnswerFeedback.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.AnswerFeedback();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.correctnessLevel = reader.int32();
                                        break;
                                    }
                                case 2: {
                                        message.agentAssistantDetailFeedback = $root.google.cloud.dialogflow.v2.AgentAssistantFeedback.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 3: {
                                        message.clicked = reader.bool();
                                        break;
                                    }
                                case 5: {
                                        message.clickTime = $root.google.protobuf.Timestamp.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 4: {
                                        message.displayed = reader.bool();
                                        break;
                                    }
                                case 6: {
                                        message.displayTime = $root.google.protobuf.Timestamp.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an AnswerFeedback message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.AnswerFeedback
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.AnswerFeedback} AnswerFeedback
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        AnswerFeedback.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an AnswerFeedback message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.AnswerFeedback
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        AnswerFeedback.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.correctnessLevel != null && message.hasOwnProperty("correctnessLevel"))
                                switch (message.correctnessLevel) {
                                default:
                                    return "correctnessLevel: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                    break;
                                }
                            if (message.agentAssistantDetailFeedback != null && message.hasOwnProperty("agentAssistantDetailFeedback")) {
                                properties.detailFeedback = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2.AgentAssistantFeedback.verify(message.agentAssistantDetailFeedback);
                                    if (error)
                                        return "agentAssistantDetailFeedback." + error;
                                }
                            }
                            if (message.clicked != null && message.hasOwnProperty("clicked"))
                                if (typeof message.clicked !== "boolean")
                                    return "clicked: boolean expected";
                            if (message.clickTime != null && message.hasOwnProperty("clickTime")) {
                                var error = $root.google.protobuf.Timestamp.verify(message.clickTime);
                                if (error)
                                    return "clickTime." + error;
                            }
                            if (message.displayed != null && message.hasOwnProperty("displayed"))
                                if (typeof message.displayed !== "boolean")
                                    return "displayed: boolean expected";
                            if (message.displayTime != null && message.hasOwnProperty("displayTime")) {
                                var error = $root.google.protobuf.Timestamp.verify(message.displayTime);
                                if (error)
                                    return "displayTime." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates an AnswerFeedback message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.AnswerFeedback
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.AnswerFeedback} AnswerFeedback
                         */
                        AnswerFeedback.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.AnswerFeedback)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.AnswerFeedback();
                            switch (object.correctnessLevel) {
                            default:
                                if (typeof object.correctnessLevel === "number") {
                                    message.correctnessLevel = object.correctnessLevel;
                                    break;
                                }
                                break;
                            case "CORRECTNESS_LEVEL_UNSPECIFIED":
                            case 0:
                                message.correctnessLevel = 0;
                                break;
                            case "NOT_CORRECT":
                            case 1:
                                message.correctnessLevel = 1;
                                break;
                            case "PARTIALLY_CORRECT":
                            case 2:
                                message.correctnessLevel = 2;
                                break;
                            case "FULLY_CORRECT":
                            case 3:
                                message.correctnessLevel = 3;
                                break;
                            }
                            if (object.agentAssistantDetailFeedback != null) {
                                if (typeof object.agentAssistantDetailFeedback !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.AnswerFeedback.agentAssistantDetailFeedback: object expected");
                                message.agentAssistantDetailFeedback = $root.google.cloud.dialogflow.v2.AgentAssistantFeedback.fromObject(object.agentAssistantDetailFeedback);
                            }
                            if (object.clicked != null)
                                message.clicked = Boolean(object.clicked);
                            if (object.clickTime != null) {
                                if (typeof object.clickTime !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.AnswerFeedback.clickTime: object expected");
                                message.clickTime = $root.google.protobuf.Timestamp.fromObject(object.clickTime);
                            }
                            if (object.displayed != null)
                                message.displayed = Boolean(object.displayed);
                            if (object.displayTime != null) {
                                if (typeof object.displayTime !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.AnswerFeedback.displayTime: object expected");
                                message.displayTime = $root.google.protobuf.Timestamp.fromObject(object.displayTime);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an AnswerFeedback message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.AnswerFeedback
                         * @static
                         * @param {google.cloud.dialogflow.v2.AnswerFeedback} message AnswerFeedback
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        AnswerFeedback.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.correctnessLevel = options.enums === String ? "CORRECTNESS_LEVEL_UNSPECIFIED" : 0;
                                object.clicked = false;
                                object.displayed = false;
                                object.clickTime = null;
                                object.displayTime = null;
                            }
                            if (message.correctnessLevel != null && message.hasOwnProperty("correctnessLevel"))
                                object.correctnessLevel = options.enums === String ? $root.google.cloud.dialogflow.v2.AnswerFeedback.CorrectnessLevel[message.correctnessLevel] === undefined ? message.correctnessLevel : $root.google.cloud.dialogflow.v2.AnswerFeedback.CorrectnessLevel[message.correctnessLevel] : message.correctnessLevel;
                            if (message.agentAssistantDetailFeedback != null && message.hasOwnProperty("agentAssistantDetailFeedback")) {
                                object.agentAssistantDetailFeedback = $root.google.cloud.dialogflow.v2.AgentAssistantFeedback.toObject(message.agentAssistantDetailFeedback, options);
                                if (options.oneofs)
                                    object.detailFeedback = "agentAssistantDetailFeedback";
                            }
                            if (message.clicked != null && message.hasOwnProperty("clicked"))
                                object.clicked = message.clicked;
                            if (message.displayed != null && message.hasOwnProperty("displayed"))
                                object.displayed = message.displayed;
                            if (message.clickTime != null && message.hasOwnProperty("clickTime"))
                                object.clickTime = $root.google.protobuf.Timestamp.toObject(message.clickTime, options);
                            if (message.displayTime != null && message.hasOwnProperty("displayTime"))
                                object.displayTime = $root.google.protobuf.Timestamp.toObject(message.displayTime, options);
                            return object;
                        };
    
                        /**
                         * Converts this AnswerFeedback to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.AnswerFeedback
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        AnswerFeedback.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for AnswerFeedback
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.AnswerFeedback
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        AnswerFeedback.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.AnswerFeedback";
                        };
    
                        /**
                         * CorrectnessLevel enum.
                         * @name google.cloud.dialogflow.v2.AnswerFeedback.CorrectnessLevel
                         * @enum {number}
                         * @property {number} CORRECTNESS_LEVEL_UNSPECIFIED=0 CORRECTNESS_LEVEL_UNSPECIFIED value
                         * @property {number} NOT_CORRECT=1 NOT_CORRECT value
                         * @property {number} PARTIALLY_CORRECT=2 PARTIALLY_CORRECT value
                         * @property {number} FULLY_CORRECT=3 FULLY_CORRECT value
                         */
                        AnswerFeedback.CorrectnessLevel = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "CORRECTNESS_LEVEL_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "NOT_CORRECT"] = 1;
                            values[valuesById[2] = "PARTIALLY_CORRECT"] = 2;
                            values[valuesById[3] = "FULLY_CORRECT"] = 3;
                            return values;
                        })();
    
                        return AnswerFeedback;
                    })();
    
                    v2.AgentAssistantFeedback = (function() {
    
                        /**
                         * Properties of an AgentAssistantFeedback.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IAgentAssistantFeedback
                         * @property {google.cloud.dialogflow.v2.AgentAssistantFeedback.AnswerRelevance|null} [answerRelevance] AgentAssistantFeedback answerRelevance
                         * @property {google.cloud.dialogflow.v2.AgentAssistantFeedback.DocumentCorrectness|null} [documentCorrectness] AgentAssistantFeedback documentCorrectness
                         * @property {google.cloud.dialogflow.v2.AgentAssistantFeedback.DocumentEfficiency|null} [documentEfficiency] AgentAssistantFeedback documentEfficiency
                         * @property {google.cloud.dialogflow.v2.AgentAssistantFeedback.ISummarizationFeedback|null} [summarizationFeedback] AgentAssistantFeedback summarizationFeedback
                         * @property {google.cloud.dialogflow.v2.AgentAssistantFeedback.IKnowledgeSearchFeedback|null} [knowledgeSearchFeedback] AgentAssistantFeedback knowledgeSearchFeedback
                         * @property {google.cloud.dialogflow.v2.AgentAssistantFeedback.IKnowledgeAssistFeedback|null} [knowledgeAssistFeedback] AgentAssistantFeedback knowledgeAssistFeedback
                         */
    
                        /**
                         * Constructs a new AgentAssistantFeedback.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an AgentAssistantFeedback.
                         * @implements IAgentAssistantFeedback
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IAgentAssistantFeedback=} [properties] Properties to set
                         */
                        function AgentAssistantFeedback(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * AgentAssistantFeedback answerRelevance.
                         * @member {google.cloud.dialogflow.v2.AgentAssistantFeedback.AnswerRelevance} answerRelevance
                         * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback
                         * @instance
                         */
                        AgentAssistantFeedback.prototype.answerRelevance = 0;
    
                        /**
                         * AgentAssistantFeedback documentCorrectness.
                         * @member {google.cloud.dialogflow.v2.AgentAssistantFeedback.DocumentCorrectness} documentCorrectness
                         * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback
                         * @instance
                         */
                        AgentAssistantFeedback.prototype.documentCorrectness = 0;
    
                        /**
                         * AgentAssistantFeedback documentEfficiency.
                         * @member {google.cloud.dialogflow.v2.AgentAssistantFeedback.DocumentEfficiency} documentEfficiency
                         * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback
                         * @instance
                         */
                        AgentAssistantFeedback.prototype.documentEfficiency = 0;
    
                        /**
                         * AgentAssistantFeedback summarizationFeedback.
                         * @member {google.cloud.dialogflow.v2.AgentAssistantFeedback.ISummarizationFeedback|null|undefined} summarizationFeedback
                         * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback
                         * @instance
                         */
                        AgentAssistantFeedback.prototype.summarizationFeedback = null;
    
                        /**
                         * AgentAssistantFeedback knowledgeSearchFeedback.
                         * @member {google.cloud.dialogflow.v2.AgentAssistantFeedback.IKnowledgeSearchFeedback|null|undefined} knowledgeSearchFeedback
                         * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback
                         * @instance
                         */
                        AgentAssistantFeedback.prototype.knowledgeSearchFeedback = null;
    
                        /**
                         * AgentAssistantFeedback knowledgeAssistFeedback.
                         * @member {google.cloud.dialogflow.v2.AgentAssistantFeedback.IKnowledgeAssistFeedback|null|undefined} knowledgeAssistFeedback
                         * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback
                         * @instance
                         */
                        AgentAssistantFeedback.prototype.knowledgeAssistFeedback = null;
    
                        /**
                         * Creates a new AgentAssistantFeedback instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback
                         * @static
                         * @param {google.cloud.dialogflow.v2.IAgentAssistantFeedback=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.AgentAssistantFeedback} AgentAssistantFeedback instance
                         */
                        AgentAssistantFeedback.create = function create(properties) {
                            return new AgentAssistantFeedback(properties);
                        };
    
                        /**
                         * Encodes the specified AgentAssistantFeedback message. Does not implicitly {@link google.cloud.dialogflow.v2.AgentAssistantFeedback.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback
                         * @static
                         * @param {google.cloud.dialogflow.v2.IAgentAssistantFeedback} message AgentAssistantFeedback message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        AgentAssistantFeedback.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.answerRelevance != null && Object.hasOwnProperty.call(message, "answerRelevance"))
                                writer.uint32(/* id 1, wireType 0 =*/8).int32(message.answerRelevance);
                            if (message.documentCorrectness != null && Object.hasOwnProperty.call(message, "documentCorrectness"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.documentCorrectness);
                            if (message.documentEfficiency != null && Object.hasOwnProperty.call(message, "documentEfficiency"))
                                writer.uint32(/* id 3, wireType 0 =*/24).int32(message.documentEfficiency);
                            if (message.summarizationFeedback != null && Object.hasOwnProperty.call(message, "summarizationFeedback"))
                                $root.google.cloud.dialogflow.v2.AgentAssistantFeedback.SummarizationFeedback.encode(message.summarizationFeedback, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            if (message.knowledgeSearchFeedback != null && Object.hasOwnProperty.call(message, "knowledgeSearchFeedback"))
                                $root.google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeSearchFeedback.encode(message.knowledgeSearchFeedback, writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                            if (message.knowledgeAssistFeedback != null && Object.hasOwnProperty.call(message, "knowledgeAssistFeedback"))
                                $root.google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeAssistFeedback.encode(message.knowledgeAssistFeedback, writer.uint32(/* id 6, wireType 2 =*/50).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified AgentAssistantFeedback message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.AgentAssistantFeedback.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback
                         * @static
                         * @param {google.cloud.dialogflow.v2.IAgentAssistantFeedback} message AgentAssistantFeedback message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        AgentAssistantFeedback.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an AgentAssistantFeedback message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.AgentAssistantFeedback} AgentAssistantFeedback
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        AgentAssistantFeedback.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.AgentAssistantFeedback();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.answerRelevance = reader.int32();
                                        break;
                                    }
                                case 2: {
                                        message.documentCorrectness = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.documentEfficiency = reader.int32();
                                        break;
                                    }
                                case 4: {
                                        message.summarizationFeedback = $root.google.cloud.dialogflow.v2.AgentAssistantFeedback.SummarizationFeedback.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 5: {
                                        message.knowledgeSearchFeedback = $root.google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeSearchFeedback.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 6: {
                                        message.knowledgeAssistFeedback = $root.google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeAssistFeedback.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an AgentAssistantFeedback message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.AgentAssistantFeedback} AgentAssistantFeedback
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        AgentAssistantFeedback.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an AgentAssistantFeedback message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        AgentAssistantFeedback.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.answerRelevance != null && message.hasOwnProperty("answerRelevance"))
                                switch (message.answerRelevance) {
                                default:
                                    return "answerRelevance: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                    break;
                                }
                            if (message.documentCorrectness != null && message.hasOwnProperty("documentCorrectness"))
                                switch (message.documentCorrectness) {
                                default:
                                    return "documentCorrectness: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                    break;
                                }
                            if (message.documentEfficiency != null && message.hasOwnProperty("documentEfficiency"))
                                switch (message.documentEfficiency) {
                                default:
                                    return "documentEfficiency: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                    break;
                                }
                            if (message.summarizationFeedback != null && message.hasOwnProperty("summarizationFeedback")) {
                                var error = $root.google.cloud.dialogflow.v2.AgentAssistantFeedback.SummarizationFeedback.verify(message.summarizationFeedback);
                                if (error)
                                    return "summarizationFeedback." + error;
                            }
                            if (message.knowledgeSearchFeedback != null && message.hasOwnProperty("knowledgeSearchFeedback")) {
                                var error = $root.google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeSearchFeedback.verify(message.knowledgeSearchFeedback);
                                if (error)
                                    return "knowledgeSearchFeedback." + error;
                            }
                            if (message.knowledgeAssistFeedback != null && message.hasOwnProperty("knowledgeAssistFeedback")) {
                                var error = $root.google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeAssistFeedback.verify(message.knowledgeAssistFeedback);
                                if (error)
                                    return "knowledgeAssistFeedback." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates an AgentAssistantFeedback message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.AgentAssistantFeedback} AgentAssistantFeedback
                         */
                        AgentAssistantFeedback.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.AgentAssistantFeedback)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.AgentAssistantFeedback();
                            switch (object.answerRelevance) {
                            default:
                                if (typeof object.answerRelevance === "number") {
                                    message.answerRelevance = object.answerRelevance;
                                    break;
                                }
                                break;
                            case "ANSWER_RELEVANCE_UNSPECIFIED":
                            case 0:
                                message.answerRelevance = 0;
                                break;
                            case "IRRELEVANT":
                            case 1:
                                message.answerRelevance = 1;
                                break;
                            case "RELEVANT":
                            case 2:
                                message.answerRelevance = 2;
                                break;
                            }
                            switch (object.documentCorrectness) {
                            default:
                                if (typeof object.documentCorrectness === "number") {
                                    message.documentCorrectness = object.documentCorrectness;
                                    break;
                                }
                                break;
                            case "DOCUMENT_CORRECTNESS_UNSPECIFIED":
                            case 0:
                                message.documentCorrectness = 0;
                                break;
                            case "INCORRECT":
                            case 1:
                                message.documentCorrectness = 1;
                                break;
                            case "CORRECT":
                            case 2:
                                message.documentCorrectness = 2;
                                break;
                            }
                            switch (object.documentEfficiency) {
                            default:
                                if (typeof object.documentEfficiency === "number") {
                                    message.documentEfficiency = object.documentEfficiency;
                                    break;
                                }
                                break;
                            case "DOCUMENT_EFFICIENCY_UNSPECIFIED":
                            case 0:
                                message.documentEfficiency = 0;
                                break;
                            case "INEFFICIENT":
                            case 1:
                                message.documentEfficiency = 1;
                                break;
                            case "EFFICIENT":
                            case 2:
                                message.documentEfficiency = 2;
                                break;
                            }
                            if (object.summarizationFeedback != null) {
                                if (typeof object.summarizationFeedback !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.AgentAssistantFeedback.summarizationFeedback: object expected");
                                message.summarizationFeedback = $root.google.cloud.dialogflow.v2.AgentAssistantFeedback.SummarizationFeedback.fromObject(object.summarizationFeedback);
                            }
                            if (object.knowledgeSearchFeedback != null) {
                                if (typeof object.knowledgeSearchFeedback !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.AgentAssistantFeedback.knowledgeSearchFeedback: object expected");
                                message.knowledgeSearchFeedback = $root.google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeSearchFeedback.fromObject(object.knowledgeSearchFeedback);
                            }
                            if (object.knowledgeAssistFeedback != null) {
                                if (typeof object.knowledgeAssistFeedback !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.AgentAssistantFeedback.knowledgeAssistFeedback: object expected");
                                message.knowledgeAssistFeedback = $root.google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeAssistFeedback.fromObject(object.knowledgeAssistFeedback);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an AgentAssistantFeedback message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback
                         * @static
                         * @param {google.cloud.dialogflow.v2.AgentAssistantFeedback} message AgentAssistantFeedback
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        AgentAssistantFeedback.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.answerRelevance = options.enums === String ? "ANSWER_RELEVANCE_UNSPECIFIED" : 0;
                                object.documentCorrectness = options.enums === String ? "DOCUMENT_CORRECTNESS_UNSPECIFIED" : 0;
                                object.documentEfficiency = options.enums === String ? "DOCUMENT_EFFICIENCY_UNSPECIFIED" : 0;
                                object.summarizationFeedback = null;
                                object.knowledgeSearchFeedback = null;
                                object.knowledgeAssistFeedback = null;
                            }
                            if (message.answerRelevance != null && message.hasOwnProperty("answerRelevance"))
                                object.answerRelevance = options.enums === String ? $root.google.cloud.dialogflow.v2.AgentAssistantFeedback.AnswerRelevance[message.answerRelevance] === undefined ? message.answerRelevance : $root.google.cloud.dialogflow.v2.AgentAssistantFeedback.AnswerRelevance[message.answerRelevance] : message.answerRelevance;
                            if (message.documentCorrectness != null && message.hasOwnProperty("documentCorrectness"))
                                object.documentCorrectness = options.enums === String ? $root.google.cloud.dialogflow.v2.AgentAssistantFeedback.DocumentCorrectness[message.documentCorrectness] === undefined ? message.documentCorrectness : $root.google.cloud.dialogflow.v2.AgentAssistantFeedback.DocumentCorrectness[message.documentCorrectness] : message.documentCorrectness;
                            if (message.documentEfficiency != null && message.hasOwnProperty("documentEfficiency"))
                                object.documentEfficiency = options.enums === String ? $root.google.cloud.dialogflow.v2.AgentAssistantFeedback.DocumentEfficiency[message.documentEfficiency] === undefined ? message.documentEfficiency : $root.google.cloud.dialogflow.v2.AgentAssistantFeedback.DocumentEfficiency[message.documentEfficiency] : message.documentEfficiency;
                            if (message.summarizationFeedback != null && message.hasOwnProperty("summarizationFeedback"))
                                object.summarizationFeedback = $root.google.cloud.dialogflow.v2.AgentAssistantFeedback.SummarizationFeedback.toObject(message.summarizationFeedback, options);
                            if (message.knowledgeSearchFeedback != null && message.hasOwnProperty("knowledgeSearchFeedback"))
                                object.knowledgeSearchFeedback = $root.google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeSearchFeedback.toObject(message.knowledgeSearchFeedback, options);
                            if (message.knowledgeAssistFeedback != null && message.hasOwnProperty("knowledgeAssistFeedback"))
                                object.knowledgeAssistFeedback = $root.google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeAssistFeedback.toObject(message.knowledgeAssistFeedback, options);
                            return object;
                        };
    
                        /**
                         * Converts this AgentAssistantFeedback to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        AgentAssistantFeedback.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for AgentAssistantFeedback
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        AgentAssistantFeedback.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.AgentAssistantFeedback";
                        };
    
                        /**
                         * AnswerRelevance enum.
                         * @name google.cloud.dialogflow.v2.AgentAssistantFeedback.AnswerRelevance
                         * @enum {number}
                         * @property {number} ANSWER_RELEVANCE_UNSPECIFIED=0 ANSWER_RELEVANCE_UNSPECIFIED value
                         * @property {number} IRRELEVANT=1 IRRELEVANT value
                         * @property {number} RELEVANT=2 RELEVANT value
                         */
                        AgentAssistantFeedback.AnswerRelevance = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "ANSWER_RELEVANCE_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "IRRELEVANT"] = 1;
                            values[valuesById[2] = "RELEVANT"] = 2;
                            return values;
                        })();
    
                        /**
                         * DocumentCorrectness enum.
                         * @name google.cloud.dialogflow.v2.AgentAssistantFeedback.DocumentCorrectness
                         * @enum {number}
                         * @property {number} DOCUMENT_CORRECTNESS_UNSPECIFIED=0 DOCUMENT_CORRECTNESS_UNSPECIFIED value
                         * @property {number} INCORRECT=1 INCORRECT value
                         * @property {number} CORRECT=2 CORRECT value
                         */
                        AgentAssistantFeedback.DocumentCorrectness = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "DOCUMENT_CORRECTNESS_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "INCORRECT"] = 1;
                            values[valuesById[2] = "CORRECT"] = 2;
                            return values;
                        })();
    
                        /**
                         * DocumentEfficiency enum.
                         * @name google.cloud.dialogflow.v2.AgentAssistantFeedback.DocumentEfficiency
                         * @enum {number}
                         * @property {number} DOCUMENT_EFFICIENCY_UNSPECIFIED=0 DOCUMENT_EFFICIENCY_UNSPECIFIED value
                         * @property {number} INEFFICIENT=1 INEFFICIENT value
                         * @property {number} EFFICIENT=2 EFFICIENT value
                         */
                        AgentAssistantFeedback.DocumentEfficiency = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "DOCUMENT_EFFICIENCY_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "INEFFICIENT"] = 1;
                            values[valuesById[2] = "EFFICIENT"] = 2;
                            return values;
                        })();
    
                        AgentAssistantFeedback.SummarizationFeedback = (function() {
    
                            /**
                             * Properties of a SummarizationFeedback.
                             * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback
                             * @interface ISummarizationFeedback
                             * @property {google.protobuf.ITimestamp|null} [startTime] SummarizationFeedback startTime
                             * @property {google.protobuf.ITimestamp|null} [submitTime] SummarizationFeedback submitTime
                             * @property {string|null} [summaryText] SummarizationFeedback summaryText
                             * @property {Object.<string,string>|null} [textSections] SummarizationFeedback textSections
                             */
    
                            /**
                             * Constructs a new SummarizationFeedback.
                             * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback
                             * @classdesc Represents a SummarizationFeedback.
                             * @implements ISummarizationFeedback
                             * @constructor
                             * @param {google.cloud.dialogflow.v2.AgentAssistantFeedback.ISummarizationFeedback=} [properties] Properties to set
                             */
                            function SummarizationFeedback(properties) {
                                this.textSections = {};
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * SummarizationFeedback startTime.
                             * @member {google.protobuf.ITimestamp|null|undefined} startTime
                             * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback.SummarizationFeedback
                             * @instance
                             */
                            SummarizationFeedback.prototype.startTime = null;
    
                            /**
                             * SummarizationFeedback submitTime.
                             * @member {google.protobuf.ITimestamp|null|undefined} submitTime
                             * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback.SummarizationFeedback
                             * @instance
                             */
                            SummarizationFeedback.prototype.submitTime = null;
    
                            /**
                             * SummarizationFeedback summaryText.
                             * @member {string} summaryText
                             * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback.SummarizationFeedback
                             * @instance
                             */
                            SummarizationFeedback.prototype.summaryText = "";
    
                            /**
                             * SummarizationFeedback textSections.
                             * @member {Object.<string,string>} textSections
                             * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback.SummarizationFeedback
                             * @instance
                             */
                            SummarizationFeedback.prototype.textSections = $util.emptyObject;
    
                            /**
                             * Creates a new SummarizationFeedback instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback.SummarizationFeedback
                             * @static
                             * @param {google.cloud.dialogflow.v2.AgentAssistantFeedback.ISummarizationFeedback=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2.AgentAssistantFeedback.SummarizationFeedback} SummarizationFeedback instance
                             */
                            SummarizationFeedback.create = function create(properties) {
                                return new SummarizationFeedback(properties);
                            };
    
                            /**
                             * Encodes the specified SummarizationFeedback message. Does not implicitly {@link google.cloud.dialogflow.v2.AgentAssistantFeedback.SummarizationFeedback.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback.SummarizationFeedback
                             * @static
                             * @param {google.cloud.dialogflow.v2.AgentAssistantFeedback.ISummarizationFeedback} message SummarizationFeedback message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            SummarizationFeedback.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.startTime != null && Object.hasOwnProperty.call(message, "startTime"))
                                    $root.google.protobuf.Timestamp.encode(message.startTime, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                                if (message.submitTime != null && Object.hasOwnProperty.call(message, "submitTime"))
                                    $root.google.protobuf.Timestamp.encode(message.submitTime, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                                if (message.summaryText != null && Object.hasOwnProperty.call(message, "summaryText"))
                                    writer.uint32(/* id 3, wireType 2 =*/26).string(message.summaryText);
                                if (message.textSections != null && Object.hasOwnProperty.call(message, "textSections"))
                                    for (var keys = Object.keys(message.textSections), i = 0; i < keys.length; ++i)
                                        writer.uint32(/* id 4, wireType 2 =*/34).fork().uint32(/* id 1, wireType 2 =*/10).string(keys[i]).uint32(/* id 2, wireType 2 =*/18).string(message.textSections[keys[i]]).ldelim();
                                return writer;
                            };
    
                            /**
                             * Encodes the specified SummarizationFeedback message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.AgentAssistantFeedback.SummarizationFeedback.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback.SummarizationFeedback
                             * @static
                             * @param {google.cloud.dialogflow.v2.AgentAssistantFeedback.ISummarizationFeedback} message SummarizationFeedback message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            SummarizationFeedback.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a SummarizationFeedback message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback.SummarizationFeedback
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2.AgentAssistantFeedback.SummarizationFeedback} SummarizationFeedback
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            SummarizationFeedback.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.AgentAssistantFeedback.SummarizationFeedback(), key, value;
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.startTime = $root.google.protobuf.Timestamp.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 2: {
                                            message.submitTime = $root.google.protobuf.Timestamp.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 3: {
                                            message.summaryText = reader.string();
                                            break;
                                        }
                                    case 4: {
                                            if (message.textSections === $util.emptyObject)
                                                message.textSections = {};
                                            var end2 = reader.uint32() + reader.pos;
                                            key = "";
                                            value = "";
                                            while (reader.pos < end2) {
                                                var tag2 = reader.uint32();
                                                switch (tag2 >>> 3) {
                                                case 1:
                                                    key = reader.string();
                                                    break;
                                                case 2:
                                                    value = reader.string();
                                                    break;
                                                default:
                                                    reader.skipType(tag2 & 7);
                                                    break;
                                                }
                                            }
                                            message.textSections[key] = value;
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a SummarizationFeedback message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback.SummarizationFeedback
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2.AgentAssistantFeedback.SummarizationFeedback} SummarizationFeedback
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            SummarizationFeedback.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a SummarizationFeedback message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback.SummarizationFeedback
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            SummarizationFeedback.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.startTime != null && message.hasOwnProperty("startTime")) {
                                    var error = $root.google.protobuf.Timestamp.verify(message.startTime);
                                    if (error)
                                        return "startTime." + error;
                                }
                                if (message.submitTime != null && message.hasOwnProperty("submitTime")) {
                                    var error = $root.google.protobuf.Timestamp.verify(message.submitTime);
                                    if (error)
                                        return "submitTime." + error;
                                }
                                if (message.summaryText != null && message.hasOwnProperty("summaryText"))
                                    if (!$util.isString(message.summaryText))
                                        return "summaryText: string expected";
                                if (message.textSections != null && message.hasOwnProperty("textSections")) {
                                    if (!$util.isObject(message.textSections))
                                        return "textSections: object expected";
                                    var key = Object.keys(message.textSections);
                                    for (var i = 0; i < key.length; ++i)
                                        if (!$util.isString(message.textSections[key[i]]))
                                            return "textSections: string{k:string} expected";
                                }
                                return null;
                            };
    
                            /**
                             * Creates a SummarizationFeedback message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback.SummarizationFeedback
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2.AgentAssistantFeedback.SummarizationFeedback} SummarizationFeedback
                             */
                            SummarizationFeedback.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2.AgentAssistantFeedback.SummarizationFeedback)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2.AgentAssistantFeedback.SummarizationFeedback();
                                if (object.startTime != null) {
                                    if (typeof object.startTime !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.AgentAssistantFeedback.SummarizationFeedback.startTime: object expected");
                                    message.startTime = $root.google.protobuf.Timestamp.fromObject(object.startTime);
                                }
                                if (object.submitTime != null) {
                                    if (typeof object.submitTime !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.AgentAssistantFeedback.SummarizationFeedback.submitTime: object expected");
                                    message.submitTime = $root.google.protobuf.Timestamp.fromObject(object.submitTime);
                                }
                                if (object.summaryText != null)
                                    message.summaryText = String(object.summaryText);
                                if (object.textSections) {
                                    if (typeof object.textSections !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.AgentAssistantFeedback.SummarizationFeedback.textSections: object expected");
                                    message.textSections = {};
                                    for (var keys = Object.keys(object.textSections), i = 0; i < keys.length; ++i)
                                        message.textSections[keys[i]] = String(object.textSections[keys[i]]);
                                }
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a SummarizationFeedback message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback.SummarizationFeedback
                             * @static
                             * @param {google.cloud.dialogflow.v2.AgentAssistantFeedback.SummarizationFeedback} message SummarizationFeedback
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            SummarizationFeedback.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.objects || options.defaults)
                                    object.textSections = {};
                                if (options.defaults) {
                                    object.startTime = null;
                                    object.submitTime = null;
                                    object.summaryText = "";
                                }
                                if (message.startTime != null && message.hasOwnProperty("startTime"))
                                    object.startTime = $root.google.protobuf.Timestamp.toObject(message.startTime, options);
                                if (message.submitTime != null && message.hasOwnProperty("submitTime"))
                                    object.submitTime = $root.google.protobuf.Timestamp.toObject(message.submitTime, options);
                                if (message.summaryText != null && message.hasOwnProperty("summaryText"))
                                    object.summaryText = message.summaryText;
                                var keys2;
                                if (message.textSections && (keys2 = Object.keys(message.textSections)).length) {
                                    object.textSections = {};
                                    for (var j = 0; j < keys2.length; ++j)
                                        object.textSections[keys2[j]] = message.textSections[keys2[j]];
                                }
                                return object;
                            };
    
                            /**
                             * Converts this SummarizationFeedback to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback.SummarizationFeedback
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            SummarizationFeedback.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for SummarizationFeedback
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback.SummarizationFeedback
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            SummarizationFeedback.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2.AgentAssistantFeedback.SummarizationFeedback";
                            };
    
                            return SummarizationFeedback;
                        })();
    
                        AgentAssistantFeedback.KnowledgeSearchFeedback = (function() {
    
                            /**
                             * Properties of a KnowledgeSearchFeedback.
                             * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback
                             * @interface IKnowledgeSearchFeedback
                             * @property {boolean|null} [answerCopied] KnowledgeSearchFeedback answerCopied
                             * @property {Array.<string>|null} [clickedUris] KnowledgeSearchFeedback clickedUris
                             */
    
                            /**
                             * Constructs a new KnowledgeSearchFeedback.
                             * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback
                             * @classdesc Represents a KnowledgeSearchFeedback.
                             * @implements IKnowledgeSearchFeedback
                             * @constructor
                             * @param {google.cloud.dialogflow.v2.AgentAssistantFeedback.IKnowledgeSearchFeedback=} [properties] Properties to set
                             */
                            function KnowledgeSearchFeedback(properties) {
                                this.clickedUris = [];
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * KnowledgeSearchFeedback answerCopied.
                             * @member {boolean} answerCopied
                             * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeSearchFeedback
                             * @instance
                             */
                            KnowledgeSearchFeedback.prototype.answerCopied = false;
    
                            /**
                             * KnowledgeSearchFeedback clickedUris.
                             * @member {Array.<string>} clickedUris
                             * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeSearchFeedback
                             * @instance
                             */
                            KnowledgeSearchFeedback.prototype.clickedUris = $util.emptyArray;
    
                            /**
                             * Creates a new KnowledgeSearchFeedback instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeSearchFeedback
                             * @static
                             * @param {google.cloud.dialogflow.v2.AgentAssistantFeedback.IKnowledgeSearchFeedback=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeSearchFeedback} KnowledgeSearchFeedback instance
                             */
                            KnowledgeSearchFeedback.create = function create(properties) {
                                return new KnowledgeSearchFeedback(properties);
                            };
    
                            /**
                             * Encodes the specified KnowledgeSearchFeedback message. Does not implicitly {@link google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeSearchFeedback.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeSearchFeedback
                             * @static
                             * @param {google.cloud.dialogflow.v2.AgentAssistantFeedback.IKnowledgeSearchFeedback} message KnowledgeSearchFeedback message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            KnowledgeSearchFeedback.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.answerCopied != null && Object.hasOwnProperty.call(message, "answerCopied"))
                                    writer.uint32(/* id 1, wireType 0 =*/8).bool(message.answerCopied);
                                if (message.clickedUris != null && message.clickedUris.length)
                                    for (var i = 0; i < message.clickedUris.length; ++i)
                                        writer.uint32(/* id 2, wireType 2 =*/18).string(message.clickedUris[i]);
                                return writer;
                            };
    
                            /**
                             * Encodes the specified KnowledgeSearchFeedback message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeSearchFeedback.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeSearchFeedback
                             * @static
                             * @param {google.cloud.dialogflow.v2.AgentAssistantFeedback.IKnowledgeSearchFeedback} message KnowledgeSearchFeedback message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            KnowledgeSearchFeedback.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a KnowledgeSearchFeedback message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeSearchFeedback
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeSearchFeedback} KnowledgeSearchFeedback
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            KnowledgeSearchFeedback.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeSearchFeedback();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.answerCopied = reader.bool();
                                            break;
                                        }
                                    case 2: {
                                            if (!(message.clickedUris && message.clickedUris.length))
                                                message.clickedUris = [];
                                            message.clickedUris.push(reader.string());
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a KnowledgeSearchFeedback message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeSearchFeedback
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeSearchFeedback} KnowledgeSearchFeedback
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            KnowledgeSearchFeedback.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a KnowledgeSearchFeedback message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeSearchFeedback
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            KnowledgeSearchFeedback.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.answerCopied != null && message.hasOwnProperty("answerCopied"))
                                    if (typeof message.answerCopied !== "boolean")
                                        return "answerCopied: boolean expected";
                                if (message.clickedUris != null && message.hasOwnProperty("clickedUris")) {
                                    if (!Array.isArray(message.clickedUris))
                                        return "clickedUris: array expected";
                                    for (var i = 0; i < message.clickedUris.length; ++i)
                                        if (!$util.isString(message.clickedUris[i]))
                                            return "clickedUris: string[] expected";
                                }
                                return null;
                            };
    
                            /**
                             * Creates a KnowledgeSearchFeedback message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeSearchFeedback
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeSearchFeedback} KnowledgeSearchFeedback
                             */
                            KnowledgeSearchFeedback.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeSearchFeedback)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeSearchFeedback();
                                if (object.answerCopied != null)
                                    message.answerCopied = Boolean(object.answerCopied);
                                if (object.clickedUris) {
                                    if (!Array.isArray(object.clickedUris))
                                        throw TypeError(".google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeSearchFeedback.clickedUris: array expected");
                                    message.clickedUris = [];
                                    for (var i = 0; i < object.clickedUris.length; ++i)
                                        message.clickedUris[i] = String(object.clickedUris[i]);
                                }
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a KnowledgeSearchFeedback message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeSearchFeedback
                             * @static
                             * @param {google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeSearchFeedback} message KnowledgeSearchFeedback
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            KnowledgeSearchFeedback.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.arrays || options.defaults)
                                    object.clickedUris = [];
                                if (options.defaults)
                                    object.answerCopied = false;
                                if (message.answerCopied != null && message.hasOwnProperty("answerCopied"))
                                    object.answerCopied = message.answerCopied;
                                if (message.clickedUris && message.clickedUris.length) {
                                    object.clickedUris = [];
                                    for (var j = 0; j < message.clickedUris.length; ++j)
                                        object.clickedUris[j] = message.clickedUris[j];
                                }
                                return object;
                            };
    
                            /**
                             * Converts this KnowledgeSearchFeedback to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeSearchFeedback
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            KnowledgeSearchFeedback.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for KnowledgeSearchFeedback
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeSearchFeedback
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            KnowledgeSearchFeedback.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeSearchFeedback";
                            };
    
                            return KnowledgeSearchFeedback;
                        })();
    
                        AgentAssistantFeedback.KnowledgeAssistFeedback = (function() {
    
                            /**
                             * Properties of a KnowledgeAssistFeedback.
                             * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback
                             * @interface IKnowledgeAssistFeedback
                             * @property {boolean|null} [answerCopied] KnowledgeAssistFeedback answerCopied
                             * @property {Array.<string>|null} [clickedUris] KnowledgeAssistFeedback clickedUris
                             */
    
                            /**
                             * Constructs a new KnowledgeAssistFeedback.
                             * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback
                             * @classdesc Represents a KnowledgeAssistFeedback.
                             * @implements IKnowledgeAssistFeedback
                             * @constructor
                             * @param {google.cloud.dialogflow.v2.AgentAssistantFeedback.IKnowledgeAssistFeedback=} [properties] Properties to set
                             */
                            function KnowledgeAssistFeedback(properties) {
                                this.clickedUris = [];
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * KnowledgeAssistFeedback answerCopied.
                             * @member {boolean} answerCopied
                             * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeAssistFeedback
                             * @instance
                             */
                            KnowledgeAssistFeedback.prototype.answerCopied = false;
    
                            /**
                             * KnowledgeAssistFeedback clickedUris.
                             * @member {Array.<string>} clickedUris
                             * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeAssistFeedback
                             * @instance
                             */
                            KnowledgeAssistFeedback.prototype.clickedUris = $util.emptyArray;
    
                            /**
                             * Creates a new KnowledgeAssistFeedback instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeAssistFeedback
                             * @static
                             * @param {google.cloud.dialogflow.v2.AgentAssistantFeedback.IKnowledgeAssistFeedback=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeAssistFeedback} KnowledgeAssistFeedback instance
                             */
                            KnowledgeAssistFeedback.create = function create(properties) {
                                return new KnowledgeAssistFeedback(properties);
                            };
    
                            /**
                             * Encodes the specified KnowledgeAssistFeedback message. Does not implicitly {@link google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeAssistFeedback.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeAssistFeedback
                             * @static
                             * @param {google.cloud.dialogflow.v2.AgentAssistantFeedback.IKnowledgeAssistFeedback} message KnowledgeAssistFeedback message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            KnowledgeAssistFeedback.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.answerCopied != null && Object.hasOwnProperty.call(message, "answerCopied"))
                                    writer.uint32(/* id 1, wireType 0 =*/8).bool(message.answerCopied);
                                if (message.clickedUris != null && message.clickedUris.length)
                                    for (var i = 0; i < message.clickedUris.length; ++i)
                                        writer.uint32(/* id 2, wireType 2 =*/18).string(message.clickedUris[i]);
                                return writer;
                            };
    
                            /**
                             * Encodes the specified KnowledgeAssistFeedback message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeAssistFeedback.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeAssistFeedback
                             * @static
                             * @param {google.cloud.dialogflow.v2.AgentAssistantFeedback.IKnowledgeAssistFeedback} message KnowledgeAssistFeedback message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            KnowledgeAssistFeedback.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a KnowledgeAssistFeedback message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeAssistFeedback
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeAssistFeedback} KnowledgeAssistFeedback
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            KnowledgeAssistFeedback.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeAssistFeedback();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.answerCopied = reader.bool();
                                            break;
                                        }
                                    case 2: {
                                            if (!(message.clickedUris && message.clickedUris.length))
                                                message.clickedUris = [];
                                            message.clickedUris.push(reader.string());
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a KnowledgeAssistFeedback message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeAssistFeedback
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeAssistFeedback} KnowledgeAssistFeedback
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            KnowledgeAssistFeedback.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a KnowledgeAssistFeedback message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeAssistFeedback
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            KnowledgeAssistFeedback.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.answerCopied != null && message.hasOwnProperty("answerCopied"))
                                    if (typeof message.answerCopied !== "boolean")
                                        return "answerCopied: boolean expected";
                                if (message.clickedUris != null && message.hasOwnProperty("clickedUris")) {
                                    if (!Array.isArray(message.clickedUris))
                                        return "clickedUris: array expected";
                                    for (var i = 0; i < message.clickedUris.length; ++i)
                                        if (!$util.isString(message.clickedUris[i]))
                                            return "clickedUris: string[] expected";
                                }
                                return null;
                            };
    
                            /**
                             * Creates a KnowledgeAssistFeedback message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeAssistFeedback
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeAssistFeedback} KnowledgeAssistFeedback
                             */
                            KnowledgeAssistFeedback.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeAssistFeedback)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeAssistFeedback();
                                if (object.answerCopied != null)
                                    message.answerCopied = Boolean(object.answerCopied);
                                if (object.clickedUris) {
                                    if (!Array.isArray(object.clickedUris))
                                        throw TypeError(".google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeAssistFeedback.clickedUris: array expected");
                                    message.clickedUris = [];
                                    for (var i = 0; i < object.clickedUris.length; ++i)
                                        message.clickedUris[i] = String(object.clickedUris[i]);
                                }
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a KnowledgeAssistFeedback message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeAssistFeedback
                             * @static
                             * @param {google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeAssistFeedback} message KnowledgeAssistFeedback
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            KnowledgeAssistFeedback.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.arrays || options.defaults)
                                    object.clickedUris = [];
                                if (options.defaults)
                                    object.answerCopied = false;
                                if (message.answerCopied != null && message.hasOwnProperty("answerCopied"))
                                    object.answerCopied = message.answerCopied;
                                if (message.clickedUris && message.clickedUris.length) {
                                    object.clickedUris = [];
                                    for (var j = 0; j < message.clickedUris.length; ++j)
                                        object.clickedUris[j] = message.clickedUris[j];
                                }
                                return object;
                            };
    
                            /**
                             * Converts this KnowledgeAssistFeedback to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeAssistFeedback
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            KnowledgeAssistFeedback.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for KnowledgeAssistFeedback
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeAssistFeedback
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            KnowledgeAssistFeedback.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2.AgentAssistantFeedback.KnowledgeAssistFeedback";
                            };
    
                            return KnowledgeAssistFeedback;
                        })();
    
                        return AgentAssistantFeedback;
                    })();
    
                    v2.AgentAssistantRecord = (function() {
    
                        /**
                         * Properties of an AgentAssistantRecord.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IAgentAssistantRecord
                         * @property {google.cloud.dialogflow.v2.IArticleAnswer|null} [articleSuggestionAnswer] AgentAssistantRecord articleSuggestionAnswer
                         * @property {google.cloud.dialogflow.v2.IFaqAnswer|null} [faqAnswer] AgentAssistantRecord faqAnswer
                         * @property {google.cloud.dialogflow.v2.IDialogflowAssistAnswer|null} [dialogflowAssistAnswer] AgentAssistantRecord dialogflowAssistAnswer
                         */
    
                        /**
                         * Constructs a new AgentAssistantRecord.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an AgentAssistantRecord.
                         * @implements IAgentAssistantRecord
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IAgentAssistantRecord=} [properties] Properties to set
                         */
                        function AgentAssistantRecord(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * AgentAssistantRecord articleSuggestionAnswer.
                         * @member {google.cloud.dialogflow.v2.IArticleAnswer|null|undefined} articleSuggestionAnswer
                         * @memberof google.cloud.dialogflow.v2.AgentAssistantRecord
                         * @instance
                         */
                        AgentAssistantRecord.prototype.articleSuggestionAnswer = null;
    
                        /**
                         * AgentAssistantRecord faqAnswer.
                         * @member {google.cloud.dialogflow.v2.IFaqAnswer|null|undefined} faqAnswer
                         * @memberof google.cloud.dialogflow.v2.AgentAssistantRecord
                         * @instance
                         */
                        AgentAssistantRecord.prototype.faqAnswer = null;
    
                        /**
                         * AgentAssistantRecord dialogflowAssistAnswer.
                         * @member {google.cloud.dialogflow.v2.IDialogflowAssistAnswer|null|undefined} dialogflowAssistAnswer
                         * @memberof google.cloud.dialogflow.v2.AgentAssistantRecord
                         * @instance
                         */
                        AgentAssistantRecord.prototype.dialogflowAssistAnswer = null;
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * AgentAssistantRecord answer.
                         * @member {"articleSuggestionAnswer"|"faqAnswer"|"dialogflowAssistAnswer"|undefined} answer
                         * @memberof google.cloud.dialogflow.v2.AgentAssistantRecord
                         * @instance
                         */
                        Object.defineProperty(AgentAssistantRecord.prototype, "answer", {
                            get: $util.oneOfGetter($oneOfFields = ["articleSuggestionAnswer", "faqAnswer", "dialogflowAssistAnswer"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new AgentAssistantRecord instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.AgentAssistantRecord
                         * @static
                         * @param {google.cloud.dialogflow.v2.IAgentAssistantRecord=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.AgentAssistantRecord} AgentAssistantRecord instance
                         */
                        AgentAssistantRecord.create = function create(properties) {
                            return new AgentAssistantRecord(properties);
                        };
    
                        /**
                         * Encodes the specified AgentAssistantRecord message. Does not implicitly {@link google.cloud.dialogflow.v2.AgentAssistantRecord.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.AgentAssistantRecord
                         * @static
                         * @param {google.cloud.dialogflow.v2.IAgentAssistantRecord} message AgentAssistantRecord message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        AgentAssistantRecord.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.articleSuggestionAnswer != null && Object.hasOwnProperty.call(message, "articleSuggestionAnswer"))
                                $root.google.cloud.dialogflow.v2.ArticleAnswer.encode(message.articleSuggestionAnswer, writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                            if (message.faqAnswer != null && Object.hasOwnProperty.call(message, "faqAnswer"))
                                $root.google.cloud.dialogflow.v2.FaqAnswer.encode(message.faqAnswer, writer.uint32(/* id 6, wireType 2 =*/50).fork()).ldelim();
                            if (message.dialogflowAssistAnswer != null && Object.hasOwnProperty.call(message, "dialogflowAssistAnswer"))
                                $root.google.cloud.dialogflow.v2.DialogflowAssistAnswer.encode(message.dialogflowAssistAnswer, writer.uint32(/* id 7, wireType 2 =*/58).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified AgentAssistantRecord message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.AgentAssistantRecord.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.AgentAssistantRecord
                         * @static
                         * @param {google.cloud.dialogflow.v2.IAgentAssistantRecord} message AgentAssistantRecord message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        AgentAssistantRecord.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an AgentAssistantRecord message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.AgentAssistantRecord
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.AgentAssistantRecord} AgentAssistantRecord
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        AgentAssistantRecord.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.AgentAssistantRecord();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 5: {
                                        message.articleSuggestionAnswer = $root.google.cloud.dialogflow.v2.ArticleAnswer.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 6: {
                                        message.faqAnswer = $root.google.cloud.dialogflow.v2.FaqAnswer.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 7: {
                                        message.dialogflowAssistAnswer = $root.google.cloud.dialogflow.v2.DialogflowAssistAnswer.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an AgentAssistantRecord message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.AgentAssistantRecord
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.AgentAssistantRecord} AgentAssistantRecord
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        AgentAssistantRecord.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an AgentAssistantRecord message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.AgentAssistantRecord
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        AgentAssistantRecord.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.articleSuggestionAnswer != null && message.hasOwnProperty("articleSuggestionAnswer")) {
                                properties.answer = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2.ArticleAnswer.verify(message.articleSuggestionAnswer);
                                    if (error)
                                        return "articleSuggestionAnswer." + error;
                                }
                            }
                            if (message.faqAnswer != null && message.hasOwnProperty("faqAnswer")) {
                                if (properties.answer === 1)
                                    return "answer: multiple values";
                                properties.answer = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2.FaqAnswer.verify(message.faqAnswer);
                                    if (error)
                                        return "faqAnswer." + error;
                                }
                            }
                            if (message.dialogflowAssistAnswer != null && message.hasOwnProperty("dialogflowAssistAnswer")) {
                                if (properties.answer === 1)
                                    return "answer: multiple values";
                                properties.answer = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2.DialogflowAssistAnswer.verify(message.dialogflowAssistAnswer);
                                    if (error)
                                        return "dialogflowAssistAnswer." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates an AgentAssistantRecord message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.AgentAssistantRecord
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.AgentAssistantRecord} AgentAssistantRecord
                         */
                        AgentAssistantRecord.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.AgentAssistantRecord)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.AgentAssistantRecord();
                            if (object.articleSuggestionAnswer != null) {
                                if (typeof object.articleSuggestionAnswer !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.AgentAssistantRecord.articleSuggestionAnswer: object expected");
                                message.articleSuggestionAnswer = $root.google.cloud.dialogflow.v2.ArticleAnswer.fromObject(object.articleSuggestionAnswer);
                            }
                            if (object.faqAnswer != null) {
                                if (typeof object.faqAnswer !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.AgentAssistantRecord.faqAnswer: object expected");
                                message.faqAnswer = $root.google.cloud.dialogflow.v2.FaqAnswer.fromObject(object.faqAnswer);
                            }
                            if (object.dialogflowAssistAnswer != null) {
                                if (typeof object.dialogflowAssistAnswer !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.AgentAssistantRecord.dialogflowAssistAnswer: object expected");
                                message.dialogflowAssistAnswer = $root.google.cloud.dialogflow.v2.DialogflowAssistAnswer.fromObject(object.dialogflowAssistAnswer);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an AgentAssistantRecord message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.AgentAssistantRecord
                         * @static
                         * @param {google.cloud.dialogflow.v2.AgentAssistantRecord} message AgentAssistantRecord
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        AgentAssistantRecord.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (message.articleSuggestionAnswer != null && message.hasOwnProperty("articleSuggestionAnswer")) {
                                object.articleSuggestionAnswer = $root.google.cloud.dialogflow.v2.ArticleAnswer.toObject(message.articleSuggestionAnswer, options);
                                if (options.oneofs)
                                    object.answer = "articleSuggestionAnswer";
                            }
                            if (message.faqAnswer != null && message.hasOwnProperty("faqAnswer")) {
                                object.faqAnswer = $root.google.cloud.dialogflow.v2.FaqAnswer.toObject(message.faqAnswer, options);
                                if (options.oneofs)
                                    object.answer = "faqAnswer";
                            }
                            if (message.dialogflowAssistAnswer != null && message.hasOwnProperty("dialogflowAssistAnswer")) {
                                object.dialogflowAssistAnswer = $root.google.cloud.dialogflow.v2.DialogflowAssistAnswer.toObject(message.dialogflowAssistAnswer, options);
                                if (options.oneofs)
                                    object.answer = "dialogflowAssistAnswer";
                            }
                            return object;
                        };
    
                        /**
                         * Converts this AgentAssistantRecord to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.AgentAssistantRecord
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        AgentAssistantRecord.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for AgentAssistantRecord
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.AgentAssistantRecord
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        AgentAssistantRecord.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.AgentAssistantRecord";
                        };
    
                        return AgentAssistantRecord;
                    })();
    
                    v2.Participants = (function() {
    
                        /**
                         * Constructs a new Participants service.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a Participants
                         * @extends $protobuf.rpc.Service
                         * @constructor
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         */
                        function Participants(rpcImpl, requestDelimited, responseDelimited) {
                            $protobuf.rpc.Service.call(this, rpcImpl, requestDelimited, responseDelimited);
                        }
    
                        (Participants.prototype = Object.create($protobuf.rpc.Service.prototype)).constructor = Participants;
    
                        /**
                         * Creates new Participants service using the specified rpc implementation.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.Participants
                         * @static
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         * @returns {Participants} RPC service. Useful where requests and/or responses are streamed.
                         */
                        Participants.create = function create(rpcImpl, requestDelimited, responseDelimited) {
                            return new this(rpcImpl, requestDelimited, responseDelimited);
                        };
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Participants|createParticipant}.
                         * @memberof google.cloud.dialogflow.v2.Participants
                         * @typedef CreateParticipantCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.Participant} [response] Participant
                         */
    
                        /**
                         * Calls CreateParticipant.
                         * @function createParticipant
                         * @memberof google.cloud.dialogflow.v2.Participants
                         * @instance
                         * @param {google.cloud.dialogflow.v2.ICreateParticipantRequest} request CreateParticipantRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Participants.CreateParticipantCallback} callback Node-style callback called with the error, if any, and Participant
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Participants.prototype.createParticipant = function createParticipant(request, callback) {
                            return this.rpcCall(createParticipant, $root.google.cloud.dialogflow.v2.CreateParticipantRequest, $root.google.cloud.dialogflow.v2.Participant, request, callback);
                        }, "name", { value: "CreateParticipant" });
    
                        /**
                         * Calls CreateParticipant.
                         * @function createParticipant
                         * @memberof google.cloud.dialogflow.v2.Participants
                         * @instance
                         * @param {google.cloud.dialogflow.v2.ICreateParticipantRequest} request CreateParticipantRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.Participant>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Participants|getParticipant}.
                         * @memberof google.cloud.dialogflow.v2.Participants
                         * @typedef GetParticipantCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.Participant} [response] Participant
                         */
    
                        /**
                         * Calls GetParticipant.
                         * @function getParticipant
                         * @memberof google.cloud.dialogflow.v2.Participants
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IGetParticipantRequest} request GetParticipantRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Participants.GetParticipantCallback} callback Node-style callback called with the error, if any, and Participant
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Participants.prototype.getParticipant = function getParticipant(request, callback) {
                            return this.rpcCall(getParticipant, $root.google.cloud.dialogflow.v2.GetParticipantRequest, $root.google.cloud.dialogflow.v2.Participant, request, callback);
                        }, "name", { value: "GetParticipant" });
    
                        /**
                         * Calls GetParticipant.
                         * @function getParticipant
                         * @memberof google.cloud.dialogflow.v2.Participants
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IGetParticipantRequest} request GetParticipantRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.Participant>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Participants|listParticipants}.
                         * @memberof google.cloud.dialogflow.v2.Participants
                         * @typedef ListParticipantsCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.ListParticipantsResponse} [response] ListParticipantsResponse
                         */
    
                        /**
                         * Calls ListParticipants.
                         * @function listParticipants
                         * @memberof google.cloud.dialogflow.v2.Participants
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IListParticipantsRequest} request ListParticipantsRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Participants.ListParticipantsCallback} callback Node-style callback called with the error, if any, and ListParticipantsResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Participants.prototype.listParticipants = function listParticipants(request, callback) {
                            return this.rpcCall(listParticipants, $root.google.cloud.dialogflow.v2.ListParticipantsRequest, $root.google.cloud.dialogflow.v2.ListParticipantsResponse, request, callback);
                        }, "name", { value: "ListParticipants" });
    
                        /**
                         * Calls ListParticipants.
                         * @function listParticipants
                         * @memberof google.cloud.dialogflow.v2.Participants
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IListParticipantsRequest} request ListParticipantsRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.ListParticipantsResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Participants|updateParticipant}.
                         * @memberof google.cloud.dialogflow.v2.Participants
                         * @typedef UpdateParticipantCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.Participant} [response] Participant
                         */
    
                        /**
                         * Calls UpdateParticipant.
                         * @function updateParticipant
                         * @memberof google.cloud.dialogflow.v2.Participants
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IUpdateParticipantRequest} request UpdateParticipantRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Participants.UpdateParticipantCallback} callback Node-style callback called with the error, if any, and Participant
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Participants.prototype.updateParticipant = function updateParticipant(request, callback) {
                            return this.rpcCall(updateParticipant, $root.google.cloud.dialogflow.v2.UpdateParticipantRequest, $root.google.cloud.dialogflow.v2.Participant, request, callback);
                        }, "name", { value: "UpdateParticipant" });
    
                        /**
                         * Calls UpdateParticipant.
                         * @function updateParticipant
                         * @memberof google.cloud.dialogflow.v2.Participants
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IUpdateParticipantRequest} request UpdateParticipantRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.Participant>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Participants|analyzeContent}.
                         * @memberof google.cloud.dialogflow.v2.Participants
                         * @typedef AnalyzeContentCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.AnalyzeContentResponse} [response] AnalyzeContentResponse
                         */
    
                        /**
                         * Calls AnalyzeContent.
                         * @function analyzeContent
                         * @memberof google.cloud.dialogflow.v2.Participants
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IAnalyzeContentRequest} request AnalyzeContentRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Participants.AnalyzeContentCallback} callback Node-style callback called with the error, if any, and AnalyzeContentResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Participants.prototype.analyzeContent = function analyzeContent(request, callback) {
                            return this.rpcCall(analyzeContent, $root.google.cloud.dialogflow.v2.AnalyzeContentRequest, $root.google.cloud.dialogflow.v2.AnalyzeContentResponse, request, callback);
                        }, "name", { value: "AnalyzeContent" });
    
                        /**
                         * Calls AnalyzeContent.
                         * @function analyzeContent
                         * @memberof google.cloud.dialogflow.v2.Participants
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IAnalyzeContentRequest} request AnalyzeContentRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.AnalyzeContentResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Participants|streamingAnalyzeContent}.
                         * @memberof google.cloud.dialogflow.v2.Participants
                         * @typedef StreamingAnalyzeContentCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.StreamingAnalyzeContentResponse} [response] StreamingAnalyzeContentResponse
                         */
    
                        /**
                         * Calls StreamingAnalyzeContent.
                         * @function streamingAnalyzeContent
                         * @memberof google.cloud.dialogflow.v2.Participants
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IStreamingAnalyzeContentRequest} request StreamingAnalyzeContentRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Participants.StreamingAnalyzeContentCallback} callback Node-style callback called with the error, if any, and StreamingAnalyzeContentResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Participants.prototype.streamingAnalyzeContent = function streamingAnalyzeContent(request, callback) {
                            return this.rpcCall(streamingAnalyzeContent, $root.google.cloud.dialogflow.v2.StreamingAnalyzeContentRequest, $root.google.cloud.dialogflow.v2.StreamingAnalyzeContentResponse, request, callback);
                        }, "name", { value: "StreamingAnalyzeContent" });
    
                        /**
                         * Calls StreamingAnalyzeContent.
                         * @function streamingAnalyzeContent
                         * @memberof google.cloud.dialogflow.v2.Participants
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IStreamingAnalyzeContentRequest} request StreamingAnalyzeContentRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.StreamingAnalyzeContentResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Participants|suggestArticles}.
                         * @memberof google.cloud.dialogflow.v2.Participants
                         * @typedef SuggestArticlesCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.SuggestArticlesResponse} [response] SuggestArticlesResponse
                         */
    
                        /**
                         * Calls SuggestArticles.
                         * @function suggestArticles
                         * @memberof google.cloud.dialogflow.v2.Participants
                         * @instance
                         * @param {google.cloud.dialogflow.v2.ISuggestArticlesRequest} request SuggestArticlesRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Participants.SuggestArticlesCallback} callback Node-style callback called with the error, if any, and SuggestArticlesResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Participants.prototype.suggestArticles = function suggestArticles(request, callback) {
                            return this.rpcCall(suggestArticles, $root.google.cloud.dialogflow.v2.SuggestArticlesRequest, $root.google.cloud.dialogflow.v2.SuggestArticlesResponse, request, callback);
                        }, "name", { value: "SuggestArticles" });
    
                        /**
                         * Calls SuggestArticles.
                         * @function suggestArticles
                         * @memberof google.cloud.dialogflow.v2.Participants
                         * @instance
                         * @param {google.cloud.dialogflow.v2.ISuggestArticlesRequest} request SuggestArticlesRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.SuggestArticlesResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Participants|suggestFaqAnswers}.
                         * @memberof google.cloud.dialogflow.v2.Participants
                         * @typedef SuggestFaqAnswersCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.SuggestFaqAnswersResponse} [response] SuggestFaqAnswersResponse
                         */
    
                        /**
                         * Calls SuggestFaqAnswers.
                         * @function suggestFaqAnswers
                         * @memberof google.cloud.dialogflow.v2.Participants
                         * @instance
                         * @param {google.cloud.dialogflow.v2.ISuggestFaqAnswersRequest} request SuggestFaqAnswersRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Participants.SuggestFaqAnswersCallback} callback Node-style callback called with the error, if any, and SuggestFaqAnswersResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Participants.prototype.suggestFaqAnswers = function suggestFaqAnswers(request, callback) {
                            return this.rpcCall(suggestFaqAnswers, $root.google.cloud.dialogflow.v2.SuggestFaqAnswersRequest, $root.google.cloud.dialogflow.v2.SuggestFaqAnswersResponse, request, callback);
                        }, "name", { value: "SuggestFaqAnswers" });
    
                        /**
                         * Calls SuggestFaqAnswers.
                         * @function suggestFaqAnswers
                         * @memberof google.cloud.dialogflow.v2.Participants
                         * @instance
                         * @param {google.cloud.dialogflow.v2.ISuggestFaqAnswersRequest} request SuggestFaqAnswersRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.SuggestFaqAnswersResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Participants|suggestSmartReplies}.
                         * @memberof google.cloud.dialogflow.v2.Participants
                         * @typedef SuggestSmartRepliesCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.SuggestSmartRepliesResponse} [response] SuggestSmartRepliesResponse
                         */
    
                        /**
                         * Calls SuggestSmartReplies.
                         * @function suggestSmartReplies
                         * @memberof google.cloud.dialogflow.v2.Participants
                         * @instance
                         * @param {google.cloud.dialogflow.v2.ISuggestSmartRepliesRequest} request SuggestSmartRepliesRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Participants.SuggestSmartRepliesCallback} callback Node-style callback called with the error, if any, and SuggestSmartRepliesResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Participants.prototype.suggestSmartReplies = function suggestSmartReplies(request, callback) {
                            return this.rpcCall(suggestSmartReplies, $root.google.cloud.dialogflow.v2.SuggestSmartRepliesRequest, $root.google.cloud.dialogflow.v2.SuggestSmartRepliesResponse, request, callback);
                        }, "name", { value: "SuggestSmartReplies" });
    
                        /**
                         * Calls SuggestSmartReplies.
                         * @function suggestSmartReplies
                         * @memberof google.cloud.dialogflow.v2.Participants
                         * @instance
                         * @param {google.cloud.dialogflow.v2.ISuggestSmartRepliesRequest} request SuggestSmartRepliesRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.SuggestSmartRepliesResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Participants|suggestKnowledgeAssist}.
                         * @memberof google.cloud.dialogflow.v2.Participants
                         * @typedef SuggestKnowledgeAssistCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.SuggestKnowledgeAssistResponse} [response] SuggestKnowledgeAssistResponse
                         */
    
                        /**
                         * Calls SuggestKnowledgeAssist.
                         * @function suggestKnowledgeAssist
                         * @memberof google.cloud.dialogflow.v2.Participants
                         * @instance
                         * @param {google.cloud.dialogflow.v2.ISuggestKnowledgeAssistRequest} request SuggestKnowledgeAssistRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Participants.SuggestKnowledgeAssistCallback} callback Node-style callback called with the error, if any, and SuggestKnowledgeAssistResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Participants.prototype.suggestKnowledgeAssist = function suggestKnowledgeAssist(request, callback) {
                            return this.rpcCall(suggestKnowledgeAssist, $root.google.cloud.dialogflow.v2.SuggestKnowledgeAssistRequest, $root.google.cloud.dialogflow.v2.SuggestKnowledgeAssistResponse, request, callback);
                        }, "name", { value: "SuggestKnowledgeAssist" });
    
                        /**
                         * Calls SuggestKnowledgeAssist.
                         * @function suggestKnowledgeAssist
                         * @memberof google.cloud.dialogflow.v2.Participants
                         * @instance
                         * @param {google.cloud.dialogflow.v2.ISuggestKnowledgeAssistRequest} request SuggestKnowledgeAssistRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.SuggestKnowledgeAssistResponse>} Promise
                         * @variation 2
                         */
    
                        return Participants;
                    })();
    
                    v2.Participant = (function() {
    
                        /**
                         * Properties of a Participant.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IParticipant
                         * @property {string|null} [name] Participant name
                         * @property {google.cloud.dialogflow.v2.Participant.Role|null} [role] Participant role
                         * @property {string|null} [sipRecordingMediaLabel] Participant sipRecordingMediaLabel
                         * @property {string|null} [obfuscatedExternalUserId] Participant obfuscatedExternalUserId
                         * @property {Object.<string,string>|null} [documentsMetadataFilters] Participant documentsMetadataFilters
                         */
    
                        /**
                         * Constructs a new Participant.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a Participant.
                         * @implements IParticipant
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IParticipant=} [properties] Properties to set
                         */
                        function Participant(properties) {
                            this.documentsMetadataFilters = {};
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * Participant name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2.Participant
                         * @instance
                         */
                        Participant.prototype.name = "";
    
                        /**
                         * Participant role.
                         * @member {google.cloud.dialogflow.v2.Participant.Role} role
                         * @memberof google.cloud.dialogflow.v2.Participant
                         * @instance
                         */
                        Participant.prototype.role = 0;
    
                        /**
                         * Participant sipRecordingMediaLabel.
                         * @member {string} sipRecordingMediaLabel
                         * @memberof google.cloud.dialogflow.v2.Participant
                         * @instance
                         */
                        Participant.prototype.sipRecordingMediaLabel = "";
    
                        /**
                         * Participant obfuscatedExternalUserId.
                         * @member {string} obfuscatedExternalUserId
                         * @memberof google.cloud.dialogflow.v2.Participant
                         * @instance
                         */
                        Participant.prototype.obfuscatedExternalUserId = "";
    
                        /**
                         * Participant documentsMetadataFilters.
                         * @member {Object.<string,string>} documentsMetadataFilters
                         * @memberof google.cloud.dialogflow.v2.Participant
                         * @instance
                         */
                        Participant.prototype.documentsMetadataFilters = $util.emptyObject;
    
                        /**
                         * Creates a new Participant instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.Participant
                         * @static
                         * @param {google.cloud.dialogflow.v2.IParticipant=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.Participant} Participant instance
                         */
                        Participant.create = function create(properties) {
                            return new Participant(properties);
                        };
    
                        /**
                         * Encodes the specified Participant message. Does not implicitly {@link google.cloud.dialogflow.v2.Participant.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.Participant
                         * @static
                         * @param {google.cloud.dialogflow.v2.IParticipant} message Participant message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        Participant.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            if (message.role != null && Object.hasOwnProperty.call(message, "role"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.role);
                            if (message.sipRecordingMediaLabel != null && Object.hasOwnProperty.call(message, "sipRecordingMediaLabel"))
                                writer.uint32(/* id 6, wireType 2 =*/50).string(message.sipRecordingMediaLabel);
                            if (message.obfuscatedExternalUserId != null && Object.hasOwnProperty.call(message, "obfuscatedExternalUserId"))
                                writer.uint32(/* id 7, wireType 2 =*/58).string(message.obfuscatedExternalUserId);
                            if (message.documentsMetadataFilters != null && Object.hasOwnProperty.call(message, "documentsMetadataFilters"))
                                for (var keys = Object.keys(message.documentsMetadataFilters), i = 0; i < keys.length; ++i)
                                    writer.uint32(/* id 8, wireType 2 =*/66).fork().uint32(/* id 1, wireType 2 =*/10).string(keys[i]).uint32(/* id 2, wireType 2 =*/18).string(message.documentsMetadataFilters[keys[i]]).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified Participant message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.Participant.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.Participant
                         * @static
                         * @param {google.cloud.dialogflow.v2.IParticipant} message Participant message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        Participant.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a Participant message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.Participant
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.Participant} Participant
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        Participant.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.Participant(), key, value;
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.role = reader.int32();
                                        break;
                                    }
                                case 6: {
                                        message.sipRecordingMediaLabel = reader.string();
                                        break;
                                    }
                                case 7: {
                                        message.obfuscatedExternalUserId = reader.string();
                                        break;
                                    }
                                case 8: {
                                        if (message.documentsMetadataFilters === $util.emptyObject)
                                            message.documentsMetadataFilters = {};
                                        var end2 = reader.uint32() + reader.pos;
                                        key = "";
                                        value = "";
                                        while (reader.pos < end2) {
                                            var tag2 = reader.uint32();
                                            switch (tag2 >>> 3) {
                                            case 1:
                                                key = reader.string();
                                                break;
                                            case 2:
                                                value = reader.string();
                                                break;
                                            default:
                                                reader.skipType(tag2 & 7);
                                                break;
                                            }
                                        }
                                        message.documentsMetadataFilters[key] = value;
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a Participant message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.Participant
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.Participant} Participant
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        Participant.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a Participant message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.Participant
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        Participant.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            if (message.role != null && message.hasOwnProperty("role"))
                                switch (message.role) {
                                default:
                                    return "role: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                    break;
                                }
                            if (message.sipRecordingMediaLabel != null && message.hasOwnProperty("sipRecordingMediaLabel"))
                                if (!$util.isString(message.sipRecordingMediaLabel))
                                    return "sipRecordingMediaLabel: string expected";
                            if (message.obfuscatedExternalUserId != null && message.hasOwnProperty("obfuscatedExternalUserId"))
                                if (!$util.isString(message.obfuscatedExternalUserId))
                                    return "obfuscatedExternalUserId: string expected";
                            if (message.documentsMetadataFilters != null && message.hasOwnProperty("documentsMetadataFilters")) {
                                if (!$util.isObject(message.documentsMetadataFilters))
                                    return "documentsMetadataFilters: object expected";
                                var key = Object.keys(message.documentsMetadataFilters);
                                for (var i = 0; i < key.length; ++i)
                                    if (!$util.isString(message.documentsMetadataFilters[key[i]]))
                                        return "documentsMetadataFilters: string{k:string} expected";
                            }
                            return null;
                        };
    
                        /**
                         * Creates a Participant message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.Participant
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.Participant} Participant
                         */
                        Participant.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.Participant)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.Participant();
                            if (object.name != null)
                                message.name = String(object.name);
                            switch (object.role) {
                            default:
                                if (typeof object.role === "number") {
                                    message.role = object.role;
                                    break;
                                }
                                break;
                            case "ROLE_UNSPECIFIED":
                            case 0:
                                message.role = 0;
                                break;
                            case "HUMAN_AGENT":
                            case 1:
                                message.role = 1;
                                break;
                            case "AUTOMATED_AGENT":
                            case 2:
                                message.role = 2;
                                break;
                            case "END_USER":
                            case 3:
                                message.role = 3;
                                break;
                            }
                            if (object.sipRecordingMediaLabel != null)
                                message.sipRecordingMediaLabel = String(object.sipRecordingMediaLabel);
                            if (object.obfuscatedExternalUserId != null)
                                message.obfuscatedExternalUserId = String(object.obfuscatedExternalUserId);
                            if (object.documentsMetadataFilters) {
                                if (typeof object.documentsMetadataFilters !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.Participant.documentsMetadataFilters: object expected");
                                message.documentsMetadataFilters = {};
                                for (var keys = Object.keys(object.documentsMetadataFilters), i = 0; i < keys.length; ++i)
                                    message.documentsMetadataFilters[keys[i]] = String(object.documentsMetadataFilters[keys[i]]);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a Participant message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.Participant
                         * @static
                         * @param {google.cloud.dialogflow.v2.Participant} message Participant
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        Participant.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.objects || options.defaults)
                                object.documentsMetadataFilters = {};
                            if (options.defaults) {
                                object.name = "";
                                object.role = options.enums === String ? "ROLE_UNSPECIFIED" : 0;
                                object.sipRecordingMediaLabel = "";
                                object.obfuscatedExternalUserId = "";
                            }
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            if (message.role != null && message.hasOwnProperty("role"))
                                object.role = options.enums === String ? $root.google.cloud.dialogflow.v2.Participant.Role[message.role] === undefined ? message.role : $root.google.cloud.dialogflow.v2.Participant.Role[message.role] : message.role;
                            if (message.sipRecordingMediaLabel != null && message.hasOwnProperty("sipRecordingMediaLabel"))
                                object.sipRecordingMediaLabel = message.sipRecordingMediaLabel;
                            if (message.obfuscatedExternalUserId != null && message.hasOwnProperty("obfuscatedExternalUserId"))
                                object.obfuscatedExternalUserId = message.obfuscatedExternalUserId;
                            var keys2;
                            if (message.documentsMetadataFilters && (keys2 = Object.keys(message.documentsMetadataFilters)).length) {
                                object.documentsMetadataFilters = {};
                                for (var j = 0; j < keys2.length; ++j)
                                    object.documentsMetadataFilters[keys2[j]] = message.documentsMetadataFilters[keys2[j]];
                            }
                            return object;
                        };
    
                        /**
                         * Converts this Participant to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.Participant
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        Participant.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for Participant
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.Participant
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        Participant.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.Participant";
                        };
    
                        /**
                         * Role enum.
                         * @name google.cloud.dialogflow.v2.Participant.Role
                         * @enum {number}
                         * @property {number} ROLE_UNSPECIFIED=0 ROLE_UNSPECIFIED value
                         * @property {number} HUMAN_AGENT=1 HUMAN_AGENT value
                         * @property {number} AUTOMATED_AGENT=2 AUTOMATED_AGENT value
                         * @property {number} END_USER=3 END_USER value
                         */
                        Participant.Role = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "ROLE_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "HUMAN_AGENT"] = 1;
                            values[valuesById[2] = "AUTOMATED_AGENT"] = 2;
                            values[valuesById[3] = "END_USER"] = 3;
                            return values;
                        })();
    
                        return Participant;
                    })();
    
                    v2.Message = (function() {
    
                        /**
                         * Properties of a Message.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IMessage
                         * @property {string|null} [name] Message name
                         * @property {string|null} [content] Message content
                         * @property {string|null} [languageCode] Message languageCode
                         * @property {string|null} [participant] Message participant
                         * @property {google.cloud.dialogflow.v2.Participant.Role|null} [participantRole] Message participantRole
                         * @property {google.protobuf.ITimestamp|null} [createTime] Message createTime
                         * @property {google.protobuf.ITimestamp|null} [sendTime] Message sendTime
                         * @property {google.cloud.dialogflow.v2.IMessageAnnotation|null} [messageAnnotation] Message messageAnnotation
                         * @property {google.cloud.dialogflow.v2.ISentimentAnalysisResult|null} [sentimentAnalysis] Message sentimentAnalysis
                         */
    
                        /**
                         * Constructs a new Message.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a Message.
                         * @implements IMessage
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IMessage=} [properties] Properties to set
                         */
                        function Message(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * Message name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2.Message
                         * @instance
                         */
                        Message.prototype.name = "";
    
                        /**
                         * Message content.
                         * @member {string} content
                         * @memberof google.cloud.dialogflow.v2.Message
                         * @instance
                         */
                        Message.prototype.content = "";
    
                        /**
                         * Message languageCode.
                         * @member {string} languageCode
                         * @memberof google.cloud.dialogflow.v2.Message
                         * @instance
                         */
                        Message.prototype.languageCode = "";
    
                        /**
                         * Message participant.
                         * @member {string} participant
                         * @memberof google.cloud.dialogflow.v2.Message
                         * @instance
                         */
                        Message.prototype.participant = "";
    
                        /**
                         * Message participantRole.
                         * @member {google.cloud.dialogflow.v2.Participant.Role} participantRole
                         * @memberof google.cloud.dialogflow.v2.Message
                         * @instance
                         */
                        Message.prototype.participantRole = 0;
    
                        /**
                         * Message createTime.
                         * @member {google.protobuf.ITimestamp|null|undefined} createTime
                         * @memberof google.cloud.dialogflow.v2.Message
                         * @instance
                         */
                        Message.prototype.createTime = null;
    
                        /**
                         * Message sendTime.
                         * @member {google.protobuf.ITimestamp|null|undefined} sendTime
                         * @memberof google.cloud.dialogflow.v2.Message
                         * @instance
                         */
                        Message.prototype.sendTime = null;
    
                        /**
                         * Message messageAnnotation.
                         * @member {google.cloud.dialogflow.v2.IMessageAnnotation|null|undefined} messageAnnotation
                         * @memberof google.cloud.dialogflow.v2.Message
                         * @instance
                         */
                        Message.prototype.messageAnnotation = null;
    
                        /**
                         * Message sentimentAnalysis.
                         * @member {google.cloud.dialogflow.v2.ISentimentAnalysisResult|null|undefined} sentimentAnalysis
                         * @memberof google.cloud.dialogflow.v2.Message
                         * @instance
                         */
                        Message.prototype.sentimentAnalysis = null;
    
                        /**
                         * Creates a new Message instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.Message
                         * @static
                         * @param {google.cloud.dialogflow.v2.IMessage=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.Message} Message instance
                         */
                        Message.create = function create(properties) {
                            return new Message(properties);
                        };
    
                        /**
                         * Encodes the specified Message message. Does not implicitly {@link google.cloud.dialogflow.v2.Message.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.Message
                         * @static
                         * @param {google.cloud.dialogflow.v2.IMessage} message Message message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        Message.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            if (message.content != null && Object.hasOwnProperty.call(message, "content"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.content);
                            if (message.languageCode != null && Object.hasOwnProperty.call(message, "languageCode"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.languageCode);
                            if (message.participant != null && Object.hasOwnProperty.call(message, "participant"))
                                writer.uint32(/* id 4, wireType 2 =*/34).string(message.participant);
                            if (message.participantRole != null && Object.hasOwnProperty.call(message, "participantRole"))
                                writer.uint32(/* id 5, wireType 0 =*/40).int32(message.participantRole);
                            if (message.createTime != null && Object.hasOwnProperty.call(message, "createTime"))
                                $root.google.protobuf.Timestamp.encode(message.createTime, writer.uint32(/* id 6, wireType 2 =*/50).fork()).ldelim();
                            if (message.messageAnnotation != null && Object.hasOwnProperty.call(message, "messageAnnotation"))
                                $root.google.cloud.dialogflow.v2.MessageAnnotation.encode(message.messageAnnotation, writer.uint32(/* id 7, wireType 2 =*/58).fork()).ldelim();
                            if (message.sentimentAnalysis != null && Object.hasOwnProperty.call(message, "sentimentAnalysis"))
                                $root.google.cloud.dialogflow.v2.SentimentAnalysisResult.encode(message.sentimentAnalysis, writer.uint32(/* id 8, wireType 2 =*/66).fork()).ldelim();
                            if (message.sendTime != null && Object.hasOwnProperty.call(message, "sendTime"))
                                $root.google.protobuf.Timestamp.encode(message.sendTime, writer.uint32(/* id 9, wireType 2 =*/74).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified Message message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.Message.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.Message
                         * @static
                         * @param {google.cloud.dialogflow.v2.IMessage} message Message message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        Message.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a Message message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.Message
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.Message} Message
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        Message.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.Message();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.content = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.languageCode = reader.string();
                                        break;
                                    }
                                case 4: {
                                        message.participant = reader.string();
                                        break;
                                    }
                                case 5: {
                                        message.participantRole = reader.int32();
                                        break;
                                    }
                                case 6: {
                                        message.createTime = $root.google.protobuf.Timestamp.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 9: {
                                        message.sendTime = $root.google.protobuf.Timestamp.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 7: {
                                        message.messageAnnotation = $root.google.cloud.dialogflow.v2.MessageAnnotation.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 8: {
                                        message.sentimentAnalysis = $root.google.cloud.dialogflow.v2.SentimentAnalysisResult.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a Message message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.Message
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.Message} Message
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        Message.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a Message message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.Message
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        Message.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            if (message.content != null && message.hasOwnProperty("content"))
                                if (!$util.isString(message.content))
                                    return "content: string expected";
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                if (!$util.isString(message.languageCode))
                                    return "languageCode: string expected";
                            if (message.participant != null && message.hasOwnProperty("participant"))
                                if (!$util.isString(message.participant))
                                    return "participant: string expected";
                            if (message.participantRole != null && message.hasOwnProperty("participantRole"))
                                switch (message.participantRole) {
                                default:
                                    return "participantRole: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                    break;
                                }
                            if (message.createTime != null && message.hasOwnProperty("createTime")) {
                                var error = $root.google.protobuf.Timestamp.verify(message.createTime);
                                if (error)
                                    return "createTime." + error;
                            }
                            if (message.sendTime != null && message.hasOwnProperty("sendTime")) {
                                var error = $root.google.protobuf.Timestamp.verify(message.sendTime);
                                if (error)
                                    return "sendTime." + error;
                            }
                            if (message.messageAnnotation != null && message.hasOwnProperty("messageAnnotation")) {
                                var error = $root.google.cloud.dialogflow.v2.MessageAnnotation.verify(message.messageAnnotation);
                                if (error)
                                    return "messageAnnotation." + error;
                            }
                            if (message.sentimentAnalysis != null && message.hasOwnProperty("sentimentAnalysis")) {
                                var error = $root.google.cloud.dialogflow.v2.SentimentAnalysisResult.verify(message.sentimentAnalysis);
                                if (error)
                                    return "sentimentAnalysis." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a Message message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.Message
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.Message} Message
                         */
                        Message.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.Message)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.Message();
                            if (object.name != null)
                                message.name = String(object.name);
                            if (object.content != null)
                                message.content = String(object.content);
                            if (object.languageCode != null)
                                message.languageCode = String(object.languageCode);
                            if (object.participant != null)
                                message.participant = String(object.participant);
                            switch (object.participantRole) {
                            default:
                                if (typeof object.participantRole === "number") {
                                    message.participantRole = object.participantRole;
                                    break;
                                }
                                break;
                            case "ROLE_UNSPECIFIED":
                            case 0:
                                message.participantRole = 0;
                                break;
                            case "HUMAN_AGENT":
                            case 1:
                                message.participantRole = 1;
                                break;
                            case "AUTOMATED_AGENT":
                            case 2:
                                message.participantRole = 2;
                                break;
                            case "END_USER":
                            case 3:
                                message.participantRole = 3;
                                break;
                            }
                            if (object.createTime != null) {
                                if (typeof object.createTime !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.Message.createTime: object expected");
                                message.createTime = $root.google.protobuf.Timestamp.fromObject(object.createTime);
                            }
                            if (object.sendTime != null) {
                                if (typeof object.sendTime !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.Message.sendTime: object expected");
                                message.sendTime = $root.google.protobuf.Timestamp.fromObject(object.sendTime);
                            }
                            if (object.messageAnnotation != null) {
                                if (typeof object.messageAnnotation !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.Message.messageAnnotation: object expected");
                                message.messageAnnotation = $root.google.cloud.dialogflow.v2.MessageAnnotation.fromObject(object.messageAnnotation);
                            }
                            if (object.sentimentAnalysis != null) {
                                if (typeof object.sentimentAnalysis !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.Message.sentimentAnalysis: object expected");
                                message.sentimentAnalysis = $root.google.cloud.dialogflow.v2.SentimentAnalysisResult.fromObject(object.sentimentAnalysis);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a Message message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.Message
                         * @static
                         * @param {google.cloud.dialogflow.v2.Message} message Message
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        Message.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.name = "";
                                object.content = "";
                                object.languageCode = "";
                                object.participant = "";
                                object.participantRole = options.enums === String ? "ROLE_UNSPECIFIED" : 0;
                                object.createTime = null;
                                object.messageAnnotation = null;
                                object.sentimentAnalysis = null;
                                object.sendTime = null;
                            }
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            if (message.content != null && message.hasOwnProperty("content"))
                                object.content = message.content;
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                object.languageCode = message.languageCode;
                            if (message.participant != null && message.hasOwnProperty("participant"))
                                object.participant = message.participant;
                            if (message.participantRole != null && message.hasOwnProperty("participantRole"))
                                object.participantRole = options.enums === String ? $root.google.cloud.dialogflow.v2.Participant.Role[message.participantRole] === undefined ? message.participantRole : $root.google.cloud.dialogflow.v2.Participant.Role[message.participantRole] : message.participantRole;
                            if (message.createTime != null && message.hasOwnProperty("createTime"))
                                object.createTime = $root.google.protobuf.Timestamp.toObject(message.createTime, options);
                            if (message.messageAnnotation != null && message.hasOwnProperty("messageAnnotation"))
                                object.messageAnnotation = $root.google.cloud.dialogflow.v2.MessageAnnotation.toObject(message.messageAnnotation, options);
                            if (message.sentimentAnalysis != null && message.hasOwnProperty("sentimentAnalysis"))
                                object.sentimentAnalysis = $root.google.cloud.dialogflow.v2.SentimentAnalysisResult.toObject(message.sentimentAnalysis, options);
                            if (message.sendTime != null && message.hasOwnProperty("sendTime"))
                                object.sendTime = $root.google.protobuf.Timestamp.toObject(message.sendTime, options);
                            return object;
                        };
    
                        /**
                         * Converts this Message to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.Message
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        Message.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for Message
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.Message
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        Message.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.Message";
                        };
    
                        return Message;
                    })();
    
                    v2.CreateParticipantRequest = (function() {
    
                        /**
                         * Properties of a CreateParticipantRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ICreateParticipantRequest
                         * @property {string|null} [parent] CreateParticipantRequest parent
                         * @property {google.cloud.dialogflow.v2.IParticipant|null} [participant] CreateParticipantRequest participant
                         */
    
                        /**
                         * Constructs a new CreateParticipantRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a CreateParticipantRequest.
                         * @implements ICreateParticipantRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ICreateParticipantRequest=} [properties] Properties to set
                         */
                        function CreateParticipantRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * CreateParticipantRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.CreateParticipantRequest
                         * @instance
                         */
                        CreateParticipantRequest.prototype.parent = "";
    
                        /**
                         * CreateParticipantRequest participant.
                         * @member {google.cloud.dialogflow.v2.IParticipant|null|undefined} participant
                         * @memberof google.cloud.dialogflow.v2.CreateParticipantRequest
                         * @instance
                         */
                        CreateParticipantRequest.prototype.participant = null;
    
                        /**
                         * Creates a new CreateParticipantRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.CreateParticipantRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICreateParticipantRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.CreateParticipantRequest} CreateParticipantRequest instance
                         */
                        CreateParticipantRequest.create = function create(properties) {
                            return new CreateParticipantRequest(properties);
                        };
    
                        /**
                         * Encodes the specified CreateParticipantRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.CreateParticipantRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.CreateParticipantRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICreateParticipantRequest} message CreateParticipantRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateParticipantRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.participant != null && Object.hasOwnProperty.call(message, "participant"))
                                $root.google.cloud.dialogflow.v2.Participant.encode(message.participant, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified CreateParticipantRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.CreateParticipantRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.CreateParticipantRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICreateParticipantRequest} message CreateParticipantRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateParticipantRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a CreateParticipantRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.CreateParticipantRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.CreateParticipantRequest} CreateParticipantRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateParticipantRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.CreateParticipantRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.participant = $root.google.cloud.dialogflow.v2.Participant.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a CreateParticipantRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.CreateParticipantRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.CreateParticipantRequest} CreateParticipantRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateParticipantRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a CreateParticipantRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.CreateParticipantRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        CreateParticipantRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.participant != null && message.hasOwnProperty("participant")) {
                                var error = $root.google.cloud.dialogflow.v2.Participant.verify(message.participant);
                                if (error)
                                    return "participant." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a CreateParticipantRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.CreateParticipantRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.CreateParticipantRequest} CreateParticipantRequest
                         */
                        CreateParticipantRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.CreateParticipantRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.CreateParticipantRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.participant != null) {
                                if (typeof object.participant !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.CreateParticipantRequest.participant: object expected");
                                message.participant = $root.google.cloud.dialogflow.v2.Participant.fromObject(object.participant);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a CreateParticipantRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.CreateParticipantRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.CreateParticipantRequest} message CreateParticipantRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        CreateParticipantRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.participant = null;
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.participant != null && message.hasOwnProperty("participant"))
                                object.participant = $root.google.cloud.dialogflow.v2.Participant.toObject(message.participant, options);
                            return object;
                        };
    
                        /**
                         * Converts this CreateParticipantRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.CreateParticipantRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        CreateParticipantRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for CreateParticipantRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.CreateParticipantRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        CreateParticipantRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.CreateParticipantRequest";
                        };
    
                        return CreateParticipantRequest;
                    })();
    
                    v2.GetParticipantRequest = (function() {
    
                        /**
                         * Properties of a GetParticipantRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IGetParticipantRequest
                         * @property {string|null} [name] GetParticipantRequest name
                         */
    
                        /**
                         * Constructs a new GetParticipantRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a GetParticipantRequest.
                         * @implements IGetParticipantRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IGetParticipantRequest=} [properties] Properties to set
                         */
                        function GetParticipantRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GetParticipantRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2.GetParticipantRequest
                         * @instance
                         */
                        GetParticipantRequest.prototype.name = "";
    
                        /**
                         * Creates a new GetParticipantRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.GetParticipantRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetParticipantRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.GetParticipantRequest} GetParticipantRequest instance
                         */
                        GetParticipantRequest.create = function create(properties) {
                            return new GetParticipantRequest(properties);
                        };
    
                        /**
                         * Encodes the specified GetParticipantRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.GetParticipantRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.GetParticipantRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetParticipantRequest} message GetParticipantRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetParticipantRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GetParticipantRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.GetParticipantRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GetParticipantRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetParticipantRequest} message GetParticipantRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetParticipantRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GetParticipantRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.GetParticipantRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.GetParticipantRequest} GetParticipantRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetParticipantRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.GetParticipantRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GetParticipantRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GetParticipantRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.GetParticipantRequest} GetParticipantRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetParticipantRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GetParticipantRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.GetParticipantRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GetParticipantRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a GetParticipantRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.GetParticipantRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.GetParticipantRequest} GetParticipantRequest
                         */
                        GetParticipantRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.GetParticipantRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.GetParticipantRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GetParticipantRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.GetParticipantRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.GetParticipantRequest} message GetParticipantRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GetParticipantRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.name = "";
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            return object;
                        };
    
                        /**
                         * Converts this GetParticipantRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.GetParticipantRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GetParticipantRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GetParticipantRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.GetParticipantRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GetParticipantRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.GetParticipantRequest";
                        };
    
                        return GetParticipantRequest;
                    })();
    
                    v2.ListParticipantsRequest = (function() {
    
                        /**
                         * Properties of a ListParticipantsRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IListParticipantsRequest
                         * @property {string|null} [parent] ListParticipantsRequest parent
                         * @property {number|null} [pageSize] ListParticipantsRequest pageSize
                         * @property {string|null} [pageToken] ListParticipantsRequest pageToken
                         */
    
                        /**
                         * Constructs a new ListParticipantsRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a ListParticipantsRequest.
                         * @implements IListParticipantsRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IListParticipantsRequest=} [properties] Properties to set
                         */
                        function ListParticipantsRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListParticipantsRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.ListParticipantsRequest
                         * @instance
                         */
                        ListParticipantsRequest.prototype.parent = "";
    
                        /**
                         * ListParticipantsRequest pageSize.
                         * @member {number} pageSize
                         * @memberof google.cloud.dialogflow.v2.ListParticipantsRequest
                         * @instance
                         */
                        ListParticipantsRequest.prototype.pageSize = 0;
    
                        /**
                         * ListParticipantsRequest pageToken.
                         * @member {string} pageToken
                         * @memberof google.cloud.dialogflow.v2.ListParticipantsRequest
                         * @instance
                         */
                        ListParticipantsRequest.prototype.pageToken = "";
    
                        /**
                         * Creates a new ListParticipantsRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ListParticipantsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListParticipantsRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ListParticipantsRequest} ListParticipantsRequest instance
                         */
                        ListParticipantsRequest.create = function create(properties) {
                            return new ListParticipantsRequest(properties);
                        };
    
                        /**
                         * Encodes the specified ListParticipantsRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.ListParticipantsRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ListParticipantsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListParticipantsRequest} message ListParticipantsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListParticipantsRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.pageSize != null && Object.hasOwnProperty.call(message, "pageSize"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.pageSize);
                            if (message.pageToken != null && Object.hasOwnProperty.call(message, "pageToken"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.pageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListParticipantsRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ListParticipantsRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListParticipantsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListParticipantsRequest} message ListParticipantsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListParticipantsRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListParticipantsRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ListParticipantsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ListParticipantsRequest} ListParticipantsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListParticipantsRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ListParticipantsRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.pageSize = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.pageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListParticipantsRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListParticipantsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ListParticipantsRequest} ListParticipantsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListParticipantsRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListParticipantsRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ListParticipantsRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListParticipantsRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                if (!$util.isInteger(message.pageSize))
                                    return "pageSize: integer expected";
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                if (!$util.isString(message.pageToken))
                                    return "pageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListParticipantsRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ListParticipantsRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ListParticipantsRequest} ListParticipantsRequest
                         */
                        ListParticipantsRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ListParticipantsRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ListParticipantsRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.pageSize != null)
                                message.pageSize = object.pageSize | 0;
                            if (object.pageToken != null)
                                message.pageToken = String(object.pageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListParticipantsRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ListParticipantsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ListParticipantsRequest} message ListParticipantsRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListParticipantsRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.pageSize = 0;
                                object.pageToken = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                object.pageSize = message.pageSize;
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                object.pageToken = message.pageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListParticipantsRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ListParticipantsRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListParticipantsRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListParticipantsRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ListParticipantsRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListParticipantsRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ListParticipantsRequest";
                        };
    
                        return ListParticipantsRequest;
                    })();
    
                    v2.ListParticipantsResponse = (function() {
    
                        /**
                         * Properties of a ListParticipantsResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IListParticipantsResponse
                         * @property {Array.<google.cloud.dialogflow.v2.IParticipant>|null} [participants] ListParticipantsResponse participants
                         * @property {string|null} [nextPageToken] ListParticipantsResponse nextPageToken
                         */
    
                        /**
                         * Constructs a new ListParticipantsResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a ListParticipantsResponse.
                         * @implements IListParticipantsResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IListParticipantsResponse=} [properties] Properties to set
                         */
                        function ListParticipantsResponse(properties) {
                            this.participants = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListParticipantsResponse participants.
                         * @member {Array.<google.cloud.dialogflow.v2.IParticipant>} participants
                         * @memberof google.cloud.dialogflow.v2.ListParticipantsResponse
                         * @instance
                         */
                        ListParticipantsResponse.prototype.participants = $util.emptyArray;
    
                        /**
                         * ListParticipantsResponse nextPageToken.
                         * @member {string} nextPageToken
                         * @memberof google.cloud.dialogflow.v2.ListParticipantsResponse
                         * @instance
                         */
                        ListParticipantsResponse.prototype.nextPageToken = "";
    
                        /**
                         * Creates a new ListParticipantsResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ListParticipantsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListParticipantsResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ListParticipantsResponse} ListParticipantsResponse instance
                         */
                        ListParticipantsResponse.create = function create(properties) {
                            return new ListParticipantsResponse(properties);
                        };
    
                        /**
                         * Encodes the specified ListParticipantsResponse message. Does not implicitly {@link google.cloud.dialogflow.v2.ListParticipantsResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ListParticipantsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListParticipantsResponse} message ListParticipantsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListParticipantsResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.participants != null && message.participants.length)
                                for (var i = 0; i < message.participants.length; ++i)
                                    $root.google.cloud.dialogflow.v2.Participant.encode(message.participants[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.nextPageToken != null && Object.hasOwnProperty.call(message, "nextPageToken"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.nextPageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListParticipantsResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ListParticipantsResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListParticipantsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListParticipantsResponse} message ListParticipantsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListParticipantsResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListParticipantsResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ListParticipantsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ListParticipantsResponse} ListParticipantsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListParticipantsResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ListParticipantsResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.participants && message.participants.length))
                                            message.participants = [];
                                        message.participants.push($root.google.cloud.dialogflow.v2.Participant.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 2: {
                                        message.nextPageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListParticipantsResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListParticipantsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ListParticipantsResponse} ListParticipantsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListParticipantsResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListParticipantsResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ListParticipantsResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListParticipantsResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.participants != null && message.hasOwnProperty("participants")) {
                                if (!Array.isArray(message.participants))
                                    return "participants: array expected";
                                for (var i = 0; i < message.participants.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.Participant.verify(message.participants[i]);
                                    if (error)
                                        return "participants." + error;
                                }
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                if (!$util.isString(message.nextPageToken))
                                    return "nextPageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListParticipantsResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ListParticipantsResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ListParticipantsResponse} ListParticipantsResponse
                         */
                        ListParticipantsResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ListParticipantsResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ListParticipantsResponse();
                            if (object.participants) {
                                if (!Array.isArray(object.participants))
                                    throw TypeError(".google.cloud.dialogflow.v2.ListParticipantsResponse.participants: array expected");
                                message.participants = [];
                                for (var i = 0; i < object.participants.length; ++i) {
                                    if (typeof object.participants[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.ListParticipantsResponse.participants: object expected");
                                    message.participants[i] = $root.google.cloud.dialogflow.v2.Participant.fromObject(object.participants[i]);
                                }
                            }
                            if (object.nextPageToken != null)
                                message.nextPageToken = String(object.nextPageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListParticipantsResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ListParticipantsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.ListParticipantsResponse} message ListParticipantsResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListParticipantsResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.participants = [];
                            if (options.defaults)
                                object.nextPageToken = "";
                            if (message.participants && message.participants.length) {
                                object.participants = [];
                                for (var j = 0; j < message.participants.length; ++j)
                                    object.participants[j] = $root.google.cloud.dialogflow.v2.Participant.toObject(message.participants[j], options);
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                object.nextPageToken = message.nextPageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListParticipantsResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ListParticipantsResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListParticipantsResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListParticipantsResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ListParticipantsResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListParticipantsResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ListParticipantsResponse";
                        };
    
                        return ListParticipantsResponse;
                    })();
    
                    v2.UpdateParticipantRequest = (function() {
    
                        /**
                         * Properties of an UpdateParticipantRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IUpdateParticipantRequest
                         * @property {google.cloud.dialogflow.v2.IParticipant|null} [participant] UpdateParticipantRequest participant
                         * @property {google.protobuf.IFieldMask|null} [updateMask] UpdateParticipantRequest updateMask
                         */
    
                        /**
                         * Constructs a new UpdateParticipantRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an UpdateParticipantRequest.
                         * @implements IUpdateParticipantRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IUpdateParticipantRequest=} [properties] Properties to set
                         */
                        function UpdateParticipantRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * UpdateParticipantRequest participant.
                         * @member {google.cloud.dialogflow.v2.IParticipant|null|undefined} participant
                         * @memberof google.cloud.dialogflow.v2.UpdateParticipantRequest
                         * @instance
                         */
                        UpdateParticipantRequest.prototype.participant = null;
    
                        /**
                         * UpdateParticipantRequest updateMask.
                         * @member {google.protobuf.IFieldMask|null|undefined} updateMask
                         * @memberof google.cloud.dialogflow.v2.UpdateParticipantRequest
                         * @instance
                         */
                        UpdateParticipantRequest.prototype.updateMask = null;
    
                        /**
                         * Creates a new UpdateParticipantRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.UpdateParticipantRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IUpdateParticipantRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.UpdateParticipantRequest} UpdateParticipantRequest instance
                         */
                        UpdateParticipantRequest.create = function create(properties) {
                            return new UpdateParticipantRequest(properties);
                        };
    
                        /**
                         * Encodes the specified UpdateParticipantRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.UpdateParticipantRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.UpdateParticipantRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IUpdateParticipantRequest} message UpdateParticipantRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UpdateParticipantRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.participant != null && Object.hasOwnProperty.call(message, "participant"))
                                $root.google.cloud.dialogflow.v2.Participant.encode(message.participant, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.updateMask != null && Object.hasOwnProperty.call(message, "updateMask"))
                                $root.google.protobuf.FieldMask.encode(message.updateMask, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified UpdateParticipantRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.UpdateParticipantRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.UpdateParticipantRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IUpdateParticipantRequest} message UpdateParticipantRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UpdateParticipantRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an UpdateParticipantRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.UpdateParticipantRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.UpdateParticipantRequest} UpdateParticipantRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UpdateParticipantRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.UpdateParticipantRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.participant = $root.google.cloud.dialogflow.v2.Participant.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.updateMask = $root.google.protobuf.FieldMask.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an UpdateParticipantRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.UpdateParticipantRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.UpdateParticipantRequest} UpdateParticipantRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UpdateParticipantRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an UpdateParticipantRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.UpdateParticipantRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        UpdateParticipantRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.participant != null && message.hasOwnProperty("participant")) {
                                var error = $root.google.cloud.dialogflow.v2.Participant.verify(message.participant);
                                if (error)
                                    return "participant." + error;
                            }
                            if (message.updateMask != null && message.hasOwnProperty("updateMask")) {
                                var error = $root.google.protobuf.FieldMask.verify(message.updateMask);
                                if (error)
                                    return "updateMask." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates an UpdateParticipantRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.UpdateParticipantRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.UpdateParticipantRequest} UpdateParticipantRequest
                         */
                        UpdateParticipantRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.UpdateParticipantRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.UpdateParticipantRequest();
                            if (object.participant != null) {
                                if (typeof object.participant !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.UpdateParticipantRequest.participant: object expected");
                                message.participant = $root.google.cloud.dialogflow.v2.Participant.fromObject(object.participant);
                            }
                            if (object.updateMask != null) {
                                if (typeof object.updateMask !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.UpdateParticipantRequest.updateMask: object expected");
                                message.updateMask = $root.google.protobuf.FieldMask.fromObject(object.updateMask);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an UpdateParticipantRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.UpdateParticipantRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.UpdateParticipantRequest} message UpdateParticipantRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        UpdateParticipantRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.participant = null;
                                object.updateMask = null;
                            }
                            if (message.participant != null && message.hasOwnProperty("participant"))
                                object.participant = $root.google.cloud.dialogflow.v2.Participant.toObject(message.participant, options);
                            if (message.updateMask != null && message.hasOwnProperty("updateMask"))
                                object.updateMask = $root.google.protobuf.FieldMask.toObject(message.updateMask, options);
                            return object;
                        };
    
                        /**
                         * Converts this UpdateParticipantRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.UpdateParticipantRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        UpdateParticipantRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for UpdateParticipantRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.UpdateParticipantRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        UpdateParticipantRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.UpdateParticipantRequest";
                        };
    
                        return UpdateParticipantRequest;
                    })();
    
                    v2.AnalyzeContentRequest = (function() {
    
                        /**
                         * Properties of an AnalyzeContentRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IAnalyzeContentRequest
                         * @property {string|null} [participant] AnalyzeContentRequest participant
                         * @property {google.cloud.dialogflow.v2.ITextInput|null} [textInput] AnalyzeContentRequest textInput
                         * @property {google.cloud.dialogflow.v2.IAudioInput|null} [audioInput] AnalyzeContentRequest audioInput
                         * @property {google.cloud.dialogflow.v2.IEventInput|null} [eventInput] AnalyzeContentRequest eventInput
                         * @property {google.cloud.dialogflow.v2.ISuggestionInput|null} [suggestionInput] AnalyzeContentRequest suggestionInput
                         * @property {google.cloud.dialogflow.v2.IOutputAudioConfig|null} [replyAudioConfig] AnalyzeContentRequest replyAudioConfig
                         * @property {google.cloud.dialogflow.v2.IQueryParameters|null} [queryParams] AnalyzeContentRequest queryParams
                         * @property {google.cloud.dialogflow.v2.IAssistQueryParameters|null} [assistQueryParams] AnalyzeContentRequest assistQueryParams
                         * @property {google.protobuf.IStruct|null} [cxParameters] AnalyzeContentRequest cxParameters
                         * @property {string|null} [requestId] AnalyzeContentRequest requestId
                         */
    
                        /**
                         * Constructs a new AnalyzeContentRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an AnalyzeContentRequest.
                         * @implements IAnalyzeContentRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IAnalyzeContentRequest=} [properties] Properties to set
                         */
                        function AnalyzeContentRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * AnalyzeContentRequest participant.
                         * @member {string} participant
                         * @memberof google.cloud.dialogflow.v2.AnalyzeContentRequest
                         * @instance
                         */
                        AnalyzeContentRequest.prototype.participant = "";
    
                        /**
                         * AnalyzeContentRequest textInput.
                         * @member {google.cloud.dialogflow.v2.ITextInput|null|undefined} textInput
                         * @memberof google.cloud.dialogflow.v2.AnalyzeContentRequest
                         * @instance
                         */
                        AnalyzeContentRequest.prototype.textInput = null;
    
                        /**
                         * AnalyzeContentRequest audioInput.
                         * @member {google.cloud.dialogflow.v2.IAudioInput|null|undefined} audioInput
                         * @memberof google.cloud.dialogflow.v2.AnalyzeContentRequest
                         * @instance
                         */
                        AnalyzeContentRequest.prototype.audioInput = null;
    
                        /**
                         * AnalyzeContentRequest eventInput.
                         * @member {google.cloud.dialogflow.v2.IEventInput|null|undefined} eventInput
                         * @memberof google.cloud.dialogflow.v2.AnalyzeContentRequest
                         * @instance
                         */
                        AnalyzeContentRequest.prototype.eventInput = null;
    
                        /**
                         * AnalyzeContentRequest suggestionInput.
                         * @member {google.cloud.dialogflow.v2.ISuggestionInput|null|undefined} suggestionInput
                         * @memberof google.cloud.dialogflow.v2.AnalyzeContentRequest
                         * @instance
                         */
                        AnalyzeContentRequest.prototype.suggestionInput = null;
    
                        /**
                         * AnalyzeContentRequest replyAudioConfig.
                         * @member {google.cloud.dialogflow.v2.IOutputAudioConfig|null|undefined} replyAudioConfig
                         * @memberof google.cloud.dialogflow.v2.AnalyzeContentRequest
                         * @instance
                         */
                        AnalyzeContentRequest.prototype.replyAudioConfig = null;
    
                        /**
                         * AnalyzeContentRequest queryParams.
                         * @member {google.cloud.dialogflow.v2.IQueryParameters|null|undefined} queryParams
                         * @memberof google.cloud.dialogflow.v2.AnalyzeContentRequest
                         * @instance
                         */
                        AnalyzeContentRequest.prototype.queryParams = null;
    
                        /**
                         * AnalyzeContentRequest assistQueryParams.
                         * @member {google.cloud.dialogflow.v2.IAssistQueryParameters|null|undefined} assistQueryParams
                         * @memberof google.cloud.dialogflow.v2.AnalyzeContentRequest
                         * @instance
                         */
                        AnalyzeContentRequest.prototype.assistQueryParams = null;
    
                        /**
                         * AnalyzeContentRequest cxParameters.
                         * @member {google.protobuf.IStruct|null|undefined} cxParameters
                         * @memberof google.cloud.dialogflow.v2.AnalyzeContentRequest
                         * @instance
                         */
                        AnalyzeContentRequest.prototype.cxParameters = null;
    
                        /**
                         * AnalyzeContentRequest requestId.
                         * @member {string} requestId
                         * @memberof google.cloud.dialogflow.v2.AnalyzeContentRequest
                         * @instance
                         */
                        AnalyzeContentRequest.prototype.requestId = "";
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * AnalyzeContentRequest input.
                         * @member {"textInput"|"audioInput"|"eventInput"|"suggestionInput"|undefined} input
                         * @memberof google.cloud.dialogflow.v2.AnalyzeContentRequest
                         * @instance
                         */
                        Object.defineProperty(AnalyzeContentRequest.prototype, "input", {
                            get: $util.oneOfGetter($oneOfFields = ["textInput", "audioInput", "eventInput", "suggestionInput"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new AnalyzeContentRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.AnalyzeContentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IAnalyzeContentRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.AnalyzeContentRequest} AnalyzeContentRequest instance
                         */
                        AnalyzeContentRequest.create = function create(properties) {
                            return new AnalyzeContentRequest(properties);
                        };
    
                        /**
                         * Encodes the specified AnalyzeContentRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.AnalyzeContentRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.AnalyzeContentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IAnalyzeContentRequest} message AnalyzeContentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        AnalyzeContentRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.participant != null && Object.hasOwnProperty.call(message, "participant"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.participant);
                            if (message.replyAudioConfig != null && Object.hasOwnProperty.call(message, "replyAudioConfig"))
                                $root.google.cloud.dialogflow.v2.OutputAudioConfig.encode(message.replyAudioConfig, writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                            if (message.textInput != null && Object.hasOwnProperty.call(message, "textInput"))
                                $root.google.cloud.dialogflow.v2.TextInput.encode(message.textInput, writer.uint32(/* id 6, wireType 2 =*/50).fork()).ldelim();
                            if (message.audioInput != null && Object.hasOwnProperty.call(message, "audioInput"))
                                $root.google.cloud.dialogflow.v2.AudioInput.encode(message.audioInput, writer.uint32(/* id 7, wireType 2 =*/58).fork()).ldelim();
                            if (message.eventInput != null && Object.hasOwnProperty.call(message, "eventInput"))
                                $root.google.cloud.dialogflow.v2.EventInput.encode(message.eventInput, writer.uint32(/* id 8, wireType 2 =*/66).fork()).ldelim();
                            if (message.queryParams != null && Object.hasOwnProperty.call(message, "queryParams"))
                                $root.google.cloud.dialogflow.v2.QueryParameters.encode(message.queryParams, writer.uint32(/* id 9, wireType 2 =*/74).fork()).ldelim();
                            if (message.requestId != null && Object.hasOwnProperty.call(message, "requestId"))
                                writer.uint32(/* id 11, wireType 2 =*/90).string(message.requestId);
                            if (message.suggestionInput != null && Object.hasOwnProperty.call(message, "suggestionInput"))
                                $root.google.cloud.dialogflow.v2.SuggestionInput.encode(message.suggestionInput, writer.uint32(/* id 12, wireType 2 =*/98).fork()).ldelim();
                            if (message.assistQueryParams != null && Object.hasOwnProperty.call(message, "assistQueryParams"))
                                $root.google.cloud.dialogflow.v2.AssistQueryParameters.encode(message.assistQueryParams, writer.uint32(/* id 14, wireType 2 =*/114).fork()).ldelim();
                            if (message.cxParameters != null && Object.hasOwnProperty.call(message, "cxParameters"))
                                $root.google.protobuf.Struct.encode(message.cxParameters, writer.uint32(/* id 18, wireType 2 =*/146).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified AnalyzeContentRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.AnalyzeContentRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.AnalyzeContentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IAnalyzeContentRequest} message AnalyzeContentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        AnalyzeContentRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an AnalyzeContentRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.AnalyzeContentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.AnalyzeContentRequest} AnalyzeContentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        AnalyzeContentRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.AnalyzeContentRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.participant = reader.string();
                                        break;
                                    }
                                case 6: {
                                        message.textInput = $root.google.cloud.dialogflow.v2.TextInput.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 7: {
                                        message.audioInput = $root.google.cloud.dialogflow.v2.AudioInput.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 8: {
                                        message.eventInput = $root.google.cloud.dialogflow.v2.EventInput.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 12: {
                                        message.suggestionInput = $root.google.cloud.dialogflow.v2.SuggestionInput.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 5: {
                                        message.replyAudioConfig = $root.google.cloud.dialogflow.v2.OutputAudioConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 9: {
                                        message.queryParams = $root.google.cloud.dialogflow.v2.QueryParameters.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 14: {
                                        message.assistQueryParams = $root.google.cloud.dialogflow.v2.AssistQueryParameters.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 18: {
                                        message.cxParameters = $root.google.protobuf.Struct.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 11: {
                                        message.requestId = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an AnalyzeContentRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.AnalyzeContentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.AnalyzeContentRequest} AnalyzeContentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        AnalyzeContentRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an AnalyzeContentRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.AnalyzeContentRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        AnalyzeContentRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.participant != null && message.hasOwnProperty("participant"))
                                if (!$util.isString(message.participant))
                                    return "participant: string expected";
                            if (message.textInput != null && message.hasOwnProperty("textInput")) {
                                properties.input = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2.TextInput.verify(message.textInput);
                                    if (error)
                                        return "textInput." + error;
                                }
                            }
                            if (message.audioInput != null && message.hasOwnProperty("audioInput")) {
                                if (properties.input === 1)
                                    return "input: multiple values";
                                properties.input = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2.AudioInput.verify(message.audioInput);
                                    if (error)
                                        return "audioInput." + error;
                                }
                            }
                            if (message.eventInput != null && message.hasOwnProperty("eventInput")) {
                                if (properties.input === 1)
                                    return "input: multiple values";
                                properties.input = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2.EventInput.verify(message.eventInput);
                                    if (error)
                                        return "eventInput." + error;
                                }
                            }
                            if (message.suggestionInput != null && message.hasOwnProperty("suggestionInput")) {
                                if (properties.input === 1)
                                    return "input: multiple values";
                                properties.input = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2.SuggestionInput.verify(message.suggestionInput);
                                    if (error)
                                        return "suggestionInput." + error;
                                }
                            }
                            if (message.replyAudioConfig != null && message.hasOwnProperty("replyAudioConfig")) {
                                var error = $root.google.cloud.dialogflow.v2.OutputAudioConfig.verify(message.replyAudioConfig);
                                if (error)
                                    return "replyAudioConfig." + error;
                            }
                            if (message.queryParams != null && message.hasOwnProperty("queryParams")) {
                                var error = $root.google.cloud.dialogflow.v2.QueryParameters.verify(message.queryParams);
                                if (error)
                                    return "queryParams." + error;
                            }
                            if (message.assistQueryParams != null && message.hasOwnProperty("assistQueryParams")) {
                                var error = $root.google.cloud.dialogflow.v2.AssistQueryParameters.verify(message.assistQueryParams);
                                if (error)
                                    return "assistQueryParams." + error;
                            }
                            if (message.cxParameters != null && message.hasOwnProperty("cxParameters")) {
                                var error = $root.google.protobuf.Struct.verify(message.cxParameters);
                                if (error)
                                    return "cxParameters." + error;
                            }
                            if (message.requestId != null && message.hasOwnProperty("requestId"))
                                if (!$util.isString(message.requestId))
                                    return "requestId: string expected";
                            return null;
                        };
    
                        /**
                         * Creates an AnalyzeContentRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.AnalyzeContentRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.AnalyzeContentRequest} AnalyzeContentRequest
                         */
                        AnalyzeContentRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.AnalyzeContentRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.AnalyzeContentRequest();
                            if (object.participant != null)
                                message.participant = String(object.participant);
                            if (object.textInput != null) {
                                if (typeof object.textInput !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.AnalyzeContentRequest.textInput: object expected");
                                message.textInput = $root.google.cloud.dialogflow.v2.TextInput.fromObject(object.textInput);
                            }
                            if (object.audioInput != null) {
                                if (typeof object.audioInput !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.AnalyzeContentRequest.audioInput: object expected");
                                message.audioInput = $root.google.cloud.dialogflow.v2.AudioInput.fromObject(object.audioInput);
                            }
                            if (object.eventInput != null) {
                                if (typeof object.eventInput !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.AnalyzeContentRequest.eventInput: object expected");
                                message.eventInput = $root.google.cloud.dialogflow.v2.EventInput.fromObject(object.eventInput);
                            }
                            if (object.suggestionInput != null) {
                                if (typeof object.suggestionInput !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.AnalyzeContentRequest.suggestionInput: object expected");
                                message.suggestionInput = $root.google.cloud.dialogflow.v2.SuggestionInput.fromObject(object.suggestionInput);
                            }
                            if (object.replyAudioConfig != null) {
                                if (typeof object.replyAudioConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.AnalyzeContentRequest.replyAudioConfig: object expected");
                                message.replyAudioConfig = $root.google.cloud.dialogflow.v2.OutputAudioConfig.fromObject(object.replyAudioConfig);
                            }
                            if (object.queryParams != null) {
                                if (typeof object.queryParams !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.AnalyzeContentRequest.queryParams: object expected");
                                message.queryParams = $root.google.cloud.dialogflow.v2.QueryParameters.fromObject(object.queryParams);
                            }
                            if (object.assistQueryParams != null) {
                                if (typeof object.assistQueryParams !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.AnalyzeContentRequest.assistQueryParams: object expected");
                                message.assistQueryParams = $root.google.cloud.dialogflow.v2.AssistQueryParameters.fromObject(object.assistQueryParams);
                            }
                            if (object.cxParameters != null) {
                                if (typeof object.cxParameters !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.AnalyzeContentRequest.cxParameters: object expected");
                                message.cxParameters = $root.google.protobuf.Struct.fromObject(object.cxParameters);
                            }
                            if (object.requestId != null)
                                message.requestId = String(object.requestId);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an AnalyzeContentRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.AnalyzeContentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.AnalyzeContentRequest} message AnalyzeContentRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        AnalyzeContentRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.participant = "";
                                object.replyAudioConfig = null;
                                object.queryParams = null;
                                object.requestId = "";
                                object.assistQueryParams = null;
                                object.cxParameters = null;
                            }
                            if (message.participant != null && message.hasOwnProperty("participant"))
                                object.participant = message.participant;
                            if (message.replyAudioConfig != null && message.hasOwnProperty("replyAudioConfig"))
                                object.replyAudioConfig = $root.google.cloud.dialogflow.v2.OutputAudioConfig.toObject(message.replyAudioConfig, options);
                            if (message.textInput != null && message.hasOwnProperty("textInput")) {
                                object.textInput = $root.google.cloud.dialogflow.v2.TextInput.toObject(message.textInput, options);
                                if (options.oneofs)
                                    object.input = "textInput";
                            }
                            if (message.audioInput != null && message.hasOwnProperty("audioInput")) {
                                object.audioInput = $root.google.cloud.dialogflow.v2.AudioInput.toObject(message.audioInput, options);
                                if (options.oneofs)
                                    object.input = "audioInput";
                            }
                            if (message.eventInput != null && message.hasOwnProperty("eventInput")) {
                                object.eventInput = $root.google.cloud.dialogflow.v2.EventInput.toObject(message.eventInput, options);
                                if (options.oneofs)
                                    object.input = "eventInput";
                            }
                            if (message.queryParams != null && message.hasOwnProperty("queryParams"))
                                object.queryParams = $root.google.cloud.dialogflow.v2.QueryParameters.toObject(message.queryParams, options);
                            if (message.requestId != null && message.hasOwnProperty("requestId"))
                                object.requestId = message.requestId;
                            if (message.suggestionInput != null && message.hasOwnProperty("suggestionInput")) {
                                object.suggestionInput = $root.google.cloud.dialogflow.v2.SuggestionInput.toObject(message.suggestionInput, options);
                                if (options.oneofs)
                                    object.input = "suggestionInput";
                            }
                            if (message.assistQueryParams != null && message.hasOwnProperty("assistQueryParams"))
                                object.assistQueryParams = $root.google.cloud.dialogflow.v2.AssistQueryParameters.toObject(message.assistQueryParams, options);
                            if (message.cxParameters != null && message.hasOwnProperty("cxParameters"))
                                object.cxParameters = $root.google.protobuf.Struct.toObject(message.cxParameters, options);
                            return object;
                        };
    
                        /**
                         * Converts this AnalyzeContentRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.AnalyzeContentRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        AnalyzeContentRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for AnalyzeContentRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.AnalyzeContentRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        AnalyzeContentRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.AnalyzeContentRequest";
                        };
    
                        return AnalyzeContentRequest;
                    })();
    
                    v2.DtmfParameters = (function() {
    
                        /**
                         * Properties of a DtmfParameters.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IDtmfParameters
                         * @property {boolean|null} [acceptsDtmfInput] DtmfParameters acceptsDtmfInput
                         */
    
                        /**
                         * Constructs a new DtmfParameters.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a DtmfParameters.
                         * @implements IDtmfParameters
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IDtmfParameters=} [properties] Properties to set
                         */
                        function DtmfParameters(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * DtmfParameters acceptsDtmfInput.
                         * @member {boolean} acceptsDtmfInput
                         * @memberof google.cloud.dialogflow.v2.DtmfParameters
                         * @instance
                         */
                        DtmfParameters.prototype.acceptsDtmfInput = false;
    
                        /**
                         * Creates a new DtmfParameters instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.DtmfParameters
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDtmfParameters=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.DtmfParameters} DtmfParameters instance
                         */
                        DtmfParameters.create = function create(properties) {
                            return new DtmfParameters(properties);
                        };
    
                        /**
                         * Encodes the specified DtmfParameters message. Does not implicitly {@link google.cloud.dialogflow.v2.DtmfParameters.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.DtmfParameters
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDtmfParameters} message DtmfParameters message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DtmfParameters.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.acceptsDtmfInput != null && Object.hasOwnProperty.call(message, "acceptsDtmfInput"))
                                writer.uint32(/* id 1, wireType 0 =*/8).bool(message.acceptsDtmfInput);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified DtmfParameters message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.DtmfParameters.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.DtmfParameters
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDtmfParameters} message DtmfParameters message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DtmfParameters.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a DtmfParameters message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.DtmfParameters
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.DtmfParameters} DtmfParameters
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DtmfParameters.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.DtmfParameters();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.acceptsDtmfInput = reader.bool();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a DtmfParameters message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.DtmfParameters
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.DtmfParameters} DtmfParameters
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DtmfParameters.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a DtmfParameters message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.DtmfParameters
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        DtmfParameters.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.acceptsDtmfInput != null && message.hasOwnProperty("acceptsDtmfInput"))
                                if (typeof message.acceptsDtmfInput !== "boolean")
                                    return "acceptsDtmfInput: boolean expected";
                            return null;
                        };
    
                        /**
                         * Creates a DtmfParameters message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.DtmfParameters
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.DtmfParameters} DtmfParameters
                         */
                        DtmfParameters.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.DtmfParameters)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.DtmfParameters();
                            if (object.acceptsDtmfInput != null)
                                message.acceptsDtmfInput = Boolean(object.acceptsDtmfInput);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a DtmfParameters message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.DtmfParameters
                         * @static
                         * @param {google.cloud.dialogflow.v2.DtmfParameters} message DtmfParameters
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        DtmfParameters.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.acceptsDtmfInput = false;
                            if (message.acceptsDtmfInput != null && message.hasOwnProperty("acceptsDtmfInput"))
                                object.acceptsDtmfInput = message.acceptsDtmfInput;
                            return object;
                        };
    
                        /**
                         * Converts this DtmfParameters to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.DtmfParameters
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        DtmfParameters.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for DtmfParameters
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.DtmfParameters
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        DtmfParameters.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.DtmfParameters";
                        };
    
                        return DtmfParameters;
                    })();
    
                    v2.AnalyzeContentResponse = (function() {
    
                        /**
                         * Properties of an AnalyzeContentResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IAnalyzeContentResponse
                         * @property {string|null} [replyText] AnalyzeContentResponse replyText
                         * @property {google.cloud.dialogflow.v2.IOutputAudio|null} [replyAudio] AnalyzeContentResponse replyAudio
                         * @property {google.cloud.dialogflow.v2.IAutomatedAgentReply|null} [automatedAgentReply] AnalyzeContentResponse automatedAgentReply
                         * @property {google.cloud.dialogflow.v2.IMessage|null} [message] AnalyzeContentResponse message
                         * @property {Array.<google.cloud.dialogflow.v2.ISuggestionResult>|null} [humanAgentSuggestionResults] AnalyzeContentResponse humanAgentSuggestionResults
                         * @property {Array.<google.cloud.dialogflow.v2.ISuggestionResult>|null} [endUserSuggestionResults] AnalyzeContentResponse endUserSuggestionResults
                         * @property {google.cloud.dialogflow.v2.IDtmfParameters|null} [dtmfParameters] AnalyzeContentResponse dtmfParameters
                         */
    
                        /**
                         * Constructs a new AnalyzeContentResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an AnalyzeContentResponse.
                         * @implements IAnalyzeContentResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IAnalyzeContentResponse=} [properties] Properties to set
                         */
                        function AnalyzeContentResponse(properties) {
                            this.humanAgentSuggestionResults = [];
                            this.endUserSuggestionResults = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * AnalyzeContentResponse replyText.
                         * @member {string} replyText
                         * @memberof google.cloud.dialogflow.v2.AnalyzeContentResponse
                         * @instance
                         */
                        AnalyzeContentResponse.prototype.replyText = "";
    
                        /**
                         * AnalyzeContentResponse replyAudio.
                         * @member {google.cloud.dialogflow.v2.IOutputAudio|null|undefined} replyAudio
                         * @memberof google.cloud.dialogflow.v2.AnalyzeContentResponse
                         * @instance
                         */
                        AnalyzeContentResponse.prototype.replyAudio = null;
    
                        /**
                         * AnalyzeContentResponse automatedAgentReply.
                         * @member {google.cloud.dialogflow.v2.IAutomatedAgentReply|null|undefined} automatedAgentReply
                         * @memberof google.cloud.dialogflow.v2.AnalyzeContentResponse
                         * @instance
                         */
                        AnalyzeContentResponse.prototype.automatedAgentReply = null;
    
                        /**
                         * AnalyzeContentResponse message.
                         * @member {google.cloud.dialogflow.v2.IMessage|null|undefined} message
                         * @memberof google.cloud.dialogflow.v2.AnalyzeContentResponse
                         * @instance
                         */
                        AnalyzeContentResponse.prototype.message = null;
    
                        /**
                         * AnalyzeContentResponse humanAgentSuggestionResults.
                         * @member {Array.<google.cloud.dialogflow.v2.ISuggestionResult>} humanAgentSuggestionResults
                         * @memberof google.cloud.dialogflow.v2.AnalyzeContentResponse
                         * @instance
                         */
                        AnalyzeContentResponse.prototype.humanAgentSuggestionResults = $util.emptyArray;
    
                        /**
                         * AnalyzeContentResponse endUserSuggestionResults.
                         * @member {Array.<google.cloud.dialogflow.v2.ISuggestionResult>} endUserSuggestionResults
                         * @memberof google.cloud.dialogflow.v2.AnalyzeContentResponse
                         * @instance
                         */
                        AnalyzeContentResponse.prototype.endUserSuggestionResults = $util.emptyArray;
    
                        /**
                         * AnalyzeContentResponse dtmfParameters.
                         * @member {google.cloud.dialogflow.v2.IDtmfParameters|null|undefined} dtmfParameters
                         * @memberof google.cloud.dialogflow.v2.AnalyzeContentResponse
                         * @instance
                         */
                        AnalyzeContentResponse.prototype.dtmfParameters = null;
    
                        /**
                         * Creates a new AnalyzeContentResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.AnalyzeContentResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IAnalyzeContentResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.AnalyzeContentResponse} AnalyzeContentResponse instance
                         */
                        AnalyzeContentResponse.create = function create(properties) {
                            return new AnalyzeContentResponse(properties);
                        };
    
                        /**
                         * Encodes the specified AnalyzeContentResponse message. Does not implicitly {@link google.cloud.dialogflow.v2.AnalyzeContentResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.AnalyzeContentResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IAnalyzeContentResponse} message AnalyzeContentResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        AnalyzeContentResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.replyText != null && Object.hasOwnProperty.call(message, "replyText"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.replyText);
                            if (message.replyAudio != null && Object.hasOwnProperty.call(message, "replyAudio"))
                                $root.google.cloud.dialogflow.v2.OutputAudio.encode(message.replyAudio, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.automatedAgentReply != null && Object.hasOwnProperty.call(message, "automatedAgentReply"))
                                $root.google.cloud.dialogflow.v2.AutomatedAgentReply.encode(message.automatedAgentReply, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            if (message.message != null && Object.hasOwnProperty.call(message, "message"))
                                $root.google.cloud.dialogflow.v2.Message.encode(message.message, writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                            if (message.humanAgentSuggestionResults != null && message.humanAgentSuggestionResults.length)
                                for (var i = 0; i < message.humanAgentSuggestionResults.length; ++i)
                                    $root.google.cloud.dialogflow.v2.SuggestionResult.encode(message.humanAgentSuggestionResults[i], writer.uint32(/* id 6, wireType 2 =*/50).fork()).ldelim();
                            if (message.endUserSuggestionResults != null && message.endUserSuggestionResults.length)
                                for (var i = 0; i < message.endUserSuggestionResults.length; ++i)
                                    $root.google.cloud.dialogflow.v2.SuggestionResult.encode(message.endUserSuggestionResults[i], writer.uint32(/* id 7, wireType 2 =*/58).fork()).ldelim();
                            if (message.dtmfParameters != null && Object.hasOwnProperty.call(message, "dtmfParameters"))
                                $root.google.cloud.dialogflow.v2.DtmfParameters.encode(message.dtmfParameters, writer.uint32(/* id 9, wireType 2 =*/74).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified AnalyzeContentResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.AnalyzeContentResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.AnalyzeContentResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IAnalyzeContentResponse} message AnalyzeContentResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        AnalyzeContentResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an AnalyzeContentResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.AnalyzeContentResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.AnalyzeContentResponse} AnalyzeContentResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        AnalyzeContentResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.AnalyzeContentResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.replyText = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.replyAudio = $root.google.cloud.dialogflow.v2.OutputAudio.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 3: {
                                        message.automatedAgentReply = $root.google.cloud.dialogflow.v2.AutomatedAgentReply.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 5: {
                                        message.message = $root.google.cloud.dialogflow.v2.Message.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 6: {
                                        if (!(message.humanAgentSuggestionResults && message.humanAgentSuggestionResults.length))
                                            message.humanAgentSuggestionResults = [];
                                        message.humanAgentSuggestionResults.push($root.google.cloud.dialogflow.v2.SuggestionResult.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 7: {
                                        if (!(message.endUserSuggestionResults && message.endUserSuggestionResults.length))
                                            message.endUserSuggestionResults = [];
                                        message.endUserSuggestionResults.push($root.google.cloud.dialogflow.v2.SuggestionResult.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 9: {
                                        message.dtmfParameters = $root.google.cloud.dialogflow.v2.DtmfParameters.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an AnalyzeContentResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.AnalyzeContentResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.AnalyzeContentResponse} AnalyzeContentResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        AnalyzeContentResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an AnalyzeContentResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.AnalyzeContentResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        AnalyzeContentResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.replyText != null && message.hasOwnProperty("replyText"))
                                if (!$util.isString(message.replyText))
                                    return "replyText: string expected";
                            if (message.replyAudio != null && message.hasOwnProperty("replyAudio")) {
                                var error = $root.google.cloud.dialogflow.v2.OutputAudio.verify(message.replyAudio);
                                if (error)
                                    return "replyAudio." + error;
                            }
                            if (message.automatedAgentReply != null && message.hasOwnProperty("automatedAgentReply")) {
                                var error = $root.google.cloud.dialogflow.v2.AutomatedAgentReply.verify(message.automatedAgentReply);
                                if (error)
                                    return "automatedAgentReply." + error;
                            }
                            if (message.message != null && message.hasOwnProperty("message")) {
                                var error = $root.google.cloud.dialogflow.v2.Message.verify(message.message);
                                if (error)
                                    return "message." + error;
                            }
                            if (message.humanAgentSuggestionResults != null && message.hasOwnProperty("humanAgentSuggestionResults")) {
                                if (!Array.isArray(message.humanAgentSuggestionResults))
                                    return "humanAgentSuggestionResults: array expected";
                                for (var i = 0; i < message.humanAgentSuggestionResults.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.SuggestionResult.verify(message.humanAgentSuggestionResults[i]);
                                    if (error)
                                        return "humanAgentSuggestionResults." + error;
                                }
                            }
                            if (message.endUserSuggestionResults != null && message.hasOwnProperty("endUserSuggestionResults")) {
                                if (!Array.isArray(message.endUserSuggestionResults))
                                    return "endUserSuggestionResults: array expected";
                                for (var i = 0; i < message.endUserSuggestionResults.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.SuggestionResult.verify(message.endUserSuggestionResults[i]);
                                    if (error)
                                        return "endUserSuggestionResults." + error;
                                }
                            }
                            if (message.dtmfParameters != null && message.hasOwnProperty("dtmfParameters")) {
                                var error = $root.google.cloud.dialogflow.v2.DtmfParameters.verify(message.dtmfParameters);
                                if (error)
                                    return "dtmfParameters." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates an AnalyzeContentResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.AnalyzeContentResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.AnalyzeContentResponse} AnalyzeContentResponse
                         */
                        AnalyzeContentResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.AnalyzeContentResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.AnalyzeContentResponse();
                            if (object.replyText != null)
                                message.replyText = String(object.replyText);
                            if (object.replyAudio != null) {
                                if (typeof object.replyAudio !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.AnalyzeContentResponse.replyAudio: object expected");
                                message.replyAudio = $root.google.cloud.dialogflow.v2.OutputAudio.fromObject(object.replyAudio);
                            }
                            if (object.automatedAgentReply != null) {
                                if (typeof object.automatedAgentReply !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.AnalyzeContentResponse.automatedAgentReply: object expected");
                                message.automatedAgentReply = $root.google.cloud.dialogflow.v2.AutomatedAgentReply.fromObject(object.automatedAgentReply);
                            }
                            if (object.message != null) {
                                if (typeof object.message !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.AnalyzeContentResponse.message: object expected");
                                message.message = $root.google.cloud.dialogflow.v2.Message.fromObject(object.message);
                            }
                            if (object.humanAgentSuggestionResults) {
                                if (!Array.isArray(object.humanAgentSuggestionResults))
                                    throw TypeError(".google.cloud.dialogflow.v2.AnalyzeContentResponse.humanAgentSuggestionResults: array expected");
                                message.humanAgentSuggestionResults = [];
                                for (var i = 0; i < object.humanAgentSuggestionResults.length; ++i) {
                                    if (typeof object.humanAgentSuggestionResults[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.AnalyzeContentResponse.humanAgentSuggestionResults: object expected");
                                    message.humanAgentSuggestionResults[i] = $root.google.cloud.dialogflow.v2.SuggestionResult.fromObject(object.humanAgentSuggestionResults[i]);
                                }
                            }
                            if (object.endUserSuggestionResults) {
                                if (!Array.isArray(object.endUserSuggestionResults))
                                    throw TypeError(".google.cloud.dialogflow.v2.AnalyzeContentResponse.endUserSuggestionResults: array expected");
                                message.endUserSuggestionResults = [];
                                for (var i = 0; i < object.endUserSuggestionResults.length; ++i) {
                                    if (typeof object.endUserSuggestionResults[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.AnalyzeContentResponse.endUserSuggestionResults: object expected");
                                    message.endUserSuggestionResults[i] = $root.google.cloud.dialogflow.v2.SuggestionResult.fromObject(object.endUserSuggestionResults[i]);
                                }
                            }
                            if (object.dtmfParameters != null) {
                                if (typeof object.dtmfParameters !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.AnalyzeContentResponse.dtmfParameters: object expected");
                                message.dtmfParameters = $root.google.cloud.dialogflow.v2.DtmfParameters.fromObject(object.dtmfParameters);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an AnalyzeContentResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.AnalyzeContentResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.AnalyzeContentResponse} message AnalyzeContentResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        AnalyzeContentResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults) {
                                object.humanAgentSuggestionResults = [];
                                object.endUserSuggestionResults = [];
                            }
                            if (options.defaults) {
                                object.replyText = "";
                                object.replyAudio = null;
                                object.automatedAgentReply = null;
                                object.message = null;
                                object.dtmfParameters = null;
                            }
                            if (message.replyText != null && message.hasOwnProperty("replyText"))
                                object.replyText = message.replyText;
                            if (message.replyAudio != null && message.hasOwnProperty("replyAudio"))
                                object.replyAudio = $root.google.cloud.dialogflow.v2.OutputAudio.toObject(message.replyAudio, options);
                            if (message.automatedAgentReply != null && message.hasOwnProperty("automatedAgentReply"))
                                object.automatedAgentReply = $root.google.cloud.dialogflow.v2.AutomatedAgentReply.toObject(message.automatedAgentReply, options);
                            if (message.message != null && message.hasOwnProperty("message"))
                                object.message = $root.google.cloud.dialogflow.v2.Message.toObject(message.message, options);
                            if (message.humanAgentSuggestionResults && message.humanAgentSuggestionResults.length) {
                                object.humanAgentSuggestionResults = [];
                                for (var j = 0; j < message.humanAgentSuggestionResults.length; ++j)
                                    object.humanAgentSuggestionResults[j] = $root.google.cloud.dialogflow.v2.SuggestionResult.toObject(message.humanAgentSuggestionResults[j], options);
                            }
                            if (message.endUserSuggestionResults && message.endUserSuggestionResults.length) {
                                object.endUserSuggestionResults = [];
                                for (var j = 0; j < message.endUserSuggestionResults.length; ++j)
                                    object.endUserSuggestionResults[j] = $root.google.cloud.dialogflow.v2.SuggestionResult.toObject(message.endUserSuggestionResults[j], options);
                            }
                            if (message.dtmfParameters != null && message.hasOwnProperty("dtmfParameters"))
                                object.dtmfParameters = $root.google.cloud.dialogflow.v2.DtmfParameters.toObject(message.dtmfParameters, options);
                            return object;
                        };
    
                        /**
                         * Converts this AnalyzeContentResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.AnalyzeContentResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        AnalyzeContentResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for AnalyzeContentResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.AnalyzeContentResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        AnalyzeContentResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.AnalyzeContentResponse";
                        };
    
                        return AnalyzeContentResponse;
                    })();
    
                    v2.StreamingAnalyzeContentRequest = (function() {
    
                        /**
                         * Properties of a StreamingAnalyzeContentRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IStreamingAnalyzeContentRequest
                         * @property {string|null} [participant] StreamingAnalyzeContentRequest participant
                         * @property {google.cloud.dialogflow.v2.IInputAudioConfig|null} [audioConfig] StreamingAnalyzeContentRequest audioConfig
                         * @property {google.cloud.dialogflow.v2.IInputTextConfig|null} [textConfig] StreamingAnalyzeContentRequest textConfig
                         * @property {google.cloud.dialogflow.v2.IOutputAudioConfig|null} [replyAudioConfig] StreamingAnalyzeContentRequest replyAudioConfig
                         * @property {Uint8Array|null} [inputAudio] StreamingAnalyzeContentRequest inputAudio
                         * @property {string|null} [inputText] StreamingAnalyzeContentRequest inputText
                         * @property {google.cloud.dialogflow.v2.ITelephonyDtmfEvents|null} [inputDtmf] StreamingAnalyzeContentRequest inputDtmf
                         * @property {google.cloud.dialogflow.v2.IQueryParameters|null} [queryParams] StreamingAnalyzeContentRequest queryParams
                         * @property {google.cloud.dialogflow.v2.IAssistQueryParameters|null} [assistQueryParams] StreamingAnalyzeContentRequest assistQueryParams
                         * @property {google.protobuf.IStruct|null} [cxParameters] StreamingAnalyzeContentRequest cxParameters
                         * @property {boolean|null} [enableExtendedStreaming] StreamingAnalyzeContentRequest enableExtendedStreaming
                         * @property {boolean|null} [enablePartialAutomatedAgentReply] StreamingAnalyzeContentRequest enablePartialAutomatedAgentReply
                         * @property {boolean|null} [enableDebuggingInfo] StreamingAnalyzeContentRequest enableDebuggingInfo
                         */
    
                        /**
                         * Constructs a new StreamingAnalyzeContentRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a StreamingAnalyzeContentRequest.
                         * @implements IStreamingAnalyzeContentRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IStreamingAnalyzeContentRequest=} [properties] Properties to set
                         */
                        function StreamingAnalyzeContentRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * StreamingAnalyzeContentRequest participant.
                         * @member {string} participant
                         * @memberof google.cloud.dialogflow.v2.StreamingAnalyzeContentRequest
                         * @instance
                         */
                        StreamingAnalyzeContentRequest.prototype.participant = "";
    
                        /**
                         * StreamingAnalyzeContentRequest audioConfig.
                         * @member {google.cloud.dialogflow.v2.IInputAudioConfig|null|undefined} audioConfig
                         * @memberof google.cloud.dialogflow.v2.StreamingAnalyzeContentRequest
                         * @instance
                         */
                        StreamingAnalyzeContentRequest.prototype.audioConfig = null;
    
                        /**
                         * StreamingAnalyzeContentRequest textConfig.
                         * @member {google.cloud.dialogflow.v2.IInputTextConfig|null|undefined} textConfig
                         * @memberof google.cloud.dialogflow.v2.StreamingAnalyzeContentRequest
                         * @instance
                         */
                        StreamingAnalyzeContentRequest.prototype.textConfig = null;
    
                        /**
                         * StreamingAnalyzeContentRequest replyAudioConfig.
                         * @member {google.cloud.dialogflow.v2.IOutputAudioConfig|null|undefined} replyAudioConfig
                         * @memberof google.cloud.dialogflow.v2.StreamingAnalyzeContentRequest
                         * @instance
                         */
                        StreamingAnalyzeContentRequest.prototype.replyAudioConfig = null;
    
                        /**
                         * StreamingAnalyzeContentRequest inputAudio.
                         * @member {Uint8Array|null|undefined} inputAudio
                         * @memberof google.cloud.dialogflow.v2.StreamingAnalyzeContentRequest
                         * @instance
                         */
                        StreamingAnalyzeContentRequest.prototype.inputAudio = null;
    
                        /**
                         * StreamingAnalyzeContentRequest inputText.
                         * @member {string|null|undefined} inputText
                         * @memberof google.cloud.dialogflow.v2.StreamingAnalyzeContentRequest
                         * @instance
                         */
                        StreamingAnalyzeContentRequest.prototype.inputText = null;
    
                        /**
                         * StreamingAnalyzeContentRequest inputDtmf.
                         * @member {google.cloud.dialogflow.v2.ITelephonyDtmfEvents|null|undefined} inputDtmf
                         * @memberof google.cloud.dialogflow.v2.StreamingAnalyzeContentRequest
                         * @instance
                         */
                        StreamingAnalyzeContentRequest.prototype.inputDtmf = null;
    
                        /**
                         * StreamingAnalyzeContentRequest queryParams.
                         * @member {google.cloud.dialogflow.v2.IQueryParameters|null|undefined} queryParams
                         * @memberof google.cloud.dialogflow.v2.StreamingAnalyzeContentRequest
                         * @instance
                         */
                        StreamingAnalyzeContentRequest.prototype.queryParams = null;
    
                        /**
                         * StreamingAnalyzeContentRequest assistQueryParams.
                         * @member {google.cloud.dialogflow.v2.IAssistQueryParameters|null|undefined} assistQueryParams
                         * @memberof google.cloud.dialogflow.v2.StreamingAnalyzeContentRequest
                         * @instance
                         */
                        StreamingAnalyzeContentRequest.prototype.assistQueryParams = null;
    
                        /**
                         * StreamingAnalyzeContentRequest cxParameters.
                         * @member {google.protobuf.IStruct|null|undefined} cxParameters
                         * @memberof google.cloud.dialogflow.v2.StreamingAnalyzeContentRequest
                         * @instance
                         */
                        StreamingAnalyzeContentRequest.prototype.cxParameters = null;
    
                        /**
                         * StreamingAnalyzeContentRequest enableExtendedStreaming.
                         * @member {boolean} enableExtendedStreaming
                         * @memberof google.cloud.dialogflow.v2.StreamingAnalyzeContentRequest
                         * @instance
                         */
                        StreamingAnalyzeContentRequest.prototype.enableExtendedStreaming = false;
    
                        /**
                         * StreamingAnalyzeContentRequest enablePartialAutomatedAgentReply.
                         * @member {boolean} enablePartialAutomatedAgentReply
                         * @memberof google.cloud.dialogflow.v2.StreamingAnalyzeContentRequest
                         * @instance
                         */
                        StreamingAnalyzeContentRequest.prototype.enablePartialAutomatedAgentReply = false;
    
                        /**
                         * StreamingAnalyzeContentRequest enableDebuggingInfo.
                         * @member {boolean} enableDebuggingInfo
                         * @memberof google.cloud.dialogflow.v2.StreamingAnalyzeContentRequest
                         * @instance
                         */
                        StreamingAnalyzeContentRequest.prototype.enableDebuggingInfo = false;
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * StreamingAnalyzeContentRequest config.
                         * @member {"audioConfig"|"textConfig"|undefined} config
                         * @memberof google.cloud.dialogflow.v2.StreamingAnalyzeContentRequest
                         * @instance
                         */
                        Object.defineProperty(StreamingAnalyzeContentRequest.prototype, "config", {
                            get: $util.oneOfGetter($oneOfFields = ["audioConfig", "textConfig"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * StreamingAnalyzeContentRequest input.
                         * @member {"inputAudio"|"inputText"|"inputDtmf"|undefined} input
                         * @memberof google.cloud.dialogflow.v2.StreamingAnalyzeContentRequest
                         * @instance
                         */
                        Object.defineProperty(StreamingAnalyzeContentRequest.prototype, "input", {
                            get: $util.oneOfGetter($oneOfFields = ["inputAudio", "inputText", "inputDtmf"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new StreamingAnalyzeContentRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.StreamingAnalyzeContentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IStreamingAnalyzeContentRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.StreamingAnalyzeContentRequest} StreamingAnalyzeContentRequest instance
                         */
                        StreamingAnalyzeContentRequest.create = function create(properties) {
                            return new StreamingAnalyzeContentRequest(properties);
                        };
    
                        /**
                         * Encodes the specified StreamingAnalyzeContentRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.StreamingAnalyzeContentRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.StreamingAnalyzeContentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IStreamingAnalyzeContentRequest} message StreamingAnalyzeContentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        StreamingAnalyzeContentRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.participant != null && Object.hasOwnProperty.call(message, "participant"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.participant);
                            if (message.audioConfig != null && Object.hasOwnProperty.call(message, "audioConfig"))
                                $root.google.cloud.dialogflow.v2.InputAudioConfig.encode(message.audioConfig, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.textConfig != null && Object.hasOwnProperty.call(message, "textConfig"))
                                $root.google.cloud.dialogflow.v2.InputTextConfig.encode(message.textConfig, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            if (message.replyAudioConfig != null && Object.hasOwnProperty.call(message, "replyAudioConfig"))
                                $root.google.cloud.dialogflow.v2.OutputAudioConfig.encode(message.replyAudioConfig, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            if (message.inputAudio != null && Object.hasOwnProperty.call(message, "inputAudio"))
                                writer.uint32(/* id 5, wireType 2 =*/42).bytes(message.inputAudio);
                            if (message.inputText != null && Object.hasOwnProperty.call(message, "inputText"))
                                writer.uint32(/* id 6, wireType 2 =*/50).string(message.inputText);
                            if (message.queryParams != null && Object.hasOwnProperty.call(message, "queryParams"))
                                $root.google.cloud.dialogflow.v2.QueryParameters.encode(message.queryParams, writer.uint32(/* id 7, wireType 2 =*/58).fork()).ldelim();
                            if (message.assistQueryParams != null && Object.hasOwnProperty.call(message, "assistQueryParams"))
                                $root.google.cloud.dialogflow.v2.AssistQueryParameters.encode(message.assistQueryParams, writer.uint32(/* id 8, wireType 2 =*/66).fork()).ldelim();
                            if (message.inputDtmf != null && Object.hasOwnProperty.call(message, "inputDtmf"))
                                $root.google.cloud.dialogflow.v2.TelephonyDtmfEvents.encode(message.inputDtmf, writer.uint32(/* id 9, wireType 2 =*/74).fork()).ldelim();
                            if (message.enableExtendedStreaming != null && Object.hasOwnProperty.call(message, "enableExtendedStreaming"))
                                writer.uint32(/* id 11, wireType 0 =*/88).bool(message.enableExtendedStreaming);
                            if (message.enablePartialAutomatedAgentReply != null && Object.hasOwnProperty.call(message, "enablePartialAutomatedAgentReply"))
                                writer.uint32(/* id 12, wireType 0 =*/96).bool(message.enablePartialAutomatedAgentReply);
                            if (message.cxParameters != null && Object.hasOwnProperty.call(message, "cxParameters"))
                                $root.google.protobuf.Struct.encode(message.cxParameters, writer.uint32(/* id 13, wireType 2 =*/106).fork()).ldelim();
                            if (message.enableDebuggingInfo != null && Object.hasOwnProperty.call(message, "enableDebuggingInfo"))
                                writer.uint32(/* id 19, wireType 0 =*/152).bool(message.enableDebuggingInfo);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified StreamingAnalyzeContentRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.StreamingAnalyzeContentRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.StreamingAnalyzeContentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IStreamingAnalyzeContentRequest} message StreamingAnalyzeContentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        StreamingAnalyzeContentRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a StreamingAnalyzeContentRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.StreamingAnalyzeContentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.StreamingAnalyzeContentRequest} StreamingAnalyzeContentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        StreamingAnalyzeContentRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.StreamingAnalyzeContentRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.participant = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.audioConfig = $root.google.cloud.dialogflow.v2.InputAudioConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 3: {
                                        message.textConfig = $root.google.cloud.dialogflow.v2.InputTextConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 4: {
                                        message.replyAudioConfig = $root.google.cloud.dialogflow.v2.OutputAudioConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 5: {
                                        message.inputAudio = reader.bytes();
                                        break;
                                    }
                                case 6: {
                                        message.inputText = reader.string();
                                        break;
                                    }
                                case 9: {
                                        message.inputDtmf = $root.google.cloud.dialogflow.v2.TelephonyDtmfEvents.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 7: {
                                        message.queryParams = $root.google.cloud.dialogflow.v2.QueryParameters.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 8: {
                                        message.assistQueryParams = $root.google.cloud.dialogflow.v2.AssistQueryParameters.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 13: {
                                        message.cxParameters = $root.google.protobuf.Struct.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 11: {
                                        message.enableExtendedStreaming = reader.bool();
                                        break;
                                    }
                                case 12: {
                                        message.enablePartialAutomatedAgentReply = reader.bool();
                                        break;
                                    }
                                case 19: {
                                        message.enableDebuggingInfo = reader.bool();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a StreamingAnalyzeContentRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.StreamingAnalyzeContentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.StreamingAnalyzeContentRequest} StreamingAnalyzeContentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        StreamingAnalyzeContentRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a StreamingAnalyzeContentRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.StreamingAnalyzeContentRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        StreamingAnalyzeContentRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.participant != null && message.hasOwnProperty("participant"))
                                if (!$util.isString(message.participant))
                                    return "participant: string expected";
                            if (message.audioConfig != null && message.hasOwnProperty("audioConfig")) {
                                properties.config = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2.InputAudioConfig.verify(message.audioConfig);
                                    if (error)
                                        return "audioConfig." + error;
                                }
                            }
                            if (message.textConfig != null && message.hasOwnProperty("textConfig")) {
                                if (properties.config === 1)
                                    return "config: multiple values";
                                properties.config = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2.InputTextConfig.verify(message.textConfig);
                                    if (error)
                                        return "textConfig." + error;
                                }
                            }
                            if (message.replyAudioConfig != null && message.hasOwnProperty("replyAudioConfig")) {
                                var error = $root.google.cloud.dialogflow.v2.OutputAudioConfig.verify(message.replyAudioConfig);
                                if (error)
                                    return "replyAudioConfig." + error;
                            }
                            if (message.inputAudio != null && message.hasOwnProperty("inputAudio")) {
                                properties.input = 1;
                                if (!(message.inputAudio && typeof message.inputAudio.length === "number" || $util.isString(message.inputAudio)))
                                    return "inputAudio: buffer expected";
                            }
                            if (message.inputText != null && message.hasOwnProperty("inputText")) {
                                if (properties.input === 1)
                                    return "input: multiple values";
                                properties.input = 1;
                                if (!$util.isString(message.inputText))
                                    return "inputText: string expected";
                            }
                            if (message.inputDtmf != null && message.hasOwnProperty("inputDtmf")) {
                                if (properties.input === 1)
                                    return "input: multiple values";
                                properties.input = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2.TelephonyDtmfEvents.verify(message.inputDtmf);
                                    if (error)
                                        return "inputDtmf." + error;
                                }
                            }
                            if (message.queryParams != null && message.hasOwnProperty("queryParams")) {
                                var error = $root.google.cloud.dialogflow.v2.QueryParameters.verify(message.queryParams);
                                if (error)
                                    return "queryParams." + error;
                            }
                            if (message.assistQueryParams != null && message.hasOwnProperty("assistQueryParams")) {
                                var error = $root.google.cloud.dialogflow.v2.AssistQueryParameters.verify(message.assistQueryParams);
                                if (error)
                                    return "assistQueryParams." + error;
                            }
                            if (message.cxParameters != null && message.hasOwnProperty("cxParameters")) {
                                var error = $root.google.protobuf.Struct.verify(message.cxParameters);
                                if (error)
                                    return "cxParameters." + error;
                            }
                            if (message.enableExtendedStreaming != null && message.hasOwnProperty("enableExtendedStreaming"))
                                if (typeof message.enableExtendedStreaming !== "boolean")
                                    return "enableExtendedStreaming: boolean expected";
                            if (message.enablePartialAutomatedAgentReply != null && message.hasOwnProperty("enablePartialAutomatedAgentReply"))
                                if (typeof message.enablePartialAutomatedAgentReply !== "boolean")
                                    return "enablePartialAutomatedAgentReply: boolean expected";
                            if (message.enableDebuggingInfo != null && message.hasOwnProperty("enableDebuggingInfo"))
                                if (typeof message.enableDebuggingInfo !== "boolean")
                                    return "enableDebuggingInfo: boolean expected";
                            return null;
                        };
    
                        /**
                         * Creates a StreamingAnalyzeContentRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.StreamingAnalyzeContentRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.StreamingAnalyzeContentRequest} StreamingAnalyzeContentRequest
                         */
                        StreamingAnalyzeContentRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.StreamingAnalyzeContentRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.StreamingAnalyzeContentRequest();
                            if (object.participant != null)
                                message.participant = String(object.participant);
                            if (object.audioConfig != null) {
                                if (typeof object.audioConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.StreamingAnalyzeContentRequest.audioConfig: object expected");
                                message.audioConfig = $root.google.cloud.dialogflow.v2.InputAudioConfig.fromObject(object.audioConfig);
                            }
                            if (object.textConfig != null) {
                                if (typeof object.textConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.StreamingAnalyzeContentRequest.textConfig: object expected");
                                message.textConfig = $root.google.cloud.dialogflow.v2.InputTextConfig.fromObject(object.textConfig);
                            }
                            if (object.replyAudioConfig != null) {
                                if (typeof object.replyAudioConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.StreamingAnalyzeContentRequest.replyAudioConfig: object expected");
                                message.replyAudioConfig = $root.google.cloud.dialogflow.v2.OutputAudioConfig.fromObject(object.replyAudioConfig);
                            }
                            if (object.inputAudio != null)
                                if (typeof object.inputAudio === "string")
                                    $util.base64.decode(object.inputAudio, message.inputAudio = $util.newBuffer($util.base64.length(object.inputAudio)), 0);
                                else if (object.inputAudio.length >= 0)
                                    message.inputAudio = object.inputAudio;
                            if (object.inputText != null)
                                message.inputText = String(object.inputText);
                            if (object.inputDtmf != null) {
                                if (typeof object.inputDtmf !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.StreamingAnalyzeContentRequest.inputDtmf: object expected");
                                message.inputDtmf = $root.google.cloud.dialogflow.v2.TelephonyDtmfEvents.fromObject(object.inputDtmf);
                            }
                            if (object.queryParams != null) {
                                if (typeof object.queryParams !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.StreamingAnalyzeContentRequest.queryParams: object expected");
                                message.queryParams = $root.google.cloud.dialogflow.v2.QueryParameters.fromObject(object.queryParams);
                            }
                            if (object.assistQueryParams != null) {
                                if (typeof object.assistQueryParams !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.StreamingAnalyzeContentRequest.assistQueryParams: object expected");
                                message.assistQueryParams = $root.google.cloud.dialogflow.v2.AssistQueryParameters.fromObject(object.assistQueryParams);
                            }
                            if (object.cxParameters != null) {
                                if (typeof object.cxParameters !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.StreamingAnalyzeContentRequest.cxParameters: object expected");
                                message.cxParameters = $root.google.protobuf.Struct.fromObject(object.cxParameters);
                            }
                            if (object.enableExtendedStreaming != null)
                                message.enableExtendedStreaming = Boolean(object.enableExtendedStreaming);
                            if (object.enablePartialAutomatedAgentReply != null)
                                message.enablePartialAutomatedAgentReply = Boolean(object.enablePartialAutomatedAgentReply);
                            if (object.enableDebuggingInfo != null)
                                message.enableDebuggingInfo = Boolean(object.enableDebuggingInfo);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a StreamingAnalyzeContentRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.StreamingAnalyzeContentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.StreamingAnalyzeContentRequest} message StreamingAnalyzeContentRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        StreamingAnalyzeContentRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.participant = "";
                                object.replyAudioConfig = null;
                                object.queryParams = null;
                                object.assistQueryParams = null;
                                object.enableExtendedStreaming = false;
                                object.enablePartialAutomatedAgentReply = false;
                                object.cxParameters = null;
                                object.enableDebuggingInfo = false;
                            }
                            if (message.participant != null && message.hasOwnProperty("participant"))
                                object.participant = message.participant;
                            if (message.audioConfig != null && message.hasOwnProperty("audioConfig")) {
                                object.audioConfig = $root.google.cloud.dialogflow.v2.InputAudioConfig.toObject(message.audioConfig, options);
                                if (options.oneofs)
                                    object.config = "audioConfig";
                            }
                            if (message.textConfig != null && message.hasOwnProperty("textConfig")) {
                                object.textConfig = $root.google.cloud.dialogflow.v2.InputTextConfig.toObject(message.textConfig, options);
                                if (options.oneofs)
                                    object.config = "textConfig";
                            }
                            if (message.replyAudioConfig != null && message.hasOwnProperty("replyAudioConfig"))
                                object.replyAudioConfig = $root.google.cloud.dialogflow.v2.OutputAudioConfig.toObject(message.replyAudioConfig, options);
                            if (message.inputAudio != null && message.hasOwnProperty("inputAudio")) {
                                object.inputAudio = options.bytes === String ? $util.base64.encode(message.inputAudio, 0, message.inputAudio.length) : options.bytes === Array ? Array.prototype.slice.call(message.inputAudio) : message.inputAudio;
                                if (options.oneofs)
                                    object.input = "inputAudio";
                            }
                            if (message.inputText != null && message.hasOwnProperty("inputText")) {
                                object.inputText = message.inputText;
                                if (options.oneofs)
                                    object.input = "inputText";
                            }
                            if (message.queryParams != null && message.hasOwnProperty("queryParams"))
                                object.queryParams = $root.google.cloud.dialogflow.v2.QueryParameters.toObject(message.queryParams, options);
                            if (message.assistQueryParams != null && message.hasOwnProperty("assistQueryParams"))
                                object.assistQueryParams = $root.google.cloud.dialogflow.v2.AssistQueryParameters.toObject(message.assistQueryParams, options);
                            if (message.inputDtmf != null && message.hasOwnProperty("inputDtmf")) {
                                object.inputDtmf = $root.google.cloud.dialogflow.v2.TelephonyDtmfEvents.toObject(message.inputDtmf, options);
                                if (options.oneofs)
                                    object.input = "inputDtmf";
                            }
                            if (message.enableExtendedStreaming != null && message.hasOwnProperty("enableExtendedStreaming"))
                                object.enableExtendedStreaming = message.enableExtendedStreaming;
                            if (message.enablePartialAutomatedAgentReply != null && message.hasOwnProperty("enablePartialAutomatedAgentReply"))
                                object.enablePartialAutomatedAgentReply = message.enablePartialAutomatedAgentReply;
                            if (message.cxParameters != null && message.hasOwnProperty("cxParameters"))
                                object.cxParameters = $root.google.protobuf.Struct.toObject(message.cxParameters, options);
                            if (message.enableDebuggingInfo != null && message.hasOwnProperty("enableDebuggingInfo"))
                                object.enableDebuggingInfo = message.enableDebuggingInfo;
                            return object;
                        };
    
                        /**
                         * Converts this StreamingAnalyzeContentRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.StreamingAnalyzeContentRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        StreamingAnalyzeContentRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for StreamingAnalyzeContentRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.StreamingAnalyzeContentRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        StreamingAnalyzeContentRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.StreamingAnalyzeContentRequest";
                        };
    
                        return StreamingAnalyzeContentRequest;
                    })();
    
                    v2.StreamingAnalyzeContentResponse = (function() {
    
                        /**
                         * Properties of a StreamingAnalyzeContentResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IStreamingAnalyzeContentResponse
                         * @property {google.cloud.dialogflow.v2.IStreamingRecognitionResult|null} [recognitionResult] StreamingAnalyzeContentResponse recognitionResult
                         * @property {string|null} [replyText] StreamingAnalyzeContentResponse replyText
                         * @property {google.cloud.dialogflow.v2.IOutputAudio|null} [replyAudio] StreamingAnalyzeContentResponse replyAudio
                         * @property {google.cloud.dialogflow.v2.IAutomatedAgentReply|null} [automatedAgentReply] StreamingAnalyzeContentResponse automatedAgentReply
                         * @property {google.cloud.dialogflow.v2.IMessage|null} [message] StreamingAnalyzeContentResponse message
                         * @property {Array.<google.cloud.dialogflow.v2.ISuggestionResult>|null} [humanAgentSuggestionResults] StreamingAnalyzeContentResponse humanAgentSuggestionResults
                         * @property {Array.<google.cloud.dialogflow.v2.ISuggestionResult>|null} [endUserSuggestionResults] StreamingAnalyzeContentResponse endUserSuggestionResults
                         * @property {google.cloud.dialogflow.v2.IDtmfParameters|null} [dtmfParameters] StreamingAnalyzeContentResponse dtmfParameters
                         * @property {google.cloud.dialogflow.v2.ICloudConversationDebuggingInfo|null} [debuggingInfo] StreamingAnalyzeContentResponse debuggingInfo
                         * @property {string|null} [speechModel] StreamingAnalyzeContentResponse speechModel
                         */
    
                        /**
                         * Constructs a new StreamingAnalyzeContentResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a StreamingAnalyzeContentResponse.
                         * @implements IStreamingAnalyzeContentResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IStreamingAnalyzeContentResponse=} [properties] Properties to set
                         */
                        function StreamingAnalyzeContentResponse(properties) {
                            this.humanAgentSuggestionResults = [];
                            this.endUserSuggestionResults = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * StreamingAnalyzeContentResponse recognitionResult.
                         * @member {google.cloud.dialogflow.v2.IStreamingRecognitionResult|null|undefined} recognitionResult
                         * @memberof google.cloud.dialogflow.v2.StreamingAnalyzeContentResponse
                         * @instance
                         */
                        StreamingAnalyzeContentResponse.prototype.recognitionResult = null;
    
                        /**
                         * StreamingAnalyzeContentResponse replyText.
                         * @member {string} replyText
                         * @memberof google.cloud.dialogflow.v2.StreamingAnalyzeContentResponse
                         * @instance
                         */
                        StreamingAnalyzeContentResponse.prototype.replyText = "";
    
                        /**
                         * StreamingAnalyzeContentResponse replyAudio.
                         * @member {google.cloud.dialogflow.v2.IOutputAudio|null|undefined} replyAudio
                         * @memberof google.cloud.dialogflow.v2.StreamingAnalyzeContentResponse
                         * @instance
                         */
                        StreamingAnalyzeContentResponse.prototype.replyAudio = null;
    
                        /**
                         * StreamingAnalyzeContentResponse automatedAgentReply.
                         * @member {google.cloud.dialogflow.v2.IAutomatedAgentReply|null|undefined} automatedAgentReply
                         * @memberof google.cloud.dialogflow.v2.StreamingAnalyzeContentResponse
                         * @instance
                         */
                        StreamingAnalyzeContentResponse.prototype.automatedAgentReply = null;
    
                        /**
                         * StreamingAnalyzeContentResponse message.
                         * @member {google.cloud.dialogflow.v2.IMessage|null|undefined} message
                         * @memberof google.cloud.dialogflow.v2.StreamingAnalyzeContentResponse
                         * @instance
                         */
                        StreamingAnalyzeContentResponse.prototype.message = null;
    
                        /**
                         * StreamingAnalyzeContentResponse humanAgentSuggestionResults.
                         * @member {Array.<google.cloud.dialogflow.v2.ISuggestionResult>} humanAgentSuggestionResults
                         * @memberof google.cloud.dialogflow.v2.StreamingAnalyzeContentResponse
                         * @instance
                         */
                        StreamingAnalyzeContentResponse.prototype.humanAgentSuggestionResults = $util.emptyArray;
    
                        /**
                         * StreamingAnalyzeContentResponse endUserSuggestionResults.
                         * @member {Array.<google.cloud.dialogflow.v2.ISuggestionResult>} endUserSuggestionResults
                         * @memberof google.cloud.dialogflow.v2.StreamingAnalyzeContentResponse
                         * @instance
                         */
                        StreamingAnalyzeContentResponse.prototype.endUserSuggestionResults = $util.emptyArray;
    
                        /**
                         * StreamingAnalyzeContentResponse dtmfParameters.
                         * @member {google.cloud.dialogflow.v2.IDtmfParameters|null|undefined} dtmfParameters
                         * @memberof google.cloud.dialogflow.v2.StreamingAnalyzeContentResponse
                         * @instance
                         */
                        StreamingAnalyzeContentResponse.prototype.dtmfParameters = null;
    
                        /**
                         * StreamingAnalyzeContentResponse debuggingInfo.
                         * @member {google.cloud.dialogflow.v2.ICloudConversationDebuggingInfo|null|undefined} debuggingInfo
                         * @memberof google.cloud.dialogflow.v2.StreamingAnalyzeContentResponse
                         * @instance
                         */
                        StreamingAnalyzeContentResponse.prototype.debuggingInfo = null;
    
                        /**
                         * StreamingAnalyzeContentResponse speechModel.
                         * @member {string} speechModel
                         * @memberof google.cloud.dialogflow.v2.StreamingAnalyzeContentResponse
                         * @instance
                         */
                        StreamingAnalyzeContentResponse.prototype.speechModel = "";
    
                        /**
                         * Creates a new StreamingAnalyzeContentResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.StreamingAnalyzeContentResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IStreamingAnalyzeContentResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.StreamingAnalyzeContentResponse} StreamingAnalyzeContentResponse instance
                         */
                        StreamingAnalyzeContentResponse.create = function create(properties) {
                            return new StreamingAnalyzeContentResponse(properties);
                        };
    
                        /**
                         * Encodes the specified StreamingAnalyzeContentResponse message. Does not implicitly {@link google.cloud.dialogflow.v2.StreamingAnalyzeContentResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.StreamingAnalyzeContentResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IStreamingAnalyzeContentResponse} message StreamingAnalyzeContentResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        StreamingAnalyzeContentResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.recognitionResult != null && Object.hasOwnProperty.call(message, "recognitionResult"))
                                $root.google.cloud.dialogflow.v2.StreamingRecognitionResult.encode(message.recognitionResult, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.replyText != null && Object.hasOwnProperty.call(message, "replyText"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.replyText);
                            if (message.replyAudio != null && Object.hasOwnProperty.call(message, "replyAudio"))
                                $root.google.cloud.dialogflow.v2.OutputAudio.encode(message.replyAudio, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            if (message.automatedAgentReply != null && Object.hasOwnProperty.call(message, "automatedAgentReply"))
                                $root.google.cloud.dialogflow.v2.AutomatedAgentReply.encode(message.automatedAgentReply, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            if (message.message != null && Object.hasOwnProperty.call(message, "message"))
                                $root.google.cloud.dialogflow.v2.Message.encode(message.message, writer.uint32(/* id 6, wireType 2 =*/50).fork()).ldelim();
                            if (message.humanAgentSuggestionResults != null && message.humanAgentSuggestionResults.length)
                                for (var i = 0; i < message.humanAgentSuggestionResults.length; ++i)
                                    $root.google.cloud.dialogflow.v2.SuggestionResult.encode(message.humanAgentSuggestionResults[i], writer.uint32(/* id 7, wireType 2 =*/58).fork()).ldelim();
                            if (message.endUserSuggestionResults != null && message.endUserSuggestionResults.length)
                                for (var i = 0; i < message.endUserSuggestionResults.length; ++i)
                                    $root.google.cloud.dialogflow.v2.SuggestionResult.encode(message.endUserSuggestionResults[i], writer.uint32(/* id 8, wireType 2 =*/66).fork()).ldelim();
                            if (message.dtmfParameters != null && Object.hasOwnProperty.call(message, "dtmfParameters"))
                                $root.google.cloud.dialogflow.v2.DtmfParameters.encode(message.dtmfParameters, writer.uint32(/* id 10, wireType 2 =*/82).fork()).ldelim();
                            if (message.debuggingInfo != null && Object.hasOwnProperty.call(message, "debuggingInfo"))
                                $root.google.cloud.dialogflow.v2.CloudConversationDebuggingInfo.encode(message.debuggingInfo, writer.uint32(/* id 11, wireType 2 =*/90).fork()).ldelim();
                            if (message.speechModel != null && Object.hasOwnProperty.call(message, "speechModel"))
                                writer.uint32(/* id 13, wireType 2 =*/106).string(message.speechModel);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified StreamingAnalyzeContentResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.StreamingAnalyzeContentResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.StreamingAnalyzeContentResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IStreamingAnalyzeContentResponse} message StreamingAnalyzeContentResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        StreamingAnalyzeContentResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a StreamingAnalyzeContentResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.StreamingAnalyzeContentResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.StreamingAnalyzeContentResponse} StreamingAnalyzeContentResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        StreamingAnalyzeContentResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.StreamingAnalyzeContentResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.recognitionResult = $root.google.cloud.dialogflow.v2.StreamingRecognitionResult.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.replyText = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.replyAudio = $root.google.cloud.dialogflow.v2.OutputAudio.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 4: {
                                        message.automatedAgentReply = $root.google.cloud.dialogflow.v2.AutomatedAgentReply.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 6: {
                                        message.message = $root.google.cloud.dialogflow.v2.Message.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 7: {
                                        if (!(message.humanAgentSuggestionResults && message.humanAgentSuggestionResults.length))
                                            message.humanAgentSuggestionResults = [];
                                        message.humanAgentSuggestionResults.push($root.google.cloud.dialogflow.v2.SuggestionResult.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 8: {
                                        if (!(message.endUserSuggestionResults && message.endUserSuggestionResults.length))
                                            message.endUserSuggestionResults = [];
                                        message.endUserSuggestionResults.push($root.google.cloud.dialogflow.v2.SuggestionResult.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 10: {
                                        message.dtmfParameters = $root.google.cloud.dialogflow.v2.DtmfParameters.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 11: {
                                        message.debuggingInfo = $root.google.cloud.dialogflow.v2.CloudConversationDebuggingInfo.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 13: {
                                        message.speechModel = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a StreamingAnalyzeContentResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.StreamingAnalyzeContentResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.StreamingAnalyzeContentResponse} StreamingAnalyzeContentResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        StreamingAnalyzeContentResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a StreamingAnalyzeContentResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.StreamingAnalyzeContentResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        StreamingAnalyzeContentResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.recognitionResult != null && message.hasOwnProperty("recognitionResult")) {
                                var error = $root.google.cloud.dialogflow.v2.StreamingRecognitionResult.verify(message.recognitionResult);
                                if (error)
                                    return "recognitionResult." + error;
                            }
                            if (message.replyText != null && message.hasOwnProperty("replyText"))
                                if (!$util.isString(message.replyText))
                                    return "replyText: string expected";
                            if (message.replyAudio != null && message.hasOwnProperty("replyAudio")) {
                                var error = $root.google.cloud.dialogflow.v2.OutputAudio.verify(message.replyAudio);
                                if (error)
                                    return "replyAudio." + error;
                            }
                            if (message.automatedAgentReply != null && message.hasOwnProperty("automatedAgentReply")) {
                                var error = $root.google.cloud.dialogflow.v2.AutomatedAgentReply.verify(message.automatedAgentReply);
                                if (error)
                                    return "automatedAgentReply." + error;
                            }
                            if (message.message != null && message.hasOwnProperty("message")) {
                                var error = $root.google.cloud.dialogflow.v2.Message.verify(message.message);
                                if (error)
                                    return "message." + error;
                            }
                            if (message.humanAgentSuggestionResults != null && message.hasOwnProperty("humanAgentSuggestionResults")) {
                                if (!Array.isArray(message.humanAgentSuggestionResults))
                                    return "humanAgentSuggestionResults: array expected";
                                for (var i = 0; i < message.humanAgentSuggestionResults.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.SuggestionResult.verify(message.humanAgentSuggestionResults[i]);
                                    if (error)
                                        return "humanAgentSuggestionResults." + error;
                                }
                            }
                            if (message.endUserSuggestionResults != null && message.hasOwnProperty("endUserSuggestionResults")) {
                                if (!Array.isArray(message.endUserSuggestionResults))
                                    return "endUserSuggestionResults: array expected";
                                for (var i = 0; i < message.endUserSuggestionResults.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.SuggestionResult.verify(message.endUserSuggestionResults[i]);
                                    if (error)
                                        return "endUserSuggestionResults." + error;
                                }
                            }
                            if (message.dtmfParameters != null && message.hasOwnProperty("dtmfParameters")) {
                                var error = $root.google.cloud.dialogflow.v2.DtmfParameters.verify(message.dtmfParameters);
                                if (error)
                                    return "dtmfParameters." + error;
                            }
                            if (message.debuggingInfo != null && message.hasOwnProperty("debuggingInfo")) {
                                var error = $root.google.cloud.dialogflow.v2.CloudConversationDebuggingInfo.verify(message.debuggingInfo);
                                if (error)
                                    return "debuggingInfo." + error;
                            }
                            if (message.speechModel != null && message.hasOwnProperty("speechModel"))
                                if (!$util.isString(message.speechModel))
                                    return "speechModel: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a StreamingAnalyzeContentResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.StreamingAnalyzeContentResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.StreamingAnalyzeContentResponse} StreamingAnalyzeContentResponse
                         */
                        StreamingAnalyzeContentResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.StreamingAnalyzeContentResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.StreamingAnalyzeContentResponse();
                            if (object.recognitionResult != null) {
                                if (typeof object.recognitionResult !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.StreamingAnalyzeContentResponse.recognitionResult: object expected");
                                message.recognitionResult = $root.google.cloud.dialogflow.v2.StreamingRecognitionResult.fromObject(object.recognitionResult);
                            }
                            if (object.replyText != null)
                                message.replyText = String(object.replyText);
                            if (object.replyAudio != null) {
                                if (typeof object.replyAudio !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.StreamingAnalyzeContentResponse.replyAudio: object expected");
                                message.replyAudio = $root.google.cloud.dialogflow.v2.OutputAudio.fromObject(object.replyAudio);
                            }
                            if (object.automatedAgentReply != null) {
                                if (typeof object.automatedAgentReply !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.StreamingAnalyzeContentResponse.automatedAgentReply: object expected");
                                message.automatedAgentReply = $root.google.cloud.dialogflow.v2.AutomatedAgentReply.fromObject(object.automatedAgentReply);
                            }
                            if (object.message != null) {
                                if (typeof object.message !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.StreamingAnalyzeContentResponse.message: object expected");
                                message.message = $root.google.cloud.dialogflow.v2.Message.fromObject(object.message);
                            }
                            if (object.humanAgentSuggestionResults) {
                                if (!Array.isArray(object.humanAgentSuggestionResults))
                                    throw TypeError(".google.cloud.dialogflow.v2.StreamingAnalyzeContentResponse.humanAgentSuggestionResults: array expected");
                                message.humanAgentSuggestionResults = [];
                                for (var i = 0; i < object.humanAgentSuggestionResults.length; ++i) {
                                    if (typeof object.humanAgentSuggestionResults[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.StreamingAnalyzeContentResponse.humanAgentSuggestionResults: object expected");
                                    message.humanAgentSuggestionResults[i] = $root.google.cloud.dialogflow.v2.SuggestionResult.fromObject(object.humanAgentSuggestionResults[i]);
                                }
                            }
                            if (object.endUserSuggestionResults) {
                                if (!Array.isArray(object.endUserSuggestionResults))
                                    throw TypeError(".google.cloud.dialogflow.v2.StreamingAnalyzeContentResponse.endUserSuggestionResults: array expected");
                                message.endUserSuggestionResults = [];
                                for (var i = 0; i < object.endUserSuggestionResults.length; ++i) {
                                    if (typeof object.endUserSuggestionResults[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.StreamingAnalyzeContentResponse.endUserSuggestionResults: object expected");
                                    message.endUserSuggestionResults[i] = $root.google.cloud.dialogflow.v2.SuggestionResult.fromObject(object.endUserSuggestionResults[i]);
                                }
                            }
                            if (object.dtmfParameters != null) {
                                if (typeof object.dtmfParameters !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.StreamingAnalyzeContentResponse.dtmfParameters: object expected");
                                message.dtmfParameters = $root.google.cloud.dialogflow.v2.DtmfParameters.fromObject(object.dtmfParameters);
                            }
                            if (object.debuggingInfo != null) {
                                if (typeof object.debuggingInfo !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.StreamingAnalyzeContentResponse.debuggingInfo: object expected");
                                message.debuggingInfo = $root.google.cloud.dialogflow.v2.CloudConversationDebuggingInfo.fromObject(object.debuggingInfo);
                            }
                            if (object.speechModel != null)
                                message.speechModel = String(object.speechModel);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a StreamingAnalyzeContentResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.StreamingAnalyzeContentResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.StreamingAnalyzeContentResponse} message StreamingAnalyzeContentResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        StreamingAnalyzeContentResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults) {
                                object.humanAgentSuggestionResults = [];
                                object.endUserSuggestionResults = [];
                            }
                            if (options.defaults) {
                                object.recognitionResult = null;
                                object.replyText = "";
                                object.replyAudio = null;
                                object.automatedAgentReply = null;
                                object.message = null;
                                object.dtmfParameters = null;
                                object.debuggingInfo = null;
                                object.speechModel = "";
                            }
                            if (message.recognitionResult != null && message.hasOwnProperty("recognitionResult"))
                                object.recognitionResult = $root.google.cloud.dialogflow.v2.StreamingRecognitionResult.toObject(message.recognitionResult, options);
                            if (message.replyText != null && message.hasOwnProperty("replyText"))
                                object.replyText = message.replyText;
                            if (message.replyAudio != null && message.hasOwnProperty("replyAudio"))
                                object.replyAudio = $root.google.cloud.dialogflow.v2.OutputAudio.toObject(message.replyAudio, options);
                            if (message.automatedAgentReply != null && message.hasOwnProperty("automatedAgentReply"))
                                object.automatedAgentReply = $root.google.cloud.dialogflow.v2.AutomatedAgentReply.toObject(message.automatedAgentReply, options);
                            if (message.message != null && message.hasOwnProperty("message"))
                                object.message = $root.google.cloud.dialogflow.v2.Message.toObject(message.message, options);
                            if (message.humanAgentSuggestionResults && message.humanAgentSuggestionResults.length) {
                                object.humanAgentSuggestionResults = [];
                                for (var j = 0; j < message.humanAgentSuggestionResults.length; ++j)
                                    object.humanAgentSuggestionResults[j] = $root.google.cloud.dialogflow.v2.SuggestionResult.toObject(message.humanAgentSuggestionResults[j], options);
                            }
                            if (message.endUserSuggestionResults && message.endUserSuggestionResults.length) {
                                object.endUserSuggestionResults = [];
                                for (var j = 0; j < message.endUserSuggestionResults.length; ++j)
                                    object.endUserSuggestionResults[j] = $root.google.cloud.dialogflow.v2.SuggestionResult.toObject(message.endUserSuggestionResults[j], options);
                            }
                            if (message.dtmfParameters != null && message.hasOwnProperty("dtmfParameters"))
                                object.dtmfParameters = $root.google.cloud.dialogflow.v2.DtmfParameters.toObject(message.dtmfParameters, options);
                            if (message.debuggingInfo != null && message.hasOwnProperty("debuggingInfo"))
                                object.debuggingInfo = $root.google.cloud.dialogflow.v2.CloudConversationDebuggingInfo.toObject(message.debuggingInfo, options);
                            if (message.speechModel != null && message.hasOwnProperty("speechModel"))
                                object.speechModel = message.speechModel;
                            return object;
                        };
    
                        /**
                         * Converts this StreamingAnalyzeContentResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.StreamingAnalyzeContentResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        StreamingAnalyzeContentResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for StreamingAnalyzeContentResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.StreamingAnalyzeContentResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        StreamingAnalyzeContentResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.StreamingAnalyzeContentResponse";
                        };
    
                        return StreamingAnalyzeContentResponse;
                    })();
    
                    v2.SuggestArticlesRequest = (function() {
    
                        /**
                         * Properties of a SuggestArticlesRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ISuggestArticlesRequest
                         * @property {string|null} [parent] SuggestArticlesRequest parent
                         * @property {string|null} [latestMessage] SuggestArticlesRequest latestMessage
                         * @property {number|null} [contextSize] SuggestArticlesRequest contextSize
                         * @property {google.cloud.dialogflow.v2.IAssistQueryParameters|null} [assistQueryParams] SuggestArticlesRequest assistQueryParams
                         */
    
                        /**
                         * Constructs a new SuggestArticlesRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a SuggestArticlesRequest.
                         * @implements ISuggestArticlesRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ISuggestArticlesRequest=} [properties] Properties to set
                         */
                        function SuggestArticlesRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SuggestArticlesRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.SuggestArticlesRequest
                         * @instance
                         */
                        SuggestArticlesRequest.prototype.parent = "";
    
                        /**
                         * SuggestArticlesRequest latestMessage.
                         * @member {string} latestMessage
                         * @memberof google.cloud.dialogflow.v2.SuggestArticlesRequest
                         * @instance
                         */
                        SuggestArticlesRequest.prototype.latestMessage = "";
    
                        /**
                         * SuggestArticlesRequest contextSize.
                         * @member {number} contextSize
                         * @memberof google.cloud.dialogflow.v2.SuggestArticlesRequest
                         * @instance
                         */
                        SuggestArticlesRequest.prototype.contextSize = 0;
    
                        /**
                         * SuggestArticlesRequest assistQueryParams.
                         * @member {google.cloud.dialogflow.v2.IAssistQueryParameters|null|undefined} assistQueryParams
                         * @memberof google.cloud.dialogflow.v2.SuggestArticlesRequest
                         * @instance
                         */
                        SuggestArticlesRequest.prototype.assistQueryParams = null;
    
                        /**
                         * Creates a new SuggestArticlesRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.SuggestArticlesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISuggestArticlesRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.SuggestArticlesRequest} SuggestArticlesRequest instance
                         */
                        SuggestArticlesRequest.create = function create(properties) {
                            return new SuggestArticlesRequest(properties);
                        };
    
                        /**
                         * Encodes the specified SuggestArticlesRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.SuggestArticlesRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.SuggestArticlesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISuggestArticlesRequest} message SuggestArticlesRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SuggestArticlesRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.latestMessage != null && Object.hasOwnProperty.call(message, "latestMessage"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.latestMessage);
                            if (message.contextSize != null && Object.hasOwnProperty.call(message, "contextSize"))
                                writer.uint32(/* id 3, wireType 0 =*/24).int32(message.contextSize);
                            if (message.assistQueryParams != null && Object.hasOwnProperty.call(message, "assistQueryParams"))
                                $root.google.cloud.dialogflow.v2.AssistQueryParameters.encode(message.assistQueryParams, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SuggestArticlesRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.SuggestArticlesRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SuggestArticlesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISuggestArticlesRequest} message SuggestArticlesRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SuggestArticlesRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SuggestArticlesRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.SuggestArticlesRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.SuggestArticlesRequest} SuggestArticlesRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SuggestArticlesRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.SuggestArticlesRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.latestMessage = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.contextSize = reader.int32();
                                        break;
                                    }
                                case 4: {
                                        message.assistQueryParams = $root.google.cloud.dialogflow.v2.AssistQueryParameters.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SuggestArticlesRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SuggestArticlesRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.SuggestArticlesRequest} SuggestArticlesRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SuggestArticlesRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SuggestArticlesRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.SuggestArticlesRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SuggestArticlesRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                if (!$util.isString(message.latestMessage))
                                    return "latestMessage: string expected";
                            if (message.contextSize != null && message.hasOwnProperty("contextSize"))
                                if (!$util.isInteger(message.contextSize))
                                    return "contextSize: integer expected";
                            if (message.assistQueryParams != null && message.hasOwnProperty("assistQueryParams")) {
                                var error = $root.google.cloud.dialogflow.v2.AssistQueryParameters.verify(message.assistQueryParams);
                                if (error)
                                    return "assistQueryParams." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a SuggestArticlesRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.SuggestArticlesRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.SuggestArticlesRequest} SuggestArticlesRequest
                         */
                        SuggestArticlesRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.SuggestArticlesRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.SuggestArticlesRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.latestMessage != null)
                                message.latestMessage = String(object.latestMessage);
                            if (object.contextSize != null)
                                message.contextSize = object.contextSize | 0;
                            if (object.assistQueryParams != null) {
                                if (typeof object.assistQueryParams !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.SuggestArticlesRequest.assistQueryParams: object expected");
                                message.assistQueryParams = $root.google.cloud.dialogflow.v2.AssistQueryParameters.fromObject(object.assistQueryParams);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SuggestArticlesRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.SuggestArticlesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.SuggestArticlesRequest} message SuggestArticlesRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SuggestArticlesRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.latestMessage = "";
                                object.contextSize = 0;
                                object.assistQueryParams = null;
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                object.latestMessage = message.latestMessage;
                            if (message.contextSize != null && message.hasOwnProperty("contextSize"))
                                object.contextSize = message.contextSize;
                            if (message.assistQueryParams != null && message.hasOwnProperty("assistQueryParams"))
                                object.assistQueryParams = $root.google.cloud.dialogflow.v2.AssistQueryParameters.toObject(message.assistQueryParams, options);
                            return object;
                        };
    
                        /**
                         * Converts this SuggestArticlesRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.SuggestArticlesRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SuggestArticlesRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SuggestArticlesRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.SuggestArticlesRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SuggestArticlesRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.SuggestArticlesRequest";
                        };
    
                        return SuggestArticlesRequest;
                    })();
    
                    v2.SuggestArticlesResponse = (function() {
    
                        /**
                         * Properties of a SuggestArticlesResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ISuggestArticlesResponse
                         * @property {Array.<google.cloud.dialogflow.v2.IArticleAnswer>|null} [articleAnswers] SuggestArticlesResponse articleAnswers
                         * @property {string|null} [latestMessage] SuggestArticlesResponse latestMessage
                         * @property {number|null} [contextSize] SuggestArticlesResponse contextSize
                         */
    
                        /**
                         * Constructs a new SuggestArticlesResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a SuggestArticlesResponse.
                         * @implements ISuggestArticlesResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ISuggestArticlesResponse=} [properties] Properties to set
                         */
                        function SuggestArticlesResponse(properties) {
                            this.articleAnswers = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SuggestArticlesResponse articleAnswers.
                         * @member {Array.<google.cloud.dialogflow.v2.IArticleAnswer>} articleAnswers
                         * @memberof google.cloud.dialogflow.v2.SuggestArticlesResponse
                         * @instance
                         */
                        SuggestArticlesResponse.prototype.articleAnswers = $util.emptyArray;
    
                        /**
                         * SuggestArticlesResponse latestMessage.
                         * @member {string} latestMessage
                         * @memberof google.cloud.dialogflow.v2.SuggestArticlesResponse
                         * @instance
                         */
                        SuggestArticlesResponse.prototype.latestMessage = "";
    
                        /**
                         * SuggestArticlesResponse contextSize.
                         * @member {number} contextSize
                         * @memberof google.cloud.dialogflow.v2.SuggestArticlesResponse
                         * @instance
                         */
                        SuggestArticlesResponse.prototype.contextSize = 0;
    
                        /**
                         * Creates a new SuggestArticlesResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.SuggestArticlesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISuggestArticlesResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.SuggestArticlesResponse} SuggestArticlesResponse instance
                         */
                        SuggestArticlesResponse.create = function create(properties) {
                            return new SuggestArticlesResponse(properties);
                        };
    
                        /**
                         * Encodes the specified SuggestArticlesResponse message. Does not implicitly {@link google.cloud.dialogflow.v2.SuggestArticlesResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.SuggestArticlesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISuggestArticlesResponse} message SuggestArticlesResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SuggestArticlesResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.articleAnswers != null && message.articleAnswers.length)
                                for (var i = 0; i < message.articleAnswers.length; ++i)
                                    $root.google.cloud.dialogflow.v2.ArticleAnswer.encode(message.articleAnswers[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.latestMessage != null && Object.hasOwnProperty.call(message, "latestMessage"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.latestMessage);
                            if (message.contextSize != null && Object.hasOwnProperty.call(message, "contextSize"))
                                writer.uint32(/* id 3, wireType 0 =*/24).int32(message.contextSize);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SuggestArticlesResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.SuggestArticlesResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SuggestArticlesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISuggestArticlesResponse} message SuggestArticlesResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SuggestArticlesResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SuggestArticlesResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.SuggestArticlesResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.SuggestArticlesResponse} SuggestArticlesResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SuggestArticlesResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.SuggestArticlesResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.articleAnswers && message.articleAnswers.length))
                                            message.articleAnswers = [];
                                        message.articleAnswers.push($root.google.cloud.dialogflow.v2.ArticleAnswer.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 2: {
                                        message.latestMessage = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.contextSize = reader.int32();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SuggestArticlesResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SuggestArticlesResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.SuggestArticlesResponse} SuggestArticlesResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SuggestArticlesResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SuggestArticlesResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.SuggestArticlesResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SuggestArticlesResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.articleAnswers != null && message.hasOwnProperty("articleAnswers")) {
                                if (!Array.isArray(message.articleAnswers))
                                    return "articleAnswers: array expected";
                                for (var i = 0; i < message.articleAnswers.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.ArticleAnswer.verify(message.articleAnswers[i]);
                                    if (error)
                                        return "articleAnswers." + error;
                                }
                            }
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                if (!$util.isString(message.latestMessage))
                                    return "latestMessage: string expected";
                            if (message.contextSize != null && message.hasOwnProperty("contextSize"))
                                if (!$util.isInteger(message.contextSize))
                                    return "contextSize: integer expected";
                            return null;
                        };
    
                        /**
                         * Creates a SuggestArticlesResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.SuggestArticlesResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.SuggestArticlesResponse} SuggestArticlesResponse
                         */
                        SuggestArticlesResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.SuggestArticlesResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.SuggestArticlesResponse();
                            if (object.articleAnswers) {
                                if (!Array.isArray(object.articleAnswers))
                                    throw TypeError(".google.cloud.dialogflow.v2.SuggestArticlesResponse.articleAnswers: array expected");
                                message.articleAnswers = [];
                                for (var i = 0; i < object.articleAnswers.length; ++i) {
                                    if (typeof object.articleAnswers[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.SuggestArticlesResponse.articleAnswers: object expected");
                                    message.articleAnswers[i] = $root.google.cloud.dialogflow.v2.ArticleAnswer.fromObject(object.articleAnswers[i]);
                                }
                            }
                            if (object.latestMessage != null)
                                message.latestMessage = String(object.latestMessage);
                            if (object.contextSize != null)
                                message.contextSize = object.contextSize | 0;
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SuggestArticlesResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.SuggestArticlesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.SuggestArticlesResponse} message SuggestArticlesResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SuggestArticlesResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.articleAnswers = [];
                            if (options.defaults) {
                                object.latestMessage = "";
                                object.contextSize = 0;
                            }
                            if (message.articleAnswers && message.articleAnswers.length) {
                                object.articleAnswers = [];
                                for (var j = 0; j < message.articleAnswers.length; ++j)
                                    object.articleAnswers[j] = $root.google.cloud.dialogflow.v2.ArticleAnswer.toObject(message.articleAnswers[j], options);
                            }
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                object.latestMessage = message.latestMessage;
                            if (message.contextSize != null && message.hasOwnProperty("contextSize"))
                                object.contextSize = message.contextSize;
                            return object;
                        };
    
                        /**
                         * Converts this SuggestArticlesResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.SuggestArticlesResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SuggestArticlesResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SuggestArticlesResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.SuggestArticlesResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SuggestArticlesResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.SuggestArticlesResponse";
                        };
    
                        return SuggestArticlesResponse;
                    })();
    
                    v2.SuggestFaqAnswersRequest = (function() {
    
                        /**
                         * Properties of a SuggestFaqAnswersRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ISuggestFaqAnswersRequest
                         * @property {string|null} [parent] SuggestFaqAnswersRequest parent
                         * @property {string|null} [latestMessage] SuggestFaqAnswersRequest latestMessage
                         * @property {number|null} [contextSize] SuggestFaqAnswersRequest contextSize
                         * @property {google.cloud.dialogflow.v2.IAssistQueryParameters|null} [assistQueryParams] SuggestFaqAnswersRequest assistQueryParams
                         */
    
                        /**
                         * Constructs a new SuggestFaqAnswersRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a SuggestFaqAnswersRequest.
                         * @implements ISuggestFaqAnswersRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ISuggestFaqAnswersRequest=} [properties] Properties to set
                         */
                        function SuggestFaqAnswersRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SuggestFaqAnswersRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.SuggestFaqAnswersRequest
                         * @instance
                         */
                        SuggestFaqAnswersRequest.prototype.parent = "";
    
                        /**
                         * SuggestFaqAnswersRequest latestMessage.
                         * @member {string} latestMessage
                         * @memberof google.cloud.dialogflow.v2.SuggestFaqAnswersRequest
                         * @instance
                         */
                        SuggestFaqAnswersRequest.prototype.latestMessage = "";
    
                        /**
                         * SuggestFaqAnswersRequest contextSize.
                         * @member {number} contextSize
                         * @memberof google.cloud.dialogflow.v2.SuggestFaqAnswersRequest
                         * @instance
                         */
                        SuggestFaqAnswersRequest.prototype.contextSize = 0;
    
                        /**
                         * SuggestFaqAnswersRequest assistQueryParams.
                         * @member {google.cloud.dialogflow.v2.IAssistQueryParameters|null|undefined} assistQueryParams
                         * @memberof google.cloud.dialogflow.v2.SuggestFaqAnswersRequest
                         * @instance
                         */
                        SuggestFaqAnswersRequest.prototype.assistQueryParams = null;
    
                        /**
                         * Creates a new SuggestFaqAnswersRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.SuggestFaqAnswersRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISuggestFaqAnswersRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.SuggestFaqAnswersRequest} SuggestFaqAnswersRequest instance
                         */
                        SuggestFaqAnswersRequest.create = function create(properties) {
                            return new SuggestFaqAnswersRequest(properties);
                        };
    
                        /**
                         * Encodes the specified SuggestFaqAnswersRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.SuggestFaqAnswersRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.SuggestFaqAnswersRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISuggestFaqAnswersRequest} message SuggestFaqAnswersRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SuggestFaqAnswersRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.latestMessage != null && Object.hasOwnProperty.call(message, "latestMessage"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.latestMessage);
                            if (message.contextSize != null && Object.hasOwnProperty.call(message, "contextSize"))
                                writer.uint32(/* id 3, wireType 0 =*/24).int32(message.contextSize);
                            if (message.assistQueryParams != null && Object.hasOwnProperty.call(message, "assistQueryParams"))
                                $root.google.cloud.dialogflow.v2.AssistQueryParameters.encode(message.assistQueryParams, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SuggestFaqAnswersRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.SuggestFaqAnswersRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SuggestFaqAnswersRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISuggestFaqAnswersRequest} message SuggestFaqAnswersRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SuggestFaqAnswersRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SuggestFaqAnswersRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.SuggestFaqAnswersRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.SuggestFaqAnswersRequest} SuggestFaqAnswersRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SuggestFaqAnswersRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.SuggestFaqAnswersRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.latestMessage = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.contextSize = reader.int32();
                                        break;
                                    }
                                case 4: {
                                        message.assistQueryParams = $root.google.cloud.dialogflow.v2.AssistQueryParameters.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SuggestFaqAnswersRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SuggestFaqAnswersRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.SuggestFaqAnswersRequest} SuggestFaqAnswersRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SuggestFaqAnswersRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SuggestFaqAnswersRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.SuggestFaqAnswersRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SuggestFaqAnswersRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                if (!$util.isString(message.latestMessage))
                                    return "latestMessage: string expected";
                            if (message.contextSize != null && message.hasOwnProperty("contextSize"))
                                if (!$util.isInteger(message.contextSize))
                                    return "contextSize: integer expected";
                            if (message.assistQueryParams != null && message.hasOwnProperty("assistQueryParams")) {
                                var error = $root.google.cloud.dialogflow.v2.AssistQueryParameters.verify(message.assistQueryParams);
                                if (error)
                                    return "assistQueryParams." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a SuggestFaqAnswersRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.SuggestFaqAnswersRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.SuggestFaqAnswersRequest} SuggestFaqAnswersRequest
                         */
                        SuggestFaqAnswersRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.SuggestFaqAnswersRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.SuggestFaqAnswersRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.latestMessage != null)
                                message.latestMessage = String(object.latestMessage);
                            if (object.contextSize != null)
                                message.contextSize = object.contextSize | 0;
                            if (object.assistQueryParams != null) {
                                if (typeof object.assistQueryParams !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.SuggestFaqAnswersRequest.assistQueryParams: object expected");
                                message.assistQueryParams = $root.google.cloud.dialogflow.v2.AssistQueryParameters.fromObject(object.assistQueryParams);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SuggestFaqAnswersRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.SuggestFaqAnswersRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.SuggestFaqAnswersRequest} message SuggestFaqAnswersRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SuggestFaqAnswersRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.latestMessage = "";
                                object.contextSize = 0;
                                object.assistQueryParams = null;
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                object.latestMessage = message.latestMessage;
                            if (message.contextSize != null && message.hasOwnProperty("contextSize"))
                                object.contextSize = message.contextSize;
                            if (message.assistQueryParams != null && message.hasOwnProperty("assistQueryParams"))
                                object.assistQueryParams = $root.google.cloud.dialogflow.v2.AssistQueryParameters.toObject(message.assistQueryParams, options);
                            return object;
                        };
    
                        /**
                         * Converts this SuggestFaqAnswersRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.SuggestFaqAnswersRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SuggestFaqAnswersRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SuggestFaqAnswersRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.SuggestFaqAnswersRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SuggestFaqAnswersRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.SuggestFaqAnswersRequest";
                        };
    
                        return SuggestFaqAnswersRequest;
                    })();
    
                    v2.SuggestFaqAnswersResponse = (function() {
    
                        /**
                         * Properties of a SuggestFaqAnswersResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ISuggestFaqAnswersResponse
                         * @property {Array.<google.cloud.dialogflow.v2.IFaqAnswer>|null} [faqAnswers] SuggestFaqAnswersResponse faqAnswers
                         * @property {string|null} [latestMessage] SuggestFaqAnswersResponse latestMessage
                         * @property {number|null} [contextSize] SuggestFaqAnswersResponse contextSize
                         */
    
                        /**
                         * Constructs a new SuggestFaqAnswersResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a SuggestFaqAnswersResponse.
                         * @implements ISuggestFaqAnswersResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ISuggestFaqAnswersResponse=} [properties] Properties to set
                         */
                        function SuggestFaqAnswersResponse(properties) {
                            this.faqAnswers = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SuggestFaqAnswersResponse faqAnswers.
                         * @member {Array.<google.cloud.dialogflow.v2.IFaqAnswer>} faqAnswers
                         * @memberof google.cloud.dialogflow.v2.SuggestFaqAnswersResponse
                         * @instance
                         */
                        SuggestFaqAnswersResponse.prototype.faqAnswers = $util.emptyArray;
    
                        /**
                         * SuggestFaqAnswersResponse latestMessage.
                         * @member {string} latestMessage
                         * @memberof google.cloud.dialogflow.v2.SuggestFaqAnswersResponse
                         * @instance
                         */
                        SuggestFaqAnswersResponse.prototype.latestMessage = "";
    
                        /**
                         * SuggestFaqAnswersResponse contextSize.
                         * @member {number} contextSize
                         * @memberof google.cloud.dialogflow.v2.SuggestFaqAnswersResponse
                         * @instance
                         */
                        SuggestFaqAnswersResponse.prototype.contextSize = 0;
    
                        /**
                         * Creates a new SuggestFaqAnswersResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.SuggestFaqAnswersResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISuggestFaqAnswersResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.SuggestFaqAnswersResponse} SuggestFaqAnswersResponse instance
                         */
                        SuggestFaqAnswersResponse.create = function create(properties) {
                            return new SuggestFaqAnswersResponse(properties);
                        };
    
                        /**
                         * Encodes the specified SuggestFaqAnswersResponse message. Does not implicitly {@link google.cloud.dialogflow.v2.SuggestFaqAnswersResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.SuggestFaqAnswersResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISuggestFaqAnswersResponse} message SuggestFaqAnswersResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SuggestFaqAnswersResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.faqAnswers != null && message.faqAnswers.length)
                                for (var i = 0; i < message.faqAnswers.length; ++i)
                                    $root.google.cloud.dialogflow.v2.FaqAnswer.encode(message.faqAnswers[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.latestMessage != null && Object.hasOwnProperty.call(message, "latestMessage"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.latestMessage);
                            if (message.contextSize != null && Object.hasOwnProperty.call(message, "contextSize"))
                                writer.uint32(/* id 3, wireType 0 =*/24).int32(message.contextSize);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SuggestFaqAnswersResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.SuggestFaqAnswersResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SuggestFaqAnswersResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISuggestFaqAnswersResponse} message SuggestFaqAnswersResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SuggestFaqAnswersResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SuggestFaqAnswersResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.SuggestFaqAnswersResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.SuggestFaqAnswersResponse} SuggestFaqAnswersResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SuggestFaqAnswersResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.SuggestFaqAnswersResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.faqAnswers && message.faqAnswers.length))
                                            message.faqAnswers = [];
                                        message.faqAnswers.push($root.google.cloud.dialogflow.v2.FaqAnswer.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 2: {
                                        message.latestMessage = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.contextSize = reader.int32();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SuggestFaqAnswersResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SuggestFaqAnswersResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.SuggestFaqAnswersResponse} SuggestFaqAnswersResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SuggestFaqAnswersResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SuggestFaqAnswersResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.SuggestFaqAnswersResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SuggestFaqAnswersResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.faqAnswers != null && message.hasOwnProperty("faqAnswers")) {
                                if (!Array.isArray(message.faqAnswers))
                                    return "faqAnswers: array expected";
                                for (var i = 0; i < message.faqAnswers.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.FaqAnswer.verify(message.faqAnswers[i]);
                                    if (error)
                                        return "faqAnswers." + error;
                                }
                            }
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                if (!$util.isString(message.latestMessage))
                                    return "latestMessage: string expected";
                            if (message.contextSize != null && message.hasOwnProperty("contextSize"))
                                if (!$util.isInteger(message.contextSize))
                                    return "contextSize: integer expected";
                            return null;
                        };
    
                        /**
                         * Creates a SuggestFaqAnswersResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.SuggestFaqAnswersResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.SuggestFaqAnswersResponse} SuggestFaqAnswersResponse
                         */
                        SuggestFaqAnswersResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.SuggestFaqAnswersResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.SuggestFaqAnswersResponse();
                            if (object.faqAnswers) {
                                if (!Array.isArray(object.faqAnswers))
                                    throw TypeError(".google.cloud.dialogflow.v2.SuggestFaqAnswersResponse.faqAnswers: array expected");
                                message.faqAnswers = [];
                                for (var i = 0; i < object.faqAnswers.length; ++i) {
                                    if (typeof object.faqAnswers[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.SuggestFaqAnswersResponse.faqAnswers: object expected");
                                    message.faqAnswers[i] = $root.google.cloud.dialogflow.v2.FaqAnswer.fromObject(object.faqAnswers[i]);
                                }
                            }
                            if (object.latestMessage != null)
                                message.latestMessage = String(object.latestMessage);
                            if (object.contextSize != null)
                                message.contextSize = object.contextSize | 0;
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SuggestFaqAnswersResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.SuggestFaqAnswersResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.SuggestFaqAnswersResponse} message SuggestFaqAnswersResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SuggestFaqAnswersResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.faqAnswers = [];
                            if (options.defaults) {
                                object.latestMessage = "";
                                object.contextSize = 0;
                            }
                            if (message.faqAnswers && message.faqAnswers.length) {
                                object.faqAnswers = [];
                                for (var j = 0; j < message.faqAnswers.length; ++j)
                                    object.faqAnswers[j] = $root.google.cloud.dialogflow.v2.FaqAnswer.toObject(message.faqAnswers[j], options);
                            }
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                object.latestMessage = message.latestMessage;
                            if (message.contextSize != null && message.hasOwnProperty("contextSize"))
                                object.contextSize = message.contextSize;
                            return object;
                        };
    
                        /**
                         * Converts this SuggestFaqAnswersResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.SuggestFaqAnswersResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SuggestFaqAnswersResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SuggestFaqAnswersResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.SuggestFaqAnswersResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SuggestFaqAnswersResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.SuggestFaqAnswersResponse";
                        };
    
                        return SuggestFaqAnswersResponse;
                    })();
    
                    v2.GenerateSuggestionsResponse = (function() {
    
                        /**
                         * Properties of a GenerateSuggestionsResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IGenerateSuggestionsResponse
                         * @property {Array.<google.cloud.dialogflow.v2.GenerateSuggestionsResponse.IGeneratorSuggestionAnswer>|null} [generatorSuggestionAnswers] GenerateSuggestionsResponse generatorSuggestionAnswers
                         * @property {string|null} [latestMessage] GenerateSuggestionsResponse latestMessage
                         */
    
                        /**
                         * Constructs a new GenerateSuggestionsResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a GenerateSuggestionsResponse.
                         * @implements IGenerateSuggestionsResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IGenerateSuggestionsResponse=} [properties] Properties to set
                         */
                        function GenerateSuggestionsResponse(properties) {
                            this.generatorSuggestionAnswers = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GenerateSuggestionsResponse generatorSuggestionAnswers.
                         * @member {Array.<google.cloud.dialogflow.v2.GenerateSuggestionsResponse.IGeneratorSuggestionAnswer>} generatorSuggestionAnswers
                         * @memberof google.cloud.dialogflow.v2.GenerateSuggestionsResponse
                         * @instance
                         */
                        GenerateSuggestionsResponse.prototype.generatorSuggestionAnswers = $util.emptyArray;
    
                        /**
                         * GenerateSuggestionsResponse latestMessage.
                         * @member {string} latestMessage
                         * @memberof google.cloud.dialogflow.v2.GenerateSuggestionsResponse
                         * @instance
                         */
                        GenerateSuggestionsResponse.prototype.latestMessage = "";
    
                        /**
                         * Creates a new GenerateSuggestionsResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.GenerateSuggestionsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGenerateSuggestionsResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.GenerateSuggestionsResponse} GenerateSuggestionsResponse instance
                         */
                        GenerateSuggestionsResponse.create = function create(properties) {
                            return new GenerateSuggestionsResponse(properties);
                        };
    
                        /**
                         * Encodes the specified GenerateSuggestionsResponse message. Does not implicitly {@link google.cloud.dialogflow.v2.GenerateSuggestionsResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.GenerateSuggestionsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGenerateSuggestionsResponse} message GenerateSuggestionsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GenerateSuggestionsResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.generatorSuggestionAnswers != null && message.generatorSuggestionAnswers.length)
                                for (var i = 0; i < message.generatorSuggestionAnswers.length; ++i)
                                    $root.google.cloud.dialogflow.v2.GenerateSuggestionsResponse.GeneratorSuggestionAnswer.encode(message.generatorSuggestionAnswers[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.latestMessage != null && Object.hasOwnProperty.call(message, "latestMessage"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.latestMessage);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GenerateSuggestionsResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.GenerateSuggestionsResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GenerateSuggestionsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGenerateSuggestionsResponse} message GenerateSuggestionsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GenerateSuggestionsResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GenerateSuggestionsResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.GenerateSuggestionsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.GenerateSuggestionsResponse} GenerateSuggestionsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GenerateSuggestionsResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.GenerateSuggestionsResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.generatorSuggestionAnswers && message.generatorSuggestionAnswers.length))
                                            message.generatorSuggestionAnswers = [];
                                        message.generatorSuggestionAnswers.push($root.google.cloud.dialogflow.v2.GenerateSuggestionsResponse.GeneratorSuggestionAnswer.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 2: {
                                        message.latestMessage = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GenerateSuggestionsResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GenerateSuggestionsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.GenerateSuggestionsResponse} GenerateSuggestionsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GenerateSuggestionsResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GenerateSuggestionsResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.GenerateSuggestionsResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GenerateSuggestionsResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.generatorSuggestionAnswers != null && message.hasOwnProperty("generatorSuggestionAnswers")) {
                                if (!Array.isArray(message.generatorSuggestionAnswers))
                                    return "generatorSuggestionAnswers: array expected";
                                for (var i = 0; i < message.generatorSuggestionAnswers.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.GenerateSuggestionsResponse.GeneratorSuggestionAnswer.verify(message.generatorSuggestionAnswers[i]);
                                    if (error)
                                        return "generatorSuggestionAnswers." + error;
                                }
                            }
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                if (!$util.isString(message.latestMessage))
                                    return "latestMessage: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a GenerateSuggestionsResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.GenerateSuggestionsResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.GenerateSuggestionsResponse} GenerateSuggestionsResponse
                         */
                        GenerateSuggestionsResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.GenerateSuggestionsResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.GenerateSuggestionsResponse();
                            if (object.generatorSuggestionAnswers) {
                                if (!Array.isArray(object.generatorSuggestionAnswers))
                                    throw TypeError(".google.cloud.dialogflow.v2.GenerateSuggestionsResponse.generatorSuggestionAnswers: array expected");
                                message.generatorSuggestionAnswers = [];
                                for (var i = 0; i < object.generatorSuggestionAnswers.length; ++i) {
                                    if (typeof object.generatorSuggestionAnswers[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.GenerateSuggestionsResponse.generatorSuggestionAnswers: object expected");
                                    message.generatorSuggestionAnswers[i] = $root.google.cloud.dialogflow.v2.GenerateSuggestionsResponse.GeneratorSuggestionAnswer.fromObject(object.generatorSuggestionAnswers[i]);
                                }
                            }
                            if (object.latestMessage != null)
                                message.latestMessage = String(object.latestMessage);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GenerateSuggestionsResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.GenerateSuggestionsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.GenerateSuggestionsResponse} message GenerateSuggestionsResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GenerateSuggestionsResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.generatorSuggestionAnswers = [];
                            if (options.defaults)
                                object.latestMessage = "";
                            if (message.generatorSuggestionAnswers && message.generatorSuggestionAnswers.length) {
                                object.generatorSuggestionAnswers = [];
                                for (var j = 0; j < message.generatorSuggestionAnswers.length; ++j)
                                    object.generatorSuggestionAnswers[j] = $root.google.cloud.dialogflow.v2.GenerateSuggestionsResponse.GeneratorSuggestionAnswer.toObject(message.generatorSuggestionAnswers[j], options);
                            }
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                object.latestMessage = message.latestMessage;
                            return object;
                        };
    
                        /**
                         * Converts this GenerateSuggestionsResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.GenerateSuggestionsResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GenerateSuggestionsResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GenerateSuggestionsResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.GenerateSuggestionsResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GenerateSuggestionsResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.GenerateSuggestionsResponse";
                        };
    
                        GenerateSuggestionsResponse.GeneratorSuggestionAnswer = (function() {
    
                            /**
                             * Properties of a GeneratorSuggestionAnswer.
                             * @memberof google.cloud.dialogflow.v2.GenerateSuggestionsResponse
                             * @interface IGeneratorSuggestionAnswer
                             * @property {google.cloud.dialogflow.v2.IGeneratorSuggestion|null} [generatorSuggestion] GeneratorSuggestionAnswer generatorSuggestion
                             * @property {string|null} [sourceGenerator] GeneratorSuggestionAnswer sourceGenerator
                             * @property {string|null} [answerRecord] GeneratorSuggestionAnswer answerRecord
                             */
    
                            /**
                             * Constructs a new GeneratorSuggestionAnswer.
                             * @memberof google.cloud.dialogflow.v2.GenerateSuggestionsResponse
                             * @classdesc Represents a GeneratorSuggestionAnswer.
                             * @implements IGeneratorSuggestionAnswer
                             * @constructor
                             * @param {google.cloud.dialogflow.v2.GenerateSuggestionsResponse.IGeneratorSuggestionAnswer=} [properties] Properties to set
                             */
                            function GeneratorSuggestionAnswer(properties) {
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * GeneratorSuggestionAnswer generatorSuggestion.
                             * @member {google.cloud.dialogflow.v2.IGeneratorSuggestion|null|undefined} generatorSuggestion
                             * @memberof google.cloud.dialogflow.v2.GenerateSuggestionsResponse.GeneratorSuggestionAnswer
                             * @instance
                             */
                            GeneratorSuggestionAnswer.prototype.generatorSuggestion = null;
    
                            /**
                             * GeneratorSuggestionAnswer sourceGenerator.
                             * @member {string} sourceGenerator
                             * @memberof google.cloud.dialogflow.v2.GenerateSuggestionsResponse.GeneratorSuggestionAnswer
                             * @instance
                             */
                            GeneratorSuggestionAnswer.prototype.sourceGenerator = "";
    
                            /**
                             * GeneratorSuggestionAnswer answerRecord.
                             * @member {string} answerRecord
                             * @memberof google.cloud.dialogflow.v2.GenerateSuggestionsResponse.GeneratorSuggestionAnswer
                             * @instance
                             */
                            GeneratorSuggestionAnswer.prototype.answerRecord = "";
    
                            /**
                             * Creates a new GeneratorSuggestionAnswer instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2.GenerateSuggestionsResponse.GeneratorSuggestionAnswer
                             * @static
                             * @param {google.cloud.dialogflow.v2.GenerateSuggestionsResponse.IGeneratorSuggestionAnswer=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2.GenerateSuggestionsResponse.GeneratorSuggestionAnswer} GeneratorSuggestionAnswer instance
                             */
                            GeneratorSuggestionAnswer.create = function create(properties) {
                                return new GeneratorSuggestionAnswer(properties);
                            };
    
                            /**
                             * Encodes the specified GeneratorSuggestionAnswer message. Does not implicitly {@link google.cloud.dialogflow.v2.GenerateSuggestionsResponse.GeneratorSuggestionAnswer.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2.GenerateSuggestionsResponse.GeneratorSuggestionAnswer
                             * @static
                             * @param {google.cloud.dialogflow.v2.GenerateSuggestionsResponse.IGeneratorSuggestionAnswer} message GeneratorSuggestionAnswer message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            GeneratorSuggestionAnswer.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.generatorSuggestion != null && Object.hasOwnProperty.call(message, "generatorSuggestion"))
                                    $root.google.cloud.dialogflow.v2.GeneratorSuggestion.encode(message.generatorSuggestion, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                                if (message.sourceGenerator != null && Object.hasOwnProperty.call(message, "sourceGenerator"))
                                    writer.uint32(/* id 2, wireType 2 =*/18).string(message.sourceGenerator);
                                if (message.answerRecord != null && Object.hasOwnProperty.call(message, "answerRecord"))
                                    writer.uint32(/* id 3, wireType 2 =*/26).string(message.answerRecord);
                                return writer;
                            };
    
                            /**
                             * Encodes the specified GeneratorSuggestionAnswer message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.GenerateSuggestionsResponse.GeneratorSuggestionAnswer.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2.GenerateSuggestionsResponse.GeneratorSuggestionAnswer
                             * @static
                             * @param {google.cloud.dialogflow.v2.GenerateSuggestionsResponse.IGeneratorSuggestionAnswer} message GeneratorSuggestionAnswer message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            GeneratorSuggestionAnswer.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a GeneratorSuggestionAnswer message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2.GenerateSuggestionsResponse.GeneratorSuggestionAnswer
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2.GenerateSuggestionsResponse.GeneratorSuggestionAnswer} GeneratorSuggestionAnswer
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            GeneratorSuggestionAnswer.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.GenerateSuggestionsResponse.GeneratorSuggestionAnswer();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.generatorSuggestion = $root.google.cloud.dialogflow.v2.GeneratorSuggestion.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 2: {
                                            message.sourceGenerator = reader.string();
                                            break;
                                        }
                                    case 3: {
                                            message.answerRecord = reader.string();
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a GeneratorSuggestionAnswer message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2.GenerateSuggestionsResponse.GeneratorSuggestionAnswer
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2.GenerateSuggestionsResponse.GeneratorSuggestionAnswer} GeneratorSuggestionAnswer
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            GeneratorSuggestionAnswer.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a GeneratorSuggestionAnswer message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2.GenerateSuggestionsResponse.GeneratorSuggestionAnswer
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            GeneratorSuggestionAnswer.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.generatorSuggestion != null && message.hasOwnProperty("generatorSuggestion")) {
                                    var error = $root.google.cloud.dialogflow.v2.GeneratorSuggestion.verify(message.generatorSuggestion);
                                    if (error)
                                        return "generatorSuggestion." + error;
                                }
                                if (message.sourceGenerator != null && message.hasOwnProperty("sourceGenerator"))
                                    if (!$util.isString(message.sourceGenerator))
                                        return "sourceGenerator: string expected";
                                if (message.answerRecord != null && message.hasOwnProperty("answerRecord"))
                                    if (!$util.isString(message.answerRecord))
                                        return "answerRecord: string expected";
                                return null;
                            };
    
                            /**
                             * Creates a GeneratorSuggestionAnswer message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2.GenerateSuggestionsResponse.GeneratorSuggestionAnswer
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2.GenerateSuggestionsResponse.GeneratorSuggestionAnswer} GeneratorSuggestionAnswer
                             */
                            GeneratorSuggestionAnswer.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2.GenerateSuggestionsResponse.GeneratorSuggestionAnswer)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2.GenerateSuggestionsResponse.GeneratorSuggestionAnswer();
                                if (object.generatorSuggestion != null) {
                                    if (typeof object.generatorSuggestion !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.GenerateSuggestionsResponse.GeneratorSuggestionAnswer.generatorSuggestion: object expected");
                                    message.generatorSuggestion = $root.google.cloud.dialogflow.v2.GeneratorSuggestion.fromObject(object.generatorSuggestion);
                                }
                                if (object.sourceGenerator != null)
                                    message.sourceGenerator = String(object.sourceGenerator);
                                if (object.answerRecord != null)
                                    message.answerRecord = String(object.answerRecord);
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a GeneratorSuggestionAnswer message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2.GenerateSuggestionsResponse.GeneratorSuggestionAnswer
                             * @static
                             * @param {google.cloud.dialogflow.v2.GenerateSuggestionsResponse.GeneratorSuggestionAnswer} message GeneratorSuggestionAnswer
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            GeneratorSuggestionAnswer.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.defaults) {
                                    object.generatorSuggestion = null;
                                    object.sourceGenerator = "";
                                    object.answerRecord = "";
                                }
                                if (message.generatorSuggestion != null && message.hasOwnProperty("generatorSuggestion"))
                                    object.generatorSuggestion = $root.google.cloud.dialogflow.v2.GeneratorSuggestion.toObject(message.generatorSuggestion, options);
                                if (message.sourceGenerator != null && message.hasOwnProperty("sourceGenerator"))
                                    object.sourceGenerator = message.sourceGenerator;
                                if (message.answerRecord != null && message.hasOwnProperty("answerRecord"))
                                    object.answerRecord = message.answerRecord;
                                return object;
                            };
    
                            /**
                             * Converts this GeneratorSuggestionAnswer to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2.GenerateSuggestionsResponse.GeneratorSuggestionAnswer
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            GeneratorSuggestionAnswer.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for GeneratorSuggestionAnswer
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2.GenerateSuggestionsResponse.GeneratorSuggestionAnswer
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            GeneratorSuggestionAnswer.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2.GenerateSuggestionsResponse.GeneratorSuggestionAnswer";
                            };
    
                            return GeneratorSuggestionAnswer;
                        })();
    
                        return GenerateSuggestionsResponse;
                    })();
    
                    v2.SuggestSmartRepliesRequest = (function() {
    
                        /**
                         * Properties of a SuggestSmartRepliesRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ISuggestSmartRepliesRequest
                         * @property {string|null} [parent] SuggestSmartRepliesRequest parent
                         * @property {google.cloud.dialogflow.v2.ITextInput|null} [currentTextInput] SuggestSmartRepliesRequest currentTextInput
                         * @property {string|null} [latestMessage] SuggestSmartRepliesRequest latestMessage
                         * @property {number|null} [contextSize] SuggestSmartRepliesRequest contextSize
                         */
    
                        /**
                         * Constructs a new SuggestSmartRepliesRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a SuggestSmartRepliesRequest.
                         * @implements ISuggestSmartRepliesRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ISuggestSmartRepliesRequest=} [properties] Properties to set
                         */
                        function SuggestSmartRepliesRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SuggestSmartRepliesRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.SuggestSmartRepliesRequest
                         * @instance
                         */
                        SuggestSmartRepliesRequest.prototype.parent = "";
    
                        /**
                         * SuggestSmartRepliesRequest currentTextInput.
                         * @member {google.cloud.dialogflow.v2.ITextInput|null|undefined} currentTextInput
                         * @memberof google.cloud.dialogflow.v2.SuggestSmartRepliesRequest
                         * @instance
                         */
                        SuggestSmartRepliesRequest.prototype.currentTextInput = null;
    
                        /**
                         * SuggestSmartRepliesRequest latestMessage.
                         * @member {string} latestMessage
                         * @memberof google.cloud.dialogflow.v2.SuggestSmartRepliesRequest
                         * @instance
                         */
                        SuggestSmartRepliesRequest.prototype.latestMessage = "";
    
                        /**
                         * SuggestSmartRepliesRequest contextSize.
                         * @member {number} contextSize
                         * @memberof google.cloud.dialogflow.v2.SuggestSmartRepliesRequest
                         * @instance
                         */
                        SuggestSmartRepliesRequest.prototype.contextSize = 0;
    
                        /**
                         * Creates a new SuggestSmartRepliesRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.SuggestSmartRepliesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISuggestSmartRepliesRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.SuggestSmartRepliesRequest} SuggestSmartRepliesRequest instance
                         */
                        SuggestSmartRepliesRequest.create = function create(properties) {
                            return new SuggestSmartRepliesRequest(properties);
                        };
    
                        /**
                         * Encodes the specified SuggestSmartRepliesRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.SuggestSmartRepliesRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.SuggestSmartRepliesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISuggestSmartRepliesRequest} message SuggestSmartRepliesRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SuggestSmartRepliesRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.latestMessage != null && Object.hasOwnProperty.call(message, "latestMessage"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.latestMessage);
                            if (message.contextSize != null && Object.hasOwnProperty.call(message, "contextSize"))
                                writer.uint32(/* id 3, wireType 0 =*/24).int32(message.contextSize);
                            if (message.currentTextInput != null && Object.hasOwnProperty.call(message, "currentTextInput"))
                                $root.google.cloud.dialogflow.v2.TextInput.encode(message.currentTextInput, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SuggestSmartRepliesRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.SuggestSmartRepliesRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SuggestSmartRepliesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISuggestSmartRepliesRequest} message SuggestSmartRepliesRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SuggestSmartRepliesRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SuggestSmartRepliesRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.SuggestSmartRepliesRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.SuggestSmartRepliesRequest} SuggestSmartRepliesRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SuggestSmartRepliesRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.SuggestSmartRepliesRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 4: {
                                        message.currentTextInput = $root.google.cloud.dialogflow.v2.TextInput.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.latestMessage = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.contextSize = reader.int32();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SuggestSmartRepliesRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SuggestSmartRepliesRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.SuggestSmartRepliesRequest} SuggestSmartRepliesRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SuggestSmartRepliesRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SuggestSmartRepliesRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.SuggestSmartRepliesRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SuggestSmartRepliesRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.currentTextInput != null && message.hasOwnProperty("currentTextInput")) {
                                var error = $root.google.cloud.dialogflow.v2.TextInput.verify(message.currentTextInput);
                                if (error)
                                    return "currentTextInput." + error;
                            }
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                if (!$util.isString(message.latestMessage))
                                    return "latestMessage: string expected";
                            if (message.contextSize != null && message.hasOwnProperty("contextSize"))
                                if (!$util.isInteger(message.contextSize))
                                    return "contextSize: integer expected";
                            return null;
                        };
    
                        /**
                         * Creates a SuggestSmartRepliesRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.SuggestSmartRepliesRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.SuggestSmartRepliesRequest} SuggestSmartRepliesRequest
                         */
                        SuggestSmartRepliesRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.SuggestSmartRepliesRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.SuggestSmartRepliesRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.currentTextInput != null) {
                                if (typeof object.currentTextInput !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.SuggestSmartRepliesRequest.currentTextInput: object expected");
                                message.currentTextInput = $root.google.cloud.dialogflow.v2.TextInput.fromObject(object.currentTextInput);
                            }
                            if (object.latestMessage != null)
                                message.latestMessage = String(object.latestMessage);
                            if (object.contextSize != null)
                                message.contextSize = object.contextSize | 0;
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SuggestSmartRepliesRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.SuggestSmartRepliesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.SuggestSmartRepliesRequest} message SuggestSmartRepliesRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SuggestSmartRepliesRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.latestMessage = "";
                                object.contextSize = 0;
                                object.currentTextInput = null;
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                object.latestMessage = message.latestMessage;
                            if (message.contextSize != null && message.hasOwnProperty("contextSize"))
                                object.contextSize = message.contextSize;
                            if (message.currentTextInput != null && message.hasOwnProperty("currentTextInput"))
                                object.currentTextInput = $root.google.cloud.dialogflow.v2.TextInput.toObject(message.currentTextInput, options);
                            return object;
                        };
    
                        /**
                         * Converts this SuggestSmartRepliesRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.SuggestSmartRepliesRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SuggestSmartRepliesRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SuggestSmartRepliesRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.SuggestSmartRepliesRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SuggestSmartRepliesRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.SuggestSmartRepliesRequest";
                        };
    
                        return SuggestSmartRepliesRequest;
                    })();
    
                    v2.SuggestSmartRepliesResponse = (function() {
    
                        /**
                         * Properties of a SuggestSmartRepliesResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ISuggestSmartRepliesResponse
                         * @property {Array.<google.cloud.dialogflow.v2.ISmartReplyAnswer>|null} [smartReplyAnswers] SuggestSmartRepliesResponse smartReplyAnswers
                         * @property {string|null} [latestMessage] SuggestSmartRepliesResponse latestMessage
                         * @property {number|null} [contextSize] SuggestSmartRepliesResponse contextSize
                         */
    
                        /**
                         * Constructs a new SuggestSmartRepliesResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a SuggestSmartRepliesResponse.
                         * @implements ISuggestSmartRepliesResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ISuggestSmartRepliesResponse=} [properties] Properties to set
                         */
                        function SuggestSmartRepliesResponse(properties) {
                            this.smartReplyAnswers = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SuggestSmartRepliesResponse smartReplyAnswers.
                         * @member {Array.<google.cloud.dialogflow.v2.ISmartReplyAnswer>} smartReplyAnswers
                         * @memberof google.cloud.dialogflow.v2.SuggestSmartRepliesResponse
                         * @instance
                         */
                        SuggestSmartRepliesResponse.prototype.smartReplyAnswers = $util.emptyArray;
    
                        /**
                         * SuggestSmartRepliesResponse latestMessage.
                         * @member {string} latestMessage
                         * @memberof google.cloud.dialogflow.v2.SuggestSmartRepliesResponse
                         * @instance
                         */
                        SuggestSmartRepliesResponse.prototype.latestMessage = "";
    
                        /**
                         * SuggestSmartRepliesResponse contextSize.
                         * @member {number} contextSize
                         * @memberof google.cloud.dialogflow.v2.SuggestSmartRepliesResponse
                         * @instance
                         */
                        SuggestSmartRepliesResponse.prototype.contextSize = 0;
    
                        /**
                         * Creates a new SuggestSmartRepliesResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.SuggestSmartRepliesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISuggestSmartRepliesResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.SuggestSmartRepliesResponse} SuggestSmartRepliesResponse instance
                         */
                        SuggestSmartRepliesResponse.create = function create(properties) {
                            return new SuggestSmartRepliesResponse(properties);
                        };
    
                        /**
                         * Encodes the specified SuggestSmartRepliesResponse message. Does not implicitly {@link google.cloud.dialogflow.v2.SuggestSmartRepliesResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.SuggestSmartRepliesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISuggestSmartRepliesResponse} message SuggestSmartRepliesResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SuggestSmartRepliesResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.smartReplyAnswers != null && message.smartReplyAnswers.length)
                                for (var i = 0; i < message.smartReplyAnswers.length; ++i)
                                    $root.google.cloud.dialogflow.v2.SmartReplyAnswer.encode(message.smartReplyAnswers[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.latestMessage != null && Object.hasOwnProperty.call(message, "latestMessage"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.latestMessage);
                            if (message.contextSize != null && Object.hasOwnProperty.call(message, "contextSize"))
                                writer.uint32(/* id 3, wireType 0 =*/24).int32(message.contextSize);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SuggestSmartRepliesResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.SuggestSmartRepliesResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SuggestSmartRepliesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISuggestSmartRepliesResponse} message SuggestSmartRepliesResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SuggestSmartRepliesResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SuggestSmartRepliesResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.SuggestSmartRepliesResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.SuggestSmartRepliesResponse} SuggestSmartRepliesResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SuggestSmartRepliesResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.SuggestSmartRepliesResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.smartReplyAnswers && message.smartReplyAnswers.length))
                                            message.smartReplyAnswers = [];
                                        message.smartReplyAnswers.push($root.google.cloud.dialogflow.v2.SmartReplyAnswer.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 2: {
                                        message.latestMessage = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.contextSize = reader.int32();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SuggestSmartRepliesResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SuggestSmartRepliesResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.SuggestSmartRepliesResponse} SuggestSmartRepliesResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SuggestSmartRepliesResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SuggestSmartRepliesResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.SuggestSmartRepliesResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SuggestSmartRepliesResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.smartReplyAnswers != null && message.hasOwnProperty("smartReplyAnswers")) {
                                if (!Array.isArray(message.smartReplyAnswers))
                                    return "smartReplyAnswers: array expected";
                                for (var i = 0; i < message.smartReplyAnswers.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.SmartReplyAnswer.verify(message.smartReplyAnswers[i]);
                                    if (error)
                                        return "smartReplyAnswers." + error;
                                }
                            }
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                if (!$util.isString(message.latestMessage))
                                    return "latestMessage: string expected";
                            if (message.contextSize != null && message.hasOwnProperty("contextSize"))
                                if (!$util.isInteger(message.contextSize))
                                    return "contextSize: integer expected";
                            return null;
                        };
    
                        /**
                         * Creates a SuggestSmartRepliesResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.SuggestSmartRepliesResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.SuggestSmartRepliesResponse} SuggestSmartRepliesResponse
                         */
                        SuggestSmartRepliesResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.SuggestSmartRepliesResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.SuggestSmartRepliesResponse();
                            if (object.smartReplyAnswers) {
                                if (!Array.isArray(object.smartReplyAnswers))
                                    throw TypeError(".google.cloud.dialogflow.v2.SuggestSmartRepliesResponse.smartReplyAnswers: array expected");
                                message.smartReplyAnswers = [];
                                for (var i = 0; i < object.smartReplyAnswers.length; ++i) {
                                    if (typeof object.smartReplyAnswers[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.SuggestSmartRepliesResponse.smartReplyAnswers: object expected");
                                    message.smartReplyAnswers[i] = $root.google.cloud.dialogflow.v2.SmartReplyAnswer.fromObject(object.smartReplyAnswers[i]);
                                }
                            }
                            if (object.latestMessage != null)
                                message.latestMessage = String(object.latestMessage);
                            if (object.contextSize != null)
                                message.contextSize = object.contextSize | 0;
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SuggestSmartRepliesResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.SuggestSmartRepliesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.SuggestSmartRepliesResponse} message SuggestSmartRepliesResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SuggestSmartRepliesResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.smartReplyAnswers = [];
                            if (options.defaults) {
                                object.latestMessage = "";
                                object.contextSize = 0;
                            }
                            if (message.smartReplyAnswers && message.smartReplyAnswers.length) {
                                object.smartReplyAnswers = [];
                                for (var j = 0; j < message.smartReplyAnswers.length; ++j)
                                    object.smartReplyAnswers[j] = $root.google.cloud.dialogflow.v2.SmartReplyAnswer.toObject(message.smartReplyAnswers[j], options);
                            }
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                object.latestMessage = message.latestMessage;
                            if (message.contextSize != null && message.hasOwnProperty("contextSize"))
                                object.contextSize = message.contextSize;
                            return object;
                        };
    
                        /**
                         * Converts this SuggestSmartRepliesResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.SuggestSmartRepliesResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SuggestSmartRepliesResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SuggestSmartRepliesResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.SuggestSmartRepliesResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SuggestSmartRepliesResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.SuggestSmartRepliesResponse";
                        };
    
                        return SuggestSmartRepliesResponse;
                    })();
    
                    v2.AudioInput = (function() {
    
                        /**
                         * Properties of an AudioInput.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IAudioInput
                         * @property {google.cloud.dialogflow.v2.IInputAudioConfig|null} [config] AudioInput config
                         * @property {Uint8Array|null} [audio] AudioInput audio
                         */
    
                        /**
                         * Constructs a new AudioInput.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an AudioInput.
                         * @implements IAudioInput
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IAudioInput=} [properties] Properties to set
                         */
                        function AudioInput(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * AudioInput config.
                         * @member {google.cloud.dialogflow.v2.IInputAudioConfig|null|undefined} config
                         * @memberof google.cloud.dialogflow.v2.AudioInput
                         * @instance
                         */
                        AudioInput.prototype.config = null;
    
                        /**
                         * AudioInput audio.
                         * @member {Uint8Array} audio
                         * @memberof google.cloud.dialogflow.v2.AudioInput
                         * @instance
                         */
                        AudioInput.prototype.audio = $util.newBuffer([]);
    
                        /**
                         * Creates a new AudioInput instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.AudioInput
                         * @static
                         * @param {google.cloud.dialogflow.v2.IAudioInput=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.AudioInput} AudioInput instance
                         */
                        AudioInput.create = function create(properties) {
                            return new AudioInput(properties);
                        };
    
                        /**
                         * Encodes the specified AudioInput message. Does not implicitly {@link google.cloud.dialogflow.v2.AudioInput.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.AudioInput
                         * @static
                         * @param {google.cloud.dialogflow.v2.IAudioInput} message AudioInput message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        AudioInput.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.config != null && Object.hasOwnProperty.call(message, "config"))
                                $root.google.cloud.dialogflow.v2.InputAudioConfig.encode(message.config, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.audio != null && Object.hasOwnProperty.call(message, "audio"))
                                writer.uint32(/* id 2, wireType 2 =*/18).bytes(message.audio);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified AudioInput message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.AudioInput.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.AudioInput
                         * @static
                         * @param {google.cloud.dialogflow.v2.IAudioInput} message AudioInput message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        AudioInput.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an AudioInput message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.AudioInput
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.AudioInput} AudioInput
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        AudioInput.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.AudioInput();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.config = $root.google.cloud.dialogflow.v2.InputAudioConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.audio = reader.bytes();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an AudioInput message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.AudioInput
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.AudioInput} AudioInput
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        AudioInput.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an AudioInput message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.AudioInput
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        AudioInput.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.config != null && message.hasOwnProperty("config")) {
                                var error = $root.google.cloud.dialogflow.v2.InputAudioConfig.verify(message.config);
                                if (error)
                                    return "config." + error;
                            }
                            if (message.audio != null && message.hasOwnProperty("audio"))
                                if (!(message.audio && typeof message.audio.length === "number" || $util.isString(message.audio)))
                                    return "audio: buffer expected";
                            return null;
                        };
    
                        /**
                         * Creates an AudioInput message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.AudioInput
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.AudioInput} AudioInput
                         */
                        AudioInput.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.AudioInput)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.AudioInput();
                            if (object.config != null) {
                                if (typeof object.config !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.AudioInput.config: object expected");
                                message.config = $root.google.cloud.dialogflow.v2.InputAudioConfig.fromObject(object.config);
                            }
                            if (object.audio != null)
                                if (typeof object.audio === "string")
                                    $util.base64.decode(object.audio, message.audio = $util.newBuffer($util.base64.length(object.audio)), 0);
                                else if (object.audio.length >= 0)
                                    message.audio = object.audio;
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an AudioInput message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.AudioInput
                         * @static
                         * @param {google.cloud.dialogflow.v2.AudioInput} message AudioInput
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        AudioInput.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.config = null;
                                if (options.bytes === String)
                                    object.audio = "";
                                else {
                                    object.audio = [];
                                    if (options.bytes !== Array)
                                        object.audio = $util.newBuffer(object.audio);
                                }
                            }
                            if (message.config != null && message.hasOwnProperty("config"))
                                object.config = $root.google.cloud.dialogflow.v2.InputAudioConfig.toObject(message.config, options);
                            if (message.audio != null && message.hasOwnProperty("audio"))
                                object.audio = options.bytes === String ? $util.base64.encode(message.audio, 0, message.audio.length) : options.bytes === Array ? Array.prototype.slice.call(message.audio) : message.audio;
                            return object;
                        };
    
                        /**
                         * Converts this AudioInput to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.AudioInput
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        AudioInput.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for AudioInput
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.AudioInput
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        AudioInput.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.AudioInput";
                        };
    
                        return AudioInput;
                    })();
    
                    v2.OutputAudio = (function() {
    
                        /**
                         * Properties of an OutputAudio.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IOutputAudio
                         * @property {google.cloud.dialogflow.v2.IOutputAudioConfig|null} [config] OutputAudio config
                         * @property {Uint8Array|null} [audio] OutputAudio audio
                         */
    
                        /**
                         * Constructs a new OutputAudio.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an OutputAudio.
                         * @implements IOutputAudio
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IOutputAudio=} [properties] Properties to set
                         */
                        function OutputAudio(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * OutputAudio config.
                         * @member {google.cloud.dialogflow.v2.IOutputAudioConfig|null|undefined} config
                         * @memberof google.cloud.dialogflow.v2.OutputAudio
                         * @instance
                         */
                        OutputAudio.prototype.config = null;
    
                        /**
                         * OutputAudio audio.
                         * @member {Uint8Array} audio
                         * @memberof google.cloud.dialogflow.v2.OutputAudio
                         * @instance
                         */
                        OutputAudio.prototype.audio = $util.newBuffer([]);
    
                        /**
                         * Creates a new OutputAudio instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.OutputAudio
                         * @static
                         * @param {google.cloud.dialogflow.v2.IOutputAudio=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.OutputAudio} OutputAudio instance
                         */
                        OutputAudio.create = function create(properties) {
                            return new OutputAudio(properties);
                        };
    
                        /**
                         * Encodes the specified OutputAudio message. Does not implicitly {@link google.cloud.dialogflow.v2.OutputAudio.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.OutputAudio
                         * @static
                         * @param {google.cloud.dialogflow.v2.IOutputAudio} message OutputAudio message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        OutputAudio.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.config != null && Object.hasOwnProperty.call(message, "config"))
                                $root.google.cloud.dialogflow.v2.OutputAudioConfig.encode(message.config, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.audio != null && Object.hasOwnProperty.call(message, "audio"))
                                writer.uint32(/* id 2, wireType 2 =*/18).bytes(message.audio);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified OutputAudio message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.OutputAudio.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.OutputAudio
                         * @static
                         * @param {google.cloud.dialogflow.v2.IOutputAudio} message OutputAudio message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        OutputAudio.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an OutputAudio message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.OutputAudio
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.OutputAudio} OutputAudio
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        OutputAudio.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.OutputAudio();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.config = $root.google.cloud.dialogflow.v2.OutputAudioConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.audio = reader.bytes();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an OutputAudio message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.OutputAudio
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.OutputAudio} OutputAudio
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        OutputAudio.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an OutputAudio message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.OutputAudio
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        OutputAudio.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.config != null && message.hasOwnProperty("config")) {
                                var error = $root.google.cloud.dialogflow.v2.OutputAudioConfig.verify(message.config);
                                if (error)
                                    return "config." + error;
                            }
                            if (message.audio != null && message.hasOwnProperty("audio"))
                                if (!(message.audio && typeof message.audio.length === "number" || $util.isString(message.audio)))
                                    return "audio: buffer expected";
                            return null;
                        };
    
                        /**
                         * Creates an OutputAudio message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.OutputAudio
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.OutputAudio} OutputAudio
                         */
                        OutputAudio.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.OutputAudio)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.OutputAudio();
                            if (object.config != null) {
                                if (typeof object.config !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.OutputAudio.config: object expected");
                                message.config = $root.google.cloud.dialogflow.v2.OutputAudioConfig.fromObject(object.config);
                            }
                            if (object.audio != null)
                                if (typeof object.audio === "string")
                                    $util.base64.decode(object.audio, message.audio = $util.newBuffer($util.base64.length(object.audio)), 0);
                                else if (object.audio.length >= 0)
                                    message.audio = object.audio;
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an OutputAudio message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.OutputAudio
                         * @static
                         * @param {google.cloud.dialogflow.v2.OutputAudio} message OutputAudio
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        OutputAudio.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.config = null;
                                if (options.bytes === String)
                                    object.audio = "";
                                else {
                                    object.audio = [];
                                    if (options.bytes !== Array)
                                        object.audio = $util.newBuffer(object.audio);
                                }
                            }
                            if (message.config != null && message.hasOwnProperty("config"))
                                object.config = $root.google.cloud.dialogflow.v2.OutputAudioConfig.toObject(message.config, options);
                            if (message.audio != null && message.hasOwnProperty("audio"))
                                object.audio = options.bytes === String ? $util.base64.encode(message.audio, 0, message.audio.length) : options.bytes === Array ? Array.prototype.slice.call(message.audio) : message.audio;
                            return object;
                        };
    
                        /**
                         * Converts this OutputAudio to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.OutputAudio
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        OutputAudio.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for OutputAudio
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.OutputAudio
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        OutputAudio.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.OutputAudio";
                        };
    
                        return OutputAudio;
                    })();
    
                    v2.AutomatedAgentReply = (function() {
    
                        /**
                         * Properties of an AutomatedAgentReply.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IAutomatedAgentReply
                         * @property {google.cloud.dialogflow.v2.IDetectIntentResponse|null} [detectIntentResponse] AutomatedAgentReply detectIntentResponse
                         * @property {google.cloud.dialogflow.v2.AutomatedAgentReply.AutomatedAgentReplyType|null} [automatedAgentReplyType] AutomatedAgentReply automatedAgentReplyType
                         * @property {boolean|null} [allowCancellation] AutomatedAgentReply allowCancellation
                         * @property {string|null} [cxCurrentPage] AutomatedAgentReply cxCurrentPage
                         */
    
                        /**
                         * Constructs a new AutomatedAgentReply.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an AutomatedAgentReply.
                         * @implements IAutomatedAgentReply
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IAutomatedAgentReply=} [properties] Properties to set
                         */
                        function AutomatedAgentReply(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * AutomatedAgentReply detectIntentResponse.
                         * @member {google.cloud.dialogflow.v2.IDetectIntentResponse|null|undefined} detectIntentResponse
                         * @memberof google.cloud.dialogflow.v2.AutomatedAgentReply
                         * @instance
                         */
                        AutomatedAgentReply.prototype.detectIntentResponse = null;
    
                        /**
                         * AutomatedAgentReply automatedAgentReplyType.
                         * @member {google.cloud.dialogflow.v2.AutomatedAgentReply.AutomatedAgentReplyType} automatedAgentReplyType
                         * @memberof google.cloud.dialogflow.v2.AutomatedAgentReply
                         * @instance
                         */
                        AutomatedAgentReply.prototype.automatedAgentReplyType = 0;
    
                        /**
                         * AutomatedAgentReply allowCancellation.
                         * @member {boolean} allowCancellation
                         * @memberof google.cloud.dialogflow.v2.AutomatedAgentReply
                         * @instance
                         */
                        AutomatedAgentReply.prototype.allowCancellation = false;
    
                        /**
                         * AutomatedAgentReply cxCurrentPage.
                         * @member {string} cxCurrentPage
                         * @memberof google.cloud.dialogflow.v2.AutomatedAgentReply
                         * @instance
                         */
                        AutomatedAgentReply.prototype.cxCurrentPage = "";
    
                        /**
                         * Creates a new AutomatedAgentReply instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.AutomatedAgentReply
                         * @static
                         * @param {google.cloud.dialogflow.v2.IAutomatedAgentReply=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.AutomatedAgentReply} AutomatedAgentReply instance
                         */
                        AutomatedAgentReply.create = function create(properties) {
                            return new AutomatedAgentReply(properties);
                        };
    
                        /**
                         * Encodes the specified AutomatedAgentReply message. Does not implicitly {@link google.cloud.dialogflow.v2.AutomatedAgentReply.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.AutomatedAgentReply
                         * @static
                         * @param {google.cloud.dialogflow.v2.IAutomatedAgentReply} message AutomatedAgentReply message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        AutomatedAgentReply.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.detectIntentResponse != null && Object.hasOwnProperty.call(message, "detectIntentResponse"))
                                $root.google.cloud.dialogflow.v2.DetectIntentResponse.encode(message.detectIntentResponse, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.automatedAgentReplyType != null && Object.hasOwnProperty.call(message, "automatedAgentReplyType"))
                                writer.uint32(/* id 7, wireType 0 =*/56).int32(message.automatedAgentReplyType);
                            if (message.allowCancellation != null && Object.hasOwnProperty.call(message, "allowCancellation"))
                                writer.uint32(/* id 8, wireType 0 =*/64).bool(message.allowCancellation);
                            if (message.cxCurrentPage != null && Object.hasOwnProperty.call(message, "cxCurrentPage"))
                                writer.uint32(/* id 11, wireType 2 =*/90).string(message.cxCurrentPage);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified AutomatedAgentReply message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.AutomatedAgentReply.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.AutomatedAgentReply
                         * @static
                         * @param {google.cloud.dialogflow.v2.IAutomatedAgentReply} message AutomatedAgentReply message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        AutomatedAgentReply.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an AutomatedAgentReply message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.AutomatedAgentReply
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.AutomatedAgentReply} AutomatedAgentReply
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        AutomatedAgentReply.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.AutomatedAgentReply();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.detectIntentResponse = $root.google.cloud.dialogflow.v2.DetectIntentResponse.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 7: {
                                        message.automatedAgentReplyType = reader.int32();
                                        break;
                                    }
                                case 8: {
                                        message.allowCancellation = reader.bool();
                                        break;
                                    }
                                case 11: {
                                        message.cxCurrentPage = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an AutomatedAgentReply message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.AutomatedAgentReply
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.AutomatedAgentReply} AutomatedAgentReply
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        AutomatedAgentReply.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an AutomatedAgentReply message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.AutomatedAgentReply
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        AutomatedAgentReply.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.detectIntentResponse != null && message.hasOwnProperty("detectIntentResponse")) {
                                var error = $root.google.cloud.dialogflow.v2.DetectIntentResponse.verify(message.detectIntentResponse);
                                if (error)
                                    return "detectIntentResponse." + error;
                            }
                            if (message.automatedAgentReplyType != null && message.hasOwnProperty("automatedAgentReplyType"))
                                switch (message.automatedAgentReplyType) {
                                default:
                                    return "automatedAgentReplyType: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                    break;
                                }
                            if (message.allowCancellation != null && message.hasOwnProperty("allowCancellation"))
                                if (typeof message.allowCancellation !== "boolean")
                                    return "allowCancellation: boolean expected";
                            if (message.cxCurrentPage != null && message.hasOwnProperty("cxCurrentPage"))
                                if (!$util.isString(message.cxCurrentPage))
                                    return "cxCurrentPage: string expected";
                            return null;
                        };
    
                        /**
                         * Creates an AutomatedAgentReply message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.AutomatedAgentReply
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.AutomatedAgentReply} AutomatedAgentReply
                         */
                        AutomatedAgentReply.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.AutomatedAgentReply)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.AutomatedAgentReply();
                            if (object.detectIntentResponse != null) {
                                if (typeof object.detectIntentResponse !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.AutomatedAgentReply.detectIntentResponse: object expected");
                                message.detectIntentResponse = $root.google.cloud.dialogflow.v2.DetectIntentResponse.fromObject(object.detectIntentResponse);
                            }
                            switch (object.automatedAgentReplyType) {
                            default:
                                if (typeof object.automatedAgentReplyType === "number") {
                                    message.automatedAgentReplyType = object.automatedAgentReplyType;
                                    break;
                                }
                                break;
                            case "AUTOMATED_AGENT_REPLY_TYPE_UNSPECIFIED":
                            case 0:
                                message.automatedAgentReplyType = 0;
                                break;
                            case "PARTIAL":
                            case 1:
                                message.automatedAgentReplyType = 1;
                                break;
                            case "FINAL":
                            case 2:
                                message.automatedAgentReplyType = 2;
                                break;
                            }
                            if (object.allowCancellation != null)
                                message.allowCancellation = Boolean(object.allowCancellation);
                            if (object.cxCurrentPage != null)
                                message.cxCurrentPage = String(object.cxCurrentPage);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an AutomatedAgentReply message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.AutomatedAgentReply
                         * @static
                         * @param {google.cloud.dialogflow.v2.AutomatedAgentReply} message AutomatedAgentReply
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        AutomatedAgentReply.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.detectIntentResponse = null;
                                object.automatedAgentReplyType = options.enums === String ? "AUTOMATED_AGENT_REPLY_TYPE_UNSPECIFIED" : 0;
                                object.allowCancellation = false;
                                object.cxCurrentPage = "";
                            }
                            if (message.detectIntentResponse != null && message.hasOwnProperty("detectIntentResponse"))
                                object.detectIntentResponse = $root.google.cloud.dialogflow.v2.DetectIntentResponse.toObject(message.detectIntentResponse, options);
                            if (message.automatedAgentReplyType != null && message.hasOwnProperty("automatedAgentReplyType"))
                                object.automatedAgentReplyType = options.enums === String ? $root.google.cloud.dialogflow.v2.AutomatedAgentReply.AutomatedAgentReplyType[message.automatedAgentReplyType] === undefined ? message.automatedAgentReplyType : $root.google.cloud.dialogflow.v2.AutomatedAgentReply.AutomatedAgentReplyType[message.automatedAgentReplyType] : message.automatedAgentReplyType;
                            if (message.allowCancellation != null && message.hasOwnProperty("allowCancellation"))
                                object.allowCancellation = message.allowCancellation;
                            if (message.cxCurrentPage != null && message.hasOwnProperty("cxCurrentPage"))
                                object.cxCurrentPage = message.cxCurrentPage;
                            return object;
                        };
    
                        /**
                         * Converts this AutomatedAgentReply to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.AutomatedAgentReply
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        AutomatedAgentReply.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for AutomatedAgentReply
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.AutomatedAgentReply
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        AutomatedAgentReply.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.AutomatedAgentReply";
                        };
    
                        /**
                         * AutomatedAgentReplyType enum.
                         * @name google.cloud.dialogflow.v2.AutomatedAgentReply.AutomatedAgentReplyType
                         * @enum {number}
                         * @property {number} AUTOMATED_AGENT_REPLY_TYPE_UNSPECIFIED=0 AUTOMATED_AGENT_REPLY_TYPE_UNSPECIFIED value
                         * @property {number} PARTIAL=1 PARTIAL value
                         * @property {number} FINAL=2 FINAL value
                         */
                        AutomatedAgentReply.AutomatedAgentReplyType = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "AUTOMATED_AGENT_REPLY_TYPE_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "PARTIAL"] = 1;
                            values[valuesById[2] = "FINAL"] = 2;
                            return values;
                        })();
    
                        return AutomatedAgentReply;
                    })();
    
                    v2.ArticleAnswer = (function() {
    
                        /**
                         * Properties of an ArticleAnswer.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IArticleAnswer
                         * @property {string|null} [title] ArticleAnswer title
                         * @property {string|null} [uri] ArticleAnswer uri
                         * @property {Array.<string>|null} [snippets] ArticleAnswer snippets
                         * @property {number|null} [confidence] ArticleAnswer confidence
                         * @property {Object.<string,string>|null} [metadata] ArticleAnswer metadata
                         * @property {string|null} [answerRecord] ArticleAnswer answerRecord
                         */
    
                        /**
                         * Constructs a new ArticleAnswer.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an ArticleAnswer.
                         * @implements IArticleAnswer
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IArticleAnswer=} [properties] Properties to set
                         */
                        function ArticleAnswer(properties) {
                            this.snippets = [];
                            this.metadata = {};
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ArticleAnswer title.
                         * @member {string} title
                         * @memberof google.cloud.dialogflow.v2.ArticleAnswer
                         * @instance
                         */
                        ArticleAnswer.prototype.title = "";
    
                        /**
                         * ArticleAnswer uri.
                         * @member {string} uri
                         * @memberof google.cloud.dialogflow.v2.ArticleAnswer
                         * @instance
                         */
                        ArticleAnswer.prototype.uri = "";
    
                        /**
                         * ArticleAnswer snippets.
                         * @member {Array.<string>} snippets
                         * @memberof google.cloud.dialogflow.v2.ArticleAnswer
                         * @instance
                         */
                        ArticleAnswer.prototype.snippets = $util.emptyArray;
    
                        /**
                         * ArticleAnswer confidence.
                         * @member {number} confidence
                         * @memberof google.cloud.dialogflow.v2.ArticleAnswer
                         * @instance
                         */
                        ArticleAnswer.prototype.confidence = 0;
    
                        /**
                         * ArticleAnswer metadata.
                         * @member {Object.<string,string>} metadata
                         * @memberof google.cloud.dialogflow.v2.ArticleAnswer
                         * @instance
                         */
                        ArticleAnswer.prototype.metadata = $util.emptyObject;
    
                        /**
                         * ArticleAnswer answerRecord.
                         * @member {string} answerRecord
                         * @memberof google.cloud.dialogflow.v2.ArticleAnswer
                         * @instance
                         */
                        ArticleAnswer.prototype.answerRecord = "";
    
                        /**
                         * Creates a new ArticleAnswer instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ArticleAnswer
                         * @static
                         * @param {google.cloud.dialogflow.v2.IArticleAnswer=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ArticleAnswer} ArticleAnswer instance
                         */
                        ArticleAnswer.create = function create(properties) {
                            return new ArticleAnswer(properties);
                        };
    
                        /**
                         * Encodes the specified ArticleAnswer message. Does not implicitly {@link google.cloud.dialogflow.v2.ArticleAnswer.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ArticleAnswer
                         * @static
                         * @param {google.cloud.dialogflow.v2.IArticleAnswer} message ArticleAnswer message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ArticleAnswer.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.title != null && Object.hasOwnProperty.call(message, "title"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.title);
                            if (message.uri != null && Object.hasOwnProperty.call(message, "uri"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.uri);
                            if (message.snippets != null && message.snippets.length)
                                for (var i = 0; i < message.snippets.length; ++i)
                                    writer.uint32(/* id 3, wireType 2 =*/26).string(message.snippets[i]);
                            if (message.confidence != null && Object.hasOwnProperty.call(message, "confidence"))
                                writer.uint32(/* id 4, wireType 5 =*/37).float(message.confidence);
                            if (message.metadata != null && Object.hasOwnProperty.call(message, "metadata"))
                                for (var keys = Object.keys(message.metadata), i = 0; i < keys.length; ++i)
                                    writer.uint32(/* id 5, wireType 2 =*/42).fork().uint32(/* id 1, wireType 2 =*/10).string(keys[i]).uint32(/* id 2, wireType 2 =*/18).string(message.metadata[keys[i]]).ldelim();
                            if (message.answerRecord != null && Object.hasOwnProperty.call(message, "answerRecord"))
                                writer.uint32(/* id 6, wireType 2 =*/50).string(message.answerRecord);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ArticleAnswer message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ArticleAnswer.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ArticleAnswer
                         * @static
                         * @param {google.cloud.dialogflow.v2.IArticleAnswer} message ArticleAnswer message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ArticleAnswer.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an ArticleAnswer message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ArticleAnswer
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ArticleAnswer} ArticleAnswer
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ArticleAnswer.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ArticleAnswer(), key, value;
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.title = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.uri = reader.string();
                                        break;
                                    }
                                case 3: {
                                        if (!(message.snippets && message.snippets.length))
                                            message.snippets = [];
                                        message.snippets.push(reader.string());
                                        break;
                                    }
                                case 4: {
                                        message.confidence = reader.float();
                                        break;
                                    }
                                case 5: {
                                        if (message.metadata === $util.emptyObject)
                                            message.metadata = {};
                                        var end2 = reader.uint32() + reader.pos;
                                        key = "";
                                        value = "";
                                        while (reader.pos < end2) {
                                            var tag2 = reader.uint32();
                                            switch (tag2 >>> 3) {
                                            case 1:
                                                key = reader.string();
                                                break;
                                            case 2:
                                                value = reader.string();
                                                break;
                                            default:
                                                reader.skipType(tag2 & 7);
                                                break;
                                            }
                                        }
                                        message.metadata[key] = value;
                                        break;
                                    }
                                case 6: {
                                        message.answerRecord = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an ArticleAnswer message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ArticleAnswer
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ArticleAnswer} ArticleAnswer
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ArticleAnswer.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an ArticleAnswer message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ArticleAnswer
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ArticleAnswer.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.title != null && message.hasOwnProperty("title"))
                                if (!$util.isString(message.title))
                                    return "title: string expected";
                            if (message.uri != null && message.hasOwnProperty("uri"))
                                if (!$util.isString(message.uri))
                                    return "uri: string expected";
                            if (message.snippets != null && message.hasOwnProperty("snippets")) {
                                if (!Array.isArray(message.snippets))
                                    return "snippets: array expected";
                                for (var i = 0; i < message.snippets.length; ++i)
                                    if (!$util.isString(message.snippets[i]))
                                        return "snippets: string[] expected";
                            }
                            if (message.confidence != null && message.hasOwnProperty("confidence"))
                                if (typeof message.confidence !== "number")
                                    return "confidence: number expected";
                            if (message.metadata != null && message.hasOwnProperty("metadata")) {
                                if (!$util.isObject(message.metadata))
                                    return "metadata: object expected";
                                var key = Object.keys(message.metadata);
                                for (var i = 0; i < key.length; ++i)
                                    if (!$util.isString(message.metadata[key[i]]))
                                        return "metadata: string{k:string} expected";
                            }
                            if (message.answerRecord != null && message.hasOwnProperty("answerRecord"))
                                if (!$util.isString(message.answerRecord))
                                    return "answerRecord: string expected";
                            return null;
                        };
    
                        /**
                         * Creates an ArticleAnswer message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ArticleAnswer
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ArticleAnswer} ArticleAnswer
                         */
                        ArticleAnswer.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ArticleAnswer)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ArticleAnswer();
                            if (object.title != null)
                                message.title = String(object.title);
                            if (object.uri != null)
                                message.uri = String(object.uri);
                            if (object.snippets) {
                                if (!Array.isArray(object.snippets))
                                    throw TypeError(".google.cloud.dialogflow.v2.ArticleAnswer.snippets: array expected");
                                message.snippets = [];
                                for (var i = 0; i < object.snippets.length; ++i)
                                    message.snippets[i] = String(object.snippets[i]);
                            }
                            if (object.confidence != null)
                                message.confidence = Number(object.confidence);
                            if (object.metadata) {
                                if (typeof object.metadata !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.ArticleAnswer.metadata: object expected");
                                message.metadata = {};
                                for (var keys = Object.keys(object.metadata), i = 0; i < keys.length; ++i)
                                    message.metadata[keys[i]] = String(object.metadata[keys[i]]);
                            }
                            if (object.answerRecord != null)
                                message.answerRecord = String(object.answerRecord);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an ArticleAnswer message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ArticleAnswer
                         * @static
                         * @param {google.cloud.dialogflow.v2.ArticleAnswer} message ArticleAnswer
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ArticleAnswer.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.snippets = [];
                            if (options.objects || options.defaults)
                                object.metadata = {};
                            if (options.defaults) {
                                object.title = "";
                                object.uri = "";
                                object.confidence = 0;
                                object.answerRecord = "";
                            }
                            if (message.title != null && message.hasOwnProperty("title"))
                                object.title = message.title;
                            if (message.uri != null && message.hasOwnProperty("uri"))
                                object.uri = message.uri;
                            if (message.snippets && message.snippets.length) {
                                object.snippets = [];
                                for (var j = 0; j < message.snippets.length; ++j)
                                    object.snippets[j] = message.snippets[j];
                            }
                            if (message.confidence != null && message.hasOwnProperty("confidence"))
                                object.confidence = options.json && !isFinite(message.confidence) ? String(message.confidence) : message.confidence;
                            var keys2;
                            if (message.metadata && (keys2 = Object.keys(message.metadata)).length) {
                                object.metadata = {};
                                for (var j = 0; j < keys2.length; ++j)
                                    object.metadata[keys2[j]] = message.metadata[keys2[j]];
                            }
                            if (message.answerRecord != null && message.hasOwnProperty("answerRecord"))
                                object.answerRecord = message.answerRecord;
                            return object;
                        };
    
                        /**
                         * Converts this ArticleAnswer to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ArticleAnswer
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ArticleAnswer.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ArticleAnswer
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ArticleAnswer
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ArticleAnswer.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ArticleAnswer";
                        };
    
                        return ArticleAnswer;
                    })();
    
                    v2.FaqAnswer = (function() {
    
                        /**
                         * Properties of a FaqAnswer.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IFaqAnswer
                         * @property {string|null} [answer] FaqAnswer answer
                         * @property {number|null} [confidence] FaqAnswer confidence
                         * @property {string|null} [question] FaqAnswer question
                         * @property {string|null} [source] FaqAnswer source
                         * @property {Object.<string,string>|null} [metadata] FaqAnswer metadata
                         * @property {string|null} [answerRecord] FaqAnswer answerRecord
                         */
    
                        /**
                         * Constructs a new FaqAnswer.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a FaqAnswer.
                         * @implements IFaqAnswer
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IFaqAnswer=} [properties] Properties to set
                         */
                        function FaqAnswer(properties) {
                            this.metadata = {};
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * FaqAnswer answer.
                         * @member {string} answer
                         * @memberof google.cloud.dialogflow.v2.FaqAnswer
                         * @instance
                         */
                        FaqAnswer.prototype.answer = "";
    
                        /**
                         * FaqAnswer confidence.
                         * @member {number} confidence
                         * @memberof google.cloud.dialogflow.v2.FaqAnswer
                         * @instance
                         */
                        FaqAnswer.prototype.confidence = 0;
    
                        /**
                         * FaqAnswer question.
                         * @member {string} question
                         * @memberof google.cloud.dialogflow.v2.FaqAnswer
                         * @instance
                         */
                        FaqAnswer.prototype.question = "";
    
                        /**
                         * FaqAnswer source.
                         * @member {string} source
                         * @memberof google.cloud.dialogflow.v2.FaqAnswer
                         * @instance
                         */
                        FaqAnswer.prototype.source = "";
    
                        /**
                         * FaqAnswer metadata.
                         * @member {Object.<string,string>} metadata
                         * @memberof google.cloud.dialogflow.v2.FaqAnswer
                         * @instance
                         */
                        FaqAnswer.prototype.metadata = $util.emptyObject;
    
                        /**
                         * FaqAnswer answerRecord.
                         * @member {string} answerRecord
                         * @memberof google.cloud.dialogflow.v2.FaqAnswer
                         * @instance
                         */
                        FaqAnswer.prototype.answerRecord = "";
    
                        /**
                         * Creates a new FaqAnswer instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.FaqAnswer
                         * @static
                         * @param {google.cloud.dialogflow.v2.IFaqAnswer=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.FaqAnswer} FaqAnswer instance
                         */
                        FaqAnswer.create = function create(properties) {
                            return new FaqAnswer(properties);
                        };
    
                        /**
                         * Encodes the specified FaqAnswer message. Does not implicitly {@link google.cloud.dialogflow.v2.FaqAnswer.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.FaqAnswer
                         * @static
                         * @param {google.cloud.dialogflow.v2.IFaqAnswer} message FaqAnswer message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        FaqAnswer.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.answer != null && Object.hasOwnProperty.call(message, "answer"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.answer);
                            if (message.confidence != null && Object.hasOwnProperty.call(message, "confidence"))
                                writer.uint32(/* id 2, wireType 5 =*/21).float(message.confidence);
                            if (message.question != null && Object.hasOwnProperty.call(message, "question"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.question);
                            if (message.source != null && Object.hasOwnProperty.call(message, "source"))
                                writer.uint32(/* id 4, wireType 2 =*/34).string(message.source);
                            if (message.metadata != null && Object.hasOwnProperty.call(message, "metadata"))
                                for (var keys = Object.keys(message.metadata), i = 0; i < keys.length; ++i)
                                    writer.uint32(/* id 5, wireType 2 =*/42).fork().uint32(/* id 1, wireType 2 =*/10).string(keys[i]).uint32(/* id 2, wireType 2 =*/18).string(message.metadata[keys[i]]).ldelim();
                            if (message.answerRecord != null && Object.hasOwnProperty.call(message, "answerRecord"))
                                writer.uint32(/* id 6, wireType 2 =*/50).string(message.answerRecord);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified FaqAnswer message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.FaqAnswer.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.FaqAnswer
                         * @static
                         * @param {google.cloud.dialogflow.v2.IFaqAnswer} message FaqAnswer message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        FaqAnswer.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a FaqAnswer message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.FaqAnswer
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.FaqAnswer} FaqAnswer
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        FaqAnswer.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.FaqAnswer(), key, value;
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.answer = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.confidence = reader.float();
                                        break;
                                    }
                                case 3: {
                                        message.question = reader.string();
                                        break;
                                    }
                                case 4: {
                                        message.source = reader.string();
                                        break;
                                    }
                                case 5: {
                                        if (message.metadata === $util.emptyObject)
                                            message.metadata = {};
                                        var end2 = reader.uint32() + reader.pos;
                                        key = "";
                                        value = "";
                                        while (reader.pos < end2) {
                                            var tag2 = reader.uint32();
                                            switch (tag2 >>> 3) {
                                            case 1:
                                                key = reader.string();
                                                break;
                                            case 2:
                                                value = reader.string();
                                                break;
                                            default:
                                                reader.skipType(tag2 & 7);
                                                break;
                                            }
                                        }
                                        message.metadata[key] = value;
                                        break;
                                    }
                                case 6: {
                                        message.answerRecord = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a FaqAnswer message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.FaqAnswer
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.FaqAnswer} FaqAnswer
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        FaqAnswer.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a FaqAnswer message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.FaqAnswer
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        FaqAnswer.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.answer != null && message.hasOwnProperty("answer"))
                                if (!$util.isString(message.answer))
                                    return "answer: string expected";
                            if (message.confidence != null && message.hasOwnProperty("confidence"))
                                if (typeof message.confidence !== "number")
                                    return "confidence: number expected";
                            if (message.question != null && message.hasOwnProperty("question"))
                                if (!$util.isString(message.question))
                                    return "question: string expected";
                            if (message.source != null && message.hasOwnProperty("source"))
                                if (!$util.isString(message.source))
                                    return "source: string expected";
                            if (message.metadata != null && message.hasOwnProperty("metadata")) {
                                if (!$util.isObject(message.metadata))
                                    return "metadata: object expected";
                                var key = Object.keys(message.metadata);
                                for (var i = 0; i < key.length; ++i)
                                    if (!$util.isString(message.metadata[key[i]]))
                                        return "metadata: string{k:string} expected";
                            }
                            if (message.answerRecord != null && message.hasOwnProperty("answerRecord"))
                                if (!$util.isString(message.answerRecord))
                                    return "answerRecord: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a FaqAnswer message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.FaqAnswer
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.FaqAnswer} FaqAnswer
                         */
                        FaqAnswer.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.FaqAnswer)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.FaqAnswer();
                            if (object.answer != null)
                                message.answer = String(object.answer);
                            if (object.confidence != null)
                                message.confidence = Number(object.confidence);
                            if (object.question != null)
                                message.question = String(object.question);
                            if (object.source != null)
                                message.source = String(object.source);
                            if (object.metadata) {
                                if (typeof object.metadata !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.FaqAnswer.metadata: object expected");
                                message.metadata = {};
                                for (var keys = Object.keys(object.metadata), i = 0; i < keys.length; ++i)
                                    message.metadata[keys[i]] = String(object.metadata[keys[i]]);
                            }
                            if (object.answerRecord != null)
                                message.answerRecord = String(object.answerRecord);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a FaqAnswer message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.FaqAnswer
                         * @static
                         * @param {google.cloud.dialogflow.v2.FaqAnswer} message FaqAnswer
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        FaqAnswer.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.objects || options.defaults)
                                object.metadata = {};
                            if (options.defaults) {
                                object.answer = "";
                                object.confidence = 0;
                                object.question = "";
                                object.source = "";
                                object.answerRecord = "";
                            }
                            if (message.answer != null && message.hasOwnProperty("answer"))
                                object.answer = message.answer;
                            if (message.confidence != null && message.hasOwnProperty("confidence"))
                                object.confidence = options.json && !isFinite(message.confidence) ? String(message.confidence) : message.confidence;
                            if (message.question != null && message.hasOwnProperty("question"))
                                object.question = message.question;
                            if (message.source != null && message.hasOwnProperty("source"))
                                object.source = message.source;
                            var keys2;
                            if (message.metadata && (keys2 = Object.keys(message.metadata)).length) {
                                object.metadata = {};
                                for (var j = 0; j < keys2.length; ++j)
                                    object.metadata[keys2[j]] = message.metadata[keys2[j]];
                            }
                            if (message.answerRecord != null && message.hasOwnProperty("answerRecord"))
                                object.answerRecord = message.answerRecord;
                            return object;
                        };
    
                        /**
                         * Converts this FaqAnswer to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.FaqAnswer
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        FaqAnswer.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for FaqAnswer
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.FaqAnswer
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        FaqAnswer.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.FaqAnswer";
                        };
    
                        return FaqAnswer;
                    })();
    
                    v2.SmartReplyAnswer = (function() {
    
                        /**
                         * Properties of a SmartReplyAnswer.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ISmartReplyAnswer
                         * @property {string|null} [reply] SmartReplyAnswer reply
                         * @property {number|null} [confidence] SmartReplyAnswer confidence
                         * @property {string|null} [answerRecord] SmartReplyAnswer answerRecord
                         */
    
                        /**
                         * Constructs a new SmartReplyAnswer.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a SmartReplyAnswer.
                         * @implements ISmartReplyAnswer
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ISmartReplyAnswer=} [properties] Properties to set
                         */
                        function SmartReplyAnswer(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SmartReplyAnswer reply.
                         * @member {string} reply
                         * @memberof google.cloud.dialogflow.v2.SmartReplyAnswer
                         * @instance
                         */
                        SmartReplyAnswer.prototype.reply = "";
    
                        /**
                         * SmartReplyAnswer confidence.
                         * @member {number} confidence
                         * @memberof google.cloud.dialogflow.v2.SmartReplyAnswer
                         * @instance
                         */
                        SmartReplyAnswer.prototype.confidence = 0;
    
                        /**
                         * SmartReplyAnswer answerRecord.
                         * @member {string} answerRecord
                         * @memberof google.cloud.dialogflow.v2.SmartReplyAnswer
                         * @instance
                         */
                        SmartReplyAnswer.prototype.answerRecord = "";
    
                        /**
                         * Creates a new SmartReplyAnswer instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.SmartReplyAnswer
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISmartReplyAnswer=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.SmartReplyAnswer} SmartReplyAnswer instance
                         */
                        SmartReplyAnswer.create = function create(properties) {
                            return new SmartReplyAnswer(properties);
                        };
    
                        /**
                         * Encodes the specified SmartReplyAnswer message. Does not implicitly {@link google.cloud.dialogflow.v2.SmartReplyAnswer.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.SmartReplyAnswer
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISmartReplyAnswer} message SmartReplyAnswer message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SmartReplyAnswer.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.reply != null && Object.hasOwnProperty.call(message, "reply"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.reply);
                            if (message.confidence != null && Object.hasOwnProperty.call(message, "confidence"))
                                writer.uint32(/* id 2, wireType 5 =*/21).float(message.confidence);
                            if (message.answerRecord != null && Object.hasOwnProperty.call(message, "answerRecord"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.answerRecord);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SmartReplyAnswer message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.SmartReplyAnswer.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SmartReplyAnswer
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISmartReplyAnswer} message SmartReplyAnswer message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SmartReplyAnswer.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SmartReplyAnswer message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.SmartReplyAnswer
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.SmartReplyAnswer} SmartReplyAnswer
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SmartReplyAnswer.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.SmartReplyAnswer();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.reply = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.confidence = reader.float();
                                        break;
                                    }
                                case 3: {
                                        message.answerRecord = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SmartReplyAnswer message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SmartReplyAnswer
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.SmartReplyAnswer} SmartReplyAnswer
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SmartReplyAnswer.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SmartReplyAnswer message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.SmartReplyAnswer
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SmartReplyAnswer.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.reply != null && message.hasOwnProperty("reply"))
                                if (!$util.isString(message.reply))
                                    return "reply: string expected";
                            if (message.confidence != null && message.hasOwnProperty("confidence"))
                                if (typeof message.confidence !== "number")
                                    return "confidence: number expected";
                            if (message.answerRecord != null && message.hasOwnProperty("answerRecord"))
                                if (!$util.isString(message.answerRecord))
                                    return "answerRecord: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a SmartReplyAnswer message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.SmartReplyAnswer
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.SmartReplyAnswer} SmartReplyAnswer
                         */
                        SmartReplyAnswer.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.SmartReplyAnswer)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.SmartReplyAnswer();
                            if (object.reply != null)
                                message.reply = String(object.reply);
                            if (object.confidence != null)
                                message.confidence = Number(object.confidence);
                            if (object.answerRecord != null)
                                message.answerRecord = String(object.answerRecord);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SmartReplyAnswer message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.SmartReplyAnswer
                         * @static
                         * @param {google.cloud.dialogflow.v2.SmartReplyAnswer} message SmartReplyAnswer
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SmartReplyAnswer.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.reply = "";
                                object.confidence = 0;
                                object.answerRecord = "";
                            }
                            if (message.reply != null && message.hasOwnProperty("reply"))
                                object.reply = message.reply;
                            if (message.confidence != null && message.hasOwnProperty("confidence"))
                                object.confidence = options.json && !isFinite(message.confidence) ? String(message.confidence) : message.confidence;
                            if (message.answerRecord != null && message.hasOwnProperty("answerRecord"))
                                object.answerRecord = message.answerRecord;
                            return object;
                        };
    
                        /**
                         * Converts this SmartReplyAnswer to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.SmartReplyAnswer
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SmartReplyAnswer.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SmartReplyAnswer
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.SmartReplyAnswer
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SmartReplyAnswer.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.SmartReplyAnswer";
                        };
    
                        return SmartReplyAnswer;
                    })();
    
                    v2.IntentSuggestion = (function() {
    
                        /**
                         * Properties of an IntentSuggestion.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IIntentSuggestion
                         * @property {string|null} [displayName] IntentSuggestion displayName
                         * @property {string|null} [intentV2] IntentSuggestion intentV2
                         * @property {string|null} [description] IntentSuggestion description
                         */
    
                        /**
                         * Constructs a new IntentSuggestion.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an IntentSuggestion.
                         * @implements IIntentSuggestion
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IIntentSuggestion=} [properties] Properties to set
                         */
                        function IntentSuggestion(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * IntentSuggestion displayName.
                         * @member {string} displayName
                         * @memberof google.cloud.dialogflow.v2.IntentSuggestion
                         * @instance
                         */
                        IntentSuggestion.prototype.displayName = "";
    
                        /**
                         * IntentSuggestion intentV2.
                         * @member {string|null|undefined} intentV2
                         * @memberof google.cloud.dialogflow.v2.IntentSuggestion
                         * @instance
                         */
                        IntentSuggestion.prototype.intentV2 = null;
    
                        /**
                         * IntentSuggestion description.
                         * @member {string} description
                         * @memberof google.cloud.dialogflow.v2.IntentSuggestion
                         * @instance
                         */
                        IntentSuggestion.prototype.description = "";
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * IntentSuggestion intent.
                         * @member {"intentV2"|undefined} intent
                         * @memberof google.cloud.dialogflow.v2.IntentSuggestion
                         * @instance
                         */
                        Object.defineProperty(IntentSuggestion.prototype, "intent", {
                            get: $util.oneOfGetter($oneOfFields = ["intentV2"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new IntentSuggestion instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.IntentSuggestion
                         * @static
                         * @param {google.cloud.dialogflow.v2.IIntentSuggestion=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.IntentSuggestion} IntentSuggestion instance
                         */
                        IntentSuggestion.create = function create(properties) {
                            return new IntentSuggestion(properties);
                        };
    
                        /**
                         * Encodes the specified IntentSuggestion message. Does not implicitly {@link google.cloud.dialogflow.v2.IntentSuggestion.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.IntentSuggestion
                         * @static
                         * @param {google.cloud.dialogflow.v2.IIntentSuggestion} message IntentSuggestion message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        IntentSuggestion.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.displayName != null && Object.hasOwnProperty.call(message, "displayName"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.displayName);
                            if (message.intentV2 != null && Object.hasOwnProperty.call(message, "intentV2"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.intentV2);
                            if (message.description != null && Object.hasOwnProperty.call(message, "description"))
                                writer.uint32(/* id 5, wireType 2 =*/42).string(message.description);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified IntentSuggestion message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.IntentSuggestion.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.IntentSuggestion
                         * @static
                         * @param {google.cloud.dialogflow.v2.IIntentSuggestion} message IntentSuggestion message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        IntentSuggestion.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an IntentSuggestion message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.IntentSuggestion
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.IntentSuggestion} IntentSuggestion
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        IntentSuggestion.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.IntentSuggestion();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.displayName = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.intentV2 = reader.string();
                                        break;
                                    }
                                case 5: {
                                        message.description = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an IntentSuggestion message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.IntentSuggestion
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.IntentSuggestion} IntentSuggestion
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        IntentSuggestion.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an IntentSuggestion message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.IntentSuggestion
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        IntentSuggestion.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.displayName != null && message.hasOwnProperty("displayName"))
                                if (!$util.isString(message.displayName))
                                    return "displayName: string expected";
                            if (message.intentV2 != null && message.hasOwnProperty("intentV2")) {
                                properties.intent = 1;
                                if (!$util.isString(message.intentV2))
                                    return "intentV2: string expected";
                            }
                            if (message.description != null && message.hasOwnProperty("description"))
                                if (!$util.isString(message.description))
                                    return "description: string expected";
                            return null;
                        };
    
                        /**
                         * Creates an IntentSuggestion message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.IntentSuggestion
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.IntentSuggestion} IntentSuggestion
                         */
                        IntentSuggestion.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.IntentSuggestion)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.IntentSuggestion();
                            if (object.displayName != null)
                                message.displayName = String(object.displayName);
                            if (object.intentV2 != null)
                                message.intentV2 = String(object.intentV2);
                            if (object.description != null)
                                message.description = String(object.description);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an IntentSuggestion message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.IntentSuggestion
                         * @static
                         * @param {google.cloud.dialogflow.v2.IntentSuggestion} message IntentSuggestion
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        IntentSuggestion.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.displayName = "";
                                object.description = "";
                            }
                            if (message.displayName != null && message.hasOwnProperty("displayName"))
                                object.displayName = message.displayName;
                            if (message.intentV2 != null && message.hasOwnProperty("intentV2")) {
                                object.intentV2 = message.intentV2;
                                if (options.oneofs)
                                    object.intent = "intentV2";
                            }
                            if (message.description != null && message.hasOwnProperty("description"))
                                object.description = message.description;
                            return object;
                        };
    
                        /**
                         * Converts this IntentSuggestion to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.IntentSuggestion
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        IntentSuggestion.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for IntentSuggestion
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.IntentSuggestion
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        IntentSuggestion.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.IntentSuggestion";
                        };
    
                        return IntentSuggestion;
                    })();
    
                    v2.DialogflowAssistAnswer = (function() {
    
                        /**
                         * Properties of a DialogflowAssistAnswer.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IDialogflowAssistAnswer
                         * @property {google.cloud.dialogflow.v2.IQueryResult|null} [queryResult] DialogflowAssistAnswer queryResult
                         * @property {google.cloud.dialogflow.v2.IIntentSuggestion|null} [intentSuggestion] DialogflowAssistAnswer intentSuggestion
                         * @property {string|null} [answerRecord] DialogflowAssistAnswer answerRecord
                         */
    
                        /**
                         * Constructs a new DialogflowAssistAnswer.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a DialogflowAssistAnswer.
                         * @implements IDialogflowAssistAnswer
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IDialogflowAssistAnswer=} [properties] Properties to set
                         */
                        function DialogflowAssistAnswer(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * DialogflowAssistAnswer queryResult.
                         * @member {google.cloud.dialogflow.v2.IQueryResult|null|undefined} queryResult
                         * @memberof google.cloud.dialogflow.v2.DialogflowAssistAnswer
                         * @instance
                         */
                        DialogflowAssistAnswer.prototype.queryResult = null;
    
                        /**
                         * DialogflowAssistAnswer intentSuggestion.
                         * @member {google.cloud.dialogflow.v2.IIntentSuggestion|null|undefined} intentSuggestion
                         * @memberof google.cloud.dialogflow.v2.DialogflowAssistAnswer
                         * @instance
                         */
                        DialogflowAssistAnswer.prototype.intentSuggestion = null;
    
                        /**
                         * DialogflowAssistAnswer answerRecord.
                         * @member {string} answerRecord
                         * @memberof google.cloud.dialogflow.v2.DialogflowAssistAnswer
                         * @instance
                         */
                        DialogflowAssistAnswer.prototype.answerRecord = "";
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * DialogflowAssistAnswer result.
                         * @member {"queryResult"|"intentSuggestion"|undefined} result
                         * @memberof google.cloud.dialogflow.v2.DialogflowAssistAnswer
                         * @instance
                         */
                        Object.defineProperty(DialogflowAssistAnswer.prototype, "result", {
                            get: $util.oneOfGetter($oneOfFields = ["queryResult", "intentSuggestion"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new DialogflowAssistAnswer instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.DialogflowAssistAnswer
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDialogflowAssistAnswer=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.DialogflowAssistAnswer} DialogflowAssistAnswer instance
                         */
                        DialogflowAssistAnswer.create = function create(properties) {
                            return new DialogflowAssistAnswer(properties);
                        };
    
                        /**
                         * Encodes the specified DialogflowAssistAnswer message. Does not implicitly {@link google.cloud.dialogflow.v2.DialogflowAssistAnswer.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.DialogflowAssistAnswer
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDialogflowAssistAnswer} message DialogflowAssistAnswer message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DialogflowAssistAnswer.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.queryResult != null && Object.hasOwnProperty.call(message, "queryResult"))
                                $root.google.cloud.dialogflow.v2.QueryResult.encode(message.queryResult, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.answerRecord != null && Object.hasOwnProperty.call(message, "answerRecord"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.answerRecord);
                            if (message.intentSuggestion != null && Object.hasOwnProperty.call(message, "intentSuggestion"))
                                $root.google.cloud.dialogflow.v2.IntentSuggestion.encode(message.intentSuggestion, writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified DialogflowAssistAnswer message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.DialogflowAssistAnswer.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.DialogflowAssistAnswer
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDialogflowAssistAnswer} message DialogflowAssistAnswer message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DialogflowAssistAnswer.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a DialogflowAssistAnswer message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.DialogflowAssistAnswer
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.DialogflowAssistAnswer} DialogflowAssistAnswer
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DialogflowAssistAnswer.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.DialogflowAssistAnswer();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.queryResult = $root.google.cloud.dialogflow.v2.QueryResult.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 5: {
                                        message.intentSuggestion = $root.google.cloud.dialogflow.v2.IntentSuggestion.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.answerRecord = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a DialogflowAssistAnswer message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.DialogflowAssistAnswer
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.DialogflowAssistAnswer} DialogflowAssistAnswer
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DialogflowAssistAnswer.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a DialogflowAssistAnswer message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.DialogflowAssistAnswer
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        DialogflowAssistAnswer.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.queryResult != null && message.hasOwnProperty("queryResult")) {
                                properties.result = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2.QueryResult.verify(message.queryResult);
                                    if (error)
                                        return "queryResult." + error;
                                }
                            }
                            if (message.intentSuggestion != null && message.hasOwnProperty("intentSuggestion")) {
                                if (properties.result === 1)
                                    return "result: multiple values";
                                properties.result = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2.IntentSuggestion.verify(message.intentSuggestion);
                                    if (error)
                                        return "intentSuggestion." + error;
                                }
                            }
                            if (message.answerRecord != null && message.hasOwnProperty("answerRecord"))
                                if (!$util.isString(message.answerRecord))
                                    return "answerRecord: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a DialogflowAssistAnswer message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.DialogflowAssistAnswer
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.DialogflowAssistAnswer} DialogflowAssistAnswer
                         */
                        DialogflowAssistAnswer.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.DialogflowAssistAnswer)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.DialogflowAssistAnswer();
                            if (object.queryResult != null) {
                                if (typeof object.queryResult !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.DialogflowAssistAnswer.queryResult: object expected");
                                message.queryResult = $root.google.cloud.dialogflow.v2.QueryResult.fromObject(object.queryResult);
                            }
                            if (object.intentSuggestion != null) {
                                if (typeof object.intentSuggestion !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.DialogflowAssistAnswer.intentSuggestion: object expected");
                                message.intentSuggestion = $root.google.cloud.dialogflow.v2.IntentSuggestion.fromObject(object.intentSuggestion);
                            }
                            if (object.answerRecord != null)
                                message.answerRecord = String(object.answerRecord);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a DialogflowAssistAnswer message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.DialogflowAssistAnswer
                         * @static
                         * @param {google.cloud.dialogflow.v2.DialogflowAssistAnswer} message DialogflowAssistAnswer
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        DialogflowAssistAnswer.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.answerRecord = "";
                            if (message.queryResult != null && message.hasOwnProperty("queryResult")) {
                                object.queryResult = $root.google.cloud.dialogflow.v2.QueryResult.toObject(message.queryResult, options);
                                if (options.oneofs)
                                    object.result = "queryResult";
                            }
                            if (message.answerRecord != null && message.hasOwnProperty("answerRecord"))
                                object.answerRecord = message.answerRecord;
                            if (message.intentSuggestion != null && message.hasOwnProperty("intentSuggestion")) {
                                object.intentSuggestion = $root.google.cloud.dialogflow.v2.IntentSuggestion.toObject(message.intentSuggestion, options);
                                if (options.oneofs)
                                    object.result = "intentSuggestion";
                            }
                            return object;
                        };
    
                        /**
                         * Converts this DialogflowAssistAnswer to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.DialogflowAssistAnswer
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        DialogflowAssistAnswer.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for DialogflowAssistAnswer
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.DialogflowAssistAnswer
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        DialogflowAssistAnswer.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.DialogflowAssistAnswer";
                        };
    
                        return DialogflowAssistAnswer;
                    })();
    
                    v2.SuggestionResult = (function() {
    
                        /**
                         * Properties of a SuggestionResult.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ISuggestionResult
                         * @property {google.rpc.IStatus|null} [error] SuggestionResult error
                         * @property {google.cloud.dialogflow.v2.ISuggestArticlesResponse|null} [suggestArticlesResponse] SuggestionResult suggestArticlesResponse
                         * @property {google.cloud.dialogflow.v2.ISuggestKnowledgeAssistResponse|null} [suggestKnowledgeAssistResponse] SuggestionResult suggestKnowledgeAssistResponse
                         * @property {google.cloud.dialogflow.v2.ISuggestFaqAnswersResponse|null} [suggestFaqAnswersResponse] SuggestionResult suggestFaqAnswersResponse
                         * @property {google.cloud.dialogflow.v2.ISuggestSmartRepliesResponse|null} [suggestSmartRepliesResponse] SuggestionResult suggestSmartRepliesResponse
                         * @property {google.cloud.dialogflow.v2.IGenerateSuggestionsResponse|null} [generateSuggestionsResponse] SuggestionResult generateSuggestionsResponse
                         */
    
                        /**
                         * Constructs a new SuggestionResult.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a SuggestionResult.
                         * @implements ISuggestionResult
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ISuggestionResult=} [properties] Properties to set
                         */
                        function SuggestionResult(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SuggestionResult error.
                         * @member {google.rpc.IStatus|null|undefined} error
                         * @memberof google.cloud.dialogflow.v2.SuggestionResult
                         * @instance
                         */
                        SuggestionResult.prototype.error = null;
    
                        /**
                         * SuggestionResult suggestArticlesResponse.
                         * @member {google.cloud.dialogflow.v2.ISuggestArticlesResponse|null|undefined} suggestArticlesResponse
                         * @memberof google.cloud.dialogflow.v2.SuggestionResult
                         * @instance
                         */
                        SuggestionResult.prototype.suggestArticlesResponse = null;
    
                        /**
                         * SuggestionResult suggestKnowledgeAssistResponse.
                         * @member {google.cloud.dialogflow.v2.ISuggestKnowledgeAssistResponse|null|undefined} suggestKnowledgeAssistResponse
                         * @memberof google.cloud.dialogflow.v2.SuggestionResult
                         * @instance
                         */
                        SuggestionResult.prototype.suggestKnowledgeAssistResponse = null;
    
                        /**
                         * SuggestionResult suggestFaqAnswersResponse.
                         * @member {google.cloud.dialogflow.v2.ISuggestFaqAnswersResponse|null|undefined} suggestFaqAnswersResponse
                         * @memberof google.cloud.dialogflow.v2.SuggestionResult
                         * @instance
                         */
                        SuggestionResult.prototype.suggestFaqAnswersResponse = null;
    
                        /**
                         * SuggestionResult suggestSmartRepliesResponse.
                         * @member {google.cloud.dialogflow.v2.ISuggestSmartRepliesResponse|null|undefined} suggestSmartRepliesResponse
                         * @memberof google.cloud.dialogflow.v2.SuggestionResult
                         * @instance
                         */
                        SuggestionResult.prototype.suggestSmartRepliesResponse = null;
    
                        /**
                         * SuggestionResult generateSuggestionsResponse.
                         * @member {google.cloud.dialogflow.v2.IGenerateSuggestionsResponse|null|undefined} generateSuggestionsResponse
                         * @memberof google.cloud.dialogflow.v2.SuggestionResult
                         * @instance
                         */
                        SuggestionResult.prototype.generateSuggestionsResponse = null;
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * SuggestionResult suggestionResponse.
                         * @member {"error"|"suggestArticlesResponse"|"suggestKnowledgeAssistResponse"|"suggestFaqAnswersResponse"|"suggestSmartRepliesResponse"|"generateSuggestionsResponse"|undefined} suggestionResponse
                         * @memberof google.cloud.dialogflow.v2.SuggestionResult
                         * @instance
                         */
                        Object.defineProperty(SuggestionResult.prototype, "suggestionResponse", {
                            get: $util.oneOfGetter($oneOfFields = ["error", "suggestArticlesResponse", "suggestKnowledgeAssistResponse", "suggestFaqAnswersResponse", "suggestSmartRepliesResponse", "generateSuggestionsResponse"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new SuggestionResult instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.SuggestionResult
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISuggestionResult=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.SuggestionResult} SuggestionResult instance
                         */
                        SuggestionResult.create = function create(properties) {
                            return new SuggestionResult(properties);
                        };
    
                        /**
                         * Encodes the specified SuggestionResult message. Does not implicitly {@link google.cloud.dialogflow.v2.SuggestionResult.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.SuggestionResult
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISuggestionResult} message SuggestionResult message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SuggestionResult.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.error != null && Object.hasOwnProperty.call(message, "error"))
                                $root.google.rpc.Status.encode(message.error, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.suggestArticlesResponse != null && Object.hasOwnProperty.call(message, "suggestArticlesResponse"))
                                $root.google.cloud.dialogflow.v2.SuggestArticlesResponse.encode(message.suggestArticlesResponse, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.suggestFaqAnswersResponse != null && Object.hasOwnProperty.call(message, "suggestFaqAnswersResponse"))
                                $root.google.cloud.dialogflow.v2.SuggestFaqAnswersResponse.encode(message.suggestFaqAnswersResponse, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            if (message.suggestSmartRepliesResponse != null && Object.hasOwnProperty.call(message, "suggestSmartRepliesResponse"))
                                $root.google.cloud.dialogflow.v2.SuggestSmartRepliesResponse.encode(message.suggestSmartRepliesResponse, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            if (message.suggestKnowledgeAssistResponse != null && Object.hasOwnProperty.call(message, "suggestKnowledgeAssistResponse"))
                                $root.google.cloud.dialogflow.v2.SuggestKnowledgeAssistResponse.encode(message.suggestKnowledgeAssistResponse, writer.uint32(/* id 8, wireType 2 =*/66).fork()).ldelim();
                            if (message.generateSuggestionsResponse != null && Object.hasOwnProperty.call(message, "generateSuggestionsResponse"))
                                $root.google.cloud.dialogflow.v2.GenerateSuggestionsResponse.encode(message.generateSuggestionsResponse, writer.uint32(/* id 9, wireType 2 =*/74).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SuggestionResult message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.SuggestionResult.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SuggestionResult
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISuggestionResult} message SuggestionResult message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SuggestionResult.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SuggestionResult message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.SuggestionResult
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.SuggestionResult} SuggestionResult
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SuggestionResult.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.SuggestionResult();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.error = $root.google.rpc.Status.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.suggestArticlesResponse = $root.google.cloud.dialogflow.v2.SuggestArticlesResponse.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 8: {
                                        message.suggestKnowledgeAssistResponse = $root.google.cloud.dialogflow.v2.SuggestKnowledgeAssistResponse.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 3: {
                                        message.suggestFaqAnswersResponse = $root.google.cloud.dialogflow.v2.SuggestFaqAnswersResponse.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 4: {
                                        message.suggestSmartRepliesResponse = $root.google.cloud.dialogflow.v2.SuggestSmartRepliesResponse.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 9: {
                                        message.generateSuggestionsResponse = $root.google.cloud.dialogflow.v2.GenerateSuggestionsResponse.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SuggestionResult message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SuggestionResult
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.SuggestionResult} SuggestionResult
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SuggestionResult.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SuggestionResult message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.SuggestionResult
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SuggestionResult.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.error != null && message.hasOwnProperty("error")) {
                                properties.suggestionResponse = 1;
                                {
                                    var error = $root.google.rpc.Status.verify(message.error);
                                    if (error)
                                        return "error." + error;
                                }
                            }
                            if (message.suggestArticlesResponse != null && message.hasOwnProperty("suggestArticlesResponse")) {
                                if (properties.suggestionResponse === 1)
                                    return "suggestionResponse: multiple values";
                                properties.suggestionResponse = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2.SuggestArticlesResponse.verify(message.suggestArticlesResponse);
                                    if (error)
                                        return "suggestArticlesResponse." + error;
                                }
                            }
                            if (message.suggestKnowledgeAssistResponse != null && message.hasOwnProperty("suggestKnowledgeAssistResponse")) {
                                if (properties.suggestionResponse === 1)
                                    return "suggestionResponse: multiple values";
                                properties.suggestionResponse = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2.SuggestKnowledgeAssistResponse.verify(message.suggestKnowledgeAssistResponse);
                                    if (error)
                                        return "suggestKnowledgeAssistResponse." + error;
                                }
                            }
                            if (message.suggestFaqAnswersResponse != null && message.hasOwnProperty("suggestFaqAnswersResponse")) {
                                if (properties.suggestionResponse === 1)
                                    return "suggestionResponse: multiple values";
                                properties.suggestionResponse = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2.SuggestFaqAnswersResponse.verify(message.suggestFaqAnswersResponse);
                                    if (error)
                                        return "suggestFaqAnswersResponse." + error;
                                }
                            }
                            if (message.suggestSmartRepliesResponse != null && message.hasOwnProperty("suggestSmartRepliesResponse")) {
                                if (properties.suggestionResponse === 1)
                                    return "suggestionResponse: multiple values";
                                properties.suggestionResponse = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2.SuggestSmartRepliesResponse.verify(message.suggestSmartRepliesResponse);
                                    if (error)
                                        return "suggestSmartRepliesResponse." + error;
                                }
                            }
                            if (message.generateSuggestionsResponse != null && message.hasOwnProperty("generateSuggestionsResponse")) {
                                if (properties.suggestionResponse === 1)
                                    return "suggestionResponse: multiple values";
                                properties.suggestionResponse = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2.GenerateSuggestionsResponse.verify(message.generateSuggestionsResponse);
                                    if (error)
                                        return "generateSuggestionsResponse." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates a SuggestionResult message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.SuggestionResult
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.SuggestionResult} SuggestionResult
                         */
                        SuggestionResult.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.SuggestionResult)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.SuggestionResult();
                            if (object.error != null) {
                                if (typeof object.error !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.SuggestionResult.error: object expected");
                                message.error = $root.google.rpc.Status.fromObject(object.error);
                            }
                            if (object.suggestArticlesResponse != null) {
                                if (typeof object.suggestArticlesResponse !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.SuggestionResult.suggestArticlesResponse: object expected");
                                message.suggestArticlesResponse = $root.google.cloud.dialogflow.v2.SuggestArticlesResponse.fromObject(object.suggestArticlesResponse);
                            }
                            if (object.suggestKnowledgeAssistResponse != null) {
                                if (typeof object.suggestKnowledgeAssistResponse !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.SuggestionResult.suggestKnowledgeAssistResponse: object expected");
                                message.suggestKnowledgeAssistResponse = $root.google.cloud.dialogflow.v2.SuggestKnowledgeAssistResponse.fromObject(object.suggestKnowledgeAssistResponse);
                            }
                            if (object.suggestFaqAnswersResponse != null) {
                                if (typeof object.suggestFaqAnswersResponse !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.SuggestionResult.suggestFaqAnswersResponse: object expected");
                                message.suggestFaqAnswersResponse = $root.google.cloud.dialogflow.v2.SuggestFaqAnswersResponse.fromObject(object.suggestFaqAnswersResponse);
                            }
                            if (object.suggestSmartRepliesResponse != null) {
                                if (typeof object.suggestSmartRepliesResponse !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.SuggestionResult.suggestSmartRepliesResponse: object expected");
                                message.suggestSmartRepliesResponse = $root.google.cloud.dialogflow.v2.SuggestSmartRepliesResponse.fromObject(object.suggestSmartRepliesResponse);
                            }
                            if (object.generateSuggestionsResponse != null) {
                                if (typeof object.generateSuggestionsResponse !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.SuggestionResult.generateSuggestionsResponse: object expected");
                                message.generateSuggestionsResponse = $root.google.cloud.dialogflow.v2.GenerateSuggestionsResponse.fromObject(object.generateSuggestionsResponse);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SuggestionResult message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.SuggestionResult
                         * @static
                         * @param {google.cloud.dialogflow.v2.SuggestionResult} message SuggestionResult
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SuggestionResult.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (message.error != null && message.hasOwnProperty("error")) {
                                object.error = $root.google.rpc.Status.toObject(message.error, options);
                                if (options.oneofs)
                                    object.suggestionResponse = "error";
                            }
                            if (message.suggestArticlesResponse != null && message.hasOwnProperty("suggestArticlesResponse")) {
                                object.suggestArticlesResponse = $root.google.cloud.dialogflow.v2.SuggestArticlesResponse.toObject(message.suggestArticlesResponse, options);
                                if (options.oneofs)
                                    object.suggestionResponse = "suggestArticlesResponse";
                            }
                            if (message.suggestFaqAnswersResponse != null && message.hasOwnProperty("suggestFaqAnswersResponse")) {
                                object.suggestFaqAnswersResponse = $root.google.cloud.dialogflow.v2.SuggestFaqAnswersResponse.toObject(message.suggestFaqAnswersResponse, options);
                                if (options.oneofs)
                                    object.suggestionResponse = "suggestFaqAnswersResponse";
                            }
                            if (message.suggestSmartRepliesResponse != null && message.hasOwnProperty("suggestSmartRepliesResponse")) {
                                object.suggestSmartRepliesResponse = $root.google.cloud.dialogflow.v2.SuggestSmartRepliesResponse.toObject(message.suggestSmartRepliesResponse, options);
                                if (options.oneofs)
                                    object.suggestionResponse = "suggestSmartRepliesResponse";
                            }
                            if (message.suggestKnowledgeAssistResponse != null && message.hasOwnProperty("suggestKnowledgeAssistResponse")) {
                                object.suggestKnowledgeAssistResponse = $root.google.cloud.dialogflow.v2.SuggestKnowledgeAssistResponse.toObject(message.suggestKnowledgeAssistResponse, options);
                                if (options.oneofs)
                                    object.suggestionResponse = "suggestKnowledgeAssistResponse";
                            }
                            if (message.generateSuggestionsResponse != null && message.hasOwnProperty("generateSuggestionsResponse")) {
                                object.generateSuggestionsResponse = $root.google.cloud.dialogflow.v2.GenerateSuggestionsResponse.toObject(message.generateSuggestionsResponse, options);
                                if (options.oneofs)
                                    object.suggestionResponse = "generateSuggestionsResponse";
                            }
                            return object;
                        };
    
                        /**
                         * Converts this SuggestionResult to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.SuggestionResult
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SuggestionResult.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SuggestionResult
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.SuggestionResult
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SuggestionResult.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.SuggestionResult";
                        };
    
                        return SuggestionResult;
                    })();
    
                    v2.InputTextConfig = (function() {
    
                        /**
                         * Properties of an InputTextConfig.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IInputTextConfig
                         * @property {string|null} [languageCode] InputTextConfig languageCode
                         */
    
                        /**
                         * Constructs a new InputTextConfig.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an InputTextConfig.
                         * @implements IInputTextConfig
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IInputTextConfig=} [properties] Properties to set
                         */
                        function InputTextConfig(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * InputTextConfig languageCode.
                         * @member {string} languageCode
                         * @memberof google.cloud.dialogflow.v2.InputTextConfig
                         * @instance
                         */
                        InputTextConfig.prototype.languageCode = "";
    
                        /**
                         * Creates a new InputTextConfig instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.InputTextConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2.IInputTextConfig=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.InputTextConfig} InputTextConfig instance
                         */
                        InputTextConfig.create = function create(properties) {
                            return new InputTextConfig(properties);
                        };
    
                        /**
                         * Encodes the specified InputTextConfig message. Does not implicitly {@link google.cloud.dialogflow.v2.InputTextConfig.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.InputTextConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2.IInputTextConfig} message InputTextConfig message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        InputTextConfig.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.languageCode != null && Object.hasOwnProperty.call(message, "languageCode"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.languageCode);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified InputTextConfig message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.InputTextConfig.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.InputTextConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2.IInputTextConfig} message InputTextConfig message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        InputTextConfig.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an InputTextConfig message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.InputTextConfig
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.InputTextConfig} InputTextConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        InputTextConfig.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.InputTextConfig();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.languageCode = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an InputTextConfig message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.InputTextConfig
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.InputTextConfig} InputTextConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        InputTextConfig.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an InputTextConfig message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.InputTextConfig
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        InputTextConfig.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                if (!$util.isString(message.languageCode))
                                    return "languageCode: string expected";
                            return null;
                        };
    
                        /**
                         * Creates an InputTextConfig message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.InputTextConfig
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.InputTextConfig} InputTextConfig
                         */
                        InputTextConfig.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.InputTextConfig)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.InputTextConfig();
                            if (object.languageCode != null)
                                message.languageCode = String(object.languageCode);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an InputTextConfig message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.InputTextConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2.InputTextConfig} message InputTextConfig
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        InputTextConfig.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.languageCode = "";
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                object.languageCode = message.languageCode;
                            return object;
                        };
    
                        /**
                         * Converts this InputTextConfig to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.InputTextConfig
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        InputTextConfig.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for InputTextConfig
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.InputTextConfig
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        InputTextConfig.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.InputTextConfig";
                        };
    
                        return InputTextConfig;
                    })();
    
                    v2.AnnotatedMessagePart = (function() {
    
                        /**
                         * Properties of an AnnotatedMessagePart.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IAnnotatedMessagePart
                         * @property {string|null} [text] AnnotatedMessagePart text
                         * @property {string|null} [entityType] AnnotatedMessagePart entityType
                         * @property {google.protobuf.IValue|null} [formattedValue] AnnotatedMessagePart formattedValue
                         */
    
                        /**
                         * Constructs a new AnnotatedMessagePart.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an AnnotatedMessagePart.
                         * @implements IAnnotatedMessagePart
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IAnnotatedMessagePart=} [properties] Properties to set
                         */
                        function AnnotatedMessagePart(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * AnnotatedMessagePart text.
                         * @member {string} text
                         * @memberof google.cloud.dialogflow.v2.AnnotatedMessagePart
                         * @instance
                         */
                        AnnotatedMessagePart.prototype.text = "";
    
                        /**
                         * AnnotatedMessagePart entityType.
                         * @member {string} entityType
                         * @memberof google.cloud.dialogflow.v2.AnnotatedMessagePart
                         * @instance
                         */
                        AnnotatedMessagePart.prototype.entityType = "";
    
                        /**
                         * AnnotatedMessagePart formattedValue.
                         * @member {google.protobuf.IValue|null|undefined} formattedValue
                         * @memberof google.cloud.dialogflow.v2.AnnotatedMessagePart
                         * @instance
                         */
                        AnnotatedMessagePart.prototype.formattedValue = null;
    
                        /**
                         * Creates a new AnnotatedMessagePart instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.AnnotatedMessagePart
                         * @static
                         * @param {google.cloud.dialogflow.v2.IAnnotatedMessagePart=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.AnnotatedMessagePart} AnnotatedMessagePart instance
                         */
                        AnnotatedMessagePart.create = function create(properties) {
                            return new AnnotatedMessagePart(properties);
                        };
    
                        /**
                         * Encodes the specified AnnotatedMessagePart message. Does not implicitly {@link google.cloud.dialogflow.v2.AnnotatedMessagePart.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.AnnotatedMessagePart
                         * @static
                         * @param {google.cloud.dialogflow.v2.IAnnotatedMessagePart} message AnnotatedMessagePart message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        AnnotatedMessagePart.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.text != null && Object.hasOwnProperty.call(message, "text"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.text);
                            if (message.entityType != null && Object.hasOwnProperty.call(message, "entityType"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.entityType);
                            if (message.formattedValue != null && Object.hasOwnProperty.call(message, "formattedValue"))
                                $root.google.protobuf.Value.encode(message.formattedValue, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified AnnotatedMessagePart message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.AnnotatedMessagePart.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.AnnotatedMessagePart
                         * @static
                         * @param {google.cloud.dialogflow.v2.IAnnotatedMessagePart} message AnnotatedMessagePart message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        AnnotatedMessagePart.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an AnnotatedMessagePart message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.AnnotatedMessagePart
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.AnnotatedMessagePart} AnnotatedMessagePart
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        AnnotatedMessagePart.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.AnnotatedMessagePart();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.text = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.entityType = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.formattedValue = $root.google.protobuf.Value.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an AnnotatedMessagePart message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.AnnotatedMessagePart
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.AnnotatedMessagePart} AnnotatedMessagePart
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        AnnotatedMessagePart.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an AnnotatedMessagePart message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.AnnotatedMessagePart
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        AnnotatedMessagePart.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.text != null && message.hasOwnProperty("text"))
                                if (!$util.isString(message.text))
                                    return "text: string expected";
                            if (message.entityType != null && message.hasOwnProperty("entityType"))
                                if (!$util.isString(message.entityType))
                                    return "entityType: string expected";
                            if (message.formattedValue != null && message.hasOwnProperty("formattedValue")) {
                                var error = $root.google.protobuf.Value.verify(message.formattedValue);
                                if (error)
                                    return "formattedValue." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates an AnnotatedMessagePart message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.AnnotatedMessagePart
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.AnnotatedMessagePart} AnnotatedMessagePart
                         */
                        AnnotatedMessagePart.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.AnnotatedMessagePart)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.AnnotatedMessagePart();
                            if (object.text != null)
                                message.text = String(object.text);
                            if (object.entityType != null)
                                message.entityType = String(object.entityType);
                            if (object.formattedValue != null) {
                                if (typeof object.formattedValue !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.AnnotatedMessagePart.formattedValue: object expected");
                                message.formattedValue = $root.google.protobuf.Value.fromObject(object.formattedValue);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an AnnotatedMessagePart message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.AnnotatedMessagePart
                         * @static
                         * @param {google.cloud.dialogflow.v2.AnnotatedMessagePart} message AnnotatedMessagePart
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        AnnotatedMessagePart.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.text = "";
                                object.entityType = "";
                                object.formattedValue = null;
                            }
                            if (message.text != null && message.hasOwnProperty("text"))
                                object.text = message.text;
                            if (message.entityType != null && message.hasOwnProperty("entityType"))
                                object.entityType = message.entityType;
                            if (message.formattedValue != null && message.hasOwnProperty("formattedValue"))
                                object.formattedValue = $root.google.protobuf.Value.toObject(message.formattedValue, options);
                            return object;
                        };
    
                        /**
                         * Converts this AnnotatedMessagePart to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.AnnotatedMessagePart
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        AnnotatedMessagePart.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for AnnotatedMessagePart
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.AnnotatedMessagePart
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        AnnotatedMessagePart.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.AnnotatedMessagePart";
                        };
    
                        return AnnotatedMessagePart;
                    })();
    
                    v2.MessageAnnotation = (function() {
    
                        /**
                         * Properties of a MessageAnnotation.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IMessageAnnotation
                         * @property {Array.<google.cloud.dialogflow.v2.IAnnotatedMessagePart>|null} [parts] MessageAnnotation parts
                         * @property {boolean|null} [containEntities] MessageAnnotation containEntities
                         */
    
                        /**
                         * Constructs a new MessageAnnotation.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a MessageAnnotation.
                         * @implements IMessageAnnotation
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IMessageAnnotation=} [properties] Properties to set
                         */
                        function MessageAnnotation(properties) {
                            this.parts = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * MessageAnnotation parts.
                         * @member {Array.<google.cloud.dialogflow.v2.IAnnotatedMessagePart>} parts
                         * @memberof google.cloud.dialogflow.v2.MessageAnnotation
                         * @instance
                         */
                        MessageAnnotation.prototype.parts = $util.emptyArray;
    
                        /**
                         * MessageAnnotation containEntities.
                         * @member {boolean} containEntities
                         * @memberof google.cloud.dialogflow.v2.MessageAnnotation
                         * @instance
                         */
                        MessageAnnotation.prototype.containEntities = false;
    
                        /**
                         * Creates a new MessageAnnotation instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.MessageAnnotation
                         * @static
                         * @param {google.cloud.dialogflow.v2.IMessageAnnotation=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.MessageAnnotation} MessageAnnotation instance
                         */
                        MessageAnnotation.create = function create(properties) {
                            return new MessageAnnotation(properties);
                        };
    
                        /**
                         * Encodes the specified MessageAnnotation message. Does not implicitly {@link google.cloud.dialogflow.v2.MessageAnnotation.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.MessageAnnotation
                         * @static
                         * @param {google.cloud.dialogflow.v2.IMessageAnnotation} message MessageAnnotation message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        MessageAnnotation.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parts != null && message.parts.length)
                                for (var i = 0; i < message.parts.length; ++i)
                                    $root.google.cloud.dialogflow.v2.AnnotatedMessagePart.encode(message.parts[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.containEntities != null && Object.hasOwnProperty.call(message, "containEntities"))
                                writer.uint32(/* id 2, wireType 0 =*/16).bool(message.containEntities);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified MessageAnnotation message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.MessageAnnotation.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.MessageAnnotation
                         * @static
                         * @param {google.cloud.dialogflow.v2.IMessageAnnotation} message MessageAnnotation message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        MessageAnnotation.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a MessageAnnotation message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.MessageAnnotation
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.MessageAnnotation} MessageAnnotation
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        MessageAnnotation.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.MessageAnnotation();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.parts && message.parts.length))
                                            message.parts = [];
                                        message.parts.push($root.google.cloud.dialogflow.v2.AnnotatedMessagePart.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 2: {
                                        message.containEntities = reader.bool();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a MessageAnnotation message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.MessageAnnotation
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.MessageAnnotation} MessageAnnotation
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        MessageAnnotation.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a MessageAnnotation message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.MessageAnnotation
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        MessageAnnotation.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parts != null && message.hasOwnProperty("parts")) {
                                if (!Array.isArray(message.parts))
                                    return "parts: array expected";
                                for (var i = 0; i < message.parts.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.AnnotatedMessagePart.verify(message.parts[i]);
                                    if (error)
                                        return "parts." + error;
                                }
                            }
                            if (message.containEntities != null && message.hasOwnProperty("containEntities"))
                                if (typeof message.containEntities !== "boolean")
                                    return "containEntities: boolean expected";
                            return null;
                        };
    
                        /**
                         * Creates a MessageAnnotation message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.MessageAnnotation
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.MessageAnnotation} MessageAnnotation
                         */
                        MessageAnnotation.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.MessageAnnotation)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.MessageAnnotation();
                            if (object.parts) {
                                if (!Array.isArray(object.parts))
                                    throw TypeError(".google.cloud.dialogflow.v2.MessageAnnotation.parts: array expected");
                                message.parts = [];
                                for (var i = 0; i < object.parts.length; ++i) {
                                    if (typeof object.parts[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.MessageAnnotation.parts: object expected");
                                    message.parts[i] = $root.google.cloud.dialogflow.v2.AnnotatedMessagePart.fromObject(object.parts[i]);
                                }
                            }
                            if (object.containEntities != null)
                                message.containEntities = Boolean(object.containEntities);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a MessageAnnotation message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.MessageAnnotation
                         * @static
                         * @param {google.cloud.dialogflow.v2.MessageAnnotation} message MessageAnnotation
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        MessageAnnotation.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.parts = [];
                            if (options.defaults)
                                object.containEntities = false;
                            if (message.parts && message.parts.length) {
                                object.parts = [];
                                for (var j = 0; j < message.parts.length; ++j)
                                    object.parts[j] = $root.google.cloud.dialogflow.v2.AnnotatedMessagePart.toObject(message.parts[j], options);
                            }
                            if (message.containEntities != null && message.hasOwnProperty("containEntities"))
                                object.containEntities = message.containEntities;
                            return object;
                        };
    
                        /**
                         * Converts this MessageAnnotation to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.MessageAnnotation
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        MessageAnnotation.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for MessageAnnotation
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.MessageAnnotation
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        MessageAnnotation.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.MessageAnnotation";
                        };
    
                        return MessageAnnotation;
                    })();
    
                    v2.SuggestionInput = (function() {
    
                        /**
                         * Properties of a SuggestionInput.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ISuggestionInput
                         * @property {string|null} [answerRecord] SuggestionInput answerRecord
                         */
    
                        /**
                         * Constructs a new SuggestionInput.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a SuggestionInput.
                         * @implements ISuggestionInput
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ISuggestionInput=} [properties] Properties to set
                         */
                        function SuggestionInput(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SuggestionInput answerRecord.
                         * @member {string} answerRecord
                         * @memberof google.cloud.dialogflow.v2.SuggestionInput
                         * @instance
                         */
                        SuggestionInput.prototype.answerRecord = "";
    
                        /**
                         * Creates a new SuggestionInput instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.SuggestionInput
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISuggestionInput=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.SuggestionInput} SuggestionInput instance
                         */
                        SuggestionInput.create = function create(properties) {
                            return new SuggestionInput(properties);
                        };
    
                        /**
                         * Encodes the specified SuggestionInput message. Does not implicitly {@link google.cloud.dialogflow.v2.SuggestionInput.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.SuggestionInput
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISuggestionInput} message SuggestionInput message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SuggestionInput.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.answerRecord != null && Object.hasOwnProperty.call(message, "answerRecord"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.answerRecord);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SuggestionInput message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.SuggestionInput.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SuggestionInput
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISuggestionInput} message SuggestionInput message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SuggestionInput.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SuggestionInput message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.SuggestionInput
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.SuggestionInput} SuggestionInput
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SuggestionInput.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.SuggestionInput();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.answerRecord = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SuggestionInput message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SuggestionInput
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.SuggestionInput} SuggestionInput
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SuggestionInput.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SuggestionInput message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.SuggestionInput
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SuggestionInput.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.answerRecord != null && message.hasOwnProperty("answerRecord"))
                                if (!$util.isString(message.answerRecord))
                                    return "answerRecord: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a SuggestionInput message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.SuggestionInput
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.SuggestionInput} SuggestionInput
                         */
                        SuggestionInput.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.SuggestionInput)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.SuggestionInput();
                            if (object.answerRecord != null)
                                message.answerRecord = String(object.answerRecord);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SuggestionInput message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.SuggestionInput
                         * @static
                         * @param {google.cloud.dialogflow.v2.SuggestionInput} message SuggestionInput
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SuggestionInput.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.answerRecord = "";
                            if (message.answerRecord != null && message.hasOwnProperty("answerRecord"))
                                object.answerRecord = message.answerRecord;
                            return object;
                        };
    
                        /**
                         * Converts this SuggestionInput to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.SuggestionInput
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SuggestionInput.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SuggestionInput
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.SuggestionInput
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SuggestionInput.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.SuggestionInput";
                        };
    
                        return SuggestionInput;
                    })();
    
                    v2.AssistQueryParameters = (function() {
    
                        /**
                         * Properties of an AssistQueryParameters.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IAssistQueryParameters
                         * @property {Object.<string,string>|null} [documentsMetadataFilters] AssistQueryParameters documentsMetadataFilters
                         */
    
                        /**
                         * Constructs a new AssistQueryParameters.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an AssistQueryParameters.
                         * @implements IAssistQueryParameters
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IAssistQueryParameters=} [properties] Properties to set
                         */
                        function AssistQueryParameters(properties) {
                            this.documentsMetadataFilters = {};
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * AssistQueryParameters documentsMetadataFilters.
                         * @member {Object.<string,string>} documentsMetadataFilters
                         * @memberof google.cloud.dialogflow.v2.AssistQueryParameters
                         * @instance
                         */
                        AssistQueryParameters.prototype.documentsMetadataFilters = $util.emptyObject;
    
                        /**
                         * Creates a new AssistQueryParameters instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.AssistQueryParameters
                         * @static
                         * @param {google.cloud.dialogflow.v2.IAssistQueryParameters=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.AssistQueryParameters} AssistQueryParameters instance
                         */
                        AssistQueryParameters.create = function create(properties) {
                            return new AssistQueryParameters(properties);
                        };
    
                        /**
                         * Encodes the specified AssistQueryParameters message. Does not implicitly {@link google.cloud.dialogflow.v2.AssistQueryParameters.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.AssistQueryParameters
                         * @static
                         * @param {google.cloud.dialogflow.v2.IAssistQueryParameters} message AssistQueryParameters message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        AssistQueryParameters.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.documentsMetadataFilters != null && Object.hasOwnProperty.call(message, "documentsMetadataFilters"))
                                for (var keys = Object.keys(message.documentsMetadataFilters), i = 0; i < keys.length; ++i)
                                    writer.uint32(/* id 1, wireType 2 =*/10).fork().uint32(/* id 1, wireType 2 =*/10).string(keys[i]).uint32(/* id 2, wireType 2 =*/18).string(message.documentsMetadataFilters[keys[i]]).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified AssistQueryParameters message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.AssistQueryParameters.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.AssistQueryParameters
                         * @static
                         * @param {google.cloud.dialogflow.v2.IAssistQueryParameters} message AssistQueryParameters message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        AssistQueryParameters.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an AssistQueryParameters message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.AssistQueryParameters
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.AssistQueryParameters} AssistQueryParameters
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        AssistQueryParameters.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.AssistQueryParameters(), key, value;
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (message.documentsMetadataFilters === $util.emptyObject)
                                            message.documentsMetadataFilters = {};
                                        var end2 = reader.uint32() + reader.pos;
                                        key = "";
                                        value = "";
                                        while (reader.pos < end2) {
                                            var tag2 = reader.uint32();
                                            switch (tag2 >>> 3) {
                                            case 1:
                                                key = reader.string();
                                                break;
                                            case 2:
                                                value = reader.string();
                                                break;
                                            default:
                                                reader.skipType(tag2 & 7);
                                                break;
                                            }
                                        }
                                        message.documentsMetadataFilters[key] = value;
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an AssistQueryParameters message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.AssistQueryParameters
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.AssistQueryParameters} AssistQueryParameters
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        AssistQueryParameters.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an AssistQueryParameters message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.AssistQueryParameters
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        AssistQueryParameters.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.documentsMetadataFilters != null && message.hasOwnProperty("documentsMetadataFilters")) {
                                if (!$util.isObject(message.documentsMetadataFilters))
                                    return "documentsMetadataFilters: object expected";
                                var key = Object.keys(message.documentsMetadataFilters);
                                for (var i = 0; i < key.length; ++i)
                                    if (!$util.isString(message.documentsMetadataFilters[key[i]]))
                                        return "documentsMetadataFilters: string{k:string} expected";
                            }
                            return null;
                        };
    
                        /**
                         * Creates an AssistQueryParameters message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.AssistQueryParameters
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.AssistQueryParameters} AssistQueryParameters
                         */
                        AssistQueryParameters.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.AssistQueryParameters)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.AssistQueryParameters();
                            if (object.documentsMetadataFilters) {
                                if (typeof object.documentsMetadataFilters !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.AssistQueryParameters.documentsMetadataFilters: object expected");
                                message.documentsMetadataFilters = {};
                                for (var keys = Object.keys(object.documentsMetadataFilters), i = 0; i < keys.length; ++i)
                                    message.documentsMetadataFilters[keys[i]] = String(object.documentsMetadataFilters[keys[i]]);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an AssistQueryParameters message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.AssistQueryParameters
                         * @static
                         * @param {google.cloud.dialogflow.v2.AssistQueryParameters} message AssistQueryParameters
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        AssistQueryParameters.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.objects || options.defaults)
                                object.documentsMetadataFilters = {};
                            var keys2;
                            if (message.documentsMetadataFilters && (keys2 = Object.keys(message.documentsMetadataFilters)).length) {
                                object.documentsMetadataFilters = {};
                                for (var j = 0; j < keys2.length; ++j)
                                    object.documentsMetadataFilters[keys2[j]] = message.documentsMetadataFilters[keys2[j]];
                            }
                            return object;
                        };
    
                        /**
                         * Converts this AssistQueryParameters to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.AssistQueryParameters
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        AssistQueryParameters.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for AssistQueryParameters
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.AssistQueryParameters
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        AssistQueryParameters.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.AssistQueryParameters";
                        };
    
                        return AssistQueryParameters;
                    })();
    
                    v2.SuggestKnowledgeAssistRequest = (function() {
    
                        /**
                         * Properties of a SuggestKnowledgeAssistRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ISuggestKnowledgeAssistRequest
                         * @property {string|null} [parent] SuggestKnowledgeAssistRequest parent
                         * @property {string|null} [latestMessage] SuggestKnowledgeAssistRequest latestMessage
                         * @property {number|null} [contextSize] SuggestKnowledgeAssistRequest contextSize
                         * @property {string|null} [previousSuggestedQuery] SuggestKnowledgeAssistRequest previousSuggestedQuery
                         */
    
                        /**
                         * Constructs a new SuggestKnowledgeAssistRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a SuggestKnowledgeAssistRequest.
                         * @implements ISuggestKnowledgeAssistRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ISuggestKnowledgeAssistRequest=} [properties] Properties to set
                         */
                        function SuggestKnowledgeAssistRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SuggestKnowledgeAssistRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.SuggestKnowledgeAssistRequest
                         * @instance
                         */
                        SuggestKnowledgeAssistRequest.prototype.parent = "";
    
                        /**
                         * SuggestKnowledgeAssistRequest latestMessage.
                         * @member {string} latestMessage
                         * @memberof google.cloud.dialogflow.v2.SuggestKnowledgeAssistRequest
                         * @instance
                         */
                        SuggestKnowledgeAssistRequest.prototype.latestMessage = "";
    
                        /**
                         * SuggestKnowledgeAssistRequest contextSize.
                         * @member {number} contextSize
                         * @memberof google.cloud.dialogflow.v2.SuggestKnowledgeAssistRequest
                         * @instance
                         */
                        SuggestKnowledgeAssistRequest.prototype.contextSize = 0;
    
                        /**
                         * SuggestKnowledgeAssistRequest previousSuggestedQuery.
                         * @member {string} previousSuggestedQuery
                         * @memberof google.cloud.dialogflow.v2.SuggestKnowledgeAssistRequest
                         * @instance
                         */
                        SuggestKnowledgeAssistRequest.prototype.previousSuggestedQuery = "";
    
                        /**
                         * Creates a new SuggestKnowledgeAssistRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.SuggestKnowledgeAssistRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISuggestKnowledgeAssistRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.SuggestKnowledgeAssistRequest} SuggestKnowledgeAssistRequest instance
                         */
                        SuggestKnowledgeAssistRequest.create = function create(properties) {
                            return new SuggestKnowledgeAssistRequest(properties);
                        };
    
                        /**
                         * Encodes the specified SuggestKnowledgeAssistRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.SuggestKnowledgeAssistRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.SuggestKnowledgeAssistRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISuggestKnowledgeAssistRequest} message SuggestKnowledgeAssistRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SuggestKnowledgeAssistRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.latestMessage != null && Object.hasOwnProperty.call(message, "latestMessage"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.latestMessage);
                            if (message.contextSize != null && Object.hasOwnProperty.call(message, "contextSize"))
                                writer.uint32(/* id 3, wireType 0 =*/24).int32(message.contextSize);
                            if (message.previousSuggestedQuery != null && Object.hasOwnProperty.call(message, "previousSuggestedQuery"))
                                writer.uint32(/* id 4, wireType 2 =*/34).string(message.previousSuggestedQuery);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SuggestKnowledgeAssistRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.SuggestKnowledgeAssistRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SuggestKnowledgeAssistRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISuggestKnowledgeAssistRequest} message SuggestKnowledgeAssistRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SuggestKnowledgeAssistRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SuggestKnowledgeAssistRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.SuggestKnowledgeAssistRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.SuggestKnowledgeAssistRequest} SuggestKnowledgeAssistRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SuggestKnowledgeAssistRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.SuggestKnowledgeAssistRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.latestMessage = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.contextSize = reader.int32();
                                        break;
                                    }
                                case 4: {
                                        message.previousSuggestedQuery = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SuggestKnowledgeAssistRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SuggestKnowledgeAssistRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.SuggestKnowledgeAssistRequest} SuggestKnowledgeAssistRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SuggestKnowledgeAssistRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SuggestKnowledgeAssistRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.SuggestKnowledgeAssistRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SuggestKnowledgeAssistRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                if (!$util.isString(message.latestMessage))
                                    return "latestMessage: string expected";
                            if (message.contextSize != null && message.hasOwnProperty("contextSize"))
                                if (!$util.isInteger(message.contextSize))
                                    return "contextSize: integer expected";
                            if (message.previousSuggestedQuery != null && message.hasOwnProperty("previousSuggestedQuery"))
                                if (!$util.isString(message.previousSuggestedQuery))
                                    return "previousSuggestedQuery: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a SuggestKnowledgeAssistRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.SuggestKnowledgeAssistRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.SuggestKnowledgeAssistRequest} SuggestKnowledgeAssistRequest
                         */
                        SuggestKnowledgeAssistRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.SuggestKnowledgeAssistRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.SuggestKnowledgeAssistRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.latestMessage != null)
                                message.latestMessage = String(object.latestMessage);
                            if (object.contextSize != null)
                                message.contextSize = object.contextSize | 0;
                            if (object.previousSuggestedQuery != null)
                                message.previousSuggestedQuery = String(object.previousSuggestedQuery);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SuggestKnowledgeAssistRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.SuggestKnowledgeAssistRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.SuggestKnowledgeAssistRequest} message SuggestKnowledgeAssistRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SuggestKnowledgeAssistRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.latestMessage = "";
                                object.contextSize = 0;
                                object.previousSuggestedQuery = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                object.latestMessage = message.latestMessage;
                            if (message.contextSize != null && message.hasOwnProperty("contextSize"))
                                object.contextSize = message.contextSize;
                            if (message.previousSuggestedQuery != null && message.hasOwnProperty("previousSuggestedQuery"))
                                object.previousSuggestedQuery = message.previousSuggestedQuery;
                            return object;
                        };
    
                        /**
                         * Converts this SuggestKnowledgeAssistRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.SuggestKnowledgeAssistRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SuggestKnowledgeAssistRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SuggestKnowledgeAssistRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.SuggestKnowledgeAssistRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SuggestKnowledgeAssistRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.SuggestKnowledgeAssistRequest";
                        };
    
                        return SuggestKnowledgeAssistRequest;
                    })();
    
                    v2.SuggestKnowledgeAssistResponse = (function() {
    
                        /**
                         * Properties of a SuggestKnowledgeAssistResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ISuggestKnowledgeAssistResponse
                         * @property {google.cloud.dialogflow.v2.IKnowledgeAssistAnswer|null} [knowledgeAssistAnswer] SuggestKnowledgeAssistResponse knowledgeAssistAnswer
                         * @property {string|null} [latestMessage] SuggestKnowledgeAssistResponse latestMessage
                         * @property {number|null} [contextSize] SuggestKnowledgeAssistResponse contextSize
                         */
    
                        /**
                         * Constructs a new SuggestKnowledgeAssistResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a SuggestKnowledgeAssistResponse.
                         * @implements ISuggestKnowledgeAssistResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ISuggestKnowledgeAssistResponse=} [properties] Properties to set
                         */
                        function SuggestKnowledgeAssistResponse(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SuggestKnowledgeAssistResponse knowledgeAssistAnswer.
                         * @member {google.cloud.dialogflow.v2.IKnowledgeAssistAnswer|null|undefined} knowledgeAssistAnswer
                         * @memberof google.cloud.dialogflow.v2.SuggestKnowledgeAssistResponse
                         * @instance
                         */
                        SuggestKnowledgeAssistResponse.prototype.knowledgeAssistAnswer = null;
    
                        /**
                         * SuggestKnowledgeAssistResponse latestMessage.
                         * @member {string} latestMessage
                         * @memberof google.cloud.dialogflow.v2.SuggestKnowledgeAssistResponse
                         * @instance
                         */
                        SuggestKnowledgeAssistResponse.prototype.latestMessage = "";
    
                        /**
                         * SuggestKnowledgeAssistResponse contextSize.
                         * @member {number} contextSize
                         * @memberof google.cloud.dialogflow.v2.SuggestKnowledgeAssistResponse
                         * @instance
                         */
                        SuggestKnowledgeAssistResponse.prototype.contextSize = 0;
    
                        /**
                         * Creates a new SuggestKnowledgeAssistResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.SuggestKnowledgeAssistResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISuggestKnowledgeAssistResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.SuggestKnowledgeAssistResponse} SuggestKnowledgeAssistResponse instance
                         */
                        SuggestKnowledgeAssistResponse.create = function create(properties) {
                            return new SuggestKnowledgeAssistResponse(properties);
                        };
    
                        /**
                         * Encodes the specified SuggestKnowledgeAssistResponse message. Does not implicitly {@link google.cloud.dialogflow.v2.SuggestKnowledgeAssistResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.SuggestKnowledgeAssistResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISuggestKnowledgeAssistResponse} message SuggestKnowledgeAssistResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SuggestKnowledgeAssistResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.knowledgeAssistAnswer != null && Object.hasOwnProperty.call(message, "knowledgeAssistAnswer"))
                                $root.google.cloud.dialogflow.v2.KnowledgeAssistAnswer.encode(message.knowledgeAssistAnswer, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.latestMessage != null && Object.hasOwnProperty.call(message, "latestMessage"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.latestMessage);
                            if (message.contextSize != null && Object.hasOwnProperty.call(message, "contextSize"))
                                writer.uint32(/* id 3, wireType 0 =*/24).int32(message.contextSize);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SuggestKnowledgeAssistResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.SuggestKnowledgeAssistResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SuggestKnowledgeAssistResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISuggestKnowledgeAssistResponse} message SuggestKnowledgeAssistResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SuggestKnowledgeAssistResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SuggestKnowledgeAssistResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.SuggestKnowledgeAssistResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.SuggestKnowledgeAssistResponse} SuggestKnowledgeAssistResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SuggestKnowledgeAssistResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.SuggestKnowledgeAssistResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.knowledgeAssistAnswer = $root.google.cloud.dialogflow.v2.KnowledgeAssistAnswer.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.latestMessage = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.contextSize = reader.int32();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SuggestKnowledgeAssistResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SuggestKnowledgeAssistResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.SuggestKnowledgeAssistResponse} SuggestKnowledgeAssistResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SuggestKnowledgeAssistResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SuggestKnowledgeAssistResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.SuggestKnowledgeAssistResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SuggestKnowledgeAssistResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.knowledgeAssistAnswer != null && message.hasOwnProperty("knowledgeAssistAnswer")) {
                                var error = $root.google.cloud.dialogflow.v2.KnowledgeAssistAnswer.verify(message.knowledgeAssistAnswer);
                                if (error)
                                    return "knowledgeAssistAnswer." + error;
                            }
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                if (!$util.isString(message.latestMessage))
                                    return "latestMessage: string expected";
                            if (message.contextSize != null && message.hasOwnProperty("contextSize"))
                                if (!$util.isInteger(message.contextSize))
                                    return "contextSize: integer expected";
                            return null;
                        };
    
                        /**
                         * Creates a SuggestKnowledgeAssistResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.SuggestKnowledgeAssistResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.SuggestKnowledgeAssistResponse} SuggestKnowledgeAssistResponse
                         */
                        SuggestKnowledgeAssistResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.SuggestKnowledgeAssistResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.SuggestKnowledgeAssistResponse();
                            if (object.knowledgeAssistAnswer != null) {
                                if (typeof object.knowledgeAssistAnswer !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.SuggestKnowledgeAssistResponse.knowledgeAssistAnswer: object expected");
                                message.knowledgeAssistAnswer = $root.google.cloud.dialogflow.v2.KnowledgeAssistAnswer.fromObject(object.knowledgeAssistAnswer);
                            }
                            if (object.latestMessage != null)
                                message.latestMessage = String(object.latestMessage);
                            if (object.contextSize != null)
                                message.contextSize = object.contextSize | 0;
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SuggestKnowledgeAssistResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.SuggestKnowledgeAssistResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.SuggestKnowledgeAssistResponse} message SuggestKnowledgeAssistResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SuggestKnowledgeAssistResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.knowledgeAssistAnswer = null;
                                object.latestMessage = "";
                                object.contextSize = 0;
                            }
                            if (message.knowledgeAssistAnswer != null && message.hasOwnProperty("knowledgeAssistAnswer"))
                                object.knowledgeAssistAnswer = $root.google.cloud.dialogflow.v2.KnowledgeAssistAnswer.toObject(message.knowledgeAssistAnswer, options);
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                object.latestMessage = message.latestMessage;
                            if (message.contextSize != null && message.hasOwnProperty("contextSize"))
                                object.contextSize = message.contextSize;
                            return object;
                        };
    
                        /**
                         * Converts this SuggestKnowledgeAssistResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.SuggestKnowledgeAssistResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SuggestKnowledgeAssistResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SuggestKnowledgeAssistResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.SuggestKnowledgeAssistResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SuggestKnowledgeAssistResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.SuggestKnowledgeAssistResponse";
                        };
    
                        return SuggestKnowledgeAssistResponse;
                    })();
    
                    v2.KnowledgeAssistAnswer = (function() {
    
                        /**
                         * Properties of a KnowledgeAssistAnswer.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IKnowledgeAssistAnswer
                         * @property {google.cloud.dialogflow.v2.KnowledgeAssistAnswer.ISuggestedQuery|null} [suggestedQuery] KnowledgeAssistAnswer suggestedQuery
                         * @property {google.cloud.dialogflow.v2.KnowledgeAssistAnswer.IKnowledgeAnswer|null} [suggestedQueryAnswer] KnowledgeAssistAnswer suggestedQueryAnswer
                         * @property {string|null} [answerRecord] KnowledgeAssistAnswer answerRecord
                         */
    
                        /**
                         * Constructs a new KnowledgeAssistAnswer.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a KnowledgeAssistAnswer.
                         * @implements IKnowledgeAssistAnswer
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IKnowledgeAssistAnswer=} [properties] Properties to set
                         */
                        function KnowledgeAssistAnswer(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * KnowledgeAssistAnswer suggestedQuery.
                         * @member {google.cloud.dialogflow.v2.KnowledgeAssistAnswer.ISuggestedQuery|null|undefined} suggestedQuery
                         * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer
                         * @instance
                         */
                        KnowledgeAssistAnswer.prototype.suggestedQuery = null;
    
                        /**
                         * KnowledgeAssistAnswer suggestedQueryAnswer.
                         * @member {google.cloud.dialogflow.v2.KnowledgeAssistAnswer.IKnowledgeAnswer|null|undefined} suggestedQueryAnswer
                         * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer
                         * @instance
                         */
                        KnowledgeAssistAnswer.prototype.suggestedQueryAnswer = null;
    
                        /**
                         * KnowledgeAssistAnswer answerRecord.
                         * @member {string} answerRecord
                         * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer
                         * @instance
                         */
                        KnowledgeAssistAnswer.prototype.answerRecord = "";
    
                        /**
                         * Creates a new KnowledgeAssistAnswer instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer
                         * @static
                         * @param {google.cloud.dialogflow.v2.IKnowledgeAssistAnswer=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.KnowledgeAssistAnswer} KnowledgeAssistAnswer instance
                         */
                        KnowledgeAssistAnswer.create = function create(properties) {
                            return new KnowledgeAssistAnswer(properties);
                        };
    
                        /**
                         * Encodes the specified KnowledgeAssistAnswer message. Does not implicitly {@link google.cloud.dialogflow.v2.KnowledgeAssistAnswer.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer
                         * @static
                         * @param {google.cloud.dialogflow.v2.IKnowledgeAssistAnswer} message KnowledgeAssistAnswer message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        KnowledgeAssistAnswer.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.suggestedQuery != null && Object.hasOwnProperty.call(message, "suggestedQuery"))
                                $root.google.cloud.dialogflow.v2.KnowledgeAssistAnswer.SuggestedQuery.encode(message.suggestedQuery, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.suggestedQueryAnswer != null && Object.hasOwnProperty.call(message, "suggestedQueryAnswer"))
                                $root.google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.encode(message.suggestedQueryAnswer, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.answerRecord != null && Object.hasOwnProperty.call(message, "answerRecord"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.answerRecord);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified KnowledgeAssistAnswer message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.KnowledgeAssistAnswer.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer
                         * @static
                         * @param {google.cloud.dialogflow.v2.IKnowledgeAssistAnswer} message KnowledgeAssistAnswer message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        KnowledgeAssistAnswer.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a KnowledgeAssistAnswer message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.KnowledgeAssistAnswer} KnowledgeAssistAnswer
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        KnowledgeAssistAnswer.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.KnowledgeAssistAnswer();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.suggestedQuery = $root.google.cloud.dialogflow.v2.KnowledgeAssistAnswer.SuggestedQuery.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.suggestedQueryAnswer = $root.google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 3: {
                                        message.answerRecord = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a KnowledgeAssistAnswer message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.KnowledgeAssistAnswer} KnowledgeAssistAnswer
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        KnowledgeAssistAnswer.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a KnowledgeAssistAnswer message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        KnowledgeAssistAnswer.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.suggestedQuery != null && message.hasOwnProperty("suggestedQuery")) {
                                var error = $root.google.cloud.dialogflow.v2.KnowledgeAssistAnswer.SuggestedQuery.verify(message.suggestedQuery);
                                if (error)
                                    return "suggestedQuery." + error;
                            }
                            if (message.suggestedQueryAnswer != null && message.hasOwnProperty("suggestedQueryAnswer")) {
                                var error = $root.google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.verify(message.suggestedQueryAnswer);
                                if (error)
                                    return "suggestedQueryAnswer." + error;
                            }
                            if (message.answerRecord != null && message.hasOwnProperty("answerRecord"))
                                if (!$util.isString(message.answerRecord))
                                    return "answerRecord: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a KnowledgeAssistAnswer message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.KnowledgeAssistAnswer} KnowledgeAssistAnswer
                         */
                        KnowledgeAssistAnswer.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.KnowledgeAssistAnswer)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.KnowledgeAssistAnswer();
                            if (object.suggestedQuery != null) {
                                if (typeof object.suggestedQuery !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.KnowledgeAssistAnswer.suggestedQuery: object expected");
                                message.suggestedQuery = $root.google.cloud.dialogflow.v2.KnowledgeAssistAnswer.SuggestedQuery.fromObject(object.suggestedQuery);
                            }
                            if (object.suggestedQueryAnswer != null) {
                                if (typeof object.suggestedQueryAnswer !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.KnowledgeAssistAnswer.suggestedQueryAnswer: object expected");
                                message.suggestedQueryAnswer = $root.google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.fromObject(object.suggestedQueryAnswer);
                            }
                            if (object.answerRecord != null)
                                message.answerRecord = String(object.answerRecord);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a KnowledgeAssistAnswer message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer
                         * @static
                         * @param {google.cloud.dialogflow.v2.KnowledgeAssistAnswer} message KnowledgeAssistAnswer
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        KnowledgeAssistAnswer.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.suggestedQuery = null;
                                object.suggestedQueryAnswer = null;
                                object.answerRecord = "";
                            }
                            if (message.suggestedQuery != null && message.hasOwnProperty("suggestedQuery"))
                                object.suggestedQuery = $root.google.cloud.dialogflow.v2.KnowledgeAssistAnswer.SuggestedQuery.toObject(message.suggestedQuery, options);
                            if (message.suggestedQueryAnswer != null && message.hasOwnProperty("suggestedQueryAnswer"))
                                object.suggestedQueryAnswer = $root.google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.toObject(message.suggestedQueryAnswer, options);
                            if (message.answerRecord != null && message.hasOwnProperty("answerRecord"))
                                object.answerRecord = message.answerRecord;
                            return object;
                        };
    
                        /**
                         * Converts this KnowledgeAssistAnswer to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        KnowledgeAssistAnswer.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for KnowledgeAssistAnswer
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        KnowledgeAssistAnswer.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.KnowledgeAssistAnswer";
                        };
    
                        KnowledgeAssistAnswer.SuggestedQuery = (function() {
    
                            /**
                             * Properties of a SuggestedQuery.
                             * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer
                             * @interface ISuggestedQuery
                             * @property {string|null} [queryText] SuggestedQuery queryText
                             */
    
                            /**
                             * Constructs a new SuggestedQuery.
                             * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer
                             * @classdesc Represents a SuggestedQuery.
                             * @implements ISuggestedQuery
                             * @constructor
                             * @param {google.cloud.dialogflow.v2.KnowledgeAssistAnswer.ISuggestedQuery=} [properties] Properties to set
                             */
                            function SuggestedQuery(properties) {
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * SuggestedQuery queryText.
                             * @member {string} queryText
                             * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.SuggestedQuery
                             * @instance
                             */
                            SuggestedQuery.prototype.queryText = "";
    
                            /**
                             * Creates a new SuggestedQuery instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.SuggestedQuery
                             * @static
                             * @param {google.cloud.dialogflow.v2.KnowledgeAssistAnswer.ISuggestedQuery=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2.KnowledgeAssistAnswer.SuggestedQuery} SuggestedQuery instance
                             */
                            SuggestedQuery.create = function create(properties) {
                                return new SuggestedQuery(properties);
                            };
    
                            /**
                             * Encodes the specified SuggestedQuery message. Does not implicitly {@link google.cloud.dialogflow.v2.KnowledgeAssistAnswer.SuggestedQuery.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.SuggestedQuery
                             * @static
                             * @param {google.cloud.dialogflow.v2.KnowledgeAssistAnswer.ISuggestedQuery} message SuggestedQuery message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            SuggestedQuery.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.queryText != null && Object.hasOwnProperty.call(message, "queryText"))
                                    writer.uint32(/* id 1, wireType 2 =*/10).string(message.queryText);
                                return writer;
                            };
    
                            /**
                             * Encodes the specified SuggestedQuery message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.KnowledgeAssistAnswer.SuggestedQuery.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.SuggestedQuery
                             * @static
                             * @param {google.cloud.dialogflow.v2.KnowledgeAssistAnswer.ISuggestedQuery} message SuggestedQuery message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            SuggestedQuery.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a SuggestedQuery message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.SuggestedQuery
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2.KnowledgeAssistAnswer.SuggestedQuery} SuggestedQuery
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            SuggestedQuery.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.KnowledgeAssistAnswer.SuggestedQuery();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.queryText = reader.string();
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a SuggestedQuery message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.SuggestedQuery
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2.KnowledgeAssistAnswer.SuggestedQuery} SuggestedQuery
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            SuggestedQuery.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a SuggestedQuery message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.SuggestedQuery
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            SuggestedQuery.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.queryText != null && message.hasOwnProperty("queryText"))
                                    if (!$util.isString(message.queryText))
                                        return "queryText: string expected";
                                return null;
                            };
    
                            /**
                             * Creates a SuggestedQuery message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.SuggestedQuery
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2.KnowledgeAssistAnswer.SuggestedQuery} SuggestedQuery
                             */
                            SuggestedQuery.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2.KnowledgeAssistAnswer.SuggestedQuery)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2.KnowledgeAssistAnswer.SuggestedQuery();
                                if (object.queryText != null)
                                    message.queryText = String(object.queryText);
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a SuggestedQuery message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.SuggestedQuery
                             * @static
                             * @param {google.cloud.dialogflow.v2.KnowledgeAssistAnswer.SuggestedQuery} message SuggestedQuery
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            SuggestedQuery.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.defaults)
                                    object.queryText = "";
                                if (message.queryText != null && message.hasOwnProperty("queryText"))
                                    object.queryText = message.queryText;
                                return object;
                            };
    
                            /**
                             * Converts this SuggestedQuery to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.SuggestedQuery
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            SuggestedQuery.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for SuggestedQuery
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.SuggestedQuery
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            SuggestedQuery.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2.KnowledgeAssistAnswer.SuggestedQuery";
                            };
    
                            return SuggestedQuery;
                        })();
    
                        KnowledgeAssistAnswer.KnowledgeAnswer = (function() {
    
                            /**
                             * Properties of a KnowledgeAnswer.
                             * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer
                             * @interface IKnowledgeAnswer
                             * @property {string|null} [answerText] KnowledgeAnswer answerText
                             * @property {google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.IFaqSource|null} [faqSource] KnowledgeAnswer faqSource
                             * @property {google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.IGenerativeSource|null} [generativeSource] KnowledgeAnswer generativeSource
                             */
    
                            /**
                             * Constructs a new KnowledgeAnswer.
                             * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer
                             * @classdesc Represents a KnowledgeAnswer.
                             * @implements IKnowledgeAnswer
                             * @constructor
                             * @param {google.cloud.dialogflow.v2.KnowledgeAssistAnswer.IKnowledgeAnswer=} [properties] Properties to set
                             */
                            function KnowledgeAnswer(properties) {
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * KnowledgeAnswer answerText.
                             * @member {string} answerText
                             * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer
                             * @instance
                             */
                            KnowledgeAnswer.prototype.answerText = "";
    
                            /**
                             * KnowledgeAnswer faqSource.
                             * @member {google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.IFaqSource|null|undefined} faqSource
                             * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer
                             * @instance
                             */
                            KnowledgeAnswer.prototype.faqSource = null;
    
                            /**
                             * KnowledgeAnswer generativeSource.
                             * @member {google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.IGenerativeSource|null|undefined} generativeSource
                             * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer
                             * @instance
                             */
                            KnowledgeAnswer.prototype.generativeSource = null;
    
                            // OneOf field names bound to virtual getters and setters
                            var $oneOfFields;
    
                            /**
                             * KnowledgeAnswer source.
                             * @member {"faqSource"|"generativeSource"|undefined} source
                             * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer
                             * @instance
                             */
                            Object.defineProperty(KnowledgeAnswer.prototype, "source", {
                                get: $util.oneOfGetter($oneOfFields = ["faqSource", "generativeSource"]),
                                set: $util.oneOfSetter($oneOfFields)
                            });
    
                            /**
                             * Creates a new KnowledgeAnswer instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer
                             * @static
                             * @param {google.cloud.dialogflow.v2.KnowledgeAssistAnswer.IKnowledgeAnswer=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer} KnowledgeAnswer instance
                             */
                            KnowledgeAnswer.create = function create(properties) {
                                return new KnowledgeAnswer(properties);
                            };
    
                            /**
                             * Encodes the specified KnowledgeAnswer message. Does not implicitly {@link google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer
                             * @static
                             * @param {google.cloud.dialogflow.v2.KnowledgeAssistAnswer.IKnowledgeAnswer} message KnowledgeAnswer message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            KnowledgeAnswer.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.answerText != null && Object.hasOwnProperty.call(message, "answerText"))
                                    writer.uint32(/* id 1, wireType 2 =*/10).string(message.answerText);
                                if (message.faqSource != null && Object.hasOwnProperty.call(message, "faqSource"))
                                    $root.google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.FaqSource.encode(message.faqSource, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                                if (message.generativeSource != null && Object.hasOwnProperty.call(message, "generativeSource"))
                                    $root.google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.encode(message.generativeSource, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                                return writer;
                            };
    
                            /**
                             * Encodes the specified KnowledgeAnswer message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer
                             * @static
                             * @param {google.cloud.dialogflow.v2.KnowledgeAssistAnswer.IKnowledgeAnswer} message KnowledgeAnswer message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            KnowledgeAnswer.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a KnowledgeAnswer message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer} KnowledgeAnswer
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            KnowledgeAnswer.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.answerText = reader.string();
                                            break;
                                        }
                                    case 3: {
                                            message.faqSource = $root.google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.FaqSource.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 4: {
                                            message.generativeSource = $root.google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.decode(reader, reader.uint32());
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a KnowledgeAnswer message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer} KnowledgeAnswer
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            KnowledgeAnswer.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a KnowledgeAnswer message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            KnowledgeAnswer.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                var properties = {};
                                if (message.answerText != null && message.hasOwnProperty("answerText"))
                                    if (!$util.isString(message.answerText))
                                        return "answerText: string expected";
                                if (message.faqSource != null && message.hasOwnProperty("faqSource")) {
                                    properties.source = 1;
                                    {
                                        var error = $root.google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.FaqSource.verify(message.faqSource);
                                        if (error)
                                            return "faqSource." + error;
                                    }
                                }
                                if (message.generativeSource != null && message.hasOwnProperty("generativeSource")) {
                                    if (properties.source === 1)
                                        return "source: multiple values";
                                    properties.source = 1;
                                    {
                                        var error = $root.google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.verify(message.generativeSource);
                                        if (error)
                                            return "generativeSource." + error;
                                    }
                                }
                                return null;
                            };
    
                            /**
                             * Creates a KnowledgeAnswer message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer} KnowledgeAnswer
                             */
                            KnowledgeAnswer.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer();
                                if (object.answerText != null)
                                    message.answerText = String(object.answerText);
                                if (object.faqSource != null) {
                                    if (typeof object.faqSource !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.faqSource: object expected");
                                    message.faqSource = $root.google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.FaqSource.fromObject(object.faqSource);
                                }
                                if (object.generativeSource != null) {
                                    if (typeof object.generativeSource !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.generativeSource: object expected");
                                    message.generativeSource = $root.google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.fromObject(object.generativeSource);
                                }
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a KnowledgeAnswer message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer
                             * @static
                             * @param {google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer} message KnowledgeAnswer
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            KnowledgeAnswer.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.defaults)
                                    object.answerText = "";
                                if (message.answerText != null && message.hasOwnProperty("answerText"))
                                    object.answerText = message.answerText;
                                if (message.faqSource != null && message.hasOwnProperty("faqSource")) {
                                    object.faqSource = $root.google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.FaqSource.toObject(message.faqSource, options);
                                    if (options.oneofs)
                                        object.source = "faqSource";
                                }
                                if (message.generativeSource != null && message.hasOwnProperty("generativeSource")) {
                                    object.generativeSource = $root.google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.toObject(message.generativeSource, options);
                                    if (options.oneofs)
                                        object.source = "generativeSource";
                                }
                                return object;
                            };
    
                            /**
                             * Converts this KnowledgeAnswer to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            KnowledgeAnswer.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for KnowledgeAnswer
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            KnowledgeAnswer.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer";
                            };
    
                            KnowledgeAnswer.FaqSource = (function() {
    
                                /**
                                 * Properties of a FaqSource.
                                 * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer
                                 * @interface IFaqSource
                                 * @property {string|null} [question] FaqSource question
                                 */
    
                                /**
                                 * Constructs a new FaqSource.
                                 * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer
                                 * @classdesc Represents a FaqSource.
                                 * @implements IFaqSource
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.IFaqSource=} [properties] Properties to set
                                 */
                                function FaqSource(properties) {
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * FaqSource question.
                                 * @member {string} question
                                 * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.FaqSource
                                 * @instance
                                 */
                                FaqSource.prototype.question = "";
    
                                /**
                                 * Creates a new FaqSource instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.FaqSource
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.IFaqSource=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.FaqSource} FaqSource instance
                                 */
                                FaqSource.create = function create(properties) {
                                    return new FaqSource(properties);
                                };
    
                                /**
                                 * Encodes the specified FaqSource message. Does not implicitly {@link google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.FaqSource.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.FaqSource
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.IFaqSource} message FaqSource message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                FaqSource.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.question != null && Object.hasOwnProperty.call(message, "question"))
                                        writer.uint32(/* id 2, wireType 2 =*/18).string(message.question);
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified FaqSource message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.FaqSource.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.FaqSource
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.IFaqSource} message FaqSource message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                FaqSource.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a FaqSource message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.FaqSource
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.FaqSource} FaqSource
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                FaqSource.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.FaqSource();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 2: {
                                                message.question = reader.string();
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a FaqSource message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.FaqSource
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.FaqSource} FaqSource
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                FaqSource.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a FaqSource message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.FaqSource
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                FaqSource.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.question != null && message.hasOwnProperty("question"))
                                        if (!$util.isString(message.question))
                                            return "question: string expected";
                                    return null;
                                };
    
                                /**
                                 * Creates a FaqSource message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.FaqSource
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.FaqSource} FaqSource
                                 */
                                FaqSource.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.FaqSource)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.FaqSource();
                                    if (object.question != null)
                                        message.question = String(object.question);
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a FaqSource message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.FaqSource
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.FaqSource} message FaqSource
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                FaqSource.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.defaults)
                                        object.question = "";
                                    if (message.question != null && message.hasOwnProperty("question"))
                                        object.question = message.question;
                                    return object;
                                };
    
                                /**
                                 * Converts this FaqSource to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.FaqSource
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                FaqSource.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for FaqSource
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.FaqSource
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                FaqSource.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.FaqSource";
                                };
    
                                return FaqSource;
                            })();
    
                            KnowledgeAnswer.GenerativeSource = (function() {
    
                                /**
                                 * Properties of a GenerativeSource.
                                 * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer
                                 * @interface IGenerativeSource
                                 * @property {Array.<google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.ISnippet>|null} [snippets] GenerativeSource snippets
                                 */
    
                                /**
                                 * Constructs a new GenerativeSource.
                                 * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer
                                 * @classdesc Represents a GenerativeSource.
                                 * @implements IGenerativeSource
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.IGenerativeSource=} [properties] Properties to set
                                 */
                                function GenerativeSource(properties) {
                                    this.snippets = [];
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * GenerativeSource snippets.
                                 * @member {Array.<google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.ISnippet>} snippets
                                 * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource
                                 * @instance
                                 */
                                GenerativeSource.prototype.snippets = $util.emptyArray;
    
                                /**
                                 * Creates a new GenerativeSource instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.IGenerativeSource=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource} GenerativeSource instance
                                 */
                                GenerativeSource.create = function create(properties) {
                                    return new GenerativeSource(properties);
                                };
    
                                /**
                                 * Encodes the specified GenerativeSource message. Does not implicitly {@link google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.IGenerativeSource} message GenerativeSource message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                GenerativeSource.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.snippets != null && message.snippets.length)
                                        for (var i = 0; i < message.snippets.length; ++i)
                                            $root.google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet.encode(message.snippets[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified GenerativeSource message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.IGenerativeSource} message GenerativeSource message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                GenerativeSource.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a GenerativeSource message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource} GenerativeSource
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                GenerativeSource.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                if (!(message.snippets && message.snippets.length))
                                                    message.snippets = [];
                                                message.snippets.push($root.google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet.decode(reader, reader.uint32()));
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a GenerativeSource message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource} GenerativeSource
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                GenerativeSource.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a GenerativeSource message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                GenerativeSource.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.snippets != null && message.hasOwnProperty("snippets")) {
                                        if (!Array.isArray(message.snippets))
                                            return "snippets: array expected";
                                        for (var i = 0; i < message.snippets.length; ++i) {
                                            var error = $root.google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet.verify(message.snippets[i]);
                                            if (error)
                                                return "snippets." + error;
                                        }
                                    }
                                    return null;
                                };
    
                                /**
                                 * Creates a GenerativeSource message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource} GenerativeSource
                                 */
                                GenerativeSource.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource();
                                    if (object.snippets) {
                                        if (!Array.isArray(object.snippets))
                                            throw TypeError(".google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.snippets: array expected");
                                        message.snippets = [];
                                        for (var i = 0; i < object.snippets.length; ++i) {
                                            if (typeof object.snippets[i] !== "object")
                                                throw TypeError(".google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.snippets: object expected");
                                            message.snippets[i] = $root.google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet.fromObject(object.snippets[i]);
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a GenerativeSource message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource} message GenerativeSource
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                GenerativeSource.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.arrays || options.defaults)
                                        object.snippets = [];
                                    if (message.snippets && message.snippets.length) {
                                        object.snippets = [];
                                        for (var j = 0; j < message.snippets.length; ++j)
                                            object.snippets[j] = $root.google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet.toObject(message.snippets[j], options);
                                    }
                                    return object;
                                };
    
                                /**
                                 * Converts this GenerativeSource to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                GenerativeSource.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for GenerativeSource
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                GenerativeSource.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource";
                                };
    
                                GenerativeSource.Snippet = (function() {
    
                                    /**
                                     * Properties of a Snippet.
                                     * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource
                                     * @interface ISnippet
                                     * @property {string|null} [uri] Snippet uri
                                     * @property {string|null} [text] Snippet text
                                     * @property {string|null} [title] Snippet title
                                     * @property {google.protobuf.IStruct|null} [metadata] Snippet metadata
                                     */
    
                                    /**
                                     * Constructs a new Snippet.
                                     * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource
                                     * @classdesc Represents a Snippet.
                                     * @implements ISnippet
                                     * @constructor
                                     * @param {google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.ISnippet=} [properties] Properties to set
                                     */
                                    function Snippet(properties) {
                                        if (properties)
                                            for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                                if (properties[keys[i]] != null)
                                                    this[keys[i]] = properties[keys[i]];
                                    }
    
                                    /**
                                     * Snippet uri.
                                     * @member {string} uri
                                     * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet
                                     * @instance
                                     */
                                    Snippet.prototype.uri = "";
    
                                    /**
                                     * Snippet text.
                                     * @member {string} text
                                     * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet
                                     * @instance
                                     */
                                    Snippet.prototype.text = "";
    
                                    /**
                                     * Snippet title.
                                     * @member {string} title
                                     * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet
                                     * @instance
                                     */
                                    Snippet.prototype.title = "";
    
                                    /**
                                     * Snippet metadata.
                                     * @member {google.protobuf.IStruct|null|undefined} metadata
                                     * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet
                                     * @instance
                                     */
                                    Snippet.prototype.metadata = null;
    
                                    /**
                                     * Creates a new Snippet instance using the specified properties.
                                     * @function create
                                     * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet
                                     * @static
                                     * @param {google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.ISnippet=} [properties] Properties to set
                                     * @returns {google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet} Snippet instance
                                     */
                                    Snippet.create = function create(properties) {
                                        return new Snippet(properties);
                                    };
    
                                    /**
                                     * Encodes the specified Snippet message. Does not implicitly {@link google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet.verify|verify} messages.
                                     * @function encode
                                     * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet
                                     * @static
                                     * @param {google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.ISnippet} message Snippet message or plain object to encode
                                     * @param {$protobuf.Writer} [writer] Writer to encode to
                                     * @returns {$protobuf.Writer} Writer
                                     */
                                    Snippet.encode = function encode(message, writer) {
                                        if (!writer)
                                            writer = $Writer.create();
                                        if (message.uri != null && Object.hasOwnProperty.call(message, "uri"))
                                            writer.uint32(/* id 2, wireType 2 =*/18).string(message.uri);
                                        if (message.text != null && Object.hasOwnProperty.call(message, "text"))
                                            writer.uint32(/* id 3, wireType 2 =*/26).string(message.text);
                                        if (message.title != null && Object.hasOwnProperty.call(message, "title"))
                                            writer.uint32(/* id 4, wireType 2 =*/34).string(message.title);
                                        if (message.metadata != null && Object.hasOwnProperty.call(message, "metadata"))
                                            $root.google.protobuf.Struct.encode(message.metadata, writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                                        return writer;
                                    };
    
                                    /**
                                     * Encodes the specified Snippet message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet.verify|verify} messages.
                                     * @function encodeDelimited
                                     * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet
                                     * @static
                                     * @param {google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.ISnippet} message Snippet message or plain object to encode
                                     * @param {$protobuf.Writer} [writer] Writer to encode to
                                     * @returns {$protobuf.Writer} Writer
                                     */
                                    Snippet.encodeDelimited = function encodeDelimited(message, writer) {
                                        return this.encode(message, writer).ldelim();
                                    };
    
                                    /**
                                     * Decodes a Snippet message from the specified reader or buffer.
                                     * @function decode
                                     * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet
                                     * @static
                                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                     * @param {number} [length] Message length if known beforehand
                                     * @returns {google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet} Snippet
                                     * @throws {Error} If the payload is not a reader or valid buffer
                                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                     */
                                    Snippet.decode = function decode(reader, length) {
                                        if (!(reader instanceof $Reader))
                                            reader = $Reader.create(reader);
                                        var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet();
                                        while (reader.pos < end) {
                                            var tag = reader.uint32();
                                            switch (tag >>> 3) {
                                            case 2: {
                                                    message.uri = reader.string();
                                                    break;
                                                }
                                            case 3: {
                                                    message.text = reader.string();
                                                    break;
                                                }
                                            case 4: {
                                                    message.title = reader.string();
                                                    break;
                                                }
                                            case 5: {
                                                    message.metadata = $root.google.protobuf.Struct.decode(reader, reader.uint32());
                                                    break;
                                                }
                                            default:
                                                reader.skipType(tag & 7);
                                                break;
                                            }
                                        }
                                        return message;
                                    };
    
                                    /**
                                     * Decodes a Snippet message from the specified reader or buffer, length delimited.
                                     * @function decodeDelimited
                                     * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet
                                     * @static
                                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                     * @returns {google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet} Snippet
                                     * @throws {Error} If the payload is not a reader or valid buffer
                                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                     */
                                    Snippet.decodeDelimited = function decodeDelimited(reader) {
                                        if (!(reader instanceof $Reader))
                                            reader = new $Reader(reader);
                                        return this.decode(reader, reader.uint32());
                                    };
    
                                    /**
                                     * Verifies a Snippet message.
                                     * @function verify
                                     * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet
                                     * @static
                                     * @param {Object.<string,*>} message Plain object to verify
                                     * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                     */
                                    Snippet.verify = function verify(message) {
                                        if (typeof message !== "object" || message === null)
                                            return "object expected";
                                        if (message.uri != null && message.hasOwnProperty("uri"))
                                            if (!$util.isString(message.uri))
                                                return "uri: string expected";
                                        if (message.text != null && message.hasOwnProperty("text"))
                                            if (!$util.isString(message.text))
                                                return "text: string expected";
                                        if (message.title != null && message.hasOwnProperty("title"))
                                            if (!$util.isString(message.title))
                                                return "title: string expected";
                                        if (message.metadata != null && message.hasOwnProperty("metadata")) {
                                            var error = $root.google.protobuf.Struct.verify(message.metadata);
                                            if (error)
                                                return "metadata." + error;
                                        }
                                        return null;
                                    };
    
                                    /**
                                     * Creates a Snippet message from a plain object. Also converts values to their respective internal types.
                                     * @function fromObject
                                     * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet
                                     * @static
                                     * @param {Object.<string,*>} object Plain object
                                     * @returns {google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet} Snippet
                                     */
                                    Snippet.fromObject = function fromObject(object) {
                                        if (object instanceof $root.google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet)
                                            return object;
                                        var message = new $root.google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet();
                                        if (object.uri != null)
                                            message.uri = String(object.uri);
                                        if (object.text != null)
                                            message.text = String(object.text);
                                        if (object.title != null)
                                            message.title = String(object.title);
                                        if (object.metadata != null) {
                                            if (typeof object.metadata !== "object")
                                                throw TypeError(".google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet.metadata: object expected");
                                            message.metadata = $root.google.protobuf.Struct.fromObject(object.metadata);
                                        }
                                        return message;
                                    };
    
                                    /**
                                     * Creates a plain object from a Snippet message. Also converts values to other types if specified.
                                     * @function toObject
                                     * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet
                                     * @static
                                     * @param {google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet} message Snippet
                                     * @param {$protobuf.IConversionOptions} [options] Conversion options
                                     * @returns {Object.<string,*>} Plain object
                                     */
                                    Snippet.toObject = function toObject(message, options) {
                                        if (!options)
                                            options = {};
                                        var object = {};
                                        if (options.defaults) {
                                            object.uri = "";
                                            object.text = "";
                                            object.title = "";
                                            object.metadata = null;
                                        }
                                        if (message.uri != null && message.hasOwnProperty("uri"))
                                            object.uri = message.uri;
                                        if (message.text != null && message.hasOwnProperty("text"))
                                            object.text = message.text;
                                        if (message.title != null && message.hasOwnProperty("title"))
                                            object.title = message.title;
                                        if (message.metadata != null && message.hasOwnProperty("metadata"))
                                            object.metadata = $root.google.protobuf.Struct.toObject(message.metadata, options);
                                        return object;
                                    };
    
                                    /**
                                     * Converts this Snippet to JSON.
                                     * @function toJSON
                                     * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet
                                     * @instance
                                     * @returns {Object.<string,*>} JSON object
                                     */
                                    Snippet.prototype.toJSON = function toJSON() {
                                        return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                    };
    
                                    /**
                                     * Gets the default type url for Snippet
                                     * @function getTypeUrl
                                     * @memberof google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet
                                     * @static
                                     * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                     * @returns {string} The default type url
                                     */
                                    Snippet.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                        if (typeUrlPrefix === undefined) {
                                            typeUrlPrefix = "type.googleapis.com";
                                        }
                                        return typeUrlPrefix + "/google.cloud.dialogflow.v2.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet";
                                    };
    
                                    return Snippet;
                                })();
    
                                return GenerativeSource;
                            })();
    
                            return KnowledgeAnswer;
                        })();
    
                        return KnowledgeAssistAnswer;
                    })();
    
                    v2.SpeechContext = (function() {
    
                        /**
                         * Properties of a SpeechContext.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ISpeechContext
                         * @property {Array.<string>|null} [phrases] SpeechContext phrases
                         * @property {number|null} [boost] SpeechContext boost
                         */
    
                        /**
                         * Constructs a new SpeechContext.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a SpeechContext.
                         * @implements ISpeechContext
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ISpeechContext=} [properties] Properties to set
                         */
                        function SpeechContext(properties) {
                            this.phrases = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SpeechContext phrases.
                         * @member {Array.<string>} phrases
                         * @memberof google.cloud.dialogflow.v2.SpeechContext
                         * @instance
                         */
                        SpeechContext.prototype.phrases = $util.emptyArray;
    
                        /**
                         * SpeechContext boost.
                         * @member {number} boost
                         * @memberof google.cloud.dialogflow.v2.SpeechContext
                         * @instance
                         */
                        SpeechContext.prototype.boost = 0;
    
                        /**
                         * Creates a new SpeechContext instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.SpeechContext
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISpeechContext=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.SpeechContext} SpeechContext instance
                         */
                        SpeechContext.create = function create(properties) {
                            return new SpeechContext(properties);
                        };
    
                        /**
                         * Encodes the specified SpeechContext message. Does not implicitly {@link google.cloud.dialogflow.v2.SpeechContext.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.SpeechContext
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISpeechContext} message SpeechContext message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SpeechContext.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.phrases != null && message.phrases.length)
                                for (var i = 0; i < message.phrases.length; ++i)
                                    writer.uint32(/* id 1, wireType 2 =*/10).string(message.phrases[i]);
                            if (message.boost != null && Object.hasOwnProperty.call(message, "boost"))
                                writer.uint32(/* id 2, wireType 5 =*/21).float(message.boost);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SpeechContext message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.SpeechContext.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SpeechContext
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISpeechContext} message SpeechContext message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SpeechContext.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SpeechContext message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.SpeechContext
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.SpeechContext} SpeechContext
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SpeechContext.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.SpeechContext();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.phrases && message.phrases.length))
                                            message.phrases = [];
                                        message.phrases.push(reader.string());
                                        break;
                                    }
                                case 2: {
                                        message.boost = reader.float();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SpeechContext message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SpeechContext
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.SpeechContext} SpeechContext
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SpeechContext.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SpeechContext message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.SpeechContext
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SpeechContext.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.phrases != null && message.hasOwnProperty("phrases")) {
                                if (!Array.isArray(message.phrases))
                                    return "phrases: array expected";
                                for (var i = 0; i < message.phrases.length; ++i)
                                    if (!$util.isString(message.phrases[i]))
                                        return "phrases: string[] expected";
                            }
                            if (message.boost != null && message.hasOwnProperty("boost"))
                                if (typeof message.boost !== "number")
                                    return "boost: number expected";
                            return null;
                        };
    
                        /**
                         * Creates a SpeechContext message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.SpeechContext
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.SpeechContext} SpeechContext
                         */
                        SpeechContext.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.SpeechContext)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.SpeechContext();
                            if (object.phrases) {
                                if (!Array.isArray(object.phrases))
                                    throw TypeError(".google.cloud.dialogflow.v2.SpeechContext.phrases: array expected");
                                message.phrases = [];
                                for (var i = 0; i < object.phrases.length; ++i)
                                    message.phrases[i] = String(object.phrases[i]);
                            }
                            if (object.boost != null)
                                message.boost = Number(object.boost);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SpeechContext message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.SpeechContext
                         * @static
                         * @param {google.cloud.dialogflow.v2.SpeechContext} message SpeechContext
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SpeechContext.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.phrases = [];
                            if (options.defaults)
                                object.boost = 0;
                            if (message.phrases && message.phrases.length) {
                                object.phrases = [];
                                for (var j = 0; j < message.phrases.length; ++j)
                                    object.phrases[j] = message.phrases[j];
                            }
                            if (message.boost != null && message.hasOwnProperty("boost"))
                                object.boost = options.json && !isFinite(message.boost) ? String(message.boost) : message.boost;
                            return object;
                        };
    
                        /**
                         * Converts this SpeechContext to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.SpeechContext
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SpeechContext.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SpeechContext
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.SpeechContext
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SpeechContext.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.SpeechContext";
                        };
    
                        return SpeechContext;
                    })();
    
                    v2.SpeechWordInfo = (function() {
    
                        /**
                         * Properties of a SpeechWordInfo.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ISpeechWordInfo
                         * @property {string|null} [word] SpeechWordInfo word
                         * @property {google.protobuf.IDuration|null} [startOffset] SpeechWordInfo startOffset
                         * @property {google.protobuf.IDuration|null} [endOffset] SpeechWordInfo endOffset
                         * @property {number|null} [confidence] SpeechWordInfo confidence
                         */
    
                        /**
                         * Constructs a new SpeechWordInfo.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a SpeechWordInfo.
                         * @implements ISpeechWordInfo
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ISpeechWordInfo=} [properties] Properties to set
                         */
                        function SpeechWordInfo(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SpeechWordInfo word.
                         * @member {string} word
                         * @memberof google.cloud.dialogflow.v2.SpeechWordInfo
                         * @instance
                         */
                        SpeechWordInfo.prototype.word = "";
    
                        /**
                         * SpeechWordInfo startOffset.
                         * @member {google.protobuf.IDuration|null|undefined} startOffset
                         * @memberof google.cloud.dialogflow.v2.SpeechWordInfo
                         * @instance
                         */
                        SpeechWordInfo.prototype.startOffset = null;
    
                        /**
                         * SpeechWordInfo endOffset.
                         * @member {google.protobuf.IDuration|null|undefined} endOffset
                         * @memberof google.cloud.dialogflow.v2.SpeechWordInfo
                         * @instance
                         */
                        SpeechWordInfo.prototype.endOffset = null;
    
                        /**
                         * SpeechWordInfo confidence.
                         * @member {number} confidence
                         * @memberof google.cloud.dialogflow.v2.SpeechWordInfo
                         * @instance
                         */
                        SpeechWordInfo.prototype.confidence = 0;
    
                        /**
                         * Creates a new SpeechWordInfo instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.SpeechWordInfo
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISpeechWordInfo=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.SpeechWordInfo} SpeechWordInfo instance
                         */
                        SpeechWordInfo.create = function create(properties) {
                            return new SpeechWordInfo(properties);
                        };
    
                        /**
                         * Encodes the specified SpeechWordInfo message. Does not implicitly {@link google.cloud.dialogflow.v2.SpeechWordInfo.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.SpeechWordInfo
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISpeechWordInfo} message SpeechWordInfo message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SpeechWordInfo.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.startOffset != null && Object.hasOwnProperty.call(message, "startOffset"))
                                $root.google.protobuf.Duration.encode(message.startOffset, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.endOffset != null && Object.hasOwnProperty.call(message, "endOffset"))
                                $root.google.protobuf.Duration.encode(message.endOffset, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.word != null && Object.hasOwnProperty.call(message, "word"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.word);
                            if (message.confidence != null && Object.hasOwnProperty.call(message, "confidence"))
                                writer.uint32(/* id 4, wireType 5 =*/37).float(message.confidence);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SpeechWordInfo message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.SpeechWordInfo.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SpeechWordInfo
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISpeechWordInfo} message SpeechWordInfo message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SpeechWordInfo.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SpeechWordInfo message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.SpeechWordInfo
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.SpeechWordInfo} SpeechWordInfo
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SpeechWordInfo.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.SpeechWordInfo();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 3: {
                                        message.word = reader.string();
                                        break;
                                    }
                                case 1: {
                                        message.startOffset = $root.google.protobuf.Duration.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.endOffset = $root.google.protobuf.Duration.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 4: {
                                        message.confidence = reader.float();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SpeechWordInfo message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SpeechWordInfo
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.SpeechWordInfo} SpeechWordInfo
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SpeechWordInfo.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SpeechWordInfo message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.SpeechWordInfo
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SpeechWordInfo.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.word != null && message.hasOwnProperty("word"))
                                if (!$util.isString(message.word))
                                    return "word: string expected";
                            if (message.startOffset != null && message.hasOwnProperty("startOffset")) {
                                var error = $root.google.protobuf.Duration.verify(message.startOffset);
                                if (error)
                                    return "startOffset." + error;
                            }
                            if (message.endOffset != null && message.hasOwnProperty("endOffset")) {
                                var error = $root.google.protobuf.Duration.verify(message.endOffset);
                                if (error)
                                    return "endOffset." + error;
                            }
                            if (message.confidence != null && message.hasOwnProperty("confidence"))
                                if (typeof message.confidence !== "number")
                                    return "confidence: number expected";
                            return null;
                        };
    
                        /**
                         * Creates a SpeechWordInfo message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.SpeechWordInfo
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.SpeechWordInfo} SpeechWordInfo
                         */
                        SpeechWordInfo.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.SpeechWordInfo)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.SpeechWordInfo();
                            if (object.word != null)
                                message.word = String(object.word);
                            if (object.startOffset != null) {
                                if (typeof object.startOffset !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.SpeechWordInfo.startOffset: object expected");
                                message.startOffset = $root.google.protobuf.Duration.fromObject(object.startOffset);
                            }
                            if (object.endOffset != null) {
                                if (typeof object.endOffset !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.SpeechWordInfo.endOffset: object expected");
                                message.endOffset = $root.google.protobuf.Duration.fromObject(object.endOffset);
                            }
                            if (object.confidence != null)
                                message.confidence = Number(object.confidence);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SpeechWordInfo message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.SpeechWordInfo
                         * @static
                         * @param {google.cloud.dialogflow.v2.SpeechWordInfo} message SpeechWordInfo
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SpeechWordInfo.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.startOffset = null;
                                object.endOffset = null;
                                object.word = "";
                                object.confidence = 0;
                            }
                            if (message.startOffset != null && message.hasOwnProperty("startOffset"))
                                object.startOffset = $root.google.protobuf.Duration.toObject(message.startOffset, options);
                            if (message.endOffset != null && message.hasOwnProperty("endOffset"))
                                object.endOffset = $root.google.protobuf.Duration.toObject(message.endOffset, options);
                            if (message.word != null && message.hasOwnProperty("word"))
                                object.word = message.word;
                            if (message.confidence != null && message.hasOwnProperty("confidence"))
                                object.confidence = options.json && !isFinite(message.confidence) ? String(message.confidence) : message.confidence;
                            return object;
                        };
    
                        /**
                         * Converts this SpeechWordInfo to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.SpeechWordInfo
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SpeechWordInfo.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SpeechWordInfo
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.SpeechWordInfo
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SpeechWordInfo.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.SpeechWordInfo";
                        };
    
                        return SpeechWordInfo;
                    })();
    
                    v2.InputAudioConfig = (function() {
    
                        /**
                         * Properties of an InputAudioConfig.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IInputAudioConfig
                         * @property {google.cloud.dialogflow.v2.AudioEncoding|null} [audioEncoding] InputAudioConfig audioEncoding
                         * @property {number|null} [sampleRateHertz] InputAudioConfig sampleRateHertz
                         * @property {string|null} [languageCode] InputAudioConfig languageCode
                         * @property {boolean|null} [enableWordInfo] InputAudioConfig enableWordInfo
                         * @property {Array.<string>|null} [phraseHints] InputAudioConfig phraseHints
                         * @property {Array.<google.cloud.dialogflow.v2.ISpeechContext>|null} [speechContexts] InputAudioConfig speechContexts
                         * @property {string|null} [model] InputAudioConfig model
                         * @property {google.cloud.dialogflow.v2.SpeechModelVariant|null} [modelVariant] InputAudioConfig modelVariant
                         * @property {boolean|null} [singleUtterance] InputAudioConfig singleUtterance
                         * @property {boolean|null} [disableNoSpeechRecognizedEvent] InputAudioConfig disableNoSpeechRecognizedEvent
                         * @property {boolean|null} [enableAutomaticPunctuation] InputAudioConfig enableAutomaticPunctuation
                         * @property {Array.<string>|null} [phraseSets] InputAudioConfig phraseSets
                         * @property {boolean|null} [optOutConformerModelMigration] InputAudioConfig optOutConformerModelMigration
                         */
    
                        /**
                         * Constructs a new InputAudioConfig.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an InputAudioConfig.
                         * @implements IInputAudioConfig
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IInputAudioConfig=} [properties] Properties to set
                         */
                        function InputAudioConfig(properties) {
                            this.phraseHints = [];
                            this.speechContexts = [];
                            this.phraseSets = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * InputAudioConfig audioEncoding.
                         * @member {google.cloud.dialogflow.v2.AudioEncoding} audioEncoding
                         * @memberof google.cloud.dialogflow.v2.InputAudioConfig
                         * @instance
                         */
                        InputAudioConfig.prototype.audioEncoding = 0;
    
                        /**
                         * InputAudioConfig sampleRateHertz.
                         * @member {number} sampleRateHertz
                         * @memberof google.cloud.dialogflow.v2.InputAudioConfig
                         * @instance
                         */
                        InputAudioConfig.prototype.sampleRateHertz = 0;
    
                        /**
                         * InputAudioConfig languageCode.
                         * @member {string} languageCode
                         * @memberof google.cloud.dialogflow.v2.InputAudioConfig
                         * @instance
                         */
                        InputAudioConfig.prototype.languageCode = "";
    
                        /**
                         * InputAudioConfig enableWordInfo.
                         * @member {boolean} enableWordInfo
                         * @memberof google.cloud.dialogflow.v2.InputAudioConfig
                         * @instance
                         */
                        InputAudioConfig.prototype.enableWordInfo = false;
    
                        /**
                         * InputAudioConfig phraseHints.
                         * @member {Array.<string>} phraseHints
                         * @memberof google.cloud.dialogflow.v2.InputAudioConfig
                         * @instance
                         */
                        InputAudioConfig.prototype.phraseHints = $util.emptyArray;
    
                        /**
                         * InputAudioConfig speechContexts.
                         * @member {Array.<google.cloud.dialogflow.v2.ISpeechContext>} speechContexts
                         * @memberof google.cloud.dialogflow.v2.InputAudioConfig
                         * @instance
                         */
                        InputAudioConfig.prototype.speechContexts = $util.emptyArray;
    
                        /**
                         * InputAudioConfig model.
                         * @member {string} model
                         * @memberof google.cloud.dialogflow.v2.InputAudioConfig
                         * @instance
                         */
                        InputAudioConfig.prototype.model = "";
    
                        /**
                         * InputAudioConfig modelVariant.
                         * @member {google.cloud.dialogflow.v2.SpeechModelVariant} modelVariant
                         * @memberof google.cloud.dialogflow.v2.InputAudioConfig
                         * @instance
                         */
                        InputAudioConfig.prototype.modelVariant = 0;
    
                        /**
                         * InputAudioConfig singleUtterance.
                         * @member {boolean} singleUtterance
                         * @memberof google.cloud.dialogflow.v2.InputAudioConfig
                         * @instance
                         */
                        InputAudioConfig.prototype.singleUtterance = false;
    
                        /**
                         * InputAudioConfig disableNoSpeechRecognizedEvent.
                         * @member {boolean} disableNoSpeechRecognizedEvent
                         * @memberof google.cloud.dialogflow.v2.InputAudioConfig
                         * @instance
                         */
                        InputAudioConfig.prototype.disableNoSpeechRecognizedEvent = false;
    
                        /**
                         * InputAudioConfig enableAutomaticPunctuation.
                         * @member {boolean} enableAutomaticPunctuation
                         * @memberof google.cloud.dialogflow.v2.InputAudioConfig
                         * @instance
                         */
                        InputAudioConfig.prototype.enableAutomaticPunctuation = false;
    
                        /**
                         * InputAudioConfig phraseSets.
                         * @member {Array.<string>} phraseSets
                         * @memberof google.cloud.dialogflow.v2.InputAudioConfig
                         * @instance
                         */
                        InputAudioConfig.prototype.phraseSets = $util.emptyArray;
    
                        /**
                         * InputAudioConfig optOutConformerModelMigration.
                         * @member {boolean} optOutConformerModelMigration
                         * @memberof google.cloud.dialogflow.v2.InputAudioConfig
                         * @instance
                         */
                        InputAudioConfig.prototype.optOutConformerModelMigration = false;
    
                        /**
                         * Creates a new InputAudioConfig instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.InputAudioConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2.IInputAudioConfig=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.InputAudioConfig} InputAudioConfig instance
                         */
                        InputAudioConfig.create = function create(properties) {
                            return new InputAudioConfig(properties);
                        };
    
                        /**
                         * Encodes the specified InputAudioConfig message. Does not implicitly {@link google.cloud.dialogflow.v2.InputAudioConfig.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.InputAudioConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2.IInputAudioConfig} message InputAudioConfig message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        InputAudioConfig.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.audioEncoding != null && Object.hasOwnProperty.call(message, "audioEncoding"))
                                writer.uint32(/* id 1, wireType 0 =*/8).int32(message.audioEncoding);
                            if (message.sampleRateHertz != null && Object.hasOwnProperty.call(message, "sampleRateHertz"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.sampleRateHertz);
                            if (message.languageCode != null && Object.hasOwnProperty.call(message, "languageCode"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.languageCode);
                            if (message.phraseHints != null && message.phraseHints.length)
                                for (var i = 0; i < message.phraseHints.length; ++i)
                                    writer.uint32(/* id 4, wireType 2 =*/34).string(message.phraseHints[i]);
                            if (message.model != null && Object.hasOwnProperty.call(message, "model"))
                                writer.uint32(/* id 7, wireType 2 =*/58).string(message.model);
                            if (message.singleUtterance != null && Object.hasOwnProperty.call(message, "singleUtterance"))
                                writer.uint32(/* id 8, wireType 0 =*/64).bool(message.singleUtterance);
                            if (message.modelVariant != null && Object.hasOwnProperty.call(message, "modelVariant"))
                                writer.uint32(/* id 10, wireType 0 =*/80).int32(message.modelVariant);
                            if (message.speechContexts != null && message.speechContexts.length)
                                for (var i = 0; i < message.speechContexts.length; ++i)
                                    $root.google.cloud.dialogflow.v2.SpeechContext.encode(message.speechContexts[i], writer.uint32(/* id 11, wireType 2 =*/90).fork()).ldelim();
                            if (message.enableWordInfo != null && Object.hasOwnProperty.call(message, "enableWordInfo"))
                                writer.uint32(/* id 13, wireType 0 =*/104).bool(message.enableWordInfo);
                            if (message.disableNoSpeechRecognizedEvent != null && Object.hasOwnProperty.call(message, "disableNoSpeechRecognizedEvent"))
                                writer.uint32(/* id 14, wireType 0 =*/112).bool(message.disableNoSpeechRecognizedEvent);
                            if (message.enableAutomaticPunctuation != null && Object.hasOwnProperty.call(message, "enableAutomaticPunctuation"))
                                writer.uint32(/* id 17, wireType 0 =*/136).bool(message.enableAutomaticPunctuation);
                            if (message.phraseSets != null && message.phraseSets.length)
                                for (var i = 0; i < message.phraseSets.length; ++i)
                                    writer.uint32(/* id 20, wireType 2 =*/162).string(message.phraseSets[i]);
                            if (message.optOutConformerModelMigration != null && Object.hasOwnProperty.call(message, "optOutConformerModelMigration"))
                                writer.uint32(/* id 26, wireType 0 =*/208).bool(message.optOutConformerModelMigration);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified InputAudioConfig message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.InputAudioConfig.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.InputAudioConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2.IInputAudioConfig} message InputAudioConfig message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        InputAudioConfig.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an InputAudioConfig message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.InputAudioConfig
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.InputAudioConfig} InputAudioConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        InputAudioConfig.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.InputAudioConfig();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.audioEncoding = reader.int32();
                                        break;
                                    }
                                case 2: {
                                        message.sampleRateHertz = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.languageCode = reader.string();
                                        break;
                                    }
                                case 13: {
                                        message.enableWordInfo = reader.bool();
                                        break;
                                    }
                                case 4: {
                                        if (!(message.phraseHints && message.phraseHints.length))
                                            message.phraseHints = [];
                                        message.phraseHints.push(reader.string());
                                        break;
                                    }
                                case 11: {
                                        if (!(message.speechContexts && message.speechContexts.length))
                                            message.speechContexts = [];
                                        message.speechContexts.push($root.google.cloud.dialogflow.v2.SpeechContext.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 7: {
                                        message.model = reader.string();
                                        break;
                                    }
                                case 10: {
                                        message.modelVariant = reader.int32();
                                        break;
                                    }
                                case 8: {
                                        message.singleUtterance = reader.bool();
                                        break;
                                    }
                                case 14: {
                                        message.disableNoSpeechRecognizedEvent = reader.bool();
                                        break;
                                    }
                                case 17: {
                                        message.enableAutomaticPunctuation = reader.bool();
                                        break;
                                    }
                                case 20: {
                                        if (!(message.phraseSets && message.phraseSets.length))
                                            message.phraseSets = [];
                                        message.phraseSets.push(reader.string());
                                        break;
                                    }
                                case 26: {
                                        message.optOutConformerModelMigration = reader.bool();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an InputAudioConfig message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.InputAudioConfig
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.InputAudioConfig} InputAudioConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        InputAudioConfig.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an InputAudioConfig message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.InputAudioConfig
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        InputAudioConfig.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.audioEncoding != null && message.hasOwnProperty("audioEncoding"))
                                switch (message.audioEncoding) {
                                default:
                                    return "audioEncoding: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                case 4:
                                case 5:
                                case 6:
                                case 7:
                                case 8:
                                    break;
                                }
                            if (message.sampleRateHertz != null && message.hasOwnProperty("sampleRateHertz"))
                                if (!$util.isInteger(message.sampleRateHertz))
                                    return "sampleRateHertz: integer expected";
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                if (!$util.isString(message.languageCode))
                                    return "languageCode: string expected";
                            if (message.enableWordInfo != null && message.hasOwnProperty("enableWordInfo"))
                                if (typeof message.enableWordInfo !== "boolean")
                                    return "enableWordInfo: boolean expected";
                            if (message.phraseHints != null && message.hasOwnProperty("phraseHints")) {
                                if (!Array.isArray(message.phraseHints))
                                    return "phraseHints: array expected";
                                for (var i = 0; i < message.phraseHints.length; ++i)
                                    if (!$util.isString(message.phraseHints[i]))
                                        return "phraseHints: string[] expected";
                            }
                            if (message.speechContexts != null && message.hasOwnProperty("speechContexts")) {
                                if (!Array.isArray(message.speechContexts))
                                    return "speechContexts: array expected";
                                for (var i = 0; i < message.speechContexts.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.SpeechContext.verify(message.speechContexts[i]);
                                    if (error)
                                        return "speechContexts." + error;
                                }
                            }
                            if (message.model != null && message.hasOwnProperty("model"))
                                if (!$util.isString(message.model))
                                    return "model: string expected";
                            if (message.modelVariant != null && message.hasOwnProperty("modelVariant"))
                                switch (message.modelVariant) {
                                default:
                                    return "modelVariant: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                    break;
                                }
                            if (message.singleUtterance != null && message.hasOwnProperty("singleUtterance"))
                                if (typeof message.singleUtterance !== "boolean")
                                    return "singleUtterance: boolean expected";
                            if (message.disableNoSpeechRecognizedEvent != null && message.hasOwnProperty("disableNoSpeechRecognizedEvent"))
                                if (typeof message.disableNoSpeechRecognizedEvent !== "boolean")
                                    return "disableNoSpeechRecognizedEvent: boolean expected";
                            if (message.enableAutomaticPunctuation != null && message.hasOwnProperty("enableAutomaticPunctuation"))
                                if (typeof message.enableAutomaticPunctuation !== "boolean")
                                    return "enableAutomaticPunctuation: boolean expected";
                            if (message.phraseSets != null && message.hasOwnProperty("phraseSets")) {
                                if (!Array.isArray(message.phraseSets))
                                    return "phraseSets: array expected";
                                for (var i = 0; i < message.phraseSets.length; ++i)
                                    if (!$util.isString(message.phraseSets[i]))
                                        return "phraseSets: string[] expected";
                            }
                            if (message.optOutConformerModelMigration != null && message.hasOwnProperty("optOutConformerModelMigration"))
                                if (typeof message.optOutConformerModelMigration !== "boolean")
                                    return "optOutConformerModelMigration: boolean expected";
                            return null;
                        };
    
                        /**
                         * Creates an InputAudioConfig message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.InputAudioConfig
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.InputAudioConfig} InputAudioConfig
                         */
                        InputAudioConfig.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.InputAudioConfig)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.InputAudioConfig();
                            switch (object.audioEncoding) {
                            default:
                                if (typeof object.audioEncoding === "number") {
                                    message.audioEncoding = object.audioEncoding;
                                    break;
                                }
                                break;
                            case "AUDIO_ENCODING_UNSPECIFIED":
                            case 0:
                                message.audioEncoding = 0;
                                break;
                            case "AUDIO_ENCODING_LINEAR_16":
                            case 1:
                                message.audioEncoding = 1;
                                break;
                            case "AUDIO_ENCODING_FLAC":
                            case 2:
                                message.audioEncoding = 2;
                                break;
                            case "AUDIO_ENCODING_MULAW":
                            case 3:
                                message.audioEncoding = 3;
                                break;
                            case "AUDIO_ENCODING_AMR":
                            case 4:
                                message.audioEncoding = 4;
                                break;
                            case "AUDIO_ENCODING_AMR_WB":
                            case 5:
                                message.audioEncoding = 5;
                                break;
                            case "AUDIO_ENCODING_OGG_OPUS":
                            case 6:
                                message.audioEncoding = 6;
                                break;
                            case "AUDIO_ENCODING_SPEEX_WITH_HEADER_BYTE":
                            case 7:
                                message.audioEncoding = 7;
                                break;
                            case "AUDIO_ENCODING_ALAW":
                            case 8:
                                message.audioEncoding = 8;
                                break;
                            }
                            if (object.sampleRateHertz != null)
                                message.sampleRateHertz = object.sampleRateHertz | 0;
                            if (object.languageCode != null)
                                message.languageCode = String(object.languageCode);
                            if (object.enableWordInfo != null)
                                message.enableWordInfo = Boolean(object.enableWordInfo);
                            if (object.phraseHints) {
                                if (!Array.isArray(object.phraseHints))
                                    throw TypeError(".google.cloud.dialogflow.v2.InputAudioConfig.phraseHints: array expected");
                                message.phraseHints = [];
                                for (var i = 0; i < object.phraseHints.length; ++i)
                                    message.phraseHints[i] = String(object.phraseHints[i]);
                            }
                            if (object.speechContexts) {
                                if (!Array.isArray(object.speechContexts))
                                    throw TypeError(".google.cloud.dialogflow.v2.InputAudioConfig.speechContexts: array expected");
                                message.speechContexts = [];
                                for (var i = 0; i < object.speechContexts.length; ++i) {
                                    if (typeof object.speechContexts[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.InputAudioConfig.speechContexts: object expected");
                                    message.speechContexts[i] = $root.google.cloud.dialogflow.v2.SpeechContext.fromObject(object.speechContexts[i]);
                                }
                            }
                            if (object.model != null)
                                message.model = String(object.model);
                            switch (object.modelVariant) {
                            default:
                                if (typeof object.modelVariant === "number") {
                                    message.modelVariant = object.modelVariant;
                                    break;
                                }
                                break;
                            case "SPEECH_MODEL_VARIANT_UNSPECIFIED":
                            case 0:
                                message.modelVariant = 0;
                                break;
                            case "USE_BEST_AVAILABLE":
                            case 1:
                                message.modelVariant = 1;
                                break;
                            case "USE_STANDARD":
                            case 2:
                                message.modelVariant = 2;
                                break;
                            case "USE_ENHANCED":
                            case 3:
                                message.modelVariant = 3;
                                break;
                            }
                            if (object.singleUtterance != null)
                                message.singleUtterance = Boolean(object.singleUtterance);
                            if (object.disableNoSpeechRecognizedEvent != null)
                                message.disableNoSpeechRecognizedEvent = Boolean(object.disableNoSpeechRecognizedEvent);
                            if (object.enableAutomaticPunctuation != null)
                                message.enableAutomaticPunctuation = Boolean(object.enableAutomaticPunctuation);
                            if (object.phraseSets) {
                                if (!Array.isArray(object.phraseSets))
                                    throw TypeError(".google.cloud.dialogflow.v2.InputAudioConfig.phraseSets: array expected");
                                message.phraseSets = [];
                                for (var i = 0; i < object.phraseSets.length; ++i)
                                    message.phraseSets[i] = String(object.phraseSets[i]);
                            }
                            if (object.optOutConformerModelMigration != null)
                                message.optOutConformerModelMigration = Boolean(object.optOutConformerModelMigration);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an InputAudioConfig message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.InputAudioConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2.InputAudioConfig} message InputAudioConfig
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        InputAudioConfig.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults) {
                                object.phraseHints = [];
                                object.speechContexts = [];
                                object.phraseSets = [];
                            }
                            if (options.defaults) {
                                object.audioEncoding = options.enums === String ? "AUDIO_ENCODING_UNSPECIFIED" : 0;
                                object.sampleRateHertz = 0;
                                object.languageCode = "";
                                object.model = "";
                                object.singleUtterance = false;
                                object.modelVariant = options.enums === String ? "SPEECH_MODEL_VARIANT_UNSPECIFIED" : 0;
                                object.enableWordInfo = false;
                                object.disableNoSpeechRecognizedEvent = false;
                                object.enableAutomaticPunctuation = false;
                                object.optOutConformerModelMigration = false;
                            }
                            if (message.audioEncoding != null && message.hasOwnProperty("audioEncoding"))
                                object.audioEncoding = options.enums === String ? $root.google.cloud.dialogflow.v2.AudioEncoding[message.audioEncoding] === undefined ? message.audioEncoding : $root.google.cloud.dialogflow.v2.AudioEncoding[message.audioEncoding] : message.audioEncoding;
                            if (message.sampleRateHertz != null && message.hasOwnProperty("sampleRateHertz"))
                                object.sampleRateHertz = message.sampleRateHertz;
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                object.languageCode = message.languageCode;
                            if (message.phraseHints && message.phraseHints.length) {
                                object.phraseHints = [];
                                for (var j = 0; j < message.phraseHints.length; ++j)
                                    object.phraseHints[j] = message.phraseHints[j];
                            }
                            if (message.model != null && message.hasOwnProperty("model"))
                                object.model = message.model;
                            if (message.singleUtterance != null && message.hasOwnProperty("singleUtterance"))
                                object.singleUtterance = message.singleUtterance;
                            if (message.modelVariant != null && message.hasOwnProperty("modelVariant"))
                                object.modelVariant = options.enums === String ? $root.google.cloud.dialogflow.v2.SpeechModelVariant[message.modelVariant] === undefined ? message.modelVariant : $root.google.cloud.dialogflow.v2.SpeechModelVariant[message.modelVariant] : message.modelVariant;
                            if (message.speechContexts && message.speechContexts.length) {
                                object.speechContexts = [];
                                for (var j = 0; j < message.speechContexts.length; ++j)
                                    object.speechContexts[j] = $root.google.cloud.dialogflow.v2.SpeechContext.toObject(message.speechContexts[j], options);
                            }
                            if (message.enableWordInfo != null && message.hasOwnProperty("enableWordInfo"))
                                object.enableWordInfo = message.enableWordInfo;
                            if (message.disableNoSpeechRecognizedEvent != null && message.hasOwnProperty("disableNoSpeechRecognizedEvent"))
                                object.disableNoSpeechRecognizedEvent = message.disableNoSpeechRecognizedEvent;
                            if (message.enableAutomaticPunctuation != null && message.hasOwnProperty("enableAutomaticPunctuation"))
                                object.enableAutomaticPunctuation = message.enableAutomaticPunctuation;
                            if (message.phraseSets && message.phraseSets.length) {
                                object.phraseSets = [];
                                for (var j = 0; j < message.phraseSets.length; ++j)
                                    object.phraseSets[j] = message.phraseSets[j];
                            }
                            if (message.optOutConformerModelMigration != null && message.hasOwnProperty("optOutConformerModelMigration"))
                                object.optOutConformerModelMigration = message.optOutConformerModelMigration;
                            return object;
                        };
    
                        /**
                         * Converts this InputAudioConfig to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.InputAudioConfig
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        InputAudioConfig.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for InputAudioConfig
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.InputAudioConfig
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        InputAudioConfig.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.InputAudioConfig";
                        };
    
                        return InputAudioConfig;
                    })();
    
                    v2.VoiceSelectionParams = (function() {
    
                        /**
                         * Properties of a VoiceSelectionParams.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IVoiceSelectionParams
                         * @property {string|null} [name] VoiceSelectionParams name
                         * @property {google.cloud.dialogflow.v2.SsmlVoiceGender|null} [ssmlGender] VoiceSelectionParams ssmlGender
                         */
    
                        /**
                         * Constructs a new VoiceSelectionParams.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a VoiceSelectionParams.
                         * @implements IVoiceSelectionParams
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IVoiceSelectionParams=} [properties] Properties to set
                         */
                        function VoiceSelectionParams(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * VoiceSelectionParams name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2.VoiceSelectionParams
                         * @instance
                         */
                        VoiceSelectionParams.prototype.name = "";
    
                        /**
                         * VoiceSelectionParams ssmlGender.
                         * @member {google.cloud.dialogflow.v2.SsmlVoiceGender} ssmlGender
                         * @memberof google.cloud.dialogflow.v2.VoiceSelectionParams
                         * @instance
                         */
                        VoiceSelectionParams.prototype.ssmlGender = 0;
    
                        /**
                         * Creates a new VoiceSelectionParams instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.VoiceSelectionParams
                         * @static
                         * @param {google.cloud.dialogflow.v2.IVoiceSelectionParams=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.VoiceSelectionParams} VoiceSelectionParams instance
                         */
                        VoiceSelectionParams.create = function create(properties) {
                            return new VoiceSelectionParams(properties);
                        };
    
                        /**
                         * Encodes the specified VoiceSelectionParams message. Does not implicitly {@link google.cloud.dialogflow.v2.VoiceSelectionParams.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.VoiceSelectionParams
                         * @static
                         * @param {google.cloud.dialogflow.v2.IVoiceSelectionParams} message VoiceSelectionParams message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        VoiceSelectionParams.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            if (message.ssmlGender != null && Object.hasOwnProperty.call(message, "ssmlGender"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.ssmlGender);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified VoiceSelectionParams message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.VoiceSelectionParams.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.VoiceSelectionParams
                         * @static
                         * @param {google.cloud.dialogflow.v2.IVoiceSelectionParams} message VoiceSelectionParams message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        VoiceSelectionParams.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a VoiceSelectionParams message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.VoiceSelectionParams
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.VoiceSelectionParams} VoiceSelectionParams
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        VoiceSelectionParams.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.VoiceSelectionParams();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.ssmlGender = reader.int32();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a VoiceSelectionParams message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.VoiceSelectionParams
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.VoiceSelectionParams} VoiceSelectionParams
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        VoiceSelectionParams.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a VoiceSelectionParams message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.VoiceSelectionParams
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        VoiceSelectionParams.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            if (message.ssmlGender != null && message.hasOwnProperty("ssmlGender"))
                                switch (message.ssmlGender) {
                                default:
                                    return "ssmlGender: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                    break;
                                }
                            return null;
                        };
    
                        /**
                         * Creates a VoiceSelectionParams message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.VoiceSelectionParams
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.VoiceSelectionParams} VoiceSelectionParams
                         */
                        VoiceSelectionParams.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.VoiceSelectionParams)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.VoiceSelectionParams();
                            if (object.name != null)
                                message.name = String(object.name);
                            switch (object.ssmlGender) {
                            default:
                                if (typeof object.ssmlGender === "number") {
                                    message.ssmlGender = object.ssmlGender;
                                    break;
                                }
                                break;
                            case "SSML_VOICE_GENDER_UNSPECIFIED":
                            case 0:
                                message.ssmlGender = 0;
                                break;
                            case "SSML_VOICE_GENDER_MALE":
                            case 1:
                                message.ssmlGender = 1;
                                break;
                            case "SSML_VOICE_GENDER_FEMALE":
                            case 2:
                                message.ssmlGender = 2;
                                break;
                            case "SSML_VOICE_GENDER_NEUTRAL":
                            case 3:
                                message.ssmlGender = 3;
                                break;
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a VoiceSelectionParams message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.VoiceSelectionParams
                         * @static
                         * @param {google.cloud.dialogflow.v2.VoiceSelectionParams} message VoiceSelectionParams
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        VoiceSelectionParams.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.name = "";
                                object.ssmlGender = options.enums === String ? "SSML_VOICE_GENDER_UNSPECIFIED" : 0;
                            }
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            if (message.ssmlGender != null && message.hasOwnProperty("ssmlGender"))
                                object.ssmlGender = options.enums === String ? $root.google.cloud.dialogflow.v2.SsmlVoiceGender[message.ssmlGender] === undefined ? message.ssmlGender : $root.google.cloud.dialogflow.v2.SsmlVoiceGender[message.ssmlGender] : message.ssmlGender;
                            return object;
                        };
    
                        /**
                         * Converts this VoiceSelectionParams to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.VoiceSelectionParams
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        VoiceSelectionParams.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for VoiceSelectionParams
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.VoiceSelectionParams
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        VoiceSelectionParams.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.VoiceSelectionParams";
                        };
    
                        return VoiceSelectionParams;
                    })();
    
                    v2.SynthesizeSpeechConfig = (function() {
    
                        /**
                         * Properties of a SynthesizeSpeechConfig.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ISynthesizeSpeechConfig
                         * @property {number|null} [speakingRate] SynthesizeSpeechConfig speakingRate
                         * @property {number|null} [pitch] SynthesizeSpeechConfig pitch
                         * @property {number|null} [volumeGainDb] SynthesizeSpeechConfig volumeGainDb
                         * @property {Array.<string>|null} [effectsProfileId] SynthesizeSpeechConfig effectsProfileId
                         * @property {google.cloud.dialogflow.v2.IVoiceSelectionParams|null} [voice] SynthesizeSpeechConfig voice
                         */
    
                        /**
                         * Constructs a new SynthesizeSpeechConfig.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a SynthesizeSpeechConfig.
                         * @implements ISynthesizeSpeechConfig
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ISynthesizeSpeechConfig=} [properties] Properties to set
                         */
                        function SynthesizeSpeechConfig(properties) {
                            this.effectsProfileId = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SynthesizeSpeechConfig speakingRate.
                         * @member {number} speakingRate
                         * @memberof google.cloud.dialogflow.v2.SynthesizeSpeechConfig
                         * @instance
                         */
                        SynthesizeSpeechConfig.prototype.speakingRate = 0;
    
                        /**
                         * SynthesizeSpeechConfig pitch.
                         * @member {number} pitch
                         * @memberof google.cloud.dialogflow.v2.SynthesizeSpeechConfig
                         * @instance
                         */
                        SynthesizeSpeechConfig.prototype.pitch = 0;
    
                        /**
                         * SynthesizeSpeechConfig volumeGainDb.
                         * @member {number} volumeGainDb
                         * @memberof google.cloud.dialogflow.v2.SynthesizeSpeechConfig
                         * @instance
                         */
                        SynthesizeSpeechConfig.prototype.volumeGainDb = 0;
    
                        /**
                         * SynthesizeSpeechConfig effectsProfileId.
                         * @member {Array.<string>} effectsProfileId
                         * @memberof google.cloud.dialogflow.v2.SynthesizeSpeechConfig
                         * @instance
                         */
                        SynthesizeSpeechConfig.prototype.effectsProfileId = $util.emptyArray;
    
                        /**
                         * SynthesizeSpeechConfig voice.
                         * @member {google.cloud.dialogflow.v2.IVoiceSelectionParams|null|undefined} voice
                         * @memberof google.cloud.dialogflow.v2.SynthesizeSpeechConfig
                         * @instance
                         */
                        SynthesizeSpeechConfig.prototype.voice = null;
    
                        /**
                         * Creates a new SynthesizeSpeechConfig instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.SynthesizeSpeechConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISynthesizeSpeechConfig=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.SynthesizeSpeechConfig} SynthesizeSpeechConfig instance
                         */
                        SynthesizeSpeechConfig.create = function create(properties) {
                            return new SynthesizeSpeechConfig(properties);
                        };
    
                        /**
                         * Encodes the specified SynthesizeSpeechConfig message. Does not implicitly {@link google.cloud.dialogflow.v2.SynthesizeSpeechConfig.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.SynthesizeSpeechConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISynthesizeSpeechConfig} message SynthesizeSpeechConfig message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SynthesizeSpeechConfig.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.speakingRate != null && Object.hasOwnProperty.call(message, "speakingRate"))
                                writer.uint32(/* id 1, wireType 1 =*/9).double(message.speakingRate);
                            if (message.pitch != null && Object.hasOwnProperty.call(message, "pitch"))
                                writer.uint32(/* id 2, wireType 1 =*/17).double(message.pitch);
                            if (message.volumeGainDb != null && Object.hasOwnProperty.call(message, "volumeGainDb"))
                                writer.uint32(/* id 3, wireType 1 =*/25).double(message.volumeGainDb);
                            if (message.voice != null && Object.hasOwnProperty.call(message, "voice"))
                                $root.google.cloud.dialogflow.v2.VoiceSelectionParams.encode(message.voice, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            if (message.effectsProfileId != null && message.effectsProfileId.length)
                                for (var i = 0; i < message.effectsProfileId.length; ++i)
                                    writer.uint32(/* id 5, wireType 2 =*/42).string(message.effectsProfileId[i]);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SynthesizeSpeechConfig message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.SynthesizeSpeechConfig.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SynthesizeSpeechConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISynthesizeSpeechConfig} message SynthesizeSpeechConfig message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SynthesizeSpeechConfig.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SynthesizeSpeechConfig message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.SynthesizeSpeechConfig
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.SynthesizeSpeechConfig} SynthesizeSpeechConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SynthesizeSpeechConfig.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.SynthesizeSpeechConfig();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.speakingRate = reader.double();
                                        break;
                                    }
                                case 2: {
                                        message.pitch = reader.double();
                                        break;
                                    }
                                case 3: {
                                        message.volumeGainDb = reader.double();
                                        break;
                                    }
                                case 5: {
                                        if (!(message.effectsProfileId && message.effectsProfileId.length))
                                            message.effectsProfileId = [];
                                        message.effectsProfileId.push(reader.string());
                                        break;
                                    }
                                case 4: {
                                        message.voice = $root.google.cloud.dialogflow.v2.VoiceSelectionParams.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SynthesizeSpeechConfig message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SynthesizeSpeechConfig
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.SynthesizeSpeechConfig} SynthesizeSpeechConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SynthesizeSpeechConfig.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SynthesizeSpeechConfig message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.SynthesizeSpeechConfig
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SynthesizeSpeechConfig.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.speakingRate != null && message.hasOwnProperty("speakingRate"))
                                if (typeof message.speakingRate !== "number")
                                    return "speakingRate: number expected";
                            if (message.pitch != null && message.hasOwnProperty("pitch"))
                                if (typeof message.pitch !== "number")
                                    return "pitch: number expected";
                            if (message.volumeGainDb != null && message.hasOwnProperty("volumeGainDb"))
                                if (typeof message.volumeGainDb !== "number")
                                    return "volumeGainDb: number expected";
                            if (message.effectsProfileId != null && message.hasOwnProperty("effectsProfileId")) {
                                if (!Array.isArray(message.effectsProfileId))
                                    return "effectsProfileId: array expected";
                                for (var i = 0; i < message.effectsProfileId.length; ++i)
                                    if (!$util.isString(message.effectsProfileId[i]))
                                        return "effectsProfileId: string[] expected";
                            }
                            if (message.voice != null && message.hasOwnProperty("voice")) {
                                var error = $root.google.cloud.dialogflow.v2.VoiceSelectionParams.verify(message.voice);
                                if (error)
                                    return "voice." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a SynthesizeSpeechConfig message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.SynthesizeSpeechConfig
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.SynthesizeSpeechConfig} SynthesizeSpeechConfig
                         */
                        SynthesizeSpeechConfig.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.SynthesizeSpeechConfig)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.SynthesizeSpeechConfig();
                            if (object.speakingRate != null)
                                message.speakingRate = Number(object.speakingRate);
                            if (object.pitch != null)
                                message.pitch = Number(object.pitch);
                            if (object.volumeGainDb != null)
                                message.volumeGainDb = Number(object.volumeGainDb);
                            if (object.effectsProfileId) {
                                if (!Array.isArray(object.effectsProfileId))
                                    throw TypeError(".google.cloud.dialogflow.v2.SynthesizeSpeechConfig.effectsProfileId: array expected");
                                message.effectsProfileId = [];
                                for (var i = 0; i < object.effectsProfileId.length; ++i)
                                    message.effectsProfileId[i] = String(object.effectsProfileId[i]);
                            }
                            if (object.voice != null) {
                                if (typeof object.voice !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.SynthesizeSpeechConfig.voice: object expected");
                                message.voice = $root.google.cloud.dialogflow.v2.VoiceSelectionParams.fromObject(object.voice);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SynthesizeSpeechConfig message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.SynthesizeSpeechConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2.SynthesizeSpeechConfig} message SynthesizeSpeechConfig
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SynthesizeSpeechConfig.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.effectsProfileId = [];
                            if (options.defaults) {
                                object.speakingRate = 0;
                                object.pitch = 0;
                                object.volumeGainDb = 0;
                                object.voice = null;
                            }
                            if (message.speakingRate != null && message.hasOwnProperty("speakingRate"))
                                object.speakingRate = options.json && !isFinite(message.speakingRate) ? String(message.speakingRate) : message.speakingRate;
                            if (message.pitch != null && message.hasOwnProperty("pitch"))
                                object.pitch = options.json && !isFinite(message.pitch) ? String(message.pitch) : message.pitch;
                            if (message.volumeGainDb != null && message.hasOwnProperty("volumeGainDb"))
                                object.volumeGainDb = options.json && !isFinite(message.volumeGainDb) ? String(message.volumeGainDb) : message.volumeGainDb;
                            if (message.voice != null && message.hasOwnProperty("voice"))
                                object.voice = $root.google.cloud.dialogflow.v2.VoiceSelectionParams.toObject(message.voice, options);
                            if (message.effectsProfileId && message.effectsProfileId.length) {
                                object.effectsProfileId = [];
                                for (var j = 0; j < message.effectsProfileId.length; ++j)
                                    object.effectsProfileId[j] = message.effectsProfileId[j];
                            }
                            return object;
                        };
    
                        /**
                         * Converts this SynthesizeSpeechConfig to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.SynthesizeSpeechConfig
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SynthesizeSpeechConfig.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SynthesizeSpeechConfig
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.SynthesizeSpeechConfig
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SynthesizeSpeechConfig.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.SynthesizeSpeechConfig";
                        };
    
                        return SynthesizeSpeechConfig;
                    })();
    
                    v2.OutputAudioConfig = (function() {
    
                        /**
                         * Properties of an OutputAudioConfig.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IOutputAudioConfig
                         * @property {google.cloud.dialogflow.v2.OutputAudioEncoding|null} [audioEncoding] OutputAudioConfig audioEncoding
                         * @property {number|null} [sampleRateHertz] OutputAudioConfig sampleRateHertz
                         * @property {google.cloud.dialogflow.v2.ISynthesizeSpeechConfig|null} [synthesizeSpeechConfig] OutputAudioConfig synthesizeSpeechConfig
                         */
    
                        /**
                         * Constructs a new OutputAudioConfig.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an OutputAudioConfig.
                         * @implements IOutputAudioConfig
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IOutputAudioConfig=} [properties] Properties to set
                         */
                        function OutputAudioConfig(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * OutputAudioConfig audioEncoding.
                         * @member {google.cloud.dialogflow.v2.OutputAudioEncoding} audioEncoding
                         * @memberof google.cloud.dialogflow.v2.OutputAudioConfig
                         * @instance
                         */
                        OutputAudioConfig.prototype.audioEncoding = 0;
    
                        /**
                         * OutputAudioConfig sampleRateHertz.
                         * @member {number} sampleRateHertz
                         * @memberof google.cloud.dialogflow.v2.OutputAudioConfig
                         * @instance
                         */
                        OutputAudioConfig.prototype.sampleRateHertz = 0;
    
                        /**
                         * OutputAudioConfig synthesizeSpeechConfig.
                         * @member {google.cloud.dialogflow.v2.ISynthesizeSpeechConfig|null|undefined} synthesizeSpeechConfig
                         * @memberof google.cloud.dialogflow.v2.OutputAudioConfig
                         * @instance
                         */
                        OutputAudioConfig.prototype.synthesizeSpeechConfig = null;
    
                        /**
                         * Creates a new OutputAudioConfig instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.OutputAudioConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2.IOutputAudioConfig=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.OutputAudioConfig} OutputAudioConfig instance
                         */
                        OutputAudioConfig.create = function create(properties) {
                            return new OutputAudioConfig(properties);
                        };
    
                        /**
                         * Encodes the specified OutputAudioConfig message. Does not implicitly {@link google.cloud.dialogflow.v2.OutputAudioConfig.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.OutputAudioConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2.IOutputAudioConfig} message OutputAudioConfig message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        OutputAudioConfig.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.audioEncoding != null && Object.hasOwnProperty.call(message, "audioEncoding"))
                                writer.uint32(/* id 1, wireType 0 =*/8).int32(message.audioEncoding);
                            if (message.sampleRateHertz != null && Object.hasOwnProperty.call(message, "sampleRateHertz"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.sampleRateHertz);
                            if (message.synthesizeSpeechConfig != null && Object.hasOwnProperty.call(message, "synthesizeSpeechConfig"))
                                $root.google.cloud.dialogflow.v2.SynthesizeSpeechConfig.encode(message.synthesizeSpeechConfig, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified OutputAudioConfig message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.OutputAudioConfig.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.OutputAudioConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2.IOutputAudioConfig} message OutputAudioConfig message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        OutputAudioConfig.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an OutputAudioConfig message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.OutputAudioConfig
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.OutputAudioConfig} OutputAudioConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        OutputAudioConfig.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.OutputAudioConfig();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.audioEncoding = reader.int32();
                                        break;
                                    }
                                case 2: {
                                        message.sampleRateHertz = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.synthesizeSpeechConfig = $root.google.cloud.dialogflow.v2.SynthesizeSpeechConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an OutputAudioConfig message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.OutputAudioConfig
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.OutputAudioConfig} OutputAudioConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        OutputAudioConfig.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an OutputAudioConfig message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.OutputAudioConfig
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        OutputAudioConfig.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.audioEncoding != null && message.hasOwnProperty("audioEncoding"))
                                switch (message.audioEncoding) {
                                default:
                                    return "audioEncoding: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 4:
                                case 3:
                                case 5:
                                case 6:
                                    break;
                                }
                            if (message.sampleRateHertz != null && message.hasOwnProperty("sampleRateHertz"))
                                if (!$util.isInteger(message.sampleRateHertz))
                                    return "sampleRateHertz: integer expected";
                            if (message.synthesizeSpeechConfig != null && message.hasOwnProperty("synthesizeSpeechConfig")) {
                                var error = $root.google.cloud.dialogflow.v2.SynthesizeSpeechConfig.verify(message.synthesizeSpeechConfig);
                                if (error)
                                    return "synthesizeSpeechConfig." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates an OutputAudioConfig message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.OutputAudioConfig
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.OutputAudioConfig} OutputAudioConfig
                         */
                        OutputAudioConfig.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.OutputAudioConfig)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.OutputAudioConfig();
                            switch (object.audioEncoding) {
                            default:
                                if (typeof object.audioEncoding === "number") {
                                    message.audioEncoding = object.audioEncoding;
                                    break;
                                }
                                break;
                            case "OUTPUT_AUDIO_ENCODING_UNSPECIFIED":
                            case 0:
                                message.audioEncoding = 0;
                                break;
                            case "OUTPUT_AUDIO_ENCODING_LINEAR_16":
                            case 1:
                                message.audioEncoding = 1;
                                break;
                            case "OUTPUT_AUDIO_ENCODING_MP3":
                            case 2:
                                message.audioEncoding = 2;
                                break;
                            case "OUTPUT_AUDIO_ENCODING_MP3_64_KBPS":
                            case 4:
                                message.audioEncoding = 4;
                                break;
                            case "OUTPUT_AUDIO_ENCODING_OGG_OPUS":
                            case 3:
                                message.audioEncoding = 3;
                                break;
                            case "OUTPUT_AUDIO_ENCODING_MULAW":
                            case 5:
                                message.audioEncoding = 5;
                                break;
                            case "OUTPUT_AUDIO_ENCODING_ALAW":
                            case 6:
                                message.audioEncoding = 6;
                                break;
                            }
                            if (object.sampleRateHertz != null)
                                message.sampleRateHertz = object.sampleRateHertz | 0;
                            if (object.synthesizeSpeechConfig != null) {
                                if (typeof object.synthesizeSpeechConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.OutputAudioConfig.synthesizeSpeechConfig: object expected");
                                message.synthesizeSpeechConfig = $root.google.cloud.dialogflow.v2.SynthesizeSpeechConfig.fromObject(object.synthesizeSpeechConfig);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an OutputAudioConfig message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.OutputAudioConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2.OutputAudioConfig} message OutputAudioConfig
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        OutputAudioConfig.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.audioEncoding = options.enums === String ? "OUTPUT_AUDIO_ENCODING_UNSPECIFIED" : 0;
                                object.sampleRateHertz = 0;
                                object.synthesizeSpeechConfig = null;
                            }
                            if (message.audioEncoding != null && message.hasOwnProperty("audioEncoding"))
                                object.audioEncoding = options.enums === String ? $root.google.cloud.dialogflow.v2.OutputAudioEncoding[message.audioEncoding] === undefined ? message.audioEncoding : $root.google.cloud.dialogflow.v2.OutputAudioEncoding[message.audioEncoding] : message.audioEncoding;
                            if (message.sampleRateHertz != null && message.hasOwnProperty("sampleRateHertz"))
                                object.sampleRateHertz = message.sampleRateHertz;
                            if (message.synthesizeSpeechConfig != null && message.hasOwnProperty("synthesizeSpeechConfig"))
                                object.synthesizeSpeechConfig = $root.google.cloud.dialogflow.v2.SynthesizeSpeechConfig.toObject(message.synthesizeSpeechConfig, options);
                            return object;
                        };
    
                        /**
                         * Converts this OutputAudioConfig to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.OutputAudioConfig
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        OutputAudioConfig.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for OutputAudioConfig
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.OutputAudioConfig
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        OutputAudioConfig.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.OutputAudioConfig";
                        };
    
                        return OutputAudioConfig;
                    })();
    
                    v2.TelephonyDtmfEvents = (function() {
    
                        /**
                         * Properties of a TelephonyDtmfEvents.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ITelephonyDtmfEvents
                         * @property {Array.<google.cloud.dialogflow.v2.TelephonyDtmf>|null} [dtmfEvents] TelephonyDtmfEvents dtmfEvents
                         */
    
                        /**
                         * Constructs a new TelephonyDtmfEvents.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a TelephonyDtmfEvents.
                         * @implements ITelephonyDtmfEvents
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ITelephonyDtmfEvents=} [properties] Properties to set
                         */
                        function TelephonyDtmfEvents(properties) {
                            this.dtmfEvents = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * TelephonyDtmfEvents dtmfEvents.
                         * @member {Array.<google.cloud.dialogflow.v2.TelephonyDtmf>} dtmfEvents
                         * @memberof google.cloud.dialogflow.v2.TelephonyDtmfEvents
                         * @instance
                         */
                        TelephonyDtmfEvents.prototype.dtmfEvents = $util.emptyArray;
    
                        /**
                         * Creates a new TelephonyDtmfEvents instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.TelephonyDtmfEvents
                         * @static
                         * @param {google.cloud.dialogflow.v2.ITelephonyDtmfEvents=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.TelephonyDtmfEvents} TelephonyDtmfEvents instance
                         */
                        TelephonyDtmfEvents.create = function create(properties) {
                            return new TelephonyDtmfEvents(properties);
                        };
    
                        /**
                         * Encodes the specified TelephonyDtmfEvents message. Does not implicitly {@link google.cloud.dialogflow.v2.TelephonyDtmfEvents.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.TelephonyDtmfEvents
                         * @static
                         * @param {google.cloud.dialogflow.v2.ITelephonyDtmfEvents} message TelephonyDtmfEvents message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        TelephonyDtmfEvents.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.dtmfEvents != null && message.dtmfEvents.length) {
                                writer.uint32(/* id 1, wireType 2 =*/10).fork();
                                for (var i = 0; i < message.dtmfEvents.length; ++i)
                                    writer.int32(message.dtmfEvents[i]);
                                writer.ldelim();
                            }
                            return writer;
                        };
    
                        /**
                         * Encodes the specified TelephonyDtmfEvents message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.TelephonyDtmfEvents.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.TelephonyDtmfEvents
                         * @static
                         * @param {google.cloud.dialogflow.v2.ITelephonyDtmfEvents} message TelephonyDtmfEvents message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        TelephonyDtmfEvents.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a TelephonyDtmfEvents message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.TelephonyDtmfEvents
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.TelephonyDtmfEvents} TelephonyDtmfEvents
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        TelephonyDtmfEvents.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.TelephonyDtmfEvents();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.dtmfEvents && message.dtmfEvents.length))
                                            message.dtmfEvents = [];
                                        if ((tag & 7) === 2) {
                                            var end2 = reader.uint32() + reader.pos;
                                            while (reader.pos < end2)
                                                message.dtmfEvents.push(reader.int32());
                                        } else
                                            message.dtmfEvents.push(reader.int32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a TelephonyDtmfEvents message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.TelephonyDtmfEvents
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.TelephonyDtmfEvents} TelephonyDtmfEvents
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        TelephonyDtmfEvents.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a TelephonyDtmfEvents message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.TelephonyDtmfEvents
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        TelephonyDtmfEvents.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.dtmfEvents != null && message.hasOwnProperty("dtmfEvents")) {
                                if (!Array.isArray(message.dtmfEvents))
                                    return "dtmfEvents: array expected";
                                for (var i = 0; i < message.dtmfEvents.length; ++i)
                                    switch (message.dtmfEvents[i]) {
                                    default:
                                        return "dtmfEvents: enum value[] expected";
                                    case 0:
                                    case 1:
                                    case 2:
                                    case 3:
                                    case 4:
                                    case 5:
                                    case 6:
                                    case 7:
                                    case 8:
                                    case 9:
                                    case 10:
                                    case 11:
                                    case 12:
                                    case 13:
                                    case 14:
                                    case 15:
                                    case 16:
                                        break;
                                    }
                            }
                            return null;
                        };
    
                        /**
                         * Creates a TelephonyDtmfEvents message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.TelephonyDtmfEvents
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.TelephonyDtmfEvents} TelephonyDtmfEvents
                         */
                        TelephonyDtmfEvents.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.TelephonyDtmfEvents)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.TelephonyDtmfEvents();
                            if (object.dtmfEvents) {
                                if (!Array.isArray(object.dtmfEvents))
                                    throw TypeError(".google.cloud.dialogflow.v2.TelephonyDtmfEvents.dtmfEvents: array expected");
                                message.dtmfEvents = [];
                                for (var i = 0; i < object.dtmfEvents.length; ++i)
                                    switch (object.dtmfEvents[i]) {
                                    default:
                                        if (typeof object.dtmfEvents[i] === "number") {
                                            message.dtmfEvents[i] = object.dtmfEvents[i];
                                            break;
                                        }
                                    case "TELEPHONY_DTMF_UNSPECIFIED":
                                    case 0:
                                        message.dtmfEvents[i] = 0;
                                        break;
                                    case "DTMF_ONE":
                                    case 1:
                                        message.dtmfEvents[i] = 1;
                                        break;
                                    case "DTMF_TWO":
                                    case 2:
                                        message.dtmfEvents[i] = 2;
                                        break;
                                    case "DTMF_THREE":
                                    case 3:
                                        message.dtmfEvents[i] = 3;
                                        break;
                                    case "DTMF_FOUR":
                                    case 4:
                                        message.dtmfEvents[i] = 4;
                                        break;
                                    case "DTMF_FIVE":
                                    case 5:
                                        message.dtmfEvents[i] = 5;
                                        break;
                                    case "DTMF_SIX":
                                    case 6:
                                        message.dtmfEvents[i] = 6;
                                        break;
                                    case "DTMF_SEVEN":
                                    case 7:
                                        message.dtmfEvents[i] = 7;
                                        break;
                                    case "DTMF_EIGHT":
                                    case 8:
                                        message.dtmfEvents[i] = 8;
                                        break;
                                    case "DTMF_NINE":
                                    case 9:
                                        message.dtmfEvents[i] = 9;
                                        break;
                                    case "DTMF_ZERO":
                                    case 10:
                                        message.dtmfEvents[i] = 10;
                                        break;
                                    case "DTMF_A":
                                    case 11:
                                        message.dtmfEvents[i] = 11;
                                        break;
                                    case "DTMF_B":
                                    case 12:
                                        message.dtmfEvents[i] = 12;
                                        break;
                                    case "DTMF_C":
                                    case 13:
                                        message.dtmfEvents[i] = 13;
                                        break;
                                    case "DTMF_D":
                                    case 14:
                                        message.dtmfEvents[i] = 14;
                                        break;
                                    case "DTMF_STAR":
                                    case 15:
                                        message.dtmfEvents[i] = 15;
                                        break;
                                    case "DTMF_POUND":
                                    case 16:
                                        message.dtmfEvents[i] = 16;
                                        break;
                                    }
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a TelephonyDtmfEvents message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.TelephonyDtmfEvents
                         * @static
                         * @param {google.cloud.dialogflow.v2.TelephonyDtmfEvents} message TelephonyDtmfEvents
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        TelephonyDtmfEvents.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.dtmfEvents = [];
                            if (message.dtmfEvents && message.dtmfEvents.length) {
                                object.dtmfEvents = [];
                                for (var j = 0; j < message.dtmfEvents.length; ++j)
                                    object.dtmfEvents[j] = options.enums === String ? $root.google.cloud.dialogflow.v2.TelephonyDtmf[message.dtmfEvents[j]] === undefined ? message.dtmfEvents[j] : $root.google.cloud.dialogflow.v2.TelephonyDtmf[message.dtmfEvents[j]] : message.dtmfEvents[j];
                            }
                            return object;
                        };
    
                        /**
                         * Converts this TelephonyDtmfEvents to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.TelephonyDtmfEvents
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        TelephonyDtmfEvents.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for TelephonyDtmfEvents
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.TelephonyDtmfEvents
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        TelephonyDtmfEvents.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.TelephonyDtmfEvents";
                        };
    
                        return TelephonyDtmfEvents;
                    })();
    
                    v2.SpeechToTextConfig = (function() {
    
                        /**
                         * Properties of a SpeechToTextConfig.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ISpeechToTextConfig
                         * @property {google.cloud.dialogflow.v2.SpeechModelVariant|null} [speechModelVariant] SpeechToTextConfig speechModelVariant
                         * @property {string|null} [model] SpeechToTextConfig model
                         * @property {Array.<string>|null} [phraseSets] SpeechToTextConfig phraseSets
                         * @property {google.cloud.dialogflow.v2.AudioEncoding|null} [audioEncoding] SpeechToTextConfig audioEncoding
                         * @property {number|null} [sampleRateHertz] SpeechToTextConfig sampleRateHertz
                         * @property {string|null} [languageCode] SpeechToTextConfig languageCode
                         * @property {boolean|null} [enableWordInfo] SpeechToTextConfig enableWordInfo
                         * @property {boolean|null} [useTimeoutBasedEndpointing] SpeechToTextConfig useTimeoutBasedEndpointing
                         */
    
                        /**
                         * Constructs a new SpeechToTextConfig.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a SpeechToTextConfig.
                         * @implements ISpeechToTextConfig
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ISpeechToTextConfig=} [properties] Properties to set
                         */
                        function SpeechToTextConfig(properties) {
                            this.phraseSets = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SpeechToTextConfig speechModelVariant.
                         * @member {google.cloud.dialogflow.v2.SpeechModelVariant} speechModelVariant
                         * @memberof google.cloud.dialogflow.v2.SpeechToTextConfig
                         * @instance
                         */
                        SpeechToTextConfig.prototype.speechModelVariant = 0;
    
                        /**
                         * SpeechToTextConfig model.
                         * @member {string} model
                         * @memberof google.cloud.dialogflow.v2.SpeechToTextConfig
                         * @instance
                         */
                        SpeechToTextConfig.prototype.model = "";
    
                        /**
                         * SpeechToTextConfig phraseSets.
                         * @member {Array.<string>} phraseSets
                         * @memberof google.cloud.dialogflow.v2.SpeechToTextConfig
                         * @instance
                         */
                        SpeechToTextConfig.prototype.phraseSets = $util.emptyArray;
    
                        /**
                         * SpeechToTextConfig audioEncoding.
                         * @member {google.cloud.dialogflow.v2.AudioEncoding} audioEncoding
                         * @memberof google.cloud.dialogflow.v2.SpeechToTextConfig
                         * @instance
                         */
                        SpeechToTextConfig.prototype.audioEncoding = 0;
    
                        /**
                         * SpeechToTextConfig sampleRateHertz.
                         * @member {number} sampleRateHertz
                         * @memberof google.cloud.dialogflow.v2.SpeechToTextConfig
                         * @instance
                         */
                        SpeechToTextConfig.prototype.sampleRateHertz = 0;
    
                        /**
                         * SpeechToTextConfig languageCode.
                         * @member {string} languageCode
                         * @memberof google.cloud.dialogflow.v2.SpeechToTextConfig
                         * @instance
                         */
                        SpeechToTextConfig.prototype.languageCode = "";
    
                        /**
                         * SpeechToTextConfig enableWordInfo.
                         * @member {boolean} enableWordInfo
                         * @memberof google.cloud.dialogflow.v2.SpeechToTextConfig
                         * @instance
                         */
                        SpeechToTextConfig.prototype.enableWordInfo = false;
    
                        /**
                         * SpeechToTextConfig useTimeoutBasedEndpointing.
                         * @member {boolean} useTimeoutBasedEndpointing
                         * @memberof google.cloud.dialogflow.v2.SpeechToTextConfig
                         * @instance
                         */
                        SpeechToTextConfig.prototype.useTimeoutBasedEndpointing = false;
    
                        /**
                         * Creates a new SpeechToTextConfig instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.SpeechToTextConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISpeechToTextConfig=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.SpeechToTextConfig} SpeechToTextConfig instance
                         */
                        SpeechToTextConfig.create = function create(properties) {
                            return new SpeechToTextConfig(properties);
                        };
    
                        /**
                         * Encodes the specified SpeechToTextConfig message. Does not implicitly {@link google.cloud.dialogflow.v2.SpeechToTextConfig.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.SpeechToTextConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISpeechToTextConfig} message SpeechToTextConfig message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SpeechToTextConfig.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.speechModelVariant != null && Object.hasOwnProperty.call(message, "speechModelVariant"))
                                writer.uint32(/* id 1, wireType 0 =*/8).int32(message.speechModelVariant);
                            if (message.model != null && Object.hasOwnProperty.call(message, "model"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.model);
                            if (message.phraseSets != null && message.phraseSets.length)
                                for (var i = 0; i < message.phraseSets.length; ++i)
                                    writer.uint32(/* id 4, wireType 2 =*/34).string(message.phraseSets[i]);
                            if (message.audioEncoding != null && Object.hasOwnProperty.call(message, "audioEncoding"))
                                writer.uint32(/* id 6, wireType 0 =*/48).int32(message.audioEncoding);
                            if (message.sampleRateHertz != null && Object.hasOwnProperty.call(message, "sampleRateHertz"))
                                writer.uint32(/* id 7, wireType 0 =*/56).int32(message.sampleRateHertz);
                            if (message.languageCode != null && Object.hasOwnProperty.call(message, "languageCode"))
                                writer.uint32(/* id 8, wireType 2 =*/66).string(message.languageCode);
                            if (message.enableWordInfo != null && Object.hasOwnProperty.call(message, "enableWordInfo"))
                                writer.uint32(/* id 9, wireType 0 =*/72).bool(message.enableWordInfo);
                            if (message.useTimeoutBasedEndpointing != null && Object.hasOwnProperty.call(message, "useTimeoutBasedEndpointing"))
                                writer.uint32(/* id 11, wireType 0 =*/88).bool(message.useTimeoutBasedEndpointing);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SpeechToTextConfig message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.SpeechToTextConfig.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SpeechToTextConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISpeechToTextConfig} message SpeechToTextConfig message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SpeechToTextConfig.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SpeechToTextConfig message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.SpeechToTextConfig
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.SpeechToTextConfig} SpeechToTextConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SpeechToTextConfig.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.SpeechToTextConfig();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.speechModelVariant = reader.int32();
                                        break;
                                    }
                                case 2: {
                                        message.model = reader.string();
                                        break;
                                    }
                                case 4: {
                                        if (!(message.phraseSets && message.phraseSets.length))
                                            message.phraseSets = [];
                                        message.phraseSets.push(reader.string());
                                        break;
                                    }
                                case 6: {
                                        message.audioEncoding = reader.int32();
                                        break;
                                    }
                                case 7: {
                                        message.sampleRateHertz = reader.int32();
                                        break;
                                    }
                                case 8: {
                                        message.languageCode = reader.string();
                                        break;
                                    }
                                case 9: {
                                        message.enableWordInfo = reader.bool();
                                        break;
                                    }
                                case 11: {
                                        message.useTimeoutBasedEndpointing = reader.bool();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SpeechToTextConfig message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SpeechToTextConfig
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.SpeechToTextConfig} SpeechToTextConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SpeechToTextConfig.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SpeechToTextConfig message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.SpeechToTextConfig
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SpeechToTextConfig.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.speechModelVariant != null && message.hasOwnProperty("speechModelVariant"))
                                switch (message.speechModelVariant) {
                                default:
                                    return "speechModelVariant: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                    break;
                                }
                            if (message.model != null && message.hasOwnProperty("model"))
                                if (!$util.isString(message.model))
                                    return "model: string expected";
                            if (message.phraseSets != null && message.hasOwnProperty("phraseSets")) {
                                if (!Array.isArray(message.phraseSets))
                                    return "phraseSets: array expected";
                                for (var i = 0; i < message.phraseSets.length; ++i)
                                    if (!$util.isString(message.phraseSets[i]))
                                        return "phraseSets: string[] expected";
                            }
                            if (message.audioEncoding != null && message.hasOwnProperty("audioEncoding"))
                                switch (message.audioEncoding) {
                                default:
                                    return "audioEncoding: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                case 4:
                                case 5:
                                case 6:
                                case 7:
                                case 8:
                                    break;
                                }
                            if (message.sampleRateHertz != null && message.hasOwnProperty("sampleRateHertz"))
                                if (!$util.isInteger(message.sampleRateHertz))
                                    return "sampleRateHertz: integer expected";
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                if (!$util.isString(message.languageCode))
                                    return "languageCode: string expected";
                            if (message.enableWordInfo != null && message.hasOwnProperty("enableWordInfo"))
                                if (typeof message.enableWordInfo !== "boolean")
                                    return "enableWordInfo: boolean expected";
                            if (message.useTimeoutBasedEndpointing != null && message.hasOwnProperty("useTimeoutBasedEndpointing"))
                                if (typeof message.useTimeoutBasedEndpointing !== "boolean")
                                    return "useTimeoutBasedEndpointing: boolean expected";
                            return null;
                        };
    
                        /**
                         * Creates a SpeechToTextConfig message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.SpeechToTextConfig
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.SpeechToTextConfig} SpeechToTextConfig
                         */
                        SpeechToTextConfig.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.SpeechToTextConfig)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.SpeechToTextConfig();
                            switch (object.speechModelVariant) {
                            default:
                                if (typeof object.speechModelVariant === "number") {
                                    message.speechModelVariant = object.speechModelVariant;
                                    break;
                                }
                                break;
                            case "SPEECH_MODEL_VARIANT_UNSPECIFIED":
                            case 0:
                                message.speechModelVariant = 0;
                                break;
                            case "USE_BEST_AVAILABLE":
                            case 1:
                                message.speechModelVariant = 1;
                                break;
                            case "USE_STANDARD":
                            case 2:
                                message.speechModelVariant = 2;
                                break;
                            case "USE_ENHANCED":
                            case 3:
                                message.speechModelVariant = 3;
                                break;
                            }
                            if (object.model != null)
                                message.model = String(object.model);
                            if (object.phraseSets) {
                                if (!Array.isArray(object.phraseSets))
                                    throw TypeError(".google.cloud.dialogflow.v2.SpeechToTextConfig.phraseSets: array expected");
                                message.phraseSets = [];
                                for (var i = 0; i < object.phraseSets.length; ++i)
                                    message.phraseSets[i] = String(object.phraseSets[i]);
                            }
                            switch (object.audioEncoding) {
                            default:
                                if (typeof object.audioEncoding === "number") {
                                    message.audioEncoding = object.audioEncoding;
                                    break;
                                }
                                break;
                            case "AUDIO_ENCODING_UNSPECIFIED":
                            case 0:
                                message.audioEncoding = 0;
                                break;
                            case "AUDIO_ENCODING_LINEAR_16":
                            case 1:
                                message.audioEncoding = 1;
                                break;
                            case "AUDIO_ENCODING_FLAC":
                            case 2:
                                message.audioEncoding = 2;
                                break;
                            case "AUDIO_ENCODING_MULAW":
                            case 3:
                                message.audioEncoding = 3;
                                break;
                            case "AUDIO_ENCODING_AMR":
                            case 4:
                                message.audioEncoding = 4;
                                break;
                            case "AUDIO_ENCODING_AMR_WB":
                            case 5:
                                message.audioEncoding = 5;
                                break;
                            case "AUDIO_ENCODING_OGG_OPUS":
                            case 6:
                                message.audioEncoding = 6;
                                break;
                            case "AUDIO_ENCODING_SPEEX_WITH_HEADER_BYTE":
                            case 7:
                                message.audioEncoding = 7;
                                break;
                            case "AUDIO_ENCODING_ALAW":
                            case 8:
                                message.audioEncoding = 8;
                                break;
                            }
                            if (object.sampleRateHertz != null)
                                message.sampleRateHertz = object.sampleRateHertz | 0;
                            if (object.languageCode != null)
                                message.languageCode = String(object.languageCode);
                            if (object.enableWordInfo != null)
                                message.enableWordInfo = Boolean(object.enableWordInfo);
                            if (object.useTimeoutBasedEndpointing != null)
                                message.useTimeoutBasedEndpointing = Boolean(object.useTimeoutBasedEndpointing);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SpeechToTextConfig message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.SpeechToTextConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2.SpeechToTextConfig} message SpeechToTextConfig
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SpeechToTextConfig.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.phraseSets = [];
                            if (options.defaults) {
                                object.speechModelVariant = options.enums === String ? "SPEECH_MODEL_VARIANT_UNSPECIFIED" : 0;
                                object.model = "";
                                object.audioEncoding = options.enums === String ? "AUDIO_ENCODING_UNSPECIFIED" : 0;
                                object.sampleRateHertz = 0;
                                object.languageCode = "";
                                object.enableWordInfo = false;
                                object.useTimeoutBasedEndpointing = false;
                            }
                            if (message.speechModelVariant != null && message.hasOwnProperty("speechModelVariant"))
                                object.speechModelVariant = options.enums === String ? $root.google.cloud.dialogflow.v2.SpeechModelVariant[message.speechModelVariant] === undefined ? message.speechModelVariant : $root.google.cloud.dialogflow.v2.SpeechModelVariant[message.speechModelVariant] : message.speechModelVariant;
                            if (message.model != null && message.hasOwnProperty("model"))
                                object.model = message.model;
                            if (message.phraseSets && message.phraseSets.length) {
                                object.phraseSets = [];
                                for (var j = 0; j < message.phraseSets.length; ++j)
                                    object.phraseSets[j] = message.phraseSets[j];
                            }
                            if (message.audioEncoding != null && message.hasOwnProperty("audioEncoding"))
                                object.audioEncoding = options.enums === String ? $root.google.cloud.dialogflow.v2.AudioEncoding[message.audioEncoding] === undefined ? message.audioEncoding : $root.google.cloud.dialogflow.v2.AudioEncoding[message.audioEncoding] : message.audioEncoding;
                            if (message.sampleRateHertz != null && message.hasOwnProperty("sampleRateHertz"))
                                object.sampleRateHertz = message.sampleRateHertz;
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                object.languageCode = message.languageCode;
                            if (message.enableWordInfo != null && message.hasOwnProperty("enableWordInfo"))
                                object.enableWordInfo = message.enableWordInfo;
                            if (message.useTimeoutBasedEndpointing != null && message.hasOwnProperty("useTimeoutBasedEndpointing"))
                                object.useTimeoutBasedEndpointing = message.useTimeoutBasedEndpointing;
                            return object;
                        };
    
                        /**
                         * Converts this SpeechToTextConfig to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.SpeechToTextConfig
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SpeechToTextConfig.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SpeechToTextConfig
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.SpeechToTextConfig
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SpeechToTextConfig.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.SpeechToTextConfig";
                        };
    
                        return SpeechToTextConfig;
                    })();
    
                    /**
                     * TelephonyDtmf enum.
                     * @name google.cloud.dialogflow.v2.TelephonyDtmf
                     * @enum {number}
                     * @property {number} TELEPHONY_DTMF_UNSPECIFIED=0 TELEPHONY_DTMF_UNSPECIFIED value
                     * @property {number} DTMF_ONE=1 DTMF_ONE value
                     * @property {number} DTMF_TWO=2 DTMF_TWO value
                     * @property {number} DTMF_THREE=3 DTMF_THREE value
                     * @property {number} DTMF_FOUR=4 DTMF_FOUR value
                     * @property {number} DTMF_FIVE=5 DTMF_FIVE value
                     * @property {number} DTMF_SIX=6 DTMF_SIX value
                     * @property {number} DTMF_SEVEN=7 DTMF_SEVEN value
                     * @property {number} DTMF_EIGHT=8 DTMF_EIGHT value
                     * @property {number} DTMF_NINE=9 DTMF_NINE value
                     * @property {number} DTMF_ZERO=10 DTMF_ZERO value
                     * @property {number} DTMF_A=11 DTMF_A value
                     * @property {number} DTMF_B=12 DTMF_B value
                     * @property {number} DTMF_C=13 DTMF_C value
                     * @property {number} DTMF_D=14 DTMF_D value
                     * @property {number} DTMF_STAR=15 DTMF_STAR value
                     * @property {number} DTMF_POUND=16 DTMF_POUND value
                     */
                    v2.TelephonyDtmf = (function() {
                        var valuesById = {}, values = Object.create(valuesById);
                        values[valuesById[0] = "TELEPHONY_DTMF_UNSPECIFIED"] = 0;
                        values[valuesById[1] = "DTMF_ONE"] = 1;
                        values[valuesById[2] = "DTMF_TWO"] = 2;
                        values[valuesById[3] = "DTMF_THREE"] = 3;
                        values[valuesById[4] = "DTMF_FOUR"] = 4;
                        values[valuesById[5] = "DTMF_FIVE"] = 5;
                        values[valuesById[6] = "DTMF_SIX"] = 6;
                        values[valuesById[7] = "DTMF_SEVEN"] = 7;
                        values[valuesById[8] = "DTMF_EIGHT"] = 8;
                        values[valuesById[9] = "DTMF_NINE"] = 9;
                        values[valuesById[10] = "DTMF_ZERO"] = 10;
                        values[valuesById[11] = "DTMF_A"] = 11;
                        values[valuesById[12] = "DTMF_B"] = 12;
                        values[valuesById[13] = "DTMF_C"] = 13;
                        values[valuesById[14] = "DTMF_D"] = 14;
                        values[valuesById[15] = "DTMF_STAR"] = 15;
                        values[valuesById[16] = "DTMF_POUND"] = 16;
                        return values;
                    })();
    
                    /**
                     * AudioEncoding enum.
                     * @name google.cloud.dialogflow.v2.AudioEncoding
                     * @enum {number}
                     * @property {number} AUDIO_ENCODING_UNSPECIFIED=0 AUDIO_ENCODING_UNSPECIFIED value
                     * @property {number} AUDIO_ENCODING_LINEAR_16=1 AUDIO_ENCODING_LINEAR_16 value
                     * @property {number} AUDIO_ENCODING_FLAC=2 AUDIO_ENCODING_FLAC value
                     * @property {number} AUDIO_ENCODING_MULAW=3 AUDIO_ENCODING_MULAW value
                     * @property {number} AUDIO_ENCODING_AMR=4 AUDIO_ENCODING_AMR value
                     * @property {number} AUDIO_ENCODING_AMR_WB=5 AUDIO_ENCODING_AMR_WB value
                     * @property {number} AUDIO_ENCODING_OGG_OPUS=6 AUDIO_ENCODING_OGG_OPUS value
                     * @property {number} AUDIO_ENCODING_SPEEX_WITH_HEADER_BYTE=7 AUDIO_ENCODING_SPEEX_WITH_HEADER_BYTE value
                     * @property {number} AUDIO_ENCODING_ALAW=8 AUDIO_ENCODING_ALAW value
                     */
                    v2.AudioEncoding = (function() {
                        var valuesById = {}, values = Object.create(valuesById);
                        values[valuesById[0] = "AUDIO_ENCODING_UNSPECIFIED"] = 0;
                        values[valuesById[1] = "AUDIO_ENCODING_LINEAR_16"] = 1;
                        values[valuesById[2] = "AUDIO_ENCODING_FLAC"] = 2;
                        values[valuesById[3] = "AUDIO_ENCODING_MULAW"] = 3;
                        values[valuesById[4] = "AUDIO_ENCODING_AMR"] = 4;
                        values[valuesById[5] = "AUDIO_ENCODING_AMR_WB"] = 5;
                        values[valuesById[6] = "AUDIO_ENCODING_OGG_OPUS"] = 6;
                        values[valuesById[7] = "AUDIO_ENCODING_SPEEX_WITH_HEADER_BYTE"] = 7;
                        values[valuesById[8] = "AUDIO_ENCODING_ALAW"] = 8;
                        return values;
                    })();
    
                    /**
                     * SpeechModelVariant enum.
                     * @name google.cloud.dialogflow.v2.SpeechModelVariant
                     * @enum {number}
                     * @property {number} SPEECH_MODEL_VARIANT_UNSPECIFIED=0 SPEECH_MODEL_VARIANT_UNSPECIFIED value
                     * @property {number} USE_BEST_AVAILABLE=1 USE_BEST_AVAILABLE value
                     * @property {number} USE_STANDARD=2 USE_STANDARD value
                     * @property {number} USE_ENHANCED=3 USE_ENHANCED value
                     */
                    v2.SpeechModelVariant = (function() {
                        var valuesById = {}, values = Object.create(valuesById);
                        values[valuesById[0] = "SPEECH_MODEL_VARIANT_UNSPECIFIED"] = 0;
                        values[valuesById[1] = "USE_BEST_AVAILABLE"] = 1;
                        values[valuesById[2] = "USE_STANDARD"] = 2;
                        values[valuesById[3] = "USE_ENHANCED"] = 3;
                        return values;
                    })();
    
                    /**
                     * SsmlVoiceGender enum.
                     * @name google.cloud.dialogflow.v2.SsmlVoiceGender
                     * @enum {number}
                     * @property {number} SSML_VOICE_GENDER_UNSPECIFIED=0 SSML_VOICE_GENDER_UNSPECIFIED value
                     * @property {number} SSML_VOICE_GENDER_MALE=1 SSML_VOICE_GENDER_MALE value
                     * @property {number} SSML_VOICE_GENDER_FEMALE=2 SSML_VOICE_GENDER_FEMALE value
                     * @property {number} SSML_VOICE_GENDER_NEUTRAL=3 SSML_VOICE_GENDER_NEUTRAL value
                     */
                    v2.SsmlVoiceGender = (function() {
                        var valuesById = {}, values = Object.create(valuesById);
                        values[valuesById[0] = "SSML_VOICE_GENDER_UNSPECIFIED"] = 0;
                        values[valuesById[1] = "SSML_VOICE_GENDER_MALE"] = 1;
                        values[valuesById[2] = "SSML_VOICE_GENDER_FEMALE"] = 2;
                        values[valuesById[3] = "SSML_VOICE_GENDER_NEUTRAL"] = 3;
                        return values;
                    })();
    
                    /**
                     * OutputAudioEncoding enum.
                     * @name google.cloud.dialogflow.v2.OutputAudioEncoding
                     * @enum {number}
                     * @property {number} OUTPUT_AUDIO_ENCODING_UNSPECIFIED=0 OUTPUT_AUDIO_ENCODING_UNSPECIFIED value
                     * @property {number} OUTPUT_AUDIO_ENCODING_LINEAR_16=1 OUTPUT_AUDIO_ENCODING_LINEAR_16 value
                     * @property {number} OUTPUT_AUDIO_ENCODING_MP3=2 OUTPUT_AUDIO_ENCODING_MP3 value
                     * @property {number} OUTPUT_AUDIO_ENCODING_MP3_64_KBPS=4 OUTPUT_AUDIO_ENCODING_MP3_64_KBPS value
                     * @property {number} OUTPUT_AUDIO_ENCODING_OGG_OPUS=3 OUTPUT_AUDIO_ENCODING_OGG_OPUS value
                     * @property {number} OUTPUT_AUDIO_ENCODING_MULAW=5 OUTPUT_AUDIO_ENCODING_MULAW value
                     * @property {number} OUTPUT_AUDIO_ENCODING_ALAW=6 OUTPUT_AUDIO_ENCODING_ALAW value
                     */
                    v2.OutputAudioEncoding = (function() {
                        var valuesById = {}, values = Object.create(valuesById);
                        values[valuesById[0] = "OUTPUT_AUDIO_ENCODING_UNSPECIFIED"] = 0;
                        values[valuesById[1] = "OUTPUT_AUDIO_ENCODING_LINEAR_16"] = 1;
                        values[valuesById[2] = "OUTPUT_AUDIO_ENCODING_MP3"] = 2;
                        values[valuesById[4] = "OUTPUT_AUDIO_ENCODING_MP3_64_KBPS"] = 4;
                        values[valuesById[3] = "OUTPUT_AUDIO_ENCODING_OGG_OPUS"] = 3;
                        values[valuesById[5] = "OUTPUT_AUDIO_ENCODING_MULAW"] = 5;
                        values[valuesById[6] = "OUTPUT_AUDIO_ENCODING_ALAW"] = 6;
                        return values;
                    })();
    
                    v2.Generators = (function() {
    
                        /**
                         * Constructs a new Generators service.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a Generators
                         * @extends $protobuf.rpc.Service
                         * @constructor
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         */
                        function Generators(rpcImpl, requestDelimited, responseDelimited) {
                            $protobuf.rpc.Service.call(this, rpcImpl, requestDelimited, responseDelimited);
                        }
    
                        (Generators.prototype = Object.create($protobuf.rpc.Service.prototype)).constructor = Generators;
    
                        /**
                         * Creates new Generators service using the specified rpc implementation.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.Generators
                         * @static
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         * @returns {Generators} RPC service. Useful where requests and/or responses are streamed.
                         */
                        Generators.create = function create(rpcImpl, requestDelimited, responseDelimited) {
                            return new this(rpcImpl, requestDelimited, responseDelimited);
                        };
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Generators|createGenerator}.
                         * @memberof google.cloud.dialogflow.v2.Generators
                         * @typedef CreateGeneratorCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.Generator} [response] Generator
                         */
    
                        /**
                         * Calls CreateGenerator.
                         * @function createGenerator
                         * @memberof google.cloud.dialogflow.v2.Generators
                         * @instance
                         * @param {google.cloud.dialogflow.v2.ICreateGeneratorRequest} request CreateGeneratorRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Generators.CreateGeneratorCallback} callback Node-style callback called with the error, if any, and Generator
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Generators.prototype.createGenerator = function createGenerator(request, callback) {
                            return this.rpcCall(createGenerator, $root.google.cloud.dialogflow.v2.CreateGeneratorRequest, $root.google.cloud.dialogflow.v2.Generator, request, callback);
                        }, "name", { value: "CreateGenerator" });
    
                        /**
                         * Calls CreateGenerator.
                         * @function createGenerator
                         * @memberof google.cloud.dialogflow.v2.Generators
                         * @instance
                         * @param {google.cloud.dialogflow.v2.ICreateGeneratorRequest} request CreateGeneratorRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.Generator>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Generators|getGenerator}.
                         * @memberof google.cloud.dialogflow.v2.Generators
                         * @typedef GetGeneratorCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.Generator} [response] Generator
                         */
    
                        /**
                         * Calls GetGenerator.
                         * @function getGenerator
                         * @memberof google.cloud.dialogflow.v2.Generators
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IGetGeneratorRequest} request GetGeneratorRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Generators.GetGeneratorCallback} callback Node-style callback called with the error, if any, and Generator
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Generators.prototype.getGenerator = function getGenerator(request, callback) {
                            return this.rpcCall(getGenerator, $root.google.cloud.dialogflow.v2.GetGeneratorRequest, $root.google.cloud.dialogflow.v2.Generator, request, callback);
                        }, "name", { value: "GetGenerator" });
    
                        /**
                         * Calls GetGenerator.
                         * @function getGenerator
                         * @memberof google.cloud.dialogflow.v2.Generators
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IGetGeneratorRequest} request GetGeneratorRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.Generator>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Generators|listGenerators}.
                         * @memberof google.cloud.dialogflow.v2.Generators
                         * @typedef ListGeneratorsCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.ListGeneratorsResponse} [response] ListGeneratorsResponse
                         */
    
                        /**
                         * Calls ListGenerators.
                         * @function listGenerators
                         * @memberof google.cloud.dialogflow.v2.Generators
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IListGeneratorsRequest} request ListGeneratorsRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Generators.ListGeneratorsCallback} callback Node-style callback called with the error, if any, and ListGeneratorsResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Generators.prototype.listGenerators = function listGenerators(request, callback) {
                            return this.rpcCall(listGenerators, $root.google.cloud.dialogflow.v2.ListGeneratorsRequest, $root.google.cloud.dialogflow.v2.ListGeneratorsResponse, request, callback);
                        }, "name", { value: "ListGenerators" });
    
                        /**
                         * Calls ListGenerators.
                         * @function listGenerators
                         * @memberof google.cloud.dialogflow.v2.Generators
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IListGeneratorsRequest} request ListGeneratorsRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.ListGeneratorsResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Generators|deleteGenerator}.
                         * @memberof google.cloud.dialogflow.v2.Generators
                         * @typedef DeleteGeneratorCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.protobuf.Empty} [response] Empty
                         */
    
                        /**
                         * Calls DeleteGenerator.
                         * @function deleteGenerator
                         * @memberof google.cloud.dialogflow.v2.Generators
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IDeleteGeneratorRequest} request DeleteGeneratorRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Generators.DeleteGeneratorCallback} callback Node-style callback called with the error, if any, and Empty
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Generators.prototype.deleteGenerator = function deleteGenerator(request, callback) {
                            return this.rpcCall(deleteGenerator, $root.google.cloud.dialogflow.v2.DeleteGeneratorRequest, $root.google.protobuf.Empty, request, callback);
                        }, "name", { value: "DeleteGenerator" });
    
                        /**
                         * Calls DeleteGenerator.
                         * @function deleteGenerator
                         * @memberof google.cloud.dialogflow.v2.Generators
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IDeleteGeneratorRequest} request DeleteGeneratorRequest message or plain object
                         * @returns {Promise<google.protobuf.Empty>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Generators|updateGenerator}.
                         * @memberof google.cloud.dialogflow.v2.Generators
                         * @typedef UpdateGeneratorCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.Generator} [response] Generator
                         */
    
                        /**
                         * Calls UpdateGenerator.
                         * @function updateGenerator
                         * @memberof google.cloud.dialogflow.v2.Generators
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IUpdateGeneratorRequest} request UpdateGeneratorRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Generators.UpdateGeneratorCallback} callback Node-style callback called with the error, if any, and Generator
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Generators.prototype.updateGenerator = function updateGenerator(request, callback) {
                            return this.rpcCall(updateGenerator, $root.google.cloud.dialogflow.v2.UpdateGeneratorRequest, $root.google.cloud.dialogflow.v2.Generator, request, callback);
                        }, "name", { value: "UpdateGenerator" });
    
                        /**
                         * Calls UpdateGenerator.
                         * @function updateGenerator
                         * @memberof google.cloud.dialogflow.v2.Generators
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IUpdateGeneratorRequest} request UpdateGeneratorRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.Generator>} Promise
                         * @variation 2
                         */
    
                        return Generators;
                    })();
    
                    v2.CreateGeneratorRequest = (function() {
    
                        /**
                         * Properties of a CreateGeneratorRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ICreateGeneratorRequest
                         * @property {string|null} [parent] CreateGeneratorRequest parent
                         * @property {google.cloud.dialogflow.v2.IGenerator|null} [generator] CreateGeneratorRequest generator
                         * @property {string|null} [generatorId] CreateGeneratorRequest generatorId
                         */
    
                        /**
                         * Constructs a new CreateGeneratorRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a CreateGeneratorRequest.
                         * @implements ICreateGeneratorRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ICreateGeneratorRequest=} [properties] Properties to set
                         */
                        function CreateGeneratorRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * CreateGeneratorRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.CreateGeneratorRequest
                         * @instance
                         */
                        CreateGeneratorRequest.prototype.parent = "";
    
                        /**
                         * CreateGeneratorRequest generator.
                         * @member {google.cloud.dialogflow.v2.IGenerator|null|undefined} generator
                         * @memberof google.cloud.dialogflow.v2.CreateGeneratorRequest
                         * @instance
                         */
                        CreateGeneratorRequest.prototype.generator = null;
    
                        /**
                         * CreateGeneratorRequest generatorId.
                         * @member {string} generatorId
                         * @memberof google.cloud.dialogflow.v2.CreateGeneratorRequest
                         * @instance
                         */
                        CreateGeneratorRequest.prototype.generatorId = "";
    
                        /**
                         * Creates a new CreateGeneratorRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.CreateGeneratorRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICreateGeneratorRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.CreateGeneratorRequest} CreateGeneratorRequest instance
                         */
                        CreateGeneratorRequest.create = function create(properties) {
                            return new CreateGeneratorRequest(properties);
                        };
    
                        /**
                         * Encodes the specified CreateGeneratorRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.CreateGeneratorRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.CreateGeneratorRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICreateGeneratorRequest} message CreateGeneratorRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateGeneratorRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.generator != null && Object.hasOwnProperty.call(message, "generator"))
                                $root.google.cloud.dialogflow.v2.Generator.encode(message.generator, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.generatorId != null && Object.hasOwnProperty.call(message, "generatorId"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.generatorId);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified CreateGeneratorRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.CreateGeneratorRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.CreateGeneratorRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICreateGeneratorRequest} message CreateGeneratorRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateGeneratorRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a CreateGeneratorRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.CreateGeneratorRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.CreateGeneratorRequest} CreateGeneratorRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateGeneratorRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.CreateGeneratorRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.generator = $root.google.cloud.dialogflow.v2.Generator.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 3: {
                                        message.generatorId = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a CreateGeneratorRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.CreateGeneratorRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.CreateGeneratorRequest} CreateGeneratorRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateGeneratorRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a CreateGeneratorRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.CreateGeneratorRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        CreateGeneratorRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.generator != null && message.hasOwnProperty("generator")) {
                                var error = $root.google.cloud.dialogflow.v2.Generator.verify(message.generator);
                                if (error)
                                    return "generator." + error;
                            }
                            if (message.generatorId != null && message.hasOwnProperty("generatorId"))
                                if (!$util.isString(message.generatorId))
                                    return "generatorId: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a CreateGeneratorRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.CreateGeneratorRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.CreateGeneratorRequest} CreateGeneratorRequest
                         */
                        CreateGeneratorRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.CreateGeneratorRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.CreateGeneratorRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.generator != null) {
                                if (typeof object.generator !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.CreateGeneratorRequest.generator: object expected");
                                message.generator = $root.google.cloud.dialogflow.v2.Generator.fromObject(object.generator);
                            }
                            if (object.generatorId != null)
                                message.generatorId = String(object.generatorId);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a CreateGeneratorRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.CreateGeneratorRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.CreateGeneratorRequest} message CreateGeneratorRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        CreateGeneratorRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.generator = null;
                                object.generatorId = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.generator != null && message.hasOwnProperty("generator"))
                                object.generator = $root.google.cloud.dialogflow.v2.Generator.toObject(message.generator, options);
                            if (message.generatorId != null && message.hasOwnProperty("generatorId"))
                                object.generatorId = message.generatorId;
                            return object;
                        };
    
                        /**
                         * Converts this CreateGeneratorRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.CreateGeneratorRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        CreateGeneratorRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for CreateGeneratorRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.CreateGeneratorRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        CreateGeneratorRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.CreateGeneratorRequest";
                        };
    
                        return CreateGeneratorRequest;
                    })();
    
                    v2.GetGeneratorRequest = (function() {
    
                        /**
                         * Properties of a GetGeneratorRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IGetGeneratorRequest
                         * @property {string|null} [name] GetGeneratorRequest name
                         */
    
                        /**
                         * Constructs a new GetGeneratorRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a GetGeneratorRequest.
                         * @implements IGetGeneratorRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IGetGeneratorRequest=} [properties] Properties to set
                         */
                        function GetGeneratorRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GetGeneratorRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2.GetGeneratorRequest
                         * @instance
                         */
                        GetGeneratorRequest.prototype.name = "";
    
                        /**
                         * Creates a new GetGeneratorRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.GetGeneratorRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetGeneratorRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.GetGeneratorRequest} GetGeneratorRequest instance
                         */
                        GetGeneratorRequest.create = function create(properties) {
                            return new GetGeneratorRequest(properties);
                        };
    
                        /**
                         * Encodes the specified GetGeneratorRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.GetGeneratorRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.GetGeneratorRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetGeneratorRequest} message GetGeneratorRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetGeneratorRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GetGeneratorRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.GetGeneratorRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GetGeneratorRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetGeneratorRequest} message GetGeneratorRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetGeneratorRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GetGeneratorRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.GetGeneratorRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.GetGeneratorRequest} GetGeneratorRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetGeneratorRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.GetGeneratorRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GetGeneratorRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GetGeneratorRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.GetGeneratorRequest} GetGeneratorRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetGeneratorRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GetGeneratorRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.GetGeneratorRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GetGeneratorRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a GetGeneratorRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.GetGeneratorRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.GetGeneratorRequest} GetGeneratorRequest
                         */
                        GetGeneratorRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.GetGeneratorRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.GetGeneratorRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GetGeneratorRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.GetGeneratorRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.GetGeneratorRequest} message GetGeneratorRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GetGeneratorRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.name = "";
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            return object;
                        };
    
                        /**
                         * Converts this GetGeneratorRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.GetGeneratorRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GetGeneratorRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GetGeneratorRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.GetGeneratorRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GetGeneratorRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.GetGeneratorRequest";
                        };
    
                        return GetGeneratorRequest;
                    })();
    
                    v2.ListGeneratorsRequest = (function() {
    
                        /**
                         * Properties of a ListGeneratorsRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IListGeneratorsRequest
                         * @property {string|null} [parent] ListGeneratorsRequest parent
                         * @property {number|null} [pageSize] ListGeneratorsRequest pageSize
                         * @property {string|null} [pageToken] ListGeneratorsRequest pageToken
                         */
    
                        /**
                         * Constructs a new ListGeneratorsRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a ListGeneratorsRequest.
                         * @implements IListGeneratorsRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IListGeneratorsRequest=} [properties] Properties to set
                         */
                        function ListGeneratorsRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListGeneratorsRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.ListGeneratorsRequest
                         * @instance
                         */
                        ListGeneratorsRequest.prototype.parent = "";
    
                        /**
                         * ListGeneratorsRequest pageSize.
                         * @member {number} pageSize
                         * @memberof google.cloud.dialogflow.v2.ListGeneratorsRequest
                         * @instance
                         */
                        ListGeneratorsRequest.prototype.pageSize = 0;
    
                        /**
                         * ListGeneratorsRequest pageToken.
                         * @member {string} pageToken
                         * @memberof google.cloud.dialogflow.v2.ListGeneratorsRequest
                         * @instance
                         */
                        ListGeneratorsRequest.prototype.pageToken = "";
    
                        /**
                         * Creates a new ListGeneratorsRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ListGeneratorsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListGeneratorsRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ListGeneratorsRequest} ListGeneratorsRequest instance
                         */
                        ListGeneratorsRequest.create = function create(properties) {
                            return new ListGeneratorsRequest(properties);
                        };
    
                        /**
                         * Encodes the specified ListGeneratorsRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.ListGeneratorsRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ListGeneratorsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListGeneratorsRequest} message ListGeneratorsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListGeneratorsRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.pageSize != null && Object.hasOwnProperty.call(message, "pageSize"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.pageSize);
                            if (message.pageToken != null && Object.hasOwnProperty.call(message, "pageToken"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.pageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListGeneratorsRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ListGeneratorsRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListGeneratorsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListGeneratorsRequest} message ListGeneratorsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListGeneratorsRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListGeneratorsRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ListGeneratorsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ListGeneratorsRequest} ListGeneratorsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListGeneratorsRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ListGeneratorsRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.pageSize = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.pageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListGeneratorsRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListGeneratorsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ListGeneratorsRequest} ListGeneratorsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListGeneratorsRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListGeneratorsRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ListGeneratorsRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListGeneratorsRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                if (!$util.isInteger(message.pageSize))
                                    return "pageSize: integer expected";
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                if (!$util.isString(message.pageToken))
                                    return "pageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListGeneratorsRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ListGeneratorsRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ListGeneratorsRequest} ListGeneratorsRequest
                         */
                        ListGeneratorsRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ListGeneratorsRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ListGeneratorsRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.pageSize != null)
                                message.pageSize = object.pageSize | 0;
                            if (object.pageToken != null)
                                message.pageToken = String(object.pageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListGeneratorsRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ListGeneratorsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ListGeneratorsRequest} message ListGeneratorsRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListGeneratorsRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.pageSize = 0;
                                object.pageToken = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                object.pageSize = message.pageSize;
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                object.pageToken = message.pageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListGeneratorsRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ListGeneratorsRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListGeneratorsRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListGeneratorsRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ListGeneratorsRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListGeneratorsRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ListGeneratorsRequest";
                        };
    
                        return ListGeneratorsRequest;
                    })();
    
                    v2.ListGeneratorsResponse = (function() {
    
                        /**
                         * Properties of a ListGeneratorsResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IListGeneratorsResponse
                         * @property {Array.<google.cloud.dialogflow.v2.IGenerator>|null} [generators] ListGeneratorsResponse generators
                         * @property {string|null} [nextPageToken] ListGeneratorsResponse nextPageToken
                         */
    
                        /**
                         * Constructs a new ListGeneratorsResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a ListGeneratorsResponse.
                         * @implements IListGeneratorsResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IListGeneratorsResponse=} [properties] Properties to set
                         */
                        function ListGeneratorsResponse(properties) {
                            this.generators = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListGeneratorsResponse generators.
                         * @member {Array.<google.cloud.dialogflow.v2.IGenerator>} generators
                         * @memberof google.cloud.dialogflow.v2.ListGeneratorsResponse
                         * @instance
                         */
                        ListGeneratorsResponse.prototype.generators = $util.emptyArray;
    
                        /**
                         * ListGeneratorsResponse nextPageToken.
                         * @member {string} nextPageToken
                         * @memberof google.cloud.dialogflow.v2.ListGeneratorsResponse
                         * @instance
                         */
                        ListGeneratorsResponse.prototype.nextPageToken = "";
    
                        /**
                         * Creates a new ListGeneratorsResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ListGeneratorsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListGeneratorsResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ListGeneratorsResponse} ListGeneratorsResponse instance
                         */
                        ListGeneratorsResponse.create = function create(properties) {
                            return new ListGeneratorsResponse(properties);
                        };
    
                        /**
                         * Encodes the specified ListGeneratorsResponse message. Does not implicitly {@link google.cloud.dialogflow.v2.ListGeneratorsResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ListGeneratorsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListGeneratorsResponse} message ListGeneratorsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListGeneratorsResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.generators != null && message.generators.length)
                                for (var i = 0; i < message.generators.length; ++i)
                                    $root.google.cloud.dialogflow.v2.Generator.encode(message.generators[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.nextPageToken != null && Object.hasOwnProperty.call(message, "nextPageToken"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.nextPageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListGeneratorsResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ListGeneratorsResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListGeneratorsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListGeneratorsResponse} message ListGeneratorsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListGeneratorsResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListGeneratorsResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ListGeneratorsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ListGeneratorsResponse} ListGeneratorsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListGeneratorsResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ListGeneratorsResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.generators && message.generators.length))
                                            message.generators = [];
                                        message.generators.push($root.google.cloud.dialogflow.v2.Generator.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 2: {
                                        message.nextPageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListGeneratorsResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListGeneratorsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ListGeneratorsResponse} ListGeneratorsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListGeneratorsResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListGeneratorsResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ListGeneratorsResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListGeneratorsResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.generators != null && message.hasOwnProperty("generators")) {
                                if (!Array.isArray(message.generators))
                                    return "generators: array expected";
                                for (var i = 0; i < message.generators.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.Generator.verify(message.generators[i]);
                                    if (error)
                                        return "generators." + error;
                                }
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                if (!$util.isString(message.nextPageToken))
                                    return "nextPageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListGeneratorsResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ListGeneratorsResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ListGeneratorsResponse} ListGeneratorsResponse
                         */
                        ListGeneratorsResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ListGeneratorsResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ListGeneratorsResponse();
                            if (object.generators) {
                                if (!Array.isArray(object.generators))
                                    throw TypeError(".google.cloud.dialogflow.v2.ListGeneratorsResponse.generators: array expected");
                                message.generators = [];
                                for (var i = 0; i < object.generators.length; ++i) {
                                    if (typeof object.generators[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.ListGeneratorsResponse.generators: object expected");
                                    message.generators[i] = $root.google.cloud.dialogflow.v2.Generator.fromObject(object.generators[i]);
                                }
                            }
                            if (object.nextPageToken != null)
                                message.nextPageToken = String(object.nextPageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListGeneratorsResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ListGeneratorsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.ListGeneratorsResponse} message ListGeneratorsResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListGeneratorsResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.generators = [];
                            if (options.defaults)
                                object.nextPageToken = "";
                            if (message.generators && message.generators.length) {
                                object.generators = [];
                                for (var j = 0; j < message.generators.length; ++j)
                                    object.generators[j] = $root.google.cloud.dialogflow.v2.Generator.toObject(message.generators[j], options);
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                object.nextPageToken = message.nextPageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListGeneratorsResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ListGeneratorsResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListGeneratorsResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListGeneratorsResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ListGeneratorsResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListGeneratorsResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ListGeneratorsResponse";
                        };
    
                        return ListGeneratorsResponse;
                    })();
    
                    v2.DeleteGeneratorRequest = (function() {
    
                        /**
                         * Properties of a DeleteGeneratorRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IDeleteGeneratorRequest
                         * @property {string|null} [name] DeleteGeneratorRequest name
                         */
    
                        /**
                         * Constructs a new DeleteGeneratorRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a DeleteGeneratorRequest.
                         * @implements IDeleteGeneratorRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IDeleteGeneratorRequest=} [properties] Properties to set
                         */
                        function DeleteGeneratorRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * DeleteGeneratorRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2.DeleteGeneratorRequest
                         * @instance
                         */
                        DeleteGeneratorRequest.prototype.name = "";
    
                        /**
                         * Creates a new DeleteGeneratorRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.DeleteGeneratorRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDeleteGeneratorRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.DeleteGeneratorRequest} DeleteGeneratorRequest instance
                         */
                        DeleteGeneratorRequest.create = function create(properties) {
                            return new DeleteGeneratorRequest(properties);
                        };
    
                        /**
                         * Encodes the specified DeleteGeneratorRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.DeleteGeneratorRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.DeleteGeneratorRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDeleteGeneratorRequest} message DeleteGeneratorRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteGeneratorRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified DeleteGeneratorRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.DeleteGeneratorRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.DeleteGeneratorRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDeleteGeneratorRequest} message DeleteGeneratorRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteGeneratorRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a DeleteGeneratorRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.DeleteGeneratorRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.DeleteGeneratorRequest} DeleteGeneratorRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteGeneratorRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.DeleteGeneratorRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a DeleteGeneratorRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.DeleteGeneratorRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.DeleteGeneratorRequest} DeleteGeneratorRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteGeneratorRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a DeleteGeneratorRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.DeleteGeneratorRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        DeleteGeneratorRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a DeleteGeneratorRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.DeleteGeneratorRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.DeleteGeneratorRequest} DeleteGeneratorRequest
                         */
                        DeleteGeneratorRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.DeleteGeneratorRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.DeleteGeneratorRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a DeleteGeneratorRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.DeleteGeneratorRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.DeleteGeneratorRequest} message DeleteGeneratorRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        DeleteGeneratorRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.name = "";
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            return object;
                        };
    
                        /**
                         * Converts this DeleteGeneratorRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.DeleteGeneratorRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        DeleteGeneratorRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for DeleteGeneratorRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.DeleteGeneratorRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        DeleteGeneratorRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.DeleteGeneratorRequest";
                        };
    
                        return DeleteGeneratorRequest;
                    })();
    
                    v2.UpdateGeneratorRequest = (function() {
    
                        /**
                         * Properties of an UpdateGeneratorRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IUpdateGeneratorRequest
                         * @property {google.cloud.dialogflow.v2.IGenerator|null} [generator] UpdateGeneratorRequest generator
                         * @property {google.protobuf.IFieldMask|null} [updateMask] UpdateGeneratorRequest updateMask
                         */
    
                        /**
                         * Constructs a new UpdateGeneratorRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an UpdateGeneratorRequest.
                         * @implements IUpdateGeneratorRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IUpdateGeneratorRequest=} [properties] Properties to set
                         */
                        function UpdateGeneratorRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * UpdateGeneratorRequest generator.
                         * @member {google.cloud.dialogflow.v2.IGenerator|null|undefined} generator
                         * @memberof google.cloud.dialogflow.v2.UpdateGeneratorRequest
                         * @instance
                         */
                        UpdateGeneratorRequest.prototype.generator = null;
    
                        /**
                         * UpdateGeneratorRequest updateMask.
                         * @member {google.protobuf.IFieldMask|null|undefined} updateMask
                         * @memberof google.cloud.dialogflow.v2.UpdateGeneratorRequest
                         * @instance
                         */
                        UpdateGeneratorRequest.prototype.updateMask = null;
    
                        /**
                         * Creates a new UpdateGeneratorRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.UpdateGeneratorRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IUpdateGeneratorRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.UpdateGeneratorRequest} UpdateGeneratorRequest instance
                         */
                        UpdateGeneratorRequest.create = function create(properties) {
                            return new UpdateGeneratorRequest(properties);
                        };
    
                        /**
                         * Encodes the specified UpdateGeneratorRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.UpdateGeneratorRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.UpdateGeneratorRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IUpdateGeneratorRequest} message UpdateGeneratorRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UpdateGeneratorRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.generator != null && Object.hasOwnProperty.call(message, "generator"))
                                $root.google.cloud.dialogflow.v2.Generator.encode(message.generator, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.updateMask != null && Object.hasOwnProperty.call(message, "updateMask"))
                                $root.google.protobuf.FieldMask.encode(message.updateMask, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified UpdateGeneratorRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.UpdateGeneratorRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.UpdateGeneratorRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IUpdateGeneratorRequest} message UpdateGeneratorRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UpdateGeneratorRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an UpdateGeneratorRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.UpdateGeneratorRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.UpdateGeneratorRequest} UpdateGeneratorRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UpdateGeneratorRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.UpdateGeneratorRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.generator = $root.google.cloud.dialogflow.v2.Generator.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.updateMask = $root.google.protobuf.FieldMask.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an UpdateGeneratorRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.UpdateGeneratorRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.UpdateGeneratorRequest} UpdateGeneratorRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UpdateGeneratorRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an UpdateGeneratorRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.UpdateGeneratorRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        UpdateGeneratorRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.generator != null && message.hasOwnProperty("generator")) {
                                var error = $root.google.cloud.dialogflow.v2.Generator.verify(message.generator);
                                if (error)
                                    return "generator." + error;
                            }
                            if (message.updateMask != null && message.hasOwnProperty("updateMask")) {
                                var error = $root.google.protobuf.FieldMask.verify(message.updateMask);
                                if (error)
                                    return "updateMask." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates an UpdateGeneratorRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.UpdateGeneratorRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.UpdateGeneratorRequest} UpdateGeneratorRequest
                         */
                        UpdateGeneratorRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.UpdateGeneratorRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.UpdateGeneratorRequest();
                            if (object.generator != null) {
                                if (typeof object.generator !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.UpdateGeneratorRequest.generator: object expected");
                                message.generator = $root.google.cloud.dialogflow.v2.Generator.fromObject(object.generator);
                            }
                            if (object.updateMask != null) {
                                if (typeof object.updateMask !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.UpdateGeneratorRequest.updateMask: object expected");
                                message.updateMask = $root.google.protobuf.FieldMask.fromObject(object.updateMask);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an UpdateGeneratorRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.UpdateGeneratorRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.UpdateGeneratorRequest} message UpdateGeneratorRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        UpdateGeneratorRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.generator = null;
                                object.updateMask = null;
                            }
                            if (message.generator != null && message.hasOwnProperty("generator"))
                                object.generator = $root.google.cloud.dialogflow.v2.Generator.toObject(message.generator, options);
                            if (message.updateMask != null && message.hasOwnProperty("updateMask"))
                                object.updateMask = $root.google.protobuf.FieldMask.toObject(message.updateMask, options);
                            return object;
                        };
    
                        /**
                         * Converts this UpdateGeneratorRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.UpdateGeneratorRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        UpdateGeneratorRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for UpdateGeneratorRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.UpdateGeneratorRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        UpdateGeneratorRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.UpdateGeneratorRequest";
                        };
    
                        return UpdateGeneratorRequest;
                    })();
    
                    v2.MessageEntry = (function() {
    
                        /**
                         * Properties of a MessageEntry.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IMessageEntry
                         * @property {google.cloud.dialogflow.v2.MessageEntry.Role|null} [role] MessageEntry role
                         * @property {string|null} [text] MessageEntry text
                         * @property {string|null} [languageCode] MessageEntry languageCode
                         * @property {google.protobuf.ITimestamp|null} [createTime] MessageEntry createTime
                         */
    
                        /**
                         * Constructs a new MessageEntry.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a MessageEntry.
                         * @implements IMessageEntry
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IMessageEntry=} [properties] Properties to set
                         */
                        function MessageEntry(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * MessageEntry role.
                         * @member {google.cloud.dialogflow.v2.MessageEntry.Role} role
                         * @memberof google.cloud.dialogflow.v2.MessageEntry
                         * @instance
                         */
                        MessageEntry.prototype.role = 0;
    
                        /**
                         * MessageEntry text.
                         * @member {string} text
                         * @memberof google.cloud.dialogflow.v2.MessageEntry
                         * @instance
                         */
                        MessageEntry.prototype.text = "";
    
                        /**
                         * MessageEntry languageCode.
                         * @member {string} languageCode
                         * @memberof google.cloud.dialogflow.v2.MessageEntry
                         * @instance
                         */
                        MessageEntry.prototype.languageCode = "";
    
                        /**
                         * MessageEntry createTime.
                         * @member {google.protobuf.ITimestamp|null|undefined} createTime
                         * @memberof google.cloud.dialogflow.v2.MessageEntry
                         * @instance
                         */
                        MessageEntry.prototype.createTime = null;
    
                        /**
                         * Creates a new MessageEntry instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.MessageEntry
                         * @static
                         * @param {google.cloud.dialogflow.v2.IMessageEntry=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.MessageEntry} MessageEntry instance
                         */
                        MessageEntry.create = function create(properties) {
                            return new MessageEntry(properties);
                        };
    
                        /**
                         * Encodes the specified MessageEntry message. Does not implicitly {@link google.cloud.dialogflow.v2.MessageEntry.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.MessageEntry
                         * @static
                         * @param {google.cloud.dialogflow.v2.IMessageEntry} message MessageEntry message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        MessageEntry.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.role != null && Object.hasOwnProperty.call(message, "role"))
                                writer.uint32(/* id 1, wireType 0 =*/8).int32(message.role);
                            if (message.text != null && Object.hasOwnProperty.call(message, "text"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.text);
                            if (message.languageCode != null && Object.hasOwnProperty.call(message, "languageCode"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.languageCode);
                            if (message.createTime != null && Object.hasOwnProperty.call(message, "createTime"))
                                $root.google.protobuf.Timestamp.encode(message.createTime, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified MessageEntry message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.MessageEntry.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.MessageEntry
                         * @static
                         * @param {google.cloud.dialogflow.v2.IMessageEntry} message MessageEntry message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        MessageEntry.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a MessageEntry message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.MessageEntry
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.MessageEntry} MessageEntry
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        MessageEntry.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.MessageEntry();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.role = reader.int32();
                                        break;
                                    }
                                case 2: {
                                        message.text = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.languageCode = reader.string();
                                        break;
                                    }
                                case 4: {
                                        message.createTime = $root.google.protobuf.Timestamp.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a MessageEntry message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.MessageEntry
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.MessageEntry} MessageEntry
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        MessageEntry.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a MessageEntry message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.MessageEntry
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        MessageEntry.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.role != null && message.hasOwnProperty("role"))
                                switch (message.role) {
                                default:
                                    return "role: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                    break;
                                }
                            if (message.text != null && message.hasOwnProperty("text"))
                                if (!$util.isString(message.text))
                                    return "text: string expected";
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                if (!$util.isString(message.languageCode))
                                    return "languageCode: string expected";
                            if (message.createTime != null && message.hasOwnProperty("createTime")) {
                                var error = $root.google.protobuf.Timestamp.verify(message.createTime);
                                if (error)
                                    return "createTime." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a MessageEntry message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.MessageEntry
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.MessageEntry} MessageEntry
                         */
                        MessageEntry.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.MessageEntry)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.MessageEntry();
                            switch (object.role) {
                            default:
                                if (typeof object.role === "number") {
                                    message.role = object.role;
                                    break;
                                }
                                break;
                            case "ROLE_UNSPECIFIED":
                            case 0:
                                message.role = 0;
                                break;
                            case "HUMAN_AGENT":
                            case 1:
                                message.role = 1;
                                break;
                            case "AUTOMATED_AGENT":
                            case 2:
                                message.role = 2;
                                break;
                            case "END_USER":
                            case 3:
                                message.role = 3;
                                break;
                            }
                            if (object.text != null)
                                message.text = String(object.text);
                            if (object.languageCode != null)
                                message.languageCode = String(object.languageCode);
                            if (object.createTime != null) {
                                if (typeof object.createTime !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.MessageEntry.createTime: object expected");
                                message.createTime = $root.google.protobuf.Timestamp.fromObject(object.createTime);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a MessageEntry message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.MessageEntry
                         * @static
                         * @param {google.cloud.dialogflow.v2.MessageEntry} message MessageEntry
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        MessageEntry.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.role = options.enums === String ? "ROLE_UNSPECIFIED" : 0;
                                object.text = "";
                                object.languageCode = "";
                                object.createTime = null;
                            }
                            if (message.role != null && message.hasOwnProperty("role"))
                                object.role = options.enums === String ? $root.google.cloud.dialogflow.v2.MessageEntry.Role[message.role] === undefined ? message.role : $root.google.cloud.dialogflow.v2.MessageEntry.Role[message.role] : message.role;
                            if (message.text != null && message.hasOwnProperty("text"))
                                object.text = message.text;
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                object.languageCode = message.languageCode;
                            if (message.createTime != null && message.hasOwnProperty("createTime"))
                                object.createTime = $root.google.protobuf.Timestamp.toObject(message.createTime, options);
                            return object;
                        };
    
                        /**
                         * Converts this MessageEntry to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.MessageEntry
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        MessageEntry.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for MessageEntry
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.MessageEntry
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        MessageEntry.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.MessageEntry";
                        };
    
                        /**
                         * Role enum.
                         * @name google.cloud.dialogflow.v2.MessageEntry.Role
                         * @enum {number}
                         * @property {number} ROLE_UNSPECIFIED=0 ROLE_UNSPECIFIED value
                         * @property {number} HUMAN_AGENT=1 HUMAN_AGENT value
                         * @property {number} AUTOMATED_AGENT=2 AUTOMATED_AGENT value
                         * @property {number} END_USER=3 END_USER value
                         */
                        MessageEntry.Role = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "ROLE_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "HUMAN_AGENT"] = 1;
                            values[valuesById[2] = "AUTOMATED_AGENT"] = 2;
                            values[valuesById[3] = "END_USER"] = 3;
                            return values;
                        })();
    
                        return MessageEntry;
                    })();
    
                    v2.ConversationContext = (function() {
    
                        /**
                         * Properties of a ConversationContext.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IConversationContext
                         * @property {Array.<google.cloud.dialogflow.v2.IMessageEntry>|null} [messageEntries] ConversationContext messageEntries
                         */
    
                        /**
                         * Constructs a new ConversationContext.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a ConversationContext.
                         * @implements IConversationContext
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IConversationContext=} [properties] Properties to set
                         */
                        function ConversationContext(properties) {
                            this.messageEntries = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ConversationContext messageEntries.
                         * @member {Array.<google.cloud.dialogflow.v2.IMessageEntry>} messageEntries
                         * @memberof google.cloud.dialogflow.v2.ConversationContext
                         * @instance
                         */
                        ConversationContext.prototype.messageEntries = $util.emptyArray;
    
                        /**
                         * Creates a new ConversationContext instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ConversationContext
                         * @static
                         * @param {google.cloud.dialogflow.v2.IConversationContext=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ConversationContext} ConversationContext instance
                         */
                        ConversationContext.create = function create(properties) {
                            return new ConversationContext(properties);
                        };
    
                        /**
                         * Encodes the specified ConversationContext message. Does not implicitly {@link google.cloud.dialogflow.v2.ConversationContext.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ConversationContext
                         * @static
                         * @param {google.cloud.dialogflow.v2.IConversationContext} message ConversationContext message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ConversationContext.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.messageEntries != null && message.messageEntries.length)
                                for (var i = 0; i < message.messageEntries.length; ++i)
                                    $root.google.cloud.dialogflow.v2.MessageEntry.encode(message.messageEntries[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ConversationContext message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ConversationContext.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ConversationContext
                         * @static
                         * @param {google.cloud.dialogflow.v2.IConversationContext} message ConversationContext message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ConversationContext.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ConversationContext message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ConversationContext
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ConversationContext} ConversationContext
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ConversationContext.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ConversationContext();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.messageEntries && message.messageEntries.length))
                                            message.messageEntries = [];
                                        message.messageEntries.push($root.google.cloud.dialogflow.v2.MessageEntry.decode(reader, reader.uint32()));
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ConversationContext message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ConversationContext
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ConversationContext} ConversationContext
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ConversationContext.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ConversationContext message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ConversationContext
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ConversationContext.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.messageEntries != null && message.hasOwnProperty("messageEntries")) {
                                if (!Array.isArray(message.messageEntries))
                                    return "messageEntries: array expected";
                                for (var i = 0; i < message.messageEntries.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.MessageEntry.verify(message.messageEntries[i]);
                                    if (error)
                                        return "messageEntries." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates a ConversationContext message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ConversationContext
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ConversationContext} ConversationContext
                         */
                        ConversationContext.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ConversationContext)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ConversationContext();
                            if (object.messageEntries) {
                                if (!Array.isArray(object.messageEntries))
                                    throw TypeError(".google.cloud.dialogflow.v2.ConversationContext.messageEntries: array expected");
                                message.messageEntries = [];
                                for (var i = 0; i < object.messageEntries.length; ++i) {
                                    if (typeof object.messageEntries[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.ConversationContext.messageEntries: object expected");
                                    message.messageEntries[i] = $root.google.cloud.dialogflow.v2.MessageEntry.fromObject(object.messageEntries[i]);
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ConversationContext message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ConversationContext
                         * @static
                         * @param {google.cloud.dialogflow.v2.ConversationContext} message ConversationContext
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ConversationContext.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.messageEntries = [];
                            if (message.messageEntries && message.messageEntries.length) {
                                object.messageEntries = [];
                                for (var j = 0; j < message.messageEntries.length; ++j)
                                    object.messageEntries[j] = $root.google.cloud.dialogflow.v2.MessageEntry.toObject(message.messageEntries[j], options);
                            }
                            return object;
                        };
    
                        /**
                         * Converts this ConversationContext to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ConversationContext
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ConversationContext.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ConversationContext
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ConversationContext
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ConversationContext.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ConversationContext";
                        };
    
                        return ConversationContext;
                    })();
    
                    v2.SummarizationSectionList = (function() {
    
                        /**
                         * Properties of a SummarizationSectionList.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ISummarizationSectionList
                         * @property {Array.<google.cloud.dialogflow.v2.ISummarizationSection>|null} [summarizationSections] SummarizationSectionList summarizationSections
                         */
    
                        /**
                         * Constructs a new SummarizationSectionList.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a SummarizationSectionList.
                         * @implements ISummarizationSectionList
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ISummarizationSectionList=} [properties] Properties to set
                         */
                        function SummarizationSectionList(properties) {
                            this.summarizationSections = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SummarizationSectionList summarizationSections.
                         * @member {Array.<google.cloud.dialogflow.v2.ISummarizationSection>} summarizationSections
                         * @memberof google.cloud.dialogflow.v2.SummarizationSectionList
                         * @instance
                         */
                        SummarizationSectionList.prototype.summarizationSections = $util.emptyArray;
    
                        /**
                         * Creates a new SummarizationSectionList instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.SummarizationSectionList
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISummarizationSectionList=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.SummarizationSectionList} SummarizationSectionList instance
                         */
                        SummarizationSectionList.create = function create(properties) {
                            return new SummarizationSectionList(properties);
                        };
    
                        /**
                         * Encodes the specified SummarizationSectionList message. Does not implicitly {@link google.cloud.dialogflow.v2.SummarizationSectionList.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.SummarizationSectionList
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISummarizationSectionList} message SummarizationSectionList message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SummarizationSectionList.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.summarizationSections != null && message.summarizationSections.length)
                                for (var i = 0; i < message.summarizationSections.length; ++i)
                                    $root.google.cloud.dialogflow.v2.SummarizationSection.encode(message.summarizationSections[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SummarizationSectionList message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.SummarizationSectionList.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SummarizationSectionList
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISummarizationSectionList} message SummarizationSectionList message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SummarizationSectionList.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SummarizationSectionList message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.SummarizationSectionList
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.SummarizationSectionList} SummarizationSectionList
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SummarizationSectionList.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.SummarizationSectionList();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.summarizationSections && message.summarizationSections.length))
                                            message.summarizationSections = [];
                                        message.summarizationSections.push($root.google.cloud.dialogflow.v2.SummarizationSection.decode(reader, reader.uint32()));
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SummarizationSectionList message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SummarizationSectionList
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.SummarizationSectionList} SummarizationSectionList
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SummarizationSectionList.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SummarizationSectionList message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.SummarizationSectionList
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SummarizationSectionList.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.summarizationSections != null && message.hasOwnProperty("summarizationSections")) {
                                if (!Array.isArray(message.summarizationSections))
                                    return "summarizationSections: array expected";
                                for (var i = 0; i < message.summarizationSections.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.SummarizationSection.verify(message.summarizationSections[i]);
                                    if (error)
                                        return "summarizationSections." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates a SummarizationSectionList message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.SummarizationSectionList
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.SummarizationSectionList} SummarizationSectionList
                         */
                        SummarizationSectionList.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.SummarizationSectionList)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.SummarizationSectionList();
                            if (object.summarizationSections) {
                                if (!Array.isArray(object.summarizationSections))
                                    throw TypeError(".google.cloud.dialogflow.v2.SummarizationSectionList.summarizationSections: array expected");
                                message.summarizationSections = [];
                                for (var i = 0; i < object.summarizationSections.length; ++i) {
                                    if (typeof object.summarizationSections[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.SummarizationSectionList.summarizationSections: object expected");
                                    message.summarizationSections[i] = $root.google.cloud.dialogflow.v2.SummarizationSection.fromObject(object.summarizationSections[i]);
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SummarizationSectionList message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.SummarizationSectionList
                         * @static
                         * @param {google.cloud.dialogflow.v2.SummarizationSectionList} message SummarizationSectionList
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SummarizationSectionList.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.summarizationSections = [];
                            if (message.summarizationSections && message.summarizationSections.length) {
                                object.summarizationSections = [];
                                for (var j = 0; j < message.summarizationSections.length; ++j)
                                    object.summarizationSections[j] = $root.google.cloud.dialogflow.v2.SummarizationSection.toObject(message.summarizationSections[j], options);
                            }
                            return object;
                        };
    
                        /**
                         * Converts this SummarizationSectionList to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.SummarizationSectionList
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SummarizationSectionList.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SummarizationSectionList
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.SummarizationSectionList
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SummarizationSectionList.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.SummarizationSectionList";
                        };
    
                        return SummarizationSectionList;
                    })();
    
                    v2.FewShotExample = (function() {
    
                        /**
                         * Properties of a FewShotExample.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IFewShotExample
                         * @property {google.cloud.dialogflow.v2.IConversationContext|null} [conversationContext] FewShotExample conversationContext
                         * @property {Object.<string,string>|null} [extraInfo] FewShotExample extraInfo
                         * @property {google.cloud.dialogflow.v2.ISummarizationSectionList|null} [summarizationSectionList] FewShotExample summarizationSectionList
                         * @property {google.cloud.dialogflow.v2.IGeneratorSuggestion|null} [output] FewShotExample output
                         */
    
                        /**
                         * Constructs a new FewShotExample.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a FewShotExample.
                         * @implements IFewShotExample
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IFewShotExample=} [properties] Properties to set
                         */
                        function FewShotExample(properties) {
                            this.extraInfo = {};
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * FewShotExample conversationContext.
                         * @member {google.cloud.dialogflow.v2.IConversationContext|null|undefined} conversationContext
                         * @memberof google.cloud.dialogflow.v2.FewShotExample
                         * @instance
                         */
                        FewShotExample.prototype.conversationContext = null;
    
                        /**
                         * FewShotExample extraInfo.
                         * @member {Object.<string,string>} extraInfo
                         * @memberof google.cloud.dialogflow.v2.FewShotExample
                         * @instance
                         */
                        FewShotExample.prototype.extraInfo = $util.emptyObject;
    
                        /**
                         * FewShotExample summarizationSectionList.
                         * @member {google.cloud.dialogflow.v2.ISummarizationSectionList|null|undefined} summarizationSectionList
                         * @memberof google.cloud.dialogflow.v2.FewShotExample
                         * @instance
                         */
                        FewShotExample.prototype.summarizationSectionList = null;
    
                        /**
                         * FewShotExample output.
                         * @member {google.cloud.dialogflow.v2.IGeneratorSuggestion|null|undefined} output
                         * @memberof google.cloud.dialogflow.v2.FewShotExample
                         * @instance
                         */
                        FewShotExample.prototype.output = null;
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * FewShotExample instructionList.
                         * @member {"summarizationSectionList"|undefined} instructionList
                         * @memberof google.cloud.dialogflow.v2.FewShotExample
                         * @instance
                         */
                        Object.defineProperty(FewShotExample.prototype, "instructionList", {
                            get: $util.oneOfGetter($oneOfFields = ["summarizationSectionList"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new FewShotExample instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.FewShotExample
                         * @static
                         * @param {google.cloud.dialogflow.v2.IFewShotExample=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.FewShotExample} FewShotExample instance
                         */
                        FewShotExample.create = function create(properties) {
                            return new FewShotExample(properties);
                        };
    
                        /**
                         * Encodes the specified FewShotExample message. Does not implicitly {@link google.cloud.dialogflow.v2.FewShotExample.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.FewShotExample
                         * @static
                         * @param {google.cloud.dialogflow.v2.IFewShotExample} message FewShotExample message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        FewShotExample.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.conversationContext != null && Object.hasOwnProperty.call(message, "conversationContext"))
                                $root.google.cloud.dialogflow.v2.ConversationContext.encode(message.conversationContext, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            if (message.extraInfo != null && Object.hasOwnProperty.call(message, "extraInfo"))
                                for (var keys = Object.keys(message.extraInfo), i = 0; i < keys.length; ++i)
                                    writer.uint32(/* id 4, wireType 2 =*/34).fork().uint32(/* id 1, wireType 2 =*/10).string(keys[i]).uint32(/* id 2, wireType 2 =*/18).string(message.extraInfo[keys[i]]).ldelim();
                            if (message.summarizationSectionList != null && Object.hasOwnProperty.call(message, "summarizationSectionList"))
                                $root.google.cloud.dialogflow.v2.SummarizationSectionList.encode(message.summarizationSectionList, writer.uint32(/* id 6, wireType 2 =*/50).fork()).ldelim();
                            if (message.output != null && Object.hasOwnProperty.call(message, "output"))
                                $root.google.cloud.dialogflow.v2.GeneratorSuggestion.encode(message.output, writer.uint32(/* id 7, wireType 2 =*/58).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified FewShotExample message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.FewShotExample.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.FewShotExample
                         * @static
                         * @param {google.cloud.dialogflow.v2.IFewShotExample} message FewShotExample message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        FewShotExample.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a FewShotExample message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.FewShotExample
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.FewShotExample} FewShotExample
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        FewShotExample.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.FewShotExample(), key, value;
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 3: {
                                        message.conversationContext = $root.google.cloud.dialogflow.v2.ConversationContext.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 4: {
                                        if (message.extraInfo === $util.emptyObject)
                                            message.extraInfo = {};
                                        var end2 = reader.uint32() + reader.pos;
                                        key = "";
                                        value = "";
                                        while (reader.pos < end2) {
                                            var tag2 = reader.uint32();
                                            switch (tag2 >>> 3) {
                                            case 1:
                                                key = reader.string();
                                                break;
                                            case 2:
                                                value = reader.string();
                                                break;
                                            default:
                                                reader.skipType(tag2 & 7);
                                                break;
                                            }
                                        }
                                        message.extraInfo[key] = value;
                                        break;
                                    }
                                case 6: {
                                        message.summarizationSectionList = $root.google.cloud.dialogflow.v2.SummarizationSectionList.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 7: {
                                        message.output = $root.google.cloud.dialogflow.v2.GeneratorSuggestion.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a FewShotExample message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.FewShotExample
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.FewShotExample} FewShotExample
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        FewShotExample.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a FewShotExample message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.FewShotExample
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        FewShotExample.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.conversationContext != null && message.hasOwnProperty("conversationContext")) {
                                var error = $root.google.cloud.dialogflow.v2.ConversationContext.verify(message.conversationContext);
                                if (error)
                                    return "conversationContext." + error;
                            }
                            if (message.extraInfo != null && message.hasOwnProperty("extraInfo")) {
                                if (!$util.isObject(message.extraInfo))
                                    return "extraInfo: object expected";
                                var key = Object.keys(message.extraInfo);
                                for (var i = 0; i < key.length; ++i)
                                    if (!$util.isString(message.extraInfo[key[i]]))
                                        return "extraInfo: string{k:string} expected";
                            }
                            if (message.summarizationSectionList != null && message.hasOwnProperty("summarizationSectionList")) {
                                properties.instructionList = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2.SummarizationSectionList.verify(message.summarizationSectionList);
                                    if (error)
                                        return "summarizationSectionList." + error;
                                }
                            }
                            if (message.output != null && message.hasOwnProperty("output")) {
                                var error = $root.google.cloud.dialogflow.v2.GeneratorSuggestion.verify(message.output);
                                if (error)
                                    return "output." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a FewShotExample message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.FewShotExample
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.FewShotExample} FewShotExample
                         */
                        FewShotExample.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.FewShotExample)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.FewShotExample();
                            if (object.conversationContext != null) {
                                if (typeof object.conversationContext !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.FewShotExample.conversationContext: object expected");
                                message.conversationContext = $root.google.cloud.dialogflow.v2.ConversationContext.fromObject(object.conversationContext);
                            }
                            if (object.extraInfo) {
                                if (typeof object.extraInfo !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.FewShotExample.extraInfo: object expected");
                                message.extraInfo = {};
                                for (var keys = Object.keys(object.extraInfo), i = 0; i < keys.length; ++i)
                                    message.extraInfo[keys[i]] = String(object.extraInfo[keys[i]]);
                            }
                            if (object.summarizationSectionList != null) {
                                if (typeof object.summarizationSectionList !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.FewShotExample.summarizationSectionList: object expected");
                                message.summarizationSectionList = $root.google.cloud.dialogflow.v2.SummarizationSectionList.fromObject(object.summarizationSectionList);
                            }
                            if (object.output != null) {
                                if (typeof object.output !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.FewShotExample.output: object expected");
                                message.output = $root.google.cloud.dialogflow.v2.GeneratorSuggestion.fromObject(object.output);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a FewShotExample message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.FewShotExample
                         * @static
                         * @param {google.cloud.dialogflow.v2.FewShotExample} message FewShotExample
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        FewShotExample.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.objects || options.defaults)
                                object.extraInfo = {};
                            if (options.defaults) {
                                object.conversationContext = null;
                                object.output = null;
                            }
                            if (message.conversationContext != null && message.hasOwnProperty("conversationContext"))
                                object.conversationContext = $root.google.cloud.dialogflow.v2.ConversationContext.toObject(message.conversationContext, options);
                            var keys2;
                            if (message.extraInfo && (keys2 = Object.keys(message.extraInfo)).length) {
                                object.extraInfo = {};
                                for (var j = 0; j < keys2.length; ++j)
                                    object.extraInfo[keys2[j]] = message.extraInfo[keys2[j]];
                            }
                            if (message.summarizationSectionList != null && message.hasOwnProperty("summarizationSectionList")) {
                                object.summarizationSectionList = $root.google.cloud.dialogflow.v2.SummarizationSectionList.toObject(message.summarizationSectionList, options);
                                if (options.oneofs)
                                    object.instructionList = "summarizationSectionList";
                            }
                            if (message.output != null && message.hasOwnProperty("output"))
                                object.output = $root.google.cloud.dialogflow.v2.GeneratorSuggestion.toObject(message.output, options);
                            return object;
                        };
    
                        /**
                         * Converts this FewShotExample to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.FewShotExample
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        FewShotExample.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for FewShotExample
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.FewShotExample
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        FewShotExample.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.FewShotExample";
                        };
    
                        return FewShotExample;
                    })();
    
                    v2.InferenceParameter = (function() {
    
                        /**
                         * Properties of an InferenceParameter.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IInferenceParameter
                         * @property {number|null} [maxOutputTokens] InferenceParameter maxOutputTokens
                         * @property {number|null} [temperature] InferenceParameter temperature
                         * @property {number|null} [topK] InferenceParameter topK
                         * @property {number|null} [topP] InferenceParameter topP
                         */
    
                        /**
                         * Constructs a new InferenceParameter.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an InferenceParameter.
                         * @implements IInferenceParameter
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IInferenceParameter=} [properties] Properties to set
                         */
                        function InferenceParameter(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * InferenceParameter maxOutputTokens.
                         * @member {number|null|undefined} maxOutputTokens
                         * @memberof google.cloud.dialogflow.v2.InferenceParameter
                         * @instance
                         */
                        InferenceParameter.prototype.maxOutputTokens = null;
    
                        /**
                         * InferenceParameter temperature.
                         * @member {number|null|undefined} temperature
                         * @memberof google.cloud.dialogflow.v2.InferenceParameter
                         * @instance
                         */
                        InferenceParameter.prototype.temperature = null;
    
                        /**
                         * InferenceParameter topK.
                         * @member {number|null|undefined} topK
                         * @memberof google.cloud.dialogflow.v2.InferenceParameter
                         * @instance
                         */
                        InferenceParameter.prototype.topK = null;
    
                        /**
                         * InferenceParameter topP.
                         * @member {number|null|undefined} topP
                         * @memberof google.cloud.dialogflow.v2.InferenceParameter
                         * @instance
                         */
                        InferenceParameter.prototype.topP = null;
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * InferenceParameter _maxOutputTokens.
                         * @member {"maxOutputTokens"|undefined} _maxOutputTokens
                         * @memberof google.cloud.dialogflow.v2.InferenceParameter
                         * @instance
                         */
                        Object.defineProperty(InferenceParameter.prototype, "_maxOutputTokens", {
                            get: $util.oneOfGetter($oneOfFields = ["maxOutputTokens"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * InferenceParameter _temperature.
                         * @member {"temperature"|undefined} _temperature
                         * @memberof google.cloud.dialogflow.v2.InferenceParameter
                         * @instance
                         */
                        Object.defineProperty(InferenceParameter.prototype, "_temperature", {
                            get: $util.oneOfGetter($oneOfFields = ["temperature"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * InferenceParameter _topK.
                         * @member {"topK"|undefined} _topK
                         * @memberof google.cloud.dialogflow.v2.InferenceParameter
                         * @instance
                         */
                        Object.defineProperty(InferenceParameter.prototype, "_topK", {
                            get: $util.oneOfGetter($oneOfFields = ["topK"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * InferenceParameter _topP.
                         * @member {"topP"|undefined} _topP
                         * @memberof google.cloud.dialogflow.v2.InferenceParameter
                         * @instance
                         */
                        Object.defineProperty(InferenceParameter.prototype, "_topP", {
                            get: $util.oneOfGetter($oneOfFields = ["topP"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new InferenceParameter instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.InferenceParameter
                         * @static
                         * @param {google.cloud.dialogflow.v2.IInferenceParameter=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.InferenceParameter} InferenceParameter instance
                         */
                        InferenceParameter.create = function create(properties) {
                            return new InferenceParameter(properties);
                        };
    
                        /**
                         * Encodes the specified InferenceParameter message. Does not implicitly {@link google.cloud.dialogflow.v2.InferenceParameter.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.InferenceParameter
                         * @static
                         * @param {google.cloud.dialogflow.v2.IInferenceParameter} message InferenceParameter message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        InferenceParameter.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.maxOutputTokens != null && Object.hasOwnProperty.call(message, "maxOutputTokens"))
                                writer.uint32(/* id 1, wireType 0 =*/8).int32(message.maxOutputTokens);
                            if (message.temperature != null && Object.hasOwnProperty.call(message, "temperature"))
                                writer.uint32(/* id 2, wireType 1 =*/17).double(message.temperature);
                            if (message.topK != null && Object.hasOwnProperty.call(message, "topK"))
                                writer.uint32(/* id 3, wireType 0 =*/24).int32(message.topK);
                            if (message.topP != null && Object.hasOwnProperty.call(message, "topP"))
                                writer.uint32(/* id 4, wireType 1 =*/33).double(message.topP);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified InferenceParameter message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.InferenceParameter.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.InferenceParameter
                         * @static
                         * @param {google.cloud.dialogflow.v2.IInferenceParameter} message InferenceParameter message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        InferenceParameter.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an InferenceParameter message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.InferenceParameter
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.InferenceParameter} InferenceParameter
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        InferenceParameter.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.InferenceParameter();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.maxOutputTokens = reader.int32();
                                        break;
                                    }
                                case 2: {
                                        message.temperature = reader.double();
                                        break;
                                    }
                                case 3: {
                                        message.topK = reader.int32();
                                        break;
                                    }
                                case 4: {
                                        message.topP = reader.double();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an InferenceParameter message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.InferenceParameter
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.InferenceParameter} InferenceParameter
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        InferenceParameter.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an InferenceParameter message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.InferenceParameter
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        InferenceParameter.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.maxOutputTokens != null && message.hasOwnProperty("maxOutputTokens")) {
                                properties._maxOutputTokens = 1;
                                if (!$util.isInteger(message.maxOutputTokens))
                                    return "maxOutputTokens: integer expected";
                            }
                            if (message.temperature != null && message.hasOwnProperty("temperature")) {
                                properties._temperature = 1;
                                if (typeof message.temperature !== "number")
                                    return "temperature: number expected";
                            }
                            if (message.topK != null && message.hasOwnProperty("topK")) {
                                properties._topK = 1;
                                if (!$util.isInteger(message.topK))
                                    return "topK: integer expected";
                            }
                            if (message.topP != null && message.hasOwnProperty("topP")) {
                                properties._topP = 1;
                                if (typeof message.topP !== "number")
                                    return "topP: number expected";
                            }
                            return null;
                        };
    
                        /**
                         * Creates an InferenceParameter message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.InferenceParameter
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.InferenceParameter} InferenceParameter
                         */
                        InferenceParameter.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.InferenceParameter)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.InferenceParameter();
                            if (object.maxOutputTokens != null)
                                message.maxOutputTokens = object.maxOutputTokens | 0;
                            if (object.temperature != null)
                                message.temperature = Number(object.temperature);
                            if (object.topK != null)
                                message.topK = object.topK | 0;
                            if (object.topP != null)
                                message.topP = Number(object.topP);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an InferenceParameter message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.InferenceParameter
                         * @static
                         * @param {google.cloud.dialogflow.v2.InferenceParameter} message InferenceParameter
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        InferenceParameter.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (message.maxOutputTokens != null && message.hasOwnProperty("maxOutputTokens")) {
                                object.maxOutputTokens = message.maxOutputTokens;
                                if (options.oneofs)
                                    object._maxOutputTokens = "maxOutputTokens";
                            }
                            if (message.temperature != null && message.hasOwnProperty("temperature")) {
                                object.temperature = options.json && !isFinite(message.temperature) ? String(message.temperature) : message.temperature;
                                if (options.oneofs)
                                    object._temperature = "temperature";
                            }
                            if (message.topK != null && message.hasOwnProperty("topK")) {
                                object.topK = message.topK;
                                if (options.oneofs)
                                    object._topK = "topK";
                            }
                            if (message.topP != null && message.hasOwnProperty("topP")) {
                                object.topP = options.json && !isFinite(message.topP) ? String(message.topP) : message.topP;
                                if (options.oneofs)
                                    object._topP = "topP";
                            }
                            return object;
                        };
    
                        /**
                         * Converts this InferenceParameter to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.InferenceParameter
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        InferenceParameter.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for InferenceParameter
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.InferenceParameter
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        InferenceParameter.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.InferenceParameter";
                        };
    
                        return InferenceParameter;
                    })();
    
                    v2.SummarizationSection = (function() {
    
                        /**
                         * Properties of a SummarizationSection.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ISummarizationSection
                         * @property {string|null} [key] SummarizationSection key
                         * @property {string|null} [definition] SummarizationSection definition
                         * @property {google.cloud.dialogflow.v2.SummarizationSection.Type|null} [type] SummarizationSection type
                         */
    
                        /**
                         * Constructs a new SummarizationSection.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a SummarizationSection.
                         * @implements ISummarizationSection
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ISummarizationSection=} [properties] Properties to set
                         */
                        function SummarizationSection(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SummarizationSection key.
                         * @member {string} key
                         * @memberof google.cloud.dialogflow.v2.SummarizationSection
                         * @instance
                         */
                        SummarizationSection.prototype.key = "";
    
                        /**
                         * SummarizationSection definition.
                         * @member {string} definition
                         * @memberof google.cloud.dialogflow.v2.SummarizationSection
                         * @instance
                         */
                        SummarizationSection.prototype.definition = "";
    
                        /**
                         * SummarizationSection type.
                         * @member {google.cloud.dialogflow.v2.SummarizationSection.Type} type
                         * @memberof google.cloud.dialogflow.v2.SummarizationSection
                         * @instance
                         */
                        SummarizationSection.prototype.type = 0;
    
                        /**
                         * Creates a new SummarizationSection instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.SummarizationSection
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISummarizationSection=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.SummarizationSection} SummarizationSection instance
                         */
                        SummarizationSection.create = function create(properties) {
                            return new SummarizationSection(properties);
                        };
    
                        /**
                         * Encodes the specified SummarizationSection message. Does not implicitly {@link google.cloud.dialogflow.v2.SummarizationSection.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.SummarizationSection
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISummarizationSection} message SummarizationSection message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SummarizationSection.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.key != null && Object.hasOwnProperty.call(message, "key"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.key);
                            if (message.definition != null && Object.hasOwnProperty.call(message, "definition"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.definition);
                            if (message.type != null && Object.hasOwnProperty.call(message, "type"))
                                writer.uint32(/* id 3, wireType 0 =*/24).int32(message.type);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SummarizationSection message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.SummarizationSection.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SummarizationSection
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISummarizationSection} message SummarizationSection message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SummarizationSection.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SummarizationSection message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.SummarizationSection
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.SummarizationSection} SummarizationSection
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SummarizationSection.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.SummarizationSection();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.key = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.definition = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.type = reader.int32();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SummarizationSection message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SummarizationSection
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.SummarizationSection} SummarizationSection
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SummarizationSection.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SummarizationSection message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.SummarizationSection
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SummarizationSection.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.key != null && message.hasOwnProperty("key"))
                                if (!$util.isString(message.key))
                                    return "key: string expected";
                            if (message.definition != null && message.hasOwnProperty("definition"))
                                if (!$util.isString(message.definition))
                                    return "definition: string expected";
                            if (message.type != null && message.hasOwnProperty("type"))
                                switch (message.type) {
                                default:
                                    return "type: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                case 4:
                                case 5:
                                case 6:
                                case 7:
                                case 9:
                                case 10:
                                    break;
                                }
                            return null;
                        };
    
                        /**
                         * Creates a SummarizationSection message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.SummarizationSection
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.SummarizationSection} SummarizationSection
                         */
                        SummarizationSection.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.SummarizationSection)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.SummarizationSection();
                            if (object.key != null)
                                message.key = String(object.key);
                            if (object.definition != null)
                                message.definition = String(object.definition);
                            switch (object.type) {
                            default:
                                if (typeof object.type === "number") {
                                    message.type = object.type;
                                    break;
                                }
                                break;
                            case "TYPE_UNSPECIFIED":
                            case 0:
                                message.type = 0;
                                break;
                            case "SITUATION":
                            case 1:
                                message.type = 1;
                                break;
                            case "ACTION":
                            case 2:
                                message.type = 2;
                                break;
                            case "RESOLUTION":
                            case 3:
                                message.type = 3;
                                break;
                            case "REASON_FOR_CANCELLATION":
                            case 4:
                                message.type = 4;
                                break;
                            case "CUSTOMER_SATISFACTION":
                            case 5:
                                message.type = 5;
                                break;
                            case "ENTITIES":
                            case 6:
                                message.type = 6;
                                break;
                            case "CUSTOMER_DEFINED":
                            case 7:
                                message.type = 7;
                                break;
                            case "SITUATION_CONCISE":
                            case 9:
                                message.type = 9;
                                break;
                            case "ACTION_CONCISE":
                            case 10:
                                message.type = 10;
                                break;
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SummarizationSection message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.SummarizationSection
                         * @static
                         * @param {google.cloud.dialogflow.v2.SummarizationSection} message SummarizationSection
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SummarizationSection.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.key = "";
                                object.definition = "";
                                object.type = options.enums === String ? "TYPE_UNSPECIFIED" : 0;
                            }
                            if (message.key != null && message.hasOwnProperty("key"))
                                object.key = message.key;
                            if (message.definition != null && message.hasOwnProperty("definition"))
                                object.definition = message.definition;
                            if (message.type != null && message.hasOwnProperty("type"))
                                object.type = options.enums === String ? $root.google.cloud.dialogflow.v2.SummarizationSection.Type[message.type] === undefined ? message.type : $root.google.cloud.dialogflow.v2.SummarizationSection.Type[message.type] : message.type;
                            return object;
                        };
    
                        /**
                         * Converts this SummarizationSection to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.SummarizationSection
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SummarizationSection.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SummarizationSection
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.SummarizationSection
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SummarizationSection.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.SummarizationSection";
                        };
    
                        /**
                         * Type enum.
                         * @name google.cloud.dialogflow.v2.SummarizationSection.Type
                         * @enum {number}
                         * @property {number} TYPE_UNSPECIFIED=0 TYPE_UNSPECIFIED value
                         * @property {number} SITUATION=1 SITUATION value
                         * @property {number} ACTION=2 ACTION value
                         * @property {number} RESOLUTION=3 RESOLUTION value
                         * @property {number} REASON_FOR_CANCELLATION=4 REASON_FOR_CANCELLATION value
                         * @property {number} CUSTOMER_SATISFACTION=5 CUSTOMER_SATISFACTION value
                         * @property {number} ENTITIES=6 ENTITIES value
                         * @property {number} CUSTOMER_DEFINED=7 CUSTOMER_DEFINED value
                         * @property {number} SITUATION_CONCISE=9 SITUATION_CONCISE value
                         * @property {number} ACTION_CONCISE=10 ACTION_CONCISE value
                         */
                        SummarizationSection.Type = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "TYPE_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "SITUATION"] = 1;
                            values[valuesById[2] = "ACTION"] = 2;
                            values[valuesById[3] = "RESOLUTION"] = 3;
                            values[valuesById[4] = "REASON_FOR_CANCELLATION"] = 4;
                            values[valuesById[5] = "CUSTOMER_SATISFACTION"] = 5;
                            values[valuesById[6] = "ENTITIES"] = 6;
                            values[valuesById[7] = "CUSTOMER_DEFINED"] = 7;
                            values[valuesById[9] = "SITUATION_CONCISE"] = 9;
                            values[valuesById[10] = "ACTION_CONCISE"] = 10;
                            return values;
                        })();
    
                        return SummarizationSection;
                    })();
    
                    v2.SummarizationContext = (function() {
    
                        /**
                         * Properties of a SummarizationContext.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ISummarizationContext
                         * @property {Array.<google.cloud.dialogflow.v2.ISummarizationSection>|null} [summarizationSections] SummarizationContext summarizationSections
                         * @property {Array.<google.cloud.dialogflow.v2.IFewShotExample>|null} [fewShotExamples] SummarizationContext fewShotExamples
                         * @property {string|null} [version] SummarizationContext version
                         * @property {string|null} [outputLanguageCode] SummarizationContext outputLanguageCode
                         */
    
                        /**
                         * Constructs a new SummarizationContext.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a SummarizationContext.
                         * @implements ISummarizationContext
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ISummarizationContext=} [properties] Properties to set
                         */
                        function SummarizationContext(properties) {
                            this.summarizationSections = [];
                            this.fewShotExamples = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SummarizationContext summarizationSections.
                         * @member {Array.<google.cloud.dialogflow.v2.ISummarizationSection>} summarizationSections
                         * @memberof google.cloud.dialogflow.v2.SummarizationContext
                         * @instance
                         */
                        SummarizationContext.prototype.summarizationSections = $util.emptyArray;
    
                        /**
                         * SummarizationContext fewShotExamples.
                         * @member {Array.<google.cloud.dialogflow.v2.IFewShotExample>} fewShotExamples
                         * @memberof google.cloud.dialogflow.v2.SummarizationContext
                         * @instance
                         */
                        SummarizationContext.prototype.fewShotExamples = $util.emptyArray;
    
                        /**
                         * SummarizationContext version.
                         * @member {string} version
                         * @memberof google.cloud.dialogflow.v2.SummarizationContext
                         * @instance
                         */
                        SummarizationContext.prototype.version = "";
    
                        /**
                         * SummarizationContext outputLanguageCode.
                         * @member {string} outputLanguageCode
                         * @memberof google.cloud.dialogflow.v2.SummarizationContext
                         * @instance
                         */
                        SummarizationContext.prototype.outputLanguageCode = "";
    
                        /**
                         * Creates a new SummarizationContext instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.SummarizationContext
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISummarizationContext=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.SummarizationContext} SummarizationContext instance
                         */
                        SummarizationContext.create = function create(properties) {
                            return new SummarizationContext(properties);
                        };
    
                        /**
                         * Encodes the specified SummarizationContext message. Does not implicitly {@link google.cloud.dialogflow.v2.SummarizationContext.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.SummarizationContext
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISummarizationContext} message SummarizationContext message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SummarizationContext.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.summarizationSections != null && message.summarizationSections.length)
                                for (var i = 0; i < message.summarizationSections.length; ++i)
                                    $root.google.cloud.dialogflow.v2.SummarizationSection.encode(message.summarizationSections[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.fewShotExamples != null && message.fewShotExamples.length)
                                for (var i = 0; i < message.fewShotExamples.length; ++i)
                                    $root.google.cloud.dialogflow.v2.FewShotExample.encode(message.fewShotExamples[i], writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.version != null && Object.hasOwnProperty.call(message, "version"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.version);
                            if (message.outputLanguageCode != null && Object.hasOwnProperty.call(message, "outputLanguageCode"))
                                writer.uint32(/* id 6, wireType 2 =*/50).string(message.outputLanguageCode);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SummarizationContext message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.SummarizationContext.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SummarizationContext
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISummarizationContext} message SummarizationContext message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SummarizationContext.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SummarizationContext message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.SummarizationContext
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.SummarizationContext} SummarizationContext
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SummarizationContext.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.SummarizationContext();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.summarizationSections && message.summarizationSections.length))
                                            message.summarizationSections = [];
                                        message.summarizationSections.push($root.google.cloud.dialogflow.v2.SummarizationSection.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 2: {
                                        if (!(message.fewShotExamples && message.fewShotExamples.length))
                                            message.fewShotExamples = [];
                                        message.fewShotExamples.push($root.google.cloud.dialogflow.v2.FewShotExample.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 3: {
                                        message.version = reader.string();
                                        break;
                                    }
                                case 6: {
                                        message.outputLanguageCode = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SummarizationContext message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SummarizationContext
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.SummarizationContext} SummarizationContext
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SummarizationContext.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SummarizationContext message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.SummarizationContext
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SummarizationContext.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.summarizationSections != null && message.hasOwnProperty("summarizationSections")) {
                                if (!Array.isArray(message.summarizationSections))
                                    return "summarizationSections: array expected";
                                for (var i = 0; i < message.summarizationSections.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.SummarizationSection.verify(message.summarizationSections[i]);
                                    if (error)
                                        return "summarizationSections." + error;
                                }
                            }
                            if (message.fewShotExamples != null && message.hasOwnProperty("fewShotExamples")) {
                                if (!Array.isArray(message.fewShotExamples))
                                    return "fewShotExamples: array expected";
                                for (var i = 0; i < message.fewShotExamples.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.FewShotExample.verify(message.fewShotExamples[i]);
                                    if (error)
                                        return "fewShotExamples." + error;
                                }
                            }
                            if (message.version != null && message.hasOwnProperty("version"))
                                if (!$util.isString(message.version))
                                    return "version: string expected";
                            if (message.outputLanguageCode != null && message.hasOwnProperty("outputLanguageCode"))
                                if (!$util.isString(message.outputLanguageCode))
                                    return "outputLanguageCode: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a SummarizationContext message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.SummarizationContext
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.SummarizationContext} SummarizationContext
                         */
                        SummarizationContext.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.SummarizationContext)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.SummarizationContext();
                            if (object.summarizationSections) {
                                if (!Array.isArray(object.summarizationSections))
                                    throw TypeError(".google.cloud.dialogflow.v2.SummarizationContext.summarizationSections: array expected");
                                message.summarizationSections = [];
                                for (var i = 0; i < object.summarizationSections.length; ++i) {
                                    if (typeof object.summarizationSections[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.SummarizationContext.summarizationSections: object expected");
                                    message.summarizationSections[i] = $root.google.cloud.dialogflow.v2.SummarizationSection.fromObject(object.summarizationSections[i]);
                                }
                            }
                            if (object.fewShotExamples) {
                                if (!Array.isArray(object.fewShotExamples))
                                    throw TypeError(".google.cloud.dialogflow.v2.SummarizationContext.fewShotExamples: array expected");
                                message.fewShotExamples = [];
                                for (var i = 0; i < object.fewShotExamples.length; ++i) {
                                    if (typeof object.fewShotExamples[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.SummarizationContext.fewShotExamples: object expected");
                                    message.fewShotExamples[i] = $root.google.cloud.dialogflow.v2.FewShotExample.fromObject(object.fewShotExamples[i]);
                                }
                            }
                            if (object.version != null)
                                message.version = String(object.version);
                            if (object.outputLanguageCode != null)
                                message.outputLanguageCode = String(object.outputLanguageCode);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SummarizationContext message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.SummarizationContext
                         * @static
                         * @param {google.cloud.dialogflow.v2.SummarizationContext} message SummarizationContext
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SummarizationContext.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults) {
                                object.summarizationSections = [];
                                object.fewShotExamples = [];
                            }
                            if (options.defaults) {
                                object.version = "";
                                object.outputLanguageCode = "";
                            }
                            if (message.summarizationSections && message.summarizationSections.length) {
                                object.summarizationSections = [];
                                for (var j = 0; j < message.summarizationSections.length; ++j)
                                    object.summarizationSections[j] = $root.google.cloud.dialogflow.v2.SummarizationSection.toObject(message.summarizationSections[j], options);
                            }
                            if (message.fewShotExamples && message.fewShotExamples.length) {
                                object.fewShotExamples = [];
                                for (var j = 0; j < message.fewShotExamples.length; ++j)
                                    object.fewShotExamples[j] = $root.google.cloud.dialogflow.v2.FewShotExample.toObject(message.fewShotExamples[j], options);
                            }
                            if (message.version != null && message.hasOwnProperty("version"))
                                object.version = message.version;
                            if (message.outputLanguageCode != null && message.hasOwnProperty("outputLanguageCode"))
                                object.outputLanguageCode = message.outputLanguageCode;
                            return object;
                        };
    
                        /**
                         * Converts this SummarizationContext to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.SummarizationContext
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SummarizationContext.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SummarizationContext
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.SummarizationContext
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SummarizationContext.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.SummarizationContext";
                        };
    
                        return SummarizationContext;
                    })();
    
                    v2.FreeFormContext = (function() {
    
                        /**
                         * Properties of a FreeFormContext.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IFreeFormContext
                         * @property {string|null} [text] FreeFormContext text
                         */
    
                        /**
                         * Constructs a new FreeFormContext.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a FreeFormContext.
                         * @implements IFreeFormContext
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IFreeFormContext=} [properties] Properties to set
                         */
                        function FreeFormContext(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * FreeFormContext text.
                         * @member {string} text
                         * @memberof google.cloud.dialogflow.v2.FreeFormContext
                         * @instance
                         */
                        FreeFormContext.prototype.text = "";
    
                        /**
                         * Creates a new FreeFormContext instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.FreeFormContext
                         * @static
                         * @param {google.cloud.dialogflow.v2.IFreeFormContext=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.FreeFormContext} FreeFormContext instance
                         */
                        FreeFormContext.create = function create(properties) {
                            return new FreeFormContext(properties);
                        };
    
                        /**
                         * Encodes the specified FreeFormContext message. Does not implicitly {@link google.cloud.dialogflow.v2.FreeFormContext.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.FreeFormContext
                         * @static
                         * @param {google.cloud.dialogflow.v2.IFreeFormContext} message FreeFormContext message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        FreeFormContext.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.text != null && Object.hasOwnProperty.call(message, "text"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.text);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified FreeFormContext message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.FreeFormContext.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.FreeFormContext
                         * @static
                         * @param {google.cloud.dialogflow.v2.IFreeFormContext} message FreeFormContext message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        FreeFormContext.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a FreeFormContext message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.FreeFormContext
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.FreeFormContext} FreeFormContext
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        FreeFormContext.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.FreeFormContext();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.text = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a FreeFormContext message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.FreeFormContext
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.FreeFormContext} FreeFormContext
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        FreeFormContext.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a FreeFormContext message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.FreeFormContext
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        FreeFormContext.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.text != null && message.hasOwnProperty("text"))
                                if (!$util.isString(message.text))
                                    return "text: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a FreeFormContext message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.FreeFormContext
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.FreeFormContext} FreeFormContext
                         */
                        FreeFormContext.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.FreeFormContext)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.FreeFormContext();
                            if (object.text != null)
                                message.text = String(object.text);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a FreeFormContext message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.FreeFormContext
                         * @static
                         * @param {google.cloud.dialogflow.v2.FreeFormContext} message FreeFormContext
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        FreeFormContext.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.text = "";
                            if (message.text != null && message.hasOwnProperty("text"))
                                object.text = message.text;
                            return object;
                        };
    
                        /**
                         * Converts this FreeFormContext to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.FreeFormContext
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        FreeFormContext.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for FreeFormContext
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.FreeFormContext
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        FreeFormContext.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.FreeFormContext";
                        };
    
                        return FreeFormContext;
                    })();
    
                    v2.Generator = (function() {
    
                        /**
                         * Properties of a Generator.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IGenerator
                         * @property {string|null} [name] Generator name
                         * @property {string|null} [description] Generator description
                         * @property {google.cloud.dialogflow.v2.IFreeFormContext|null} [freeFormContext] Generator freeFormContext
                         * @property {google.cloud.dialogflow.v2.ISummarizationContext|null} [summarizationContext] Generator summarizationContext
                         * @property {google.cloud.dialogflow.v2.IInferenceParameter|null} [inferenceParameter] Generator inferenceParameter
                         * @property {google.cloud.dialogflow.v2.TriggerEvent|null} [triggerEvent] Generator triggerEvent
                         * @property {string|null} [publishedModel] Generator publishedModel
                         * @property {google.protobuf.ITimestamp|null} [createTime] Generator createTime
                         * @property {google.protobuf.ITimestamp|null} [updateTime] Generator updateTime
                         */
    
                        /**
                         * Constructs a new Generator.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a Generator.
                         * @implements IGenerator
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IGenerator=} [properties] Properties to set
                         */
                        function Generator(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * Generator name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2.Generator
                         * @instance
                         */
                        Generator.prototype.name = "";
    
                        /**
                         * Generator description.
                         * @member {string} description
                         * @memberof google.cloud.dialogflow.v2.Generator
                         * @instance
                         */
                        Generator.prototype.description = "";
    
                        /**
                         * Generator freeFormContext.
                         * @member {google.cloud.dialogflow.v2.IFreeFormContext|null|undefined} freeFormContext
                         * @memberof google.cloud.dialogflow.v2.Generator
                         * @instance
                         */
                        Generator.prototype.freeFormContext = null;
    
                        /**
                         * Generator summarizationContext.
                         * @member {google.cloud.dialogflow.v2.ISummarizationContext|null|undefined} summarizationContext
                         * @memberof google.cloud.dialogflow.v2.Generator
                         * @instance
                         */
                        Generator.prototype.summarizationContext = null;
    
                        /**
                         * Generator inferenceParameter.
                         * @member {google.cloud.dialogflow.v2.IInferenceParameter|null|undefined} inferenceParameter
                         * @memberof google.cloud.dialogflow.v2.Generator
                         * @instance
                         */
                        Generator.prototype.inferenceParameter = null;
    
                        /**
                         * Generator triggerEvent.
                         * @member {google.cloud.dialogflow.v2.TriggerEvent} triggerEvent
                         * @memberof google.cloud.dialogflow.v2.Generator
                         * @instance
                         */
                        Generator.prototype.triggerEvent = 0;
    
                        /**
                         * Generator publishedModel.
                         * @member {string|null|undefined} publishedModel
                         * @memberof google.cloud.dialogflow.v2.Generator
                         * @instance
                         */
                        Generator.prototype.publishedModel = null;
    
                        /**
                         * Generator createTime.
                         * @member {google.protobuf.ITimestamp|null|undefined} createTime
                         * @memberof google.cloud.dialogflow.v2.Generator
                         * @instance
                         */
                        Generator.prototype.createTime = null;
    
                        /**
                         * Generator updateTime.
                         * @member {google.protobuf.ITimestamp|null|undefined} updateTime
                         * @memberof google.cloud.dialogflow.v2.Generator
                         * @instance
                         */
                        Generator.prototype.updateTime = null;
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * Generator context.
                         * @member {"freeFormContext"|"summarizationContext"|undefined} context
                         * @memberof google.cloud.dialogflow.v2.Generator
                         * @instance
                         */
                        Object.defineProperty(Generator.prototype, "context", {
                            get: $util.oneOfGetter($oneOfFields = ["freeFormContext", "summarizationContext"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Generator foundationModel.
                         * @member {"publishedModel"|undefined} foundationModel
                         * @memberof google.cloud.dialogflow.v2.Generator
                         * @instance
                         */
                        Object.defineProperty(Generator.prototype, "foundationModel", {
                            get: $util.oneOfGetter($oneOfFields = ["publishedModel"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new Generator instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.Generator
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGenerator=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.Generator} Generator instance
                         */
                        Generator.create = function create(properties) {
                            return new Generator(properties);
                        };
    
                        /**
                         * Encodes the specified Generator message. Does not implicitly {@link google.cloud.dialogflow.v2.Generator.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.Generator
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGenerator} message Generator message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        Generator.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            if (message.description != null && Object.hasOwnProperty.call(message, "description"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.description);
                            if (message.inferenceParameter != null && Object.hasOwnProperty.call(message, "inferenceParameter"))
                                $root.google.cloud.dialogflow.v2.InferenceParameter.encode(message.inferenceParameter, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            if (message.triggerEvent != null && Object.hasOwnProperty.call(message, "triggerEvent"))
                                writer.uint32(/* id 5, wireType 0 =*/40).int32(message.triggerEvent);
                            if (message.createTime != null && Object.hasOwnProperty.call(message, "createTime"))
                                $root.google.protobuf.Timestamp.encode(message.createTime, writer.uint32(/* id 8, wireType 2 =*/66).fork()).ldelim();
                            if (message.updateTime != null && Object.hasOwnProperty.call(message, "updateTime"))
                                $root.google.protobuf.Timestamp.encode(message.updateTime, writer.uint32(/* id 9, wireType 2 =*/74).fork()).ldelim();
                            if (message.freeFormContext != null && Object.hasOwnProperty.call(message, "freeFormContext"))
                                $root.google.cloud.dialogflow.v2.FreeFormContext.encode(message.freeFormContext, writer.uint32(/* id 11, wireType 2 =*/90).fork()).ldelim();
                            if (message.summarizationContext != null && Object.hasOwnProperty.call(message, "summarizationContext"))
                                $root.google.cloud.dialogflow.v2.SummarizationContext.encode(message.summarizationContext, writer.uint32(/* id 13, wireType 2 =*/106).fork()).ldelim();
                            if (message.publishedModel != null && Object.hasOwnProperty.call(message, "publishedModel"))
                                writer.uint32(/* id 15, wireType 2 =*/122).string(message.publishedModel);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified Generator message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.Generator.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.Generator
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGenerator} message Generator message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        Generator.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a Generator message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.Generator
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.Generator} Generator
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        Generator.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.Generator();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.description = reader.string();
                                        break;
                                    }
                                case 11: {
                                        message.freeFormContext = $root.google.cloud.dialogflow.v2.FreeFormContext.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 13: {
                                        message.summarizationContext = $root.google.cloud.dialogflow.v2.SummarizationContext.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 4: {
                                        message.inferenceParameter = $root.google.cloud.dialogflow.v2.InferenceParameter.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 5: {
                                        message.triggerEvent = reader.int32();
                                        break;
                                    }
                                case 15: {
                                        message.publishedModel = reader.string();
                                        break;
                                    }
                                case 8: {
                                        message.createTime = $root.google.protobuf.Timestamp.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 9: {
                                        message.updateTime = $root.google.protobuf.Timestamp.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a Generator message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.Generator
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.Generator} Generator
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        Generator.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a Generator message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.Generator
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        Generator.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            if (message.description != null && message.hasOwnProperty("description"))
                                if (!$util.isString(message.description))
                                    return "description: string expected";
                            if (message.freeFormContext != null && message.hasOwnProperty("freeFormContext")) {
                                properties.context = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2.FreeFormContext.verify(message.freeFormContext);
                                    if (error)
                                        return "freeFormContext." + error;
                                }
                            }
                            if (message.summarizationContext != null && message.hasOwnProperty("summarizationContext")) {
                                if (properties.context === 1)
                                    return "context: multiple values";
                                properties.context = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2.SummarizationContext.verify(message.summarizationContext);
                                    if (error)
                                        return "summarizationContext." + error;
                                }
                            }
                            if (message.inferenceParameter != null && message.hasOwnProperty("inferenceParameter")) {
                                var error = $root.google.cloud.dialogflow.v2.InferenceParameter.verify(message.inferenceParameter);
                                if (error)
                                    return "inferenceParameter." + error;
                            }
                            if (message.triggerEvent != null && message.hasOwnProperty("triggerEvent"))
                                switch (message.triggerEvent) {
                                default:
                                    return "triggerEvent: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                case 4:
                                    break;
                                }
                            if (message.publishedModel != null && message.hasOwnProperty("publishedModel")) {
                                properties.foundationModel = 1;
                                if (!$util.isString(message.publishedModel))
                                    return "publishedModel: string expected";
                            }
                            if (message.createTime != null && message.hasOwnProperty("createTime")) {
                                var error = $root.google.protobuf.Timestamp.verify(message.createTime);
                                if (error)
                                    return "createTime." + error;
                            }
                            if (message.updateTime != null && message.hasOwnProperty("updateTime")) {
                                var error = $root.google.protobuf.Timestamp.verify(message.updateTime);
                                if (error)
                                    return "updateTime." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a Generator message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.Generator
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.Generator} Generator
                         */
                        Generator.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.Generator)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.Generator();
                            if (object.name != null)
                                message.name = String(object.name);
                            if (object.description != null)
                                message.description = String(object.description);
                            if (object.freeFormContext != null) {
                                if (typeof object.freeFormContext !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.Generator.freeFormContext: object expected");
                                message.freeFormContext = $root.google.cloud.dialogflow.v2.FreeFormContext.fromObject(object.freeFormContext);
                            }
                            if (object.summarizationContext != null) {
                                if (typeof object.summarizationContext !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.Generator.summarizationContext: object expected");
                                message.summarizationContext = $root.google.cloud.dialogflow.v2.SummarizationContext.fromObject(object.summarizationContext);
                            }
                            if (object.inferenceParameter != null) {
                                if (typeof object.inferenceParameter !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.Generator.inferenceParameter: object expected");
                                message.inferenceParameter = $root.google.cloud.dialogflow.v2.InferenceParameter.fromObject(object.inferenceParameter);
                            }
                            switch (object.triggerEvent) {
                            default:
                                if (typeof object.triggerEvent === "number") {
                                    message.triggerEvent = object.triggerEvent;
                                    break;
                                }
                                break;
                            case "TRIGGER_EVENT_UNSPECIFIED":
                            case 0:
                                message.triggerEvent = 0;
                                break;
                            case "END_OF_UTTERANCE":
                            case 1:
                                message.triggerEvent = 1;
                                break;
                            case "MANUAL_CALL":
                            case 2:
                                message.triggerEvent = 2;
                                break;
                            case "CUSTOMER_MESSAGE":
                            case 3:
                                message.triggerEvent = 3;
                                break;
                            case "AGENT_MESSAGE":
                            case 4:
                                message.triggerEvent = 4;
                                break;
                            }
                            if (object.publishedModel != null)
                                message.publishedModel = String(object.publishedModel);
                            if (object.createTime != null) {
                                if (typeof object.createTime !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.Generator.createTime: object expected");
                                message.createTime = $root.google.protobuf.Timestamp.fromObject(object.createTime);
                            }
                            if (object.updateTime != null) {
                                if (typeof object.updateTime !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.Generator.updateTime: object expected");
                                message.updateTime = $root.google.protobuf.Timestamp.fromObject(object.updateTime);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a Generator message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.Generator
                         * @static
                         * @param {google.cloud.dialogflow.v2.Generator} message Generator
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        Generator.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.name = "";
                                object.description = "";
                                object.inferenceParameter = null;
                                object.triggerEvent = options.enums === String ? "TRIGGER_EVENT_UNSPECIFIED" : 0;
                                object.createTime = null;
                                object.updateTime = null;
                            }
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            if (message.description != null && message.hasOwnProperty("description"))
                                object.description = message.description;
                            if (message.inferenceParameter != null && message.hasOwnProperty("inferenceParameter"))
                                object.inferenceParameter = $root.google.cloud.dialogflow.v2.InferenceParameter.toObject(message.inferenceParameter, options);
                            if (message.triggerEvent != null && message.hasOwnProperty("triggerEvent"))
                                object.triggerEvent = options.enums === String ? $root.google.cloud.dialogflow.v2.TriggerEvent[message.triggerEvent] === undefined ? message.triggerEvent : $root.google.cloud.dialogflow.v2.TriggerEvent[message.triggerEvent] : message.triggerEvent;
                            if (message.createTime != null && message.hasOwnProperty("createTime"))
                                object.createTime = $root.google.protobuf.Timestamp.toObject(message.createTime, options);
                            if (message.updateTime != null && message.hasOwnProperty("updateTime"))
                                object.updateTime = $root.google.protobuf.Timestamp.toObject(message.updateTime, options);
                            if (message.freeFormContext != null && message.hasOwnProperty("freeFormContext")) {
                                object.freeFormContext = $root.google.cloud.dialogflow.v2.FreeFormContext.toObject(message.freeFormContext, options);
                                if (options.oneofs)
                                    object.context = "freeFormContext";
                            }
                            if (message.summarizationContext != null && message.hasOwnProperty("summarizationContext")) {
                                object.summarizationContext = $root.google.cloud.dialogflow.v2.SummarizationContext.toObject(message.summarizationContext, options);
                                if (options.oneofs)
                                    object.context = "summarizationContext";
                            }
                            if (message.publishedModel != null && message.hasOwnProperty("publishedModel")) {
                                object.publishedModel = message.publishedModel;
                                if (options.oneofs)
                                    object.foundationModel = "publishedModel";
                            }
                            return object;
                        };
    
                        /**
                         * Converts this Generator to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.Generator
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        Generator.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for Generator
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.Generator
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        Generator.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.Generator";
                        };
    
                        return Generator;
                    })();
    
                    v2.FreeFormSuggestion = (function() {
    
                        /**
                         * Properties of a FreeFormSuggestion.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IFreeFormSuggestion
                         * @property {string|null} [response] FreeFormSuggestion response
                         */
    
                        /**
                         * Constructs a new FreeFormSuggestion.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a FreeFormSuggestion.
                         * @implements IFreeFormSuggestion
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IFreeFormSuggestion=} [properties] Properties to set
                         */
                        function FreeFormSuggestion(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * FreeFormSuggestion response.
                         * @member {string} response
                         * @memberof google.cloud.dialogflow.v2.FreeFormSuggestion
                         * @instance
                         */
                        FreeFormSuggestion.prototype.response = "";
    
                        /**
                         * Creates a new FreeFormSuggestion instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.FreeFormSuggestion
                         * @static
                         * @param {google.cloud.dialogflow.v2.IFreeFormSuggestion=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.FreeFormSuggestion} FreeFormSuggestion instance
                         */
                        FreeFormSuggestion.create = function create(properties) {
                            return new FreeFormSuggestion(properties);
                        };
    
                        /**
                         * Encodes the specified FreeFormSuggestion message. Does not implicitly {@link google.cloud.dialogflow.v2.FreeFormSuggestion.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.FreeFormSuggestion
                         * @static
                         * @param {google.cloud.dialogflow.v2.IFreeFormSuggestion} message FreeFormSuggestion message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        FreeFormSuggestion.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.response != null && Object.hasOwnProperty.call(message, "response"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.response);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified FreeFormSuggestion message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.FreeFormSuggestion.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.FreeFormSuggestion
                         * @static
                         * @param {google.cloud.dialogflow.v2.IFreeFormSuggestion} message FreeFormSuggestion message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        FreeFormSuggestion.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a FreeFormSuggestion message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.FreeFormSuggestion
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.FreeFormSuggestion} FreeFormSuggestion
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        FreeFormSuggestion.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.FreeFormSuggestion();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.response = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a FreeFormSuggestion message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.FreeFormSuggestion
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.FreeFormSuggestion} FreeFormSuggestion
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        FreeFormSuggestion.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a FreeFormSuggestion message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.FreeFormSuggestion
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        FreeFormSuggestion.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.response != null && message.hasOwnProperty("response"))
                                if (!$util.isString(message.response))
                                    return "response: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a FreeFormSuggestion message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.FreeFormSuggestion
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.FreeFormSuggestion} FreeFormSuggestion
                         */
                        FreeFormSuggestion.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.FreeFormSuggestion)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.FreeFormSuggestion();
                            if (object.response != null)
                                message.response = String(object.response);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a FreeFormSuggestion message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.FreeFormSuggestion
                         * @static
                         * @param {google.cloud.dialogflow.v2.FreeFormSuggestion} message FreeFormSuggestion
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        FreeFormSuggestion.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.response = "";
                            if (message.response != null && message.hasOwnProperty("response"))
                                object.response = message.response;
                            return object;
                        };
    
                        /**
                         * Converts this FreeFormSuggestion to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.FreeFormSuggestion
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        FreeFormSuggestion.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for FreeFormSuggestion
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.FreeFormSuggestion
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        FreeFormSuggestion.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.FreeFormSuggestion";
                        };
    
                        return FreeFormSuggestion;
                    })();
    
                    v2.SummarySuggestion = (function() {
    
                        /**
                         * Properties of a SummarySuggestion.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ISummarySuggestion
                         * @property {Array.<google.cloud.dialogflow.v2.SummarySuggestion.ISummarySection>|null} [summarySections] SummarySuggestion summarySections
                         */
    
                        /**
                         * Constructs a new SummarySuggestion.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a SummarySuggestion.
                         * @implements ISummarySuggestion
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ISummarySuggestion=} [properties] Properties to set
                         */
                        function SummarySuggestion(properties) {
                            this.summarySections = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SummarySuggestion summarySections.
                         * @member {Array.<google.cloud.dialogflow.v2.SummarySuggestion.ISummarySection>} summarySections
                         * @memberof google.cloud.dialogflow.v2.SummarySuggestion
                         * @instance
                         */
                        SummarySuggestion.prototype.summarySections = $util.emptyArray;
    
                        /**
                         * Creates a new SummarySuggestion instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.SummarySuggestion
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISummarySuggestion=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.SummarySuggestion} SummarySuggestion instance
                         */
                        SummarySuggestion.create = function create(properties) {
                            return new SummarySuggestion(properties);
                        };
    
                        /**
                         * Encodes the specified SummarySuggestion message. Does not implicitly {@link google.cloud.dialogflow.v2.SummarySuggestion.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.SummarySuggestion
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISummarySuggestion} message SummarySuggestion message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SummarySuggestion.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.summarySections != null && message.summarySections.length)
                                for (var i = 0; i < message.summarySections.length; ++i)
                                    $root.google.cloud.dialogflow.v2.SummarySuggestion.SummarySection.encode(message.summarySections[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SummarySuggestion message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.SummarySuggestion.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SummarySuggestion
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISummarySuggestion} message SummarySuggestion message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SummarySuggestion.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SummarySuggestion message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.SummarySuggestion
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.SummarySuggestion} SummarySuggestion
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SummarySuggestion.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.SummarySuggestion();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.summarySections && message.summarySections.length))
                                            message.summarySections = [];
                                        message.summarySections.push($root.google.cloud.dialogflow.v2.SummarySuggestion.SummarySection.decode(reader, reader.uint32()));
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SummarySuggestion message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SummarySuggestion
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.SummarySuggestion} SummarySuggestion
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SummarySuggestion.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SummarySuggestion message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.SummarySuggestion
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SummarySuggestion.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.summarySections != null && message.hasOwnProperty("summarySections")) {
                                if (!Array.isArray(message.summarySections))
                                    return "summarySections: array expected";
                                for (var i = 0; i < message.summarySections.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.SummarySuggestion.SummarySection.verify(message.summarySections[i]);
                                    if (error)
                                        return "summarySections." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates a SummarySuggestion message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.SummarySuggestion
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.SummarySuggestion} SummarySuggestion
                         */
                        SummarySuggestion.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.SummarySuggestion)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.SummarySuggestion();
                            if (object.summarySections) {
                                if (!Array.isArray(object.summarySections))
                                    throw TypeError(".google.cloud.dialogflow.v2.SummarySuggestion.summarySections: array expected");
                                message.summarySections = [];
                                for (var i = 0; i < object.summarySections.length; ++i) {
                                    if (typeof object.summarySections[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.SummarySuggestion.summarySections: object expected");
                                    message.summarySections[i] = $root.google.cloud.dialogflow.v2.SummarySuggestion.SummarySection.fromObject(object.summarySections[i]);
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SummarySuggestion message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.SummarySuggestion
                         * @static
                         * @param {google.cloud.dialogflow.v2.SummarySuggestion} message SummarySuggestion
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SummarySuggestion.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.summarySections = [];
                            if (message.summarySections && message.summarySections.length) {
                                object.summarySections = [];
                                for (var j = 0; j < message.summarySections.length; ++j)
                                    object.summarySections[j] = $root.google.cloud.dialogflow.v2.SummarySuggestion.SummarySection.toObject(message.summarySections[j], options);
                            }
                            return object;
                        };
    
                        /**
                         * Converts this SummarySuggestion to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.SummarySuggestion
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SummarySuggestion.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SummarySuggestion
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.SummarySuggestion
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SummarySuggestion.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.SummarySuggestion";
                        };
    
                        SummarySuggestion.SummarySection = (function() {
    
                            /**
                             * Properties of a SummarySection.
                             * @memberof google.cloud.dialogflow.v2.SummarySuggestion
                             * @interface ISummarySection
                             * @property {string|null} [section] SummarySection section
                             * @property {string|null} [summary] SummarySection summary
                             */
    
                            /**
                             * Constructs a new SummarySection.
                             * @memberof google.cloud.dialogflow.v2.SummarySuggestion
                             * @classdesc Represents a SummarySection.
                             * @implements ISummarySection
                             * @constructor
                             * @param {google.cloud.dialogflow.v2.SummarySuggestion.ISummarySection=} [properties] Properties to set
                             */
                            function SummarySection(properties) {
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * SummarySection section.
                             * @member {string} section
                             * @memberof google.cloud.dialogflow.v2.SummarySuggestion.SummarySection
                             * @instance
                             */
                            SummarySection.prototype.section = "";
    
                            /**
                             * SummarySection summary.
                             * @member {string} summary
                             * @memberof google.cloud.dialogflow.v2.SummarySuggestion.SummarySection
                             * @instance
                             */
                            SummarySection.prototype.summary = "";
    
                            /**
                             * Creates a new SummarySection instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2.SummarySuggestion.SummarySection
                             * @static
                             * @param {google.cloud.dialogflow.v2.SummarySuggestion.ISummarySection=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2.SummarySuggestion.SummarySection} SummarySection instance
                             */
                            SummarySection.create = function create(properties) {
                                return new SummarySection(properties);
                            };
    
                            /**
                             * Encodes the specified SummarySection message. Does not implicitly {@link google.cloud.dialogflow.v2.SummarySuggestion.SummarySection.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2.SummarySuggestion.SummarySection
                             * @static
                             * @param {google.cloud.dialogflow.v2.SummarySuggestion.ISummarySection} message SummarySection message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            SummarySection.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.section != null && Object.hasOwnProperty.call(message, "section"))
                                    writer.uint32(/* id 1, wireType 2 =*/10).string(message.section);
                                if (message.summary != null && Object.hasOwnProperty.call(message, "summary"))
                                    writer.uint32(/* id 2, wireType 2 =*/18).string(message.summary);
                                return writer;
                            };
    
                            /**
                             * Encodes the specified SummarySection message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.SummarySuggestion.SummarySection.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2.SummarySuggestion.SummarySection
                             * @static
                             * @param {google.cloud.dialogflow.v2.SummarySuggestion.ISummarySection} message SummarySection message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            SummarySection.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a SummarySection message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2.SummarySuggestion.SummarySection
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2.SummarySuggestion.SummarySection} SummarySection
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            SummarySection.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.SummarySuggestion.SummarySection();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.section = reader.string();
                                            break;
                                        }
                                    case 2: {
                                            message.summary = reader.string();
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a SummarySection message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2.SummarySuggestion.SummarySection
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2.SummarySuggestion.SummarySection} SummarySection
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            SummarySection.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a SummarySection message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2.SummarySuggestion.SummarySection
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            SummarySection.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.section != null && message.hasOwnProperty("section"))
                                    if (!$util.isString(message.section))
                                        return "section: string expected";
                                if (message.summary != null && message.hasOwnProperty("summary"))
                                    if (!$util.isString(message.summary))
                                        return "summary: string expected";
                                return null;
                            };
    
                            /**
                             * Creates a SummarySection message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2.SummarySuggestion.SummarySection
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2.SummarySuggestion.SummarySection} SummarySection
                             */
                            SummarySection.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2.SummarySuggestion.SummarySection)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2.SummarySuggestion.SummarySection();
                                if (object.section != null)
                                    message.section = String(object.section);
                                if (object.summary != null)
                                    message.summary = String(object.summary);
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a SummarySection message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2.SummarySuggestion.SummarySection
                             * @static
                             * @param {google.cloud.dialogflow.v2.SummarySuggestion.SummarySection} message SummarySection
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            SummarySection.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.defaults) {
                                    object.section = "";
                                    object.summary = "";
                                }
                                if (message.section != null && message.hasOwnProperty("section"))
                                    object.section = message.section;
                                if (message.summary != null && message.hasOwnProperty("summary"))
                                    object.summary = message.summary;
                                return object;
                            };
    
                            /**
                             * Converts this SummarySection to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2.SummarySuggestion.SummarySection
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            SummarySection.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for SummarySection
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2.SummarySuggestion.SummarySection
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            SummarySection.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2.SummarySuggestion.SummarySection";
                            };
    
                            return SummarySection;
                        })();
    
                        return SummarySuggestion;
                    })();
    
                    v2.GeneratorSuggestion = (function() {
    
                        /**
                         * Properties of a GeneratorSuggestion.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IGeneratorSuggestion
                         * @property {google.cloud.dialogflow.v2.IFreeFormSuggestion|null} [freeFormSuggestion] GeneratorSuggestion freeFormSuggestion
                         * @property {google.cloud.dialogflow.v2.ISummarySuggestion|null} [summarySuggestion] GeneratorSuggestion summarySuggestion
                         */
    
                        /**
                         * Constructs a new GeneratorSuggestion.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a GeneratorSuggestion.
                         * @implements IGeneratorSuggestion
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IGeneratorSuggestion=} [properties] Properties to set
                         */
                        function GeneratorSuggestion(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GeneratorSuggestion freeFormSuggestion.
                         * @member {google.cloud.dialogflow.v2.IFreeFormSuggestion|null|undefined} freeFormSuggestion
                         * @memberof google.cloud.dialogflow.v2.GeneratorSuggestion
                         * @instance
                         */
                        GeneratorSuggestion.prototype.freeFormSuggestion = null;
    
                        /**
                         * GeneratorSuggestion summarySuggestion.
                         * @member {google.cloud.dialogflow.v2.ISummarySuggestion|null|undefined} summarySuggestion
                         * @memberof google.cloud.dialogflow.v2.GeneratorSuggestion
                         * @instance
                         */
                        GeneratorSuggestion.prototype.summarySuggestion = null;
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * GeneratorSuggestion suggestion.
                         * @member {"freeFormSuggestion"|"summarySuggestion"|undefined} suggestion
                         * @memberof google.cloud.dialogflow.v2.GeneratorSuggestion
                         * @instance
                         */
                        Object.defineProperty(GeneratorSuggestion.prototype, "suggestion", {
                            get: $util.oneOfGetter($oneOfFields = ["freeFormSuggestion", "summarySuggestion"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new GeneratorSuggestion instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.GeneratorSuggestion
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGeneratorSuggestion=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.GeneratorSuggestion} GeneratorSuggestion instance
                         */
                        GeneratorSuggestion.create = function create(properties) {
                            return new GeneratorSuggestion(properties);
                        };
    
                        /**
                         * Encodes the specified GeneratorSuggestion message. Does not implicitly {@link google.cloud.dialogflow.v2.GeneratorSuggestion.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.GeneratorSuggestion
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGeneratorSuggestion} message GeneratorSuggestion message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GeneratorSuggestion.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.freeFormSuggestion != null && Object.hasOwnProperty.call(message, "freeFormSuggestion"))
                                $root.google.cloud.dialogflow.v2.FreeFormSuggestion.encode(message.freeFormSuggestion, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.summarySuggestion != null && Object.hasOwnProperty.call(message, "summarySuggestion"))
                                $root.google.cloud.dialogflow.v2.SummarySuggestion.encode(message.summarySuggestion, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GeneratorSuggestion message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.GeneratorSuggestion.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GeneratorSuggestion
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGeneratorSuggestion} message GeneratorSuggestion message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GeneratorSuggestion.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GeneratorSuggestion message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.GeneratorSuggestion
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.GeneratorSuggestion} GeneratorSuggestion
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GeneratorSuggestion.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.GeneratorSuggestion();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.freeFormSuggestion = $root.google.cloud.dialogflow.v2.FreeFormSuggestion.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.summarySuggestion = $root.google.cloud.dialogflow.v2.SummarySuggestion.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GeneratorSuggestion message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GeneratorSuggestion
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.GeneratorSuggestion} GeneratorSuggestion
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GeneratorSuggestion.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GeneratorSuggestion message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.GeneratorSuggestion
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GeneratorSuggestion.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.freeFormSuggestion != null && message.hasOwnProperty("freeFormSuggestion")) {
                                properties.suggestion = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2.FreeFormSuggestion.verify(message.freeFormSuggestion);
                                    if (error)
                                        return "freeFormSuggestion." + error;
                                }
                            }
                            if (message.summarySuggestion != null && message.hasOwnProperty("summarySuggestion")) {
                                if (properties.suggestion === 1)
                                    return "suggestion: multiple values";
                                properties.suggestion = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2.SummarySuggestion.verify(message.summarySuggestion);
                                    if (error)
                                        return "summarySuggestion." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates a GeneratorSuggestion message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.GeneratorSuggestion
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.GeneratorSuggestion} GeneratorSuggestion
                         */
                        GeneratorSuggestion.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.GeneratorSuggestion)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.GeneratorSuggestion();
                            if (object.freeFormSuggestion != null) {
                                if (typeof object.freeFormSuggestion !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.GeneratorSuggestion.freeFormSuggestion: object expected");
                                message.freeFormSuggestion = $root.google.cloud.dialogflow.v2.FreeFormSuggestion.fromObject(object.freeFormSuggestion);
                            }
                            if (object.summarySuggestion != null) {
                                if (typeof object.summarySuggestion !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.GeneratorSuggestion.summarySuggestion: object expected");
                                message.summarySuggestion = $root.google.cloud.dialogflow.v2.SummarySuggestion.fromObject(object.summarySuggestion);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GeneratorSuggestion message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.GeneratorSuggestion
                         * @static
                         * @param {google.cloud.dialogflow.v2.GeneratorSuggestion} message GeneratorSuggestion
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GeneratorSuggestion.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (message.freeFormSuggestion != null && message.hasOwnProperty("freeFormSuggestion")) {
                                object.freeFormSuggestion = $root.google.cloud.dialogflow.v2.FreeFormSuggestion.toObject(message.freeFormSuggestion, options);
                                if (options.oneofs)
                                    object.suggestion = "freeFormSuggestion";
                            }
                            if (message.summarySuggestion != null && message.hasOwnProperty("summarySuggestion")) {
                                object.summarySuggestion = $root.google.cloud.dialogflow.v2.SummarySuggestion.toObject(message.summarySuggestion, options);
                                if (options.oneofs)
                                    object.suggestion = "summarySuggestion";
                            }
                            return object;
                        };
    
                        /**
                         * Converts this GeneratorSuggestion to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.GeneratorSuggestion
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GeneratorSuggestion.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GeneratorSuggestion
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.GeneratorSuggestion
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GeneratorSuggestion.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.GeneratorSuggestion";
                        };
    
                        return GeneratorSuggestion;
                    })();
    
                    /**
                     * TriggerEvent enum.
                     * @name google.cloud.dialogflow.v2.TriggerEvent
                     * @enum {number}
                     * @property {number} TRIGGER_EVENT_UNSPECIFIED=0 TRIGGER_EVENT_UNSPECIFIED value
                     * @property {number} END_OF_UTTERANCE=1 END_OF_UTTERANCE value
                     * @property {number} MANUAL_CALL=2 MANUAL_CALL value
                     * @property {number} CUSTOMER_MESSAGE=3 CUSTOMER_MESSAGE value
                     * @property {number} AGENT_MESSAGE=4 AGENT_MESSAGE value
                     */
                    v2.TriggerEvent = (function() {
                        var valuesById = {}, values = Object.create(valuesById);
                        values[valuesById[0] = "TRIGGER_EVENT_UNSPECIFIED"] = 0;
                        values[valuesById[1] = "END_OF_UTTERANCE"] = 1;
                        values[valuesById[2] = "MANUAL_CALL"] = 2;
                        values[valuesById[3] = "CUSTOMER_MESSAGE"] = 3;
                        values[valuesById[4] = "AGENT_MESSAGE"] = 4;
                        return values;
                    })();
    
                    v2.Sessions = (function() {
    
                        /**
                         * Constructs a new Sessions service.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a Sessions
                         * @extends $protobuf.rpc.Service
                         * @constructor
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         */
                        function Sessions(rpcImpl, requestDelimited, responseDelimited) {
                            $protobuf.rpc.Service.call(this, rpcImpl, requestDelimited, responseDelimited);
                        }
    
                        (Sessions.prototype = Object.create($protobuf.rpc.Service.prototype)).constructor = Sessions;
    
                        /**
                         * Creates new Sessions service using the specified rpc implementation.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.Sessions
                         * @static
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         * @returns {Sessions} RPC service. Useful where requests and/or responses are streamed.
                         */
                        Sessions.create = function create(rpcImpl, requestDelimited, responseDelimited) {
                            return new this(rpcImpl, requestDelimited, responseDelimited);
                        };
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Sessions|detectIntent}.
                         * @memberof google.cloud.dialogflow.v2.Sessions
                         * @typedef DetectIntentCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.DetectIntentResponse} [response] DetectIntentResponse
                         */
    
                        /**
                         * Calls DetectIntent.
                         * @function detectIntent
                         * @memberof google.cloud.dialogflow.v2.Sessions
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IDetectIntentRequest} request DetectIntentRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Sessions.DetectIntentCallback} callback Node-style callback called with the error, if any, and DetectIntentResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Sessions.prototype.detectIntent = function detectIntent(request, callback) {
                            return this.rpcCall(detectIntent, $root.google.cloud.dialogflow.v2.DetectIntentRequest, $root.google.cloud.dialogflow.v2.DetectIntentResponse, request, callback);
                        }, "name", { value: "DetectIntent" });
    
                        /**
                         * Calls DetectIntent.
                         * @function detectIntent
                         * @memberof google.cloud.dialogflow.v2.Sessions
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IDetectIntentRequest} request DetectIntentRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.DetectIntentResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Sessions|streamingDetectIntent}.
                         * @memberof google.cloud.dialogflow.v2.Sessions
                         * @typedef StreamingDetectIntentCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.StreamingDetectIntentResponse} [response] StreamingDetectIntentResponse
                         */
    
                        /**
                         * Calls StreamingDetectIntent.
                         * @function streamingDetectIntent
                         * @memberof google.cloud.dialogflow.v2.Sessions
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IStreamingDetectIntentRequest} request StreamingDetectIntentRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Sessions.StreamingDetectIntentCallback} callback Node-style callback called with the error, if any, and StreamingDetectIntentResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Sessions.prototype.streamingDetectIntent = function streamingDetectIntent(request, callback) {
                            return this.rpcCall(streamingDetectIntent, $root.google.cloud.dialogflow.v2.StreamingDetectIntentRequest, $root.google.cloud.dialogflow.v2.StreamingDetectIntentResponse, request, callback);
                        }, "name", { value: "StreamingDetectIntent" });
    
                        /**
                         * Calls StreamingDetectIntent.
                         * @function streamingDetectIntent
                         * @memberof google.cloud.dialogflow.v2.Sessions
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IStreamingDetectIntentRequest} request StreamingDetectIntentRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.StreamingDetectIntentResponse>} Promise
                         * @variation 2
                         */
    
                        return Sessions;
                    })();
    
                    v2.DetectIntentRequest = (function() {
    
                        /**
                         * Properties of a DetectIntentRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IDetectIntentRequest
                         * @property {string|null} [session] DetectIntentRequest session
                         * @property {google.cloud.dialogflow.v2.IQueryParameters|null} [queryParams] DetectIntentRequest queryParams
                         * @property {google.cloud.dialogflow.v2.IQueryInput|null} [queryInput] DetectIntentRequest queryInput
                         * @property {google.cloud.dialogflow.v2.IOutputAudioConfig|null} [outputAudioConfig] DetectIntentRequest outputAudioConfig
                         * @property {google.protobuf.IFieldMask|null} [outputAudioConfigMask] DetectIntentRequest outputAudioConfigMask
                         * @property {Uint8Array|null} [inputAudio] DetectIntentRequest inputAudio
                         */
    
                        /**
                         * Constructs a new DetectIntentRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a DetectIntentRequest.
                         * @implements IDetectIntentRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IDetectIntentRequest=} [properties] Properties to set
                         */
                        function DetectIntentRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * DetectIntentRequest session.
                         * @member {string} session
                         * @memberof google.cloud.dialogflow.v2.DetectIntentRequest
                         * @instance
                         */
                        DetectIntentRequest.prototype.session = "";
    
                        /**
                         * DetectIntentRequest queryParams.
                         * @member {google.cloud.dialogflow.v2.IQueryParameters|null|undefined} queryParams
                         * @memberof google.cloud.dialogflow.v2.DetectIntentRequest
                         * @instance
                         */
                        DetectIntentRequest.prototype.queryParams = null;
    
                        /**
                         * DetectIntentRequest queryInput.
                         * @member {google.cloud.dialogflow.v2.IQueryInput|null|undefined} queryInput
                         * @memberof google.cloud.dialogflow.v2.DetectIntentRequest
                         * @instance
                         */
                        DetectIntentRequest.prototype.queryInput = null;
    
                        /**
                         * DetectIntentRequest outputAudioConfig.
                         * @member {google.cloud.dialogflow.v2.IOutputAudioConfig|null|undefined} outputAudioConfig
                         * @memberof google.cloud.dialogflow.v2.DetectIntentRequest
                         * @instance
                         */
                        DetectIntentRequest.prototype.outputAudioConfig = null;
    
                        /**
                         * DetectIntentRequest outputAudioConfigMask.
                         * @member {google.protobuf.IFieldMask|null|undefined} outputAudioConfigMask
                         * @memberof google.cloud.dialogflow.v2.DetectIntentRequest
                         * @instance
                         */
                        DetectIntentRequest.prototype.outputAudioConfigMask = null;
    
                        /**
                         * DetectIntentRequest inputAudio.
                         * @member {Uint8Array} inputAudio
                         * @memberof google.cloud.dialogflow.v2.DetectIntentRequest
                         * @instance
                         */
                        DetectIntentRequest.prototype.inputAudio = $util.newBuffer([]);
    
                        /**
                         * Creates a new DetectIntentRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.DetectIntentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDetectIntentRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.DetectIntentRequest} DetectIntentRequest instance
                         */
                        DetectIntentRequest.create = function create(properties) {
                            return new DetectIntentRequest(properties);
                        };
    
                        /**
                         * Encodes the specified DetectIntentRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.DetectIntentRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.DetectIntentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDetectIntentRequest} message DetectIntentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DetectIntentRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.session != null && Object.hasOwnProperty.call(message, "session"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.session);
                            if (message.queryParams != null && Object.hasOwnProperty.call(message, "queryParams"))
                                $root.google.cloud.dialogflow.v2.QueryParameters.encode(message.queryParams, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.queryInput != null && Object.hasOwnProperty.call(message, "queryInput"))
                                $root.google.cloud.dialogflow.v2.QueryInput.encode(message.queryInput, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            if (message.outputAudioConfig != null && Object.hasOwnProperty.call(message, "outputAudioConfig"))
                                $root.google.cloud.dialogflow.v2.OutputAudioConfig.encode(message.outputAudioConfig, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            if (message.inputAudio != null && Object.hasOwnProperty.call(message, "inputAudio"))
                                writer.uint32(/* id 5, wireType 2 =*/42).bytes(message.inputAudio);
                            if (message.outputAudioConfigMask != null && Object.hasOwnProperty.call(message, "outputAudioConfigMask"))
                                $root.google.protobuf.FieldMask.encode(message.outputAudioConfigMask, writer.uint32(/* id 7, wireType 2 =*/58).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified DetectIntentRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.DetectIntentRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.DetectIntentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDetectIntentRequest} message DetectIntentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DetectIntentRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a DetectIntentRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.DetectIntentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.DetectIntentRequest} DetectIntentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DetectIntentRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.DetectIntentRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.session = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.queryParams = $root.google.cloud.dialogflow.v2.QueryParameters.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 3: {
                                        message.queryInput = $root.google.cloud.dialogflow.v2.QueryInput.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 4: {
                                        message.outputAudioConfig = $root.google.cloud.dialogflow.v2.OutputAudioConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 7: {
                                        message.outputAudioConfigMask = $root.google.protobuf.FieldMask.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 5: {
                                        message.inputAudio = reader.bytes();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a DetectIntentRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.DetectIntentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.DetectIntentRequest} DetectIntentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DetectIntentRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a DetectIntentRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.DetectIntentRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        DetectIntentRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.session != null && message.hasOwnProperty("session"))
                                if (!$util.isString(message.session))
                                    return "session: string expected";
                            if (message.queryParams != null && message.hasOwnProperty("queryParams")) {
                                var error = $root.google.cloud.dialogflow.v2.QueryParameters.verify(message.queryParams);
                                if (error)
                                    return "queryParams." + error;
                            }
                            if (message.queryInput != null && message.hasOwnProperty("queryInput")) {
                                var error = $root.google.cloud.dialogflow.v2.QueryInput.verify(message.queryInput);
                                if (error)
                                    return "queryInput." + error;
                            }
                            if (message.outputAudioConfig != null && message.hasOwnProperty("outputAudioConfig")) {
                                var error = $root.google.cloud.dialogflow.v2.OutputAudioConfig.verify(message.outputAudioConfig);
                                if (error)
                                    return "outputAudioConfig." + error;
                            }
                            if (message.outputAudioConfigMask != null && message.hasOwnProperty("outputAudioConfigMask")) {
                                var error = $root.google.protobuf.FieldMask.verify(message.outputAudioConfigMask);
                                if (error)
                                    return "outputAudioConfigMask." + error;
                            }
                            if (message.inputAudio != null && message.hasOwnProperty("inputAudio"))
                                if (!(message.inputAudio && typeof message.inputAudio.length === "number" || $util.isString(message.inputAudio)))
                                    return "inputAudio: buffer expected";
                            return null;
                        };
    
                        /**
                         * Creates a DetectIntentRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.DetectIntentRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.DetectIntentRequest} DetectIntentRequest
                         */
                        DetectIntentRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.DetectIntentRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.DetectIntentRequest();
                            if (object.session != null)
                                message.session = String(object.session);
                            if (object.queryParams != null) {
                                if (typeof object.queryParams !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.DetectIntentRequest.queryParams: object expected");
                                message.queryParams = $root.google.cloud.dialogflow.v2.QueryParameters.fromObject(object.queryParams);
                            }
                            if (object.queryInput != null) {
                                if (typeof object.queryInput !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.DetectIntentRequest.queryInput: object expected");
                                message.queryInput = $root.google.cloud.dialogflow.v2.QueryInput.fromObject(object.queryInput);
                            }
                            if (object.outputAudioConfig != null) {
                                if (typeof object.outputAudioConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.DetectIntentRequest.outputAudioConfig: object expected");
                                message.outputAudioConfig = $root.google.cloud.dialogflow.v2.OutputAudioConfig.fromObject(object.outputAudioConfig);
                            }
                            if (object.outputAudioConfigMask != null) {
                                if (typeof object.outputAudioConfigMask !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.DetectIntentRequest.outputAudioConfigMask: object expected");
                                message.outputAudioConfigMask = $root.google.protobuf.FieldMask.fromObject(object.outputAudioConfigMask);
                            }
                            if (object.inputAudio != null)
                                if (typeof object.inputAudio === "string")
                                    $util.base64.decode(object.inputAudio, message.inputAudio = $util.newBuffer($util.base64.length(object.inputAudio)), 0);
                                else if (object.inputAudio.length >= 0)
                                    message.inputAudio = object.inputAudio;
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a DetectIntentRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.DetectIntentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.DetectIntentRequest} message DetectIntentRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        DetectIntentRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.session = "";
                                object.queryParams = null;
                                object.queryInput = null;
                                object.outputAudioConfig = null;
                                if (options.bytes === String)
                                    object.inputAudio = "";
                                else {
                                    object.inputAudio = [];
                                    if (options.bytes !== Array)
                                        object.inputAudio = $util.newBuffer(object.inputAudio);
                                }
                                object.outputAudioConfigMask = null;
                            }
                            if (message.session != null && message.hasOwnProperty("session"))
                                object.session = message.session;
                            if (message.queryParams != null && message.hasOwnProperty("queryParams"))
                                object.queryParams = $root.google.cloud.dialogflow.v2.QueryParameters.toObject(message.queryParams, options);
                            if (message.queryInput != null && message.hasOwnProperty("queryInput"))
                                object.queryInput = $root.google.cloud.dialogflow.v2.QueryInput.toObject(message.queryInput, options);
                            if (message.outputAudioConfig != null && message.hasOwnProperty("outputAudioConfig"))
                                object.outputAudioConfig = $root.google.cloud.dialogflow.v2.OutputAudioConfig.toObject(message.outputAudioConfig, options);
                            if (message.inputAudio != null && message.hasOwnProperty("inputAudio"))
                                object.inputAudio = options.bytes === String ? $util.base64.encode(message.inputAudio, 0, message.inputAudio.length) : options.bytes === Array ? Array.prototype.slice.call(message.inputAudio) : message.inputAudio;
                            if (message.outputAudioConfigMask != null && message.hasOwnProperty("outputAudioConfigMask"))
                                object.outputAudioConfigMask = $root.google.protobuf.FieldMask.toObject(message.outputAudioConfigMask, options);
                            return object;
                        };
    
                        /**
                         * Converts this DetectIntentRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.DetectIntentRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        DetectIntentRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for DetectIntentRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.DetectIntentRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        DetectIntentRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.DetectIntentRequest";
                        };
    
                        return DetectIntentRequest;
                    })();
    
                    v2.DetectIntentResponse = (function() {
    
                        /**
                         * Properties of a DetectIntentResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IDetectIntentResponse
                         * @property {string|null} [responseId] DetectIntentResponse responseId
                         * @property {google.cloud.dialogflow.v2.IQueryResult|null} [queryResult] DetectIntentResponse queryResult
                         * @property {google.rpc.IStatus|null} [webhookStatus] DetectIntentResponse webhookStatus
                         * @property {Uint8Array|null} [outputAudio] DetectIntentResponse outputAudio
                         * @property {google.cloud.dialogflow.v2.IOutputAudioConfig|null} [outputAudioConfig] DetectIntentResponse outputAudioConfig
                         */
    
                        /**
                         * Constructs a new DetectIntentResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a DetectIntentResponse.
                         * @implements IDetectIntentResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IDetectIntentResponse=} [properties] Properties to set
                         */
                        function DetectIntentResponse(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * DetectIntentResponse responseId.
                         * @member {string} responseId
                         * @memberof google.cloud.dialogflow.v2.DetectIntentResponse
                         * @instance
                         */
                        DetectIntentResponse.prototype.responseId = "";
    
                        /**
                         * DetectIntentResponse queryResult.
                         * @member {google.cloud.dialogflow.v2.IQueryResult|null|undefined} queryResult
                         * @memberof google.cloud.dialogflow.v2.DetectIntentResponse
                         * @instance
                         */
                        DetectIntentResponse.prototype.queryResult = null;
    
                        /**
                         * DetectIntentResponse webhookStatus.
                         * @member {google.rpc.IStatus|null|undefined} webhookStatus
                         * @memberof google.cloud.dialogflow.v2.DetectIntentResponse
                         * @instance
                         */
                        DetectIntentResponse.prototype.webhookStatus = null;
    
                        /**
                         * DetectIntentResponse outputAudio.
                         * @member {Uint8Array} outputAudio
                         * @memberof google.cloud.dialogflow.v2.DetectIntentResponse
                         * @instance
                         */
                        DetectIntentResponse.prototype.outputAudio = $util.newBuffer([]);
    
                        /**
                         * DetectIntentResponse outputAudioConfig.
                         * @member {google.cloud.dialogflow.v2.IOutputAudioConfig|null|undefined} outputAudioConfig
                         * @memberof google.cloud.dialogflow.v2.DetectIntentResponse
                         * @instance
                         */
                        DetectIntentResponse.prototype.outputAudioConfig = null;
    
                        /**
                         * Creates a new DetectIntentResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.DetectIntentResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDetectIntentResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.DetectIntentResponse} DetectIntentResponse instance
                         */
                        DetectIntentResponse.create = function create(properties) {
                            return new DetectIntentResponse(properties);
                        };
    
                        /**
                         * Encodes the specified DetectIntentResponse message. Does not implicitly {@link google.cloud.dialogflow.v2.DetectIntentResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.DetectIntentResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDetectIntentResponse} message DetectIntentResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DetectIntentResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.responseId != null && Object.hasOwnProperty.call(message, "responseId"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.responseId);
                            if (message.queryResult != null && Object.hasOwnProperty.call(message, "queryResult"))
                                $root.google.cloud.dialogflow.v2.QueryResult.encode(message.queryResult, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.webhookStatus != null && Object.hasOwnProperty.call(message, "webhookStatus"))
                                $root.google.rpc.Status.encode(message.webhookStatus, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            if (message.outputAudio != null && Object.hasOwnProperty.call(message, "outputAudio"))
                                writer.uint32(/* id 4, wireType 2 =*/34).bytes(message.outputAudio);
                            if (message.outputAudioConfig != null && Object.hasOwnProperty.call(message, "outputAudioConfig"))
                                $root.google.cloud.dialogflow.v2.OutputAudioConfig.encode(message.outputAudioConfig, writer.uint32(/* id 6, wireType 2 =*/50).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified DetectIntentResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.DetectIntentResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.DetectIntentResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDetectIntentResponse} message DetectIntentResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DetectIntentResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a DetectIntentResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.DetectIntentResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.DetectIntentResponse} DetectIntentResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DetectIntentResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.DetectIntentResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.responseId = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.queryResult = $root.google.cloud.dialogflow.v2.QueryResult.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 3: {
                                        message.webhookStatus = $root.google.rpc.Status.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 4: {
                                        message.outputAudio = reader.bytes();
                                        break;
                                    }
                                case 6: {
                                        message.outputAudioConfig = $root.google.cloud.dialogflow.v2.OutputAudioConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a DetectIntentResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.DetectIntentResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.DetectIntentResponse} DetectIntentResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DetectIntentResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a DetectIntentResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.DetectIntentResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        DetectIntentResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.responseId != null && message.hasOwnProperty("responseId"))
                                if (!$util.isString(message.responseId))
                                    return "responseId: string expected";
                            if (message.queryResult != null && message.hasOwnProperty("queryResult")) {
                                var error = $root.google.cloud.dialogflow.v2.QueryResult.verify(message.queryResult);
                                if (error)
                                    return "queryResult." + error;
                            }
                            if (message.webhookStatus != null && message.hasOwnProperty("webhookStatus")) {
                                var error = $root.google.rpc.Status.verify(message.webhookStatus);
                                if (error)
                                    return "webhookStatus." + error;
                            }
                            if (message.outputAudio != null && message.hasOwnProperty("outputAudio"))
                                if (!(message.outputAudio && typeof message.outputAudio.length === "number" || $util.isString(message.outputAudio)))
                                    return "outputAudio: buffer expected";
                            if (message.outputAudioConfig != null && message.hasOwnProperty("outputAudioConfig")) {
                                var error = $root.google.cloud.dialogflow.v2.OutputAudioConfig.verify(message.outputAudioConfig);
                                if (error)
                                    return "outputAudioConfig." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a DetectIntentResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.DetectIntentResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.DetectIntentResponse} DetectIntentResponse
                         */
                        DetectIntentResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.DetectIntentResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.DetectIntentResponse();
                            if (object.responseId != null)
                                message.responseId = String(object.responseId);
                            if (object.queryResult != null) {
                                if (typeof object.queryResult !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.DetectIntentResponse.queryResult: object expected");
                                message.queryResult = $root.google.cloud.dialogflow.v2.QueryResult.fromObject(object.queryResult);
                            }
                            if (object.webhookStatus != null) {
                                if (typeof object.webhookStatus !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.DetectIntentResponse.webhookStatus: object expected");
                                message.webhookStatus = $root.google.rpc.Status.fromObject(object.webhookStatus);
                            }
                            if (object.outputAudio != null)
                                if (typeof object.outputAudio === "string")
                                    $util.base64.decode(object.outputAudio, message.outputAudio = $util.newBuffer($util.base64.length(object.outputAudio)), 0);
                                else if (object.outputAudio.length >= 0)
                                    message.outputAudio = object.outputAudio;
                            if (object.outputAudioConfig != null) {
                                if (typeof object.outputAudioConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.DetectIntentResponse.outputAudioConfig: object expected");
                                message.outputAudioConfig = $root.google.cloud.dialogflow.v2.OutputAudioConfig.fromObject(object.outputAudioConfig);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a DetectIntentResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.DetectIntentResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.DetectIntentResponse} message DetectIntentResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        DetectIntentResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.responseId = "";
                                object.queryResult = null;
                                object.webhookStatus = null;
                                if (options.bytes === String)
                                    object.outputAudio = "";
                                else {
                                    object.outputAudio = [];
                                    if (options.bytes !== Array)
                                        object.outputAudio = $util.newBuffer(object.outputAudio);
                                }
                                object.outputAudioConfig = null;
                            }
                            if (message.responseId != null && message.hasOwnProperty("responseId"))
                                object.responseId = message.responseId;
                            if (message.queryResult != null && message.hasOwnProperty("queryResult"))
                                object.queryResult = $root.google.cloud.dialogflow.v2.QueryResult.toObject(message.queryResult, options);
                            if (message.webhookStatus != null && message.hasOwnProperty("webhookStatus"))
                                object.webhookStatus = $root.google.rpc.Status.toObject(message.webhookStatus, options);
                            if (message.outputAudio != null && message.hasOwnProperty("outputAudio"))
                                object.outputAudio = options.bytes === String ? $util.base64.encode(message.outputAudio, 0, message.outputAudio.length) : options.bytes === Array ? Array.prototype.slice.call(message.outputAudio) : message.outputAudio;
                            if (message.outputAudioConfig != null && message.hasOwnProperty("outputAudioConfig"))
                                object.outputAudioConfig = $root.google.cloud.dialogflow.v2.OutputAudioConfig.toObject(message.outputAudioConfig, options);
                            return object;
                        };
    
                        /**
                         * Converts this DetectIntentResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.DetectIntentResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        DetectIntentResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for DetectIntentResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.DetectIntentResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        DetectIntentResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.DetectIntentResponse";
                        };
    
                        return DetectIntentResponse;
                    })();
    
                    v2.QueryParameters = (function() {
    
                        /**
                         * Properties of a QueryParameters.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IQueryParameters
                         * @property {string|null} [timeZone] QueryParameters timeZone
                         * @property {google.type.ILatLng|null} [geoLocation] QueryParameters geoLocation
                         * @property {Array.<google.cloud.dialogflow.v2.IContext>|null} [contexts] QueryParameters contexts
                         * @property {boolean|null} [resetContexts] QueryParameters resetContexts
                         * @property {Array.<google.cloud.dialogflow.v2.ISessionEntityType>|null} [sessionEntityTypes] QueryParameters sessionEntityTypes
                         * @property {google.protobuf.IStruct|null} [payload] QueryParameters payload
                         * @property {google.cloud.dialogflow.v2.ISentimentAnalysisRequestConfig|null} [sentimentAnalysisRequestConfig] QueryParameters sentimentAnalysisRequestConfig
                         * @property {Object.<string,string>|null} [webhookHeaders] QueryParameters webhookHeaders
                         * @property {string|null} [platform] QueryParameters platform
                         */
    
                        /**
                         * Constructs a new QueryParameters.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a QueryParameters.
                         * @implements IQueryParameters
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IQueryParameters=} [properties] Properties to set
                         */
                        function QueryParameters(properties) {
                            this.contexts = [];
                            this.sessionEntityTypes = [];
                            this.webhookHeaders = {};
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * QueryParameters timeZone.
                         * @member {string} timeZone
                         * @memberof google.cloud.dialogflow.v2.QueryParameters
                         * @instance
                         */
                        QueryParameters.prototype.timeZone = "";
    
                        /**
                         * QueryParameters geoLocation.
                         * @member {google.type.ILatLng|null|undefined} geoLocation
                         * @memberof google.cloud.dialogflow.v2.QueryParameters
                         * @instance
                         */
                        QueryParameters.prototype.geoLocation = null;
    
                        /**
                         * QueryParameters contexts.
                         * @member {Array.<google.cloud.dialogflow.v2.IContext>} contexts
                         * @memberof google.cloud.dialogflow.v2.QueryParameters
                         * @instance
                         */
                        QueryParameters.prototype.contexts = $util.emptyArray;
    
                        /**
                         * QueryParameters resetContexts.
                         * @member {boolean} resetContexts
                         * @memberof google.cloud.dialogflow.v2.QueryParameters
                         * @instance
                         */
                        QueryParameters.prototype.resetContexts = false;
    
                        /**
                         * QueryParameters sessionEntityTypes.
                         * @member {Array.<google.cloud.dialogflow.v2.ISessionEntityType>} sessionEntityTypes
                         * @memberof google.cloud.dialogflow.v2.QueryParameters
                         * @instance
                         */
                        QueryParameters.prototype.sessionEntityTypes = $util.emptyArray;
    
                        /**
                         * QueryParameters payload.
                         * @member {google.protobuf.IStruct|null|undefined} payload
                         * @memberof google.cloud.dialogflow.v2.QueryParameters
                         * @instance
                         */
                        QueryParameters.prototype.payload = null;
    
                        /**
                         * QueryParameters sentimentAnalysisRequestConfig.
                         * @member {google.cloud.dialogflow.v2.ISentimentAnalysisRequestConfig|null|undefined} sentimentAnalysisRequestConfig
                         * @memberof google.cloud.dialogflow.v2.QueryParameters
                         * @instance
                         */
                        QueryParameters.prototype.sentimentAnalysisRequestConfig = null;
    
                        /**
                         * QueryParameters webhookHeaders.
                         * @member {Object.<string,string>} webhookHeaders
                         * @memberof google.cloud.dialogflow.v2.QueryParameters
                         * @instance
                         */
                        QueryParameters.prototype.webhookHeaders = $util.emptyObject;
    
                        /**
                         * QueryParameters platform.
                         * @member {string} platform
                         * @memberof google.cloud.dialogflow.v2.QueryParameters
                         * @instance
                         */
                        QueryParameters.prototype.platform = "";
    
                        /**
                         * Creates a new QueryParameters instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.QueryParameters
                         * @static
                         * @param {google.cloud.dialogflow.v2.IQueryParameters=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.QueryParameters} QueryParameters instance
                         */
                        QueryParameters.create = function create(properties) {
                            return new QueryParameters(properties);
                        };
    
                        /**
                         * Encodes the specified QueryParameters message. Does not implicitly {@link google.cloud.dialogflow.v2.QueryParameters.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.QueryParameters
                         * @static
                         * @param {google.cloud.dialogflow.v2.IQueryParameters} message QueryParameters message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        QueryParameters.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.timeZone != null && Object.hasOwnProperty.call(message, "timeZone"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.timeZone);
                            if (message.geoLocation != null && Object.hasOwnProperty.call(message, "geoLocation"))
                                $root.google.type.LatLng.encode(message.geoLocation, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.contexts != null && message.contexts.length)
                                for (var i = 0; i < message.contexts.length; ++i)
                                    $root.google.cloud.dialogflow.v2.Context.encode(message.contexts[i], writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            if (message.resetContexts != null && Object.hasOwnProperty.call(message, "resetContexts"))
                                writer.uint32(/* id 4, wireType 0 =*/32).bool(message.resetContexts);
                            if (message.sessionEntityTypes != null && message.sessionEntityTypes.length)
                                for (var i = 0; i < message.sessionEntityTypes.length; ++i)
                                    $root.google.cloud.dialogflow.v2.SessionEntityType.encode(message.sessionEntityTypes[i], writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                            if (message.payload != null && Object.hasOwnProperty.call(message, "payload"))
                                $root.google.protobuf.Struct.encode(message.payload, writer.uint32(/* id 6, wireType 2 =*/50).fork()).ldelim();
                            if (message.sentimentAnalysisRequestConfig != null && Object.hasOwnProperty.call(message, "sentimentAnalysisRequestConfig"))
                                $root.google.cloud.dialogflow.v2.SentimentAnalysisRequestConfig.encode(message.sentimentAnalysisRequestConfig, writer.uint32(/* id 10, wireType 2 =*/82).fork()).ldelim();
                            if (message.webhookHeaders != null && Object.hasOwnProperty.call(message, "webhookHeaders"))
                                for (var keys = Object.keys(message.webhookHeaders), i = 0; i < keys.length; ++i)
                                    writer.uint32(/* id 14, wireType 2 =*/114).fork().uint32(/* id 1, wireType 2 =*/10).string(keys[i]).uint32(/* id 2, wireType 2 =*/18).string(message.webhookHeaders[keys[i]]).ldelim();
                            if (message.platform != null && Object.hasOwnProperty.call(message, "platform"))
                                writer.uint32(/* id 18, wireType 2 =*/146).string(message.platform);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified QueryParameters message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.QueryParameters.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.QueryParameters
                         * @static
                         * @param {google.cloud.dialogflow.v2.IQueryParameters} message QueryParameters message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        QueryParameters.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a QueryParameters message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.QueryParameters
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.QueryParameters} QueryParameters
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        QueryParameters.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.QueryParameters(), key, value;
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.timeZone = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.geoLocation = $root.google.type.LatLng.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 3: {
                                        if (!(message.contexts && message.contexts.length))
                                            message.contexts = [];
                                        message.contexts.push($root.google.cloud.dialogflow.v2.Context.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 4: {
                                        message.resetContexts = reader.bool();
                                        break;
                                    }
                                case 5: {
                                        if (!(message.sessionEntityTypes && message.sessionEntityTypes.length))
                                            message.sessionEntityTypes = [];
                                        message.sessionEntityTypes.push($root.google.cloud.dialogflow.v2.SessionEntityType.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 6: {
                                        message.payload = $root.google.protobuf.Struct.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 10: {
                                        message.sentimentAnalysisRequestConfig = $root.google.cloud.dialogflow.v2.SentimentAnalysisRequestConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 14: {
                                        if (message.webhookHeaders === $util.emptyObject)
                                            message.webhookHeaders = {};
                                        var end2 = reader.uint32() + reader.pos;
                                        key = "";
                                        value = "";
                                        while (reader.pos < end2) {
                                            var tag2 = reader.uint32();
                                            switch (tag2 >>> 3) {
                                            case 1:
                                                key = reader.string();
                                                break;
                                            case 2:
                                                value = reader.string();
                                                break;
                                            default:
                                                reader.skipType(tag2 & 7);
                                                break;
                                            }
                                        }
                                        message.webhookHeaders[key] = value;
                                        break;
                                    }
                                case 18: {
                                        message.platform = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a QueryParameters message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.QueryParameters
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.QueryParameters} QueryParameters
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        QueryParameters.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a QueryParameters message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.QueryParameters
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        QueryParameters.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.timeZone != null && message.hasOwnProperty("timeZone"))
                                if (!$util.isString(message.timeZone))
                                    return "timeZone: string expected";
                            if (message.geoLocation != null && message.hasOwnProperty("geoLocation")) {
                                var error = $root.google.type.LatLng.verify(message.geoLocation);
                                if (error)
                                    return "geoLocation." + error;
                            }
                            if (message.contexts != null && message.hasOwnProperty("contexts")) {
                                if (!Array.isArray(message.contexts))
                                    return "contexts: array expected";
                                for (var i = 0; i < message.contexts.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.Context.verify(message.contexts[i]);
                                    if (error)
                                        return "contexts." + error;
                                }
                            }
                            if (message.resetContexts != null && message.hasOwnProperty("resetContexts"))
                                if (typeof message.resetContexts !== "boolean")
                                    return "resetContexts: boolean expected";
                            if (message.sessionEntityTypes != null && message.hasOwnProperty("sessionEntityTypes")) {
                                if (!Array.isArray(message.sessionEntityTypes))
                                    return "sessionEntityTypes: array expected";
                                for (var i = 0; i < message.sessionEntityTypes.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.SessionEntityType.verify(message.sessionEntityTypes[i]);
                                    if (error)
                                        return "sessionEntityTypes." + error;
                                }
                            }
                            if (message.payload != null && message.hasOwnProperty("payload")) {
                                var error = $root.google.protobuf.Struct.verify(message.payload);
                                if (error)
                                    return "payload." + error;
                            }
                            if (message.sentimentAnalysisRequestConfig != null && message.hasOwnProperty("sentimentAnalysisRequestConfig")) {
                                var error = $root.google.cloud.dialogflow.v2.SentimentAnalysisRequestConfig.verify(message.sentimentAnalysisRequestConfig);
                                if (error)
                                    return "sentimentAnalysisRequestConfig." + error;
                            }
                            if (message.webhookHeaders != null && message.hasOwnProperty("webhookHeaders")) {
                                if (!$util.isObject(message.webhookHeaders))
                                    return "webhookHeaders: object expected";
                                var key = Object.keys(message.webhookHeaders);
                                for (var i = 0; i < key.length; ++i)
                                    if (!$util.isString(message.webhookHeaders[key[i]]))
                                        return "webhookHeaders: string{k:string} expected";
                            }
                            if (message.platform != null && message.hasOwnProperty("platform"))
                                if (!$util.isString(message.platform))
                                    return "platform: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a QueryParameters message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.QueryParameters
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.QueryParameters} QueryParameters
                         */
                        QueryParameters.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.QueryParameters)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.QueryParameters();
                            if (object.timeZone != null)
                                message.timeZone = String(object.timeZone);
                            if (object.geoLocation != null) {
                                if (typeof object.geoLocation !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.QueryParameters.geoLocation: object expected");
                                message.geoLocation = $root.google.type.LatLng.fromObject(object.geoLocation);
                            }
                            if (object.contexts) {
                                if (!Array.isArray(object.contexts))
                                    throw TypeError(".google.cloud.dialogflow.v2.QueryParameters.contexts: array expected");
                                message.contexts = [];
                                for (var i = 0; i < object.contexts.length; ++i) {
                                    if (typeof object.contexts[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.QueryParameters.contexts: object expected");
                                    message.contexts[i] = $root.google.cloud.dialogflow.v2.Context.fromObject(object.contexts[i]);
                                }
                            }
                            if (object.resetContexts != null)
                                message.resetContexts = Boolean(object.resetContexts);
                            if (object.sessionEntityTypes) {
                                if (!Array.isArray(object.sessionEntityTypes))
                                    throw TypeError(".google.cloud.dialogflow.v2.QueryParameters.sessionEntityTypes: array expected");
                                message.sessionEntityTypes = [];
                                for (var i = 0; i < object.sessionEntityTypes.length; ++i) {
                                    if (typeof object.sessionEntityTypes[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.QueryParameters.sessionEntityTypes: object expected");
                                    message.sessionEntityTypes[i] = $root.google.cloud.dialogflow.v2.SessionEntityType.fromObject(object.sessionEntityTypes[i]);
                                }
                            }
                            if (object.payload != null) {
                                if (typeof object.payload !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.QueryParameters.payload: object expected");
                                message.payload = $root.google.protobuf.Struct.fromObject(object.payload);
                            }
                            if (object.sentimentAnalysisRequestConfig != null) {
                                if (typeof object.sentimentAnalysisRequestConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.QueryParameters.sentimentAnalysisRequestConfig: object expected");
                                message.sentimentAnalysisRequestConfig = $root.google.cloud.dialogflow.v2.SentimentAnalysisRequestConfig.fromObject(object.sentimentAnalysisRequestConfig);
                            }
                            if (object.webhookHeaders) {
                                if (typeof object.webhookHeaders !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.QueryParameters.webhookHeaders: object expected");
                                message.webhookHeaders = {};
                                for (var keys = Object.keys(object.webhookHeaders), i = 0; i < keys.length; ++i)
                                    message.webhookHeaders[keys[i]] = String(object.webhookHeaders[keys[i]]);
                            }
                            if (object.platform != null)
                                message.platform = String(object.platform);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a QueryParameters message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.QueryParameters
                         * @static
                         * @param {google.cloud.dialogflow.v2.QueryParameters} message QueryParameters
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        QueryParameters.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults) {
                                object.contexts = [];
                                object.sessionEntityTypes = [];
                            }
                            if (options.objects || options.defaults)
                                object.webhookHeaders = {};
                            if (options.defaults) {
                                object.timeZone = "";
                                object.geoLocation = null;
                                object.resetContexts = false;
                                object.payload = null;
                                object.sentimentAnalysisRequestConfig = null;
                                object.platform = "";
                            }
                            if (message.timeZone != null && message.hasOwnProperty("timeZone"))
                                object.timeZone = message.timeZone;
                            if (message.geoLocation != null && message.hasOwnProperty("geoLocation"))
                                object.geoLocation = $root.google.type.LatLng.toObject(message.geoLocation, options);
                            if (message.contexts && message.contexts.length) {
                                object.contexts = [];
                                for (var j = 0; j < message.contexts.length; ++j)
                                    object.contexts[j] = $root.google.cloud.dialogflow.v2.Context.toObject(message.contexts[j], options);
                            }
                            if (message.resetContexts != null && message.hasOwnProperty("resetContexts"))
                                object.resetContexts = message.resetContexts;
                            if (message.sessionEntityTypes && message.sessionEntityTypes.length) {
                                object.sessionEntityTypes = [];
                                for (var j = 0; j < message.sessionEntityTypes.length; ++j)
                                    object.sessionEntityTypes[j] = $root.google.cloud.dialogflow.v2.SessionEntityType.toObject(message.sessionEntityTypes[j], options);
                            }
                            if (message.payload != null && message.hasOwnProperty("payload"))
                                object.payload = $root.google.protobuf.Struct.toObject(message.payload, options);
                            if (message.sentimentAnalysisRequestConfig != null && message.hasOwnProperty("sentimentAnalysisRequestConfig"))
                                object.sentimentAnalysisRequestConfig = $root.google.cloud.dialogflow.v2.SentimentAnalysisRequestConfig.toObject(message.sentimentAnalysisRequestConfig, options);
                            var keys2;
                            if (message.webhookHeaders && (keys2 = Object.keys(message.webhookHeaders)).length) {
                                object.webhookHeaders = {};
                                for (var j = 0; j < keys2.length; ++j)
                                    object.webhookHeaders[keys2[j]] = message.webhookHeaders[keys2[j]];
                            }
                            if (message.platform != null && message.hasOwnProperty("platform"))
                                object.platform = message.platform;
                            return object;
                        };
    
                        /**
                         * Converts this QueryParameters to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.QueryParameters
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        QueryParameters.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for QueryParameters
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.QueryParameters
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        QueryParameters.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.QueryParameters";
                        };
    
                        return QueryParameters;
                    })();
    
                    v2.QueryInput = (function() {
    
                        /**
                         * Properties of a QueryInput.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IQueryInput
                         * @property {google.cloud.dialogflow.v2.IInputAudioConfig|null} [audioConfig] QueryInput audioConfig
                         * @property {google.cloud.dialogflow.v2.ITextInput|null} [text] QueryInput text
                         * @property {google.cloud.dialogflow.v2.IEventInput|null} [event] QueryInput event
                         */
    
                        /**
                         * Constructs a new QueryInput.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a QueryInput.
                         * @implements IQueryInput
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IQueryInput=} [properties] Properties to set
                         */
                        function QueryInput(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * QueryInput audioConfig.
                         * @member {google.cloud.dialogflow.v2.IInputAudioConfig|null|undefined} audioConfig
                         * @memberof google.cloud.dialogflow.v2.QueryInput
                         * @instance
                         */
                        QueryInput.prototype.audioConfig = null;
    
                        /**
                         * QueryInput text.
                         * @member {google.cloud.dialogflow.v2.ITextInput|null|undefined} text
                         * @memberof google.cloud.dialogflow.v2.QueryInput
                         * @instance
                         */
                        QueryInput.prototype.text = null;
    
                        /**
                         * QueryInput event.
                         * @member {google.cloud.dialogflow.v2.IEventInput|null|undefined} event
                         * @memberof google.cloud.dialogflow.v2.QueryInput
                         * @instance
                         */
                        QueryInput.prototype.event = null;
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * QueryInput input.
                         * @member {"audioConfig"|"text"|"event"|undefined} input
                         * @memberof google.cloud.dialogflow.v2.QueryInput
                         * @instance
                         */
                        Object.defineProperty(QueryInput.prototype, "input", {
                            get: $util.oneOfGetter($oneOfFields = ["audioConfig", "text", "event"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new QueryInput instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.QueryInput
                         * @static
                         * @param {google.cloud.dialogflow.v2.IQueryInput=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.QueryInput} QueryInput instance
                         */
                        QueryInput.create = function create(properties) {
                            return new QueryInput(properties);
                        };
    
                        /**
                         * Encodes the specified QueryInput message. Does not implicitly {@link google.cloud.dialogflow.v2.QueryInput.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.QueryInput
                         * @static
                         * @param {google.cloud.dialogflow.v2.IQueryInput} message QueryInput message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        QueryInput.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.audioConfig != null && Object.hasOwnProperty.call(message, "audioConfig"))
                                $root.google.cloud.dialogflow.v2.InputAudioConfig.encode(message.audioConfig, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.text != null && Object.hasOwnProperty.call(message, "text"))
                                $root.google.cloud.dialogflow.v2.TextInput.encode(message.text, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.event != null && Object.hasOwnProperty.call(message, "event"))
                                $root.google.cloud.dialogflow.v2.EventInput.encode(message.event, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified QueryInput message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.QueryInput.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.QueryInput
                         * @static
                         * @param {google.cloud.dialogflow.v2.IQueryInput} message QueryInput message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        QueryInput.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a QueryInput message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.QueryInput
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.QueryInput} QueryInput
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        QueryInput.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.QueryInput();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.audioConfig = $root.google.cloud.dialogflow.v2.InputAudioConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.text = $root.google.cloud.dialogflow.v2.TextInput.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 3: {
                                        message.event = $root.google.cloud.dialogflow.v2.EventInput.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a QueryInput message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.QueryInput
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.QueryInput} QueryInput
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        QueryInput.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a QueryInput message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.QueryInput
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        QueryInput.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.audioConfig != null && message.hasOwnProperty("audioConfig")) {
                                properties.input = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2.InputAudioConfig.verify(message.audioConfig);
                                    if (error)
                                        return "audioConfig." + error;
                                }
                            }
                            if (message.text != null && message.hasOwnProperty("text")) {
                                if (properties.input === 1)
                                    return "input: multiple values";
                                properties.input = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2.TextInput.verify(message.text);
                                    if (error)
                                        return "text." + error;
                                }
                            }
                            if (message.event != null && message.hasOwnProperty("event")) {
                                if (properties.input === 1)
                                    return "input: multiple values";
                                properties.input = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2.EventInput.verify(message.event);
                                    if (error)
                                        return "event." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates a QueryInput message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.QueryInput
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.QueryInput} QueryInput
                         */
                        QueryInput.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.QueryInput)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.QueryInput();
                            if (object.audioConfig != null) {
                                if (typeof object.audioConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.QueryInput.audioConfig: object expected");
                                message.audioConfig = $root.google.cloud.dialogflow.v2.InputAudioConfig.fromObject(object.audioConfig);
                            }
                            if (object.text != null) {
                                if (typeof object.text !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.QueryInput.text: object expected");
                                message.text = $root.google.cloud.dialogflow.v2.TextInput.fromObject(object.text);
                            }
                            if (object.event != null) {
                                if (typeof object.event !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.QueryInput.event: object expected");
                                message.event = $root.google.cloud.dialogflow.v2.EventInput.fromObject(object.event);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a QueryInput message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.QueryInput
                         * @static
                         * @param {google.cloud.dialogflow.v2.QueryInput} message QueryInput
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        QueryInput.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (message.audioConfig != null && message.hasOwnProperty("audioConfig")) {
                                object.audioConfig = $root.google.cloud.dialogflow.v2.InputAudioConfig.toObject(message.audioConfig, options);
                                if (options.oneofs)
                                    object.input = "audioConfig";
                            }
                            if (message.text != null && message.hasOwnProperty("text")) {
                                object.text = $root.google.cloud.dialogflow.v2.TextInput.toObject(message.text, options);
                                if (options.oneofs)
                                    object.input = "text";
                            }
                            if (message.event != null && message.hasOwnProperty("event")) {
                                object.event = $root.google.cloud.dialogflow.v2.EventInput.toObject(message.event, options);
                                if (options.oneofs)
                                    object.input = "event";
                            }
                            return object;
                        };
    
                        /**
                         * Converts this QueryInput to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.QueryInput
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        QueryInput.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for QueryInput
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.QueryInput
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        QueryInput.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.QueryInput";
                        };
    
                        return QueryInput;
                    })();
    
                    v2.QueryResult = (function() {
    
                        /**
                         * Properties of a QueryResult.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IQueryResult
                         * @property {string|null} [queryText] QueryResult queryText
                         * @property {string|null} [languageCode] QueryResult languageCode
                         * @property {number|null} [speechRecognitionConfidence] QueryResult speechRecognitionConfidence
                         * @property {string|null} [action] QueryResult action
                         * @property {google.protobuf.IStruct|null} [parameters] QueryResult parameters
                         * @property {boolean|null} [allRequiredParamsPresent] QueryResult allRequiredParamsPresent
                         * @property {boolean|null} [cancelsSlotFilling] QueryResult cancelsSlotFilling
                         * @property {string|null} [fulfillmentText] QueryResult fulfillmentText
                         * @property {Array.<google.cloud.dialogflow.v2.Intent.IMessage>|null} [fulfillmentMessages] QueryResult fulfillmentMessages
                         * @property {string|null} [webhookSource] QueryResult webhookSource
                         * @property {google.protobuf.IStruct|null} [webhookPayload] QueryResult webhookPayload
                         * @property {Array.<google.cloud.dialogflow.v2.IContext>|null} [outputContexts] QueryResult outputContexts
                         * @property {google.cloud.dialogflow.v2.IIntent|null} [intent] QueryResult intent
                         * @property {number|null} [intentDetectionConfidence] QueryResult intentDetectionConfidence
                         * @property {google.protobuf.IStruct|null} [diagnosticInfo] QueryResult diagnosticInfo
                         * @property {google.cloud.dialogflow.v2.ISentimentAnalysisResult|null} [sentimentAnalysisResult] QueryResult sentimentAnalysisResult
                         */
    
                        /**
                         * Constructs a new QueryResult.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a QueryResult.
                         * @implements IQueryResult
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IQueryResult=} [properties] Properties to set
                         */
                        function QueryResult(properties) {
                            this.fulfillmentMessages = [];
                            this.outputContexts = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * QueryResult queryText.
                         * @member {string} queryText
                         * @memberof google.cloud.dialogflow.v2.QueryResult
                         * @instance
                         */
                        QueryResult.prototype.queryText = "";
    
                        /**
                         * QueryResult languageCode.
                         * @member {string} languageCode
                         * @memberof google.cloud.dialogflow.v2.QueryResult
                         * @instance
                         */
                        QueryResult.prototype.languageCode = "";
    
                        /**
                         * QueryResult speechRecognitionConfidence.
                         * @member {number} speechRecognitionConfidence
                         * @memberof google.cloud.dialogflow.v2.QueryResult
                         * @instance
                         */
                        QueryResult.prototype.speechRecognitionConfidence = 0;
    
                        /**
                         * QueryResult action.
                         * @member {string} action
                         * @memberof google.cloud.dialogflow.v2.QueryResult
                         * @instance
                         */
                        QueryResult.prototype.action = "";
    
                        /**
                         * QueryResult parameters.
                         * @member {google.protobuf.IStruct|null|undefined} parameters
                         * @memberof google.cloud.dialogflow.v2.QueryResult
                         * @instance
                         */
                        QueryResult.prototype.parameters = null;
    
                        /**
                         * QueryResult allRequiredParamsPresent.
                         * @member {boolean} allRequiredParamsPresent
                         * @memberof google.cloud.dialogflow.v2.QueryResult
                         * @instance
                         */
                        QueryResult.prototype.allRequiredParamsPresent = false;
    
                        /**
                         * QueryResult cancelsSlotFilling.
                         * @member {boolean} cancelsSlotFilling
                         * @memberof google.cloud.dialogflow.v2.QueryResult
                         * @instance
                         */
                        QueryResult.prototype.cancelsSlotFilling = false;
    
                        /**
                         * QueryResult fulfillmentText.
                         * @member {string} fulfillmentText
                         * @memberof google.cloud.dialogflow.v2.QueryResult
                         * @instance
                         */
                        QueryResult.prototype.fulfillmentText = "";
    
                        /**
                         * QueryResult fulfillmentMessages.
                         * @member {Array.<google.cloud.dialogflow.v2.Intent.IMessage>} fulfillmentMessages
                         * @memberof google.cloud.dialogflow.v2.QueryResult
                         * @instance
                         */
                        QueryResult.prototype.fulfillmentMessages = $util.emptyArray;
    
                        /**
                         * QueryResult webhookSource.
                         * @member {string} webhookSource
                         * @memberof google.cloud.dialogflow.v2.QueryResult
                         * @instance
                         */
                        QueryResult.prototype.webhookSource = "";
    
                        /**
                         * QueryResult webhookPayload.
                         * @member {google.protobuf.IStruct|null|undefined} webhookPayload
                         * @memberof google.cloud.dialogflow.v2.QueryResult
                         * @instance
                         */
                        QueryResult.prototype.webhookPayload = null;
    
                        /**
                         * QueryResult outputContexts.
                         * @member {Array.<google.cloud.dialogflow.v2.IContext>} outputContexts
                         * @memberof google.cloud.dialogflow.v2.QueryResult
                         * @instance
                         */
                        QueryResult.prototype.outputContexts = $util.emptyArray;
    
                        /**
                         * QueryResult intent.
                         * @member {google.cloud.dialogflow.v2.IIntent|null|undefined} intent
                         * @memberof google.cloud.dialogflow.v2.QueryResult
                         * @instance
                         */
                        QueryResult.prototype.intent = null;
    
                        /**
                         * QueryResult intentDetectionConfidence.
                         * @member {number} intentDetectionConfidence
                         * @memberof google.cloud.dialogflow.v2.QueryResult
                         * @instance
                         */
                        QueryResult.prototype.intentDetectionConfidence = 0;
    
                        /**
                         * QueryResult diagnosticInfo.
                         * @member {google.protobuf.IStruct|null|undefined} diagnosticInfo
                         * @memberof google.cloud.dialogflow.v2.QueryResult
                         * @instance
                         */
                        QueryResult.prototype.diagnosticInfo = null;
    
                        /**
                         * QueryResult sentimentAnalysisResult.
                         * @member {google.cloud.dialogflow.v2.ISentimentAnalysisResult|null|undefined} sentimentAnalysisResult
                         * @memberof google.cloud.dialogflow.v2.QueryResult
                         * @instance
                         */
                        QueryResult.prototype.sentimentAnalysisResult = null;
    
                        /**
                         * Creates a new QueryResult instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.QueryResult
                         * @static
                         * @param {google.cloud.dialogflow.v2.IQueryResult=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.QueryResult} QueryResult instance
                         */
                        QueryResult.create = function create(properties) {
                            return new QueryResult(properties);
                        };
    
                        /**
                         * Encodes the specified QueryResult message. Does not implicitly {@link google.cloud.dialogflow.v2.QueryResult.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.QueryResult
                         * @static
                         * @param {google.cloud.dialogflow.v2.IQueryResult} message QueryResult message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        QueryResult.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.queryText != null && Object.hasOwnProperty.call(message, "queryText"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.queryText);
                            if (message.speechRecognitionConfidence != null && Object.hasOwnProperty.call(message, "speechRecognitionConfidence"))
                                writer.uint32(/* id 2, wireType 5 =*/21).float(message.speechRecognitionConfidence);
                            if (message.action != null && Object.hasOwnProperty.call(message, "action"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.action);
                            if (message.parameters != null && Object.hasOwnProperty.call(message, "parameters"))
                                $root.google.protobuf.Struct.encode(message.parameters, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            if (message.allRequiredParamsPresent != null && Object.hasOwnProperty.call(message, "allRequiredParamsPresent"))
                                writer.uint32(/* id 5, wireType 0 =*/40).bool(message.allRequiredParamsPresent);
                            if (message.fulfillmentText != null && Object.hasOwnProperty.call(message, "fulfillmentText"))
                                writer.uint32(/* id 6, wireType 2 =*/50).string(message.fulfillmentText);
                            if (message.fulfillmentMessages != null && message.fulfillmentMessages.length)
                                for (var i = 0; i < message.fulfillmentMessages.length; ++i)
                                    $root.google.cloud.dialogflow.v2.Intent.Message.encode(message.fulfillmentMessages[i], writer.uint32(/* id 7, wireType 2 =*/58).fork()).ldelim();
                            if (message.webhookSource != null && Object.hasOwnProperty.call(message, "webhookSource"))
                                writer.uint32(/* id 8, wireType 2 =*/66).string(message.webhookSource);
                            if (message.webhookPayload != null && Object.hasOwnProperty.call(message, "webhookPayload"))
                                $root.google.protobuf.Struct.encode(message.webhookPayload, writer.uint32(/* id 9, wireType 2 =*/74).fork()).ldelim();
                            if (message.outputContexts != null && message.outputContexts.length)
                                for (var i = 0; i < message.outputContexts.length; ++i)
                                    $root.google.cloud.dialogflow.v2.Context.encode(message.outputContexts[i], writer.uint32(/* id 10, wireType 2 =*/82).fork()).ldelim();
                            if (message.intent != null && Object.hasOwnProperty.call(message, "intent"))
                                $root.google.cloud.dialogflow.v2.Intent.encode(message.intent, writer.uint32(/* id 11, wireType 2 =*/90).fork()).ldelim();
                            if (message.intentDetectionConfidence != null && Object.hasOwnProperty.call(message, "intentDetectionConfidence"))
                                writer.uint32(/* id 12, wireType 5 =*/101).float(message.intentDetectionConfidence);
                            if (message.diagnosticInfo != null && Object.hasOwnProperty.call(message, "diagnosticInfo"))
                                $root.google.protobuf.Struct.encode(message.diagnosticInfo, writer.uint32(/* id 14, wireType 2 =*/114).fork()).ldelim();
                            if (message.languageCode != null && Object.hasOwnProperty.call(message, "languageCode"))
                                writer.uint32(/* id 15, wireType 2 =*/122).string(message.languageCode);
                            if (message.sentimentAnalysisResult != null && Object.hasOwnProperty.call(message, "sentimentAnalysisResult"))
                                $root.google.cloud.dialogflow.v2.SentimentAnalysisResult.encode(message.sentimentAnalysisResult, writer.uint32(/* id 17, wireType 2 =*/138).fork()).ldelim();
                            if (message.cancelsSlotFilling != null && Object.hasOwnProperty.call(message, "cancelsSlotFilling"))
                                writer.uint32(/* id 21, wireType 0 =*/168).bool(message.cancelsSlotFilling);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified QueryResult message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.QueryResult.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.QueryResult
                         * @static
                         * @param {google.cloud.dialogflow.v2.IQueryResult} message QueryResult message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        QueryResult.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a QueryResult message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.QueryResult
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.QueryResult} QueryResult
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        QueryResult.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.QueryResult();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.queryText = reader.string();
                                        break;
                                    }
                                case 15: {
                                        message.languageCode = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.speechRecognitionConfidence = reader.float();
                                        break;
                                    }
                                case 3: {
                                        message.action = reader.string();
                                        break;
                                    }
                                case 4: {
                                        message.parameters = $root.google.protobuf.Struct.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 5: {
                                        message.allRequiredParamsPresent = reader.bool();
                                        break;
                                    }
                                case 21: {
                                        message.cancelsSlotFilling = reader.bool();
                                        break;
                                    }
                                case 6: {
                                        message.fulfillmentText = reader.string();
                                        break;
                                    }
                                case 7: {
                                        if (!(message.fulfillmentMessages && message.fulfillmentMessages.length))
                                            message.fulfillmentMessages = [];
                                        message.fulfillmentMessages.push($root.google.cloud.dialogflow.v2.Intent.Message.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 8: {
                                        message.webhookSource = reader.string();
                                        break;
                                    }
                                case 9: {
                                        message.webhookPayload = $root.google.protobuf.Struct.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 10: {
                                        if (!(message.outputContexts && message.outputContexts.length))
                                            message.outputContexts = [];
                                        message.outputContexts.push($root.google.cloud.dialogflow.v2.Context.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 11: {
                                        message.intent = $root.google.cloud.dialogflow.v2.Intent.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 12: {
                                        message.intentDetectionConfidence = reader.float();
                                        break;
                                    }
                                case 14: {
                                        message.diagnosticInfo = $root.google.protobuf.Struct.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 17: {
                                        message.sentimentAnalysisResult = $root.google.cloud.dialogflow.v2.SentimentAnalysisResult.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a QueryResult message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.QueryResult
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.QueryResult} QueryResult
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        QueryResult.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a QueryResult message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.QueryResult
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        QueryResult.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.queryText != null && message.hasOwnProperty("queryText"))
                                if (!$util.isString(message.queryText))
                                    return "queryText: string expected";
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                if (!$util.isString(message.languageCode))
                                    return "languageCode: string expected";
                            if (message.speechRecognitionConfidence != null && message.hasOwnProperty("speechRecognitionConfidence"))
                                if (typeof message.speechRecognitionConfidence !== "number")
                                    return "speechRecognitionConfidence: number expected";
                            if (message.action != null && message.hasOwnProperty("action"))
                                if (!$util.isString(message.action))
                                    return "action: string expected";
                            if (message.parameters != null && message.hasOwnProperty("parameters")) {
                                var error = $root.google.protobuf.Struct.verify(message.parameters);
                                if (error)
                                    return "parameters." + error;
                            }
                            if (message.allRequiredParamsPresent != null && message.hasOwnProperty("allRequiredParamsPresent"))
                                if (typeof message.allRequiredParamsPresent !== "boolean")
                                    return "allRequiredParamsPresent: boolean expected";
                            if (message.cancelsSlotFilling != null && message.hasOwnProperty("cancelsSlotFilling"))
                                if (typeof message.cancelsSlotFilling !== "boolean")
                                    return "cancelsSlotFilling: boolean expected";
                            if (message.fulfillmentText != null && message.hasOwnProperty("fulfillmentText"))
                                if (!$util.isString(message.fulfillmentText))
                                    return "fulfillmentText: string expected";
                            if (message.fulfillmentMessages != null && message.hasOwnProperty("fulfillmentMessages")) {
                                if (!Array.isArray(message.fulfillmentMessages))
                                    return "fulfillmentMessages: array expected";
                                for (var i = 0; i < message.fulfillmentMessages.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.Intent.Message.verify(message.fulfillmentMessages[i]);
                                    if (error)
                                        return "fulfillmentMessages." + error;
                                }
                            }
                            if (message.webhookSource != null && message.hasOwnProperty("webhookSource"))
                                if (!$util.isString(message.webhookSource))
                                    return "webhookSource: string expected";
                            if (message.webhookPayload != null && message.hasOwnProperty("webhookPayload")) {
                                var error = $root.google.protobuf.Struct.verify(message.webhookPayload);
                                if (error)
                                    return "webhookPayload." + error;
                            }
                            if (message.outputContexts != null && message.hasOwnProperty("outputContexts")) {
                                if (!Array.isArray(message.outputContexts))
                                    return "outputContexts: array expected";
                                for (var i = 0; i < message.outputContexts.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.Context.verify(message.outputContexts[i]);
                                    if (error)
                                        return "outputContexts." + error;
                                }
                            }
                            if (message.intent != null && message.hasOwnProperty("intent")) {
                                var error = $root.google.cloud.dialogflow.v2.Intent.verify(message.intent);
                                if (error)
                                    return "intent." + error;
                            }
                            if (message.intentDetectionConfidence != null && message.hasOwnProperty("intentDetectionConfidence"))
                                if (typeof message.intentDetectionConfidence !== "number")
                                    return "intentDetectionConfidence: number expected";
                            if (message.diagnosticInfo != null && message.hasOwnProperty("diagnosticInfo")) {
                                var error = $root.google.protobuf.Struct.verify(message.diagnosticInfo);
                                if (error)
                                    return "diagnosticInfo." + error;
                            }
                            if (message.sentimentAnalysisResult != null && message.hasOwnProperty("sentimentAnalysisResult")) {
                                var error = $root.google.cloud.dialogflow.v2.SentimentAnalysisResult.verify(message.sentimentAnalysisResult);
                                if (error)
                                    return "sentimentAnalysisResult." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a QueryResult message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.QueryResult
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.QueryResult} QueryResult
                         */
                        QueryResult.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.QueryResult)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.QueryResult();
                            if (object.queryText != null)
                                message.queryText = String(object.queryText);
                            if (object.languageCode != null)
                                message.languageCode = String(object.languageCode);
                            if (object.speechRecognitionConfidence != null)
                                message.speechRecognitionConfidence = Number(object.speechRecognitionConfidence);
                            if (object.action != null)
                                message.action = String(object.action);
                            if (object.parameters != null) {
                                if (typeof object.parameters !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.QueryResult.parameters: object expected");
                                message.parameters = $root.google.protobuf.Struct.fromObject(object.parameters);
                            }
                            if (object.allRequiredParamsPresent != null)
                                message.allRequiredParamsPresent = Boolean(object.allRequiredParamsPresent);
                            if (object.cancelsSlotFilling != null)
                                message.cancelsSlotFilling = Boolean(object.cancelsSlotFilling);
                            if (object.fulfillmentText != null)
                                message.fulfillmentText = String(object.fulfillmentText);
                            if (object.fulfillmentMessages) {
                                if (!Array.isArray(object.fulfillmentMessages))
                                    throw TypeError(".google.cloud.dialogflow.v2.QueryResult.fulfillmentMessages: array expected");
                                message.fulfillmentMessages = [];
                                for (var i = 0; i < object.fulfillmentMessages.length; ++i) {
                                    if (typeof object.fulfillmentMessages[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.QueryResult.fulfillmentMessages: object expected");
                                    message.fulfillmentMessages[i] = $root.google.cloud.dialogflow.v2.Intent.Message.fromObject(object.fulfillmentMessages[i]);
                                }
                            }
                            if (object.webhookSource != null)
                                message.webhookSource = String(object.webhookSource);
                            if (object.webhookPayload != null) {
                                if (typeof object.webhookPayload !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.QueryResult.webhookPayload: object expected");
                                message.webhookPayload = $root.google.protobuf.Struct.fromObject(object.webhookPayload);
                            }
                            if (object.outputContexts) {
                                if (!Array.isArray(object.outputContexts))
                                    throw TypeError(".google.cloud.dialogflow.v2.QueryResult.outputContexts: array expected");
                                message.outputContexts = [];
                                for (var i = 0; i < object.outputContexts.length; ++i) {
                                    if (typeof object.outputContexts[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.QueryResult.outputContexts: object expected");
                                    message.outputContexts[i] = $root.google.cloud.dialogflow.v2.Context.fromObject(object.outputContexts[i]);
                                }
                            }
                            if (object.intent != null) {
                                if (typeof object.intent !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.QueryResult.intent: object expected");
                                message.intent = $root.google.cloud.dialogflow.v2.Intent.fromObject(object.intent);
                            }
                            if (object.intentDetectionConfidence != null)
                                message.intentDetectionConfidence = Number(object.intentDetectionConfidence);
                            if (object.diagnosticInfo != null) {
                                if (typeof object.diagnosticInfo !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.QueryResult.diagnosticInfo: object expected");
                                message.diagnosticInfo = $root.google.protobuf.Struct.fromObject(object.diagnosticInfo);
                            }
                            if (object.sentimentAnalysisResult != null) {
                                if (typeof object.sentimentAnalysisResult !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.QueryResult.sentimentAnalysisResult: object expected");
                                message.sentimentAnalysisResult = $root.google.cloud.dialogflow.v2.SentimentAnalysisResult.fromObject(object.sentimentAnalysisResult);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a QueryResult message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.QueryResult
                         * @static
                         * @param {google.cloud.dialogflow.v2.QueryResult} message QueryResult
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        QueryResult.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults) {
                                object.fulfillmentMessages = [];
                                object.outputContexts = [];
                            }
                            if (options.defaults) {
                                object.queryText = "";
                                object.speechRecognitionConfidence = 0;
                                object.action = "";
                                object.parameters = null;
                                object.allRequiredParamsPresent = false;
                                object.fulfillmentText = "";
                                object.webhookSource = "";
                                object.webhookPayload = null;
                                object.intent = null;
                                object.intentDetectionConfidence = 0;
                                object.diagnosticInfo = null;
                                object.languageCode = "";
                                object.sentimentAnalysisResult = null;
                                object.cancelsSlotFilling = false;
                            }
                            if (message.queryText != null && message.hasOwnProperty("queryText"))
                                object.queryText = message.queryText;
                            if (message.speechRecognitionConfidence != null && message.hasOwnProperty("speechRecognitionConfidence"))
                                object.speechRecognitionConfidence = options.json && !isFinite(message.speechRecognitionConfidence) ? String(message.speechRecognitionConfidence) : message.speechRecognitionConfidence;
                            if (message.action != null && message.hasOwnProperty("action"))
                                object.action = message.action;
                            if (message.parameters != null && message.hasOwnProperty("parameters"))
                                object.parameters = $root.google.protobuf.Struct.toObject(message.parameters, options);
                            if (message.allRequiredParamsPresent != null && message.hasOwnProperty("allRequiredParamsPresent"))
                                object.allRequiredParamsPresent = message.allRequiredParamsPresent;
                            if (message.fulfillmentText != null && message.hasOwnProperty("fulfillmentText"))
                                object.fulfillmentText = message.fulfillmentText;
                            if (message.fulfillmentMessages && message.fulfillmentMessages.length) {
                                object.fulfillmentMessages = [];
                                for (var j = 0; j < message.fulfillmentMessages.length; ++j)
                                    object.fulfillmentMessages[j] = $root.google.cloud.dialogflow.v2.Intent.Message.toObject(message.fulfillmentMessages[j], options);
                            }
                            if (message.webhookSource != null && message.hasOwnProperty("webhookSource"))
                                object.webhookSource = message.webhookSource;
                            if (message.webhookPayload != null && message.hasOwnProperty("webhookPayload"))
                                object.webhookPayload = $root.google.protobuf.Struct.toObject(message.webhookPayload, options);
                            if (message.outputContexts && message.outputContexts.length) {
                                object.outputContexts = [];
                                for (var j = 0; j < message.outputContexts.length; ++j)
                                    object.outputContexts[j] = $root.google.cloud.dialogflow.v2.Context.toObject(message.outputContexts[j], options);
                            }
                            if (message.intent != null && message.hasOwnProperty("intent"))
                                object.intent = $root.google.cloud.dialogflow.v2.Intent.toObject(message.intent, options);
                            if (message.intentDetectionConfidence != null && message.hasOwnProperty("intentDetectionConfidence"))
                                object.intentDetectionConfidence = options.json && !isFinite(message.intentDetectionConfidence) ? String(message.intentDetectionConfidence) : message.intentDetectionConfidence;
                            if (message.diagnosticInfo != null && message.hasOwnProperty("diagnosticInfo"))
                                object.diagnosticInfo = $root.google.protobuf.Struct.toObject(message.diagnosticInfo, options);
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                object.languageCode = message.languageCode;
                            if (message.sentimentAnalysisResult != null && message.hasOwnProperty("sentimentAnalysisResult"))
                                object.sentimentAnalysisResult = $root.google.cloud.dialogflow.v2.SentimentAnalysisResult.toObject(message.sentimentAnalysisResult, options);
                            if (message.cancelsSlotFilling != null && message.hasOwnProperty("cancelsSlotFilling"))
                                object.cancelsSlotFilling = message.cancelsSlotFilling;
                            return object;
                        };
    
                        /**
                         * Converts this QueryResult to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.QueryResult
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        QueryResult.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for QueryResult
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.QueryResult
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        QueryResult.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.QueryResult";
                        };
    
                        return QueryResult;
                    })();
    
                    v2.StreamingDetectIntentRequest = (function() {
    
                        /**
                         * Properties of a StreamingDetectIntentRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IStreamingDetectIntentRequest
                         * @property {string|null} [session] StreamingDetectIntentRequest session
                         * @property {google.cloud.dialogflow.v2.IQueryParameters|null} [queryParams] StreamingDetectIntentRequest queryParams
                         * @property {google.cloud.dialogflow.v2.IQueryInput|null} [queryInput] StreamingDetectIntentRequest queryInput
                         * @property {boolean|null} [singleUtterance] StreamingDetectIntentRequest singleUtterance
                         * @property {google.cloud.dialogflow.v2.IOutputAudioConfig|null} [outputAudioConfig] StreamingDetectIntentRequest outputAudioConfig
                         * @property {google.protobuf.IFieldMask|null} [outputAudioConfigMask] StreamingDetectIntentRequest outputAudioConfigMask
                         * @property {Uint8Array|null} [inputAudio] StreamingDetectIntentRequest inputAudio
                         * @property {boolean|null} [enableDebuggingInfo] StreamingDetectIntentRequest enableDebuggingInfo
                         */
    
                        /**
                         * Constructs a new StreamingDetectIntentRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a StreamingDetectIntentRequest.
                         * @implements IStreamingDetectIntentRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IStreamingDetectIntentRequest=} [properties] Properties to set
                         */
                        function StreamingDetectIntentRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * StreamingDetectIntentRequest session.
                         * @member {string} session
                         * @memberof google.cloud.dialogflow.v2.StreamingDetectIntentRequest
                         * @instance
                         */
                        StreamingDetectIntentRequest.prototype.session = "";
    
                        /**
                         * StreamingDetectIntentRequest queryParams.
                         * @member {google.cloud.dialogflow.v2.IQueryParameters|null|undefined} queryParams
                         * @memberof google.cloud.dialogflow.v2.StreamingDetectIntentRequest
                         * @instance
                         */
                        StreamingDetectIntentRequest.prototype.queryParams = null;
    
                        /**
                         * StreamingDetectIntentRequest queryInput.
                         * @member {google.cloud.dialogflow.v2.IQueryInput|null|undefined} queryInput
                         * @memberof google.cloud.dialogflow.v2.StreamingDetectIntentRequest
                         * @instance
                         */
                        StreamingDetectIntentRequest.prototype.queryInput = null;
    
                        /**
                         * StreamingDetectIntentRequest singleUtterance.
                         * @member {boolean} singleUtterance
                         * @memberof google.cloud.dialogflow.v2.StreamingDetectIntentRequest
                         * @instance
                         */
                        StreamingDetectIntentRequest.prototype.singleUtterance = false;
    
                        /**
                         * StreamingDetectIntentRequest outputAudioConfig.
                         * @member {google.cloud.dialogflow.v2.IOutputAudioConfig|null|undefined} outputAudioConfig
                         * @memberof google.cloud.dialogflow.v2.StreamingDetectIntentRequest
                         * @instance
                         */
                        StreamingDetectIntentRequest.prototype.outputAudioConfig = null;
    
                        /**
                         * StreamingDetectIntentRequest outputAudioConfigMask.
                         * @member {google.protobuf.IFieldMask|null|undefined} outputAudioConfigMask
                         * @memberof google.cloud.dialogflow.v2.StreamingDetectIntentRequest
                         * @instance
                         */
                        StreamingDetectIntentRequest.prototype.outputAudioConfigMask = null;
    
                        /**
                         * StreamingDetectIntentRequest inputAudio.
                         * @member {Uint8Array} inputAudio
                         * @memberof google.cloud.dialogflow.v2.StreamingDetectIntentRequest
                         * @instance
                         */
                        StreamingDetectIntentRequest.prototype.inputAudio = $util.newBuffer([]);
    
                        /**
                         * StreamingDetectIntentRequest enableDebuggingInfo.
                         * @member {boolean} enableDebuggingInfo
                         * @memberof google.cloud.dialogflow.v2.StreamingDetectIntentRequest
                         * @instance
                         */
                        StreamingDetectIntentRequest.prototype.enableDebuggingInfo = false;
    
                        /**
                         * Creates a new StreamingDetectIntentRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.StreamingDetectIntentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IStreamingDetectIntentRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.StreamingDetectIntentRequest} StreamingDetectIntentRequest instance
                         */
                        StreamingDetectIntentRequest.create = function create(properties) {
                            return new StreamingDetectIntentRequest(properties);
                        };
    
                        /**
                         * Encodes the specified StreamingDetectIntentRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.StreamingDetectIntentRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.StreamingDetectIntentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IStreamingDetectIntentRequest} message StreamingDetectIntentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        StreamingDetectIntentRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.session != null && Object.hasOwnProperty.call(message, "session"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.session);
                            if (message.queryParams != null && Object.hasOwnProperty.call(message, "queryParams"))
                                $root.google.cloud.dialogflow.v2.QueryParameters.encode(message.queryParams, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.queryInput != null && Object.hasOwnProperty.call(message, "queryInput"))
                                $root.google.cloud.dialogflow.v2.QueryInput.encode(message.queryInput, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            if (message.singleUtterance != null && Object.hasOwnProperty.call(message, "singleUtterance"))
                                writer.uint32(/* id 4, wireType 0 =*/32).bool(message.singleUtterance);
                            if (message.outputAudioConfig != null && Object.hasOwnProperty.call(message, "outputAudioConfig"))
                                $root.google.cloud.dialogflow.v2.OutputAudioConfig.encode(message.outputAudioConfig, writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                            if (message.inputAudio != null && Object.hasOwnProperty.call(message, "inputAudio"))
                                writer.uint32(/* id 6, wireType 2 =*/50).bytes(message.inputAudio);
                            if (message.outputAudioConfigMask != null && Object.hasOwnProperty.call(message, "outputAudioConfigMask"))
                                $root.google.protobuf.FieldMask.encode(message.outputAudioConfigMask, writer.uint32(/* id 7, wireType 2 =*/58).fork()).ldelim();
                            if (message.enableDebuggingInfo != null && Object.hasOwnProperty.call(message, "enableDebuggingInfo"))
                                writer.uint32(/* id 8, wireType 0 =*/64).bool(message.enableDebuggingInfo);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified StreamingDetectIntentRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.StreamingDetectIntentRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.StreamingDetectIntentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IStreamingDetectIntentRequest} message StreamingDetectIntentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        StreamingDetectIntentRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a StreamingDetectIntentRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.StreamingDetectIntentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.StreamingDetectIntentRequest} StreamingDetectIntentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        StreamingDetectIntentRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.StreamingDetectIntentRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.session = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.queryParams = $root.google.cloud.dialogflow.v2.QueryParameters.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 3: {
                                        message.queryInput = $root.google.cloud.dialogflow.v2.QueryInput.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 4: {
                                        message.singleUtterance = reader.bool();
                                        break;
                                    }
                                case 5: {
                                        message.outputAudioConfig = $root.google.cloud.dialogflow.v2.OutputAudioConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 7: {
                                        message.outputAudioConfigMask = $root.google.protobuf.FieldMask.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 6: {
                                        message.inputAudio = reader.bytes();
                                        break;
                                    }
                                case 8: {
                                        message.enableDebuggingInfo = reader.bool();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a StreamingDetectIntentRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.StreamingDetectIntentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.StreamingDetectIntentRequest} StreamingDetectIntentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        StreamingDetectIntentRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a StreamingDetectIntentRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.StreamingDetectIntentRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        StreamingDetectIntentRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.session != null && message.hasOwnProperty("session"))
                                if (!$util.isString(message.session))
                                    return "session: string expected";
                            if (message.queryParams != null && message.hasOwnProperty("queryParams")) {
                                var error = $root.google.cloud.dialogflow.v2.QueryParameters.verify(message.queryParams);
                                if (error)
                                    return "queryParams." + error;
                            }
                            if (message.queryInput != null && message.hasOwnProperty("queryInput")) {
                                var error = $root.google.cloud.dialogflow.v2.QueryInput.verify(message.queryInput);
                                if (error)
                                    return "queryInput." + error;
                            }
                            if (message.singleUtterance != null && message.hasOwnProperty("singleUtterance"))
                                if (typeof message.singleUtterance !== "boolean")
                                    return "singleUtterance: boolean expected";
                            if (message.outputAudioConfig != null && message.hasOwnProperty("outputAudioConfig")) {
                                var error = $root.google.cloud.dialogflow.v2.OutputAudioConfig.verify(message.outputAudioConfig);
                                if (error)
                                    return "outputAudioConfig." + error;
                            }
                            if (message.outputAudioConfigMask != null && message.hasOwnProperty("outputAudioConfigMask")) {
                                var error = $root.google.protobuf.FieldMask.verify(message.outputAudioConfigMask);
                                if (error)
                                    return "outputAudioConfigMask." + error;
                            }
                            if (message.inputAudio != null && message.hasOwnProperty("inputAudio"))
                                if (!(message.inputAudio && typeof message.inputAudio.length === "number" || $util.isString(message.inputAudio)))
                                    return "inputAudio: buffer expected";
                            if (message.enableDebuggingInfo != null && message.hasOwnProperty("enableDebuggingInfo"))
                                if (typeof message.enableDebuggingInfo !== "boolean")
                                    return "enableDebuggingInfo: boolean expected";
                            return null;
                        };
    
                        /**
                         * Creates a StreamingDetectIntentRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.StreamingDetectIntentRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.StreamingDetectIntentRequest} StreamingDetectIntentRequest
                         */
                        StreamingDetectIntentRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.StreamingDetectIntentRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.StreamingDetectIntentRequest();
                            if (object.session != null)
                                message.session = String(object.session);
                            if (object.queryParams != null) {
                                if (typeof object.queryParams !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.StreamingDetectIntentRequest.queryParams: object expected");
                                message.queryParams = $root.google.cloud.dialogflow.v2.QueryParameters.fromObject(object.queryParams);
                            }
                            if (object.queryInput != null) {
                                if (typeof object.queryInput !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.StreamingDetectIntentRequest.queryInput: object expected");
                                message.queryInput = $root.google.cloud.dialogflow.v2.QueryInput.fromObject(object.queryInput);
                            }
                            if (object.singleUtterance != null)
                                message.singleUtterance = Boolean(object.singleUtterance);
                            if (object.outputAudioConfig != null) {
                                if (typeof object.outputAudioConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.StreamingDetectIntentRequest.outputAudioConfig: object expected");
                                message.outputAudioConfig = $root.google.cloud.dialogflow.v2.OutputAudioConfig.fromObject(object.outputAudioConfig);
                            }
                            if (object.outputAudioConfigMask != null) {
                                if (typeof object.outputAudioConfigMask !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.StreamingDetectIntentRequest.outputAudioConfigMask: object expected");
                                message.outputAudioConfigMask = $root.google.protobuf.FieldMask.fromObject(object.outputAudioConfigMask);
                            }
                            if (object.inputAudio != null)
                                if (typeof object.inputAudio === "string")
                                    $util.base64.decode(object.inputAudio, message.inputAudio = $util.newBuffer($util.base64.length(object.inputAudio)), 0);
                                else if (object.inputAudio.length >= 0)
                                    message.inputAudio = object.inputAudio;
                            if (object.enableDebuggingInfo != null)
                                message.enableDebuggingInfo = Boolean(object.enableDebuggingInfo);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a StreamingDetectIntentRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.StreamingDetectIntentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.StreamingDetectIntentRequest} message StreamingDetectIntentRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        StreamingDetectIntentRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.session = "";
                                object.queryParams = null;
                                object.queryInput = null;
                                object.singleUtterance = false;
                                object.outputAudioConfig = null;
                                if (options.bytes === String)
                                    object.inputAudio = "";
                                else {
                                    object.inputAudio = [];
                                    if (options.bytes !== Array)
                                        object.inputAudio = $util.newBuffer(object.inputAudio);
                                }
                                object.outputAudioConfigMask = null;
                                object.enableDebuggingInfo = false;
                            }
                            if (message.session != null && message.hasOwnProperty("session"))
                                object.session = message.session;
                            if (message.queryParams != null && message.hasOwnProperty("queryParams"))
                                object.queryParams = $root.google.cloud.dialogflow.v2.QueryParameters.toObject(message.queryParams, options);
                            if (message.queryInput != null && message.hasOwnProperty("queryInput"))
                                object.queryInput = $root.google.cloud.dialogflow.v2.QueryInput.toObject(message.queryInput, options);
                            if (message.singleUtterance != null && message.hasOwnProperty("singleUtterance"))
                                object.singleUtterance = message.singleUtterance;
                            if (message.outputAudioConfig != null && message.hasOwnProperty("outputAudioConfig"))
                                object.outputAudioConfig = $root.google.cloud.dialogflow.v2.OutputAudioConfig.toObject(message.outputAudioConfig, options);
                            if (message.inputAudio != null && message.hasOwnProperty("inputAudio"))
                                object.inputAudio = options.bytes === String ? $util.base64.encode(message.inputAudio, 0, message.inputAudio.length) : options.bytes === Array ? Array.prototype.slice.call(message.inputAudio) : message.inputAudio;
                            if (message.outputAudioConfigMask != null && message.hasOwnProperty("outputAudioConfigMask"))
                                object.outputAudioConfigMask = $root.google.protobuf.FieldMask.toObject(message.outputAudioConfigMask, options);
                            if (message.enableDebuggingInfo != null && message.hasOwnProperty("enableDebuggingInfo"))
                                object.enableDebuggingInfo = message.enableDebuggingInfo;
                            return object;
                        };
    
                        /**
                         * Converts this StreamingDetectIntentRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.StreamingDetectIntentRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        StreamingDetectIntentRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for StreamingDetectIntentRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.StreamingDetectIntentRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        StreamingDetectIntentRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.StreamingDetectIntentRequest";
                        };
    
                        return StreamingDetectIntentRequest;
                    })();
    
                    v2.CloudConversationDebuggingInfo = (function() {
    
                        /**
                         * Properties of a CloudConversationDebuggingInfo.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ICloudConversationDebuggingInfo
                         * @property {number|null} [audioDataChunks] CloudConversationDebuggingInfo audioDataChunks
                         * @property {google.protobuf.IDuration|null} [resultEndTimeOffset] CloudConversationDebuggingInfo resultEndTimeOffset
                         * @property {google.protobuf.IDuration|null} [firstAudioDuration] CloudConversationDebuggingInfo firstAudioDuration
                         * @property {boolean|null} [singleUtterance] CloudConversationDebuggingInfo singleUtterance
                         * @property {Array.<google.protobuf.IDuration>|null} [speechPartialResultsEndTimes] CloudConversationDebuggingInfo speechPartialResultsEndTimes
                         * @property {Array.<google.protobuf.IDuration>|null} [speechFinalResultsEndTimes] CloudConversationDebuggingInfo speechFinalResultsEndTimes
                         * @property {number|null} [partialResponses] CloudConversationDebuggingInfo partialResponses
                         * @property {number|null} [speakerIdPassiveLatencyMsOffset] CloudConversationDebuggingInfo speakerIdPassiveLatencyMsOffset
                         * @property {boolean|null} [bargeinEventTriggered] CloudConversationDebuggingInfo bargeinEventTriggered
                         * @property {boolean|null} [speechSingleUtterance] CloudConversationDebuggingInfo speechSingleUtterance
                         * @property {Array.<google.protobuf.IDuration>|null} [dtmfPartialResultsTimes] CloudConversationDebuggingInfo dtmfPartialResultsTimes
                         * @property {Array.<google.protobuf.IDuration>|null} [dtmfFinalResultsTimes] CloudConversationDebuggingInfo dtmfFinalResultsTimes
                         * @property {google.protobuf.IDuration|null} [singleUtteranceEndTimeOffset] CloudConversationDebuggingInfo singleUtteranceEndTimeOffset
                         * @property {google.protobuf.IDuration|null} [noSpeechTimeout] CloudConversationDebuggingInfo noSpeechTimeout
                         * @property {google.protobuf.IDuration|null} [endpointingTimeout] CloudConversationDebuggingInfo endpointingTimeout
                         * @property {boolean|null} [isInputText] CloudConversationDebuggingInfo isInputText
                         * @property {google.protobuf.IDuration|null} [clientHalfCloseTimeOffset] CloudConversationDebuggingInfo clientHalfCloseTimeOffset
                         * @property {google.protobuf.IDuration|null} [clientHalfCloseStreamingTimeOffset] CloudConversationDebuggingInfo clientHalfCloseStreamingTimeOffset
                         */
    
                        /**
                         * Constructs a new CloudConversationDebuggingInfo.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a CloudConversationDebuggingInfo.
                         * @implements ICloudConversationDebuggingInfo
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ICloudConversationDebuggingInfo=} [properties] Properties to set
                         */
                        function CloudConversationDebuggingInfo(properties) {
                            this.speechPartialResultsEndTimes = [];
                            this.speechFinalResultsEndTimes = [];
                            this.dtmfPartialResultsTimes = [];
                            this.dtmfFinalResultsTimes = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * CloudConversationDebuggingInfo audioDataChunks.
                         * @member {number} audioDataChunks
                         * @memberof google.cloud.dialogflow.v2.CloudConversationDebuggingInfo
                         * @instance
                         */
                        CloudConversationDebuggingInfo.prototype.audioDataChunks = 0;
    
                        /**
                         * CloudConversationDebuggingInfo resultEndTimeOffset.
                         * @member {google.protobuf.IDuration|null|undefined} resultEndTimeOffset
                         * @memberof google.cloud.dialogflow.v2.CloudConversationDebuggingInfo
                         * @instance
                         */
                        CloudConversationDebuggingInfo.prototype.resultEndTimeOffset = null;
    
                        /**
                         * CloudConversationDebuggingInfo firstAudioDuration.
                         * @member {google.protobuf.IDuration|null|undefined} firstAudioDuration
                         * @memberof google.cloud.dialogflow.v2.CloudConversationDebuggingInfo
                         * @instance
                         */
                        CloudConversationDebuggingInfo.prototype.firstAudioDuration = null;
    
                        /**
                         * CloudConversationDebuggingInfo singleUtterance.
                         * @member {boolean} singleUtterance
                         * @memberof google.cloud.dialogflow.v2.CloudConversationDebuggingInfo
                         * @instance
                         */
                        CloudConversationDebuggingInfo.prototype.singleUtterance = false;
    
                        /**
                         * CloudConversationDebuggingInfo speechPartialResultsEndTimes.
                         * @member {Array.<google.protobuf.IDuration>} speechPartialResultsEndTimes
                         * @memberof google.cloud.dialogflow.v2.CloudConversationDebuggingInfo
                         * @instance
                         */
                        CloudConversationDebuggingInfo.prototype.speechPartialResultsEndTimes = $util.emptyArray;
    
                        /**
                         * CloudConversationDebuggingInfo speechFinalResultsEndTimes.
                         * @member {Array.<google.protobuf.IDuration>} speechFinalResultsEndTimes
                         * @memberof google.cloud.dialogflow.v2.CloudConversationDebuggingInfo
                         * @instance
                         */
                        CloudConversationDebuggingInfo.prototype.speechFinalResultsEndTimes = $util.emptyArray;
    
                        /**
                         * CloudConversationDebuggingInfo partialResponses.
                         * @member {number} partialResponses
                         * @memberof google.cloud.dialogflow.v2.CloudConversationDebuggingInfo
                         * @instance
                         */
                        CloudConversationDebuggingInfo.prototype.partialResponses = 0;
    
                        /**
                         * CloudConversationDebuggingInfo speakerIdPassiveLatencyMsOffset.
                         * @member {number} speakerIdPassiveLatencyMsOffset
                         * @memberof google.cloud.dialogflow.v2.CloudConversationDebuggingInfo
                         * @instance
                         */
                        CloudConversationDebuggingInfo.prototype.speakerIdPassiveLatencyMsOffset = 0;
    
                        /**
                         * CloudConversationDebuggingInfo bargeinEventTriggered.
                         * @member {boolean} bargeinEventTriggered
                         * @memberof google.cloud.dialogflow.v2.CloudConversationDebuggingInfo
                         * @instance
                         */
                        CloudConversationDebuggingInfo.prototype.bargeinEventTriggered = false;
    
                        /**
                         * CloudConversationDebuggingInfo speechSingleUtterance.
                         * @member {boolean} speechSingleUtterance
                         * @memberof google.cloud.dialogflow.v2.CloudConversationDebuggingInfo
                         * @instance
                         */
                        CloudConversationDebuggingInfo.prototype.speechSingleUtterance = false;
    
                        /**
                         * CloudConversationDebuggingInfo dtmfPartialResultsTimes.
                         * @member {Array.<google.protobuf.IDuration>} dtmfPartialResultsTimes
                         * @memberof google.cloud.dialogflow.v2.CloudConversationDebuggingInfo
                         * @instance
                         */
                        CloudConversationDebuggingInfo.prototype.dtmfPartialResultsTimes = $util.emptyArray;
    
                        /**
                         * CloudConversationDebuggingInfo dtmfFinalResultsTimes.
                         * @member {Array.<google.protobuf.IDuration>} dtmfFinalResultsTimes
                         * @memberof google.cloud.dialogflow.v2.CloudConversationDebuggingInfo
                         * @instance
                         */
                        CloudConversationDebuggingInfo.prototype.dtmfFinalResultsTimes = $util.emptyArray;
    
                        /**
                         * CloudConversationDebuggingInfo singleUtteranceEndTimeOffset.
                         * @member {google.protobuf.IDuration|null|undefined} singleUtteranceEndTimeOffset
                         * @memberof google.cloud.dialogflow.v2.CloudConversationDebuggingInfo
                         * @instance
                         */
                        CloudConversationDebuggingInfo.prototype.singleUtteranceEndTimeOffset = null;
    
                        /**
                         * CloudConversationDebuggingInfo noSpeechTimeout.
                         * @member {google.protobuf.IDuration|null|undefined} noSpeechTimeout
                         * @memberof google.cloud.dialogflow.v2.CloudConversationDebuggingInfo
                         * @instance
                         */
                        CloudConversationDebuggingInfo.prototype.noSpeechTimeout = null;
    
                        /**
                         * CloudConversationDebuggingInfo endpointingTimeout.
                         * @member {google.protobuf.IDuration|null|undefined} endpointingTimeout
                         * @memberof google.cloud.dialogflow.v2.CloudConversationDebuggingInfo
                         * @instance
                         */
                        CloudConversationDebuggingInfo.prototype.endpointingTimeout = null;
    
                        /**
                         * CloudConversationDebuggingInfo isInputText.
                         * @member {boolean} isInputText
                         * @memberof google.cloud.dialogflow.v2.CloudConversationDebuggingInfo
                         * @instance
                         */
                        CloudConversationDebuggingInfo.prototype.isInputText = false;
    
                        /**
                         * CloudConversationDebuggingInfo clientHalfCloseTimeOffset.
                         * @member {google.protobuf.IDuration|null|undefined} clientHalfCloseTimeOffset
                         * @memberof google.cloud.dialogflow.v2.CloudConversationDebuggingInfo
                         * @instance
                         */
                        CloudConversationDebuggingInfo.prototype.clientHalfCloseTimeOffset = null;
    
                        /**
                         * CloudConversationDebuggingInfo clientHalfCloseStreamingTimeOffset.
                         * @member {google.protobuf.IDuration|null|undefined} clientHalfCloseStreamingTimeOffset
                         * @memberof google.cloud.dialogflow.v2.CloudConversationDebuggingInfo
                         * @instance
                         */
                        CloudConversationDebuggingInfo.prototype.clientHalfCloseStreamingTimeOffset = null;
    
                        /**
                         * Creates a new CloudConversationDebuggingInfo instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.CloudConversationDebuggingInfo
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICloudConversationDebuggingInfo=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.CloudConversationDebuggingInfo} CloudConversationDebuggingInfo instance
                         */
                        CloudConversationDebuggingInfo.create = function create(properties) {
                            return new CloudConversationDebuggingInfo(properties);
                        };
    
                        /**
                         * Encodes the specified CloudConversationDebuggingInfo message. Does not implicitly {@link google.cloud.dialogflow.v2.CloudConversationDebuggingInfo.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.CloudConversationDebuggingInfo
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICloudConversationDebuggingInfo} message CloudConversationDebuggingInfo message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CloudConversationDebuggingInfo.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.audioDataChunks != null && Object.hasOwnProperty.call(message, "audioDataChunks"))
                                writer.uint32(/* id 1, wireType 0 =*/8).int32(message.audioDataChunks);
                            if (message.resultEndTimeOffset != null && Object.hasOwnProperty.call(message, "resultEndTimeOffset"))
                                $root.google.protobuf.Duration.encode(message.resultEndTimeOffset, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.firstAudioDuration != null && Object.hasOwnProperty.call(message, "firstAudioDuration"))
                                $root.google.protobuf.Duration.encode(message.firstAudioDuration, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            if (message.singleUtterance != null && Object.hasOwnProperty.call(message, "singleUtterance"))
                                writer.uint32(/* id 5, wireType 0 =*/40).bool(message.singleUtterance);
                            if (message.speechPartialResultsEndTimes != null && message.speechPartialResultsEndTimes.length)
                                for (var i = 0; i < message.speechPartialResultsEndTimes.length; ++i)
                                    $root.google.protobuf.Duration.encode(message.speechPartialResultsEndTimes[i], writer.uint32(/* id 6, wireType 2 =*/50).fork()).ldelim();
                            if (message.speechFinalResultsEndTimes != null && message.speechFinalResultsEndTimes.length)
                                for (var i = 0; i < message.speechFinalResultsEndTimes.length; ++i)
                                    $root.google.protobuf.Duration.encode(message.speechFinalResultsEndTimes[i], writer.uint32(/* id 7, wireType 2 =*/58).fork()).ldelim();
                            if (message.partialResponses != null && Object.hasOwnProperty.call(message, "partialResponses"))
                                writer.uint32(/* id 8, wireType 0 =*/64).int32(message.partialResponses);
                            if (message.speakerIdPassiveLatencyMsOffset != null && Object.hasOwnProperty.call(message, "speakerIdPassiveLatencyMsOffset"))
                                writer.uint32(/* id 9, wireType 0 =*/72).int32(message.speakerIdPassiveLatencyMsOffset);
                            if (message.bargeinEventTriggered != null && Object.hasOwnProperty.call(message, "bargeinEventTriggered"))
                                writer.uint32(/* id 10, wireType 0 =*/80).bool(message.bargeinEventTriggered);
                            if (message.speechSingleUtterance != null && Object.hasOwnProperty.call(message, "speechSingleUtterance"))
                                writer.uint32(/* id 11, wireType 0 =*/88).bool(message.speechSingleUtterance);
                            if (message.dtmfPartialResultsTimes != null && message.dtmfPartialResultsTimes.length)
                                for (var i = 0; i < message.dtmfPartialResultsTimes.length; ++i)
                                    $root.google.protobuf.Duration.encode(message.dtmfPartialResultsTimes[i], writer.uint32(/* id 12, wireType 2 =*/98).fork()).ldelim();
                            if (message.dtmfFinalResultsTimes != null && message.dtmfFinalResultsTimes.length)
                                for (var i = 0; i < message.dtmfFinalResultsTimes.length; ++i)
                                    $root.google.protobuf.Duration.encode(message.dtmfFinalResultsTimes[i], writer.uint32(/* id 13, wireType 2 =*/106).fork()).ldelim();
                            if (message.singleUtteranceEndTimeOffset != null && Object.hasOwnProperty.call(message, "singleUtteranceEndTimeOffset"))
                                $root.google.protobuf.Duration.encode(message.singleUtteranceEndTimeOffset, writer.uint32(/* id 14, wireType 2 =*/114).fork()).ldelim();
                            if (message.noSpeechTimeout != null && Object.hasOwnProperty.call(message, "noSpeechTimeout"))
                                $root.google.protobuf.Duration.encode(message.noSpeechTimeout, writer.uint32(/* id 15, wireType 2 =*/122).fork()).ldelim();
                            if (message.isInputText != null && Object.hasOwnProperty.call(message, "isInputText"))
                                writer.uint32(/* id 16, wireType 0 =*/128).bool(message.isInputText);
                            if (message.clientHalfCloseTimeOffset != null && Object.hasOwnProperty.call(message, "clientHalfCloseTimeOffset"))
                                $root.google.protobuf.Duration.encode(message.clientHalfCloseTimeOffset, writer.uint32(/* id 17, wireType 2 =*/138).fork()).ldelim();
                            if (message.clientHalfCloseStreamingTimeOffset != null && Object.hasOwnProperty.call(message, "clientHalfCloseStreamingTimeOffset"))
                                $root.google.protobuf.Duration.encode(message.clientHalfCloseStreamingTimeOffset, writer.uint32(/* id 18, wireType 2 =*/146).fork()).ldelim();
                            if (message.endpointingTimeout != null && Object.hasOwnProperty.call(message, "endpointingTimeout"))
                                $root.google.protobuf.Duration.encode(message.endpointingTimeout, writer.uint32(/* id 19, wireType 2 =*/154).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified CloudConversationDebuggingInfo message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.CloudConversationDebuggingInfo.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.CloudConversationDebuggingInfo
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICloudConversationDebuggingInfo} message CloudConversationDebuggingInfo message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CloudConversationDebuggingInfo.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a CloudConversationDebuggingInfo message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.CloudConversationDebuggingInfo
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.CloudConversationDebuggingInfo} CloudConversationDebuggingInfo
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CloudConversationDebuggingInfo.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.CloudConversationDebuggingInfo();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.audioDataChunks = reader.int32();
                                        break;
                                    }
                                case 2: {
                                        message.resultEndTimeOffset = $root.google.protobuf.Duration.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 3: {
                                        message.firstAudioDuration = $root.google.protobuf.Duration.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 5: {
                                        message.singleUtterance = reader.bool();
                                        break;
                                    }
                                case 6: {
                                        if (!(message.speechPartialResultsEndTimes && message.speechPartialResultsEndTimes.length))
                                            message.speechPartialResultsEndTimes = [];
                                        message.speechPartialResultsEndTimes.push($root.google.protobuf.Duration.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 7: {
                                        if (!(message.speechFinalResultsEndTimes && message.speechFinalResultsEndTimes.length))
                                            message.speechFinalResultsEndTimes = [];
                                        message.speechFinalResultsEndTimes.push($root.google.protobuf.Duration.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 8: {
                                        message.partialResponses = reader.int32();
                                        break;
                                    }
                                case 9: {
                                        message.speakerIdPassiveLatencyMsOffset = reader.int32();
                                        break;
                                    }
                                case 10: {
                                        message.bargeinEventTriggered = reader.bool();
                                        break;
                                    }
                                case 11: {
                                        message.speechSingleUtterance = reader.bool();
                                        break;
                                    }
                                case 12: {
                                        if (!(message.dtmfPartialResultsTimes && message.dtmfPartialResultsTimes.length))
                                            message.dtmfPartialResultsTimes = [];
                                        message.dtmfPartialResultsTimes.push($root.google.protobuf.Duration.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 13: {
                                        if (!(message.dtmfFinalResultsTimes && message.dtmfFinalResultsTimes.length))
                                            message.dtmfFinalResultsTimes = [];
                                        message.dtmfFinalResultsTimes.push($root.google.protobuf.Duration.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 14: {
                                        message.singleUtteranceEndTimeOffset = $root.google.protobuf.Duration.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 15: {
                                        message.noSpeechTimeout = $root.google.protobuf.Duration.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 19: {
                                        message.endpointingTimeout = $root.google.protobuf.Duration.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 16: {
                                        message.isInputText = reader.bool();
                                        break;
                                    }
                                case 17: {
                                        message.clientHalfCloseTimeOffset = $root.google.protobuf.Duration.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 18: {
                                        message.clientHalfCloseStreamingTimeOffset = $root.google.protobuf.Duration.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a CloudConversationDebuggingInfo message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.CloudConversationDebuggingInfo
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.CloudConversationDebuggingInfo} CloudConversationDebuggingInfo
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CloudConversationDebuggingInfo.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a CloudConversationDebuggingInfo message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.CloudConversationDebuggingInfo
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        CloudConversationDebuggingInfo.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.audioDataChunks != null && message.hasOwnProperty("audioDataChunks"))
                                if (!$util.isInteger(message.audioDataChunks))
                                    return "audioDataChunks: integer expected";
                            if (message.resultEndTimeOffset != null && message.hasOwnProperty("resultEndTimeOffset")) {
                                var error = $root.google.protobuf.Duration.verify(message.resultEndTimeOffset);
                                if (error)
                                    return "resultEndTimeOffset." + error;
                            }
                            if (message.firstAudioDuration != null && message.hasOwnProperty("firstAudioDuration")) {
                                var error = $root.google.protobuf.Duration.verify(message.firstAudioDuration);
                                if (error)
                                    return "firstAudioDuration." + error;
                            }
                            if (message.singleUtterance != null && message.hasOwnProperty("singleUtterance"))
                                if (typeof message.singleUtterance !== "boolean")
                                    return "singleUtterance: boolean expected";
                            if (message.speechPartialResultsEndTimes != null && message.hasOwnProperty("speechPartialResultsEndTimes")) {
                                if (!Array.isArray(message.speechPartialResultsEndTimes))
                                    return "speechPartialResultsEndTimes: array expected";
                                for (var i = 0; i < message.speechPartialResultsEndTimes.length; ++i) {
                                    var error = $root.google.protobuf.Duration.verify(message.speechPartialResultsEndTimes[i]);
                                    if (error)
                                        return "speechPartialResultsEndTimes." + error;
                                }
                            }
                            if (message.speechFinalResultsEndTimes != null && message.hasOwnProperty("speechFinalResultsEndTimes")) {
                                if (!Array.isArray(message.speechFinalResultsEndTimes))
                                    return "speechFinalResultsEndTimes: array expected";
                                for (var i = 0; i < message.speechFinalResultsEndTimes.length; ++i) {
                                    var error = $root.google.protobuf.Duration.verify(message.speechFinalResultsEndTimes[i]);
                                    if (error)
                                        return "speechFinalResultsEndTimes." + error;
                                }
                            }
                            if (message.partialResponses != null && message.hasOwnProperty("partialResponses"))
                                if (!$util.isInteger(message.partialResponses))
                                    return "partialResponses: integer expected";
                            if (message.speakerIdPassiveLatencyMsOffset != null && message.hasOwnProperty("speakerIdPassiveLatencyMsOffset"))
                                if (!$util.isInteger(message.speakerIdPassiveLatencyMsOffset))
                                    return "speakerIdPassiveLatencyMsOffset: integer expected";
                            if (message.bargeinEventTriggered != null && message.hasOwnProperty("bargeinEventTriggered"))
                                if (typeof message.bargeinEventTriggered !== "boolean")
                                    return "bargeinEventTriggered: boolean expected";
                            if (message.speechSingleUtterance != null && message.hasOwnProperty("speechSingleUtterance"))
                                if (typeof message.speechSingleUtterance !== "boolean")
                                    return "speechSingleUtterance: boolean expected";
                            if (message.dtmfPartialResultsTimes != null && message.hasOwnProperty("dtmfPartialResultsTimes")) {
                                if (!Array.isArray(message.dtmfPartialResultsTimes))
                                    return "dtmfPartialResultsTimes: array expected";
                                for (var i = 0; i < message.dtmfPartialResultsTimes.length; ++i) {
                                    var error = $root.google.protobuf.Duration.verify(message.dtmfPartialResultsTimes[i]);
                                    if (error)
                                        return "dtmfPartialResultsTimes." + error;
                                }
                            }
                            if (message.dtmfFinalResultsTimes != null && message.hasOwnProperty("dtmfFinalResultsTimes")) {
                                if (!Array.isArray(message.dtmfFinalResultsTimes))
                                    return "dtmfFinalResultsTimes: array expected";
                                for (var i = 0; i < message.dtmfFinalResultsTimes.length; ++i) {
                                    var error = $root.google.protobuf.Duration.verify(message.dtmfFinalResultsTimes[i]);
                                    if (error)
                                        return "dtmfFinalResultsTimes." + error;
                                }
                            }
                            if (message.singleUtteranceEndTimeOffset != null && message.hasOwnProperty("singleUtteranceEndTimeOffset")) {
                                var error = $root.google.protobuf.Duration.verify(message.singleUtteranceEndTimeOffset);
                                if (error)
                                    return "singleUtteranceEndTimeOffset." + error;
                            }
                            if (message.noSpeechTimeout != null && message.hasOwnProperty("noSpeechTimeout")) {
                                var error = $root.google.protobuf.Duration.verify(message.noSpeechTimeout);
                                if (error)
                                    return "noSpeechTimeout." + error;
                            }
                            if (message.endpointingTimeout != null && message.hasOwnProperty("endpointingTimeout")) {
                                var error = $root.google.protobuf.Duration.verify(message.endpointingTimeout);
                                if (error)
                                    return "endpointingTimeout." + error;
                            }
                            if (message.isInputText != null && message.hasOwnProperty("isInputText"))
                                if (typeof message.isInputText !== "boolean")
                                    return "isInputText: boolean expected";
                            if (message.clientHalfCloseTimeOffset != null && message.hasOwnProperty("clientHalfCloseTimeOffset")) {
                                var error = $root.google.protobuf.Duration.verify(message.clientHalfCloseTimeOffset);
                                if (error)
                                    return "clientHalfCloseTimeOffset." + error;
                            }
                            if (message.clientHalfCloseStreamingTimeOffset != null && message.hasOwnProperty("clientHalfCloseStreamingTimeOffset")) {
                                var error = $root.google.protobuf.Duration.verify(message.clientHalfCloseStreamingTimeOffset);
                                if (error)
                                    return "clientHalfCloseStreamingTimeOffset." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a CloudConversationDebuggingInfo message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.CloudConversationDebuggingInfo
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.CloudConversationDebuggingInfo} CloudConversationDebuggingInfo
                         */
                        CloudConversationDebuggingInfo.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.CloudConversationDebuggingInfo)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.CloudConversationDebuggingInfo();
                            if (object.audioDataChunks != null)
                                message.audioDataChunks = object.audioDataChunks | 0;
                            if (object.resultEndTimeOffset != null) {
                                if (typeof object.resultEndTimeOffset !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.CloudConversationDebuggingInfo.resultEndTimeOffset: object expected");
                                message.resultEndTimeOffset = $root.google.protobuf.Duration.fromObject(object.resultEndTimeOffset);
                            }
                            if (object.firstAudioDuration != null) {
                                if (typeof object.firstAudioDuration !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.CloudConversationDebuggingInfo.firstAudioDuration: object expected");
                                message.firstAudioDuration = $root.google.protobuf.Duration.fromObject(object.firstAudioDuration);
                            }
                            if (object.singleUtterance != null)
                                message.singleUtterance = Boolean(object.singleUtterance);
                            if (object.speechPartialResultsEndTimes) {
                                if (!Array.isArray(object.speechPartialResultsEndTimes))
                                    throw TypeError(".google.cloud.dialogflow.v2.CloudConversationDebuggingInfo.speechPartialResultsEndTimes: array expected");
                                message.speechPartialResultsEndTimes = [];
                                for (var i = 0; i < object.speechPartialResultsEndTimes.length; ++i) {
                                    if (typeof object.speechPartialResultsEndTimes[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.CloudConversationDebuggingInfo.speechPartialResultsEndTimes: object expected");
                                    message.speechPartialResultsEndTimes[i] = $root.google.protobuf.Duration.fromObject(object.speechPartialResultsEndTimes[i]);
                                }
                            }
                            if (object.speechFinalResultsEndTimes) {
                                if (!Array.isArray(object.speechFinalResultsEndTimes))
                                    throw TypeError(".google.cloud.dialogflow.v2.CloudConversationDebuggingInfo.speechFinalResultsEndTimes: array expected");
                                message.speechFinalResultsEndTimes = [];
                                for (var i = 0; i < object.speechFinalResultsEndTimes.length; ++i) {
                                    if (typeof object.speechFinalResultsEndTimes[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.CloudConversationDebuggingInfo.speechFinalResultsEndTimes: object expected");
                                    message.speechFinalResultsEndTimes[i] = $root.google.protobuf.Duration.fromObject(object.speechFinalResultsEndTimes[i]);
                                }
                            }
                            if (object.partialResponses != null)
                                message.partialResponses = object.partialResponses | 0;
                            if (object.speakerIdPassiveLatencyMsOffset != null)
                                message.speakerIdPassiveLatencyMsOffset = object.speakerIdPassiveLatencyMsOffset | 0;
                            if (object.bargeinEventTriggered != null)
                                message.bargeinEventTriggered = Boolean(object.bargeinEventTriggered);
                            if (object.speechSingleUtterance != null)
                                message.speechSingleUtterance = Boolean(object.speechSingleUtterance);
                            if (object.dtmfPartialResultsTimes) {
                                if (!Array.isArray(object.dtmfPartialResultsTimes))
                                    throw TypeError(".google.cloud.dialogflow.v2.CloudConversationDebuggingInfo.dtmfPartialResultsTimes: array expected");
                                message.dtmfPartialResultsTimes = [];
                                for (var i = 0; i < object.dtmfPartialResultsTimes.length; ++i) {
                                    if (typeof object.dtmfPartialResultsTimes[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.CloudConversationDebuggingInfo.dtmfPartialResultsTimes: object expected");
                                    message.dtmfPartialResultsTimes[i] = $root.google.protobuf.Duration.fromObject(object.dtmfPartialResultsTimes[i]);
                                }
                            }
                            if (object.dtmfFinalResultsTimes) {
                                if (!Array.isArray(object.dtmfFinalResultsTimes))
                                    throw TypeError(".google.cloud.dialogflow.v2.CloudConversationDebuggingInfo.dtmfFinalResultsTimes: array expected");
                                message.dtmfFinalResultsTimes = [];
                                for (var i = 0; i < object.dtmfFinalResultsTimes.length; ++i) {
                                    if (typeof object.dtmfFinalResultsTimes[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.CloudConversationDebuggingInfo.dtmfFinalResultsTimes: object expected");
                                    message.dtmfFinalResultsTimes[i] = $root.google.protobuf.Duration.fromObject(object.dtmfFinalResultsTimes[i]);
                                }
                            }
                            if (object.singleUtteranceEndTimeOffset != null) {
                                if (typeof object.singleUtteranceEndTimeOffset !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.CloudConversationDebuggingInfo.singleUtteranceEndTimeOffset: object expected");
                                message.singleUtteranceEndTimeOffset = $root.google.protobuf.Duration.fromObject(object.singleUtteranceEndTimeOffset);
                            }
                            if (object.noSpeechTimeout != null) {
                                if (typeof object.noSpeechTimeout !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.CloudConversationDebuggingInfo.noSpeechTimeout: object expected");
                                message.noSpeechTimeout = $root.google.protobuf.Duration.fromObject(object.noSpeechTimeout);
                            }
                            if (object.endpointingTimeout != null) {
                                if (typeof object.endpointingTimeout !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.CloudConversationDebuggingInfo.endpointingTimeout: object expected");
                                message.endpointingTimeout = $root.google.protobuf.Duration.fromObject(object.endpointingTimeout);
                            }
                            if (object.isInputText != null)
                                message.isInputText = Boolean(object.isInputText);
                            if (object.clientHalfCloseTimeOffset != null) {
                                if (typeof object.clientHalfCloseTimeOffset !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.CloudConversationDebuggingInfo.clientHalfCloseTimeOffset: object expected");
                                message.clientHalfCloseTimeOffset = $root.google.protobuf.Duration.fromObject(object.clientHalfCloseTimeOffset);
                            }
                            if (object.clientHalfCloseStreamingTimeOffset != null) {
                                if (typeof object.clientHalfCloseStreamingTimeOffset !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.CloudConversationDebuggingInfo.clientHalfCloseStreamingTimeOffset: object expected");
                                message.clientHalfCloseStreamingTimeOffset = $root.google.protobuf.Duration.fromObject(object.clientHalfCloseStreamingTimeOffset);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a CloudConversationDebuggingInfo message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.CloudConversationDebuggingInfo
                         * @static
                         * @param {google.cloud.dialogflow.v2.CloudConversationDebuggingInfo} message CloudConversationDebuggingInfo
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        CloudConversationDebuggingInfo.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults) {
                                object.speechPartialResultsEndTimes = [];
                                object.speechFinalResultsEndTimes = [];
                                object.dtmfPartialResultsTimes = [];
                                object.dtmfFinalResultsTimes = [];
                            }
                            if (options.defaults) {
                                object.audioDataChunks = 0;
                                object.resultEndTimeOffset = null;
                                object.firstAudioDuration = null;
                                object.singleUtterance = false;
                                object.partialResponses = 0;
                                object.speakerIdPassiveLatencyMsOffset = 0;
                                object.bargeinEventTriggered = false;
                                object.speechSingleUtterance = false;
                                object.singleUtteranceEndTimeOffset = null;
                                object.noSpeechTimeout = null;
                                object.isInputText = false;
                                object.clientHalfCloseTimeOffset = null;
                                object.clientHalfCloseStreamingTimeOffset = null;
                                object.endpointingTimeout = null;
                            }
                            if (message.audioDataChunks != null && message.hasOwnProperty("audioDataChunks"))
                                object.audioDataChunks = message.audioDataChunks;
                            if (message.resultEndTimeOffset != null && message.hasOwnProperty("resultEndTimeOffset"))
                                object.resultEndTimeOffset = $root.google.protobuf.Duration.toObject(message.resultEndTimeOffset, options);
                            if (message.firstAudioDuration != null && message.hasOwnProperty("firstAudioDuration"))
                                object.firstAudioDuration = $root.google.protobuf.Duration.toObject(message.firstAudioDuration, options);
                            if (message.singleUtterance != null && message.hasOwnProperty("singleUtterance"))
                                object.singleUtterance = message.singleUtterance;
                            if (message.speechPartialResultsEndTimes && message.speechPartialResultsEndTimes.length) {
                                object.speechPartialResultsEndTimes = [];
                                for (var j = 0; j < message.speechPartialResultsEndTimes.length; ++j)
                                    object.speechPartialResultsEndTimes[j] = $root.google.protobuf.Duration.toObject(message.speechPartialResultsEndTimes[j], options);
                            }
                            if (message.speechFinalResultsEndTimes && message.speechFinalResultsEndTimes.length) {
                                object.speechFinalResultsEndTimes = [];
                                for (var j = 0; j < message.speechFinalResultsEndTimes.length; ++j)
                                    object.speechFinalResultsEndTimes[j] = $root.google.protobuf.Duration.toObject(message.speechFinalResultsEndTimes[j], options);
                            }
                            if (message.partialResponses != null && message.hasOwnProperty("partialResponses"))
                                object.partialResponses = message.partialResponses;
                            if (message.speakerIdPassiveLatencyMsOffset != null && message.hasOwnProperty("speakerIdPassiveLatencyMsOffset"))
                                object.speakerIdPassiveLatencyMsOffset = message.speakerIdPassiveLatencyMsOffset;
                            if (message.bargeinEventTriggered != null && message.hasOwnProperty("bargeinEventTriggered"))
                                object.bargeinEventTriggered = message.bargeinEventTriggered;
                            if (message.speechSingleUtterance != null && message.hasOwnProperty("speechSingleUtterance"))
                                object.speechSingleUtterance = message.speechSingleUtterance;
                            if (message.dtmfPartialResultsTimes && message.dtmfPartialResultsTimes.length) {
                                object.dtmfPartialResultsTimes = [];
                                for (var j = 0; j < message.dtmfPartialResultsTimes.length; ++j)
                                    object.dtmfPartialResultsTimes[j] = $root.google.protobuf.Duration.toObject(message.dtmfPartialResultsTimes[j], options);
                            }
                            if (message.dtmfFinalResultsTimes && message.dtmfFinalResultsTimes.length) {
                                object.dtmfFinalResultsTimes = [];
                                for (var j = 0; j < message.dtmfFinalResultsTimes.length; ++j)
                                    object.dtmfFinalResultsTimes[j] = $root.google.protobuf.Duration.toObject(message.dtmfFinalResultsTimes[j], options);
                            }
                            if (message.singleUtteranceEndTimeOffset != null && message.hasOwnProperty("singleUtteranceEndTimeOffset"))
                                object.singleUtteranceEndTimeOffset = $root.google.protobuf.Duration.toObject(message.singleUtteranceEndTimeOffset, options);
                            if (message.noSpeechTimeout != null && message.hasOwnProperty("noSpeechTimeout"))
                                object.noSpeechTimeout = $root.google.protobuf.Duration.toObject(message.noSpeechTimeout, options);
                            if (message.isInputText != null && message.hasOwnProperty("isInputText"))
                                object.isInputText = message.isInputText;
                            if (message.clientHalfCloseTimeOffset != null && message.hasOwnProperty("clientHalfCloseTimeOffset"))
                                object.clientHalfCloseTimeOffset = $root.google.protobuf.Duration.toObject(message.clientHalfCloseTimeOffset, options);
                            if (message.clientHalfCloseStreamingTimeOffset != null && message.hasOwnProperty("clientHalfCloseStreamingTimeOffset"))
                                object.clientHalfCloseStreamingTimeOffset = $root.google.protobuf.Duration.toObject(message.clientHalfCloseStreamingTimeOffset, options);
                            if (message.endpointingTimeout != null && message.hasOwnProperty("endpointingTimeout"))
                                object.endpointingTimeout = $root.google.protobuf.Duration.toObject(message.endpointingTimeout, options);
                            return object;
                        };
    
                        /**
                         * Converts this CloudConversationDebuggingInfo to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.CloudConversationDebuggingInfo
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        CloudConversationDebuggingInfo.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for CloudConversationDebuggingInfo
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.CloudConversationDebuggingInfo
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        CloudConversationDebuggingInfo.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.CloudConversationDebuggingInfo";
                        };
    
                        return CloudConversationDebuggingInfo;
                    })();
    
                    v2.StreamingDetectIntentResponse = (function() {
    
                        /**
                         * Properties of a StreamingDetectIntentResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IStreamingDetectIntentResponse
                         * @property {string|null} [responseId] StreamingDetectIntentResponse responseId
                         * @property {google.cloud.dialogflow.v2.IStreamingRecognitionResult|null} [recognitionResult] StreamingDetectIntentResponse recognitionResult
                         * @property {google.cloud.dialogflow.v2.IQueryResult|null} [queryResult] StreamingDetectIntentResponse queryResult
                         * @property {google.rpc.IStatus|null} [webhookStatus] StreamingDetectIntentResponse webhookStatus
                         * @property {Uint8Array|null} [outputAudio] StreamingDetectIntentResponse outputAudio
                         * @property {google.cloud.dialogflow.v2.IOutputAudioConfig|null} [outputAudioConfig] StreamingDetectIntentResponse outputAudioConfig
                         * @property {google.cloud.dialogflow.v2.ICloudConversationDebuggingInfo|null} [debuggingInfo] StreamingDetectIntentResponse debuggingInfo
                         */
    
                        /**
                         * Constructs a new StreamingDetectIntentResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a StreamingDetectIntentResponse.
                         * @implements IStreamingDetectIntentResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IStreamingDetectIntentResponse=} [properties] Properties to set
                         */
                        function StreamingDetectIntentResponse(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * StreamingDetectIntentResponse responseId.
                         * @member {string} responseId
                         * @memberof google.cloud.dialogflow.v2.StreamingDetectIntentResponse
                         * @instance
                         */
                        StreamingDetectIntentResponse.prototype.responseId = "";
    
                        /**
                         * StreamingDetectIntentResponse recognitionResult.
                         * @member {google.cloud.dialogflow.v2.IStreamingRecognitionResult|null|undefined} recognitionResult
                         * @memberof google.cloud.dialogflow.v2.StreamingDetectIntentResponse
                         * @instance
                         */
                        StreamingDetectIntentResponse.prototype.recognitionResult = null;
    
                        /**
                         * StreamingDetectIntentResponse queryResult.
                         * @member {google.cloud.dialogflow.v2.IQueryResult|null|undefined} queryResult
                         * @memberof google.cloud.dialogflow.v2.StreamingDetectIntentResponse
                         * @instance
                         */
                        StreamingDetectIntentResponse.prototype.queryResult = null;
    
                        /**
                         * StreamingDetectIntentResponse webhookStatus.
                         * @member {google.rpc.IStatus|null|undefined} webhookStatus
                         * @memberof google.cloud.dialogflow.v2.StreamingDetectIntentResponse
                         * @instance
                         */
                        StreamingDetectIntentResponse.prototype.webhookStatus = null;
    
                        /**
                         * StreamingDetectIntentResponse outputAudio.
                         * @member {Uint8Array} outputAudio
                         * @memberof google.cloud.dialogflow.v2.StreamingDetectIntentResponse
                         * @instance
                         */
                        StreamingDetectIntentResponse.prototype.outputAudio = $util.newBuffer([]);
    
                        /**
                         * StreamingDetectIntentResponse outputAudioConfig.
                         * @member {google.cloud.dialogflow.v2.IOutputAudioConfig|null|undefined} outputAudioConfig
                         * @memberof google.cloud.dialogflow.v2.StreamingDetectIntentResponse
                         * @instance
                         */
                        StreamingDetectIntentResponse.prototype.outputAudioConfig = null;
    
                        /**
                         * StreamingDetectIntentResponse debuggingInfo.
                         * @member {google.cloud.dialogflow.v2.ICloudConversationDebuggingInfo|null|undefined} debuggingInfo
                         * @memberof google.cloud.dialogflow.v2.StreamingDetectIntentResponse
                         * @instance
                         */
                        StreamingDetectIntentResponse.prototype.debuggingInfo = null;
    
                        /**
                         * Creates a new StreamingDetectIntentResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.StreamingDetectIntentResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IStreamingDetectIntentResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.StreamingDetectIntentResponse} StreamingDetectIntentResponse instance
                         */
                        StreamingDetectIntentResponse.create = function create(properties) {
                            return new StreamingDetectIntentResponse(properties);
                        };
    
                        /**
                         * Encodes the specified StreamingDetectIntentResponse message. Does not implicitly {@link google.cloud.dialogflow.v2.StreamingDetectIntentResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.StreamingDetectIntentResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IStreamingDetectIntentResponse} message StreamingDetectIntentResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        StreamingDetectIntentResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.responseId != null && Object.hasOwnProperty.call(message, "responseId"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.responseId);
                            if (message.recognitionResult != null && Object.hasOwnProperty.call(message, "recognitionResult"))
                                $root.google.cloud.dialogflow.v2.StreamingRecognitionResult.encode(message.recognitionResult, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.queryResult != null && Object.hasOwnProperty.call(message, "queryResult"))
                                $root.google.cloud.dialogflow.v2.QueryResult.encode(message.queryResult, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            if (message.webhookStatus != null && Object.hasOwnProperty.call(message, "webhookStatus"))
                                $root.google.rpc.Status.encode(message.webhookStatus, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            if (message.outputAudio != null && Object.hasOwnProperty.call(message, "outputAudio"))
                                writer.uint32(/* id 5, wireType 2 =*/42).bytes(message.outputAudio);
                            if (message.outputAudioConfig != null && Object.hasOwnProperty.call(message, "outputAudioConfig"))
                                $root.google.cloud.dialogflow.v2.OutputAudioConfig.encode(message.outputAudioConfig, writer.uint32(/* id 6, wireType 2 =*/50).fork()).ldelim();
                            if (message.debuggingInfo != null && Object.hasOwnProperty.call(message, "debuggingInfo"))
                                $root.google.cloud.dialogflow.v2.CloudConversationDebuggingInfo.encode(message.debuggingInfo, writer.uint32(/* id 8, wireType 2 =*/66).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified StreamingDetectIntentResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.StreamingDetectIntentResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.StreamingDetectIntentResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IStreamingDetectIntentResponse} message StreamingDetectIntentResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        StreamingDetectIntentResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a StreamingDetectIntentResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.StreamingDetectIntentResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.StreamingDetectIntentResponse} StreamingDetectIntentResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        StreamingDetectIntentResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.StreamingDetectIntentResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.responseId = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.recognitionResult = $root.google.cloud.dialogflow.v2.StreamingRecognitionResult.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 3: {
                                        message.queryResult = $root.google.cloud.dialogflow.v2.QueryResult.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 4: {
                                        message.webhookStatus = $root.google.rpc.Status.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 5: {
                                        message.outputAudio = reader.bytes();
                                        break;
                                    }
                                case 6: {
                                        message.outputAudioConfig = $root.google.cloud.dialogflow.v2.OutputAudioConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 8: {
                                        message.debuggingInfo = $root.google.cloud.dialogflow.v2.CloudConversationDebuggingInfo.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a StreamingDetectIntentResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.StreamingDetectIntentResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.StreamingDetectIntentResponse} StreamingDetectIntentResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        StreamingDetectIntentResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a StreamingDetectIntentResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.StreamingDetectIntentResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        StreamingDetectIntentResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.responseId != null && message.hasOwnProperty("responseId"))
                                if (!$util.isString(message.responseId))
                                    return "responseId: string expected";
                            if (message.recognitionResult != null && message.hasOwnProperty("recognitionResult")) {
                                var error = $root.google.cloud.dialogflow.v2.StreamingRecognitionResult.verify(message.recognitionResult);
                                if (error)
                                    return "recognitionResult." + error;
                            }
                            if (message.queryResult != null && message.hasOwnProperty("queryResult")) {
                                var error = $root.google.cloud.dialogflow.v2.QueryResult.verify(message.queryResult);
                                if (error)
                                    return "queryResult." + error;
                            }
                            if (message.webhookStatus != null && message.hasOwnProperty("webhookStatus")) {
                                var error = $root.google.rpc.Status.verify(message.webhookStatus);
                                if (error)
                                    return "webhookStatus." + error;
                            }
                            if (message.outputAudio != null && message.hasOwnProperty("outputAudio"))
                                if (!(message.outputAudio && typeof message.outputAudio.length === "number" || $util.isString(message.outputAudio)))
                                    return "outputAudio: buffer expected";
                            if (message.outputAudioConfig != null && message.hasOwnProperty("outputAudioConfig")) {
                                var error = $root.google.cloud.dialogflow.v2.OutputAudioConfig.verify(message.outputAudioConfig);
                                if (error)
                                    return "outputAudioConfig." + error;
                            }
                            if (message.debuggingInfo != null && message.hasOwnProperty("debuggingInfo")) {
                                var error = $root.google.cloud.dialogflow.v2.CloudConversationDebuggingInfo.verify(message.debuggingInfo);
                                if (error)
                                    return "debuggingInfo." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a StreamingDetectIntentResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.StreamingDetectIntentResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.StreamingDetectIntentResponse} StreamingDetectIntentResponse
                         */
                        StreamingDetectIntentResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.StreamingDetectIntentResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.StreamingDetectIntentResponse();
                            if (object.responseId != null)
                                message.responseId = String(object.responseId);
                            if (object.recognitionResult != null) {
                                if (typeof object.recognitionResult !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.StreamingDetectIntentResponse.recognitionResult: object expected");
                                message.recognitionResult = $root.google.cloud.dialogflow.v2.StreamingRecognitionResult.fromObject(object.recognitionResult);
                            }
                            if (object.queryResult != null) {
                                if (typeof object.queryResult !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.StreamingDetectIntentResponse.queryResult: object expected");
                                message.queryResult = $root.google.cloud.dialogflow.v2.QueryResult.fromObject(object.queryResult);
                            }
                            if (object.webhookStatus != null) {
                                if (typeof object.webhookStatus !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.StreamingDetectIntentResponse.webhookStatus: object expected");
                                message.webhookStatus = $root.google.rpc.Status.fromObject(object.webhookStatus);
                            }
                            if (object.outputAudio != null)
                                if (typeof object.outputAudio === "string")
                                    $util.base64.decode(object.outputAudio, message.outputAudio = $util.newBuffer($util.base64.length(object.outputAudio)), 0);
                                else if (object.outputAudio.length >= 0)
                                    message.outputAudio = object.outputAudio;
                            if (object.outputAudioConfig != null) {
                                if (typeof object.outputAudioConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.StreamingDetectIntentResponse.outputAudioConfig: object expected");
                                message.outputAudioConfig = $root.google.cloud.dialogflow.v2.OutputAudioConfig.fromObject(object.outputAudioConfig);
                            }
                            if (object.debuggingInfo != null) {
                                if (typeof object.debuggingInfo !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.StreamingDetectIntentResponse.debuggingInfo: object expected");
                                message.debuggingInfo = $root.google.cloud.dialogflow.v2.CloudConversationDebuggingInfo.fromObject(object.debuggingInfo);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a StreamingDetectIntentResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.StreamingDetectIntentResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.StreamingDetectIntentResponse} message StreamingDetectIntentResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        StreamingDetectIntentResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.responseId = "";
                                object.recognitionResult = null;
                                object.queryResult = null;
                                object.webhookStatus = null;
                                if (options.bytes === String)
                                    object.outputAudio = "";
                                else {
                                    object.outputAudio = [];
                                    if (options.bytes !== Array)
                                        object.outputAudio = $util.newBuffer(object.outputAudio);
                                }
                                object.outputAudioConfig = null;
                                object.debuggingInfo = null;
                            }
                            if (message.responseId != null && message.hasOwnProperty("responseId"))
                                object.responseId = message.responseId;
                            if (message.recognitionResult != null && message.hasOwnProperty("recognitionResult"))
                                object.recognitionResult = $root.google.cloud.dialogflow.v2.StreamingRecognitionResult.toObject(message.recognitionResult, options);
                            if (message.queryResult != null && message.hasOwnProperty("queryResult"))
                                object.queryResult = $root.google.cloud.dialogflow.v2.QueryResult.toObject(message.queryResult, options);
                            if (message.webhookStatus != null && message.hasOwnProperty("webhookStatus"))
                                object.webhookStatus = $root.google.rpc.Status.toObject(message.webhookStatus, options);
                            if (message.outputAudio != null && message.hasOwnProperty("outputAudio"))
                                object.outputAudio = options.bytes === String ? $util.base64.encode(message.outputAudio, 0, message.outputAudio.length) : options.bytes === Array ? Array.prototype.slice.call(message.outputAudio) : message.outputAudio;
                            if (message.outputAudioConfig != null && message.hasOwnProperty("outputAudioConfig"))
                                object.outputAudioConfig = $root.google.cloud.dialogflow.v2.OutputAudioConfig.toObject(message.outputAudioConfig, options);
                            if (message.debuggingInfo != null && message.hasOwnProperty("debuggingInfo"))
                                object.debuggingInfo = $root.google.cloud.dialogflow.v2.CloudConversationDebuggingInfo.toObject(message.debuggingInfo, options);
                            return object;
                        };
    
                        /**
                         * Converts this StreamingDetectIntentResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.StreamingDetectIntentResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        StreamingDetectIntentResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for StreamingDetectIntentResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.StreamingDetectIntentResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        StreamingDetectIntentResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.StreamingDetectIntentResponse";
                        };
    
                        return StreamingDetectIntentResponse;
                    })();
    
                    v2.StreamingRecognitionResult = (function() {
    
                        /**
                         * Properties of a StreamingRecognitionResult.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IStreamingRecognitionResult
                         * @property {google.cloud.dialogflow.v2.StreamingRecognitionResult.MessageType|null} [messageType] StreamingRecognitionResult messageType
                         * @property {string|null} [transcript] StreamingRecognitionResult transcript
                         * @property {boolean|null} [isFinal] StreamingRecognitionResult isFinal
                         * @property {number|null} [confidence] StreamingRecognitionResult confidence
                         * @property {Array.<google.cloud.dialogflow.v2.ISpeechWordInfo>|null} [speechWordInfo] StreamingRecognitionResult speechWordInfo
                         * @property {google.protobuf.IDuration|null} [speechEndOffset] StreamingRecognitionResult speechEndOffset
                         * @property {string|null} [languageCode] StreamingRecognitionResult languageCode
                         */
    
                        /**
                         * Constructs a new StreamingRecognitionResult.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a StreamingRecognitionResult.
                         * @implements IStreamingRecognitionResult
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IStreamingRecognitionResult=} [properties] Properties to set
                         */
                        function StreamingRecognitionResult(properties) {
                            this.speechWordInfo = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * StreamingRecognitionResult messageType.
                         * @member {google.cloud.dialogflow.v2.StreamingRecognitionResult.MessageType} messageType
                         * @memberof google.cloud.dialogflow.v2.StreamingRecognitionResult
                         * @instance
                         */
                        StreamingRecognitionResult.prototype.messageType = 0;
    
                        /**
                         * StreamingRecognitionResult transcript.
                         * @member {string} transcript
                         * @memberof google.cloud.dialogflow.v2.StreamingRecognitionResult
                         * @instance
                         */
                        StreamingRecognitionResult.prototype.transcript = "";
    
                        /**
                         * StreamingRecognitionResult isFinal.
                         * @member {boolean} isFinal
                         * @memberof google.cloud.dialogflow.v2.StreamingRecognitionResult
                         * @instance
                         */
                        StreamingRecognitionResult.prototype.isFinal = false;
    
                        /**
                         * StreamingRecognitionResult confidence.
                         * @member {number} confidence
                         * @memberof google.cloud.dialogflow.v2.StreamingRecognitionResult
                         * @instance
                         */
                        StreamingRecognitionResult.prototype.confidence = 0;
    
                        /**
                         * StreamingRecognitionResult speechWordInfo.
                         * @member {Array.<google.cloud.dialogflow.v2.ISpeechWordInfo>} speechWordInfo
                         * @memberof google.cloud.dialogflow.v2.StreamingRecognitionResult
                         * @instance
                         */
                        StreamingRecognitionResult.prototype.speechWordInfo = $util.emptyArray;
    
                        /**
                         * StreamingRecognitionResult speechEndOffset.
                         * @member {google.protobuf.IDuration|null|undefined} speechEndOffset
                         * @memberof google.cloud.dialogflow.v2.StreamingRecognitionResult
                         * @instance
                         */
                        StreamingRecognitionResult.prototype.speechEndOffset = null;
    
                        /**
                         * StreamingRecognitionResult languageCode.
                         * @member {string} languageCode
                         * @memberof google.cloud.dialogflow.v2.StreamingRecognitionResult
                         * @instance
                         */
                        StreamingRecognitionResult.prototype.languageCode = "";
    
                        /**
                         * Creates a new StreamingRecognitionResult instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.StreamingRecognitionResult
                         * @static
                         * @param {google.cloud.dialogflow.v2.IStreamingRecognitionResult=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.StreamingRecognitionResult} StreamingRecognitionResult instance
                         */
                        StreamingRecognitionResult.create = function create(properties) {
                            return new StreamingRecognitionResult(properties);
                        };
    
                        /**
                         * Encodes the specified StreamingRecognitionResult message. Does not implicitly {@link google.cloud.dialogflow.v2.StreamingRecognitionResult.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.StreamingRecognitionResult
                         * @static
                         * @param {google.cloud.dialogflow.v2.IStreamingRecognitionResult} message StreamingRecognitionResult message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        StreamingRecognitionResult.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.messageType != null && Object.hasOwnProperty.call(message, "messageType"))
                                writer.uint32(/* id 1, wireType 0 =*/8).int32(message.messageType);
                            if (message.transcript != null && Object.hasOwnProperty.call(message, "transcript"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.transcript);
                            if (message.isFinal != null && Object.hasOwnProperty.call(message, "isFinal"))
                                writer.uint32(/* id 3, wireType 0 =*/24).bool(message.isFinal);
                            if (message.confidence != null && Object.hasOwnProperty.call(message, "confidence"))
                                writer.uint32(/* id 4, wireType 5 =*/37).float(message.confidence);
                            if (message.speechWordInfo != null && message.speechWordInfo.length)
                                for (var i = 0; i < message.speechWordInfo.length; ++i)
                                    $root.google.cloud.dialogflow.v2.SpeechWordInfo.encode(message.speechWordInfo[i], writer.uint32(/* id 7, wireType 2 =*/58).fork()).ldelim();
                            if (message.speechEndOffset != null && Object.hasOwnProperty.call(message, "speechEndOffset"))
                                $root.google.protobuf.Duration.encode(message.speechEndOffset, writer.uint32(/* id 8, wireType 2 =*/66).fork()).ldelim();
                            if (message.languageCode != null && Object.hasOwnProperty.call(message, "languageCode"))
                                writer.uint32(/* id 10, wireType 2 =*/82).string(message.languageCode);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified StreamingRecognitionResult message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.StreamingRecognitionResult.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.StreamingRecognitionResult
                         * @static
                         * @param {google.cloud.dialogflow.v2.IStreamingRecognitionResult} message StreamingRecognitionResult message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        StreamingRecognitionResult.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a StreamingRecognitionResult message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.StreamingRecognitionResult
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.StreamingRecognitionResult} StreamingRecognitionResult
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        StreamingRecognitionResult.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.StreamingRecognitionResult();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.messageType = reader.int32();
                                        break;
                                    }
                                case 2: {
                                        message.transcript = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.isFinal = reader.bool();
                                        break;
                                    }
                                case 4: {
                                        message.confidence = reader.float();
                                        break;
                                    }
                                case 7: {
                                        if (!(message.speechWordInfo && message.speechWordInfo.length))
                                            message.speechWordInfo = [];
                                        message.speechWordInfo.push($root.google.cloud.dialogflow.v2.SpeechWordInfo.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 8: {
                                        message.speechEndOffset = $root.google.protobuf.Duration.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 10: {
                                        message.languageCode = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a StreamingRecognitionResult message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.StreamingRecognitionResult
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.StreamingRecognitionResult} StreamingRecognitionResult
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        StreamingRecognitionResult.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a StreamingRecognitionResult message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.StreamingRecognitionResult
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        StreamingRecognitionResult.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.messageType != null && message.hasOwnProperty("messageType"))
                                switch (message.messageType) {
                                default:
                                    return "messageType: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                    break;
                                }
                            if (message.transcript != null && message.hasOwnProperty("transcript"))
                                if (!$util.isString(message.transcript))
                                    return "transcript: string expected";
                            if (message.isFinal != null && message.hasOwnProperty("isFinal"))
                                if (typeof message.isFinal !== "boolean")
                                    return "isFinal: boolean expected";
                            if (message.confidence != null && message.hasOwnProperty("confidence"))
                                if (typeof message.confidence !== "number")
                                    return "confidence: number expected";
                            if (message.speechWordInfo != null && message.hasOwnProperty("speechWordInfo")) {
                                if (!Array.isArray(message.speechWordInfo))
                                    return "speechWordInfo: array expected";
                                for (var i = 0; i < message.speechWordInfo.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.SpeechWordInfo.verify(message.speechWordInfo[i]);
                                    if (error)
                                        return "speechWordInfo." + error;
                                }
                            }
                            if (message.speechEndOffset != null && message.hasOwnProperty("speechEndOffset")) {
                                var error = $root.google.protobuf.Duration.verify(message.speechEndOffset);
                                if (error)
                                    return "speechEndOffset." + error;
                            }
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                if (!$util.isString(message.languageCode))
                                    return "languageCode: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a StreamingRecognitionResult message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.StreamingRecognitionResult
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.StreamingRecognitionResult} StreamingRecognitionResult
                         */
                        StreamingRecognitionResult.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.StreamingRecognitionResult)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.StreamingRecognitionResult();
                            switch (object.messageType) {
                            default:
                                if (typeof object.messageType === "number") {
                                    message.messageType = object.messageType;
                                    break;
                                }
                                break;
                            case "MESSAGE_TYPE_UNSPECIFIED":
                            case 0:
                                message.messageType = 0;
                                break;
                            case "TRANSCRIPT":
                            case 1:
                                message.messageType = 1;
                                break;
                            case "END_OF_SINGLE_UTTERANCE":
                            case 2:
                                message.messageType = 2;
                                break;
                            }
                            if (object.transcript != null)
                                message.transcript = String(object.transcript);
                            if (object.isFinal != null)
                                message.isFinal = Boolean(object.isFinal);
                            if (object.confidence != null)
                                message.confidence = Number(object.confidence);
                            if (object.speechWordInfo) {
                                if (!Array.isArray(object.speechWordInfo))
                                    throw TypeError(".google.cloud.dialogflow.v2.StreamingRecognitionResult.speechWordInfo: array expected");
                                message.speechWordInfo = [];
                                for (var i = 0; i < object.speechWordInfo.length; ++i) {
                                    if (typeof object.speechWordInfo[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.StreamingRecognitionResult.speechWordInfo: object expected");
                                    message.speechWordInfo[i] = $root.google.cloud.dialogflow.v2.SpeechWordInfo.fromObject(object.speechWordInfo[i]);
                                }
                            }
                            if (object.speechEndOffset != null) {
                                if (typeof object.speechEndOffset !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.StreamingRecognitionResult.speechEndOffset: object expected");
                                message.speechEndOffset = $root.google.protobuf.Duration.fromObject(object.speechEndOffset);
                            }
                            if (object.languageCode != null)
                                message.languageCode = String(object.languageCode);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a StreamingRecognitionResult message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.StreamingRecognitionResult
                         * @static
                         * @param {google.cloud.dialogflow.v2.StreamingRecognitionResult} message StreamingRecognitionResult
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        StreamingRecognitionResult.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.speechWordInfo = [];
                            if (options.defaults) {
                                object.messageType = options.enums === String ? "MESSAGE_TYPE_UNSPECIFIED" : 0;
                                object.transcript = "";
                                object.isFinal = false;
                                object.confidence = 0;
                                object.speechEndOffset = null;
                                object.languageCode = "";
                            }
                            if (message.messageType != null && message.hasOwnProperty("messageType"))
                                object.messageType = options.enums === String ? $root.google.cloud.dialogflow.v2.StreamingRecognitionResult.MessageType[message.messageType] === undefined ? message.messageType : $root.google.cloud.dialogflow.v2.StreamingRecognitionResult.MessageType[message.messageType] : message.messageType;
                            if (message.transcript != null && message.hasOwnProperty("transcript"))
                                object.transcript = message.transcript;
                            if (message.isFinal != null && message.hasOwnProperty("isFinal"))
                                object.isFinal = message.isFinal;
                            if (message.confidence != null && message.hasOwnProperty("confidence"))
                                object.confidence = options.json && !isFinite(message.confidence) ? String(message.confidence) : message.confidence;
                            if (message.speechWordInfo && message.speechWordInfo.length) {
                                object.speechWordInfo = [];
                                for (var j = 0; j < message.speechWordInfo.length; ++j)
                                    object.speechWordInfo[j] = $root.google.cloud.dialogflow.v2.SpeechWordInfo.toObject(message.speechWordInfo[j], options);
                            }
                            if (message.speechEndOffset != null && message.hasOwnProperty("speechEndOffset"))
                                object.speechEndOffset = $root.google.protobuf.Duration.toObject(message.speechEndOffset, options);
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                object.languageCode = message.languageCode;
                            return object;
                        };
    
                        /**
                         * Converts this StreamingRecognitionResult to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.StreamingRecognitionResult
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        StreamingRecognitionResult.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for StreamingRecognitionResult
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.StreamingRecognitionResult
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        StreamingRecognitionResult.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.StreamingRecognitionResult";
                        };
    
                        /**
                         * MessageType enum.
                         * @name google.cloud.dialogflow.v2.StreamingRecognitionResult.MessageType
                         * @enum {number}
                         * @property {number} MESSAGE_TYPE_UNSPECIFIED=0 MESSAGE_TYPE_UNSPECIFIED value
                         * @property {number} TRANSCRIPT=1 TRANSCRIPT value
                         * @property {number} END_OF_SINGLE_UTTERANCE=2 END_OF_SINGLE_UTTERANCE value
                         */
                        StreamingRecognitionResult.MessageType = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "MESSAGE_TYPE_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "TRANSCRIPT"] = 1;
                            values[valuesById[2] = "END_OF_SINGLE_UTTERANCE"] = 2;
                            return values;
                        })();
    
                        return StreamingRecognitionResult;
                    })();
    
                    v2.TextInput = (function() {
    
                        /**
                         * Properties of a TextInput.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ITextInput
                         * @property {string|null} [text] TextInput text
                         * @property {string|null} [languageCode] TextInput languageCode
                         */
    
                        /**
                         * Constructs a new TextInput.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a TextInput.
                         * @implements ITextInput
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ITextInput=} [properties] Properties to set
                         */
                        function TextInput(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * TextInput text.
                         * @member {string} text
                         * @memberof google.cloud.dialogflow.v2.TextInput
                         * @instance
                         */
                        TextInput.prototype.text = "";
    
                        /**
                         * TextInput languageCode.
                         * @member {string} languageCode
                         * @memberof google.cloud.dialogflow.v2.TextInput
                         * @instance
                         */
                        TextInput.prototype.languageCode = "";
    
                        /**
                         * Creates a new TextInput instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.TextInput
                         * @static
                         * @param {google.cloud.dialogflow.v2.ITextInput=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.TextInput} TextInput instance
                         */
                        TextInput.create = function create(properties) {
                            return new TextInput(properties);
                        };
    
                        /**
                         * Encodes the specified TextInput message. Does not implicitly {@link google.cloud.dialogflow.v2.TextInput.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.TextInput
                         * @static
                         * @param {google.cloud.dialogflow.v2.ITextInput} message TextInput message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        TextInput.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.text != null && Object.hasOwnProperty.call(message, "text"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.text);
                            if (message.languageCode != null && Object.hasOwnProperty.call(message, "languageCode"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.languageCode);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified TextInput message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.TextInput.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.TextInput
                         * @static
                         * @param {google.cloud.dialogflow.v2.ITextInput} message TextInput message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        TextInput.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a TextInput message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.TextInput
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.TextInput} TextInput
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        TextInput.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.TextInput();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.text = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.languageCode = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a TextInput message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.TextInput
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.TextInput} TextInput
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        TextInput.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a TextInput message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.TextInput
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        TextInput.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.text != null && message.hasOwnProperty("text"))
                                if (!$util.isString(message.text))
                                    return "text: string expected";
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                if (!$util.isString(message.languageCode))
                                    return "languageCode: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a TextInput message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.TextInput
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.TextInput} TextInput
                         */
                        TextInput.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.TextInput)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.TextInput();
                            if (object.text != null)
                                message.text = String(object.text);
                            if (object.languageCode != null)
                                message.languageCode = String(object.languageCode);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a TextInput message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.TextInput
                         * @static
                         * @param {google.cloud.dialogflow.v2.TextInput} message TextInput
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        TextInput.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.text = "";
                                object.languageCode = "";
                            }
                            if (message.text != null && message.hasOwnProperty("text"))
                                object.text = message.text;
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                object.languageCode = message.languageCode;
                            return object;
                        };
    
                        /**
                         * Converts this TextInput to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.TextInput
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        TextInput.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for TextInput
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.TextInput
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        TextInput.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.TextInput";
                        };
    
                        return TextInput;
                    })();
    
                    v2.EventInput = (function() {
    
                        /**
                         * Properties of an EventInput.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IEventInput
                         * @property {string|null} [name] EventInput name
                         * @property {google.protobuf.IStruct|null} [parameters] EventInput parameters
                         * @property {string|null} [languageCode] EventInput languageCode
                         */
    
                        /**
                         * Constructs a new EventInput.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an EventInput.
                         * @implements IEventInput
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IEventInput=} [properties] Properties to set
                         */
                        function EventInput(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * EventInput name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2.EventInput
                         * @instance
                         */
                        EventInput.prototype.name = "";
    
                        /**
                         * EventInput parameters.
                         * @member {google.protobuf.IStruct|null|undefined} parameters
                         * @memberof google.cloud.dialogflow.v2.EventInput
                         * @instance
                         */
                        EventInput.prototype.parameters = null;
    
                        /**
                         * EventInput languageCode.
                         * @member {string} languageCode
                         * @memberof google.cloud.dialogflow.v2.EventInput
                         * @instance
                         */
                        EventInput.prototype.languageCode = "";
    
                        /**
                         * Creates a new EventInput instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.EventInput
                         * @static
                         * @param {google.cloud.dialogflow.v2.IEventInput=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.EventInput} EventInput instance
                         */
                        EventInput.create = function create(properties) {
                            return new EventInput(properties);
                        };
    
                        /**
                         * Encodes the specified EventInput message. Does not implicitly {@link google.cloud.dialogflow.v2.EventInput.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.EventInput
                         * @static
                         * @param {google.cloud.dialogflow.v2.IEventInput} message EventInput message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        EventInput.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            if (message.parameters != null && Object.hasOwnProperty.call(message, "parameters"))
                                $root.google.protobuf.Struct.encode(message.parameters, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.languageCode != null && Object.hasOwnProperty.call(message, "languageCode"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.languageCode);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified EventInput message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.EventInput.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.EventInput
                         * @static
                         * @param {google.cloud.dialogflow.v2.IEventInput} message EventInput message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        EventInput.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an EventInput message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.EventInput
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.EventInput} EventInput
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        EventInput.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.EventInput();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.parameters = $root.google.protobuf.Struct.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 3: {
                                        message.languageCode = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an EventInput message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.EventInput
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.EventInput} EventInput
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        EventInput.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an EventInput message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.EventInput
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        EventInput.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            if (message.parameters != null && message.hasOwnProperty("parameters")) {
                                var error = $root.google.protobuf.Struct.verify(message.parameters);
                                if (error)
                                    return "parameters." + error;
                            }
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                if (!$util.isString(message.languageCode))
                                    return "languageCode: string expected";
                            return null;
                        };
    
                        /**
                         * Creates an EventInput message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.EventInput
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.EventInput} EventInput
                         */
                        EventInput.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.EventInput)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.EventInput();
                            if (object.name != null)
                                message.name = String(object.name);
                            if (object.parameters != null) {
                                if (typeof object.parameters !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.EventInput.parameters: object expected");
                                message.parameters = $root.google.protobuf.Struct.fromObject(object.parameters);
                            }
                            if (object.languageCode != null)
                                message.languageCode = String(object.languageCode);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an EventInput message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.EventInput
                         * @static
                         * @param {google.cloud.dialogflow.v2.EventInput} message EventInput
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        EventInput.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.name = "";
                                object.parameters = null;
                                object.languageCode = "";
                            }
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            if (message.parameters != null && message.hasOwnProperty("parameters"))
                                object.parameters = $root.google.protobuf.Struct.toObject(message.parameters, options);
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                object.languageCode = message.languageCode;
                            return object;
                        };
    
                        /**
                         * Converts this EventInput to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.EventInput
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        EventInput.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for EventInput
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.EventInput
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        EventInput.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.EventInput";
                        };
    
                        return EventInput;
                    })();
    
                    v2.SentimentAnalysisRequestConfig = (function() {
    
                        /**
                         * Properties of a SentimentAnalysisRequestConfig.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ISentimentAnalysisRequestConfig
                         * @property {boolean|null} [analyzeQueryTextSentiment] SentimentAnalysisRequestConfig analyzeQueryTextSentiment
                         */
    
                        /**
                         * Constructs a new SentimentAnalysisRequestConfig.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a SentimentAnalysisRequestConfig.
                         * @implements ISentimentAnalysisRequestConfig
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ISentimentAnalysisRequestConfig=} [properties] Properties to set
                         */
                        function SentimentAnalysisRequestConfig(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SentimentAnalysisRequestConfig analyzeQueryTextSentiment.
                         * @member {boolean} analyzeQueryTextSentiment
                         * @memberof google.cloud.dialogflow.v2.SentimentAnalysisRequestConfig
                         * @instance
                         */
                        SentimentAnalysisRequestConfig.prototype.analyzeQueryTextSentiment = false;
    
                        /**
                         * Creates a new SentimentAnalysisRequestConfig instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.SentimentAnalysisRequestConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISentimentAnalysisRequestConfig=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.SentimentAnalysisRequestConfig} SentimentAnalysisRequestConfig instance
                         */
                        SentimentAnalysisRequestConfig.create = function create(properties) {
                            return new SentimentAnalysisRequestConfig(properties);
                        };
    
                        /**
                         * Encodes the specified SentimentAnalysisRequestConfig message. Does not implicitly {@link google.cloud.dialogflow.v2.SentimentAnalysisRequestConfig.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.SentimentAnalysisRequestConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISentimentAnalysisRequestConfig} message SentimentAnalysisRequestConfig message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SentimentAnalysisRequestConfig.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.analyzeQueryTextSentiment != null && Object.hasOwnProperty.call(message, "analyzeQueryTextSentiment"))
                                writer.uint32(/* id 1, wireType 0 =*/8).bool(message.analyzeQueryTextSentiment);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SentimentAnalysisRequestConfig message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.SentimentAnalysisRequestConfig.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SentimentAnalysisRequestConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISentimentAnalysisRequestConfig} message SentimentAnalysisRequestConfig message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SentimentAnalysisRequestConfig.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SentimentAnalysisRequestConfig message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.SentimentAnalysisRequestConfig
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.SentimentAnalysisRequestConfig} SentimentAnalysisRequestConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SentimentAnalysisRequestConfig.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.SentimentAnalysisRequestConfig();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.analyzeQueryTextSentiment = reader.bool();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SentimentAnalysisRequestConfig message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SentimentAnalysisRequestConfig
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.SentimentAnalysisRequestConfig} SentimentAnalysisRequestConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SentimentAnalysisRequestConfig.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SentimentAnalysisRequestConfig message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.SentimentAnalysisRequestConfig
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SentimentAnalysisRequestConfig.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.analyzeQueryTextSentiment != null && message.hasOwnProperty("analyzeQueryTextSentiment"))
                                if (typeof message.analyzeQueryTextSentiment !== "boolean")
                                    return "analyzeQueryTextSentiment: boolean expected";
                            return null;
                        };
    
                        /**
                         * Creates a SentimentAnalysisRequestConfig message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.SentimentAnalysisRequestConfig
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.SentimentAnalysisRequestConfig} SentimentAnalysisRequestConfig
                         */
                        SentimentAnalysisRequestConfig.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.SentimentAnalysisRequestConfig)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.SentimentAnalysisRequestConfig();
                            if (object.analyzeQueryTextSentiment != null)
                                message.analyzeQueryTextSentiment = Boolean(object.analyzeQueryTextSentiment);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SentimentAnalysisRequestConfig message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.SentimentAnalysisRequestConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2.SentimentAnalysisRequestConfig} message SentimentAnalysisRequestConfig
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SentimentAnalysisRequestConfig.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.analyzeQueryTextSentiment = false;
                            if (message.analyzeQueryTextSentiment != null && message.hasOwnProperty("analyzeQueryTextSentiment"))
                                object.analyzeQueryTextSentiment = message.analyzeQueryTextSentiment;
                            return object;
                        };
    
                        /**
                         * Converts this SentimentAnalysisRequestConfig to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.SentimentAnalysisRequestConfig
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SentimentAnalysisRequestConfig.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SentimentAnalysisRequestConfig
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.SentimentAnalysisRequestConfig
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SentimentAnalysisRequestConfig.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.SentimentAnalysisRequestConfig";
                        };
    
                        return SentimentAnalysisRequestConfig;
                    })();
    
                    v2.SentimentAnalysisResult = (function() {
    
                        /**
                         * Properties of a SentimentAnalysisResult.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ISentimentAnalysisResult
                         * @property {google.cloud.dialogflow.v2.ISentiment|null} [queryTextSentiment] SentimentAnalysisResult queryTextSentiment
                         */
    
                        /**
                         * Constructs a new SentimentAnalysisResult.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a SentimentAnalysisResult.
                         * @implements ISentimentAnalysisResult
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ISentimentAnalysisResult=} [properties] Properties to set
                         */
                        function SentimentAnalysisResult(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SentimentAnalysisResult queryTextSentiment.
                         * @member {google.cloud.dialogflow.v2.ISentiment|null|undefined} queryTextSentiment
                         * @memberof google.cloud.dialogflow.v2.SentimentAnalysisResult
                         * @instance
                         */
                        SentimentAnalysisResult.prototype.queryTextSentiment = null;
    
                        /**
                         * Creates a new SentimentAnalysisResult instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.SentimentAnalysisResult
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISentimentAnalysisResult=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.SentimentAnalysisResult} SentimentAnalysisResult instance
                         */
                        SentimentAnalysisResult.create = function create(properties) {
                            return new SentimentAnalysisResult(properties);
                        };
    
                        /**
                         * Encodes the specified SentimentAnalysisResult message. Does not implicitly {@link google.cloud.dialogflow.v2.SentimentAnalysisResult.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.SentimentAnalysisResult
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISentimentAnalysisResult} message SentimentAnalysisResult message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SentimentAnalysisResult.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.queryTextSentiment != null && Object.hasOwnProperty.call(message, "queryTextSentiment"))
                                $root.google.cloud.dialogflow.v2.Sentiment.encode(message.queryTextSentiment, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SentimentAnalysisResult message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.SentimentAnalysisResult.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SentimentAnalysisResult
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISentimentAnalysisResult} message SentimentAnalysisResult message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SentimentAnalysisResult.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SentimentAnalysisResult message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.SentimentAnalysisResult
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.SentimentAnalysisResult} SentimentAnalysisResult
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SentimentAnalysisResult.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.SentimentAnalysisResult();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.queryTextSentiment = $root.google.cloud.dialogflow.v2.Sentiment.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SentimentAnalysisResult message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SentimentAnalysisResult
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.SentimentAnalysisResult} SentimentAnalysisResult
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SentimentAnalysisResult.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SentimentAnalysisResult message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.SentimentAnalysisResult
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SentimentAnalysisResult.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.queryTextSentiment != null && message.hasOwnProperty("queryTextSentiment")) {
                                var error = $root.google.cloud.dialogflow.v2.Sentiment.verify(message.queryTextSentiment);
                                if (error)
                                    return "queryTextSentiment." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a SentimentAnalysisResult message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.SentimentAnalysisResult
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.SentimentAnalysisResult} SentimentAnalysisResult
                         */
                        SentimentAnalysisResult.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.SentimentAnalysisResult)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.SentimentAnalysisResult();
                            if (object.queryTextSentiment != null) {
                                if (typeof object.queryTextSentiment !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.SentimentAnalysisResult.queryTextSentiment: object expected");
                                message.queryTextSentiment = $root.google.cloud.dialogflow.v2.Sentiment.fromObject(object.queryTextSentiment);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SentimentAnalysisResult message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.SentimentAnalysisResult
                         * @static
                         * @param {google.cloud.dialogflow.v2.SentimentAnalysisResult} message SentimentAnalysisResult
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SentimentAnalysisResult.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.queryTextSentiment = null;
                            if (message.queryTextSentiment != null && message.hasOwnProperty("queryTextSentiment"))
                                object.queryTextSentiment = $root.google.cloud.dialogflow.v2.Sentiment.toObject(message.queryTextSentiment, options);
                            return object;
                        };
    
                        /**
                         * Converts this SentimentAnalysisResult to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.SentimentAnalysisResult
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SentimentAnalysisResult.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SentimentAnalysisResult
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.SentimentAnalysisResult
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SentimentAnalysisResult.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.SentimentAnalysisResult";
                        };
    
                        return SentimentAnalysisResult;
                    })();
    
                    v2.Sentiment = (function() {
    
                        /**
                         * Properties of a Sentiment.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ISentiment
                         * @property {number|null} [score] Sentiment score
                         * @property {number|null} [magnitude] Sentiment magnitude
                         */
    
                        /**
                         * Constructs a new Sentiment.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a Sentiment.
                         * @implements ISentiment
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ISentiment=} [properties] Properties to set
                         */
                        function Sentiment(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * Sentiment score.
                         * @member {number} score
                         * @memberof google.cloud.dialogflow.v2.Sentiment
                         * @instance
                         */
                        Sentiment.prototype.score = 0;
    
                        /**
                         * Sentiment magnitude.
                         * @member {number} magnitude
                         * @memberof google.cloud.dialogflow.v2.Sentiment
                         * @instance
                         */
                        Sentiment.prototype.magnitude = 0;
    
                        /**
                         * Creates a new Sentiment instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.Sentiment
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISentiment=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.Sentiment} Sentiment instance
                         */
                        Sentiment.create = function create(properties) {
                            return new Sentiment(properties);
                        };
    
                        /**
                         * Encodes the specified Sentiment message. Does not implicitly {@link google.cloud.dialogflow.v2.Sentiment.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.Sentiment
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISentiment} message Sentiment message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        Sentiment.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.score != null && Object.hasOwnProperty.call(message, "score"))
                                writer.uint32(/* id 1, wireType 5 =*/13).float(message.score);
                            if (message.magnitude != null && Object.hasOwnProperty.call(message, "magnitude"))
                                writer.uint32(/* id 2, wireType 5 =*/21).float(message.magnitude);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified Sentiment message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.Sentiment.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.Sentiment
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISentiment} message Sentiment message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        Sentiment.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a Sentiment message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.Sentiment
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.Sentiment} Sentiment
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        Sentiment.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.Sentiment();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.score = reader.float();
                                        break;
                                    }
                                case 2: {
                                        message.magnitude = reader.float();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a Sentiment message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.Sentiment
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.Sentiment} Sentiment
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        Sentiment.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a Sentiment message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.Sentiment
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        Sentiment.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.score != null && message.hasOwnProperty("score"))
                                if (typeof message.score !== "number")
                                    return "score: number expected";
                            if (message.magnitude != null && message.hasOwnProperty("magnitude"))
                                if (typeof message.magnitude !== "number")
                                    return "magnitude: number expected";
                            return null;
                        };
    
                        /**
                         * Creates a Sentiment message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.Sentiment
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.Sentiment} Sentiment
                         */
                        Sentiment.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.Sentiment)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.Sentiment();
                            if (object.score != null)
                                message.score = Number(object.score);
                            if (object.magnitude != null)
                                message.magnitude = Number(object.magnitude);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a Sentiment message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.Sentiment
                         * @static
                         * @param {google.cloud.dialogflow.v2.Sentiment} message Sentiment
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        Sentiment.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.score = 0;
                                object.magnitude = 0;
                            }
                            if (message.score != null && message.hasOwnProperty("score"))
                                object.score = options.json && !isFinite(message.score) ? String(message.score) : message.score;
                            if (message.magnitude != null && message.hasOwnProperty("magnitude"))
                                object.magnitude = options.json && !isFinite(message.magnitude) ? String(message.magnitude) : message.magnitude;
                            return object;
                        };
    
                        /**
                         * Converts this Sentiment to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.Sentiment
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        Sentiment.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for Sentiment
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.Sentiment
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        Sentiment.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.Sentiment";
                        };
    
                        return Sentiment;
                    })();
    
                    v2.Contexts = (function() {
    
                        /**
                         * Constructs a new Contexts service.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a Contexts
                         * @extends $protobuf.rpc.Service
                         * @constructor
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         */
                        function Contexts(rpcImpl, requestDelimited, responseDelimited) {
                            $protobuf.rpc.Service.call(this, rpcImpl, requestDelimited, responseDelimited);
                        }
    
                        (Contexts.prototype = Object.create($protobuf.rpc.Service.prototype)).constructor = Contexts;
    
                        /**
                         * Creates new Contexts service using the specified rpc implementation.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.Contexts
                         * @static
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         * @returns {Contexts} RPC service. Useful where requests and/or responses are streamed.
                         */
                        Contexts.create = function create(rpcImpl, requestDelimited, responseDelimited) {
                            return new this(rpcImpl, requestDelimited, responseDelimited);
                        };
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Contexts|listContexts}.
                         * @memberof google.cloud.dialogflow.v2.Contexts
                         * @typedef ListContextsCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.ListContextsResponse} [response] ListContextsResponse
                         */
    
                        /**
                         * Calls ListContexts.
                         * @function listContexts
                         * @memberof google.cloud.dialogflow.v2.Contexts
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IListContextsRequest} request ListContextsRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Contexts.ListContextsCallback} callback Node-style callback called with the error, if any, and ListContextsResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Contexts.prototype.listContexts = function listContexts(request, callback) {
                            return this.rpcCall(listContexts, $root.google.cloud.dialogflow.v2.ListContextsRequest, $root.google.cloud.dialogflow.v2.ListContextsResponse, request, callback);
                        }, "name", { value: "ListContexts" });
    
                        /**
                         * Calls ListContexts.
                         * @function listContexts
                         * @memberof google.cloud.dialogflow.v2.Contexts
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IListContextsRequest} request ListContextsRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.ListContextsResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Contexts|getContext}.
                         * @memberof google.cloud.dialogflow.v2.Contexts
                         * @typedef GetContextCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.Context} [response] Context
                         */
    
                        /**
                         * Calls GetContext.
                         * @function getContext
                         * @memberof google.cloud.dialogflow.v2.Contexts
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IGetContextRequest} request GetContextRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Contexts.GetContextCallback} callback Node-style callback called with the error, if any, and Context
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Contexts.prototype.getContext = function getContext(request, callback) {
                            return this.rpcCall(getContext, $root.google.cloud.dialogflow.v2.GetContextRequest, $root.google.cloud.dialogflow.v2.Context, request, callback);
                        }, "name", { value: "GetContext" });
    
                        /**
                         * Calls GetContext.
                         * @function getContext
                         * @memberof google.cloud.dialogflow.v2.Contexts
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IGetContextRequest} request GetContextRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.Context>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Contexts|createContext}.
                         * @memberof google.cloud.dialogflow.v2.Contexts
                         * @typedef CreateContextCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.Context} [response] Context
                         */
    
                        /**
                         * Calls CreateContext.
                         * @function createContext
                         * @memberof google.cloud.dialogflow.v2.Contexts
                         * @instance
                         * @param {google.cloud.dialogflow.v2.ICreateContextRequest} request CreateContextRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Contexts.CreateContextCallback} callback Node-style callback called with the error, if any, and Context
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Contexts.prototype.createContext = function createContext(request, callback) {
                            return this.rpcCall(createContext, $root.google.cloud.dialogflow.v2.CreateContextRequest, $root.google.cloud.dialogflow.v2.Context, request, callback);
                        }, "name", { value: "CreateContext" });
    
                        /**
                         * Calls CreateContext.
                         * @function createContext
                         * @memberof google.cloud.dialogflow.v2.Contexts
                         * @instance
                         * @param {google.cloud.dialogflow.v2.ICreateContextRequest} request CreateContextRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.Context>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Contexts|updateContext}.
                         * @memberof google.cloud.dialogflow.v2.Contexts
                         * @typedef UpdateContextCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.Context} [response] Context
                         */
    
                        /**
                         * Calls UpdateContext.
                         * @function updateContext
                         * @memberof google.cloud.dialogflow.v2.Contexts
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IUpdateContextRequest} request UpdateContextRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Contexts.UpdateContextCallback} callback Node-style callback called with the error, if any, and Context
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Contexts.prototype.updateContext = function updateContext(request, callback) {
                            return this.rpcCall(updateContext, $root.google.cloud.dialogflow.v2.UpdateContextRequest, $root.google.cloud.dialogflow.v2.Context, request, callback);
                        }, "name", { value: "UpdateContext" });
    
                        /**
                         * Calls UpdateContext.
                         * @function updateContext
                         * @memberof google.cloud.dialogflow.v2.Contexts
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IUpdateContextRequest} request UpdateContextRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.Context>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Contexts|deleteContext}.
                         * @memberof google.cloud.dialogflow.v2.Contexts
                         * @typedef DeleteContextCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.protobuf.Empty} [response] Empty
                         */
    
                        /**
                         * Calls DeleteContext.
                         * @function deleteContext
                         * @memberof google.cloud.dialogflow.v2.Contexts
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IDeleteContextRequest} request DeleteContextRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Contexts.DeleteContextCallback} callback Node-style callback called with the error, if any, and Empty
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Contexts.prototype.deleteContext = function deleteContext(request, callback) {
                            return this.rpcCall(deleteContext, $root.google.cloud.dialogflow.v2.DeleteContextRequest, $root.google.protobuf.Empty, request, callback);
                        }, "name", { value: "DeleteContext" });
    
                        /**
                         * Calls DeleteContext.
                         * @function deleteContext
                         * @memberof google.cloud.dialogflow.v2.Contexts
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IDeleteContextRequest} request DeleteContextRequest message or plain object
                         * @returns {Promise<google.protobuf.Empty>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Contexts|deleteAllContexts}.
                         * @memberof google.cloud.dialogflow.v2.Contexts
                         * @typedef DeleteAllContextsCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.protobuf.Empty} [response] Empty
                         */
    
                        /**
                         * Calls DeleteAllContexts.
                         * @function deleteAllContexts
                         * @memberof google.cloud.dialogflow.v2.Contexts
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IDeleteAllContextsRequest} request DeleteAllContextsRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Contexts.DeleteAllContextsCallback} callback Node-style callback called with the error, if any, and Empty
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Contexts.prototype.deleteAllContexts = function deleteAllContexts(request, callback) {
                            return this.rpcCall(deleteAllContexts, $root.google.cloud.dialogflow.v2.DeleteAllContextsRequest, $root.google.protobuf.Empty, request, callback);
                        }, "name", { value: "DeleteAllContexts" });
    
                        /**
                         * Calls DeleteAllContexts.
                         * @function deleteAllContexts
                         * @memberof google.cloud.dialogflow.v2.Contexts
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IDeleteAllContextsRequest} request DeleteAllContextsRequest message or plain object
                         * @returns {Promise<google.protobuf.Empty>} Promise
                         * @variation 2
                         */
    
                        return Contexts;
                    })();
    
                    v2.Context = (function() {
    
                        /**
                         * Properties of a Context.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IContext
                         * @property {string|null} [name] Context name
                         * @property {number|null} [lifespanCount] Context lifespanCount
                         * @property {google.protobuf.IStruct|null} [parameters] Context parameters
                         */
    
                        /**
                         * Constructs a new Context.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a Context.
                         * @implements IContext
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IContext=} [properties] Properties to set
                         */
                        function Context(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * Context name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2.Context
                         * @instance
                         */
                        Context.prototype.name = "";
    
                        /**
                         * Context lifespanCount.
                         * @member {number} lifespanCount
                         * @memberof google.cloud.dialogflow.v2.Context
                         * @instance
                         */
                        Context.prototype.lifespanCount = 0;
    
                        /**
                         * Context parameters.
                         * @member {google.protobuf.IStruct|null|undefined} parameters
                         * @memberof google.cloud.dialogflow.v2.Context
                         * @instance
                         */
                        Context.prototype.parameters = null;
    
                        /**
                         * Creates a new Context instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.Context
                         * @static
                         * @param {google.cloud.dialogflow.v2.IContext=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.Context} Context instance
                         */
                        Context.create = function create(properties) {
                            return new Context(properties);
                        };
    
                        /**
                         * Encodes the specified Context message. Does not implicitly {@link google.cloud.dialogflow.v2.Context.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.Context
                         * @static
                         * @param {google.cloud.dialogflow.v2.IContext} message Context message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        Context.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            if (message.lifespanCount != null && Object.hasOwnProperty.call(message, "lifespanCount"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.lifespanCount);
                            if (message.parameters != null && Object.hasOwnProperty.call(message, "parameters"))
                                $root.google.protobuf.Struct.encode(message.parameters, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified Context message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.Context.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.Context
                         * @static
                         * @param {google.cloud.dialogflow.v2.IContext} message Context message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        Context.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a Context message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.Context
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.Context} Context
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        Context.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.Context();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.lifespanCount = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.parameters = $root.google.protobuf.Struct.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a Context message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.Context
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.Context} Context
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        Context.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a Context message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.Context
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        Context.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            if (message.lifespanCount != null && message.hasOwnProperty("lifespanCount"))
                                if (!$util.isInteger(message.lifespanCount))
                                    return "lifespanCount: integer expected";
                            if (message.parameters != null && message.hasOwnProperty("parameters")) {
                                var error = $root.google.protobuf.Struct.verify(message.parameters);
                                if (error)
                                    return "parameters." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a Context message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.Context
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.Context} Context
                         */
                        Context.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.Context)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.Context();
                            if (object.name != null)
                                message.name = String(object.name);
                            if (object.lifespanCount != null)
                                message.lifespanCount = object.lifespanCount | 0;
                            if (object.parameters != null) {
                                if (typeof object.parameters !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.Context.parameters: object expected");
                                message.parameters = $root.google.protobuf.Struct.fromObject(object.parameters);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a Context message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.Context
                         * @static
                         * @param {google.cloud.dialogflow.v2.Context} message Context
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        Context.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.name = "";
                                object.lifespanCount = 0;
                                object.parameters = null;
                            }
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            if (message.lifespanCount != null && message.hasOwnProperty("lifespanCount"))
                                object.lifespanCount = message.lifespanCount;
                            if (message.parameters != null && message.hasOwnProperty("parameters"))
                                object.parameters = $root.google.protobuf.Struct.toObject(message.parameters, options);
                            return object;
                        };
    
                        /**
                         * Converts this Context to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.Context
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        Context.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for Context
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.Context
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        Context.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.Context";
                        };
    
                        return Context;
                    })();
    
                    v2.ListContextsRequest = (function() {
    
                        /**
                         * Properties of a ListContextsRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IListContextsRequest
                         * @property {string|null} [parent] ListContextsRequest parent
                         * @property {number|null} [pageSize] ListContextsRequest pageSize
                         * @property {string|null} [pageToken] ListContextsRequest pageToken
                         */
    
                        /**
                         * Constructs a new ListContextsRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a ListContextsRequest.
                         * @implements IListContextsRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IListContextsRequest=} [properties] Properties to set
                         */
                        function ListContextsRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListContextsRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.ListContextsRequest
                         * @instance
                         */
                        ListContextsRequest.prototype.parent = "";
    
                        /**
                         * ListContextsRequest pageSize.
                         * @member {number} pageSize
                         * @memberof google.cloud.dialogflow.v2.ListContextsRequest
                         * @instance
                         */
                        ListContextsRequest.prototype.pageSize = 0;
    
                        /**
                         * ListContextsRequest pageToken.
                         * @member {string} pageToken
                         * @memberof google.cloud.dialogflow.v2.ListContextsRequest
                         * @instance
                         */
                        ListContextsRequest.prototype.pageToken = "";
    
                        /**
                         * Creates a new ListContextsRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ListContextsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListContextsRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ListContextsRequest} ListContextsRequest instance
                         */
                        ListContextsRequest.create = function create(properties) {
                            return new ListContextsRequest(properties);
                        };
    
                        /**
                         * Encodes the specified ListContextsRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.ListContextsRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ListContextsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListContextsRequest} message ListContextsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListContextsRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.pageSize != null && Object.hasOwnProperty.call(message, "pageSize"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.pageSize);
                            if (message.pageToken != null && Object.hasOwnProperty.call(message, "pageToken"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.pageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListContextsRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ListContextsRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListContextsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListContextsRequest} message ListContextsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListContextsRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListContextsRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ListContextsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ListContextsRequest} ListContextsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListContextsRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ListContextsRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.pageSize = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.pageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListContextsRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListContextsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ListContextsRequest} ListContextsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListContextsRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListContextsRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ListContextsRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListContextsRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                if (!$util.isInteger(message.pageSize))
                                    return "pageSize: integer expected";
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                if (!$util.isString(message.pageToken))
                                    return "pageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListContextsRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ListContextsRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ListContextsRequest} ListContextsRequest
                         */
                        ListContextsRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ListContextsRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ListContextsRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.pageSize != null)
                                message.pageSize = object.pageSize | 0;
                            if (object.pageToken != null)
                                message.pageToken = String(object.pageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListContextsRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ListContextsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ListContextsRequest} message ListContextsRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListContextsRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.pageSize = 0;
                                object.pageToken = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                object.pageSize = message.pageSize;
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                object.pageToken = message.pageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListContextsRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ListContextsRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListContextsRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListContextsRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ListContextsRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListContextsRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ListContextsRequest";
                        };
    
                        return ListContextsRequest;
                    })();
    
                    v2.ListContextsResponse = (function() {
    
                        /**
                         * Properties of a ListContextsResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IListContextsResponse
                         * @property {Array.<google.cloud.dialogflow.v2.IContext>|null} [contexts] ListContextsResponse contexts
                         * @property {string|null} [nextPageToken] ListContextsResponse nextPageToken
                         */
    
                        /**
                         * Constructs a new ListContextsResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a ListContextsResponse.
                         * @implements IListContextsResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IListContextsResponse=} [properties] Properties to set
                         */
                        function ListContextsResponse(properties) {
                            this.contexts = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListContextsResponse contexts.
                         * @member {Array.<google.cloud.dialogflow.v2.IContext>} contexts
                         * @memberof google.cloud.dialogflow.v2.ListContextsResponse
                         * @instance
                         */
                        ListContextsResponse.prototype.contexts = $util.emptyArray;
    
                        /**
                         * ListContextsResponse nextPageToken.
                         * @member {string} nextPageToken
                         * @memberof google.cloud.dialogflow.v2.ListContextsResponse
                         * @instance
                         */
                        ListContextsResponse.prototype.nextPageToken = "";
    
                        /**
                         * Creates a new ListContextsResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ListContextsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListContextsResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ListContextsResponse} ListContextsResponse instance
                         */
                        ListContextsResponse.create = function create(properties) {
                            return new ListContextsResponse(properties);
                        };
    
                        /**
                         * Encodes the specified ListContextsResponse message. Does not implicitly {@link google.cloud.dialogflow.v2.ListContextsResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ListContextsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListContextsResponse} message ListContextsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListContextsResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.contexts != null && message.contexts.length)
                                for (var i = 0; i < message.contexts.length; ++i)
                                    $root.google.cloud.dialogflow.v2.Context.encode(message.contexts[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.nextPageToken != null && Object.hasOwnProperty.call(message, "nextPageToken"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.nextPageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListContextsResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ListContextsResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListContextsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListContextsResponse} message ListContextsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListContextsResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListContextsResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ListContextsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ListContextsResponse} ListContextsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListContextsResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ListContextsResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.contexts && message.contexts.length))
                                            message.contexts = [];
                                        message.contexts.push($root.google.cloud.dialogflow.v2.Context.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 2: {
                                        message.nextPageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListContextsResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListContextsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ListContextsResponse} ListContextsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListContextsResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListContextsResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ListContextsResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListContextsResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.contexts != null && message.hasOwnProperty("contexts")) {
                                if (!Array.isArray(message.contexts))
                                    return "contexts: array expected";
                                for (var i = 0; i < message.contexts.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.Context.verify(message.contexts[i]);
                                    if (error)
                                        return "contexts." + error;
                                }
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                if (!$util.isString(message.nextPageToken))
                                    return "nextPageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListContextsResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ListContextsResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ListContextsResponse} ListContextsResponse
                         */
                        ListContextsResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ListContextsResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ListContextsResponse();
                            if (object.contexts) {
                                if (!Array.isArray(object.contexts))
                                    throw TypeError(".google.cloud.dialogflow.v2.ListContextsResponse.contexts: array expected");
                                message.contexts = [];
                                for (var i = 0; i < object.contexts.length; ++i) {
                                    if (typeof object.contexts[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.ListContextsResponse.contexts: object expected");
                                    message.contexts[i] = $root.google.cloud.dialogflow.v2.Context.fromObject(object.contexts[i]);
                                }
                            }
                            if (object.nextPageToken != null)
                                message.nextPageToken = String(object.nextPageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListContextsResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ListContextsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.ListContextsResponse} message ListContextsResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListContextsResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.contexts = [];
                            if (options.defaults)
                                object.nextPageToken = "";
                            if (message.contexts && message.contexts.length) {
                                object.contexts = [];
                                for (var j = 0; j < message.contexts.length; ++j)
                                    object.contexts[j] = $root.google.cloud.dialogflow.v2.Context.toObject(message.contexts[j], options);
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                object.nextPageToken = message.nextPageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListContextsResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ListContextsResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListContextsResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListContextsResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ListContextsResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListContextsResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ListContextsResponse";
                        };
    
                        return ListContextsResponse;
                    })();
    
                    v2.GetContextRequest = (function() {
    
                        /**
                         * Properties of a GetContextRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IGetContextRequest
                         * @property {string|null} [name] GetContextRequest name
                         */
    
                        /**
                         * Constructs a new GetContextRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a GetContextRequest.
                         * @implements IGetContextRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IGetContextRequest=} [properties] Properties to set
                         */
                        function GetContextRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GetContextRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2.GetContextRequest
                         * @instance
                         */
                        GetContextRequest.prototype.name = "";
    
                        /**
                         * Creates a new GetContextRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.GetContextRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetContextRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.GetContextRequest} GetContextRequest instance
                         */
                        GetContextRequest.create = function create(properties) {
                            return new GetContextRequest(properties);
                        };
    
                        /**
                         * Encodes the specified GetContextRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.GetContextRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.GetContextRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetContextRequest} message GetContextRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetContextRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GetContextRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.GetContextRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GetContextRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetContextRequest} message GetContextRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetContextRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GetContextRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.GetContextRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.GetContextRequest} GetContextRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetContextRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.GetContextRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GetContextRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GetContextRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.GetContextRequest} GetContextRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetContextRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GetContextRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.GetContextRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GetContextRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a GetContextRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.GetContextRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.GetContextRequest} GetContextRequest
                         */
                        GetContextRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.GetContextRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.GetContextRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GetContextRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.GetContextRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.GetContextRequest} message GetContextRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GetContextRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.name = "";
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            return object;
                        };
    
                        /**
                         * Converts this GetContextRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.GetContextRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GetContextRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GetContextRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.GetContextRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GetContextRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.GetContextRequest";
                        };
    
                        return GetContextRequest;
                    })();
    
                    v2.CreateContextRequest = (function() {
    
                        /**
                         * Properties of a CreateContextRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ICreateContextRequest
                         * @property {string|null} [parent] CreateContextRequest parent
                         * @property {google.cloud.dialogflow.v2.IContext|null} [context] CreateContextRequest context
                         */
    
                        /**
                         * Constructs a new CreateContextRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a CreateContextRequest.
                         * @implements ICreateContextRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ICreateContextRequest=} [properties] Properties to set
                         */
                        function CreateContextRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * CreateContextRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.CreateContextRequest
                         * @instance
                         */
                        CreateContextRequest.prototype.parent = "";
    
                        /**
                         * CreateContextRequest context.
                         * @member {google.cloud.dialogflow.v2.IContext|null|undefined} context
                         * @memberof google.cloud.dialogflow.v2.CreateContextRequest
                         * @instance
                         */
                        CreateContextRequest.prototype.context = null;
    
                        /**
                         * Creates a new CreateContextRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.CreateContextRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICreateContextRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.CreateContextRequest} CreateContextRequest instance
                         */
                        CreateContextRequest.create = function create(properties) {
                            return new CreateContextRequest(properties);
                        };
    
                        /**
                         * Encodes the specified CreateContextRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.CreateContextRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.CreateContextRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICreateContextRequest} message CreateContextRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateContextRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.context != null && Object.hasOwnProperty.call(message, "context"))
                                $root.google.cloud.dialogflow.v2.Context.encode(message.context, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified CreateContextRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.CreateContextRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.CreateContextRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICreateContextRequest} message CreateContextRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateContextRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a CreateContextRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.CreateContextRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.CreateContextRequest} CreateContextRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateContextRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.CreateContextRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.context = $root.google.cloud.dialogflow.v2.Context.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a CreateContextRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.CreateContextRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.CreateContextRequest} CreateContextRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateContextRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a CreateContextRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.CreateContextRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        CreateContextRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.context != null && message.hasOwnProperty("context")) {
                                var error = $root.google.cloud.dialogflow.v2.Context.verify(message.context);
                                if (error)
                                    return "context." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a CreateContextRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.CreateContextRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.CreateContextRequest} CreateContextRequest
                         */
                        CreateContextRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.CreateContextRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.CreateContextRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.context != null) {
                                if (typeof object.context !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.CreateContextRequest.context: object expected");
                                message.context = $root.google.cloud.dialogflow.v2.Context.fromObject(object.context);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a CreateContextRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.CreateContextRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.CreateContextRequest} message CreateContextRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        CreateContextRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.context = null;
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.context != null && message.hasOwnProperty("context"))
                                object.context = $root.google.cloud.dialogflow.v2.Context.toObject(message.context, options);
                            return object;
                        };
    
                        /**
                         * Converts this CreateContextRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.CreateContextRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        CreateContextRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for CreateContextRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.CreateContextRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        CreateContextRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.CreateContextRequest";
                        };
    
                        return CreateContextRequest;
                    })();
    
                    v2.UpdateContextRequest = (function() {
    
                        /**
                         * Properties of an UpdateContextRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IUpdateContextRequest
                         * @property {google.cloud.dialogflow.v2.IContext|null} [context] UpdateContextRequest context
                         * @property {google.protobuf.IFieldMask|null} [updateMask] UpdateContextRequest updateMask
                         */
    
                        /**
                         * Constructs a new UpdateContextRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an UpdateContextRequest.
                         * @implements IUpdateContextRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IUpdateContextRequest=} [properties] Properties to set
                         */
                        function UpdateContextRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * UpdateContextRequest context.
                         * @member {google.cloud.dialogflow.v2.IContext|null|undefined} context
                         * @memberof google.cloud.dialogflow.v2.UpdateContextRequest
                         * @instance
                         */
                        UpdateContextRequest.prototype.context = null;
    
                        /**
                         * UpdateContextRequest updateMask.
                         * @member {google.protobuf.IFieldMask|null|undefined} updateMask
                         * @memberof google.cloud.dialogflow.v2.UpdateContextRequest
                         * @instance
                         */
                        UpdateContextRequest.prototype.updateMask = null;
    
                        /**
                         * Creates a new UpdateContextRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.UpdateContextRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IUpdateContextRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.UpdateContextRequest} UpdateContextRequest instance
                         */
                        UpdateContextRequest.create = function create(properties) {
                            return new UpdateContextRequest(properties);
                        };
    
                        /**
                         * Encodes the specified UpdateContextRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.UpdateContextRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.UpdateContextRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IUpdateContextRequest} message UpdateContextRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UpdateContextRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.context != null && Object.hasOwnProperty.call(message, "context"))
                                $root.google.cloud.dialogflow.v2.Context.encode(message.context, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.updateMask != null && Object.hasOwnProperty.call(message, "updateMask"))
                                $root.google.protobuf.FieldMask.encode(message.updateMask, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified UpdateContextRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.UpdateContextRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.UpdateContextRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IUpdateContextRequest} message UpdateContextRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UpdateContextRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an UpdateContextRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.UpdateContextRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.UpdateContextRequest} UpdateContextRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UpdateContextRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.UpdateContextRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.context = $root.google.cloud.dialogflow.v2.Context.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.updateMask = $root.google.protobuf.FieldMask.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an UpdateContextRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.UpdateContextRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.UpdateContextRequest} UpdateContextRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UpdateContextRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an UpdateContextRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.UpdateContextRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        UpdateContextRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.context != null && message.hasOwnProperty("context")) {
                                var error = $root.google.cloud.dialogflow.v2.Context.verify(message.context);
                                if (error)
                                    return "context." + error;
                            }
                            if (message.updateMask != null && message.hasOwnProperty("updateMask")) {
                                var error = $root.google.protobuf.FieldMask.verify(message.updateMask);
                                if (error)
                                    return "updateMask." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates an UpdateContextRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.UpdateContextRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.UpdateContextRequest} UpdateContextRequest
                         */
                        UpdateContextRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.UpdateContextRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.UpdateContextRequest();
                            if (object.context != null) {
                                if (typeof object.context !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.UpdateContextRequest.context: object expected");
                                message.context = $root.google.cloud.dialogflow.v2.Context.fromObject(object.context);
                            }
                            if (object.updateMask != null) {
                                if (typeof object.updateMask !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.UpdateContextRequest.updateMask: object expected");
                                message.updateMask = $root.google.protobuf.FieldMask.fromObject(object.updateMask);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an UpdateContextRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.UpdateContextRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.UpdateContextRequest} message UpdateContextRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        UpdateContextRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.context = null;
                                object.updateMask = null;
                            }
                            if (message.context != null && message.hasOwnProperty("context"))
                                object.context = $root.google.cloud.dialogflow.v2.Context.toObject(message.context, options);
                            if (message.updateMask != null && message.hasOwnProperty("updateMask"))
                                object.updateMask = $root.google.protobuf.FieldMask.toObject(message.updateMask, options);
                            return object;
                        };
    
                        /**
                         * Converts this UpdateContextRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.UpdateContextRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        UpdateContextRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for UpdateContextRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.UpdateContextRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        UpdateContextRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.UpdateContextRequest";
                        };
    
                        return UpdateContextRequest;
                    })();
    
                    v2.DeleteContextRequest = (function() {
    
                        /**
                         * Properties of a DeleteContextRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IDeleteContextRequest
                         * @property {string|null} [name] DeleteContextRequest name
                         */
    
                        /**
                         * Constructs a new DeleteContextRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a DeleteContextRequest.
                         * @implements IDeleteContextRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IDeleteContextRequest=} [properties] Properties to set
                         */
                        function DeleteContextRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * DeleteContextRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2.DeleteContextRequest
                         * @instance
                         */
                        DeleteContextRequest.prototype.name = "";
    
                        /**
                         * Creates a new DeleteContextRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.DeleteContextRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDeleteContextRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.DeleteContextRequest} DeleteContextRequest instance
                         */
                        DeleteContextRequest.create = function create(properties) {
                            return new DeleteContextRequest(properties);
                        };
    
                        /**
                         * Encodes the specified DeleteContextRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.DeleteContextRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.DeleteContextRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDeleteContextRequest} message DeleteContextRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteContextRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified DeleteContextRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.DeleteContextRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.DeleteContextRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDeleteContextRequest} message DeleteContextRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteContextRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a DeleteContextRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.DeleteContextRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.DeleteContextRequest} DeleteContextRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteContextRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.DeleteContextRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a DeleteContextRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.DeleteContextRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.DeleteContextRequest} DeleteContextRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteContextRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a DeleteContextRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.DeleteContextRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        DeleteContextRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a DeleteContextRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.DeleteContextRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.DeleteContextRequest} DeleteContextRequest
                         */
                        DeleteContextRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.DeleteContextRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.DeleteContextRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a DeleteContextRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.DeleteContextRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.DeleteContextRequest} message DeleteContextRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        DeleteContextRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.name = "";
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            return object;
                        };
    
                        /**
                         * Converts this DeleteContextRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.DeleteContextRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        DeleteContextRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for DeleteContextRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.DeleteContextRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        DeleteContextRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.DeleteContextRequest";
                        };
    
                        return DeleteContextRequest;
                    })();
    
                    v2.DeleteAllContextsRequest = (function() {
    
                        /**
                         * Properties of a DeleteAllContextsRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IDeleteAllContextsRequest
                         * @property {string|null} [parent] DeleteAllContextsRequest parent
                         */
    
                        /**
                         * Constructs a new DeleteAllContextsRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a DeleteAllContextsRequest.
                         * @implements IDeleteAllContextsRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IDeleteAllContextsRequest=} [properties] Properties to set
                         */
                        function DeleteAllContextsRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * DeleteAllContextsRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.DeleteAllContextsRequest
                         * @instance
                         */
                        DeleteAllContextsRequest.prototype.parent = "";
    
                        /**
                         * Creates a new DeleteAllContextsRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.DeleteAllContextsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDeleteAllContextsRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.DeleteAllContextsRequest} DeleteAllContextsRequest instance
                         */
                        DeleteAllContextsRequest.create = function create(properties) {
                            return new DeleteAllContextsRequest(properties);
                        };
    
                        /**
                         * Encodes the specified DeleteAllContextsRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.DeleteAllContextsRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.DeleteAllContextsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDeleteAllContextsRequest} message DeleteAllContextsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteAllContextsRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified DeleteAllContextsRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.DeleteAllContextsRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.DeleteAllContextsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDeleteAllContextsRequest} message DeleteAllContextsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteAllContextsRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a DeleteAllContextsRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.DeleteAllContextsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.DeleteAllContextsRequest} DeleteAllContextsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteAllContextsRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.DeleteAllContextsRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a DeleteAllContextsRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.DeleteAllContextsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.DeleteAllContextsRequest} DeleteAllContextsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteAllContextsRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a DeleteAllContextsRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.DeleteAllContextsRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        DeleteAllContextsRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a DeleteAllContextsRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.DeleteAllContextsRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.DeleteAllContextsRequest} DeleteAllContextsRequest
                         */
                        DeleteAllContextsRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.DeleteAllContextsRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.DeleteAllContextsRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a DeleteAllContextsRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.DeleteAllContextsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.DeleteAllContextsRequest} message DeleteAllContextsRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        DeleteAllContextsRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.parent = "";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            return object;
                        };
    
                        /**
                         * Converts this DeleteAllContextsRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.DeleteAllContextsRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        DeleteAllContextsRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for DeleteAllContextsRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.DeleteAllContextsRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        DeleteAllContextsRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.DeleteAllContextsRequest";
                        };
    
                        return DeleteAllContextsRequest;
                    })();
    
                    v2.Intents = (function() {
    
                        /**
                         * Constructs a new Intents service.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an Intents
                         * @extends $protobuf.rpc.Service
                         * @constructor
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         */
                        function Intents(rpcImpl, requestDelimited, responseDelimited) {
                            $protobuf.rpc.Service.call(this, rpcImpl, requestDelimited, responseDelimited);
                        }
    
                        (Intents.prototype = Object.create($protobuf.rpc.Service.prototype)).constructor = Intents;
    
                        /**
                         * Creates new Intents service using the specified rpc implementation.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.Intents
                         * @static
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         * @returns {Intents} RPC service. Useful where requests and/or responses are streamed.
                         */
                        Intents.create = function create(rpcImpl, requestDelimited, responseDelimited) {
                            return new this(rpcImpl, requestDelimited, responseDelimited);
                        };
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Intents|listIntents}.
                         * @memberof google.cloud.dialogflow.v2.Intents
                         * @typedef ListIntentsCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.ListIntentsResponse} [response] ListIntentsResponse
                         */
    
                        /**
                         * Calls ListIntents.
                         * @function listIntents
                         * @memberof google.cloud.dialogflow.v2.Intents
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IListIntentsRequest} request ListIntentsRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Intents.ListIntentsCallback} callback Node-style callback called with the error, if any, and ListIntentsResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Intents.prototype.listIntents = function listIntents(request, callback) {
                            return this.rpcCall(listIntents, $root.google.cloud.dialogflow.v2.ListIntentsRequest, $root.google.cloud.dialogflow.v2.ListIntentsResponse, request, callback);
                        }, "name", { value: "ListIntents" });
    
                        /**
                         * Calls ListIntents.
                         * @function listIntents
                         * @memberof google.cloud.dialogflow.v2.Intents
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IListIntentsRequest} request ListIntentsRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.ListIntentsResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Intents|getIntent}.
                         * @memberof google.cloud.dialogflow.v2.Intents
                         * @typedef GetIntentCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.Intent} [response] Intent
                         */
    
                        /**
                         * Calls GetIntent.
                         * @function getIntent
                         * @memberof google.cloud.dialogflow.v2.Intents
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IGetIntentRequest} request GetIntentRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Intents.GetIntentCallback} callback Node-style callback called with the error, if any, and Intent
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Intents.prototype.getIntent = function getIntent(request, callback) {
                            return this.rpcCall(getIntent, $root.google.cloud.dialogflow.v2.GetIntentRequest, $root.google.cloud.dialogflow.v2.Intent, request, callback);
                        }, "name", { value: "GetIntent" });
    
                        /**
                         * Calls GetIntent.
                         * @function getIntent
                         * @memberof google.cloud.dialogflow.v2.Intents
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IGetIntentRequest} request GetIntentRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.Intent>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Intents|createIntent}.
                         * @memberof google.cloud.dialogflow.v2.Intents
                         * @typedef CreateIntentCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.Intent} [response] Intent
                         */
    
                        /**
                         * Calls CreateIntent.
                         * @function createIntent
                         * @memberof google.cloud.dialogflow.v2.Intents
                         * @instance
                         * @param {google.cloud.dialogflow.v2.ICreateIntentRequest} request CreateIntentRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Intents.CreateIntentCallback} callback Node-style callback called with the error, if any, and Intent
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Intents.prototype.createIntent = function createIntent(request, callback) {
                            return this.rpcCall(createIntent, $root.google.cloud.dialogflow.v2.CreateIntentRequest, $root.google.cloud.dialogflow.v2.Intent, request, callback);
                        }, "name", { value: "CreateIntent" });
    
                        /**
                         * Calls CreateIntent.
                         * @function createIntent
                         * @memberof google.cloud.dialogflow.v2.Intents
                         * @instance
                         * @param {google.cloud.dialogflow.v2.ICreateIntentRequest} request CreateIntentRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.Intent>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Intents|updateIntent}.
                         * @memberof google.cloud.dialogflow.v2.Intents
                         * @typedef UpdateIntentCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.Intent} [response] Intent
                         */
    
                        /**
                         * Calls UpdateIntent.
                         * @function updateIntent
                         * @memberof google.cloud.dialogflow.v2.Intents
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IUpdateIntentRequest} request UpdateIntentRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Intents.UpdateIntentCallback} callback Node-style callback called with the error, if any, and Intent
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Intents.prototype.updateIntent = function updateIntent(request, callback) {
                            return this.rpcCall(updateIntent, $root.google.cloud.dialogflow.v2.UpdateIntentRequest, $root.google.cloud.dialogflow.v2.Intent, request, callback);
                        }, "name", { value: "UpdateIntent" });
    
                        /**
                         * Calls UpdateIntent.
                         * @function updateIntent
                         * @memberof google.cloud.dialogflow.v2.Intents
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IUpdateIntentRequest} request UpdateIntentRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.Intent>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Intents|deleteIntent}.
                         * @memberof google.cloud.dialogflow.v2.Intents
                         * @typedef DeleteIntentCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.protobuf.Empty} [response] Empty
                         */
    
                        /**
                         * Calls DeleteIntent.
                         * @function deleteIntent
                         * @memberof google.cloud.dialogflow.v2.Intents
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IDeleteIntentRequest} request DeleteIntentRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Intents.DeleteIntentCallback} callback Node-style callback called with the error, if any, and Empty
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Intents.prototype.deleteIntent = function deleteIntent(request, callback) {
                            return this.rpcCall(deleteIntent, $root.google.cloud.dialogflow.v2.DeleteIntentRequest, $root.google.protobuf.Empty, request, callback);
                        }, "name", { value: "DeleteIntent" });
    
                        /**
                         * Calls DeleteIntent.
                         * @function deleteIntent
                         * @memberof google.cloud.dialogflow.v2.Intents
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IDeleteIntentRequest} request DeleteIntentRequest message or plain object
                         * @returns {Promise<google.protobuf.Empty>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Intents|batchUpdateIntents}.
                         * @memberof google.cloud.dialogflow.v2.Intents
                         * @typedef BatchUpdateIntentsCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.longrunning.Operation} [response] Operation
                         */
    
                        /**
                         * Calls BatchUpdateIntents.
                         * @function batchUpdateIntents
                         * @memberof google.cloud.dialogflow.v2.Intents
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IBatchUpdateIntentsRequest} request BatchUpdateIntentsRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Intents.BatchUpdateIntentsCallback} callback Node-style callback called with the error, if any, and Operation
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Intents.prototype.batchUpdateIntents = function batchUpdateIntents(request, callback) {
                            return this.rpcCall(batchUpdateIntents, $root.google.cloud.dialogflow.v2.BatchUpdateIntentsRequest, $root.google.longrunning.Operation, request, callback);
                        }, "name", { value: "BatchUpdateIntents" });
    
                        /**
                         * Calls BatchUpdateIntents.
                         * @function batchUpdateIntents
                         * @memberof google.cloud.dialogflow.v2.Intents
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IBatchUpdateIntentsRequest} request BatchUpdateIntentsRequest message or plain object
                         * @returns {Promise<google.longrunning.Operation>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Intents|batchDeleteIntents}.
                         * @memberof google.cloud.dialogflow.v2.Intents
                         * @typedef BatchDeleteIntentsCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.longrunning.Operation} [response] Operation
                         */
    
                        /**
                         * Calls BatchDeleteIntents.
                         * @function batchDeleteIntents
                         * @memberof google.cloud.dialogflow.v2.Intents
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IBatchDeleteIntentsRequest} request BatchDeleteIntentsRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Intents.BatchDeleteIntentsCallback} callback Node-style callback called with the error, if any, and Operation
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Intents.prototype.batchDeleteIntents = function batchDeleteIntents(request, callback) {
                            return this.rpcCall(batchDeleteIntents, $root.google.cloud.dialogflow.v2.BatchDeleteIntentsRequest, $root.google.longrunning.Operation, request, callback);
                        }, "name", { value: "BatchDeleteIntents" });
    
                        /**
                         * Calls BatchDeleteIntents.
                         * @function batchDeleteIntents
                         * @memberof google.cloud.dialogflow.v2.Intents
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IBatchDeleteIntentsRequest} request BatchDeleteIntentsRequest message or plain object
                         * @returns {Promise<google.longrunning.Operation>} Promise
                         * @variation 2
                         */
    
                        return Intents;
                    })();
    
                    v2.Intent = (function() {
    
                        /**
                         * Properties of an Intent.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IIntent
                         * @property {string|null} [name] Intent name
                         * @property {string|null} [displayName] Intent displayName
                         * @property {google.cloud.dialogflow.v2.Intent.WebhookState|null} [webhookState] Intent webhookState
                         * @property {number|null} [priority] Intent priority
                         * @property {boolean|null} [isFallback] Intent isFallback
                         * @property {boolean|null} [mlDisabled] Intent mlDisabled
                         * @property {boolean|null} [liveAgentHandoff] Intent liveAgentHandoff
                         * @property {boolean|null} [endInteraction] Intent endInteraction
                         * @property {Array.<string>|null} [inputContextNames] Intent inputContextNames
                         * @property {Array.<string>|null} [events] Intent events
                         * @property {Array.<google.cloud.dialogflow.v2.Intent.ITrainingPhrase>|null} [trainingPhrases] Intent trainingPhrases
                         * @property {string|null} [action] Intent action
                         * @property {Array.<google.cloud.dialogflow.v2.IContext>|null} [outputContexts] Intent outputContexts
                         * @property {boolean|null} [resetContexts] Intent resetContexts
                         * @property {Array.<google.cloud.dialogflow.v2.Intent.IParameter>|null} [parameters] Intent parameters
                         * @property {Array.<google.cloud.dialogflow.v2.Intent.IMessage>|null} [messages] Intent messages
                         * @property {Array.<google.cloud.dialogflow.v2.Intent.Message.Platform>|null} [defaultResponsePlatforms] Intent defaultResponsePlatforms
                         * @property {string|null} [rootFollowupIntentName] Intent rootFollowupIntentName
                         * @property {string|null} [parentFollowupIntentName] Intent parentFollowupIntentName
                         * @property {Array.<google.cloud.dialogflow.v2.Intent.IFollowupIntentInfo>|null} [followupIntentInfo] Intent followupIntentInfo
                         */
    
                        /**
                         * Constructs a new Intent.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an Intent.
                         * @implements IIntent
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IIntent=} [properties] Properties to set
                         */
                        function Intent(properties) {
                            this.inputContextNames = [];
                            this.events = [];
                            this.trainingPhrases = [];
                            this.outputContexts = [];
                            this.parameters = [];
                            this.messages = [];
                            this.defaultResponsePlatforms = [];
                            this.followupIntentInfo = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * Intent name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2.Intent
                         * @instance
                         */
                        Intent.prototype.name = "";
    
                        /**
                         * Intent displayName.
                         * @member {string} displayName
                         * @memberof google.cloud.dialogflow.v2.Intent
                         * @instance
                         */
                        Intent.prototype.displayName = "";
    
                        /**
                         * Intent webhookState.
                         * @member {google.cloud.dialogflow.v2.Intent.WebhookState} webhookState
                         * @memberof google.cloud.dialogflow.v2.Intent
                         * @instance
                         */
                        Intent.prototype.webhookState = 0;
    
                        /**
                         * Intent priority.
                         * @member {number} priority
                         * @memberof google.cloud.dialogflow.v2.Intent
                         * @instance
                         */
                        Intent.prototype.priority = 0;
    
                        /**
                         * Intent isFallback.
                         * @member {boolean} isFallback
                         * @memberof google.cloud.dialogflow.v2.Intent
                         * @instance
                         */
                        Intent.prototype.isFallback = false;
    
                        /**
                         * Intent mlDisabled.
                         * @member {boolean} mlDisabled
                         * @memberof google.cloud.dialogflow.v2.Intent
                         * @instance
                         */
                        Intent.prototype.mlDisabled = false;
    
                        /**
                         * Intent liveAgentHandoff.
                         * @member {boolean} liveAgentHandoff
                         * @memberof google.cloud.dialogflow.v2.Intent
                         * @instance
                         */
                        Intent.prototype.liveAgentHandoff = false;
    
                        /**
                         * Intent endInteraction.
                         * @member {boolean} endInteraction
                         * @memberof google.cloud.dialogflow.v2.Intent
                         * @instance
                         */
                        Intent.prototype.endInteraction = false;
    
                        /**
                         * Intent inputContextNames.
                         * @member {Array.<string>} inputContextNames
                         * @memberof google.cloud.dialogflow.v2.Intent
                         * @instance
                         */
                        Intent.prototype.inputContextNames = $util.emptyArray;
    
                        /**
                         * Intent events.
                         * @member {Array.<string>} events
                         * @memberof google.cloud.dialogflow.v2.Intent
                         * @instance
                         */
                        Intent.prototype.events = $util.emptyArray;
    
                        /**
                         * Intent trainingPhrases.
                         * @member {Array.<google.cloud.dialogflow.v2.Intent.ITrainingPhrase>} trainingPhrases
                         * @memberof google.cloud.dialogflow.v2.Intent
                         * @instance
                         */
                        Intent.prototype.trainingPhrases = $util.emptyArray;
    
                        /**
                         * Intent action.
                         * @member {string} action
                         * @memberof google.cloud.dialogflow.v2.Intent
                         * @instance
                         */
                        Intent.prototype.action = "";
    
                        /**
                         * Intent outputContexts.
                         * @member {Array.<google.cloud.dialogflow.v2.IContext>} outputContexts
                         * @memberof google.cloud.dialogflow.v2.Intent
                         * @instance
                         */
                        Intent.prototype.outputContexts = $util.emptyArray;
    
                        /**
                         * Intent resetContexts.
                         * @member {boolean} resetContexts
                         * @memberof google.cloud.dialogflow.v2.Intent
                         * @instance
                         */
                        Intent.prototype.resetContexts = false;
    
                        /**
                         * Intent parameters.
                         * @member {Array.<google.cloud.dialogflow.v2.Intent.IParameter>} parameters
                         * @memberof google.cloud.dialogflow.v2.Intent
                         * @instance
                         */
                        Intent.prototype.parameters = $util.emptyArray;
    
                        /**
                         * Intent messages.
                         * @member {Array.<google.cloud.dialogflow.v2.Intent.IMessage>} messages
                         * @memberof google.cloud.dialogflow.v2.Intent
                         * @instance
                         */
                        Intent.prototype.messages = $util.emptyArray;
    
                        /**
                         * Intent defaultResponsePlatforms.
                         * @member {Array.<google.cloud.dialogflow.v2.Intent.Message.Platform>} defaultResponsePlatforms
                         * @memberof google.cloud.dialogflow.v2.Intent
                         * @instance
                         */
                        Intent.prototype.defaultResponsePlatforms = $util.emptyArray;
    
                        /**
                         * Intent rootFollowupIntentName.
                         * @member {string} rootFollowupIntentName
                         * @memberof google.cloud.dialogflow.v2.Intent
                         * @instance
                         */
                        Intent.prototype.rootFollowupIntentName = "";
    
                        /**
                         * Intent parentFollowupIntentName.
                         * @member {string} parentFollowupIntentName
                         * @memberof google.cloud.dialogflow.v2.Intent
                         * @instance
                         */
                        Intent.prototype.parentFollowupIntentName = "";
    
                        /**
                         * Intent followupIntentInfo.
                         * @member {Array.<google.cloud.dialogflow.v2.Intent.IFollowupIntentInfo>} followupIntentInfo
                         * @memberof google.cloud.dialogflow.v2.Intent
                         * @instance
                         */
                        Intent.prototype.followupIntentInfo = $util.emptyArray;
    
                        /**
                         * Creates a new Intent instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.Intent
                         * @static
                         * @param {google.cloud.dialogflow.v2.IIntent=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.Intent} Intent instance
                         */
                        Intent.create = function create(properties) {
                            return new Intent(properties);
                        };
    
                        /**
                         * Encodes the specified Intent message. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.Intent
                         * @static
                         * @param {google.cloud.dialogflow.v2.IIntent} message Intent message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        Intent.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            if (message.displayName != null && Object.hasOwnProperty.call(message, "displayName"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.displayName);
                            if (message.priority != null && Object.hasOwnProperty.call(message, "priority"))
                                writer.uint32(/* id 3, wireType 0 =*/24).int32(message.priority);
                            if (message.isFallback != null && Object.hasOwnProperty.call(message, "isFallback"))
                                writer.uint32(/* id 4, wireType 0 =*/32).bool(message.isFallback);
                            if (message.webhookState != null && Object.hasOwnProperty.call(message, "webhookState"))
                                writer.uint32(/* id 6, wireType 0 =*/48).int32(message.webhookState);
                            if (message.inputContextNames != null && message.inputContextNames.length)
                                for (var i = 0; i < message.inputContextNames.length; ++i)
                                    writer.uint32(/* id 7, wireType 2 =*/58).string(message.inputContextNames[i]);
                            if (message.events != null && message.events.length)
                                for (var i = 0; i < message.events.length; ++i)
                                    writer.uint32(/* id 8, wireType 2 =*/66).string(message.events[i]);
                            if (message.trainingPhrases != null && message.trainingPhrases.length)
                                for (var i = 0; i < message.trainingPhrases.length; ++i)
                                    $root.google.cloud.dialogflow.v2.Intent.TrainingPhrase.encode(message.trainingPhrases[i], writer.uint32(/* id 9, wireType 2 =*/74).fork()).ldelim();
                            if (message.action != null && Object.hasOwnProperty.call(message, "action"))
                                writer.uint32(/* id 10, wireType 2 =*/82).string(message.action);
                            if (message.outputContexts != null && message.outputContexts.length)
                                for (var i = 0; i < message.outputContexts.length; ++i)
                                    $root.google.cloud.dialogflow.v2.Context.encode(message.outputContexts[i], writer.uint32(/* id 11, wireType 2 =*/90).fork()).ldelim();
                            if (message.resetContexts != null && Object.hasOwnProperty.call(message, "resetContexts"))
                                writer.uint32(/* id 12, wireType 0 =*/96).bool(message.resetContexts);
                            if (message.parameters != null && message.parameters.length)
                                for (var i = 0; i < message.parameters.length; ++i)
                                    $root.google.cloud.dialogflow.v2.Intent.Parameter.encode(message.parameters[i], writer.uint32(/* id 13, wireType 2 =*/106).fork()).ldelim();
                            if (message.messages != null && message.messages.length)
                                for (var i = 0; i < message.messages.length; ++i)
                                    $root.google.cloud.dialogflow.v2.Intent.Message.encode(message.messages[i], writer.uint32(/* id 14, wireType 2 =*/114).fork()).ldelim();
                            if (message.defaultResponsePlatforms != null && message.defaultResponsePlatforms.length) {
                                writer.uint32(/* id 15, wireType 2 =*/122).fork();
                                for (var i = 0; i < message.defaultResponsePlatforms.length; ++i)
                                    writer.int32(message.defaultResponsePlatforms[i]);
                                writer.ldelim();
                            }
                            if (message.rootFollowupIntentName != null && Object.hasOwnProperty.call(message, "rootFollowupIntentName"))
                                writer.uint32(/* id 16, wireType 2 =*/130).string(message.rootFollowupIntentName);
                            if (message.parentFollowupIntentName != null && Object.hasOwnProperty.call(message, "parentFollowupIntentName"))
                                writer.uint32(/* id 17, wireType 2 =*/138).string(message.parentFollowupIntentName);
                            if (message.followupIntentInfo != null && message.followupIntentInfo.length)
                                for (var i = 0; i < message.followupIntentInfo.length; ++i)
                                    $root.google.cloud.dialogflow.v2.Intent.FollowupIntentInfo.encode(message.followupIntentInfo[i], writer.uint32(/* id 18, wireType 2 =*/146).fork()).ldelim();
                            if (message.mlDisabled != null && Object.hasOwnProperty.call(message, "mlDisabled"))
                                writer.uint32(/* id 19, wireType 0 =*/152).bool(message.mlDisabled);
                            if (message.liveAgentHandoff != null && Object.hasOwnProperty.call(message, "liveAgentHandoff"))
                                writer.uint32(/* id 20, wireType 0 =*/160).bool(message.liveAgentHandoff);
                            if (message.endInteraction != null && Object.hasOwnProperty.call(message, "endInteraction"))
                                writer.uint32(/* id 21, wireType 0 =*/168).bool(message.endInteraction);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified Intent message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.Intent
                         * @static
                         * @param {google.cloud.dialogflow.v2.IIntent} message Intent message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        Intent.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an Intent message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.Intent
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.Intent} Intent
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        Intent.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.Intent();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.displayName = reader.string();
                                        break;
                                    }
                                case 6: {
                                        message.webhookState = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.priority = reader.int32();
                                        break;
                                    }
                                case 4: {
                                        message.isFallback = reader.bool();
                                        break;
                                    }
                                case 19: {
                                        message.mlDisabled = reader.bool();
                                        break;
                                    }
                                case 20: {
                                        message.liveAgentHandoff = reader.bool();
                                        break;
                                    }
                                case 21: {
                                        message.endInteraction = reader.bool();
                                        break;
                                    }
                                case 7: {
                                        if (!(message.inputContextNames && message.inputContextNames.length))
                                            message.inputContextNames = [];
                                        message.inputContextNames.push(reader.string());
                                        break;
                                    }
                                case 8: {
                                        if (!(message.events && message.events.length))
                                            message.events = [];
                                        message.events.push(reader.string());
                                        break;
                                    }
                                case 9: {
                                        if (!(message.trainingPhrases && message.trainingPhrases.length))
                                            message.trainingPhrases = [];
                                        message.trainingPhrases.push($root.google.cloud.dialogflow.v2.Intent.TrainingPhrase.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 10: {
                                        message.action = reader.string();
                                        break;
                                    }
                                case 11: {
                                        if (!(message.outputContexts && message.outputContexts.length))
                                            message.outputContexts = [];
                                        message.outputContexts.push($root.google.cloud.dialogflow.v2.Context.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 12: {
                                        message.resetContexts = reader.bool();
                                        break;
                                    }
                                case 13: {
                                        if (!(message.parameters && message.parameters.length))
                                            message.parameters = [];
                                        message.parameters.push($root.google.cloud.dialogflow.v2.Intent.Parameter.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 14: {
                                        if (!(message.messages && message.messages.length))
                                            message.messages = [];
                                        message.messages.push($root.google.cloud.dialogflow.v2.Intent.Message.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 15: {
                                        if (!(message.defaultResponsePlatforms && message.defaultResponsePlatforms.length))
                                            message.defaultResponsePlatforms = [];
                                        if ((tag & 7) === 2) {
                                            var end2 = reader.uint32() + reader.pos;
                                            while (reader.pos < end2)
                                                message.defaultResponsePlatforms.push(reader.int32());
                                        } else
                                            message.defaultResponsePlatforms.push(reader.int32());
                                        break;
                                    }
                                case 16: {
                                        message.rootFollowupIntentName = reader.string();
                                        break;
                                    }
                                case 17: {
                                        message.parentFollowupIntentName = reader.string();
                                        break;
                                    }
                                case 18: {
                                        if (!(message.followupIntentInfo && message.followupIntentInfo.length))
                                            message.followupIntentInfo = [];
                                        message.followupIntentInfo.push($root.google.cloud.dialogflow.v2.Intent.FollowupIntentInfo.decode(reader, reader.uint32()));
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an Intent message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.Intent
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.Intent} Intent
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        Intent.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an Intent message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.Intent
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        Intent.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            if (message.displayName != null && message.hasOwnProperty("displayName"))
                                if (!$util.isString(message.displayName))
                                    return "displayName: string expected";
                            if (message.webhookState != null && message.hasOwnProperty("webhookState"))
                                switch (message.webhookState) {
                                default:
                                    return "webhookState: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                    break;
                                }
                            if (message.priority != null && message.hasOwnProperty("priority"))
                                if (!$util.isInteger(message.priority))
                                    return "priority: integer expected";
                            if (message.isFallback != null && message.hasOwnProperty("isFallback"))
                                if (typeof message.isFallback !== "boolean")
                                    return "isFallback: boolean expected";
                            if (message.mlDisabled != null && message.hasOwnProperty("mlDisabled"))
                                if (typeof message.mlDisabled !== "boolean")
                                    return "mlDisabled: boolean expected";
                            if (message.liveAgentHandoff != null && message.hasOwnProperty("liveAgentHandoff"))
                                if (typeof message.liveAgentHandoff !== "boolean")
                                    return "liveAgentHandoff: boolean expected";
                            if (message.endInteraction != null && message.hasOwnProperty("endInteraction"))
                                if (typeof message.endInteraction !== "boolean")
                                    return "endInteraction: boolean expected";
                            if (message.inputContextNames != null && message.hasOwnProperty("inputContextNames")) {
                                if (!Array.isArray(message.inputContextNames))
                                    return "inputContextNames: array expected";
                                for (var i = 0; i < message.inputContextNames.length; ++i)
                                    if (!$util.isString(message.inputContextNames[i]))
                                        return "inputContextNames: string[] expected";
                            }
                            if (message.events != null && message.hasOwnProperty("events")) {
                                if (!Array.isArray(message.events))
                                    return "events: array expected";
                                for (var i = 0; i < message.events.length; ++i)
                                    if (!$util.isString(message.events[i]))
                                        return "events: string[] expected";
                            }
                            if (message.trainingPhrases != null && message.hasOwnProperty("trainingPhrases")) {
                                if (!Array.isArray(message.trainingPhrases))
                                    return "trainingPhrases: array expected";
                                for (var i = 0; i < message.trainingPhrases.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.Intent.TrainingPhrase.verify(message.trainingPhrases[i]);
                                    if (error)
                                        return "trainingPhrases." + error;
                                }
                            }
                            if (message.action != null && message.hasOwnProperty("action"))
                                if (!$util.isString(message.action))
                                    return "action: string expected";
                            if (message.outputContexts != null && message.hasOwnProperty("outputContexts")) {
                                if (!Array.isArray(message.outputContexts))
                                    return "outputContexts: array expected";
                                for (var i = 0; i < message.outputContexts.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.Context.verify(message.outputContexts[i]);
                                    if (error)
                                        return "outputContexts." + error;
                                }
                            }
                            if (message.resetContexts != null && message.hasOwnProperty("resetContexts"))
                                if (typeof message.resetContexts !== "boolean")
                                    return "resetContexts: boolean expected";
                            if (message.parameters != null && message.hasOwnProperty("parameters")) {
                                if (!Array.isArray(message.parameters))
                                    return "parameters: array expected";
                                for (var i = 0; i < message.parameters.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.Intent.Parameter.verify(message.parameters[i]);
                                    if (error)
                                        return "parameters." + error;
                                }
                            }
                            if (message.messages != null && message.hasOwnProperty("messages")) {
                                if (!Array.isArray(message.messages))
                                    return "messages: array expected";
                                for (var i = 0; i < message.messages.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.Intent.Message.verify(message.messages[i]);
                                    if (error)
                                        return "messages." + error;
                                }
                            }
                            if (message.defaultResponsePlatforms != null && message.hasOwnProperty("defaultResponsePlatforms")) {
                                if (!Array.isArray(message.defaultResponsePlatforms))
                                    return "defaultResponsePlatforms: array expected";
                                for (var i = 0; i < message.defaultResponsePlatforms.length; ++i)
                                    switch (message.defaultResponsePlatforms[i]) {
                                    default:
                                        return "defaultResponsePlatforms: enum value[] expected";
                                    case 0:
                                    case 1:
                                    case 2:
                                    case 3:
                                    case 4:
                                    case 5:
                                    case 6:
                                    case 7:
                                    case 8:
                                    case 11:
                                        break;
                                    }
                            }
                            if (message.rootFollowupIntentName != null && message.hasOwnProperty("rootFollowupIntentName"))
                                if (!$util.isString(message.rootFollowupIntentName))
                                    return "rootFollowupIntentName: string expected";
                            if (message.parentFollowupIntentName != null && message.hasOwnProperty("parentFollowupIntentName"))
                                if (!$util.isString(message.parentFollowupIntentName))
                                    return "parentFollowupIntentName: string expected";
                            if (message.followupIntentInfo != null && message.hasOwnProperty("followupIntentInfo")) {
                                if (!Array.isArray(message.followupIntentInfo))
                                    return "followupIntentInfo: array expected";
                                for (var i = 0; i < message.followupIntentInfo.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.Intent.FollowupIntentInfo.verify(message.followupIntentInfo[i]);
                                    if (error)
                                        return "followupIntentInfo." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates an Intent message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.Intent
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.Intent} Intent
                         */
                        Intent.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.Intent)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.Intent();
                            if (object.name != null)
                                message.name = String(object.name);
                            if (object.displayName != null)
                                message.displayName = String(object.displayName);
                            switch (object.webhookState) {
                            default:
                                if (typeof object.webhookState === "number") {
                                    message.webhookState = object.webhookState;
                                    break;
                                }
                                break;
                            case "WEBHOOK_STATE_UNSPECIFIED":
                            case 0:
                                message.webhookState = 0;
                                break;
                            case "WEBHOOK_STATE_ENABLED":
                            case 1:
                                message.webhookState = 1;
                                break;
                            case "WEBHOOK_STATE_ENABLED_FOR_SLOT_FILLING":
                            case 2:
                                message.webhookState = 2;
                                break;
                            }
                            if (object.priority != null)
                                message.priority = object.priority | 0;
                            if (object.isFallback != null)
                                message.isFallback = Boolean(object.isFallback);
                            if (object.mlDisabled != null)
                                message.mlDisabled = Boolean(object.mlDisabled);
                            if (object.liveAgentHandoff != null)
                                message.liveAgentHandoff = Boolean(object.liveAgentHandoff);
                            if (object.endInteraction != null)
                                message.endInteraction = Boolean(object.endInteraction);
                            if (object.inputContextNames) {
                                if (!Array.isArray(object.inputContextNames))
                                    throw TypeError(".google.cloud.dialogflow.v2.Intent.inputContextNames: array expected");
                                message.inputContextNames = [];
                                for (var i = 0; i < object.inputContextNames.length; ++i)
                                    message.inputContextNames[i] = String(object.inputContextNames[i]);
                            }
                            if (object.events) {
                                if (!Array.isArray(object.events))
                                    throw TypeError(".google.cloud.dialogflow.v2.Intent.events: array expected");
                                message.events = [];
                                for (var i = 0; i < object.events.length; ++i)
                                    message.events[i] = String(object.events[i]);
                            }
                            if (object.trainingPhrases) {
                                if (!Array.isArray(object.trainingPhrases))
                                    throw TypeError(".google.cloud.dialogflow.v2.Intent.trainingPhrases: array expected");
                                message.trainingPhrases = [];
                                for (var i = 0; i < object.trainingPhrases.length; ++i) {
                                    if (typeof object.trainingPhrases[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.Intent.trainingPhrases: object expected");
                                    message.trainingPhrases[i] = $root.google.cloud.dialogflow.v2.Intent.TrainingPhrase.fromObject(object.trainingPhrases[i]);
                                }
                            }
                            if (object.action != null)
                                message.action = String(object.action);
                            if (object.outputContexts) {
                                if (!Array.isArray(object.outputContexts))
                                    throw TypeError(".google.cloud.dialogflow.v2.Intent.outputContexts: array expected");
                                message.outputContexts = [];
                                for (var i = 0; i < object.outputContexts.length; ++i) {
                                    if (typeof object.outputContexts[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.Intent.outputContexts: object expected");
                                    message.outputContexts[i] = $root.google.cloud.dialogflow.v2.Context.fromObject(object.outputContexts[i]);
                                }
                            }
                            if (object.resetContexts != null)
                                message.resetContexts = Boolean(object.resetContexts);
                            if (object.parameters) {
                                if (!Array.isArray(object.parameters))
                                    throw TypeError(".google.cloud.dialogflow.v2.Intent.parameters: array expected");
                                message.parameters = [];
                                for (var i = 0; i < object.parameters.length; ++i) {
                                    if (typeof object.parameters[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.Intent.parameters: object expected");
                                    message.parameters[i] = $root.google.cloud.dialogflow.v2.Intent.Parameter.fromObject(object.parameters[i]);
                                }
                            }
                            if (object.messages) {
                                if (!Array.isArray(object.messages))
                                    throw TypeError(".google.cloud.dialogflow.v2.Intent.messages: array expected");
                                message.messages = [];
                                for (var i = 0; i < object.messages.length; ++i) {
                                    if (typeof object.messages[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.Intent.messages: object expected");
                                    message.messages[i] = $root.google.cloud.dialogflow.v2.Intent.Message.fromObject(object.messages[i]);
                                }
                            }
                            if (object.defaultResponsePlatforms) {
                                if (!Array.isArray(object.defaultResponsePlatforms))
                                    throw TypeError(".google.cloud.dialogflow.v2.Intent.defaultResponsePlatforms: array expected");
                                message.defaultResponsePlatforms = [];
                                for (var i = 0; i < object.defaultResponsePlatforms.length; ++i)
                                    switch (object.defaultResponsePlatforms[i]) {
                                    default:
                                        if (typeof object.defaultResponsePlatforms[i] === "number") {
                                            message.defaultResponsePlatforms[i] = object.defaultResponsePlatforms[i];
                                            break;
                                        }
                                    case "PLATFORM_UNSPECIFIED":
                                    case 0:
                                        message.defaultResponsePlatforms[i] = 0;
                                        break;
                                    case "FACEBOOK":
                                    case 1:
                                        message.defaultResponsePlatforms[i] = 1;
                                        break;
                                    case "SLACK":
                                    case 2:
                                        message.defaultResponsePlatforms[i] = 2;
                                        break;
                                    case "TELEGRAM":
                                    case 3:
                                        message.defaultResponsePlatforms[i] = 3;
                                        break;
                                    case "KIK":
                                    case 4:
                                        message.defaultResponsePlatforms[i] = 4;
                                        break;
                                    case "SKYPE":
                                    case 5:
                                        message.defaultResponsePlatforms[i] = 5;
                                        break;
                                    case "LINE":
                                    case 6:
                                        message.defaultResponsePlatforms[i] = 6;
                                        break;
                                    case "VIBER":
                                    case 7:
                                        message.defaultResponsePlatforms[i] = 7;
                                        break;
                                    case "ACTIONS_ON_GOOGLE":
                                    case 8:
                                        message.defaultResponsePlatforms[i] = 8;
                                        break;
                                    case "GOOGLE_HANGOUTS":
                                    case 11:
                                        message.defaultResponsePlatforms[i] = 11;
                                        break;
                                    }
                            }
                            if (object.rootFollowupIntentName != null)
                                message.rootFollowupIntentName = String(object.rootFollowupIntentName);
                            if (object.parentFollowupIntentName != null)
                                message.parentFollowupIntentName = String(object.parentFollowupIntentName);
                            if (object.followupIntentInfo) {
                                if (!Array.isArray(object.followupIntentInfo))
                                    throw TypeError(".google.cloud.dialogflow.v2.Intent.followupIntentInfo: array expected");
                                message.followupIntentInfo = [];
                                for (var i = 0; i < object.followupIntentInfo.length; ++i) {
                                    if (typeof object.followupIntentInfo[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.Intent.followupIntentInfo: object expected");
                                    message.followupIntentInfo[i] = $root.google.cloud.dialogflow.v2.Intent.FollowupIntentInfo.fromObject(object.followupIntentInfo[i]);
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an Intent message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.Intent
                         * @static
                         * @param {google.cloud.dialogflow.v2.Intent} message Intent
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        Intent.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults) {
                                object.inputContextNames = [];
                                object.events = [];
                                object.trainingPhrases = [];
                                object.outputContexts = [];
                                object.parameters = [];
                                object.messages = [];
                                object.defaultResponsePlatforms = [];
                                object.followupIntentInfo = [];
                            }
                            if (options.defaults) {
                                object.name = "";
                                object.displayName = "";
                                object.priority = 0;
                                object.isFallback = false;
                                object.webhookState = options.enums === String ? "WEBHOOK_STATE_UNSPECIFIED" : 0;
                                object.action = "";
                                object.resetContexts = false;
                                object.rootFollowupIntentName = "";
                                object.parentFollowupIntentName = "";
                                object.mlDisabled = false;
                                object.liveAgentHandoff = false;
                                object.endInteraction = false;
                            }
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            if (message.displayName != null && message.hasOwnProperty("displayName"))
                                object.displayName = message.displayName;
                            if (message.priority != null && message.hasOwnProperty("priority"))
                                object.priority = message.priority;
                            if (message.isFallback != null && message.hasOwnProperty("isFallback"))
                                object.isFallback = message.isFallback;
                            if (message.webhookState != null && message.hasOwnProperty("webhookState"))
                                object.webhookState = options.enums === String ? $root.google.cloud.dialogflow.v2.Intent.WebhookState[message.webhookState] === undefined ? message.webhookState : $root.google.cloud.dialogflow.v2.Intent.WebhookState[message.webhookState] : message.webhookState;
                            if (message.inputContextNames && message.inputContextNames.length) {
                                object.inputContextNames = [];
                                for (var j = 0; j < message.inputContextNames.length; ++j)
                                    object.inputContextNames[j] = message.inputContextNames[j];
                            }
                            if (message.events && message.events.length) {
                                object.events = [];
                                for (var j = 0; j < message.events.length; ++j)
                                    object.events[j] = message.events[j];
                            }
                            if (message.trainingPhrases && message.trainingPhrases.length) {
                                object.trainingPhrases = [];
                                for (var j = 0; j < message.trainingPhrases.length; ++j)
                                    object.trainingPhrases[j] = $root.google.cloud.dialogflow.v2.Intent.TrainingPhrase.toObject(message.trainingPhrases[j], options);
                            }
                            if (message.action != null && message.hasOwnProperty("action"))
                                object.action = message.action;
                            if (message.outputContexts && message.outputContexts.length) {
                                object.outputContexts = [];
                                for (var j = 0; j < message.outputContexts.length; ++j)
                                    object.outputContexts[j] = $root.google.cloud.dialogflow.v2.Context.toObject(message.outputContexts[j], options);
                            }
                            if (message.resetContexts != null && message.hasOwnProperty("resetContexts"))
                                object.resetContexts = message.resetContexts;
                            if (message.parameters && message.parameters.length) {
                                object.parameters = [];
                                for (var j = 0; j < message.parameters.length; ++j)
                                    object.parameters[j] = $root.google.cloud.dialogflow.v2.Intent.Parameter.toObject(message.parameters[j], options);
                            }
                            if (message.messages && message.messages.length) {
                                object.messages = [];
                                for (var j = 0; j < message.messages.length; ++j)
                                    object.messages[j] = $root.google.cloud.dialogflow.v2.Intent.Message.toObject(message.messages[j], options);
                            }
                            if (message.defaultResponsePlatforms && message.defaultResponsePlatforms.length) {
                                object.defaultResponsePlatforms = [];
                                for (var j = 0; j < message.defaultResponsePlatforms.length; ++j)
                                    object.defaultResponsePlatforms[j] = options.enums === String ? $root.google.cloud.dialogflow.v2.Intent.Message.Platform[message.defaultResponsePlatforms[j]] === undefined ? message.defaultResponsePlatforms[j] : $root.google.cloud.dialogflow.v2.Intent.Message.Platform[message.defaultResponsePlatforms[j]] : message.defaultResponsePlatforms[j];
                            }
                            if (message.rootFollowupIntentName != null && message.hasOwnProperty("rootFollowupIntentName"))
                                object.rootFollowupIntentName = message.rootFollowupIntentName;
                            if (message.parentFollowupIntentName != null && message.hasOwnProperty("parentFollowupIntentName"))
                                object.parentFollowupIntentName = message.parentFollowupIntentName;
                            if (message.followupIntentInfo && message.followupIntentInfo.length) {
                                object.followupIntentInfo = [];
                                for (var j = 0; j < message.followupIntentInfo.length; ++j)
                                    object.followupIntentInfo[j] = $root.google.cloud.dialogflow.v2.Intent.FollowupIntentInfo.toObject(message.followupIntentInfo[j], options);
                            }
                            if (message.mlDisabled != null && message.hasOwnProperty("mlDisabled"))
                                object.mlDisabled = message.mlDisabled;
                            if (message.liveAgentHandoff != null && message.hasOwnProperty("liveAgentHandoff"))
                                object.liveAgentHandoff = message.liveAgentHandoff;
                            if (message.endInteraction != null && message.hasOwnProperty("endInteraction"))
                                object.endInteraction = message.endInteraction;
                            return object;
                        };
    
                        /**
                         * Converts this Intent to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.Intent
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        Intent.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for Intent
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.Intent
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        Intent.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.Intent";
                        };
    
                        /**
                         * WebhookState enum.
                         * @name google.cloud.dialogflow.v2.Intent.WebhookState
                         * @enum {number}
                         * @property {number} WEBHOOK_STATE_UNSPECIFIED=0 WEBHOOK_STATE_UNSPECIFIED value
                         * @property {number} WEBHOOK_STATE_ENABLED=1 WEBHOOK_STATE_ENABLED value
                         * @property {number} WEBHOOK_STATE_ENABLED_FOR_SLOT_FILLING=2 WEBHOOK_STATE_ENABLED_FOR_SLOT_FILLING value
                         */
                        Intent.WebhookState = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "WEBHOOK_STATE_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "WEBHOOK_STATE_ENABLED"] = 1;
                            values[valuesById[2] = "WEBHOOK_STATE_ENABLED_FOR_SLOT_FILLING"] = 2;
                            return values;
                        })();
    
                        Intent.TrainingPhrase = (function() {
    
                            /**
                             * Properties of a TrainingPhrase.
                             * @memberof google.cloud.dialogflow.v2.Intent
                             * @interface ITrainingPhrase
                             * @property {string|null} [name] TrainingPhrase name
                             * @property {google.cloud.dialogflow.v2.Intent.TrainingPhrase.Type|null} [type] TrainingPhrase type
                             * @property {Array.<google.cloud.dialogflow.v2.Intent.TrainingPhrase.IPart>|null} [parts] TrainingPhrase parts
                             * @property {number|null} [timesAddedCount] TrainingPhrase timesAddedCount
                             */
    
                            /**
                             * Constructs a new TrainingPhrase.
                             * @memberof google.cloud.dialogflow.v2.Intent
                             * @classdesc Represents a TrainingPhrase.
                             * @implements ITrainingPhrase
                             * @constructor
                             * @param {google.cloud.dialogflow.v2.Intent.ITrainingPhrase=} [properties] Properties to set
                             */
                            function TrainingPhrase(properties) {
                                this.parts = [];
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * TrainingPhrase name.
                             * @member {string} name
                             * @memberof google.cloud.dialogflow.v2.Intent.TrainingPhrase
                             * @instance
                             */
                            TrainingPhrase.prototype.name = "";
    
                            /**
                             * TrainingPhrase type.
                             * @member {google.cloud.dialogflow.v2.Intent.TrainingPhrase.Type} type
                             * @memberof google.cloud.dialogflow.v2.Intent.TrainingPhrase
                             * @instance
                             */
                            TrainingPhrase.prototype.type = 0;
    
                            /**
                             * TrainingPhrase parts.
                             * @member {Array.<google.cloud.dialogflow.v2.Intent.TrainingPhrase.IPart>} parts
                             * @memberof google.cloud.dialogflow.v2.Intent.TrainingPhrase
                             * @instance
                             */
                            TrainingPhrase.prototype.parts = $util.emptyArray;
    
                            /**
                             * TrainingPhrase timesAddedCount.
                             * @member {number} timesAddedCount
                             * @memberof google.cloud.dialogflow.v2.Intent.TrainingPhrase
                             * @instance
                             */
                            TrainingPhrase.prototype.timesAddedCount = 0;
    
                            /**
                             * Creates a new TrainingPhrase instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2.Intent.TrainingPhrase
                             * @static
                             * @param {google.cloud.dialogflow.v2.Intent.ITrainingPhrase=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2.Intent.TrainingPhrase} TrainingPhrase instance
                             */
                            TrainingPhrase.create = function create(properties) {
                                return new TrainingPhrase(properties);
                            };
    
                            /**
                             * Encodes the specified TrainingPhrase message. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.TrainingPhrase.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2.Intent.TrainingPhrase
                             * @static
                             * @param {google.cloud.dialogflow.v2.Intent.ITrainingPhrase} message TrainingPhrase message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            TrainingPhrase.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                    writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                                if (message.type != null && Object.hasOwnProperty.call(message, "type"))
                                    writer.uint32(/* id 2, wireType 0 =*/16).int32(message.type);
                                if (message.parts != null && message.parts.length)
                                    for (var i = 0; i < message.parts.length; ++i)
                                        $root.google.cloud.dialogflow.v2.Intent.TrainingPhrase.Part.encode(message.parts[i], writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                                if (message.timesAddedCount != null && Object.hasOwnProperty.call(message, "timesAddedCount"))
                                    writer.uint32(/* id 4, wireType 0 =*/32).int32(message.timesAddedCount);
                                return writer;
                            };
    
                            /**
                             * Encodes the specified TrainingPhrase message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.TrainingPhrase.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2.Intent.TrainingPhrase
                             * @static
                             * @param {google.cloud.dialogflow.v2.Intent.ITrainingPhrase} message TrainingPhrase message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            TrainingPhrase.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a TrainingPhrase message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2.Intent.TrainingPhrase
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2.Intent.TrainingPhrase} TrainingPhrase
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            TrainingPhrase.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.Intent.TrainingPhrase();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.name = reader.string();
                                            break;
                                        }
                                    case 2: {
                                            message.type = reader.int32();
                                            break;
                                        }
                                    case 3: {
                                            if (!(message.parts && message.parts.length))
                                                message.parts = [];
                                            message.parts.push($root.google.cloud.dialogflow.v2.Intent.TrainingPhrase.Part.decode(reader, reader.uint32()));
                                            break;
                                        }
                                    case 4: {
                                            message.timesAddedCount = reader.int32();
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a TrainingPhrase message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2.Intent.TrainingPhrase
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2.Intent.TrainingPhrase} TrainingPhrase
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            TrainingPhrase.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a TrainingPhrase message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2.Intent.TrainingPhrase
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            TrainingPhrase.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.name != null && message.hasOwnProperty("name"))
                                    if (!$util.isString(message.name))
                                        return "name: string expected";
                                if (message.type != null && message.hasOwnProperty("type"))
                                    switch (message.type) {
                                    default:
                                        return "type: enum value expected";
                                    case 0:
                                    case 1:
                                    case 2:
                                        break;
                                    }
                                if (message.parts != null && message.hasOwnProperty("parts")) {
                                    if (!Array.isArray(message.parts))
                                        return "parts: array expected";
                                    for (var i = 0; i < message.parts.length; ++i) {
                                        var error = $root.google.cloud.dialogflow.v2.Intent.TrainingPhrase.Part.verify(message.parts[i]);
                                        if (error)
                                            return "parts." + error;
                                    }
                                }
                                if (message.timesAddedCount != null && message.hasOwnProperty("timesAddedCount"))
                                    if (!$util.isInteger(message.timesAddedCount))
                                        return "timesAddedCount: integer expected";
                                return null;
                            };
    
                            /**
                             * Creates a TrainingPhrase message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2.Intent.TrainingPhrase
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2.Intent.TrainingPhrase} TrainingPhrase
                             */
                            TrainingPhrase.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2.Intent.TrainingPhrase)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2.Intent.TrainingPhrase();
                                if (object.name != null)
                                    message.name = String(object.name);
                                switch (object.type) {
                                default:
                                    if (typeof object.type === "number") {
                                        message.type = object.type;
                                        break;
                                    }
                                    break;
                                case "TYPE_UNSPECIFIED":
                                case 0:
                                    message.type = 0;
                                    break;
                                case "EXAMPLE":
                                case 1:
                                    message.type = 1;
                                    break;
                                case "TEMPLATE":
                                case 2:
                                    message.type = 2;
                                    break;
                                }
                                if (object.parts) {
                                    if (!Array.isArray(object.parts))
                                        throw TypeError(".google.cloud.dialogflow.v2.Intent.TrainingPhrase.parts: array expected");
                                    message.parts = [];
                                    for (var i = 0; i < object.parts.length; ++i) {
                                        if (typeof object.parts[i] !== "object")
                                            throw TypeError(".google.cloud.dialogflow.v2.Intent.TrainingPhrase.parts: object expected");
                                        message.parts[i] = $root.google.cloud.dialogflow.v2.Intent.TrainingPhrase.Part.fromObject(object.parts[i]);
                                    }
                                }
                                if (object.timesAddedCount != null)
                                    message.timesAddedCount = object.timesAddedCount | 0;
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a TrainingPhrase message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2.Intent.TrainingPhrase
                             * @static
                             * @param {google.cloud.dialogflow.v2.Intent.TrainingPhrase} message TrainingPhrase
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            TrainingPhrase.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.arrays || options.defaults)
                                    object.parts = [];
                                if (options.defaults) {
                                    object.name = "";
                                    object.type = options.enums === String ? "TYPE_UNSPECIFIED" : 0;
                                    object.timesAddedCount = 0;
                                }
                                if (message.name != null && message.hasOwnProperty("name"))
                                    object.name = message.name;
                                if (message.type != null && message.hasOwnProperty("type"))
                                    object.type = options.enums === String ? $root.google.cloud.dialogflow.v2.Intent.TrainingPhrase.Type[message.type] === undefined ? message.type : $root.google.cloud.dialogflow.v2.Intent.TrainingPhrase.Type[message.type] : message.type;
                                if (message.parts && message.parts.length) {
                                    object.parts = [];
                                    for (var j = 0; j < message.parts.length; ++j)
                                        object.parts[j] = $root.google.cloud.dialogflow.v2.Intent.TrainingPhrase.Part.toObject(message.parts[j], options);
                                }
                                if (message.timesAddedCount != null && message.hasOwnProperty("timesAddedCount"))
                                    object.timesAddedCount = message.timesAddedCount;
                                return object;
                            };
    
                            /**
                             * Converts this TrainingPhrase to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2.Intent.TrainingPhrase
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            TrainingPhrase.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for TrainingPhrase
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2.Intent.TrainingPhrase
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            TrainingPhrase.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2.Intent.TrainingPhrase";
                            };
    
                            /**
                             * Type enum.
                             * @name google.cloud.dialogflow.v2.Intent.TrainingPhrase.Type
                             * @enum {number}
                             * @property {number} TYPE_UNSPECIFIED=0 TYPE_UNSPECIFIED value
                             * @property {number} EXAMPLE=1 EXAMPLE value
                             * @property {number} TEMPLATE=2 TEMPLATE value
                             */
                            TrainingPhrase.Type = (function() {
                                var valuesById = {}, values = Object.create(valuesById);
                                values[valuesById[0] = "TYPE_UNSPECIFIED"] = 0;
                                values[valuesById[1] = "EXAMPLE"] = 1;
                                values[valuesById[2] = "TEMPLATE"] = 2;
                                return values;
                            })();
    
                            TrainingPhrase.Part = (function() {
    
                                /**
                                 * Properties of a Part.
                                 * @memberof google.cloud.dialogflow.v2.Intent.TrainingPhrase
                                 * @interface IPart
                                 * @property {string|null} [text] Part text
                                 * @property {string|null} [entityType] Part entityType
                                 * @property {string|null} [alias] Part alias
                                 * @property {boolean|null} [userDefined] Part userDefined
                                 */
    
                                /**
                                 * Constructs a new Part.
                                 * @memberof google.cloud.dialogflow.v2.Intent.TrainingPhrase
                                 * @classdesc Represents a Part.
                                 * @implements IPart
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2.Intent.TrainingPhrase.IPart=} [properties] Properties to set
                                 */
                                function Part(properties) {
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * Part text.
                                 * @member {string} text
                                 * @memberof google.cloud.dialogflow.v2.Intent.TrainingPhrase.Part
                                 * @instance
                                 */
                                Part.prototype.text = "";
    
                                /**
                                 * Part entityType.
                                 * @member {string} entityType
                                 * @memberof google.cloud.dialogflow.v2.Intent.TrainingPhrase.Part
                                 * @instance
                                 */
                                Part.prototype.entityType = "";
    
                                /**
                                 * Part alias.
                                 * @member {string} alias
                                 * @memberof google.cloud.dialogflow.v2.Intent.TrainingPhrase.Part
                                 * @instance
                                 */
                                Part.prototype.alias = "";
    
                                /**
                                 * Part userDefined.
                                 * @member {boolean} userDefined
                                 * @memberof google.cloud.dialogflow.v2.Intent.TrainingPhrase.Part
                                 * @instance
                                 */
                                Part.prototype.userDefined = false;
    
                                /**
                                 * Creates a new Part instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2.Intent.TrainingPhrase.Part
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.TrainingPhrase.IPart=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2.Intent.TrainingPhrase.Part} Part instance
                                 */
                                Part.create = function create(properties) {
                                    return new Part(properties);
                                };
    
                                /**
                                 * Encodes the specified Part message. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.TrainingPhrase.Part.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2.Intent.TrainingPhrase.Part
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.TrainingPhrase.IPart} message Part message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                Part.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.text != null && Object.hasOwnProperty.call(message, "text"))
                                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.text);
                                    if (message.entityType != null && Object.hasOwnProperty.call(message, "entityType"))
                                        writer.uint32(/* id 2, wireType 2 =*/18).string(message.entityType);
                                    if (message.alias != null && Object.hasOwnProperty.call(message, "alias"))
                                        writer.uint32(/* id 3, wireType 2 =*/26).string(message.alias);
                                    if (message.userDefined != null && Object.hasOwnProperty.call(message, "userDefined"))
                                        writer.uint32(/* id 4, wireType 0 =*/32).bool(message.userDefined);
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified Part message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.TrainingPhrase.Part.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.Intent.TrainingPhrase.Part
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.TrainingPhrase.IPart} message Part message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                Part.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a Part message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2.Intent.TrainingPhrase.Part
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2.Intent.TrainingPhrase.Part} Part
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                Part.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.Intent.TrainingPhrase.Part();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                message.text = reader.string();
                                                break;
                                            }
                                        case 2: {
                                                message.entityType = reader.string();
                                                break;
                                            }
                                        case 3: {
                                                message.alias = reader.string();
                                                break;
                                            }
                                        case 4: {
                                                message.userDefined = reader.bool();
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a Part message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.Intent.TrainingPhrase.Part
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2.Intent.TrainingPhrase.Part} Part
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                Part.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a Part message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2.Intent.TrainingPhrase.Part
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                Part.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.text != null && message.hasOwnProperty("text"))
                                        if (!$util.isString(message.text))
                                            return "text: string expected";
                                    if (message.entityType != null && message.hasOwnProperty("entityType"))
                                        if (!$util.isString(message.entityType))
                                            return "entityType: string expected";
                                    if (message.alias != null && message.hasOwnProperty("alias"))
                                        if (!$util.isString(message.alias))
                                            return "alias: string expected";
                                    if (message.userDefined != null && message.hasOwnProperty("userDefined"))
                                        if (typeof message.userDefined !== "boolean")
                                            return "userDefined: boolean expected";
                                    return null;
                                };
    
                                /**
                                 * Creates a Part message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2.Intent.TrainingPhrase.Part
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2.Intent.TrainingPhrase.Part} Part
                                 */
                                Part.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2.Intent.TrainingPhrase.Part)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2.Intent.TrainingPhrase.Part();
                                    if (object.text != null)
                                        message.text = String(object.text);
                                    if (object.entityType != null)
                                        message.entityType = String(object.entityType);
                                    if (object.alias != null)
                                        message.alias = String(object.alias);
                                    if (object.userDefined != null)
                                        message.userDefined = Boolean(object.userDefined);
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a Part message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2.Intent.TrainingPhrase.Part
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.TrainingPhrase.Part} message Part
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                Part.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.defaults) {
                                        object.text = "";
                                        object.entityType = "";
                                        object.alias = "";
                                        object.userDefined = false;
                                    }
                                    if (message.text != null && message.hasOwnProperty("text"))
                                        object.text = message.text;
                                    if (message.entityType != null && message.hasOwnProperty("entityType"))
                                        object.entityType = message.entityType;
                                    if (message.alias != null && message.hasOwnProperty("alias"))
                                        object.alias = message.alias;
                                    if (message.userDefined != null && message.hasOwnProperty("userDefined"))
                                        object.userDefined = message.userDefined;
                                    return object;
                                };
    
                                /**
                                 * Converts this Part to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2.Intent.TrainingPhrase.Part
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                Part.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for Part
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2.Intent.TrainingPhrase.Part
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                Part.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2.Intent.TrainingPhrase.Part";
                                };
    
                                return Part;
                            })();
    
                            return TrainingPhrase;
                        })();
    
                        Intent.Parameter = (function() {
    
                            /**
                             * Properties of a Parameter.
                             * @memberof google.cloud.dialogflow.v2.Intent
                             * @interface IParameter
                             * @property {string|null} [name] Parameter name
                             * @property {string|null} [displayName] Parameter displayName
                             * @property {string|null} [value] Parameter value
                             * @property {string|null} [defaultValue] Parameter defaultValue
                             * @property {string|null} [entityTypeDisplayName] Parameter entityTypeDisplayName
                             * @property {boolean|null} [mandatory] Parameter mandatory
                             * @property {Array.<string>|null} [prompts] Parameter prompts
                             * @property {boolean|null} [isList] Parameter isList
                             */
    
                            /**
                             * Constructs a new Parameter.
                             * @memberof google.cloud.dialogflow.v2.Intent
                             * @classdesc Represents a Parameter.
                             * @implements IParameter
                             * @constructor
                             * @param {google.cloud.dialogflow.v2.Intent.IParameter=} [properties] Properties to set
                             */
                            function Parameter(properties) {
                                this.prompts = [];
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * Parameter name.
                             * @member {string} name
                             * @memberof google.cloud.dialogflow.v2.Intent.Parameter
                             * @instance
                             */
                            Parameter.prototype.name = "";
    
                            /**
                             * Parameter displayName.
                             * @member {string} displayName
                             * @memberof google.cloud.dialogflow.v2.Intent.Parameter
                             * @instance
                             */
                            Parameter.prototype.displayName = "";
    
                            /**
                             * Parameter value.
                             * @member {string} value
                             * @memberof google.cloud.dialogflow.v2.Intent.Parameter
                             * @instance
                             */
                            Parameter.prototype.value = "";
    
                            /**
                             * Parameter defaultValue.
                             * @member {string} defaultValue
                             * @memberof google.cloud.dialogflow.v2.Intent.Parameter
                             * @instance
                             */
                            Parameter.prototype.defaultValue = "";
    
                            /**
                             * Parameter entityTypeDisplayName.
                             * @member {string} entityTypeDisplayName
                             * @memberof google.cloud.dialogflow.v2.Intent.Parameter
                             * @instance
                             */
                            Parameter.prototype.entityTypeDisplayName = "";
    
                            /**
                             * Parameter mandatory.
                             * @member {boolean} mandatory
                             * @memberof google.cloud.dialogflow.v2.Intent.Parameter
                             * @instance
                             */
                            Parameter.prototype.mandatory = false;
    
                            /**
                             * Parameter prompts.
                             * @member {Array.<string>} prompts
                             * @memberof google.cloud.dialogflow.v2.Intent.Parameter
                             * @instance
                             */
                            Parameter.prototype.prompts = $util.emptyArray;
    
                            /**
                             * Parameter isList.
                             * @member {boolean} isList
                             * @memberof google.cloud.dialogflow.v2.Intent.Parameter
                             * @instance
                             */
                            Parameter.prototype.isList = false;
    
                            /**
                             * Creates a new Parameter instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2.Intent.Parameter
                             * @static
                             * @param {google.cloud.dialogflow.v2.Intent.IParameter=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2.Intent.Parameter} Parameter instance
                             */
                            Parameter.create = function create(properties) {
                                return new Parameter(properties);
                            };
    
                            /**
                             * Encodes the specified Parameter message. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Parameter.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2.Intent.Parameter
                             * @static
                             * @param {google.cloud.dialogflow.v2.Intent.IParameter} message Parameter message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            Parameter.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                    writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                                if (message.displayName != null && Object.hasOwnProperty.call(message, "displayName"))
                                    writer.uint32(/* id 2, wireType 2 =*/18).string(message.displayName);
                                if (message.value != null && Object.hasOwnProperty.call(message, "value"))
                                    writer.uint32(/* id 3, wireType 2 =*/26).string(message.value);
                                if (message.defaultValue != null && Object.hasOwnProperty.call(message, "defaultValue"))
                                    writer.uint32(/* id 4, wireType 2 =*/34).string(message.defaultValue);
                                if (message.entityTypeDisplayName != null && Object.hasOwnProperty.call(message, "entityTypeDisplayName"))
                                    writer.uint32(/* id 5, wireType 2 =*/42).string(message.entityTypeDisplayName);
                                if (message.mandatory != null && Object.hasOwnProperty.call(message, "mandatory"))
                                    writer.uint32(/* id 6, wireType 0 =*/48).bool(message.mandatory);
                                if (message.prompts != null && message.prompts.length)
                                    for (var i = 0; i < message.prompts.length; ++i)
                                        writer.uint32(/* id 7, wireType 2 =*/58).string(message.prompts[i]);
                                if (message.isList != null && Object.hasOwnProperty.call(message, "isList"))
                                    writer.uint32(/* id 8, wireType 0 =*/64).bool(message.isList);
                                return writer;
                            };
    
                            /**
                             * Encodes the specified Parameter message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Parameter.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2.Intent.Parameter
                             * @static
                             * @param {google.cloud.dialogflow.v2.Intent.IParameter} message Parameter message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            Parameter.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a Parameter message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2.Intent.Parameter
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2.Intent.Parameter} Parameter
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            Parameter.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.Intent.Parameter();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.name = reader.string();
                                            break;
                                        }
                                    case 2: {
                                            message.displayName = reader.string();
                                            break;
                                        }
                                    case 3: {
                                            message.value = reader.string();
                                            break;
                                        }
                                    case 4: {
                                            message.defaultValue = reader.string();
                                            break;
                                        }
                                    case 5: {
                                            message.entityTypeDisplayName = reader.string();
                                            break;
                                        }
                                    case 6: {
                                            message.mandatory = reader.bool();
                                            break;
                                        }
                                    case 7: {
                                            if (!(message.prompts && message.prompts.length))
                                                message.prompts = [];
                                            message.prompts.push(reader.string());
                                            break;
                                        }
                                    case 8: {
                                            message.isList = reader.bool();
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a Parameter message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2.Intent.Parameter
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2.Intent.Parameter} Parameter
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            Parameter.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a Parameter message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2.Intent.Parameter
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            Parameter.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.name != null && message.hasOwnProperty("name"))
                                    if (!$util.isString(message.name))
                                        return "name: string expected";
                                if (message.displayName != null && message.hasOwnProperty("displayName"))
                                    if (!$util.isString(message.displayName))
                                        return "displayName: string expected";
                                if (message.value != null && message.hasOwnProperty("value"))
                                    if (!$util.isString(message.value))
                                        return "value: string expected";
                                if (message.defaultValue != null && message.hasOwnProperty("defaultValue"))
                                    if (!$util.isString(message.defaultValue))
                                        return "defaultValue: string expected";
                                if (message.entityTypeDisplayName != null && message.hasOwnProperty("entityTypeDisplayName"))
                                    if (!$util.isString(message.entityTypeDisplayName))
                                        return "entityTypeDisplayName: string expected";
                                if (message.mandatory != null && message.hasOwnProperty("mandatory"))
                                    if (typeof message.mandatory !== "boolean")
                                        return "mandatory: boolean expected";
                                if (message.prompts != null && message.hasOwnProperty("prompts")) {
                                    if (!Array.isArray(message.prompts))
                                        return "prompts: array expected";
                                    for (var i = 0; i < message.prompts.length; ++i)
                                        if (!$util.isString(message.prompts[i]))
                                            return "prompts: string[] expected";
                                }
                                if (message.isList != null && message.hasOwnProperty("isList"))
                                    if (typeof message.isList !== "boolean")
                                        return "isList: boolean expected";
                                return null;
                            };
    
                            /**
                             * Creates a Parameter message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2.Intent.Parameter
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2.Intent.Parameter} Parameter
                             */
                            Parameter.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2.Intent.Parameter)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2.Intent.Parameter();
                                if (object.name != null)
                                    message.name = String(object.name);
                                if (object.displayName != null)
                                    message.displayName = String(object.displayName);
                                if (object.value != null)
                                    message.value = String(object.value);
                                if (object.defaultValue != null)
                                    message.defaultValue = String(object.defaultValue);
                                if (object.entityTypeDisplayName != null)
                                    message.entityTypeDisplayName = String(object.entityTypeDisplayName);
                                if (object.mandatory != null)
                                    message.mandatory = Boolean(object.mandatory);
                                if (object.prompts) {
                                    if (!Array.isArray(object.prompts))
                                        throw TypeError(".google.cloud.dialogflow.v2.Intent.Parameter.prompts: array expected");
                                    message.prompts = [];
                                    for (var i = 0; i < object.prompts.length; ++i)
                                        message.prompts[i] = String(object.prompts[i]);
                                }
                                if (object.isList != null)
                                    message.isList = Boolean(object.isList);
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a Parameter message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2.Intent.Parameter
                             * @static
                             * @param {google.cloud.dialogflow.v2.Intent.Parameter} message Parameter
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            Parameter.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.arrays || options.defaults)
                                    object.prompts = [];
                                if (options.defaults) {
                                    object.name = "";
                                    object.displayName = "";
                                    object.value = "";
                                    object.defaultValue = "";
                                    object.entityTypeDisplayName = "";
                                    object.mandatory = false;
                                    object.isList = false;
                                }
                                if (message.name != null && message.hasOwnProperty("name"))
                                    object.name = message.name;
                                if (message.displayName != null && message.hasOwnProperty("displayName"))
                                    object.displayName = message.displayName;
                                if (message.value != null && message.hasOwnProperty("value"))
                                    object.value = message.value;
                                if (message.defaultValue != null && message.hasOwnProperty("defaultValue"))
                                    object.defaultValue = message.defaultValue;
                                if (message.entityTypeDisplayName != null && message.hasOwnProperty("entityTypeDisplayName"))
                                    object.entityTypeDisplayName = message.entityTypeDisplayName;
                                if (message.mandatory != null && message.hasOwnProperty("mandatory"))
                                    object.mandatory = message.mandatory;
                                if (message.prompts && message.prompts.length) {
                                    object.prompts = [];
                                    for (var j = 0; j < message.prompts.length; ++j)
                                        object.prompts[j] = message.prompts[j];
                                }
                                if (message.isList != null && message.hasOwnProperty("isList"))
                                    object.isList = message.isList;
                                return object;
                            };
    
                            /**
                             * Converts this Parameter to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2.Intent.Parameter
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            Parameter.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for Parameter
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2.Intent.Parameter
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            Parameter.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2.Intent.Parameter";
                            };
    
                            return Parameter;
                        })();
    
                        Intent.Message = (function() {
    
                            /**
                             * Properties of a Message.
                             * @memberof google.cloud.dialogflow.v2.Intent
                             * @interface IMessage
                             * @property {google.cloud.dialogflow.v2.Intent.Message.IText|null} [text] Message text
                             * @property {google.cloud.dialogflow.v2.Intent.Message.IImage|null} [image] Message image
                             * @property {google.cloud.dialogflow.v2.Intent.Message.IQuickReplies|null} [quickReplies] Message quickReplies
                             * @property {google.cloud.dialogflow.v2.Intent.Message.ICard|null} [card] Message card
                             * @property {google.protobuf.IStruct|null} [payload] Message payload
                             * @property {google.cloud.dialogflow.v2.Intent.Message.ISimpleResponses|null} [simpleResponses] Message simpleResponses
                             * @property {google.cloud.dialogflow.v2.Intent.Message.IBasicCard|null} [basicCard] Message basicCard
                             * @property {google.cloud.dialogflow.v2.Intent.Message.ISuggestions|null} [suggestions] Message suggestions
                             * @property {google.cloud.dialogflow.v2.Intent.Message.ILinkOutSuggestion|null} [linkOutSuggestion] Message linkOutSuggestion
                             * @property {google.cloud.dialogflow.v2.Intent.Message.IListSelect|null} [listSelect] Message listSelect
                             * @property {google.cloud.dialogflow.v2.Intent.Message.ICarouselSelect|null} [carouselSelect] Message carouselSelect
                             * @property {google.cloud.dialogflow.v2.Intent.Message.IBrowseCarouselCard|null} [browseCarouselCard] Message browseCarouselCard
                             * @property {google.cloud.dialogflow.v2.Intent.Message.ITableCard|null} [tableCard] Message tableCard
                             * @property {google.cloud.dialogflow.v2.Intent.Message.IMediaContent|null} [mediaContent] Message mediaContent
                             * @property {google.cloud.dialogflow.v2.Intent.Message.Platform|null} [platform] Message platform
                             */
    
                            /**
                             * Constructs a new Message.
                             * @memberof google.cloud.dialogflow.v2.Intent
                             * @classdesc Represents a Message.
                             * @implements IMessage
                             * @constructor
                             * @param {google.cloud.dialogflow.v2.Intent.IMessage=} [properties] Properties to set
                             */
                            function Message(properties) {
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * Message text.
                             * @member {google.cloud.dialogflow.v2.Intent.Message.IText|null|undefined} text
                             * @memberof google.cloud.dialogflow.v2.Intent.Message
                             * @instance
                             */
                            Message.prototype.text = null;
    
                            /**
                             * Message image.
                             * @member {google.cloud.dialogflow.v2.Intent.Message.IImage|null|undefined} image
                             * @memberof google.cloud.dialogflow.v2.Intent.Message
                             * @instance
                             */
                            Message.prototype.image = null;
    
                            /**
                             * Message quickReplies.
                             * @member {google.cloud.dialogflow.v2.Intent.Message.IQuickReplies|null|undefined} quickReplies
                             * @memberof google.cloud.dialogflow.v2.Intent.Message
                             * @instance
                             */
                            Message.prototype.quickReplies = null;
    
                            /**
                             * Message card.
                             * @member {google.cloud.dialogflow.v2.Intent.Message.ICard|null|undefined} card
                             * @memberof google.cloud.dialogflow.v2.Intent.Message
                             * @instance
                             */
                            Message.prototype.card = null;
    
                            /**
                             * Message payload.
                             * @member {google.protobuf.IStruct|null|undefined} payload
                             * @memberof google.cloud.dialogflow.v2.Intent.Message
                             * @instance
                             */
                            Message.prototype.payload = null;
    
                            /**
                             * Message simpleResponses.
                             * @member {google.cloud.dialogflow.v2.Intent.Message.ISimpleResponses|null|undefined} simpleResponses
                             * @memberof google.cloud.dialogflow.v2.Intent.Message
                             * @instance
                             */
                            Message.prototype.simpleResponses = null;
    
                            /**
                             * Message basicCard.
                             * @member {google.cloud.dialogflow.v2.Intent.Message.IBasicCard|null|undefined} basicCard
                             * @memberof google.cloud.dialogflow.v2.Intent.Message
                             * @instance
                             */
                            Message.prototype.basicCard = null;
    
                            /**
                             * Message suggestions.
                             * @member {google.cloud.dialogflow.v2.Intent.Message.ISuggestions|null|undefined} suggestions
                             * @memberof google.cloud.dialogflow.v2.Intent.Message
                             * @instance
                             */
                            Message.prototype.suggestions = null;
    
                            /**
                             * Message linkOutSuggestion.
                             * @member {google.cloud.dialogflow.v2.Intent.Message.ILinkOutSuggestion|null|undefined} linkOutSuggestion
                             * @memberof google.cloud.dialogflow.v2.Intent.Message
                             * @instance
                             */
                            Message.prototype.linkOutSuggestion = null;
    
                            /**
                             * Message listSelect.
                             * @member {google.cloud.dialogflow.v2.Intent.Message.IListSelect|null|undefined} listSelect
                             * @memberof google.cloud.dialogflow.v2.Intent.Message
                             * @instance
                             */
                            Message.prototype.listSelect = null;
    
                            /**
                             * Message carouselSelect.
                             * @member {google.cloud.dialogflow.v2.Intent.Message.ICarouselSelect|null|undefined} carouselSelect
                             * @memberof google.cloud.dialogflow.v2.Intent.Message
                             * @instance
                             */
                            Message.prototype.carouselSelect = null;
    
                            /**
                             * Message browseCarouselCard.
                             * @member {google.cloud.dialogflow.v2.Intent.Message.IBrowseCarouselCard|null|undefined} browseCarouselCard
                             * @memberof google.cloud.dialogflow.v2.Intent.Message
                             * @instance
                             */
                            Message.prototype.browseCarouselCard = null;
    
                            /**
                             * Message tableCard.
                             * @member {google.cloud.dialogflow.v2.Intent.Message.ITableCard|null|undefined} tableCard
                             * @memberof google.cloud.dialogflow.v2.Intent.Message
                             * @instance
                             */
                            Message.prototype.tableCard = null;
    
                            /**
                             * Message mediaContent.
                             * @member {google.cloud.dialogflow.v2.Intent.Message.IMediaContent|null|undefined} mediaContent
                             * @memberof google.cloud.dialogflow.v2.Intent.Message
                             * @instance
                             */
                            Message.prototype.mediaContent = null;
    
                            /**
                             * Message platform.
                             * @member {google.cloud.dialogflow.v2.Intent.Message.Platform} platform
                             * @memberof google.cloud.dialogflow.v2.Intent.Message
                             * @instance
                             */
                            Message.prototype.platform = 0;
    
                            // OneOf field names bound to virtual getters and setters
                            var $oneOfFields;
    
                            /**
                             * Message message.
                             * @member {"text"|"image"|"quickReplies"|"card"|"payload"|"simpleResponses"|"basicCard"|"suggestions"|"linkOutSuggestion"|"listSelect"|"carouselSelect"|"browseCarouselCard"|"tableCard"|"mediaContent"|undefined} message
                             * @memberof google.cloud.dialogflow.v2.Intent.Message
                             * @instance
                             */
                            Object.defineProperty(Message.prototype, "message", {
                                get: $util.oneOfGetter($oneOfFields = ["text", "image", "quickReplies", "card", "payload", "simpleResponses", "basicCard", "suggestions", "linkOutSuggestion", "listSelect", "carouselSelect", "browseCarouselCard", "tableCard", "mediaContent"]),
                                set: $util.oneOfSetter($oneOfFields)
                            });
    
                            /**
                             * Creates a new Message instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2.Intent.Message
                             * @static
                             * @param {google.cloud.dialogflow.v2.Intent.IMessage=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2.Intent.Message} Message instance
                             */
                            Message.create = function create(properties) {
                                return new Message(properties);
                            };
    
                            /**
                             * Encodes the specified Message message. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Message.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2.Intent.Message
                             * @static
                             * @param {google.cloud.dialogflow.v2.Intent.IMessage} message Message message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            Message.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.text != null && Object.hasOwnProperty.call(message, "text"))
                                    $root.google.cloud.dialogflow.v2.Intent.Message.Text.encode(message.text, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                                if (message.image != null && Object.hasOwnProperty.call(message, "image"))
                                    $root.google.cloud.dialogflow.v2.Intent.Message.Image.encode(message.image, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                                if (message.quickReplies != null && Object.hasOwnProperty.call(message, "quickReplies"))
                                    $root.google.cloud.dialogflow.v2.Intent.Message.QuickReplies.encode(message.quickReplies, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                                if (message.card != null && Object.hasOwnProperty.call(message, "card"))
                                    $root.google.cloud.dialogflow.v2.Intent.Message.Card.encode(message.card, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                                if (message.payload != null && Object.hasOwnProperty.call(message, "payload"))
                                    $root.google.protobuf.Struct.encode(message.payload, writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                                if (message.platform != null && Object.hasOwnProperty.call(message, "platform"))
                                    writer.uint32(/* id 6, wireType 0 =*/48).int32(message.platform);
                                if (message.simpleResponses != null && Object.hasOwnProperty.call(message, "simpleResponses"))
                                    $root.google.cloud.dialogflow.v2.Intent.Message.SimpleResponses.encode(message.simpleResponses, writer.uint32(/* id 7, wireType 2 =*/58).fork()).ldelim();
                                if (message.basicCard != null && Object.hasOwnProperty.call(message, "basicCard"))
                                    $root.google.cloud.dialogflow.v2.Intent.Message.BasicCard.encode(message.basicCard, writer.uint32(/* id 8, wireType 2 =*/66).fork()).ldelim();
                                if (message.suggestions != null && Object.hasOwnProperty.call(message, "suggestions"))
                                    $root.google.cloud.dialogflow.v2.Intent.Message.Suggestions.encode(message.suggestions, writer.uint32(/* id 9, wireType 2 =*/74).fork()).ldelim();
                                if (message.linkOutSuggestion != null && Object.hasOwnProperty.call(message, "linkOutSuggestion"))
                                    $root.google.cloud.dialogflow.v2.Intent.Message.LinkOutSuggestion.encode(message.linkOutSuggestion, writer.uint32(/* id 10, wireType 2 =*/82).fork()).ldelim();
                                if (message.listSelect != null && Object.hasOwnProperty.call(message, "listSelect"))
                                    $root.google.cloud.dialogflow.v2.Intent.Message.ListSelect.encode(message.listSelect, writer.uint32(/* id 11, wireType 2 =*/90).fork()).ldelim();
                                if (message.carouselSelect != null && Object.hasOwnProperty.call(message, "carouselSelect"))
                                    $root.google.cloud.dialogflow.v2.Intent.Message.CarouselSelect.encode(message.carouselSelect, writer.uint32(/* id 12, wireType 2 =*/98).fork()).ldelim();
                                if (message.browseCarouselCard != null && Object.hasOwnProperty.call(message, "browseCarouselCard"))
                                    $root.google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.encode(message.browseCarouselCard, writer.uint32(/* id 22, wireType 2 =*/178).fork()).ldelim();
                                if (message.tableCard != null && Object.hasOwnProperty.call(message, "tableCard"))
                                    $root.google.cloud.dialogflow.v2.Intent.Message.TableCard.encode(message.tableCard, writer.uint32(/* id 23, wireType 2 =*/186).fork()).ldelim();
                                if (message.mediaContent != null && Object.hasOwnProperty.call(message, "mediaContent"))
                                    $root.google.cloud.dialogflow.v2.Intent.Message.MediaContent.encode(message.mediaContent, writer.uint32(/* id 24, wireType 2 =*/194).fork()).ldelim();
                                return writer;
                            };
    
                            /**
                             * Encodes the specified Message message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Message.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2.Intent.Message
                             * @static
                             * @param {google.cloud.dialogflow.v2.Intent.IMessage} message Message message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            Message.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a Message message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2.Intent.Message
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2.Intent.Message} Message
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            Message.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.Intent.Message();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.text = $root.google.cloud.dialogflow.v2.Intent.Message.Text.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 2: {
                                            message.image = $root.google.cloud.dialogflow.v2.Intent.Message.Image.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 3: {
                                            message.quickReplies = $root.google.cloud.dialogflow.v2.Intent.Message.QuickReplies.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 4: {
                                            message.card = $root.google.cloud.dialogflow.v2.Intent.Message.Card.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 5: {
                                            message.payload = $root.google.protobuf.Struct.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 7: {
                                            message.simpleResponses = $root.google.cloud.dialogflow.v2.Intent.Message.SimpleResponses.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 8: {
                                            message.basicCard = $root.google.cloud.dialogflow.v2.Intent.Message.BasicCard.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 9: {
                                            message.suggestions = $root.google.cloud.dialogflow.v2.Intent.Message.Suggestions.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 10: {
                                            message.linkOutSuggestion = $root.google.cloud.dialogflow.v2.Intent.Message.LinkOutSuggestion.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 11: {
                                            message.listSelect = $root.google.cloud.dialogflow.v2.Intent.Message.ListSelect.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 12: {
                                            message.carouselSelect = $root.google.cloud.dialogflow.v2.Intent.Message.CarouselSelect.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 22: {
                                            message.browseCarouselCard = $root.google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 23: {
                                            message.tableCard = $root.google.cloud.dialogflow.v2.Intent.Message.TableCard.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 24: {
                                            message.mediaContent = $root.google.cloud.dialogflow.v2.Intent.Message.MediaContent.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 6: {
                                            message.platform = reader.int32();
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a Message message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2.Intent.Message
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2.Intent.Message} Message
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            Message.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a Message message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2.Intent.Message
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            Message.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                var properties = {};
                                if (message.text != null && message.hasOwnProperty("text")) {
                                    properties.message = 1;
                                    {
                                        var error = $root.google.cloud.dialogflow.v2.Intent.Message.Text.verify(message.text);
                                        if (error)
                                            return "text." + error;
                                    }
                                }
                                if (message.image != null && message.hasOwnProperty("image")) {
                                    if (properties.message === 1)
                                        return "message: multiple values";
                                    properties.message = 1;
                                    {
                                        var error = $root.google.cloud.dialogflow.v2.Intent.Message.Image.verify(message.image);
                                        if (error)
                                            return "image." + error;
                                    }
                                }
                                if (message.quickReplies != null && message.hasOwnProperty("quickReplies")) {
                                    if (properties.message === 1)
                                        return "message: multiple values";
                                    properties.message = 1;
                                    {
                                        var error = $root.google.cloud.dialogflow.v2.Intent.Message.QuickReplies.verify(message.quickReplies);
                                        if (error)
                                            return "quickReplies." + error;
                                    }
                                }
                                if (message.card != null && message.hasOwnProperty("card")) {
                                    if (properties.message === 1)
                                        return "message: multiple values";
                                    properties.message = 1;
                                    {
                                        var error = $root.google.cloud.dialogflow.v2.Intent.Message.Card.verify(message.card);
                                        if (error)
                                            return "card." + error;
                                    }
                                }
                                if (message.payload != null && message.hasOwnProperty("payload")) {
                                    if (properties.message === 1)
                                        return "message: multiple values";
                                    properties.message = 1;
                                    {
                                        var error = $root.google.protobuf.Struct.verify(message.payload);
                                        if (error)
                                            return "payload." + error;
                                    }
                                }
                                if (message.simpleResponses != null && message.hasOwnProperty("simpleResponses")) {
                                    if (properties.message === 1)
                                        return "message: multiple values";
                                    properties.message = 1;
                                    {
                                        var error = $root.google.cloud.dialogflow.v2.Intent.Message.SimpleResponses.verify(message.simpleResponses);
                                        if (error)
                                            return "simpleResponses." + error;
                                    }
                                }
                                if (message.basicCard != null && message.hasOwnProperty("basicCard")) {
                                    if (properties.message === 1)
                                        return "message: multiple values";
                                    properties.message = 1;
                                    {
                                        var error = $root.google.cloud.dialogflow.v2.Intent.Message.BasicCard.verify(message.basicCard);
                                        if (error)
                                            return "basicCard." + error;
                                    }
                                }
                                if (message.suggestions != null && message.hasOwnProperty("suggestions")) {
                                    if (properties.message === 1)
                                        return "message: multiple values";
                                    properties.message = 1;
                                    {
                                        var error = $root.google.cloud.dialogflow.v2.Intent.Message.Suggestions.verify(message.suggestions);
                                        if (error)
                                            return "suggestions." + error;
                                    }
                                }
                                if (message.linkOutSuggestion != null && message.hasOwnProperty("linkOutSuggestion")) {
                                    if (properties.message === 1)
                                        return "message: multiple values";
                                    properties.message = 1;
                                    {
                                        var error = $root.google.cloud.dialogflow.v2.Intent.Message.LinkOutSuggestion.verify(message.linkOutSuggestion);
                                        if (error)
                                            return "linkOutSuggestion." + error;
                                    }
                                }
                                if (message.listSelect != null && message.hasOwnProperty("listSelect")) {
                                    if (properties.message === 1)
                                        return "message: multiple values";
                                    properties.message = 1;
                                    {
                                        var error = $root.google.cloud.dialogflow.v2.Intent.Message.ListSelect.verify(message.listSelect);
                                        if (error)
                                            return "listSelect." + error;
                                    }
                                }
                                if (message.carouselSelect != null && message.hasOwnProperty("carouselSelect")) {
                                    if (properties.message === 1)
                                        return "message: multiple values";
                                    properties.message = 1;
                                    {
                                        var error = $root.google.cloud.dialogflow.v2.Intent.Message.CarouselSelect.verify(message.carouselSelect);
                                        if (error)
                                            return "carouselSelect." + error;
                                    }
                                }
                                if (message.browseCarouselCard != null && message.hasOwnProperty("browseCarouselCard")) {
                                    if (properties.message === 1)
                                        return "message: multiple values";
                                    properties.message = 1;
                                    {
                                        var error = $root.google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.verify(message.browseCarouselCard);
                                        if (error)
                                            return "browseCarouselCard." + error;
                                    }
                                }
                                if (message.tableCard != null && message.hasOwnProperty("tableCard")) {
                                    if (properties.message === 1)
                                        return "message: multiple values";
                                    properties.message = 1;
                                    {
                                        var error = $root.google.cloud.dialogflow.v2.Intent.Message.TableCard.verify(message.tableCard);
                                        if (error)
                                            return "tableCard." + error;
                                    }
                                }
                                if (message.mediaContent != null && message.hasOwnProperty("mediaContent")) {
                                    if (properties.message === 1)
                                        return "message: multiple values";
                                    properties.message = 1;
                                    {
                                        var error = $root.google.cloud.dialogflow.v2.Intent.Message.MediaContent.verify(message.mediaContent);
                                        if (error)
                                            return "mediaContent." + error;
                                    }
                                }
                                if (message.platform != null && message.hasOwnProperty("platform"))
                                    switch (message.platform) {
                                    default:
                                        return "platform: enum value expected";
                                    case 0:
                                    case 1:
                                    case 2:
                                    case 3:
                                    case 4:
                                    case 5:
                                    case 6:
                                    case 7:
                                    case 8:
                                    case 11:
                                        break;
                                    }
                                return null;
                            };
    
                            /**
                             * Creates a Message message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2.Intent.Message
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2.Intent.Message} Message
                             */
                            Message.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2.Intent.Message)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2.Intent.Message();
                                if (object.text != null) {
                                    if (typeof object.text !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.Intent.Message.text: object expected");
                                    message.text = $root.google.cloud.dialogflow.v2.Intent.Message.Text.fromObject(object.text);
                                }
                                if (object.image != null) {
                                    if (typeof object.image !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.Intent.Message.image: object expected");
                                    message.image = $root.google.cloud.dialogflow.v2.Intent.Message.Image.fromObject(object.image);
                                }
                                if (object.quickReplies != null) {
                                    if (typeof object.quickReplies !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.Intent.Message.quickReplies: object expected");
                                    message.quickReplies = $root.google.cloud.dialogflow.v2.Intent.Message.QuickReplies.fromObject(object.quickReplies);
                                }
                                if (object.card != null) {
                                    if (typeof object.card !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.Intent.Message.card: object expected");
                                    message.card = $root.google.cloud.dialogflow.v2.Intent.Message.Card.fromObject(object.card);
                                }
                                if (object.payload != null) {
                                    if (typeof object.payload !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.Intent.Message.payload: object expected");
                                    message.payload = $root.google.protobuf.Struct.fromObject(object.payload);
                                }
                                if (object.simpleResponses != null) {
                                    if (typeof object.simpleResponses !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.Intent.Message.simpleResponses: object expected");
                                    message.simpleResponses = $root.google.cloud.dialogflow.v2.Intent.Message.SimpleResponses.fromObject(object.simpleResponses);
                                }
                                if (object.basicCard != null) {
                                    if (typeof object.basicCard !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.Intent.Message.basicCard: object expected");
                                    message.basicCard = $root.google.cloud.dialogflow.v2.Intent.Message.BasicCard.fromObject(object.basicCard);
                                }
                                if (object.suggestions != null) {
                                    if (typeof object.suggestions !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.Intent.Message.suggestions: object expected");
                                    message.suggestions = $root.google.cloud.dialogflow.v2.Intent.Message.Suggestions.fromObject(object.suggestions);
                                }
                                if (object.linkOutSuggestion != null) {
                                    if (typeof object.linkOutSuggestion !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.Intent.Message.linkOutSuggestion: object expected");
                                    message.linkOutSuggestion = $root.google.cloud.dialogflow.v2.Intent.Message.LinkOutSuggestion.fromObject(object.linkOutSuggestion);
                                }
                                if (object.listSelect != null) {
                                    if (typeof object.listSelect !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.Intent.Message.listSelect: object expected");
                                    message.listSelect = $root.google.cloud.dialogflow.v2.Intent.Message.ListSelect.fromObject(object.listSelect);
                                }
                                if (object.carouselSelect != null) {
                                    if (typeof object.carouselSelect !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.Intent.Message.carouselSelect: object expected");
                                    message.carouselSelect = $root.google.cloud.dialogflow.v2.Intent.Message.CarouselSelect.fromObject(object.carouselSelect);
                                }
                                if (object.browseCarouselCard != null) {
                                    if (typeof object.browseCarouselCard !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.Intent.Message.browseCarouselCard: object expected");
                                    message.browseCarouselCard = $root.google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.fromObject(object.browseCarouselCard);
                                }
                                if (object.tableCard != null) {
                                    if (typeof object.tableCard !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.Intent.Message.tableCard: object expected");
                                    message.tableCard = $root.google.cloud.dialogflow.v2.Intent.Message.TableCard.fromObject(object.tableCard);
                                }
                                if (object.mediaContent != null) {
                                    if (typeof object.mediaContent !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.Intent.Message.mediaContent: object expected");
                                    message.mediaContent = $root.google.cloud.dialogflow.v2.Intent.Message.MediaContent.fromObject(object.mediaContent);
                                }
                                switch (object.platform) {
                                default:
                                    if (typeof object.platform === "number") {
                                        message.platform = object.platform;
                                        break;
                                    }
                                    break;
                                case "PLATFORM_UNSPECIFIED":
                                case 0:
                                    message.platform = 0;
                                    break;
                                case "FACEBOOK":
                                case 1:
                                    message.platform = 1;
                                    break;
                                case "SLACK":
                                case 2:
                                    message.platform = 2;
                                    break;
                                case "TELEGRAM":
                                case 3:
                                    message.platform = 3;
                                    break;
                                case "KIK":
                                case 4:
                                    message.platform = 4;
                                    break;
                                case "SKYPE":
                                case 5:
                                    message.platform = 5;
                                    break;
                                case "LINE":
                                case 6:
                                    message.platform = 6;
                                    break;
                                case "VIBER":
                                case 7:
                                    message.platform = 7;
                                    break;
                                case "ACTIONS_ON_GOOGLE":
                                case 8:
                                    message.platform = 8;
                                    break;
                                case "GOOGLE_HANGOUTS":
                                case 11:
                                    message.platform = 11;
                                    break;
                                }
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a Message message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2.Intent.Message
                             * @static
                             * @param {google.cloud.dialogflow.v2.Intent.Message} message Message
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            Message.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.defaults)
                                    object.platform = options.enums === String ? "PLATFORM_UNSPECIFIED" : 0;
                                if (message.text != null && message.hasOwnProperty("text")) {
                                    object.text = $root.google.cloud.dialogflow.v2.Intent.Message.Text.toObject(message.text, options);
                                    if (options.oneofs)
                                        object.message = "text";
                                }
                                if (message.image != null && message.hasOwnProperty("image")) {
                                    object.image = $root.google.cloud.dialogflow.v2.Intent.Message.Image.toObject(message.image, options);
                                    if (options.oneofs)
                                        object.message = "image";
                                }
                                if (message.quickReplies != null && message.hasOwnProperty("quickReplies")) {
                                    object.quickReplies = $root.google.cloud.dialogflow.v2.Intent.Message.QuickReplies.toObject(message.quickReplies, options);
                                    if (options.oneofs)
                                        object.message = "quickReplies";
                                }
                                if (message.card != null && message.hasOwnProperty("card")) {
                                    object.card = $root.google.cloud.dialogflow.v2.Intent.Message.Card.toObject(message.card, options);
                                    if (options.oneofs)
                                        object.message = "card";
                                }
                                if (message.payload != null && message.hasOwnProperty("payload")) {
                                    object.payload = $root.google.protobuf.Struct.toObject(message.payload, options);
                                    if (options.oneofs)
                                        object.message = "payload";
                                }
                                if (message.platform != null && message.hasOwnProperty("platform"))
                                    object.platform = options.enums === String ? $root.google.cloud.dialogflow.v2.Intent.Message.Platform[message.platform] === undefined ? message.platform : $root.google.cloud.dialogflow.v2.Intent.Message.Platform[message.platform] : message.platform;
                                if (message.simpleResponses != null && message.hasOwnProperty("simpleResponses")) {
                                    object.simpleResponses = $root.google.cloud.dialogflow.v2.Intent.Message.SimpleResponses.toObject(message.simpleResponses, options);
                                    if (options.oneofs)
                                        object.message = "simpleResponses";
                                }
                                if (message.basicCard != null && message.hasOwnProperty("basicCard")) {
                                    object.basicCard = $root.google.cloud.dialogflow.v2.Intent.Message.BasicCard.toObject(message.basicCard, options);
                                    if (options.oneofs)
                                        object.message = "basicCard";
                                }
                                if (message.suggestions != null && message.hasOwnProperty("suggestions")) {
                                    object.suggestions = $root.google.cloud.dialogflow.v2.Intent.Message.Suggestions.toObject(message.suggestions, options);
                                    if (options.oneofs)
                                        object.message = "suggestions";
                                }
                                if (message.linkOutSuggestion != null && message.hasOwnProperty("linkOutSuggestion")) {
                                    object.linkOutSuggestion = $root.google.cloud.dialogflow.v2.Intent.Message.LinkOutSuggestion.toObject(message.linkOutSuggestion, options);
                                    if (options.oneofs)
                                        object.message = "linkOutSuggestion";
                                }
                                if (message.listSelect != null && message.hasOwnProperty("listSelect")) {
                                    object.listSelect = $root.google.cloud.dialogflow.v2.Intent.Message.ListSelect.toObject(message.listSelect, options);
                                    if (options.oneofs)
                                        object.message = "listSelect";
                                }
                                if (message.carouselSelect != null && message.hasOwnProperty("carouselSelect")) {
                                    object.carouselSelect = $root.google.cloud.dialogflow.v2.Intent.Message.CarouselSelect.toObject(message.carouselSelect, options);
                                    if (options.oneofs)
                                        object.message = "carouselSelect";
                                }
                                if (message.browseCarouselCard != null && message.hasOwnProperty("browseCarouselCard")) {
                                    object.browseCarouselCard = $root.google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.toObject(message.browseCarouselCard, options);
                                    if (options.oneofs)
                                        object.message = "browseCarouselCard";
                                }
                                if (message.tableCard != null && message.hasOwnProperty("tableCard")) {
                                    object.tableCard = $root.google.cloud.dialogflow.v2.Intent.Message.TableCard.toObject(message.tableCard, options);
                                    if (options.oneofs)
                                        object.message = "tableCard";
                                }
                                if (message.mediaContent != null && message.hasOwnProperty("mediaContent")) {
                                    object.mediaContent = $root.google.cloud.dialogflow.v2.Intent.Message.MediaContent.toObject(message.mediaContent, options);
                                    if (options.oneofs)
                                        object.message = "mediaContent";
                                }
                                return object;
                            };
    
                            /**
                             * Converts this Message to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2.Intent.Message
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            Message.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for Message
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2.Intent.Message
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            Message.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2.Intent.Message";
                            };
    
                            /**
                             * Platform enum.
                             * @name google.cloud.dialogflow.v2.Intent.Message.Platform
                             * @enum {number}
                             * @property {number} PLATFORM_UNSPECIFIED=0 PLATFORM_UNSPECIFIED value
                             * @property {number} FACEBOOK=1 FACEBOOK value
                             * @property {number} SLACK=2 SLACK value
                             * @property {number} TELEGRAM=3 TELEGRAM value
                             * @property {number} KIK=4 KIK value
                             * @property {number} SKYPE=5 SKYPE value
                             * @property {number} LINE=6 LINE value
                             * @property {number} VIBER=7 VIBER value
                             * @property {number} ACTIONS_ON_GOOGLE=8 ACTIONS_ON_GOOGLE value
                             * @property {number} GOOGLE_HANGOUTS=11 GOOGLE_HANGOUTS value
                             */
                            Message.Platform = (function() {
                                var valuesById = {}, values = Object.create(valuesById);
                                values[valuesById[0] = "PLATFORM_UNSPECIFIED"] = 0;
                                values[valuesById[1] = "FACEBOOK"] = 1;
                                values[valuesById[2] = "SLACK"] = 2;
                                values[valuesById[3] = "TELEGRAM"] = 3;
                                values[valuesById[4] = "KIK"] = 4;
                                values[valuesById[5] = "SKYPE"] = 5;
                                values[valuesById[6] = "LINE"] = 6;
                                values[valuesById[7] = "VIBER"] = 7;
                                values[valuesById[8] = "ACTIONS_ON_GOOGLE"] = 8;
                                values[valuesById[11] = "GOOGLE_HANGOUTS"] = 11;
                                return values;
                            })();
    
                            Message.Text = (function() {
    
                                /**
                                 * Properties of a Text.
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message
                                 * @interface IText
                                 * @property {Array.<string>|null} [text] Text text
                                 */
    
                                /**
                                 * Constructs a new Text.
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message
                                 * @classdesc Represents a Text.
                                 * @implements IText
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.IText=} [properties] Properties to set
                                 */
                                function Text(properties) {
                                    this.text = [];
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * Text text.
                                 * @member {Array.<string>} text
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Text
                                 * @instance
                                 */
                                Text.prototype.text = $util.emptyArray;
    
                                /**
                                 * Creates a new Text instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Text
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.IText=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.Text} Text instance
                                 */
                                Text.create = function create(properties) {
                                    return new Text(properties);
                                };
    
                                /**
                                 * Encodes the specified Text message. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Message.Text.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Text
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.IText} message Text message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                Text.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.text != null && message.text.length)
                                        for (var i = 0; i < message.text.length; ++i)
                                            writer.uint32(/* id 1, wireType 2 =*/10).string(message.text[i]);
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified Text message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Message.Text.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Text
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.IText} message Text message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                Text.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a Text message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Text
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.Text} Text
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                Text.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.Intent.Message.Text();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                if (!(message.text && message.text.length))
                                                    message.text = [];
                                                message.text.push(reader.string());
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a Text message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Text
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.Text} Text
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                Text.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a Text message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Text
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                Text.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.text != null && message.hasOwnProperty("text")) {
                                        if (!Array.isArray(message.text))
                                            return "text: array expected";
                                        for (var i = 0; i < message.text.length; ++i)
                                            if (!$util.isString(message.text[i]))
                                                return "text: string[] expected";
                                    }
                                    return null;
                                };
    
                                /**
                                 * Creates a Text message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Text
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.Text} Text
                                 */
                                Text.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2.Intent.Message.Text)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2.Intent.Message.Text();
                                    if (object.text) {
                                        if (!Array.isArray(object.text))
                                            throw TypeError(".google.cloud.dialogflow.v2.Intent.Message.Text.text: array expected");
                                        message.text = [];
                                        for (var i = 0; i < object.text.length; ++i)
                                            message.text[i] = String(object.text[i]);
                                    }
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a Text message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Text
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.Text} message Text
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                Text.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.arrays || options.defaults)
                                        object.text = [];
                                    if (message.text && message.text.length) {
                                        object.text = [];
                                        for (var j = 0; j < message.text.length; ++j)
                                            object.text[j] = message.text[j];
                                    }
                                    return object;
                                };
    
                                /**
                                 * Converts this Text to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Text
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                Text.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for Text
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Text
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                Text.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2.Intent.Message.Text";
                                };
    
                                return Text;
                            })();
    
                            Message.Image = (function() {
    
                                /**
                                 * Properties of an Image.
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message
                                 * @interface IImage
                                 * @property {string|null} [imageUri] Image imageUri
                                 * @property {string|null} [accessibilityText] Image accessibilityText
                                 */
    
                                /**
                                 * Constructs a new Image.
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message
                                 * @classdesc Represents an Image.
                                 * @implements IImage
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.IImage=} [properties] Properties to set
                                 */
                                function Image(properties) {
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * Image imageUri.
                                 * @member {string} imageUri
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Image
                                 * @instance
                                 */
                                Image.prototype.imageUri = "";
    
                                /**
                                 * Image accessibilityText.
                                 * @member {string} accessibilityText
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Image
                                 * @instance
                                 */
                                Image.prototype.accessibilityText = "";
    
                                /**
                                 * Creates a new Image instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Image
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.IImage=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.Image} Image instance
                                 */
                                Image.create = function create(properties) {
                                    return new Image(properties);
                                };
    
                                /**
                                 * Encodes the specified Image message. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Message.Image.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Image
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.IImage} message Image message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                Image.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.imageUri != null && Object.hasOwnProperty.call(message, "imageUri"))
                                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.imageUri);
                                    if (message.accessibilityText != null && Object.hasOwnProperty.call(message, "accessibilityText"))
                                        writer.uint32(/* id 2, wireType 2 =*/18).string(message.accessibilityText);
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified Image message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Message.Image.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Image
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.IImage} message Image message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                Image.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes an Image message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Image
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.Image} Image
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                Image.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.Intent.Message.Image();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                message.imageUri = reader.string();
                                                break;
                                            }
                                        case 2: {
                                                message.accessibilityText = reader.string();
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes an Image message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Image
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.Image} Image
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                Image.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies an Image message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Image
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                Image.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.imageUri != null && message.hasOwnProperty("imageUri"))
                                        if (!$util.isString(message.imageUri))
                                            return "imageUri: string expected";
                                    if (message.accessibilityText != null && message.hasOwnProperty("accessibilityText"))
                                        if (!$util.isString(message.accessibilityText))
                                            return "accessibilityText: string expected";
                                    return null;
                                };
    
                                /**
                                 * Creates an Image message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Image
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.Image} Image
                                 */
                                Image.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2.Intent.Message.Image)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2.Intent.Message.Image();
                                    if (object.imageUri != null)
                                        message.imageUri = String(object.imageUri);
                                    if (object.accessibilityText != null)
                                        message.accessibilityText = String(object.accessibilityText);
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from an Image message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Image
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.Image} message Image
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                Image.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.defaults) {
                                        object.imageUri = "";
                                        object.accessibilityText = "";
                                    }
                                    if (message.imageUri != null && message.hasOwnProperty("imageUri"))
                                        object.imageUri = message.imageUri;
                                    if (message.accessibilityText != null && message.hasOwnProperty("accessibilityText"))
                                        object.accessibilityText = message.accessibilityText;
                                    return object;
                                };
    
                                /**
                                 * Converts this Image to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Image
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                Image.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for Image
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Image
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                Image.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2.Intent.Message.Image";
                                };
    
                                return Image;
                            })();
    
                            Message.QuickReplies = (function() {
    
                                /**
                                 * Properties of a QuickReplies.
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message
                                 * @interface IQuickReplies
                                 * @property {string|null} [title] QuickReplies title
                                 * @property {Array.<string>|null} [quickReplies] QuickReplies quickReplies
                                 */
    
                                /**
                                 * Constructs a new QuickReplies.
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message
                                 * @classdesc Represents a QuickReplies.
                                 * @implements IQuickReplies
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.IQuickReplies=} [properties] Properties to set
                                 */
                                function QuickReplies(properties) {
                                    this.quickReplies = [];
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * QuickReplies title.
                                 * @member {string} title
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.QuickReplies
                                 * @instance
                                 */
                                QuickReplies.prototype.title = "";
    
                                /**
                                 * QuickReplies quickReplies.
                                 * @member {Array.<string>} quickReplies
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.QuickReplies
                                 * @instance
                                 */
                                QuickReplies.prototype.quickReplies = $util.emptyArray;
    
                                /**
                                 * Creates a new QuickReplies instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.QuickReplies
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.IQuickReplies=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.QuickReplies} QuickReplies instance
                                 */
                                QuickReplies.create = function create(properties) {
                                    return new QuickReplies(properties);
                                };
    
                                /**
                                 * Encodes the specified QuickReplies message. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Message.QuickReplies.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.QuickReplies
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.IQuickReplies} message QuickReplies message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                QuickReplies.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.title != null && Object.hasOwnProperty.call(message, "title"))
                                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.title);
                                    if (message.quickReplies != null && message.quickReplies.length)
                                        for (var i = 0; i < message.quickReplies.length; ++i)
                                            writer.uint32(/* id 2, wireType 2 =*/18).string(message.quickReplies[i]);
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified QuickReplies message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Message.QuickReplies.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.QuickReplies
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.IQuickReplies} message QuickReplies message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                QuickReplies.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a QuickReplies message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.QuickReplies
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.QuickReplies} QuickReplies
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                QuickReplies.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.Intent.Message.QuickReplies();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                message.title = reader.string();
                                                break;
                                            }
                                        case 2: {
                                                if (!(message.quickReplies && message.quickReplies.length))
                                                    message.quickReplies = [];
                                                message.quickReplies.push(reader.string());
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a QuickReplies message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.QuickReplies
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.QuickReplies} QuickReplies
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                QuickReplies.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a QuickReplies message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.QuickReplies
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                QuickReplies.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.title != null && message.hasOwnProperty("title"))
                                        if (!$util.isString(message.title))
                                            return "title: string expected";
                                    if (message.quickReplies != null && message.hasOwnProperty("quickReplies")) {
                                        if (!Array.isArray(message.quickReplies))
                                            return "quickReplies: array expected";
                                        for (var i = 0; i < message.quickReplies.length; ++i)
                                            if (!$util.isString(message.quickReplies[i]))
                                                return "quickReplies: string[] expected";
                                    }
                                    return null;
                                };
    
                                /**
                                 * Creates a QuickReplies message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.QuickReplies
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.QuickReplies} QuickReplies
                                 */
                                QuickReplies.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2.Intent.Message.QuickReplies)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2.Intent.Message.QuickReplies();
                                    if (object.title != null)
                                        message.title = String(object.title);
                                    if (object.quickReplies) {
                                        if (!Array.isArray(object.quickReplies))
                                            throw TypeError(".google.cloud.dialogflow.v2.Intent.Message.QuickReplies.quickReplies: array expected");
                                        message.quickReplies = [];
                                        for (var i = 0; i < object.quickReplies.length; ++i)
                                            message.quickReplies[i] = String(object.quickReplies[i]);
                                    }
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a QuickReplies message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.QuickReplies
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.QuickReplies} message QuickReplies
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                QuickReplies.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.arrays || options.defaults)
                                        object.quickReplies = [];
                                    if (options.defaults)
                                        object.title = "";
                                    if (message.title != null && message.hasOwnProperty("title"))
                                        object.title = message.title;
                                    if (message.quickReplies && message.quickReplies.length) {
                                        object.quickReplies = [];
                                        for (var j = 0; j < message.quickReplies.length; ++j)
                                            object.quickReplies[j] = message.quickReplies[j];
                                    }
                                    return object;
                                };
    
                                /**
                                 * Converts this QuickReplies to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.QuickReplies
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                QuickReplies.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for QuickReplies
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.QuickReplies
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                QuickReplies.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2.Intent.Message.QuickReplies";
                                };
    
                                return QuickReplies;
                            })();
    
                            Message.Card = (function() {
    
                                /**
                                 * Properties of a Card.
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message
                                 * @interface ICard
                                 * @property {string|null} [title] Card title
                                 * @property {string|null} [subtitle] Card subtitle
                                 * @property {string|null} [imageUri] Card imageUri
                                 * @property {Array.<google.cloud.dialogflow.v2.Intent.Message.Card.IButton>|null} [buttons] Card buttons
                                 */
    
                                /**
                                 * Constructs a new Card.
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message
                                 * @classdesc Represents a Card.
                                 * @implements ICard
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.ICard=} [properties] Properties to set
                                 */
                                function Card(properties) {
                                    this.buttons = [];
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * Card title.
                                 * @member {string} title
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Card
                                 * @instance
                                 */
                                Card.prototype.title = "";
    
                                /**
                                 * Card subtitle.
                                 * @member {string} subtitle
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Card
                                 * @instance
                                 */
                                Card.prototype.subtitle = "";
    
                                /**
                                 * Card imageUri.
                                 * @member {string} imageUri
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Card
                                 * @instance
                                 */
                                Card.prototype.imageUri = "";
    
                                /**
                                 * Card buttons.
                                 * @member {Array.<google.cloud.dialogflow.v2.Intent.Message.Card.IButton>} buttons
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Card
                                 * @instance
                                 */
                                Card.prototype.buttons = $util.emptyArray;
    
                                /**
                                 * Creates a new Card instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Card
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.ICard=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.Card} Card instance
                                 */
                                Card.create = function create(properties) {
                                    return new Card(properties);
                                };
    
                                /**
                                 * Encodes the specified Card message. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Message.Card.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Card
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.ICard} message Card message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                Card.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.title != null && Object.hasOwnProperty.call(message, "title"))
                                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.title);
                                    if (message.subtitle != null && Object.hasOwnProperty.call(message, "subtitle"))
                                        writer.uint32(/* id 2, wireType 2 =*/18).string(message.subtitle);
                                    if (message.imageUri != null && Object.hasOwnProperty.call(message, "imageUri"))
                                        writer.uint32(/* id 3, wireType 2 =*/26).string(message.imageUri);
                                    if (message.buttons != null && message.buttons.length)
                                        for (var i = 0; i < message.buttons.length; ++i)
                                            $root.google.cloud.dialogflow.v2.Intent.Message.Card.Button.encode(message.buttons[i], writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified Card message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Message.Card.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Card
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.ICard} message Card message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                Card.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a Card message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Card
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.Card} Card
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                Card.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.Intent.Message.Card();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                message.title = reader.string();
                                                break;
                                            }
                                        case 2: {
                                                message.subtitle = reader.string();
                                                break;
                                            }
                                        case 3: {
                                                message.imageUri = reader.string();
                                                break;
                                            }
                                        case 4: {
                                                if (!(message.buttons && message.buttons.length))
                                                    message.buttons = [];
                                                message.buttons.push($root.google.cloud.dialogflow.v2.Intent.Message.Card.Button.decode(reader, reader.uint32()));
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a Card message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Card
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.Card} Card
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                Card.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a Card message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Card
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                Card.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.title != null && message.hasOwnProperty("title"))
                                        if (!$util.isString(message.title))
                                            return "title: string expected";
                                    if (message.subtitle != null && message.hasOwnProperty("subtitle"))
                                        if (!$util.isString(message.subtitle))
                                            return "subtitle: string expected";
                                    if (message.imageUri != null && message.hasOwnProperty("imageUri"))
                                        if (!$util.isString(message.imageUri))
                                            return "imageUri: string expected";
                                    if (message.buttons != null && message.hasOwnProperty("buttons")) {
                                        if (!Array.isArray(message.buttons))
                                            return "buttons: array expected";
                                        for (var i = 0; i < message.buttons.length; ++i) {
                                            var error = $root.google.cloud.dialogflow.v2.Intent.Message.Card.Button.verify(message.buttons[i]);
                                            if (error)
                                                return "buttons." + error;
                                        }
                                    }
                                    return null;
                                };
    
                                /**
                                 * Creates a Card message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Card
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.Card} Card
                                 */
                                Card.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2.Intent.Message.Card)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2.Intent.Message.Card();
                                    if (object.title != null)
                                        message.title = String(object.title);
                                    if (object.subtitle != null)
                                        message.subtitle = String(object.subtitle);
                                    if (object.imageUri != null)
                                        message.imageUri = String(object.imageUri);
                                    if (object.buttons) {
                                        if (!Array.isArray(object.buttons))
                                            throw TypeError(".google.cloud.dialogflow.v2.Intent.Message.Card.buttons: array expected");
                                        message.buttons = [];
                                        for (var i = 0; i < object.buttons.length; ++i) {
                                            if (typeof object.buttons[i] !== "object")
                                                throw TypeError(".google.cloud.dialogflow.v2.Intent.Message.Card.buttons: object expected");
                                            message.buttons[i] = $root.google.cloud.dialogflow.v2.Intent.Message.Card.Button.fromObject(object.buttons[i]);
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a Card message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Card
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.Card} message Card
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                Card.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.arrays || options.defaults)
                                        object.buttons = [];
                                    if (options.defaults) {
                                        object.title = "";
                                        object.subtitle = "";
                                        object.imageUri = "";
                                    }
                                    if (message.title != null && message.hasOwnProperty("title"))
                                        object.title = message.title;
                                    if (message.subtitle != null && message.hasOwnProperty("subtitle"))
                                        object.subtitle = message.subtitle;
                                    if (message.imageUri != null && message.hasOwnProperty("imageUri"))
                                        object.imageUri = message.imageUri;
                                    if (message.buttons && message.buttons.length) {
                                        object.buttons = [];
                                        for (var j = 0; j < message.buttons.length; ++j)
                                            object.buttons[j] = $root.google.cloud.dialogflow.v2.Intent.Message.Card.Button.toObject(message.buttons[j], options);
                                    }
                                    return object;
                                };
    
                                /**
                                 * Converts this Card to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Card
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                Card.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for Card
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Card
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                Card.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2.Intent.Message.Card";
                                };
    
                                Card.Button = (function() {
    
                                    /**
                                     * Properties of a Button.
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.Card
                                     * @interface IButton
                                     * @property {string|null} [text] Button text
                                     * @property {string|null} [postback] Button postback
                                     */
    
                                    /**
                                     * Constructs a new Button.
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.Card
                                     * @classdesc Represents a Button.
                                     * @implements IButton
                                     * @constructor
                                     * @param {google.cloud.dialogflow.v2.Intent.Message.Card.IButton=} [properties] Properties to set
                                     */
                                    function Button(properties) {
                                        if (properties)
                                            for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                                if (properties[keys[i]] != null)
                                                    this[keys[i]] = properties[keys[i]];
                                    }
    
                                    /**
                                     * Button text.
                                     * @member {string} text
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.Card.Button
                                     * @instance
                                     */
                                    Button.prototype.text = "";
    
                                    /**
                                     * Button postback.
                                     * @member {string} postback
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.Card.Button
                                     * @instance
                                     */
                                    Button.prototype.postback = "";
    
                                    /**
                                     * Creates a new Button instance using the specified properties.
                                     * @function create
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.Card.Button
                                     * @static
                                     * @param {google.cloud.dialogflow.v2.Intent.Message.Card.IButton=} [properties] Properties to set
                                     * @returns {google.cloud.dialogflow.v2.Intent.Message.Card.Button} Button instance
                                     */
                                    Button.create = function create(properties) {
                                        return new Button(properties);
                                    };
    
                                    /**
                                     * Encodes the specified Button message. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Message.Card.Button.verify|verify} messages.
                                     * @function encode
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.Card.Button
                                     * @static
                                     * @param {google.cloud.dialogflow.v2.Intent.Message.Card.IButton} message Button message or plain object to encode
                                     * @param {$protobuf.Writer} [writer] Writer to encode to
                                     * @returns {$protobuf.Writer} Writer
                                     */
                                    Button.encode = function encode(message, writer) {
                                        if (!writer)
                                            writer = $Writer.create();
                                        if (message.text != null && Object.hasOwnProperty.call(message, "text"))
                                            writer.uint32(/* id 1, wireType 2 =*/10).string(message.text);
                                        if (message.postback != null && Object.hasOwnProperty.call(message, "postback"))
                                            writer.uint32(/* id 2, wireType 2 =*/18).string(message.postback);
                                        return writer;
                                    };
    
                                    /**
                                     * Encodes the specified Button message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Message.Card.Button.verify|verify} messages.
                                     * @function encodeDelimited
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.Card.Button
                                     * @static
                                     * @param {google.cloud.dialogflow.v2.Intent.Message.Card.IButton} message Button message or plain object to encode
                                     * @param {$protobuf.Writer} [writer] Writer to encode to
                                     * @returns {$protobuf.Writer} Writer
                                     */
                                    Button.encodeDelimited = function encodeDelimited(message, writer) {
                                        return this.encode(message, writer).ldelim();
                                    };
    
                                    /**
                                     * Decodes a Button message from the specified reader or buffer.
                                     * @function decode
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.Card.Button
                                     * @static
                                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                     * @param {number} [length] Message length if known beforehand
                                     * @returns {google.cloud.dialogflow.v2.Intent.Message.Card.Button} Button
                                     * @throws {Error} If the payload is not a reader or valid buffer
                                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                     */
                                    Button.decode = function decode(reader, length) {
                                        if (!(reader instanceof $Reader))
                                            reader = $Reader.create(reader);
                                        var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.Intent.Message.Card.Button();
                                        while (reader.pos < end) {
                                            var tag = reader.uint32();
                                            switch (tag >>> 3) {
                                            case 1: {
                                                    message.text = reader.string();
                                                    break;
                                                }
                                            case 2: {
                                                    message.postback = reader.string();
                                                    break;
                                                }
                                            default:
                                                reader.skipType(tag & 7);
                                                break;
                                            }
                                        }
                                        return message;
                                    };
    
                                    /**
                                     * Decodes a Button message from the specified reader or buffer, length delimited.
                                     * @function decodeDelimited
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.Card.Button
                                     * @static
                                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                     * @returns {google.cloud.dialogflow.v2.Intent.Message.Card.Button} Button
                                     * @throws {Error} If the payload is not a reader or valid buffer
                                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                     */
                                    Button.decodeDelimited = function decodeDelimited(reader) {
                                        if (!(reader instanceof $Reader))
                                            reader = new $Reader(reader);
                                        return this.decode(reader, reader.uint32());
                                    };
    
                                    /**
                                     * Verifies a Button message.
                                     * @function verify
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.Card.Button
                                     * @static
                                     * @param {Object.<string,*>} message Plain object to verify
                                     * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                     */
                                    Button.verify = function verify(message) {
                                        if (typeof message !== "object" || message === null)
                                            return "object expected";
                                        if (message.text != null && message.hasOwnProperty("text"))
                                            if (!$util.isString(message.text))
                                                return "text: string expected";
                                        if (message.postback != null && message.hasOwnProperty("postback"))
                                            if (!$util.isString(message.postback))
                                                return "postback: string expected";
                                        return null;
                                    };
    
                                    /**
                                     * Creates a Button message from a plain object. Also converts values to their respective internal types.
                                     * @function fromObject
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.Card.Button
                                     * @static
                                     * @param {Object.<string,*>} object Plain object
                                     * @returns {google.cloud.dialogflow.v2.Intent.Message.Card.Button} Button
                                     */
                                    Button.fromObject = function fromObject(object) {
                                        if (object instanceof $root.google.cloud.dialogflow.v2.Intent.Message.Card.Button)
                                            return object;
                                        var message = new $root.google.cloud.dialogflow.v2.Intent.Message.Card.Button();
                                        if (object.text != null)
                                            message.text = String(object.text);
                                        if (object.postback != null)
                                            message.postback = String(object.postback);
                                        return message;
                                    };
    
                                    /**
                                     * Creates a plain object from a Button message. Also converts values to other types if specified.
                                     * @function toObject
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.Card.Button
                                     * @static
                                     * @param {google.cloud.dialogflow.v2.Intent.Message.Card.Button} message Button
                                     * @param {$protobuf.IConversionOptions} [options] Conversion options
                                     * @returns {Object.<string,*>} Plain object
                                     */
                                    Button.toObject = function toObject(message, options) {
                                        if (!options)
                                            options = {};
                                        var object = {};
                                        if (options.defaults) {
                                            object.text = "";
                                            object.postback = "";
                                        }
                                        if (message.text != null && message.hasOwnProperty("text"))
                                            object.text = message.text;
                                        if (message.postback != null && message.hasOwnProperty("postback"))
                                            object.postback = message.postback;
                                        return object;
                                    };
    
                                    /**
                                     * Converts this Button to JSON.
                                     * @function toJSON
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.Card.Button
                                     * @instance
                                     * @returns {Object.<string,*>} JSON object
                                     */
                                    Button.prototype.toJSON = function toJSON() {
                                        return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                    };
    
                                    /**
                                     * Gets the default type url for Button
                                     * @function getTypeUrl
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.Card.Button
                                     * @static
                                     * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                     * @returns {string} The default type url
                                     */
                                    Button.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                        if (typeUrlPrefix === undefined) {
                                            typeUrlPrefix = "type.googleapis.com";
                                        }
                                        return typeUrlPrefix + "/google.cloud.dialogflow.v2.Intent.Message.Card.Button";
                                    };
    
                                    return Button;
                                })();
    
                                return Card;
                            })();
    
                            Message.SimpleResponse = (function() {
    
                                /**
                                 * Properties of a SimpleResponse.
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message
                                 * @interface ISimpleResponse
                                 * @property {string|null} [textToSpeech] SimpleResponse textToSpeech
                                 * @property {string|null} [ssml] SimpleResponse ssml
                                 * @property {string|null} [displayText] SimpleResponse displayText
                                 */
    
                                /**
                                 * Constructs a new SimpleResponse.
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message
                                 * @classdesc Represents a SimpleResponse.
                                 * @implements ISimpleResponse
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.ISimpleResponse=} [properties] Properties to set
                                 */
                                function SimpleResponse(properties) {
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * SimpleResponse textToSpeech.
                                 * @member {string} textToSpeech
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.SimpleResponse
                                 * @instance
                                 */
                                SimpleResponse.prototype.textToSpeech = "";
    
                                /**
                                 * SimpleResponse ssml.
                                 * @member {string} ssml
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.SimpleResponse
                                 * @instance
                                 */
                                SimpleResponse.prototype.ssml = "";
    
                                /**
                                 * SimpleResponse displayText.
                                 * @member {string} displayText
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.SimpleResponse
                                 * @instance
                                 */
                                SimpleResponse.prototype.displayText = "";
    
                                /**
                                 * Creates a new SimpleResponse instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.SimpleResponse
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.ISimpleResponse=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.SimpleResponse} SimpleResponse instance
                                 */
                                SimpleResponse.create = function create(properties) {
                                    return new SimpleResponse(properties);
                                };
    
                                /**
                                 * Encodes the specified SimpleResponse message. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Message.SimpleResponse.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.SimpleResponse
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.ISimpleResponse} message SimpleResponse message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                SimpleResponse.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.textToSpeech != null && Object.hasOwnProperty.call(message, "textToSpeech"))
                                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.textToSpeech);
                                    if (message.ssml != null && Object.hasOwnProperty.call(message, "ssml"))
                                        writer.uint32(/* id 2, wireType 2 =*/18).string(message.ssml);
                                    if (message.displayText != null && Object.hasOwnProperty.call(message, "displayText"))
                                        writer.uint32(/* id 3, wireType 2 =*/26).string(message.displayText);
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified SimpleResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Message.SimpleResponse.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.SimpleResponse
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.ISimpleResponse} message SimpleResponse message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                SimpleResponse.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a SimpleResponse message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.SimpleResponse
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.SimpleResponse} SimpleResponse
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                SimpleResponse.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.Intent.Message.SimpleResponse();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                message.textToSpeech = reader.string();
                                                break;
                                            }
                                        case 2: {
                                                message.ssml = reader.string();
                                                break;
                                            }
                                        case 3: {
                                                message.displayText = reader.string();
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a SimpleResponse message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.SimpleResponse
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.SimpleResponse} SimpleResponse
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                SimpleResponse.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a SimpleResponse message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.SimpleResponse
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                SimpleResponse.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.textToSpeech != null && message.hasOwnProperty("textToSpeech"))
                                        if (!$util.isString(message.textToSpeech))
                                            return "textToSpeech: string expected";
                                    if (message.ssml != null && message.hasOwnProperty("ssml"))
                                        if (!$util.isString(message.ssml))
                                            return "ssml: string expected";
                                    if (message.displayText != null && message.hasOwnProperty("displayText"))
                                        if (!$util.isString(message.displayText))
                                            return "displayText: string expected";
                                    return null;
                                };
    
                                /**
                                 * Creates a SimpleResponse message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.SimpleResponse
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.SimpleResponse} SimpleResponse
                                 */
                                SimpleResponse.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2.Intent.Message.SimpleResponse)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2.Intent.Message.SimpleResponse();
                                    if (object.textToSpeech != null)
                                        message.textToSpeech = String(object.textToSpeech);
                                    if (object.ssml != null)
                                        message.ssml = String(object.ssml);
                                    if (object.displayText != null)
                                        message.displayText = String(object.displayText);
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a SimpleResponse message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.SimpleResponse
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.SimpleResponse} message SimpleResponse
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                SimpleResponse.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.defaults) {
                                        object.textToSpeech = "";
                                        object.ssml = "";
                                        object.displayText = "";
                                    }
                                    if (message.textToSpeech != null && message.hasOwnProperty("textToSpeech"))
                                        object.textToSpeech = message.textToSpeech;
                                    if (message.ssml != null && message.hasOwnProperty("ssml"))
                                        object.ssml = message.ssml;
                                    if (message.displayText != null && message.hasOwnProperty("displayText"))
                                        object.displayText = message.displayText;
                                    return object;
                                };
    
                                /**
                                 * Converts this SimpleResponse to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.SimpleResponse
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                SimpleResponse.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for SimpleResponse
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.SimpleResponse
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                SimpleResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2.Intent.Message.SimpleResponse";
                                };
    
                                return SimpleResponse;
                            })();
    
                            Message.SimpleResponses = (function() {
    
                                /**
                                 * Properties of a SimpleResponses.
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message
                                 * @interface ISimpleResponses
                                 * @property {Array.<google.cloud.dialogflow.v2.Intent.Message.ISimpleResponse>|null} [simpleResponses] SimpleResponses simpleResponses
                                 */
    
                                /**
                                 * Constructs a new SimpleResponses.
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message
                                 * @classdesc Represents a SimpleResponses.
                                 * @implements ISimpleResponses
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.ISimpleResponses=} [properties] Properties to set
                                 */
                                function SimpleResponses(properties) {
                                    this.simpleResponses = [];
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * SimpleResponses simpleResponses.
                                 * @member {Array.<google.cloud.dialogflow.v2.Intent.Message.ISimpleResponse>} simpleResponses
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.SimpleResponses
                                 * @instance
                                 */
                                SimpleResponses.prototype.simpleResponses = $util.emptyArray;
    
                                /**
                                 * Creates a new SimpleResponses instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.SimpleResponses
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.ISimpleResponses=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.SimpleResponses} SimpleResponses instance
                                 */
                                SimpleResponses.create = function create(properties) {
                                    return new SimpleResponses(properties);
                                };
    
                                /**
                                 * Encodes the specified SimpleResponses message. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Message.SimpleResponses.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.SimpleResponses
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.ISimpleResponses} message SimpleResponses message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                SimpleResponses.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.simpleResponses != null && message.simpleResponses.length)
                                        for (var i = 0; i < message.simpleResponses.length; ++i)
                                            $root.google.cloud.dialogflow.v2.Intent.Message.SimpleResponse.encode(message.simpleResponses[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified SimpleResponses message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Message.SimpleResponses.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.SimpleResponses
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.ISimpleResponses} message SimpleResponses message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                SimpleResponses.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a SimpleResponses message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.SimpleResponses
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.SimpleResponses} SimpleResponses
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                SimpleResponses.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.Intent.Message.SimpleResponses();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                if (!(message.simpleResponses && message.simpleResponses.length))
                                                    message.simpleResponses = [];
                                                message.simpleResponses.push($root.google.cloud.dialogflow.v2.Intent.Message.SimpleResponse.decode(reader, reader.uint32()));
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a SimpleResponses message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.SimpleResponses
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.SimpleResponses} SimpleResponses
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                SimpleResponses.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a SimpleResponses message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.SimpleResponses
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                SimpleResponses.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.simpleResponses != null && message.hasOwnProperty("simpleResponses")) {
                                        if (!Array.isArray(message.simpleResponses))
                                            return "simpleResponses: array expected";
                                        for (var i = 0; i < message.simpleResponses.length; ++i) {
                                            var error = $root.google.cloud.dialogflow.v2.Intent.Message.SimpleResponse.verify(message.simpleResponses[i]);
                                            if (error)
                                                return "simpleResponses." + error;
                                        }
                                    }
                                    return null;
                                };
    
                                /**
                                 * Creates a SimpleResponses message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.SimpleResponses
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.SimpleResponses} SimpleResponses
                                 */
                                SimpleResponses.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2.Intent.Message.SimpleResponses)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2.Intent.Message.SimpleResponses();
                                    if (object.simpleResponses) {
                                        if (!Array.isArray(object.simpleResponses))
                                            throw TypeError(".google.cloud.dialogflow.v2.Intent.Message.SimpleResponses.simpleResponses: array expected");
                                        message.simpleResponses = [];
                                        for (var i = 0; i < object.simpleResponses.length; ++i) {
                                            if (typeof object.simpleResponses[i] !== "object")
                                                throw TypeError(".google.cloud.dialogflow.v2.Intent.Message.SimpleResponses.simpleResponses: object expected");
                                            message.simpleResponses[i] = $root.google.cloud.dialogflow.v2.Intent.Message.SimpleResponse.fromObject(object.simpleResponses[i]);
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a SimpleResponses message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.SimpleResponses
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.SimpleResponses} message SimpleResponses
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                SimpleResponses.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.arrays || options.defaults)
                                        object.simpleResponses = [];
                                    if (message.simpleResponses && message.simpleResponses.length) {
                                        object.simpleResponses = [];
                                        for (var j = 0; j < message.simpleResponses.length; ++j)
                                            object.simpleResponses[j] = $root.google.cloud.dialogflow.v2.Intent.Message.SimpleResponse.toObject(message.simpleResponses[j], options);
                                    }
                                    return object;
                                };
    
                                /**
                                 * Converts this SimpleResponses to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.SimpleResponses
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                SimpleResponses.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for SimpleResponses
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.SimpleResponses
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                SimpleResponses.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2.Intent.Message.SimpleResponses";
                                };
    
                                return SimpleResponses;
                            })();
    
                            Message.BasicCard = (function() {
    
                                /**
                                 * Properties of a BasicCard.
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message
                                 * @interface IBasicCard
                                 * @property {string|null} [title] BasicCard title
                                 * @property {string|null} [subtitle] BasicCard subtitle
                                 * @property {string|null} [formattedText] BasicCard formattedText
                                 * @property {google.cloud.dialogflow.v2.Intent.Message.IImage|null} [image] BasicCard image
                                 * @property {Array.<google.cloud.dialogflow.v2.Intent.Message.BasicCard.IButton>|null} [buttons] BasicCard buttons
                                 */
    
                                /**
                                 * Constructs a new BasicCard.
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message
                                 * @classdesc Represents a BasicCard.
                                 * @implements IBasicCard
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.IBasicCard=} [properties] Properties to set
                                 */
                                function BasicCard(properties) {
                                    this.buttons = [];
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * BasicCard title.
                                 * @member {string} title
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.BasicCard
                                 * @instance
                                 */
                                BasicCard.prototype.title = "";
    
                                /**
                                 * BasicCard subtitle.
                                 * @member {string} subtitle
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.BasicCard
                                 * @instance
                                 */
                                BasicCard.prototype.subtitle = "";
    
                                /**
                                 * BasicCard formattedText.
                                 * @member {string} formattedText
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.BasicCard
                                 * @instance
                                 */
                                BasicCard.prototype.formattedText = "";
    
                                /**
                                 * BasicCard image.
                                 * @member {google.cloud.dialogflow.v2.Intent.Message.IImage|null|undefined} image
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.BasicCard
                                 * @instance
                                 */
                                BasicCard.prototype.image = null;
    
                                /**
                                 * BasicCard buttons.
                                 * @member {Array.<google.cloud.dialogflow.v2.Intent.Message.BasicCard.IButton>} buttons
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.BasicCard
                                 * @instance
                                 */
                                BasicCard.prototype.buttons = $util.emptyArray;
    
                                /**
                                 * Creates a new BasicCard instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.BasicCard
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.IBasicCard=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.BasicCard} BasicCard instance
                                 */
                                BasicCard.create = function create(properties) {
                                    return new BasicCard(properties);
                                };
    
                                /**
                                 * Encodes the specified BasicCard message. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Message.BasicCard.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.BasicCard
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.IBasicCard} message BasicCard message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                BasicCard.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.title != null && Object.hasOwnProperty.call(message, "title"))
                                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.title);
                                    if (message.subtitle != null && Object.hasOwnProperty.call(message, "subtitle"))
                                        writer.uint32(/* id 2, wireType 2 =*/18).string(message.subtitle);
                                    if (message.formattedText != null && Object.hasOwnProperty.call(message, "formattedText"))
                                        writer.uint32(/* id 3, wireType 2 =*/26).string(message.formattedText);
                                    if (message.image != null && Object.hasOwnProperty.call(message, "image"))
                                        $root.google.cloud.dialogflow.v2.Intent.Message.Image.encode(message.image, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                                    if (message.buttons != null && message.buttons.length)
                                        for (var i = 0; i < message.buttons.length; ++i)
                                            $root.google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button.encode(message.buttons[i], writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified BasicCard message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Message.BasicCard.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.BasicCard
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.IBasicCard} message BasicCard message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                BasicCard.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a BasicCard message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.BasicCard
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.BasicCard} BasicCard
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                BasicCard.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.Intent.Message.BasicCard();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                message.title = reader.string();
                                                break;
                                            }
                                        case 2: {
                                                message.subtitle = reader.string();
                                                break;
                                            }
                                        case 3: {
                                                message.formattedText = reader.string();
                                                break;
                                            }
                                        case 4: {
                                                message.image = $root.google.cloud.dialogflow.v2.Intent.Message.Image.decode(reader, reader.uint32());
                                                break;
                                            }
                                        case 5: {
                                                if (!(message.buttons && message.buttons.length))
                                                    message.buttons = [];
                                                message.buttons.push($root.google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button.decode(reader, reader.uint32()));
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a BasicCard message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.BasicCard
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.BasicCard} BasicCard
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                BasicCard.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a BasicCard message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.BasicCard
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                BasicCard.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.title != null && message.hasOwnProperty("title"))
                                        if (!$util.isString(message.title))
                                            return "title: string expected";
                                    if (message.subtitle != null && message.hasOwnProperty("subtitle"))
                                        if (!$util.isString(message.subtitle))
                                            return "subtitle: string expected";
                                    if (message.formattedText != null && message.hasOwnProperty("formattedText"))
                                        if (!$util.isString(message.formattedText))
                                            return "formattedText: string expected";
                                    if (message.image != null && message.hasOwnProperty("image")) {
                                        var error = $root.google.cloud.dialogflow.v2.Intent.Message.Image.verify(message.image);
                                        if (error)
                                            return "image." + error;
                                    }
                                    if (message.buttons != null && message.hasOwnProperty("buttons")) {
                                        if (!Array.isArray(message.buttons))
                                            return "buttons: array expected";
                                        for (var i = 0; i < message.buttons.length; ++i) {
                                            var error = $root.google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button.verify(message.buttons[i]);
                                            if (error)
                                                return "buttons." + error;
                                        }
                                    }
                                    return null;
                                };
    
                                /**
                                 * Creates a BasicCard message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.BasicCard
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.BasicCard} BasicCard
                                 */
                                BasicCard.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2.Intent.Message.BasicCard)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2.Intent.Message.BasicCard();
                                    if (object.title != null)
                                        message.title = String(object.title);
                                    if (object.subtitle != null)
                                        message.subtitle = String(object.subtitle);
                                    if (object.formattedText != null)
                                        message.formattedText = String(object.formattedText);
                                    if (object.image != null) {
                                        if (typeof object.image !== "object")
                                            throw TypeError(".google.cloud.dialogflow.v2.Intent.Message.BasicCard.image: object expected");
                                        message.image = $root.google.cloud.dialogflow.v2.Intent.Message.Image.fromObject(object.image);
                                    }
                                    if (object.buttons) {
                                        if (!Array.isArray(object.buttons))
                                            throw TypeError(".google.cloud.dialogflow.v2.Intent.Message.BasicCard.buttons: array expected");
                                        message.buttons = [];
                                        for (var i = 0; i < object.buttons.length; ++i) {
                                            if (typeof object.buttons[i] !== "object")
                                                throw TypeError(".google.cloud.dialogflow.v2.Intent.Message.BasicCard.buttons: object expected");
                                            message.buttons[i] = $root.google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button.fromObject(object.buttons[i]);
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a BasicCard message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.BasicCard
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.BasicCard} message BasicCard
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                BasicCard.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.arrays || options.defaults)
                                        object.buttons = [];
                                    if (options.defaults) {
                                        object.title = "";
                                        object.subtitle = "";
                                        object.formattedText = "";
                                        object.image = null;
                                    }
                                    if (message.title != null && message.hasOwnProperty("title"))
                                        object.title = message.title;
                                    if (message.subtitle != null && message.hasOwnProperty("subtitle"))
                                        object.subtitle = message.subtitle;
                                    if (message.formattedText != null && message.hasOwnProperty("formattedText"))
                                        object.formattedText = message.formattedText;
                                    if (message.image != null && message.hasOwnProperty("image"))
                                        object.image = $root.google.cloud.dialogflow.v2.Intent.Message.Image.toObject(message.image, options);
                                    if (message.buttons && message.buttons.length) {
                                        object.buttons = [];
                                        for (var j = 0; j < message.buttons.length; ++j)
                                            object.buttons[j] = $root.google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button.toObject(message.buttons[j], options);
                                    }
                                    return object;
                                };
    
                                /**
                                 * Converts this BasicCard to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.BasicCard
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                BasicCard.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for BasicCard
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.BasicCard
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                BasicCard.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2.Intent.Message.BasicCard";
                                };
    
                                BasicCard.Button = (function() {
    
                                    /**
                                     * Properties of a Button.
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.BasicCard
                                     * @interface IButton
                                     * @property {string|null} [title] Button title
                                     * @property {google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button.IOpenUriAction|null} [openUriAction] Button openUriAction
                                     */
    
                                    /**
                                     * Constructs a new Button.
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.BasicCard
                                     * @classdesc Represents a Button.
                                     * @implements IButton
                                     * @constructor
                                     * @param {google.cloud.dialogflow.v2.Intent.Message.BasicCard.IButton=} [properties] Properties to set
                                     */
                                    function Button(properties) {
                                        if (properties)
                                            for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                                if (properties[keys[i]] != null)
                                                    this[keys[i]] = properties[keys[i]];
                                    }
    
                                    /**
                                     * Button title.
                                     * @member {string} title
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button
                                     * @instance
                                     */
                                    Button.prototype.title = "";
    
                                    /**
                                     * Button openUriAction.
                                     * @member {google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button.IOpenUriAction|null|undefined} openUriAction
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button
                                     * @instance
                                     */
                                    Button.prototype.openUriAction = null;
    
                                    /**
                                     * Creates a new Button instance using the specified properties.
                                     * @function create
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button
                                     * @static
                                     * @param {google.cloud.dialogflow.v2.Intent.Message.BasicCard.IButton=} [properties] Properties to set
                                     * @returns {google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button} Button instance
                                     */
                                    Button.create = function create(properties) {
                                        return new Button(properties);
                                    };
    
                                    /**
                                     * Encodes the specified Button message. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button.verify|verify} messages.
                                     * @function encode
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button
                                     * @static
                                     * @param {google.cloud.dialogflow.v2.Intent.Message.BasicCard.IButton} message Button message or plain object to encode
                                     * @param {$protobuf.Writer} [writer] Writer to encode to
                                     * @returns {$protobuf.Writer} Writer
                                     */
                                    Button.encode = function encode(message, writer) {
                                        if (!writer)
                                            writer = $Writer.create();
                                        if (message.title != null && Object.hasOwnProperty.call(message, "title"))
                                            writer.uint32(/* id 1, wireType 2 =*/10).string(message.title);
                                        if (message.openUriAction != null && Object.hasOwnProperty.call(message, "openUriAction"))
                                            $root.google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button.OpenUriAction.encode(message.openUriAction, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                                        return writer;
                                    };
    
                                    /**
                                     * Encodes the specified Button message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button.verify|verify} messages.
                                     * @function encodeDelimited
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button
                                     * @static
                                     * @param {google.cloud.dialogflow.v2.Intent.Message.BasicCard.IButton} message Button message or plain object to encode
                                     * @param {$protobuf.Writer} [writer] Writer to encode to
                                     * @returns {$protobuf.Writer} Writer
                                     */
                                    Button.encodeDelimited = function encodeDelimited(message, writer) {
                                        return this.encode(message, writer).ldelim();
                                    };
    
                                    /**
                                     * Decodes a Button message from the specified reader or buffer.
                                     * @function decode
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button
                                     * @static
                                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                     * @param {number} [length] Message length if known beforehand
                                     * @returns {google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button} Button
                                     * @throws {Error} If the payload is not a reader or valid buffer
                                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                     */
                                    Button.decode = function decode(reader, length) {
                                        if (!(reader instanceof $Reader))
                                            reader = $Reader.create(reader);
                                        var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button();
                                        while (reader.pos < end) {
                                            var tag = reader.uint32();
                                            switch (tag >>> 3) {
                                            case 1: {
                                                    message.title = reader.string();
                                                    break;
                                                }
                                            case 2: {
                                                    message.openUriAction = $root.google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button.OpenUriAction.decode(reader, reader.uint32());
                                                    break;
                                                }
                                            default:
                                                reader.skipType(tag & 7);
                                                break;
                                            }
                                        }
                                        return message;
                                    };
    
                                    /**
                                     * Decodes a Button message from the specified reader or buffer, length delimited.
                                     * @function decodeDelimited
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button
                                     * @static
                                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                     * @returns {google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button} Button
                                     * @throws {Error} If the payload is not a reader or valid buffer
                                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                     */
                                    Button.decodeDelimited = function decodeDelimited(reader) {
                                        if (!(reader instanceof $Reader))
                                            reader = new $Reader(reader);
                                        return this.decode(reader, reader.uint32());
                                    };
    
                                    /**
                                     * Verifies a Button message.
                                     * @function verify
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button
                                     * @static
                                     * @param {Object.<string,*>} message Plain object to verify
                                     * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                     */
                                    Button.verify = function verify(message) {
                                        if (typeof message !== "object" || message === null)
                                            return "object expected";
                                        if (message.title != null && message.hasOwnProperty("title"))
                                            if (!$util.isString(message.title))
                                                return "title: string expected";
                                        if (message.openUriAction != null && message.hasOwnProperty("openUriAction")) {
                                            var error = $root.google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button.OpenUriAction.verify(message.openUriAction);
                                            if (error)
                                                return "openUriAction." + error;
                                        }
                                        return null;
                                    };
    
                                    /**
                                     * Creates a Button message from a plain object. Also converts values to their respective internal types.
                                     * @function fromObject
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button
                                     * @static
                                     * @param {Object.<string,*>} object Plain object
                                     * @returns {google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button} Button
                                     */
                                    Button.fromObject = function fromObject(object) {
                                        if (object instanceof $root.google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button)
                                            return object;
                                        var message = new $root.google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button();
                                        if (object.title != null)
                                            message.title = String(object.title);
                                        if (object.openUriAction != null) {
                                            if (typeof object.openUriAction !== "object")
                                                throw TypeError(".google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button.openUriAction: object expected");
                                            message.openUriAction = $root.google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button.OpenUriAction.fromObject(object.openUriAction);
                                        }
                                        return message;
                                    };
    
                                    /**
                                     * Creates a plain object from a Button message. Also converts values to other types if specified.
                                     * @function toObject
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button
                                     * @static
                                     * @param {google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button} message Button
                                     * @param {$protobuf.IConversionOptions} [options] Conversion options
                                     * @returns {Object.<string,*>} Plain object
                                     */
                                    Button.toObject = function toObject(message, options) {
                                        if (!options)
                                            options = {};
                                        var object = {};
                                        if (options.defaults) {
                                            object.title = "";
                                            object.openUriAction = null;
                                        }
                                        if (message.title != null && message.hasOwnProperty("title"))
                                            object.title = message.title;
                                        if (message.openUriAction != null && message.hasOwnProperty("openUriAction"))
                                            object.openUriAction = $root.google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button.OpenUriAction.toObject(message.openUriAction, options);
                                        return object;
                                    };
    
                                    /**
                                     * Converts this Button to JSON.
                                     * @function toJSON
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button
                                     * @instance
                                     * @returns {Object.<string,*>} JSON object
                                     */
                                    Button.prototype.toJSON = function toJSON() {
                                        return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                    };
    
                                    /**
                                     * Gets the default type url for Button
                                     * @function getTypeUrl
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button
                                     * @static
                                     * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                     * @returns {string} The default type url
                                     */
                                    Button.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                        if (typeUrlPrefix === undefined) {
                                            typeUrlPrefix = "type.googleapis.com";
                                        }
                                        return typeUrlPrefix + "/google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button";
                                    };
    
                                    Button.OpenUriAction = (function() {
    
                                        /**
                                         * Properties of an OpenUriAction.
                                         * @memberof google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button
                                         * @interface IOpenUriAction
                                         * @property {string|null} [uri] OpenUriAction uri
                                         */
    
                                        /**
                                         * Constructs a new OpenUriAction.
                                         * @memberof google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button
                                         * @classdesc Represents an OpenUriAction.
                                         * @implements IOpenUriAction
                                         * @constructor
                                         * @param {google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button.IOpenUriAction=} [properties] Properties to set
                                         */
                                        function OpenUriAction(properties) {
                                            if (properties)
                                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                                    if (properties[keys[i]] != null)
                                                        this[keys[i]] = properties[keys[i]];
                                        }
    
                                        /**
                                         * OpenUriAction uri.
                                         * @member {string} uri
                                         * @memberof google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button.OpenUriAction
                                         * @instance
                                         */
                                        OpenUriAction.prototype.uri = "";
    
                                        /**
                                         * Creates a new OpenUriAction instance using the specified properties.
                                         * @function create
                                         * @memberof google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button.OpenUriAction
                                         * @static
                                         * @param {google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button.IOpenUriAction=} [properties] Properties to set
                                         * @returns {google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button.OpenUriAction} OpenUriAction instance
                                         */
                                        OpenUriAction.create = function create(properties) {
                                            return new OpenUriAction(properties);
                                        };
    
                                        /**
                                         * Encodes the specified OpenUriAction message. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button.OpenUriAction.verify|verify} messages.
                                         * @function encode
                                         * @memberof google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button.OpenUriAction
                                         * @static
                                         * @param {google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button.IOpenUriAction} message OpenUriAction message or plain object to encode
                                         * @param {$protobuf.Writer} [writer] Writer to encode to
                                         * @returns {$protobuf.Writer} Writer
                                         */
                                        OpenUriAction.encode = function encode(message, writer) {
                                            if (!writer)
                                                writer = $Writer.create();
                                            if (message.uri != null && Object.hasOwnProperty.call(message, "uri"))
                                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.uri);
                                            return writer;
                                        };
    
                                        /**
                                         * Encodes the specified OpenUriAction message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button.OpenUriAction.verify|verify} messages.
                                         * @function encodeDelimited
                                         * @memberof google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button.OpenUriAction
                                         * @static
                                         * @param {google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button.IOpenUriAction} message OpenUriAction message or plain object to encode
                                         * @param {$protobuf.Writer} [writer] Writer to encode to
                                         * @returns {$protobuf.Writer} Writer
                                         */
                                        OpenUriAction.encodeDelimited = function encodeDelimited(message, writer) {
                                            return this.encode(message, writer).ldelim();
                                        };
    
                                        /**
                                         * Decodes an OpenUriAction message from the specified reader or buffer.
                                         * @function decode
                                         * @memberof google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button.OpenUriAction
                                         * @static
                                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                         * @param {number} [length] Message length if known beforehand
                                         * @returns {google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button.OpenUriAction} OpenUriAction
                                         * @throws {Error} If the payload is not a reader or valid buffer
                                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                         */
                                        OpenUriAction.decode = function decode(reader, length) {
                                            if (!(reader instanceof $Reader))
                                                reader = $Reader.create(reader);
                                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button.OpenUriAction();
                                            while (reader.pos < end) {
                                                var tag = reader.uint32();
                                                switch (tag >>> 3) {
                                                case 1: {
                                                        message.uri = reader.string();
                                                        break;
                                                    }
                                                default:
                                                    reader.skipType(tag & 7);
                                                    break;
                                                }
                                            }
                                            return message;
                                        };
    
                                        /**
                                         * Decodes an OpenUriAction message from the specified reader or buffer, length delimited.
                                         * @function decodeDelimited
                                         * @memberof google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button.OpenUriAction
                                         * @static
                                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                         * @returns {google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button.OpenUriAction} OpenUriAction
                                         * @throws {Error} If the payload is not a reader or valid buffer
                                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                         */
                                        OpenUriAction.decodeDelimited = function decodeDelimited(reader) {
                                            if (!(reader instanceof $Reader))
                                                reader = new $Reader(reader);
                                            return this.decode(reader, reader.uint32());
                                        };
    
                                        /**
                                         * Verifies an OpenUriAction message.
                                         * @function verify
                                         * @memberof google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button.OpenUriAction
                                         * @static
                                         * @param {Object.<string,*>} message Plain object to verify
                                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                         */
                                        OpenUriAction.verify = function verify(message) {
                                            if (typeof message !== "object" || message === null)
                                                return "object expected";
                                            if (message.uri != null && message.hasOwnProperty("uri"))
                                                if (!$util.isString(message.uri))
                                                    return "uri: string expected";
                                            return null;
                                        };
    
                                        /**
                                         * Creates an OpenUriAction message from a plain object. Also converts values to their respective internal types.
                                         * @function fromObject
                                         * @memberof google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button.OpenUriAction
                                         * @static
                                         * @param {Object.<string,*>} object Plain object
                                         * @returns {google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button.OpenUriAction} OpenUriAction
                                         */
                                        OpenUriAction.fromObject = function fromObject(object) {
                                            if (object instanceof $root.google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button.OpenUriAction)
                                                return object;
                                            var message = new $root.google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button.OpenUriAction();
                                            if (object.uri != null)
                                                message.uri = String(object.uri);
                                            return message;
                                        };
    
                                        /**
                                         * Creates a plain object from an OpenUriAction message. Also converts values to other types if specified.
                                         * @function toObject
                                         * @memberof google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button.OpenUriAction
                                         * @static
                                         * @param {google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button.OpenUriAction} message OpenUriAction
                                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                                         * @returns {Object.<string,*>} Plain object
                                         */
                                        OpenUriAction.toObject = function toObject(message, options) {
                                            if (!options)
                                                options = {};
                                            var object = {};
                                            if (options.defaults)
                                                object.uri = "";
                                            if (message.uri != null && message.hasOwnProperty("uri"))
                                                object.uri = message.uri;
                                            return object;
                                        };
    
                                        /**
                                         * Converts this OpenUriAction to JSON.
                                         * @function toJSON
                                         * @memberof google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button.OpenUriAction
                                         * @instance
                                         * @returns {Object.<string,*>} JSON object
                                         */
                                        OpenUriAction.prototype.toJSON = function toJSON() {
                                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                        };
    
                                        /**
                                         * Gets the default type url for OpenUriAction
                                         * @function getTypeUrl
                                         * @memberof google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button.OpenUriAction
                                         * @static
                                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                         * @returns {string} The default type url
                                         */
                                        OpenUriAction.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                            if (typeUrlPrefix === undefined) {
                                                typeUrlPrefix = "type.googleapis.com";
                                            }
                                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button.OpenUriAction";
                                        };
    
                                        return OpenUriAction;
                                    })();
    
                                    return Button;
                                })();
    
                                return BasicCard;
                            })();
    
                            Message.Suggestion = (function() {
    
                                /**
                                 * Properties of a Suggestion.
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message
                                 * @interface ISuggestion
                                 * @property {string|null} [title] Suggestion title
                                 */
    
                                /**
                                 * Constructs a new Suggestion.
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message
                                 * @classdesc Represents a Suggestion.
                                 * @implements ISuggestion
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.ISuggestion=} [properties] Properties to set
                                 */
                                function Suggestion(properties) {
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * Suggestion title.
                                 * @member {string} title
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Suggestion
                                 * @instance
                                 */
                                Suggestion.prototype.title = "";
    
                                /**
                                 * Creates a new Suggestion instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Suggestion
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.ISuggestion=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.Suggestion} Suggestion instance
                                 */
                                Suggestion.create = function create(properties) {
                                    return new Suggestion(properties);
                                };
    
                                /**
                                 * Encodes the specified Suggestion message. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Message.Suggestion.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Suggestion
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.ISuggestion} message Suggestion message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                Suggestion.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.title != null && Object.hasOwnProperty.call(message, "title"))
                                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.title);
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified Suggestion message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Message.Suggestion.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Suggestion
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.ISuggestion} message Suggestion message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                Suggestion.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a Suggestion message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Suggestion
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.Suggestion} Suggestion
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                Suggestion.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.Intent.Message.Suggestion();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                message.title = reader.string();
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a Suggestion message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Suggestion
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.Suggestion} Suggestion
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                Suggestion.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a Suggestion message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Suggestion
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                Suggestion.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.title != null && message.hasOwnProperty("title"))
                                        if (!$util.isString(message.title))
                                            return "title: string expected";
                                    return null;
                                };
    
                                /**
                                 * Creates a Suggestion message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Suggestion
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.Suggestion} Suggestion
                                 */
                                Suggestion.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2.Intent.Message.Suggestion)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2.Intent.Message.Suggestion();
                                    if (object.title != null)
                                        message.title = String(object.title);
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a Suggestion message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Suggestion
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.Suggestion} message Suggestion
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                Suggestion.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.defaults)
                                        object.title = "";
                                    if (message.title != null && message.hasOwnProperty("title"))
                                        object.title = message.title;
                                    return object;
                                };
    
                                /**
                                 * Converts this Suggestion to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Suggestion
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                Suggestion.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for Suggestion
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Suggestion
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                Suggestion.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2.Intent.Message.Suggestion";
                                };
    
                                return Suggestion;
                            })();
    
                            Message.Suggestions = (function() {
    
                                /**
                                 * Properties of a Suggestions.
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message
                                 * @interface ISuggestions
                                 * @property {Array.<google.cloud.dialogflow.v2.Intent.Message.ISuggestion>|null} [suggestions] Suggestions suggestions
                                 */
    
                                /**
                                 * Constructs a new Suggestions.
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message
                                 * @classdesc Represents a Suggestions.
                                 * @implements ISuggestions
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.ISuggestions=} [properties] Properties to set
                                 */
                                function Suggestions(properties) {
                                    this.suggestions = [];
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * Suggestions suggestions.
                                 * @member {Array.<google.cloud.dialogflow.v2.Intent.Message.ISuggestion>} suggestions
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Suggestions
                                 * @instance
                                 */
                                Suggestions.prototype.suggestions = $util.emptyArray;
    
                                /**
                                 * Creates a new Suggestions instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Suggestions
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.ISuggestions=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.Suggestions} Suggestions instance
                                 */
                                Suggestions.create = function create(properties) {
                                    return new Suggestions(properties);
                                };
    
                                /**
                                 * Encodes the specified Suggestions message. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Message.Suggestions.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Suggestions
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.ISuggestions} message Suggestions message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                Suggestions.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.suggestions != null && message.suggestions.length)
                                        for (var i = 0; i < message.suggestions.length; ++i)
                                            $root.google.cloud.dialogflow.v2.Intent.Message.Suggestion.encode(message.suggestions[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified Suggestions message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Message.Suggestions.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Suggestions
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.ISuggestions} message Suggestions message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                Suggestions.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a Suggestions message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Suggestions
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.Suggestions} Suggestions
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                Suggestions.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.Intent.Message.Suggestions();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                if (!(message.suggestions && message.suggestions.length))
                                                    message.suggestions = [];
                                                message.suggestions.push($root.google.cloud.dialogflow.v2.Intent.Message.Suggestion.decode(reader, reader.uint32()));
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a Suggestions message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Suggestions
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.Suggestions} Suggestions
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                Suggestions.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a Suggestions message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Suggestions
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                Suggestions.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.suggestions != null && message.hasOwnProperty("suggestions")) {
                                        if (!Array.isArray(message.suggestions))
                                            return "suggestions: array expected";
                                        for (var i = 0; i < message.suggestions.length; ++i) {
                                            var error = $root.google.cloud.dialogflow.v2.Intent.Message.Suggestion.verify(message.suggestions[i]);
                                            if (error)
                                                return "suggestions." + error;
                                        }
                                    }
                                    return null;
                                };
    
                                /**
                                 * Creates a Suggestions message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Suggestions
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.Suggestions} Suggestions
                                 */
                                Suggestions.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2.Intent.Message.Suggestions)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2.Intent.Message.Suggestions();
                                    if (object.suggestions) {
                                        if (!Array.isArray(object.suggestions))
                                            throw TypeError(".google.cloud.dialogflow.v2.Intent.Message.Suggestions.suggestions: array expected");
                                        message.suggestions = [];
                                        for (var i = 0; i < object.suggestions.length; ++i) {
                                            if (typeof object.suggestions[i] !== "object")
                                                throw TypeError(".google.cloud.dialogflow.v2.Intent.Message.Suggestions.suggestions: object expected");
                                            message.suggestions[i] = $root.google.cloud.dialogflow.v2.Intent.Message.Suggestion.fromObject(object.suggestions[i]);
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a Suggestions message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Suggestions
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.Suggestions} message Suggestions
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                Suggestions.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.arrays || options.defaults)
                                        object.suggestions = [];
                                    if (message.suggestions && message.suggestions.length) {
                                        object.suggestions = [];
                                        for (var j = 0; j < message.suggestions.length; ++j)
                                            object.suggestions[j] = $root.google.cloud.dialogflow.v2.Intent.Message.Suggestion.toObject(message.suggestions[j], options);
                                    }
                                    return object;
                                };
    
                                /**
                                 * Converts this Suggestions to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Suggestions
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                Suggestions.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for Suggestions
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.Suggestions
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                Suggestions.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2.Intent.Message.Suggestions";
                                };
    
                                return Suggestions;
                            })();
    
                            Message.LinkOutSuggestion = (function() {
    
                                /**
                                 * Properties of a LinkOutSuggestion.
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message
                                 * @interface ILinkOutSuggestion
                                 * @property {string|null} [destinationName] LinkOutSuggestion destinationName
                                 * @property {string|null} [uri] LinkOutSuggestion uri
                                 */
    
                                /**
                                 * Constructs a new LinkOutSuggestion.
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message
                                 * @classdesc Represents a LinkOutSuggestion.
                                 * @implements ILinkOutSuggestion
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.ILinkOutSuggestion=} [properties] Properties to set
                                 */
                                function LinkOutSuggestion(properties) {
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * LinkOutSuggestion destinationName.
                                 * @member {string} destinationName
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.LinkOutSuggestion
                                 * @instance
                                 */
                                LinkOutSuggestion.prototype.destinationName = "";
    
                                /**
                                 * LinkOutSuggestion uri.
                                 * @member {string} uri
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.LinkOutSuggestion
                                 * @instance
                                 */
                                LinkOutSuggestion.prototype.uri = "";
    
                                /**
                                 * Creates a new LinkOutSuggestion instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.LinkOutSuggestion
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.ILinkOutSuggestion=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.LinkOutSuggestion} LinkOutSuggestion instance
                                 */
                                LinkOutSuggestion.create = function create(properties) {
                                    return new LinkOutSuggestion(properties);
                                };
    
                                /**
                                 * Encodes the specified LinkOutSuggestion message. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Message.LinkOutSuggestion.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.LinkOutSuggestion
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.ILinkOutSuggestion} message LinkOutSuggestion message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                LinkOutSuggestion.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.destinationName != null && Object.hasOwnProperty.call(message, "destinationName"))
                                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.destinationName);
                                    if (message.uri != null && Object.hasOwnProperty.call(message, "uri"))
                                        writer.uint32(/* id 2, wireType 2 =*/18).string(message.uri);
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified LinkOutSuggestion message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Message.LinkOutSuggestion.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.LinkOutSuggestion
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.ILinkOutSuggestion} message LinkOutSuggestion message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                LinkOutSuggestion.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a LinkOutSuggestion message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.LinkOutSuggestion
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.LinkOutSuggestion} LinkOutSuggestion
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                LinkOutSuggestion.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.Intent.Message.LinkOutSuggestion();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                message.destinationName = reader.string();
                                                break;
                                            }
                                        case 2: {
                                                message.uri = reader.string();
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a LinkOutSuggestion message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.LinkOutSuggestion
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.LinkOutSuggestion} LinkOutSuggestion
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                LinkOutSuggestion.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a LinkOutSuggestion message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.LinkOutSuggestion
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                LinkOutSuggestion.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.destinationName != null && message.hasOwnProperty("destinationName"))
                                        if (!$util.isString(message.destinationName))
                                            return "destinationName: string expected";
                                    if (message.uri != null && message.hasOwnProperty("uri"))
                                        if (!$util.isString(message.uri))
                                            return "uri: string expected";
                                    return null;
                                };
    
                                /**
                                 * Creates a LinkOutSuggestion message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.LinkOutSuggestion
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.LinkOutSuggestion} LinkOutSuggestion
                                 */
                                LinkOutSuggestion.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2.Intent.Message.LinkOutSuggestion)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2.Intent.Message.LinkOutSuggestion();
                                    if (object.destinationName != null)
                                        message.destinationName = String(object.destinationName);
                                    if (object.uri != null)
                                        message.uri = String(object.uri);
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a LinkOutSuggestion message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.LinkOutSuggestion
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.LinkOutSuggestion} message LinkOutSuggestion
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                LinkOutSuggestion.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.defaults) {
                                        object.destinationName = "";
                                        object.uri = "";
                                    }
                                    if (message.destinationName != null && message.hasOwnProperty("destinationName"))
                                        object.destinationName = message.destinationName;
                                    if (message.uri != null && message.hasOwnProperty("uri"))
                                        object.uri = message.uri;
                                    return object;
                                };
    
                                /**
                                 * Converts this LinkOutSuggestion to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.LinkOutSuggestion
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                LinkOutSuggestion.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for LinkOutSuggestion
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.LinkOutSuggestion
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                LinkOutSuggestion.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2.Intent.Message.LinkOutSuggestion";
                                };
    
                                return LinkOutSuggestion;
                            })();
    
                            Message.ListSelect = (function() {
    
                                /**
                                 * Properties of a ListSelect.
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message
                                 * @interface IListSelect
                                 * @property {string|null} [title] ListSelect title
                                 * @property {Array.<google.cloud.dialogflow.v2.Intent.Message.ListSelect.IItem>|null} [items] ListSelect items
                                 * @property {string|null} [subtitle] ListSelect subtitle
                                 */
    
                                /**
                                 * Constructs a new ListSelect.
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message
                                 * @classdesc Represents a ListSelect.
                                 * @implements IListSelect
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.IListSelect=} [properties] Properties to set
                                 */
                                function ListSelect(properties) {
                                    this.items = [];
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * ListSelect title.
                                 * @member {string} title
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.ListSelect
                                 * @instance
                                 */
                                ListSelect.prototype.title = "";
    
                                /**
                                 * ListSelect items.
                                 * @member {Array.<google.cloud.dialogflow.v2.Intent.Message.ListSelect.IItem>} items
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.ListSelect
                                 * @instance
                                 */
                                ListSelect.prototype.items = $util.emptyArray;
    
                                /**
                                 * ListSelect subtitle.
                                 * @member {string} subtitle
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.ListSelect
                                 * @instance
                                 */
                                ListSelect.prototype.subtitle = "";
    
                                /**
                                 * Creates a new ListSelect instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.ListSelect
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.IListSelect=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.ListSelect} ListSelect instance
                                 */
                                ListSelect.create = function create(properties) {
                                    return new ListSelect(properties);
                                };
    
                                /**
                                 * Encodes the specified ListSelect message. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Message.ListSelect.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.ListSelect
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.IListSelect} message ListSelect message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                ListSelect.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.title != null && Object.hasOwnProperty.call(message, "title"))
                                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.title);
                                    if (message.items != null && message.items.length)
                                        for (var i = 0; i < message.items.length; ++i)
                                            $root.google.cloud.dialogflow.v2.Intent.Message.ListSelect.Item.encode(message.items[i], writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                                    if (message.subtitle != null && Object.hasOwnProperty.call(message, "subtitle"))
                                        writer.uint32(/* id 3, wireType 2 =*/26).string(message.subtitle);
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified ListSelect message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Message.ListSelect.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.ListSelect
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.IListSelect} message ListSelect message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                ListSelect.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a ListSelect message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.ListSelect
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.ListSelect} ListSelect
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                ListSelect.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.Intent.Message.ListSelect();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                message.title = reader.string();
                                                break;
                                            }
                                        case 2: {
                                                if (!(message.items && message.items.length))
                                                    message.items = [];
                                                message.items.push($root.google.cloud.dialogflow.v2.Intent.Message.ListSelect.Item.decode(reader, reader.uint32()));
                                                break;
                                            }
                                        case 3: {
                                                message.subtitle = reader.string();
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a ListSelect message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.ListSelect
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.ListSelect} ListSelect
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                ListSelect.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a ListSelect message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.ListSelect
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                ListSelect.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.title != null && message.hasOwnProperty("title"))
                                        if (!$util.isString(message.title))
                                            return "title: string expected";
                                    if (message.items != null && message.hasOwnProperty("items")) {
                                        if (!Array.isArray(message.items))
                                            return "items: array expected";
                                        for (var i = 0; i < message.items.length; ++i) {
                                            var error = $root.google.cloud.dialogflow.v2.Intent.Message.ListSelect.Item.verify(message.items[i]);
                                            if (error)
                                                return "items." + error;
                                        }
                                    }
                                    if (message.subtitle != null && message.hasOwnProperty("subtitle"))
                                        if (!$util.isString(message.subtitle))
                                            return "subtitle: string expected";
                                    return null;
                                };
    
                                /**
                                 * Creates a ListSelect message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.ListSelect
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.ListSelect} ListSelect
                                 */
                                ListSelect.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2.Intent.Message.ListSelect)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2.Intent.Message.ListSelect();
                                    if (object.title != null)
                                        message.title = String(object.title);
                                    if (object.items) {
                                        if (!Array.isArray(object.items))
                                            throw TypeError(".google.cloud.dialogflow.v2.Intent.Message.ListSelect.items: array expected");
                                        message.items = [];
                                        for (var i = 0; i < object.items.length; ++i) {
                                            if (typeof object.items[i] !== "object")
                                                throw TypeError(".google.cloud.dialogflow.v2.Intent.Message.ListSelect.items: object expected");
                                            message.items[i] = $root.google.cloud.dialogflow.v2.Intent.Message.ListSelect.Item.fromObject(object.items[i]);
                                        }
                                    }
                                    if (object.subtitle != null)
                                        message.subtitle = String(object.subtitle);
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a ListSelect message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.ListSelect
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.ListSelect} message ListSelect
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                ListSelect.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.arrays || options.defaults)
                                        object.items = [];
                                    if (options.defaults) {
                                        object.title = "";
                                        object.subtitle = "";
                                    }
                                    if (message.title != null && message.hasOwnProperty("title"))
                                        object.title = message.title;
                                    if (message.items && message.items.length) {
                                        object.items = [];
                                        for (var j = 0; j < message.items.length; ++j)
                                            object.items[j] = $root.google.cloud.dialogflow.v2.Intent.Message.ListSelect.Item.toObject(message.items[j], options);
                                    }
                                    if (message.subtitle != null && message.hasOwnProperty("subtitle"))
                                        object.subtitle = message.subtitle;
                                    return object;
                                };
    
                                /**
                                 * Converts this ListSelect to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.ListSelect
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                ListSelect.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for ListSelect
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.ListSelect
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                ListSelect.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2.Intent.Message.ListSelect";
                                };
    
                                ListSelect.Item = (function() {
    
                                    /**
                                     * Properties of an Item.
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.ListSelect
                                     * @interface IItem
                                     * @property {google.cloud.dialogflow.v2.Intent.Message.ISelectItemInfo|null} [info] Item info
                                     * @property {string|null} [title] Item title
                                     * @property {string|null} [description] Item description
                                     * @property {google.cloud.dialogflow.v2.Intent.Message.IImage|null} [image] Item image
                                     */
    
                                    /**
                                     * Constructs a new Item.
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.ListSelect
                                     * @classdesc Represents an Item.
                                     * @implements IItem
                                     * @constructor
                                     * @param {google.cloud.dialogflow.v2.Intent.Message.ListSelect.IItem=} [properties] Properties to set
                                     */
                                    function Item(properties) {
                                        if (properties)
                                            for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                                if (properties[keys[i]] != null)
                                                    this[keys[i]] = properties[keys[i]];
                                    }
    
                                    /**
                                     * Item info.
                                     * @member {google.cloud.dialogflow.v2.Intent.Message.ISelectItemInfo|null|undefined} info
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.ListSelect.Item
                                     * @instance
                                     */
                                    Item.prototype.info = null;
    
                                    /**
                                     * Item title.
                                     * @member {string} title
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.ListSelect.Item
                                     * @instance
                                     */
                                    Item.prototype.title = "";
    
                                    /**
                                     * Item description.
                                     * @member {string} description
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.ListSelect.Item
                                     * @instance
                                     */
                                    Item.prototype.description = "";
    
                                    /**
                                     * Item image.
                                     * @member {google.cloud.dialogflow.v2.Intent.Message.IImage|null|undefined} image
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.ListSelect.Item
                                     * @instance
                                     */
                                    Item.prototype.image = null;
    
                                    /**
                                     * Creates a new Item instance using the specified properties.
                                     * @function create
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.ListSelect.Item
                                     * @static
                                     * @param {google.cloud.dialogflow.v2.Intent.Message.ListSelect.IItem=} [properties] Properties to set
                                     * @returns {google.cloud.dialogflow.v2.Intent.Message.ListSelect.Item} Item instance
                                     */
                                    Item.create = function create(properties) {
                                        return new Item(properties);
                                    };
    
                                    /**
                                     * Encodes the specified Item message. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Message.ListSelect.Item.verify|verify} messages.
                                     * @function encode
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.ListSelect.Item
                                     * @static
                                     * @param {google.cloud.dialogflow.v2.Intent.Message.ListSelect.IItem} message Item message or plain object to encode
                                     * @param {$protobuf.Writer} [writer] Writer to encode to
                                     * @returns {$protobuf.Writer} Writer
                                     */
                                    Item.encode = function encode(message, writer) {
                                        if (!writer)
                                            writer = $Writer.create();
                                        if (message.info != null && Object.hasOwnProperty.call(message, "info"))
                                            $root.google.cloud.dialogflow.v2.Intent.Message.SelectItemInfo.encode(message.info, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                                        if (message.title != null && Object.hasOwnProperty.call(message, "title"))
                                            writer.uint32(/* id 2, wireType 2 =*/18).string(message.title);
                                        if (message.description != null && Object.hasOwnProperty.call(message, "description"))
                                            writer.uint32(/* id 3, wireType 2 =*/26).string(message.description);
                                        if (message.image != null && Object.hasOwnProperty.call(message, "image"))
                                            $root.google.cloud.dialogflow.v2.Intent.Message.Image.encode(message.image, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                                        return writer;
                                    };
    
                                    /**
                                     * Encodes the specified Item message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Message.ListSelect.Item.verify|verify} messages.
                                     * @function encodeDelimited
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.ListSelect.Item
                                     * @static
                                     * @param {google.cloud.dialogflow.v2.Intent.Message.ListSelect.IItem} message Item message or plain object to encode
                                     * @param {$protobuf.Writer} [writer] Writer to encode to
                                     * @returns {$protobuf.Writer} Writer
                                     */
                                    Item.encodeDelimited = function encodeDelimited(message, writer) {
                                        return this.encode(message, writer).ldelim();
                                    };
    
                                    /**
                                     * Decodes an Item message from the specified reader or buffer.
                                     * @function decode
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.ListSelect.Item
                                     * @static
                                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                     * @param {number} [length] Message length if known beforehand
                                     * @returns {google.cloud.dialogflow.v2.Intent.Message.ListSelect.Item} Item
                                     * @throws {Error} If the payload is not a reader or valid buffer
                                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                     */
                                    Item.decode = function decode(reader, length) {
                                        if (!(reader instanceof $Reader))
                                            reader = $Reader.create(reader);
                                        var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.Intent.Message.ListSelect.Item();
                                        while (reader.pos < end) {
                                            var tag = reader.uint32();
                                            switch (tag >>> 3) {
                                            case 1: {
                                                    message.info = $root.google.cloud.dialogflow.v2.Intent.Message.SelectItemInfo.decode(reader, reader.uint32());
                                                    break;
                                                }
                                            case 2: {
                                                    message.title = reader.string();
                                                    break;
                                                }
                                            case 3: {
                                                    message.description = reader.string();
                                                    break;
                                                }
                                            case 4: {
                                                    message.image = $root.google.cloud.dialogflow.v2.Intent.Message.Image.decode(reader, reader.uint32());
                                                    break;
                                                }
                                            default:
                                                reader.skipType(tag & 7);
                                                break;
                                            }
                                        }
                                        return message;
                                    };
    
                                    /**
                                     * Decodes an Item message from the specified reader or buffer, length delimited.
                                     * @function decodeDelimited
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.ListSelect.Item
                                     * @static
                                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                     * @returns {google.cloud.dialogflow.v2.Intent.Message.ListSelect.Item} Item
                                     * @throws {Error} If the payload is not a reader or valid buffer
                                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                     */
                                    Item.decodeDelimited = function decodeDelimited(reader) {
                                        if (!(reader instanceof $Reader))
                                            reader = new $Reader(reader);
                                        return this.decode(reader, reader.uint32());
                                    };
    
                                    /**
                                     * Verifies an Item message.
                                     * @function verify
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.ListSelect.Item
                                     * @static
                                     * @param {Object.<string,*>} message Plain object to verify
                                     * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                     */
                                    Item.verify = function verify(message) {
                                        if (typeof message !== "object" || message === null)
                                            return "object expected";
                                        if (message.info != null && message.hasOwnProperty("info")) {
                                            var error = $root.google.cloud.dialogflow.v2.Intent.Message.SelectItemInfo.verify(message.info);
                                            if (error)
                                                return "info." + error;
                                        }
                                        if (message.title != null && message.hasOwnProperty("title"))
                                            if (!$util.isString(message.title))
                                                return "title: string expected";
                                        if (message.description != null && message.hasOwnProperty("description"))
                                            if (!$util.isString(message.description))
                                                return "description: string expected";
                                        if (message.image != null && message.hasOwnProperty("image")) {
                                            var error = $root.google.cloud.dialogflow.v2.Intent.Message.Image.verify(message.image);
                                            if (error)
                                                return "image." + error;
                                        }
                                        return null;
                                    };
    
                                    /**
                                     * Creates an Item message from a plain object. Also converts values to their respective internal types.
                                     * @function fromObject
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.ListSelect.Item
                                     * @static
                                     * @param {Object.<string,*>} object Plain object
                                     * @returns {google.cloud.dialogflow.v2.Intent.Message.ListSelect.Item} Item
                                     */
                                    Item.fromObject = function fromObject(object) {
                                        if (object instanceof $root.google.cloud.dialogflow.v2.Intent.Message.ListSelect.Item)
                                            return object;
                                        var message = new $root.google.cloud.dialogflow.v2.Intent.Message.ListSelect.Item();
                                        if (object.info != null) {
                                            if (typeof object.info !== "object")
                                                throw TypeError(".google.cloud.dialogflow.v2.Intent.Message.ListSelect.Item.info: object expected");
                                            message.info = $root.google.cloud.dialogflow.v2.Intent.Message.SelectItemInfo.fromObject(object.info);
                                        }
                                        if (object.title != null)
                                            message.title = String(object.title);
                                        if (object.description != null)
                                            message.description = String(object.description);
                                        if (object.image != null) {
                                            if (typeof object.image !== "object")
                                                throw TypeError(".google.cloud.dialogflow.v2.Intent.Message.ListSelect.Item.image: object expected");
                                            message.image = $root.google.cloud.dialogflow.v2.Intent.Message.Image.fromObject(object.image);
                                        }
                                        return message;
                                    };
    
                                    /**
                                     * Creates a plain object from an Item message. Also converts values to other types if specified.
                                     * @function toObject
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.ListSelect.Item
                                     * @static
                                     * @param {google.cloud.dialogflow.v2.Intent.Message.ListSelect.Item} message Item
                                     * @param {$protobuf.IConversionOptions} [options] Conversion options
                                     * @returns {Object.<string,*>} Plain object
                                     */
                                    Item.toObject = function toObject(message, options) {
                                        if (!options)
                                            options = {};
                                        var object = {};
                                        if (options.defaults) {
                                            object.info = null;
                                            object.title = "";
                                            object.description = "";
                                            object.image = null;
                                        }
                                        if (message.info != null && message.hasOwnProperty("info"))
                                            object.info = $root.google.cloud.dialogflow.v2.Intent.Message.SelectItemInfo.toObject(message.info, options);
                                        if (message.title != null && message.hasOwnProperty("title"))
                                            object.title = message.title;
                                        if (message.description != null && message.hasOwnProperty("description"))
                                            object.description = message.description;
                                        if (message.image != null && message.hasOwnProperty("image"))
                                            object.image = $root.google.cloud.dialogflow.v2.Intent.Message.Image.toObject(message.image, options);
                                        return object;
                                    };
    
                                    /**
                                     * Converts this Item to JSON.
                                     * @function toJSON
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.ListSelect.Item
                                     * @instance
                                     * @returns {Object.<string,*>} JSON object
                                     */
                                    Item.prototype.toJSON = function toJSON() {
                                        return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                    };
    
                                    /**
                                     * Gets the default type url for Item
                                     * @function getTypeUrl
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.ListSelect.Item
                                     * @static
                                     * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                     * @returns {string} The default type url
                                     */
                                    Item.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                        if (typeUrlPrefix === undefined) {
                                            typeUrlPrefix = "type.googleapis.com";
                                        }
                                        return typeUrlPrefix + "/google.cloud.dialogflow.v2.Intent.Message.ListSelect.Item";
                                    };
    
                                    return Item;
                                })();
    
                                return ListSelect;
                            })();
    
                            Message.CarouselSelect = (function() {
    
                                /**
                                 * Properties of a CarouselSelect.
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message
                                 * @interface ICarouselSelect
                                 * @property {Array.<google.cloud.dialogflow.v2.Intent.Message.CarouselSelect.IItem>|null} [items] CarouselSelect items
                                 */
    
                                /**
                                 * Constructs a new CarouselSelect.
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message
                                 * @classdesc Represents a CarouselSelect.
                                 * @implements ICarouselSelect
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.ICarouselSelect=} [properties] Properties to set
                                 */
                                function CarouselSelect(properties) {
                                    this.items = [];
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * CarouselSelect items.
                                 * @member {Array.<google.cloud.dialogflow.v2.Intent.Message.CarouselSelect.IItem>} items
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.CarouselSelect
                                 * @instance
                                 */
                                CarouselSelect.prototype.items = $util.emptyArray;
    
                                /**
                                 * Creates a new CarouselSelect instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.CarouselSelect
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.ICarouselSelect=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.CarouselSelect} CarouselSelect instance
                                 */
                                CarouselSelect.create = function create(properties) {
                                    return new CarouselSelect(properties);
                                };
    
                                /**
                                 * Encodes the specified CarouselSelect message. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Message.CarouselSelect.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.CarouselSelect
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.ICarouselSelect} message CarouselSelect message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                CarouselSelect.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.items != null && message.items.length)
                                        for (var i = 0; i < message.items.length; ++i)
                                            $root.google.cloud.dialogflow.v2.Intent.Message.CarouselSelect.Item.encode(message.items[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified CarouselSelect message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Message.CarouselSelect.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.CarouselSelect
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.ICarouselSelect} message CarouselSelect message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                CarouselSelect.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a CarouselSelect message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.CarouselSelect
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.CarouselSelect} CarouselSelect
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                CarouselSelect.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.Intent.Message.CarouselSelect();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                if (!(message.items && message.items.length))
                                                    message.items = [];
                                                message.items.push($root.google.cloud.dialogflow.v2.Intent.Message.CarouselSelect.Item.decode(reader, reader.uint32()));
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a CarouselSelect message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.CarouselSelect
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.CarouselSelect} CarouselSelect
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                CarouselSelect.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a CarouselSelect message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.CarouselSelect
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                CarouselSelect.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.items != null && message.hasOwnProperty("items")) {
                                        if (!Array.isArray(message.items))
                                            return "items: array expected";
                                        for (var i = 0; i < message.items.length; ++i) {
                                            var error = $root.google.cloud.dialogflow.v2.Intent.Message.CarouselSelect.Item.verify(message.items[i]);
                                            if (error)
                                                return "items." + error;
                                        }
                                    }
                                    return null;
                                };
    
                                /**
                                 * Creates a CarouselSelect message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.CarouselSelect
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.CarouselSelect} CarouselSelect
                                 */
                                CarouselSelect.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2.Intent.Message.CarouselSelect)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2.Intent.Message.CarouselSelect();
                                    if (object.items) {
                                        if (!Array.isArray(object.items))
                                            throw TypeError(".google.cloud.dialogflow.v2.Intent.Message.CarouselSelect.items: array expected");
                                        message.items = [];
                                        for (var i = 0; i < object.items.length; ++i) {
                                            if (typeof object.items[i] !== "object")
                                                throw TypeError(".google.cloud.dialogflow.v2.Intent.Message.CarouselSelect.items: object expected");
                                            message.items[i] = $root.google.cloud.dialogflow.v2.Intent.Message.CarouselSelect.Item.fromObject(object.items[i]);
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a CarouselSelect message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.CarouselSelect
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.CarouselSelect} message CarouselSelect
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                CarouselSelect.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.arrays || options.defaults)
                                        object.items = [];
                                    if (message.items && message.items.length) {
                                        object.items = [];
                                        for (var j = 0; j < message.items.length; ++j)
                                            object.items[j] = $root.google.cloud.dialogflow.v2.Intent.Message.CarouselSelect.Item.toObject(message.items[j], options);
                                    }
                                    return object;
                                };
    
                                /**
                                 * Converts this CarouselSelect to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.CarouselSelect
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                CarouselSelect.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for CarouselSelect
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.CarouselSelect
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                CarouselSelect.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2.Intent.Message.CarouselSelect";
                                };
    
                                CarouselSelect.Item = (function() {
    
                                    /**
                                     * Properties of an Item.
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.CarouselSelect
                                     * @interface IItem
                                     * @property {google.cloud.dialogflow.v2.Intent.Message.ISelectItemInfo|null} [info] Item info
                                     * @property {string|null} [title] Item title
                                     * @property {string|null} [description] Item description
                                     * @property {google.cloud.dialogflow.v2.Intent.Message.IImage|null} [image] Item image
                                     */
    
                                    /**
                                     * Constructs a new Item.
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.CarouselSelect
                                     * @classdesc Represents an Item.
                                     * @implements IItem
                                     * @constructor
                                     * @param {google.cloud.dialogflow.v2.Intent.Message.CarouselSelect.IItem=} [properties] Properties to set
                                     */
                                    function Item(properties) {
                                        if (properties)
                                            for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                                if (properties[keys[i]] != null)
                                                    this[keys[i]] = properties[keys[i]];
                                    }
    
                                    /**
                                     * Item info.
                                     * @member {google.cloud.dialogflow.v2.Intent.Message.ISelectItemInfo|null|undefined} info
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.CarouselSelect.Item
                                     * @instance
                                     */
                                    Item.prototype.info = null;
    
                                    /**
                                     * Item title.
                                     * @member {string} title
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.CarouselSelect.Item
                                     * @instance
                                     */
                                    Item.prototype.title = "";
    
                                    /**
                                     * Item description.
                                     * @member {string} description
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.CarouselSelect.Item
                                     * @instance
                                     */
                                    Item.prototype.description = "";
    
                                    /**
                                     * Item image.
                                     * @member {google.cloud.dialogflow.v2.Intent.Message.IImage|null|undefined} image
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.CarouselSelect.Item
                                     * @instance
                                     */
                                    Item.prototype.image = null;
    
                                    /**
                                     * Creates a new Item instance using the specified properties.
                                     * @function create
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.CarouselSelect.Item
                                     * @static
                                     * @param {google.cloud.dialogflow.v2.Intent.Message.CarouselSelect.IItem=} [properties] Properties to set
                                     * @returns {google.cloud.dialogflow.v2.Intent.Message.CarouselSelect.Item} Item instance
                                     */
                                    Item.create = function create(properties) {
                                        return new Item(properties);
                                    };
    
                                    /**
                                     * Encodes the specified Item message. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Message.CarouselSelect.Item.verify|verify} messages.
                                     * @function encode
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.CarouselSelect.Item
                                     * @static
                                     * @param {google.cloud.dialogflow.v2.Intent.Message.CarouselSelect.IItem} message Item message or plain object to encode
                                     * @param {$protobuf.Writer} [writer] Writer to encode to
                                     * @returns {$protobuf.Writer} Writer
                                     */
                                    Item.encode = function encode(message, writer) {
                                        if (!writer)
                                            writer = $Writer.create();
                                        if (message.info != null && Object.hasOwnProperty.call(message, "info"))
                                            $root.google.cloud.dialogflow.v2.Intent.Message.SelectItemInfo.encode(message.info, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                                        if (message.title != null && Object.hasOwnProperty.call(message, "title"))
                                            writer.uint32(/* id 2, wireType 2 =*/18).string(message.title);
                                        if (message.description != null && Object.hasOwnProperty.call(message, "description"))
                                            writer.uint32(/* id 3, wireType 2 =*/26).string(message.description);
                                        if (message.image != null && Object.hasOwnProperty.call(message, "image"))
                                            $root.google.cloud.dialogflow.v2.Intent.Message.Image.encode(message.image, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                                        return writer;
                                    };
    
                                    /**
                                     * Encodes the specified Item message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Message.CarouselSelect.Item.verify|verify} messages.
                                     * @function encodeDelimited
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.CarouselSelect.Item
                                     * @static
                                     * @param {google.cloud.dialogflow.v2.Intent.Message.CarouselSelect.IItem} message Item message or plain object to encode
                                     * @param {$protobuf.Writer} [writer] Writer to encode to
                                     * @returns {$protobuf.Writer} Writer
                                     */
                                    Item.encodeDelimited = function encodeDelimited(message, writer) {
                                        return this.encode(message, writer).ldelim();
                                    };
    
                                    /**
                                     * Decodes an Item message from the specified reader or buffer.
                                     * @function decode
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.CarouselSelect.Item
                                     * @static
                                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                     * @param {number} [length] Message length if known beforehand
                                     * @returns {google.cloud.dialogflow.v2.Intent.Message.CarouselSelect.Item} Item
                                     * @throws {Error} If the payload is not a reader or valid buffer
                                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                     */
                                    Item.decode = function decode(reader, length) {
                                        if (!(reader instanceof $Reader))
                                            reader = $Reader.create(reader);
                                        var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.Intent.Message.CarouselSelect.Item();
                                        while (reader.pos < end) {
                                            var tag = reader.uint32();
                                            switch (tag >>> 3) {
                                            case 1: {
                                                    message.info = $root.google.cloud.dialogflow.v2.Intent.Message.SelectItemInfo.decode(reader, reader.uint32());
                                                    break;
                                                }
                                            case 2: {
                                                    message.title = reader.string();
                                                    break;
                                                }
                                            case 3: {
                                                    message.description = reader.string();
                                                    break;
                                                }
                                            case 4: {
                                                    message.image = $root.google.cloud.dialogflow.v2.Intent.Message.Image.decode(reader, reader.uint32());
                                                    break;
                                                }
                                            default:
                                                reader.skipType(tag & 7);
                                                break;
                                            }
                                        }
                                        return message;
                                    };
    
                                    /**
                                     * Decodes an Item message from the specified reader or buffer, length delimited.
                                     * @function decodeDelimited
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.CarouselSelect.Item
                                     * @static
                                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                     * @returns {google.cloud.dialogflow.v2.Intent.Message.CarouselSelect.Item} Item
                                     * @throws {Error} If the payload is not a reader or valid buffer
                                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                     */
                                    Item.decodeDelimited = function decodeDelimited(reader) {
                                        if (!(reader instanceof $Reader))
                                            reader = new $Reader(reader);
                                        return this.decode(reader, reader.uint32());
                                    };
    
                                    /**
                                     * Verifies an Item message.
                                     * @function verify
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.CarouselSelect.Item
                                     * @static
                                     * @param {Object.<string,*>} message Plain object to verify
                                     * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                     */
                                    Item.verify = function verify(message) {
                                        if (typeof message !== "object" || message === null)
                                            return "object expected";
                                        if (message.info != null && message.hasOwnProperty("info")) {
                                            var error = $root.google.cloud.dialogflow.v2.Intent.Message.SelectItemInfo.verify(message.info);
                                            if (error)
                                                return "info." + error;
                                        }
                                        if (message.title != null && message.hasOwnProperty("title"))
                                            if (!$util.isString(message.title))
                                                return "title: string expected";
                                        if (message.description != null && message.hasOwnProperty("description"))
                                            if (!$util.isString(message.description))
                                                return "description: string expected";
                                        if (message.image != null && message.hasOwnProperty("image")) {
                                            var error = $root.google.cloud.dialogflow.v2.Intent.Message.Image.verify(message.image);
                                            if (error)
                                                return "image." + error;
                                        }
                                        return null;
                                    };
    
                                    /**
                                     * Creates an Item message from a plain object. Also converts values to their respective internal types.
                                     * @function fromObject
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.CarouselSelect.Item
                                     * @static
                                     * @param {Object.<string,*>} object Plain object
                                     * @returns {google.cloud.dialogflow.v2.Intent.Message.CarouselSelect.Item} Item
                                     */
                                    Item.fromObject = function fromObject(object) {
                                        if (object instanceof $root.google.cloud.dialogflow.v2.Intent.Message.CarouselSelect.Item)
                                            return object;
                                        var message = new $root.google.cloud.dialogflow.v2.Intent.Message.CarouselSelect.Item();
                                        if (object.info != null) {
                                            if (typeof object.info !== "object")
                                                throw TypeError(".google.cloud.dialogflow.v2.Intent.Message.CarouselSelect.Item.info: object expected");
                                            message.info = $root.google.cloud.dialogflow.v2.Intent.Message.SelectItemInfo.fromObject(object.info);
                                        }
                                        if (object.title != null)
                                            message.title = String(object.title);
                                        if (object.description != null)
                                            message.description = String(object.description);
                                        if (object.image != null) {
                                            if (typeof object.image !== "object")
                                                throw TypeError(".google.cloud.dialogflow.v2.Intent.Message.CarouselSelect.Item.image: object expected");
                                            message.image = $root.google.cloud.dialogflow.v2.Intent.Message.Image.fromObject(object.image);
                                        }
                                        return message;
                                    };
    
                                    /**
                                     * Creates a plain object from an Item message. Also converts values to other types if specified.
                                     * @function toObject
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.CarouselSelect.Item
                                     * @static
                                     * @param {google.cloud.dialogflow.v2.Intent.Message.CarouselSelect.Item} message Item
                                     * @param {$protobuf.IConversionOptions} [options] Conversion options
                                     * @returns {Object.<string,*>} Plain object
                                     */
                                    Item.toObject = function toObject(message, options) {
                                        if (!options)
                                            options = {};
                                        var object = {};
                                        if (options.defaults) {
                                            object.info = null;
                                            object.title = "";
                                            object.description = "";
                                            object.image = null;
                                        }
                                        if (message.info != null && message.hasOwnProperty("info"))
                                            object.info = $root.google.cloud.dialogflow.v2.Intent.Message.SelectItemInfo.toObject(message.info, options);
                                        if (message.title != null && message.hasOwnProperty("title"))
                                            object.title = message.title;
                                        if (message.description != null && message.hasOwnProperty("description"))
                                            object.description = message.description;
                                        if (message.image != null && message.hasOwnProperty("image"))
                                            object.image = $root.google.cloud.dialogflow.v2.Intent.Message.Image.toObject(message.image, options);
                                        return object;
                                    };
    
                                    /**
                                     * Converts this Item to JSON.
                                     * @function toJSON
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.CarouselSelect.Item
                                     * @instance
                                     * @returns {Object.<string,*>} JSON object
                                     */
                                    Item.prototype.toJSON = function toJSON() {
                                        return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                    };
    
                                    /**
                                     * Gets the default type url for Item
                                     * @function getTypeUrl
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.CarouselSelect.Item
                                     * @static
                                     * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                     * @returns {string} The default type url
                                     */
                                    Item.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                        if (typeUrlPrefix === undefined) {
                                            typeUrlPrefix = "type.googleapis.com";
                                        }
                                        return typeUrlPrefix + "/google.cloud.dialogflow.v2.Intent.Message.CarouselSelect.Item";
                                    };
    
                                    return Item;
                                })();
    
                                return CarouselSelect;
                            })();
    
                            Message.SelectItemInfo = (function() {
    
                                /**
                                 * Properties of a SelectItemInfo.
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message
                                 * @interface ISelectItemInfo
                                 * @property {string|null} [key] SelectItemInfo key
                                 * @property {Array.<string>|null} [synonyms] SelectItemInfo synonyms
                                 */
    
                                /**
                                 * Constructs a new SelectItemInfo.
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message
                                 * @classdesc Represents a SelectItemInfo.
                                 * @implements ISelectItemInfo
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.ISelectItemInfo=} [properties] Properties to set
                                 */
                                function SelectItemInfo(properties) {
                                    this.synonyms = [];
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * SelectItemInfo key.
                                 * @member {string} key
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.SelectItemInfo
                                 * @instance
                                 */
                                SelectItemInfo.prototype.key = "";
    
                                /**
                                 * SelectItemInfo synonyms.
                                 * @member {Array.<string>} synonyms
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.SelectItemInfo
                                 * @instance
                                 */
                                SelectItemInfo.prototype.synonyms = $util.emptyArray;
    
                                /**
                                 * Creates a new SelectItemInfo instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.SelectItemInfo
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.ISelectItemInfo=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.SelectItemInfo} SelectItemInfo instance
                                 */
                                SelectItemInfo.create = function create(properties) {
                                    return new SelectItemInfo(properties);
                                };
    
                                /**
                                 * Encodes the specified SelectItemInfo message. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Message.SelectItemInfo.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.SelectItemInfo
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.ISelectItemInfo} message SelectItemInfo message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                SelectItemInfo.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.key != null && Object.hasOwnProperty.call(message, "key"))
                                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.key);
                                    if (message.synonyms != null && message.synonyms.length)
                                        for (var i = 0; i < message.synonyms.length; ++i)
                                            writer.uint32(/* id 2, wireType 2 =*/18).string(message.synonyms[i]);
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified SelectItemInfo message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Message.SelectItemInfo.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.SelectItemInfo
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.ISelectItemInfo} message SelectItemInfo message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                SelectItemInfo.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a SelectItemInfo message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.SelectItemInfo
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.SelectItemInfo} SelectItemInfo
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                SelectItemInfo.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.Intent.Message.SelectItemInfo();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                message.key = reader.string();
                                                break;
                                            }
                                        case 2: {
                                                if (!(message.synonyms && message.synonyms.length))
                                                    message.synonyms = [];
                                                message.synonyms.push(reader.string());
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a SelectItemInfo message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.SelectItemInfo
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.SelectItemInfo} SelectItemInfo
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                SelectItemInfo.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a SelectItemInfo message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.SelectItemInfo
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                SelectItemInfo.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.key != null && message.hasOwnProperty("key"))
                                        if (!$util.isString(message.key))
                                            return "key: string expected";
                                    if (message.synonyms != null && message.hasOwnProperty("synonyms")) {
                                        if (!Array.isArray(message.synonyms))
                                            return "synonyms: array expected";
                                        for (var i = 0; i < message.synonyms.length; ++i)
                                            if (!$util.isString(message.synonyms[i]))
                                                return "synonyms: string[] expected";
                                    }
                                    return null;
                                };
    
                                /**
                                 * Creates a SelectItemInfo message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.SelectItemInfo
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.SelectItemInfo} SelectItemInfo
                                 */
                                SelectItemInfo.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2.Intent.Message.SelectItemInfo)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2.Intent.Message.SelectItemInfo();
                                    if (object.key != null)
                                        message.key = String(object.key);
                                    if (object.synonyms) {
                                        if (!Array.isArray(object.synonyms))
                                            throw TypeError(".google.cloud.dialogflow.v2.Intent.Message.SelectItemInfo.synonyms: array expected");
                                        message.synonyms = [];
                                        for (var i = 0; i < object.synonyms.length; ++i)
                                            message.synonyms[i] = String(object.synonyms[i]);
                                    }
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a SelectItemInfo message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.SelectItemInfo
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.SelectItemInfo} message SelectItemInfo
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                SelectItemInfo.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.arrays || options.defaults)
                                        object.synonyms = [];
                                    if (options.defaults)
                                        object.key = "";
                                    if (message.key != null && message.hasOwnProperty("key"))
                                        object.key = message.key;
                                    if (message.synonyms && message.synonyms.length) {
                                        object.synonyms = [];
                                        for (var j = 0; j < message.synonyms.length; ++j)
                                            object.synonyms[j] = message.synonyms[j];
                                    }
                                    return object;
                                };
    
                                /**
                                 * Converts this SelectItemInfo to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.SelectItemInfo
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                SelectItemInfo.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for SelectItemInfo
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.SelectItemInfo
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                SelectItemInfo.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2.Intent.Message.SelectItemInfo";
                                };
    
                                return SelectItemInfo;
                            })();
    
                            Message.MediaContent = (function() {
    
                                /**
                                 * Properties of a MediaContent.
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message
                                 * @interface IMediaContent
                                 * @property {google.cloud.dialogflow.v2.Intent.Message.MediaContent.ResponseMediaType|null} [mediaType] MediaContent mediaType
                                 * @property {Array.<google.cloud.dialogflow.v2.Intent.Message.MediaContent.IResponseMediaObject>|null} [mediaObjects] MediaContent mediaObjects
                                 */
    
                                /**
                                 * Constructs a new MediaContent.
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message
                                 * @classdesc Represents a MediaContent.
                                 * @implements IMediaContent
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.IMediaContent=} [properties] Properties to set
                                 */
                                function MediaContent(properties) {
                                    this.mediaObjects = [];
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * MediaContent mediaType.
                                 * @member {google.cloud.dialogflow.v2.Intent.Message.MediaContent.ResponseMediaType} mediaType
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.MediaContent
                                 * @instance
                                 */
                                MediaContent.prototype.mediaType = 0;
    
                                /**
                                 * MediaContent mediaObjects.
                                 * @member {Array.<google.cloud.dialogflow.v2.Intent.Message.MediaContent.IResponseMediaObject>} mediaObjects
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.MediaContent
                                 * @instance
                                 */
                                MediaContent.prototype.mediaObjects = $util.emptyArray;
    
                                /**
                                 * Creates a new MediaContent instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.MediaContent
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.IMediaContent=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.MediaContent} MediaContent instance
                                 */
                                MediaContent.create = function create(properties) {
                                    return new MediaContent(properties);
                                };
    
                                /**
                                 * Encodes the specified MediaContent message. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Message.MediaContent.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.MediaContent
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.IMediaContent} message MediaContent message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                MediaContent.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.mediaType != null && Object.hasOwnProperty.call(message, "mediaType"))
                                        writer.uint32(/* id 1, wireType 0 =*/8).int32(message.mediaType);
                                    if (message.mediaObjects != null && message.mediaObjects.length)
                                        for (var i = 0; i < message.mediaObjects.length; ++i)
                                            $root.google.cloud.dialogflow.v2.Intent.Message.MediaContent.ResponseMediaObject.encode(message.mediaObjects[i], writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified MediaContent message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Message.MediaContent.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.MediaContent
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.IMediaContent} message MediaContent message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                MediaContent.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a MediaContent message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.MediaContent
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.MediaContent} MediaContent
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                MediaContent.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.Intent.Message.MediaContent();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                message.mediaType = reader.int32();
                                                break;
                                            }
                                        case 2: {
                                                if (!(message.mediaObjects && message.mediaObjects.length))
                                                    message.mediaObjects = [];
                                                message.mediaObjects.push($root.google.cloud.dialogflow.v2.Intent.Message.MediaContent.ResponseMediaObject.decode(reader, reader.uint32()));
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a MediaContent message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.MediaContent
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.MediaContent} MediaContent
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                MediaContent.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a MediaContent message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.MediaContent
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                MediaContent.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.mediaType != null && message.hasOwnProperty("mediaType"))
                                        switch (message.mediaType) {
                                        default:
                                            return "mediaType: enum value expected";
                                        case 0:
                                        case 1:
                                            break;
                                        }
                                    if (message.mediaObjects != null && message.hasOwnProperty("mediaObjects")) {
                                        if (!Array.isArray(message.mediaObjects))
                                            return "mediaObjects: array expected";
                                        for (var i = 0; i < message.mediaObjects.length; ++i) {
                                            var error = $root.google.cloud.dialogflow.v2.Intent.Message.MediaContent.ResponseMediaObject.verify(message.mediaObjects[i]);
                                            if (error)
                                                return "mediaObjects." + error;
                                        }
                                    }
                                    return null;
                                };
    
                                /**
                                 * Creates a MediaContent message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.MediaContent
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.MediaContent} MediaContent
                                 */
                                MediaContent.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2.Intent.Message.MediaContent)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2.Intent.Message.MediaContent();
                                    switch (object.mediaType) {
                                    default:
                                        if (typeof object.mediaType === "number") {
                                            message.mediaType = object.mediaType;
                                            break;
                                        }
                                        break;
                                    case "RESPONSE_MEDIA_TYPE_UNSPECIFIED":
                                    case 0:
                                        message.mediaType = 0;
                                        break;
                                    case "AUDIO":
                                    case 1:
                                        message.mediaType = 1;
                                        break;
                                    }
                                    if (object.mediaObjects) {
                                        if (!Array.isArray(object.mediaObjects))
                                            throw TypeError(".google.cloud.dialogflow.v2.Intent.Message.MediaContent.mediaObjects: array expected");
                                        message.mediaObjects = [];
                                        for (var i = 0; i < object.mediaObjects.length; ++i) {
                                            if (typeof object.mediaObjects[i] !== "object")
                                                throw TypeError(".google.cloud.dialogflow.v2.Intent.Message.MediaContent.mediaObjects: object expected");
                                            message.mediaObjects[i] = $root.google.cloud.dialogflow.v2.Intent.Message.MediaContent.ResponseMediaObject.fromObject(object.mediaObjects[i]);
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a MediaContent message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.MediaContent
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.MediaContent} message MediaContent
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                MediaContent.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.arrays || options.defaults)
                                        object.mediaObjects = [];
                                    if (options.defaults)
                                        object.mediaType = options.enums === String ? "RESPONSE_MEDIA_TYPE_UNSPECIFIED" : 0;
                                    if (message.mediaType != null && message.hasOwnProperty("mediaType"))
                                        object.mediaType = options.enums === String ? $root.google.cloud.dialogflow.v2.Intent.Message.MediaContent.ResponseMediaType[message.mediaType] === undefined ? message.mediaType : $root.google.cloud.dialogflow.v2.Intent.Message.MediaContent.ResponseMediaType[message.mediaType] : message.mediaType;
                                    if (message.mediaObjects && message.mediaObjects.length) {
                                        object.mediaObjects = [];
                                        for (var j = 0; j < message.mediaObjects.length; ++j)
                                            object.mediaObjects[j] = $root.google.cloud.dialogflow.v2.Intent.Message.MediaContent.ResponseMediaObject.toObject(message.mediaObjects[j], options);
                                    }
                                    return object;
                                };
    
                                /**
                                 * Converts this MediaContent to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.MediaContent
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                MediaContent.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for MediaContent
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.MediaContent
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                MediaContent.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2.Intent.Message.MediaContent";
                                };
    
                                /**
                                 * ResponseMediaType enum.
                                 * @name google.cloud.dialogflow.v2.Intent.Message.MediaContent.ResponseMediaType
                                 * @enum {number}
                                 * @property {number} RESPONSE_MEDIA_TYPE_UNSPECIFIED=0 RESPONSE_MEDIA_TYPE_UNSPECIFIED value
                                 * @property {number} AUDIO=1 AUDIO value
                                 */
                                MediaContent.ResponseMediaType = (function() {
                                    var valuesById = {}, values = Object.create(valuesById);
                                    values[valuesById[0] = "RESPONSE_MEDIA_TYPE_UNSPECIFIED"] = 0;
                                    values[valuesById[1] = "AUDIO"] = 1;
                                    return values;
                                })();
    
                                MediaContent.ResponseMediaObject = (function() {
    
                                    /**
                                     * Properties of a ResponseMediaObject.
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.MediaContent
                                     * @interface IResponseMediaObject
                                     * @property {string|null} [name] ResponseMediaObject name
                                     * @property {string|null} [description] ResponseMediaObject description
                                     * @property {google.cloud.dialogflow.v2.Intent.Message.IImage|null} [largeImage] ResponseMediaObject largeImage
                                     * @property {google.cloud.dialogflow.v2.Intent.Message.IImage|null} [icon] ResponseMediaObject icon
                                     * @property {string|null} [contentUrl] ResponseMediaObject contentUrl
                                     */
    
                                    /**
                                     * Constructs a new ResponseMediaObject.
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.MediaContent
                                     * @classdesc Represents a ResponseMediaObject.
                                     * @implements IResponseMediaObject
                                     * @constructor
                                     * @param {google.cloud.dialogflow.v2.Intent.Message.MediaContent.IResponseMediaObject=} [properties] Properties to set
                                     */
                                    function ResponseMediaObject(properties) {
                                        if (properties)
                                            for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                                if (properties[keys[i]] != null)
                                                    this[keys[i]] = properties[keys[i]];
                                    }
    
                                    /**
                                     * ResponseMediaObject name.
                                     * @member {string} name
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.MediaContent.ResponseMediaObject
                                     * @instance
                                     */
                                    ResponseMediaObject.prototype.name = "";
    
                                    /**
                                     * ResponseMediaObject description.
                                     * @member {string} description
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.MediaContent.ResponseMediaObject
                                     * @instance
                                     */
                                    ResponseMediaObject.prototype.description = "";
    
                                    /**
                                     * ResponseMediaObject largeImage.
                                     * @member {google.cloud.dialogflow.v2.Intent.Message.IImage|null|undefined} largeImage
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.MediaContent.ResponseMediaObject
                                     * @instance
                                     */
                                    ResponseMediaObject.prototype.largeImage = null;
    
                                    /**
                                     * ResponseMediaObject icon.
                                     * @member {google.cloud.dialogflow.v2.Intent.Message.IImage|null|undefined} icon
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.MediaContent.ResponseMediaObject
                                     * @instance
                                     */
                                    ResponseMediaObject.prototype.icon = null;
    
                                    /**
                                     * ResponseMediaObject contentUrl.
                                     * @member {string} contentUrl
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.MediaContent.ResponseMediaObject
                                     * @instance
                                     */
                                    ResponseMediaObject.prototype.contentUrl = "";
    
                                    // OneOf field names bound to virtual getters and setters
                                    var $oneOfFields;
    
                                    /**
                                     * ResponseMediaObject image.
                                     * @member {"largeImage"|"icon"|undefined} image
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.MediaContent.ResponseMediaObject
                                     * @instance
                                     */
                                    Object.defineProperty(ResponseMediaObject.prototype, "image", {
                                        get: $util.oneOfGetter($oneOfFields = ["largeImage", "icon"]),
                                        set: $util.oneOfSetter($oneOfFields)
                                    });
    
                                    /**
                                     * Creates a new ResponseMediaObject instance using the specified properties.
                                     * @function create
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.MediaContent.ResponseMediaObject
                                     * @static
                                     * @param {google.cloud.dialogflow.v2.Intent.Message.MediaContent.IResponseMediaObject=} [properties] Properties to set
                                     * @returns {google.cloud.dialogflow.v2.Intent.Message.MediaContent.ResponseMediaObject} ResponseMediaObject instance
                                     */
                                    ResponseMediaObject.create = function create(properties) {
                                        return new ResponseMediaObject(properties);
                                    };
    
                                    /**
                                     * Encodes the specified ResponseMediaObject message. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Message.MediaContent.ResponseMediaObject.verify|verify} messages.
                                     * @function encode
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.MediaContent.ResponseMediaObject
                                     * @static
                                     * @param {google.cloud.dialogflow.v2.Intent.Message.MediaContent.IResponseMediaObject} message ResponseMediaObject message or plain object to encode
                                     * @param {$protobuf.Writer} [writer] Writer to encode to
                                     * @returns {$protobuf.Writer} Writer
                                     */
                                    ResponseMediaObject.encode = function encode(message, writer) {
                                        if (!writer)
                                            writer = $Writer.create();
                                        if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                            writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                                        if (message.description != null && Object.hasOwnProperty.call(message, "description"))
                                            writer.uint32(/* id 2, wireType 2 =*/18).string(message.description);
                                        if (message.largeImage != null && Object.hasOwnProperty.call(message, "largeImage"))
                                            $root.google.cloud.dialogflow.v2.Intent.Message.Image.encode(message.largeImage, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                                        if (message.icon != null && Object.hasOwnProperty.call(message, "icon"))
                                            $root.google.cloud.dialogflow.v2.Intent.Message.Image.encode(message.icon, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                                        if (message.contentUrl != null && Object.hasOwnProperty.call(message, "contentUrl"))
                                            writer.uint32(/* id 5, wireType 2 =*/42).string(message.contentUrl);
                                        return writer;
                                    };
    
                                    /**
                                     * Encodes the specified ResponseMediaObject message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Message.MediaContent.ResponseMediaObject.verify|verify} messages.
                                     * @function encodeDelimited
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.MediaContent.ResponseMediaObject
                                     * @static
                                     * @param {google.cloud.dialogflow.v2.Intent.Message.MediaContent.IResponseMediaObject} message ResponseMediaObject message or plain object to encode
                                     * @param {$protobuf.Writer} [writer] Writer to encode to
                                     * @returns {$protobuf.Writer} Writer
                                     */
                                    ResponseMediaObject.encodeDelimited = function encodeDelimited(message, writer) {
                                        return this.encode(message, writer).ldelim();
                                    };
    
                                    /**
                                     * Decodes a ResponseMediaObject message from the specified reader or buffer.
                                     * @function decode
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.MediaContent.ResponseMediaObject
                                     * @static
                                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                     * @param {number} [length] Message length if known beforehand
                                     * @returns {google.cloud.dialogflow.v2.Intent.Message.MediaContent.ResponseMediaObject} ResponseMediaObject
                                     * @throws {Error} If the payload is not a reader or valid buffer
                                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                     */
                                    ResponseMediaObject.decode = function decode(reader, length) {
                                        if (!(reader instanceof $Reader))
                                            reader = $Reader.create(reader);
                                        var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.Intent.Message.MediaContent.ResponseMediaObject();
                                        while (reader.pos < end) {
                                            var tag = reader.uint32();
                                            switch (tag >>> 3) {
                                            case 1: {
                                                    message.name = reader.string();
                                                    break;
                                                }
                                            case 2: {
                                                    message.description = reader.string();
                                                    break;
                                                }
                                            case 3: {
                                                    message.largeImage = $root.google.cloud.dialogflow.v2.Intent.Message.Image.decode(reader, reader.uint32());
                                                    break;
                                                }
                                            case 4: {
                                                    message.icon = $root.google.cloud.dialogflow.v2.Intent.Message.Image.decode(reader, reader.uint32());
                                                    break;
                                                }
                                            case 5: {
                                                    message.contentUrl = reader.string();
                                                    break;
                                                }
                                            default:
                                                reader.skipType(tag & 7);
                                                break;
                                            }
                                        }
                                        return message;
                                    };
    
                                    /**
                                     * Decodes a ResponseMediaObject message from the specified reader or buffer, length delimited.
                                     * @function decodeDelimited
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.MediaContent.ResponseMediaObject
                                     * @static
                                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                     * @returns {google.cloud.dialogflow.v2.Intent.Message.MediaContent.ResponseMediaObject} ResponseMediaObject
                                     * @throws {Error} If the payload is not a reader or valid buffer
                                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                     */
                                    ResponseMediaObject.decodeDelimited = function decodeDelimited(reader) {
                                        if (!(reader instanceof $Reader))
                                            reader = new $Reader(reader);
                                        return this.decode(reader, reader.uint32());
                                    };
    
                                    /**
                                     * Verifies a ResponseMediaObject message.
                                     * @function verify
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.MediaContent.ResponseMediaObject
                                     * @static
                                     * @param {Object.<string,*>} message Plain object to verify
                                     * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                     */
                                    ResponseMediaObject.verify = function verify(message) {
                                        if (typeof message !== "object" || message === null)
                                            return "object expected";
                                        var properties = {};
                                        if (message.name != null && message.hasOwnProperty("name"))
                                            if (!$util.isString(message.name))
                                                return "name: string expected";
                                        if (message.description != null && message.hasOwnProperty("description"))
                                            if (!$util.isString(message.description))
                                                return "description: string expected";
                                        if (message.largeImage != null && message.hasOwnProperty("largeImage")) {
                                            properties.image = 1;
                                            {
                                                var error = $root.google.cloud.dialogflow.v2.Intent.Message.Image.verify(message.largeImage);
                                                if (error)
                                                    return "largeImage." + error;
                                            }
                                        }
                                        if (message.icon != null && message.hasOwnProperty("icon")) {
                                            if (properties.image === 1)
                                                return "image: multiple values";
                                            properties.image = 1;
                                            {
                                                var error = $root.google.cloud.dialogflow.v2.Intent.Message.Image.verify(message.icon);
                                                if (error)
                                                    return "icon." + error;
                                            }
                                        }
                                        if (message.contentUrl != null && message.hasOwnProperty("contentUrl"))
                                            if (!$util.isString(message.contentUrl))
                                                return "contentUrl: string expected";
                                        return null;
                                    };
    
                                    /**
                                     * Creates a ResponseMediaObject message from a plain object. Also converts values to their respective internal types.
                                     * @function fromObject
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.MediaContent.ResponseMediaObject
                                     * @static
                                     * @param {Object.<string,*>} object Plain object
                                     * @returns {google.cloud.dialogflow.v2.Intent.Message.MediaContent.ResponseMediaObject} ResponseMediaObject
                                     */
                                    ResponseMediaObject.fromObject = function fromObject(object) {
                                        if (object instanceof $root.google.cloud.dialogflow.v2.Intent.Message.MediaContent.ResponseMediaObject)
                                            return object;
                                        var message = new $root.google.cloud.dialogflow.v2.Intent.Message.MediaContent.ResponseMediaObject();
                                        if (object.name != null)
                                            message.name = String(object.name);
                                        if (object.description != null)
                                            message.description = String(object.description);
                                        if (object.largeImage != null) {
                                            if (typeof object.largeImage !== "object")
                                                throw TypeError(".google.cloud.dialogflow.v2.Intent.Message.MediaContent.ResponseMediaObject.largeImage: object expected");
                                            message.largeImage = $root.google.cloud.dialogflow.v2.Intent.Message.Image.fromObject(object.largeImage);
                                        }
                                        if (object.icon != null) {
                                            if (typeof object.icon !== "object")
                                                throw TypeError(".google.cloud.dialogflow.v2.Intent.Message.MediaContent.ResponseMediaObject.icon: object expected");
                                            message.icon = $root.google.cloud.dialogflow.v2.Intent.Message.Image.fromObject(object.icon);
                                        }
                                        if (object.contentUrl != null)
                                            message.contentUrl = String(object.contentUrl);
                                        return message;
                                    };
    
                                    /**
                                     * Creates a plain object from a ResponseMediaObject message. Also converts values to other types if specified.
                                     * @function toObject
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.MediaContent.ResponseMediaObject
                                     * @static
                                     * @param {google.cloud.dialogflow.v2.Intent.Message.MediaContent.ResponseMediaObject} message ResponseMediaObject
                                     * @param {$protobuf.IConversionOptions} [options] Conversion options
                                     * @returns {Object.<string,*>} Plain object
                                     */
                                    ResponseMediaObject.toObject = function toObject(message, options) {
                                        if (!options)
                                            options = {};
                                        var object = {};
                                        if (options.defaults) {
                                            object.name = "";
                                            object.description = "";
                                            object.contentUrl = "";
                                        }
                                        if (message.name != null && message.hasOwnProperty("name"))
                                            object.name = message.name;
                                        if (message.description != null && message.hasOwnProperty("description"))
                                            object.description = message.description;
                                        if (message.largeImage != null && message.hasOwnProperty("largeImage")) {
                                            object.largeImage = $root.google.cloud.dialogflow.v2.Intent.Message.Image.toObject(message.largeImage, options);
                                            if (options.oneofs)
                                                object.image = "largeImage";
                                        }
                                        if (message.icon != null && message.hasOwnProperty("icon")) {
                                            object.icon = $root.google.cloud.dialogflow.v2.Intent.Message.Image.toObject(message.icon, options);
                                            if (options.oneofs)
                                                object.image = "icon";
                                        }
                                        if (message.contentUrl != null && message.hasOwnProperty("contentUrl"))
                                            object.contentUrl = message.contentUrl;
                                        return object;
                                    };
    
                                    /**
                                     * Converts this ResponseMediaObject to JSON.
                                     * @function toJSON
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.MediaContent.ResponseMediaObject
                                     * @instance
                                     * @returns {Object.<string,*>} JSON object
                                     */
                                    ResponseMediaObject.prototype.toJSON = function toJSON() {
                                        return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                    };
    
                                    /**
                                     * Gets the default type url for ResponseMediaObject
                                     * @function getTypeUrl
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.MediaContent.ResponseMediaObject
                                     * @static
                                     * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                     * @returns {string} The default type url
                                     */
                                    ResponseMediaObject.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                        if (typeUrlPrefix === undefined) {
                                            typeUrlPrefix = "type.googleapis.com";
                                        }
                                        return typeUrlPrefix + "/google.cloud.dialogflow.v2.Intent.Message.MediaContent.ResponseMediaObject";
                                    };
    
                                    return ResponseMediaObject;
                                })();
    
                                return MediaContent;
                            })();
    
                            Message.BrowseCarouselCard = (function() {
    
                                /**
                                 * Properties of a BrowseCarouselCard.
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message
                                 * @interface IBrowseCarouselCard
                                 * @property {Array.<google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.IBrowseCarouselCardItem>|null} [items] BrowseCarouselCard items
                                 * @property {google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.ImageDisplayOptions|null} [imageDisplayOptions] BrowseCarouselCard imageDisplayOptions
                                 */
    
                                /**
                                 * Constructs a new BrowseCarouselCard.
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message
                                 * @classdesc Represents a BrowseCarouselCard.
                                 * @implements IBrowseCarouselCard
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.IBrowseCarouselCard=} [properties] Properties to set
                                 */
                                function BrowseCarouselCard(properties) {
                                    this.items = [];
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * BrowseCarouselCard items.
                                 * @member {Array.<google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.IBrowseCarouselCardItem>} items
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard
                                 * @instance
                                 */
                                BrowseCarouselCard.prototype.items = $util.emptyArray;
    
                                /**
                                 * BrowseCarouselCard imageDisplayOptions.
                                 * @member {google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.ImageDisplayOptions} imageDisplayOptions
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard
                                 * @instance
                                 */
                                BrowseCarouselCard.prototype.imageDisplayOptions = 0;
    
                                /**
                                 * Creates a new BrowseCarouselCard instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.IBrowseCarouselCard=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard} BrowseCarouselCard instance
                                 */
                                BrowseCarouselCard.create = function create(properties) {
                                    return new BrowseCarouselCard(properties);
                                };
    
                                /**
                                 * Encodes the specified BrowseCarouselCard message. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.IBrowseCarouselCard} message BrowseCarouselCard message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                BrowseCarouselCard.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.items != null && message.items.length)
                                        for (var i = 0; i < message.items.length; ++i)
                                            $root.google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.encode(message.items[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                                    if (message.imageDisplayOptions != null && Object.hasOwnProperty.call(message, "imageDisplayOptions"))
                                        writer.uint32(/* id 2, wireType 0 =*/16).int32(message.imageDisplayOptions);
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified BrowseCarouselCard message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.IBrowseCarouselCard} message BrowseCarouselCard message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                BrowseCarouselCard.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a BrowseCarouselCard message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard} BrowseCarouselCard
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                BrowseCarouselCard.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                if (!(message.items && message.items.length))
                                                    message.items = [];
                                                message.items.push($root.google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.decode(reader, reader.uint32()));
                                                break;
                                            }
                                        case 2: {
                                                message.imageDisplayOptions = reader.int32();
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a BrowseCarouselCard message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard} BrowseCarouselCard
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                BrowseCarouselCard.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a BrowseCarouselCard message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                BrowseCarouselCard.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.items != null && message.hasOwnProperty("items")) {
                                        if (!Array.isArray(message.items))
                                            return "items: array expected";
                                        for (var i = 0; i < message.items.length; ++i) {
                                            var error = $root.google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.verify(message.items[i]);
                                            if (error)
                                                return "items." + error;
                                        }
                                    }
                                    if (message.imageDisplayOptions != null && message.hasOwnProperty("imageDisplayOptions"))
                                        switch (message.imageDisplayOptions) {
                                        default:
                                            return "imageDisplayOptions: enum value expected";
                                        case 0:
                                        case 1:
                                        case 2:
                                        case 3:
                                        case 4:
                                            break;
                                        }
                                    return null;
                                };
    
                                /**
                                 * Creates a BrowseCarouselCard message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard} BrowseCarouselCard
                                 */
                                BrowseCarouselCard.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard();
                                    if (object.items) {
                                        if (!Array.isArray(object.items))
                                            throw TypeError(".google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.items: array expected");
                                        message.items = [];
                                        for (var i = 0; i < object.items.length; ++i) {
                                            if (typeof object.items[i] !== "object")
                                                throw TypeError(".google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.items: object expected");
                                            message.items[i] = $root.google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.fromObject(object.items[i]);
                                        }
                                    }
                                    switch (object.imageDisplayOptions) {
                                    default:
                                        if (typeof object.imageDisplayOptions === "number") {
                                            message.imageDisplayOptions = object.imageDisplayOptions;
                                            break;
                                        }
                                        break;
                                    case "IMAGE_DISPLAY_OPTIONS_UNSPECIFIED":
                                    case 0:
                                        message.imageDisplayOptions = 0;
                                        break;
                                    case "GRAY":
                                    case 1:
                                        message.imageDisplayOptions = 1;
                                        break;
                                    case "WHITE":
                                    case 2:
                                        message.imageDisplayOptions = 2;
                                        break;
                                    case "CROPPED":
                                    case 3:
                                        message.imageDisplayOptions = 3;
                                        break;
                                    case "BLURRED_BACKGROUND":
                                    case 4:
                                        message.imageDisplayOptions = 4;
                                        break;
                                    }
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a BrowseCarouselCard message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard} message BrowseCarouselCard
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                BrowseCarouselCard.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.arrays || options.defaults)
                                        object.items = [];
                                    if (options.defaults)
                                        object.imageDisplayOptions = options.enums === String ? "IMAGE_DISPLAY_OPTIONS_UNSPECIFIED" : 0;
                                    if (message.items && message.items.length) {
                                        object.items = [];
                                        for (var j = 0; j < message.items.length; ++j)
                                            object.items[j] = $root.google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.toObject(message.items[j], options);
                                    }
                                    if (message.imageDisplayOptions != null && message.hasOwnProperty("imageDisplayOptions"))
                                        object.imageDisplayOptions = options.enums === String ? $root.google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.ImageDisplayOptions[message.imageDisplayOptions] === undefined ? message.imageDisplayOptions : $root.google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.ImageDisplayOptions[message.imageDisplayOptions] : message.imageDisplayOptions;
                                    return object;
                                };
    
                                /**
                                 * Converts this BrowseCarouselCard to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                BrowseCarouselCard.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for BrowseCarouselCard
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                BrowseCarouselCard.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard";
                                };
    
                                BrowseCarouselCard.BrowseCarouselCardItem = (function() {
    
                                    /**
                                     * Properties of a BrowseCarouselCardItem.
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard
                                     * @interface IBrowseCarouselCardItem
                                     * @property {google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.IOpenUrlAction|null} [openUriAction] BrowseCarouselCardItem openUriAction
                                     * @property {string|null} [title] BrowseCarouselCardItem title
                                     * @property {string|null} [description] BrowseCarouselCardItem description
                                     * @property {google.cloud.dialogflow.v2.Intent.Message.IImage|null} [image] BrowseCarouselCardItem image
                                     * @property {string|null} [footer] BrowseCarouselCardItem footer
                                     */
    
                                    /**
                                     * Constructs a new BrowseCarouselCardItem.
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard
                                     * @classdesc Represents a BrowseCarouselCardItem.
                                     * @implements IBrowseCarouselCardItem
                                     * @constructor
                                     * @param {google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.IBrowseCarouselCardItem=} [properties] Properties to set
                                     */
                                    function BrowseCarouselCardItem(properties) {
                                        if (properties)
                                            for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                                if (properties[keys[i]] != null)
                                                    this[keys[i]] = properties[keys[i]];
                                    }
    
                                    /**
                                     * BrowseCarouselCardItem openUriAction.
                                     * @member {google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.IOpenUrlAction|null|undefined} openUriAction
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem
                                     * @instance
                                     */
                                    BrowseCarouselCardItem.prototype.openUriAction = null;
    
                                    /**
                                     * BrowseCarouselCardItem title.
                                     * @member {string} title
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem
                                     * @instance
                                     */
                                    BrowseCarouselCardItem.prototype.title = "";
    
                                    /**
                                     * BrowseCarouselCardItem description.
                                     * @member {string} description
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem
                                     * @instance
                                     */
                                    BrowseCarouselCardItem.prototype.description = "";
    
                                    /**
                                     * BrowseCarouselCardItem image.
                                     * @member {google.cloud.dialogflow.v2.Intent.Message.IImage|null|undefined} image
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem
                                     * @instance
                                     */
                                    BrowseCarouselCardItem.prototype.image = null;
    
                                    /**
                                     * BrowseCarouselCardItem footer.
                                     * @member {string} footer
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem
                                     * @instance
                                     */
                                    BrowseCarouselCardItem.prototype.footer = "";
    
                                    /**
                                     * Creates a new BrowseCarouselCardItem instance using the specified properties.
                                     * @function create
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem
                                     * @static
                                     * @param {google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.IBrowseCarouselCardItem=} [properties] Properties to set
                                     * @returns {google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem} BrowseCarouselCardItem instance
                                     */
                                    BrowseCarouselCardItem.create = function create(properties) {
                                        return new BrowseCarouselCardItem(properties);
                                    };
    
                                    /**
                                     * Encodes the specified BrowseCarouselCardItem message. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.verify|verify} messages.
                                     * @function encode
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem
                                     * @static
                                     * @param {google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.IBrowseCarouselCardItem} message BrowseCarouselCardItem message or plain object to encode
                                     * @param {$protobuf.Writer} [writer] Writer to encode to
                                     * @returns {$protobuf.Writer} Writer
                                     */
                                    BrowseCarouselCardItem.encode = function encode(message, writer) {
                                        if (!writer)
                                            writer = $Writer.create();
                                        if (message.openUriAction != null && Object.hasOwnProperty.call(message, "openUriAction"))
                                            $root.google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction.encode(message.openUriAction, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                                        if (message.title != null && Object.hasOwnProperty.call(message, "title"))
                                            writer.uint32(/* id 2, wireType 2 =*/18).string(message.title);
                                        if (message.description != null && Object.hasOwnProperty.call(message, "description"))
                                            writer.uint32(/* id 3, wireType 2 =*/26).string(message.description);
                                        if (message.image != null && Object.hasOwnProperty.call(message, "image"))
                                            $root.google.cloud.dialogflow.v2.Intent.Message.Image.encode(message.image, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                                        if (message.footer != null && Object.hasOwnProperty.call(message, "footer"))
                                            writer.uint32(/* id 5, wireType 2 =*/42).string(message.footer);
                                        return writer;
                                    };
    
                                    /**
                                     * Encodes the specified BrowseCarouselCardItem message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.verify|verify} messages.
                                     * @function encodeDelimited
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem
                                     * @static
                                     * @param {google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.IBrowseCarouselCardItem} message BrowseCarouselCardItem message or plain object to encode
                                     * @param {$protobuf.Writer} [writer] Writer to encode to
                                     * @returns {$protobuf.Writer} Writer
                                     */
                                    BrowseCarouselCardItem.encodeDelimited = function encodeDelimited(message, writer) {
                                        return this.encode(message, writer).ldelim();
                                    };
    
                                    /**
                                     * Decodes a BrowseCarouselCardItem message from the specified reader or buffer.
                                     * @function decode
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem
                                     * @static
                                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                     * @param {number} [length] Message length if known beforehand
                                     * @returns {google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem} BrowseCarouselCardItem
                                     * @throws {Error} If the payload is not a reader or valid buffer
                                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                     */
                                    BrowseCarouselCardItem.decode = function decode(reader, length) {
                                        if (!(reader instanceof $Reader))
                                            reader = $Reader.create(reader);
                                        var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem();
                                        while (reader.pos < end) {
                                            var tag = reader.uint32();
                                            switch (tag >>> 3) {
                                            case 1: {
                                                    message.openUriAction = $root.google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction.decode(reader, reader.uint32());
                                                    break;
                                                }
                                            case 2: {
                                                    message.title = reader.string();
                                                    break;
                                                }
                                            case 3: {
                                                    message.description = reader.string();
                                                    break;
                                                }
                                            case 4: {
                                                    message.image = $root.google.cloud.dialogflow.v2.Intent.Message.Image.decode(reader, reader.uint32());
                                                    break;
                                                }
                                            case 5: {
                                                    message.footer = reader.string();
                                                    break;
                                                }
                                            default:
                                                reader.skipType(tag & 7);
                                                break;
                                            }
                                        }
                                        return message;
                                    };
    
                                    /**
                                     * Decodes a BrowseCarouselCardItem message from the specified reader or buffer, length delimited.
                                     * @function decodeDelimited
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem
                                     * @static
                                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                     * @returns {google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem} BrowseCarouselCardItem
                                     * @throws {Error} If the payload is not a reader or valid buffer
                                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                     */
                                    BrowseCarouselCardItem.decodeDelimited = function decodeDelimited(reader) {
                                        if (!(reader instanceof $Reader))
                                            reader = new $Reader(reader);
                                        return this.decode(reader, reader.uint32());
                                    };
    
                                    /**
                                     * Verifies a BrowseCarouselCardItem message.
                                     * @function verify
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem
                                     * @static
                                     * @param {Object.<string,*>} message Plain object to verify
                                     * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                     */
                                    BrowseCarouselCardItem.verify = function verify(message) {
                                        if (typeof message !== "object" || message === null)
                                            return "object expected";
                                        if (message.openUriAction != null && message.hasOwnProperty("openUriAction")) {
                                            var error = $root.google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction.verify(message.openUriAction);
                                            if (error)
                                                return "openUriAction." + error;
                                        }
                                        if (message.title != null && message.hasOwnProperty("title"))
                                            if (!$util.isString(message.title))
                                                return "title: string expected";
                                        if (message.description != null && message.hasOwnProperty("description"))
                                            if (!$util.isString(message.description))
                                                return "description: string expected";
                                        if (message.image != null && message.hasOwnProperty("image")) {
                                            var error = $root.google.cloud.dialogflow.v2.Intent.Message.Image.verify(message.image);
                                            if (error)
                                                return "image." + error;
                                        }
                                        if (message.footer != null && message.hasOwnProperty("footer"))
                                            if (!$util.isString(message.footer))
                                                return "footer: string expected";
                                        return null;
                                    };
    
                                    /**
                                     * Creates a BrowseCarouselCardItem message from a plain object. Also converts values to their respective internal types.
                                     * @function fromObject
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem
                                     * @static
                                     * @param {Object.<string,*>} object Plain object
                                     * @returns {google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem} BrowseCarouselCardItem
                                     */
                                    BrowseCarouselCardItem.fromObject = function fromObject(object) {
                                        if (object instanceof $root.google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem)
                                            return object;
                                        var message = new $root.google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem();
                                        if (object.openUriAction != null) {
                                            if (typeof object.openUriAction !== "object")
                                                throw TypeError(".google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.openUriAction: object expected");
                                            message.openUriAction = $root.google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction.fromObject(object.openUriAction);
                                        }
                                        if (object.title != null)
                                            message.title = String(object.title);
                                        if (object.description != null)
                                            message.description = String(object.description);
                                        if (object.image != null) {
                                            if (typeof object.image !== "object")
                                                throw TypeError(".google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.image: object expected");
                                            message.image = $root.google.cloud.dialogflow.v2.Intent.Message.Image.fromObject(object.image);
                                        }
                                        if (object.footer != null)
                                            message.footer = String(object.footer);
                                        return message;
                                    };
    
                                    /**
                                     * Creates a plain object from a BrowseCarouselCardItem message. Also converts values to other types if specified.
                                     * @function toObject
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem
                                     * @static
                                     * @param {google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem} message BrowseCarouselCardItem
                                     * @param {$protobuf.IConversionOptions} [options] Conversion options
                                     * @returns {Object.<string,*>} Plain object
                                     */
                                    BrowseCarouselCardItem.toObject = function toObject(message, options) {
                                        if (!options)
                                            options = {};
                                        var object = {};
                                        if (options.defaults) {
                                            object.openUriAction = null;
                                            object.title = "";
                                            object.description = "";
                                            object.image = null;
                                            object.footer = "";
                                        }
                                        if (message.openUriAction != null && message.hasOwnProperty("openUriAction"))
                                            object.openUriAction = $root.google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction.toObject(message.openUriAction, options);
                                        if (message.title != null && message.hasOwnProperty("title"))
                                            object.title = message.title;
                                        if (message.description != null && message.hasOwnProperty("description"))
                                            object.description = message.description;
                                        if (message.image != null && message.hasOwnProperty("image"))
                                            object.image = $root.google.cloud.dialogflow.v2.Intent.Message.Image.toObject(message.image, options);
                                        if (message.footer != null && message.hasOwnProperty("footer"))
                                            object.footer = message.footer;
                                        return object;
                                    };
    
                                    /**
                                     * Converts this BrowseCarouselCardItem to JSON.
                                     * @function toJSON
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem
                                     * @instance
                                     * @returns {Object.<string,*>} JSON object
                                     */
                                    BrowseCarouselCardItem.prototype.toJSON = function toJSON() {
                                        return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                    };
    
                                    /**
                                     * Gets the default type url for BrowseCarouselCardItem
                                     * @function getTypeUrl
                                     * @memberof google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem
                                     * @static
                                     * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                     * @returns {string} The default type url
                                     */
                                    BrowseCarouselCardItem.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                        if (typeUrlPrefix === undefined) {
                                            typeUrlPrefix = "type.googleapis.com";
                                        }
                                        return typeUrlPrefix + "/google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem";
                                    };
    
                                    BrowseCarouselCardItem.OpenUrlAction = (function() {
    
                                        /**
                                         * Properties of an OpenUrlAction.
                                         * @memberof google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem
                                         * @interface IOpenUrlAction
                                         * @property {string|null} [url] OpenUrlAction url
                                         * @property {google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction.UrlTypeHint|null} [urlTypeHint] OpenUrlAction urlTypeHint
                                         */
    
                                        /**
                                         * Constructs a new OpenUrlAction.
                                         * @memberof google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem
                                         * @classdesc Represents an OpenUrlAction.
                                         * @implements IOpenUrlAction
                                         * @constructor
                                         * @param {google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.IOpenUrlAction=} [properties] Properties to set
                                         */
                                        function OpenUrlAction(properties) {
                                            if (properties)
                                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                                    if (properties[keys[i]] != null)
                                                        this[keys[i]] = properties[keys[i]];
                                        }
    
                                        /**
                                         * OpenUrlAction url.
                                         * @member {string} url
                                         * @memberof google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction
                                         * @instance
                                         */
                                        OpenUrlAction.prototype.url = "";
    
                                        /**
                                         * OpenUrlAction urlTypeHint.
                                         * @member {google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction.UrlTypeHint} urlTypeHint
                                         * @memberof google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction
                                         * @instance
                                         */
                                        OpenUrlAction.prototype.urlTypeHint = 0;
    
                                        /**
                                         * Creates a new OpenUrlAction instance using the specified properties.
                                         * @function create
                                         * @memberof google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction
                                         * @static
                                         * @param {google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.IOpenUrlAction=} [properties] Properties to set
                                         * @returns {google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction} OpenUrlAction instance
                                         */
                                        OpenUrlAction.create = function create(properties) {
                                            return new OpenUrlAction(properties);
                                        };
    
                                        /**
                                         * Encodes the specified OpenUrlAction message. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction.verify|verify} messages.
                                         * @function encode
                                         * @memberof google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction
                                         * @static
                                         * @param {google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.IOpenUrlAction} message OpenUrlAction message or plain object to encode
                                         * @param {$protobuf.Writer} [writer] Writer to encode to
                                         * @returns {$protobuf.Writer} Writer
                                         */
                                        OpenUrlAction.encode = function encode(message, writer) {
                                            if (!writer)
                                                writer = $Writer.create();
                                            if (message.url != null && Object.hasOwnProperty.call(message, "url"))
                                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.url);
                                            if (message.urlTypeHint != null && Object.hasOwnProperty.call(message, "urlTypeHint"))
                                                writer.uint32(/* id 3, wireType 0 =*/24).int32(message.urlTypeHint);
                                            return writer;
                                        };
    
                                        /**
                                         * Encodes the specified OpenUrlAction message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction.verify|verify} messages.
                                         * @function encodeDelimited
                                         * @memberof google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction
                                         * @static
                                         * @param {google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.IOpenUrlAction} message OpenUrlAction message or plain object to encode
                                         * @param {$protobuf.Writer} [writer] Writer to encode to
                                         * @returns {$protobuf.Writer} Writer
                                         */
                                        OpenUrlAction.encodeDelimited = function encodeDelimited(message, writer) {
                                            return this.encode(message, writer).ldelim();
                                        };
    
                                        /**
                                         * Decodes an OpenUrlAction message from the specified reader or buffer.
                                         * @function decode
                                         * @memberof google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction
                                         * @static
                                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                         * @param {number} [length] Message length if known beforehand
                                         * @returns {google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction} OpenUrlAction
                                         * @throws {Error} If the payload is not a reader or valid buffer
                                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                         */
                                        OpenUrlAction.decode = function decode(reader, length) {
                                            if (!(reader instanceof $Reader))
                                                reader = $Reader.create(reader);
                                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction();
                                            while (reader.pos < end) {
                                                var tag = reader.uint32();
                                                switch (tag >>> 3) {
                                                case 1: {
                                                        message.url = reader.string();
                                                        break;
                                                    }
                                                case 3: {
                                                        message.urlTypeHint = reader.int32();
                                                        break;
                                                    }
                                                default:
                                                    reader.skipType(tag & 7);
                                                    break;
                                                }
                                            }
                                            return message;
                                        };
    
                                        /**
                                         * Decodes an OpenUrlAction message from the specified reader or buffer, length delimited.
                                         * @function decodeDelimited
                                         * @memberof google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction
                                         * @static
                                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                         * @returns {google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction} OpenUrlAction
                                         * @throws {Error} If the payload is not a reader or valid buffer
                                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                         */
                                        OpenUrlAction.decodeDelimited = function decodeDelimited(reader) {
                                            if (!(reader instanceof $Reader))
                                                reader = new $Reader(reader);
                                            return this.decode(reader, reader.uint32());
                                        };
    
                                        /**
                                         * Verifies an OpenUrlAction message.
                                         * @function verify
                                         * @memberof google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction
                                         * @static
                                         * @param {Object.<string,*>} message Plain object to verify
                                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                         */
                                        OpenUrlAction.verify = function verify(message) {
                                            if (typeof message !== "object" || message === null)
                                                return "object expected";
                                            if (message.url != null && message.hasOwnProperty("url"))
                                                if (!$util.isString(message.url))
                                                    return "url: string expected";
                                            if (message.urlTypeHint != null && message.hasOwnProperty("urlTypeHint"))
                                                switch (message.urlTypeHint) {
                                                default:
                                                    return "urlTypeHint: enum value expected";
                                                case 0:
                                                case 1:
                                                case 2:
                                                    break;
                                                }
                                            return null;
                                        };
    
                                        /**
                                         * Creates an OpenUrlAction message from a plain object. Also converts values to their respective internal types.
                                         * @function fromObject
                                         * @memberof google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction
                                         * @static
                                         * @param {Object.<string,*>} object Plain object
                                         * @returns {google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction} OpenUrlAction
                                         */
                                        OpenUrlAction.fromObject = function fromObject(object) {
                                            if (object instanceof $root.google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction)
                                                return object;
                                            var message = new $root.google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction();
                                            if (object.url != null)
                                                message.url = String(object.url);
                                            switch (object.urlTypeHint) {
                                            default:
                                                if (typeof object.urlTypeHint === "number") {
                                                    message.urlTypeHint = object.urlTypeHint;
                                                    break;
                                                }
                                                break;
                                            case "URL_TYPE_HINT_UNSPECIFIED":
                                            case 0:
                                                message.urlTypeHint = 0;
                                                break;
                                            case "AMP_ACTION":
                                            case 1:
                                                message.urlTypeHint = 1;
                                                break;
                                            case "AMP_CONTENT":
                                            case 2:
                                                message.urlTypeHint = 2;
                                                break;
                                            }
                                            return message;
                                        };
    
                                        /**
                                         * Creates a plain object from an OpenUrlAction message. Also converts values to other types if specified.
                                         * @function toObject
                                         * @memberof google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction
                                         * @static
                                         * @param {google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction} message OpenUrlAction
                                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                                         * @returns {Object.<string,*>} Plain object
                                         */
                                        OpenUrlAction.toObject = function toObject(message, options) {
                                            if (!options)
                                                options = {};
                                            var object = {};
                                            if (options.defaults) {
                                                object.url = "";
                                                object.urlTypeHint = options.enums === String ? "URL_TYPE_HINT_UNSPECIFIED" : 0;
                                            }
                                            if (message.url != null && message.hasOwnProperty("url"))
                                                object.url = message.url;
                                            if (message.urlTypeHint != null && message.hasOwnProperty("urlTypeHint"))
                                                object.urlTypeHint = options.enums === String ? $root.google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction.UrlTypeHint[message.urlTypeHint] === undefined ? message.urlTypeHint : $root.google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction.UrlTypeHint[message.urlTypeHint] : message.urlTypeHint;
                                            return object;
                                        };
    
                                        /**
                                         * Converts this OpenUrlAction to JSON.
                                         * @function toJSON
                                         * @memberof google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction
                                         * @instance
                                         * @returns {Object.<string,*>} JSON object
                                         */
                                        OpenUrlAction.prototype.toJSON = function toJSON() {
                                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                        };
    
                                        /**
                                         * Gets the default type url for OpenUrlAction
                                         * @function getTypeUrl
                                         * @memberof google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction
                                         * @static
                                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                         * @returns {string} The default type url
                                         */
                                        OpenUrlAction.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                            if (typeUrlPrefix === undefined) {
                                                typeUrlPrefix = "type.googleapis.com";
                                            }
                                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction";
                                        };
    
                                        /**
                                         * UrlTypeHint enum.
                                         * @name google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction.UrlTypeHint
                                         * @enum {number}
                                         * @property {number} URL_TYPE_HINT_UNSPECIFIED=0 URL_TYPE_HINT_UNSPECIFIED value
                                         * @property {number} AMP_ACTION=1 AMP_ACTION value
                                         * @property {number} AMP_CONTENT=2 AMP_CONTENT value
                                         */
                                        OpenUrlAction.UrlTypeHint = (function() {
                                            var valuesById = {}, values = Object.create(valuesById);
                                            values[valuesById[0] = "URL_TYPE_HINT_UNSPECIFIED"] = 0;
                                            values[valuesById[1] = "AMP_ACTION"] = 1;
                                            values[valuesById[2] = "AMP_CONTENT"] = 2;
                                            return values;
                                        })();
    
                                        return OpenUrlAction;
                                    })();
    
                                    return BrowseCarouselCardItem;
                                })();
    
                                /**
                                 * ImageDisplayOptions enum.
                                 * @name google.cloud.dialogflow.v2.Intent.Message.BrowseCarouselCard.ImageDisplayOptions
                                 * @enum {number}
                                 * @property {number} IMAGE_DISPLAY_OPTIONS_UNSPECIFIED=0 IMAGE_DISPLAY_OPTIONS_UNSPECIFIED value
                                 * @property {number} GRAY=1 GRAY value
                                 * @property {number} WHITE=2 WHITE value
                                 * @property {number} CROPPED=3 CROPPED value
                                 * @property {number} BLURRED_BACKGROUND=4 BLURRED_BACKGROUND value
                                 */
                                BrowseCarouselCard.ImageDisplayOptions = (function() {
                                    var valuesById = {}, values = Object.create(valuesById);
                                    values[valuesById[0] = "IMAGE_DISPLAY_OPTIONS_UNSPECIFIED"] = 0;
                                    values[valuesById[1] = "GRAY"] = 1;
                                    values[valuesById[2] = "WHITE"] = 2;
                                    values[valuesById[3] = "CROPPED"] = 3;
                                    values[valuesById[4] = "BLURRED_BACKGROUND"] = 4;
                                    return values;
                                })();
    
                                return BrowseCarouselCard;
                            })();
    
                            Message.TableCard = (function() {
    
                                /**
                                 * Properties of a TableCard.
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message
                                 * @interface ITableCard
                                 * @property {string|null} [title] TableCard title
                                 * @property {string|null} [subtitle] TableCard subtitle
                                 * @property {google.cloud.dialogflow.v2.Intent.Message.IImage|null} [image] TableCard image
                                 * @property {Array.<google.cloud.dialogflow.v2.Intent.Message.IColumnProperties>|null} [columnProperties] TableCard columnProperties
                                 * @property {Array.<google.cloud.dialogflow.v2.Intent.Message.ITableCardRow>|null} [rows] TableCard rows
                                 * @property {Array.<google.cloud.dialogflow.v2.Intent.Message.BasicCard.IButton>|null} [buttons] TableCard buttons
                                 */
    
                                /**
                                 * Constructs a new TableCard.
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message
                                 * @classdesc Represents a TableCard.
                                 * @implements ITableCard
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.ITableCard=} [properties] Properties to set
                                 */
                                function TableCard(properties) {
                                    this.columnProperties = [];
                                    this.rows = [];
                                    this.buttons = [];
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * TableCard title.
                                 * @member {string} title
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.TableCard
                                 * @instance
                                 */
                                TableCard.prototype.title = "";
    
                                /**
                                 * TableCard subtitle.
                                 * @member {string} subtitle
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.TableCard
                                 * @instance
                                 */
                                TableCard.prototype.subtitle = "";
    
                                /**
                                 * TableCard image.
                                 * @member {google.cloud.dialogflow.v2.Intent.Message.IImage|null|undefined} image
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.TableCard
                                 * @instance
                                 */
                                TableCard.prototype.image = null;
    
                                /**
                                 * TableCard columnProperties.
                                 * @member {Array.<google.cloud.dialogflow.v2.Intent.Message.IColumnProperties>} columnProperties
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.TableCard
                                 * @instance
                                 */
                                TableCard.prototype.columnProperties = $util.emptyArray;
    
                                /**
                                 * TableCard rows.
                                 * @member {Array.<google.cloud.dialogflow.v2.Intent.Message.ITableCardRow>} rows
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.TableCard
                                 * @instance
                                 */
                                TableCard.prototype.rows = $util.emptyArray;
    
                                /**
                                 * TableCard buttons.
                                 * @member {Array.<google.cloud.dialogflow.v2.Intent.Message.BasicCard.IButton>} buttons
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.TableCard
                                 * @instance
                                 */
                                TableCard.prototype.buttons = $util.emptyArray;
    
                                /**
                                 * Creates a new TableCard instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.TableCard
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.ITableCard=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.TableCard} TableCard instance
                                 */
                                TableCard.create = function create(properties) {
                                    return new TableCard(properties);
                                };
    
                                /**
                                 * Encodes the specified TableCard message. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Message.TableCard.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.TableCard
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.ITableCard} message TableCard message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                TableCard.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.title != null && Object.hasOwnProperty.call(message, "title"))
                                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.title);
                                    if (message.subtitle != null && Object.hasOwnProperty.call(message, "subtitle"))
                                        writer.uint32(/* id 2, wireType 2 =*/18).string(message.subtitle);
                                    if (message.image != null && Object.hasOwnProperty.call(message, "image"))
                                        $root.google.cloud.dialogflow.v2.Intent.Message.Image.encode(message.image, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                                    if (message.columnProperties != null && message.columnProperties.length)
                                        for (var i = 0; i < message.columnProperties.length; ++i)
                                            $root.google.cloud.dialogflow.v2.Intent.Message.ColumnProperties.encode(message.columnProperties[i], writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                                    if (message.rows != null && message.rows.length)
                                        for (var i = 0; i < message.rows.length; ++i)
                                            $root.google.cloud.dialogflow.v2.Intent.Message.TableCardRow.encode(message.rows[i], writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                                    if (message.buttons != null && message.buttons.length)
                                        for (var i = 0; i < message.buttons.length; ++i)
                                            $root.google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button.encode(message.buttons[i], writer.uint32(/* id 6, wireType 2 =*/50).fork()).ldelim();
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified TableCard message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Message.TableCard.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.TableCard
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.ITableCard} message TableCard message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                TableCard.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a TableCard message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.TableCard
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.TableCard} TableCard
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                TableCard.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.Intent.Message.TableCard();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                message.title = reader.string();
                                                break;
                                            }
                                        case 2: {
                                                message.subtitle = reader.string();
                                                break;
                                            }
                                        case 3: {
                                                message.image = $root.google.cloud.dialogflow.v2.Intent.Message.Image.decode(reader, reader.uint32());
                                                break;
                                            }
                                        case 4: {
                                                if (!(message.columnProperties && message.columnProperties.length))
                                                    message.columnProperties = [];
                                                message.columnProperties.push($root.google.cloud.dialogflow.v2.Intent.Message.ColumnProperties.decode(reader, reader.uint32()));
                                                break;
                                            }
                                        case 5: {
                                                if (!(message.rows && message.rows.length))
                                                    message.rows = [];
                                                message.rows.push($root.google.cloud.dialogflow.v2.Intent.Message.TableCardRow.decode(reader, reader.uint32()));
                                                break;
                                            }
                                        case 6: {
                                                if (!(message.buttons && message.buttons.length))
                                                    message.buttons = [];
                                                message.buttons.push($root.google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button.decode(reader, reader.uint32()));
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a TableCard message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.TableCard
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.TableCard} TableCard
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                TableCard.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a TableCard message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.TableCard
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                TableCard.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.title != null && message.hasOwnProperty("title"))
                                        if (!$util.isString(message.title))
                                            return "title: string expected";
                                    if (message.subtitle != null && message.hasOwnProperty("subtitle"))
                                        if (!$util.isString(message.subtitle))
                                            return "subtitle: string expected";
                                    if (message.image != null && message.hasOwnProperty("image")) {
                                        var error = $root.google.cloud.dialogflow.v2.Intent.Message.Image.verify(message.image);
                                        if (error)
                                            return "image." + error;
                                    }
                                    if (message.columnProperties != null && message.hasOwnProperty("columnProperties")) {
                                        if (!Array.isArray(message.columnProperties))
                                            return "columnProperties: array expected";
                                        for (var i = 0; i < message.columnProperties.length; ++i) {
                                            var error = $root.google.cloud.dialogflow.v2.Intent.Message.ColumnProperties.verify(message.columnProperties[i]);
                                            if (error)
                                                return "columnProperties." + error;
                                        }
                                    }
                                    if (message.rows != null && message.hasOwnProperty("rows")) {
                                        if (!Array.isArray(message.rows))
                                            return "rows: array expected";
                                        for (var i = 0; i < message.rows.length; ++i) {
                                            var error = $root.google.cloud.dialogflow.v2.Intent.Message.TableCardRow.verify(message.rows[i]);
                                            if (error)
                                                return "rows." + error;
                                        }
                                    }
                                    if (message.buttons != null && message.hasOwnProperty("buttons")) {
                                        if (!Array.isArray(message.buttons))
                                            return "buttons: array expected";
                                        for (var i = 0; i < message.buttons.length; ++i) {
                                            var error = $root.google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button.verify(message.buttons[i]);
                                            if (error)
                                                return "buttons." + error;
                                        }
                                    }
                                    return null;
                                };
    
                                /**
                                 * Creates a TableCard message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.TableCard
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.TableCard} TableCard
                                 */
                                TableCard.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2.Intent.Message.TableCard)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2.Intent.Message.TableCard();
                                    if (object.title != null)
                                        message.title = String(object.title);
                                    if (object.subtitle != null)
                                        message.subtitle = String(object.subtitle);
                                    if (object.image != null) {
                                        if (typeof object.image !== "object")
                                            throw TypeError(".google.cloud.dialogflow.v2.Intent.Message.TableCard.image: object expected");
                                        message.image = $root.google.cloud.dialogflow.v2.Intent.Message.Image.fromObject(object.image);
                                    }
                                    if (object.columnProperties) {
                                        if (!Array.isArray(object.columnProperties))
                                            throw TypeError(".google.cloud.dialogflow.v2.Intent.Message.TableCard.columnProperties: array expected");
                                        message.columnProperties = [];
                                        for (var i = 0; i < object.columnProperties.length; ++i) {
                                            if (typeof object.columnProperties[i] !== "object")
                                                throw TypeError(".google.cloud.dialogflow.v2.Intent.Message.TableCard.columnProperties: object expected");
                                            message.columnProperties[i] = $root.google.cloud.dialogflow.v2.Intent.Message.ColumnProperties.fromObject(object.columnProperties[i]);
                                        }
                                    }
                                    if (object.rows) {
                                        if (!Array.isArray(object.rows))
                                            throw TypeError(".google.cloud.dialogflow.v2.Intent.Message.TableCard.rows: array expected");
                                        message.rows = [];
                                        for (var i = 0; i < object.rows.length; ++i) {
                                            if (typeof object.rows[i] !== "object")
                                                throw TypeError(".google.cloud.dialogflow.v2.Intent.Message.TableCard.rows: object expected");
                                            message.rows[i] = $root.google.cloud.dialogflow.v2.Intent.Message.TableCardRow.fromObject(object.rows[i]);
                                        }
                                    }
                                    if (object.buttons) {
                                        if (!Array.isArray(object.buttons))
                                            throw TypeError(".google.cloud.dialogflow.v2.Intent.Message.TableCard.buttons: array expected");
                                        message.buttons = [];
                                        for (var i = 0; i < object.buttons.length; ++i) {
                                            if (typeof object.buttons[i] !== "object")
                                                throw TypeError(".google.cloud.dialogflow.v2.Intent.Message.TableCard.buttons: object expected");
                                            message.buttons[i] = $root.google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button.fromObject(object.buttons[i]);
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a TableCard message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.TableCard
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.TableCard} message TableCard
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                TableCard.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.arrays || options.defaults) {
                                        object.columnProperties = [];
                                        object.rows = [];
                                        object.buttons = [];
                                    }
                                    if (options.defaults) {
                                        object.title = "";
                                        object.subtitle = "";
                                        object.image = null;
                                    }
                                    if (message.title != null && message.hasOwnProperty("title"))
                                        object.title = message.title;
                                    if (message.subtitle != null && message.hasOwnProperty("subtitle"))
                                        object.subtitle = message.subtitle;
                                    if (message.image != null && message.hasOwnProperty("image"))
                                        object.image = $root.google.cloud.dialogflow.v2.Intent.Message.Image.toObject(message.image, options);
                                    if (message.columnProperties && message.columnProperties.length) {
                                        object.columnProperties = [];
                                        for (var j = 0; j < message.columnProperties.length; ++j)
                                            object.columnProperties[j] = $root.google.cloud.dialogflow.v2.Intent.Message.ColumnProperties.toObject(message.columnProperties[j], options);
                                    }
                                    if (message.rows && message.rows.length) {
                                        object.rows = [];
                                        for (var j = 0; j < message.rows.length; ++j)
                                            object.rows[j] = $root.google.cloud.dialogflow.v2.Intent.Message.TableCardRow.toObject(message.rows[j], options);
                                    }
                                    if (message.buttons && message.buttons.length) {
                                        object.buttons = [];
                                        for (var j = 0; j < message.buttons.length; ++j)
                                            object.buttons[j] = $root.google.cloud.dialogflow.v2.Intent.Message.BasicCard.Button.toObject(message.buttons[j], options);
                                    }
                                    return object;
                                };
    
                                /**
                                 * Converts this TableCard to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.TableCard
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                TableCard.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for TableCard
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.TableCard
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                TableCard.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2.Intent.Message.TableCard";
                                };
    
                                return TableCard;
                            })();
    
                            Message.ColumnProperties = (function() {
    
                                /**
                                 * Properties of a ColumnProperties.
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message
                                 * @interface IColumnProperties
                                 * @property {string|null} [header] ColumnProperties header
                                 * @property {google.cloud.dialogflow.v2.Intent.Message.ColumnProperties.HorizontalAlignment|null} [horizontalAlignment] ColumnProperties horizontalAlignment
                                 */
    
                                /**
                                 * Constructs a new ColumnProperties.
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message
                                 * @classdesc Represents a ColumnProperties.
                                 * @implements IColumnProperties
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.IColumnProperties=} [properties] Properties to set
                                 */
                                function ColumnProperties(properties) {
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * ColumnProperties header.
                                 * @member {string} header
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.ColumnProperties
                                 * @instance
                                 */
                                ColumnProperties.prototype.header = "";
    
                                /**
                                 * ColumnProperties horizontalAlignment.
                                 * @member {google.cloud.dialogflow.v2.Intent.Message.ColumnProperties.HorizontalAlignment} horizontalAlignment
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.ColumnProperties
                                 * @instance
                                 */
                                ColumnProperties.prototype.horizontalAlignment = 0;
    
                                /**
                                 * Creates a new ColumnProperties instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.ColumnProperties
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.IColumnProperties=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.ColumnProperties} ColumnProperties instance
                                 */
                                ColumnProperties.create = function create(properties) {
                                    return new ColumnProperties(properties);
                                };
    
                                /**
                                 * Encodes the specified ColumnProperties message. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Message.ColumnProperties.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.ColumnProperties
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.IColumnProperties} message ColumnProperties message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                ColumnProperties.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.header != null && Object.hasOwnProperty.call(message, "header"))
                                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.header);
                                    if (message.horizontalAlignment != null && Object.hasOwnProperty.call(message, "horizontalAlignment"))
                                        writer.uint32(/* id 2, wireType 0 =*/16).int32(message.horizontalAlignment);
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified ColumnProperties message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Message.ColumnProperties.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.ColumnProperties
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.IColumnProperties} message ColumnProperties message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                ColumnProperties.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a ColumnProperties message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.ColumnProperties
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.ColumnProperties} ColumnProperties
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                ColumnProperties.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.Intent.Message.ColumnProperties();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                message.header = reader.string();
                                                break;
                                            }
                                        case 2: {
                                                message.horizontalAlignment = reader.int32();
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a ColumnProperties message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.ColumnProperties
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.ColumnProperties} ColumnProperties
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                ColumnProperties.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a ColumnProperties message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.ColumnProperties
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                ColumnProperties.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.header != null && message.hasOwnProperty("header"))
                                        if (!$util.isString(message.header))
                                            return "header: string expected";
                                    if (message.horizontalAlignment != null && message.hasOwnProperty("horizontalAlignment"))
                                        switch (message.horizontalAlignment) {
                                        default:
                                            return "horizontalAlignment: enum value expected";
                                        case 0:
                                        case 1:
                                        case 2:
                                        case 3:
                                            break;
                                        }
                                    return null;
                                };
    
                                /**
                                 * Creates a ColumnProperties message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.ColumnProperties
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.ColumnProperties} ColumnProperties
                                 */
                                ColumnProperties.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2.Intent.Message.ColumnProperties)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2.Intent.Message.ColumnProperties();
                                    if (object.header != null)
                                        message.header = String(object.header);
                                    switch (object.horizontalAlignment) {
                                    default:
                                        if (typeof object.horizontalAlignment === "number") {
                                            message.horizontalAlignment = object.horizontalAlignment;
                                            break;
                                        }
                                        break;
                                    case "HORIZONTAL_ALIGNMENT_UNSPECIFIED":
                                    case 0:
                                        message.horizontalAlignment = 0;
                                        break;
                                    case "LEADING":
                                    case 1:
                                        message.horizontalAlignment = 1;
                                        break;
                                    case "CENTER":
                                    case 2:
                                        message.horizontalAlignment = 2;
                                        break;
                                    case "TRAILING":
                                    case 3:
                                        message.horizontalAlignment = 3;
                                        break;
                                    }
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a ColumnProperties message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.ColumnProperties
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.ColumnProperties} message ColumnProperties
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                ColumnProperties.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.defaults) {
                                        object.header = "";
                                        object.horizontalAlignment = options.enums === String ? "HORIZONTAL_ALIGNMENT_UNSPECIFIED" : 0;
                                    }
                                    if (message.header != null && message.hasOwnProperty("header"))
                                        object.header = message.header;
                                    if (message.horizontalAlignment != null && message.hasOwnProperty("horizontalAlignment"))
                                        object.horizontalAlignment = options.enums === String ? $root.google.cloud.dialogflow.v2.Intent.Message.ColumnProperties.HorizontalAlignment[message.horizontalAlignment] === undefined ? message.horizontalAlignment : $root.google.cloud.dialogflow.v2.Intent.Message.ColumnProperties.HorizontalAlignment[message.horizontalAlignment] : message.horizontalAlignment;
                                    return object;
                                };
    
                                /**
                                 * Converts this ColumnProperties to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.ColumnProperties
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                ColumnProperties.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for ColumnProperties
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.ColumnProperties
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                ColumnProperties.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2.Intent.Message.ColumnProperties";
                                };
    
                                /**
                                 * HorizontalAlignment enum.
                                 * @name google.cloud.dialogflow.v2.Intent.Message.ColumnProperties.HorizontalAlignment
                                 * @enum {number}
                                 * @property {number} HORIZONTAL_ALIGNMENT_UNSPECIFIED=0 HORIZONTAL_ALIGNMENT_UNSPECIFIED value
                                 * @property {number} LEADING=1 LEADING value
                                 * @property {number} CENTER=2 CENTER value
                                 * @property {number} TRAILING=3 TRAILING value
                                 */
                                ColumnProperties.HorizontalAlignment = (function() {
                                    var valuesById = {}, values = Object.create(valuesById);
                                    values[valuesById[0] = "HORIZONTAL_ALIGNMENT_UNSPECIFIED"] = 0;
                                    values[valuesById[1] = "LEADING"] = 1;
                                    values[valuesById[2] = "CENTER"] = 2;
                                    values[valuesById[3] = "TRAILING"] = 3;
                                    return values;
                                })();
    
                                return ColumnProperties;
                            })();
    
                            Message.TableCardRow = (function() {
    
                                /**
                                 * Properties of a TableCardRow.
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message
                                 * @interface ITableCardRow
                                 * @property {Array.<google.cloud.dialogflow.v2.Intent.Message.ITableCardCell>|null} [cells] TableCardRow cells
                                 * @property {boolean|null} [dividerAfter] TableCardRow dividerAfter
                                 */
    
                                /**
                                 * Constructs a new TableCardRow.
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message
                                 * @classdesc Represents a TableCardRow.
                                 * @implements ITableCardRow
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.ITableCardRow=} [properties] Properties to set
                                 */
                                function TableCardRow(properties) {
                                    this.cells = [];
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * TableCardRow cells.
                                 * @member {Array.<google.cloud.dialogflow.v2.Intent.Message.ITableCardCell>} cells
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.TableCardRow
                                 * @instance
                                 */
                                TableCardRow.prototype.cells = $util.emptyArray;
    
                                /**
                                 * TableCardRow dividerAfter.
                                 * @member {boolean} dividerAfter
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.TableCardRow
                                 * @instance
                                 */
                                TableCardRow.prototype.dividerAfter = false;
    
                                /**
                                 * Creates a new TableCardRow instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.TableCardRow
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.ITableCardRow=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.TableCardRow} TableCardRow instance
                                 */
                                TableCardRow.create = function create(properties) {
                                    return new TableCardRow(properties);
                                };
    
                                /**
                                 * Encodes the specified TableCardRow message. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Message.TableCardRow.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.TableCardRow
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.ITableCardRow} message TableCardRow message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                TableCardRow.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.cells != null && message.cells.length)
                                        for (var i = 0; i < message.cells.length; ++i)
                                            $root.google.cloud.dialogflow.v2.Intent.Message.TableCardCell.encode(message.cells[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                                    if (message.dividerAfter != null && Object.hasOwnProperty.call(message, "dividerAfter"))
                                        writer.uint32(/* id 2, wireType 0 =*/16).bool(message.dividerAfter);
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified TableCardRow message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Message.TableCardRow.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.TableCardRow
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.ITableCardRow} message TableCardRow message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                TableCardRow.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a TableCardRow message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.TableCardRow
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.TableCardRow} TableCardRow
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                TableCardRow.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.Intent.Message.TableCardRow();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                if (!(message.cells && message.cells.length))
                                                    message.cells = [];
                                                message.cells.push($root.google.cloud.dialogflow.v2.Intent.Message.TableCardCell.decode(reader, reader.uint32()));
                                                break;
                                            }
                                        case 2: {
                                                message.dividerAfter = reader.bool();
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a TableCardRow message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.TableCardRow
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.TableCardRow} TableCardRow
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                TableCardRow.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a TableCardRow message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.TableCardRow
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                TableCardRow.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.cells != null && message.hasOwnProperty("cells")) {
                                        if (!Array.isArray(message.cells))
                                            return "cells: array expected";
                                        for (var i = 0; i < message.cells.length; ++i) {
                                            var error = $root.google.cloud.dialogflow.v2.Intent.Message.TableCardCell.verify(message.cells[i]);
                                            if (error)
                                                return "cells." + error;
                                        }
                                    }
                                    if (message.dividerAfter != null && message.hasOwnProperty("dividerAfter"))
                                        if (typeof message.dividerAfter !== "boolean")
                                            return "dividerAfter: boolean expected";
                                    return null;
                                };
    
                                /**
                                 * Creates a TableCardRow message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.TableCardRow
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.TableCardRow} TableCardRow
                                 */
                                TableCardRow.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2.Intent.Message.TableCardRow)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2.Intent.Message.TableCardRow();
                                    if (object.cells) {
                                        if (!Array.isArray(object.cells))
                                            throw TypeError(".google.cloud.dialogflow.v2.Intent.Message.TableCardRow.cells: array expected");
                                        message.cells = [];
                                        for (var i = 0; i < object.cells.length; ++i) {
                                            if (typeof object.cells[i] !== "object")
                                                throw TypeError(".google.cloud.dialogflow.v2.Intent.Message.TableCardRow.cells: object expected");
                                            message.cells[i] = $root.google.cloud.dialogflow.v2.Intent.Message.TableCardCell.fromObject(object.cells[i]);
                                        }
                                    }
                                    if (object.dividerAfter != null)
                                        message.dividerAfter = Boolean(object.dividerAfter);
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a TableCardRow message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.TableCardRow
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.TableCardRow} message TableCardRow
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                TableCardRow.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.arrays || options.defaults)
                                        object.cells = [];
                                    if (options.defaults)
                                        object.dividerAfter = false;
                                    if (message.cells && message.cells.length) {
                                        object.cells = [];
                                        for (var j = 0; j < message.cells.length; ++j)
                                            object.cells[j] = $root.google.cloud.dialogflow.v2.Intent.Message.TableCardCell.toObject(message.cells[j], options);
                                    }
                                    if (message.dividerAfter != null && message.hasOwnProperty("dividerAfter"))
                                        object.dividerAfter = message.dividerAfter;
                                    return object;
                                };
    
                                /**
                                 * Converts this TableCardRow to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.TableCardRow
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                TableCardRow.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for TableCardRow
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.TableCardRow
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                TableCardRow.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2.Intent.Message.TableCardRow";
                                };
    
                                return TableCardRow;
                            })();
    
                            Message.TableCardCell = (function() {
    
                                /**
                                 * Properties of a TableCardCell.
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message
                                 * @interface ITableCardCell
                                 * @property {string|null} [text] TableCardCell text
                                 */
    
                                /**
                                 * Constructs a new TableCardCell.
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message
                                 * @classdesc Represents a TableCardCell.
                                 * @implements ITableCardCell
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.ITableCardCell=} [properties] Properties to set
                                 */
                                function TableCardCell(properties) {
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * TableCardCell text.
                                 * @member {string} text
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.TableCardCell
                                 * @instance
                                 */
                                TableCardCell.prototype.text = "";
    
                                /**
                                 * Creates a new TableCardCell instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.TableCardCell
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.ITableCardCell=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.TableCardCell} TableCardCell instance
                                 */
                                TableCardCell.create = function create(properties) {
                                    return new TableCardCell(properties);
                                };
    
                                /**
                                 * Encodes the specified TableCardCell message. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Message.TableCardCell.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.TableCardCell
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.ITableCardCell} message TableCardCell message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                TableCardCell.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.text != null && Object.hasOwnProperty.call(message, "text"))
                                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.text);
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified TableCardCell message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.Message.TableCardCell.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.TableCardCell
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.ITableCardCell} message TableCardCell message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                TableCardCell.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a TableCardCell message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.TableCardCell
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.TableCardCell} TableCardCell
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                TableCardCell.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.Intent.Message.TableCardCell();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                message.text = reader.string();
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a TableCardCell message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.TableCardCell
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.TableCardCell} TableCardCell
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                TableCardCell.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a TableCardCell message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.TableCardCell
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                TableCardCell.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.text != null && message.hasOwnProperty("text"))
                                        if (!$util.isString(message.text))
                                            return "text: string expected";
                                    return null;
                                };
    
                                /**
                                 * Creates a TableCardCell message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.TableCardCell
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2.Intent.Message.TableCardCell} TableCardCell
                                 */
                                TableCardCell.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2.Intent.Message.TableCardCell)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2.Intent.Message.TableCardCell();
                                    if (object.text != null)
                                        message.text = String(object.text);
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a TableCardCell message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.TableCardCell
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Intent.Message.TableCardCell} message TableCardCell
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                TableCardCell.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.defaults)
                                        object.text = "";
                                    if (message.text != null && message.hasOwnProperty("text"))
                                        object.text = message.text;
                                    return object;
                                };
    
                                /**
                                 * Converts this TableCardCell to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.TableCardCell
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                TableCardCell.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for TableCardCell
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2.Intent.Message.TableCardCell
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                TableCardCell.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2.Intent.Message.TableCardCell";
                                };
    
                                return TableCardCell;
                            })();
    
                            return Message;
                        })();
    
                        Intent.FollowupIntentInfo = (function() {
    
                            /**
                             * Properties of a FollowupIntentInfo.
                             * @memberof google.cloud.dialogflow.v2.Intent
                             * @interface IFollowupIntentInfo
                             * @property {string|null} [followupIntentName] FollowupIntentInfo followupIntentName
                             * @property {string|null} [parentFollowupIntentName] FollowupIntentInfo parentFollowupIntentName
                             */
    
                            /**
                             * Constructs a new FollowupIntentInfo.
                             * @memberof google.cloud.dialogflow.v2.Intent
                             * @classdesc Represents a FollowupIntentInfo.
                             * @implements IFollowupIntentInfo
                             * @constructor
                             * @param {google.cloud.dialogflow.v2.Intent.IFollowupIntentInfo=} [properties] Properties to set
                             */
                            function FollowupIntentInfo(properties) {
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * FollowupIntentInfo followupIntentName.
                             * @member {string} followupIntentName
                             * @memberof google.cloud.dialogflow.v2.Intent.FollowupIntentInfo
                             * @instance
                             */
                            FollowupIntentInfo.prototype.followupIntentName = "";
    
                            /**
                             * FollowupIntentInfo parentFollowupIntentName.
                             * @member {string} parentFollowupIntentName
                             * @memberof google.cloud.dialogflow.v2.Intent.FollowupIntentInfo
                             * @instance
                             */
                            FollowupIntentInfo.prototype.parentFollowupIntentName = "";
    
                            /**
                             * Creates a new FollowupIntentInfo instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2.Intent.FollowupIntentInfo
                             * @static
                             * @param {google.cloud.dialogflow.v2.Intent.IFollowupIntentInfo=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2.Intent.FollowupIntentInfo} FollowupIntentInfo instance
                             */
                            FollowupIntentInfo.create = function create(properties) {
                                return new FollowupIntentInfo(properties);
                            };
    
                            /**
                             * Encodes the specified FollowupIntentInfo message. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.FollowupIntentInfo.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2.Intent.FollowupIntentInfo
                             * @static
                             * @param {google.cloud.dialogflow.v2.Intent.IFollowupIntentInfo} message FollowupIntentInfo message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            FollowupIntentInfo.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.followupIntentName != null && Object.hasOwnProperty.call(message, "followupIntentName"))
                                    writer.uint32(/* id 1, wireType 2 =*/10).string(message.followupIntentName);
                                if (message.parentFollowupIntentName != null && Object.hasOwnProperty.call(message, "parentFollowupIntentName"))
                                    writer.uint32(/* id 2, wireType 2 =*/18).string(message.parentFollowupIntentName);
                                return writer;
                            };
    
                            /**
                             * Encodes the specified FollowupIntentInfo message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.Intent.FollowupIntentInfo.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2.Intent.FollowupIntentInfo
                             * @static
                             * @param {google.cloud.dialogflow.v2.Intent.IFollowupIntentInfo} message FollowupIntentInfo message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            FollowupIntentInfo.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a FollowupIntentInfo message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2.Intent.FollowupIntentInfo
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2.Intent.FollowupIntentInfo} FollowupIntentInfo
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            FollowupIntentInfo.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.Intent.FollowupIntentInfo();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.followupIntentName = reader.string();
                                            break;
                                        }
                                    case 2: {
                                            message.parentFollowupIntentName = reader.string();
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a FollowupIntentInfo message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2.Intent.FollowupIntentInfo
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2.Intent.FollowupIntentInfo} FollowupIntentInfo
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            FollowupIntentInfo.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a FollowupIntentInfo message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2.Intent.FollowupIntentInfo
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            FollowupIntentInfo.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.followupIntentName != null && message.hasOwnProperty("followupIntentName"))
                                    if (!$util.isString(message.followupIntentName))
                                        return "followupIntentName: string expected";
                                if (message.parentFollowupIntentName != null && message.hasOwnProperty("parentFollowupIntentName"))
                                    if (!$util.isString(message.parentFollowupIntentName))
                                        return "parentFollowupIntentName: string expected";
                                return null;
                            };
    
                            /**
                             * Creates a FollowupIntentInfo message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2.Intent.FollowupIntentInfo
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2.Intent.FollowupIntentInfo} FollowupIntentInfo
                             */
                            FollowupIntentInfo.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2.Intent.FollowupIntentInfo)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2.Intent.FollowupIntentInfo();
                                if (object.followupIntentName != null)
                                    message.followupIntentName = String(object.followupIntentName);
                                if (object.parentFollowupIntentName != null)
                                    message.parentFollowupIntentName = String(object.parentFollowupIntentName);
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a FollowupIntentInfo message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2.Intent.FollowupIntentInfo
                             * @static
                             * @param {google.cloud.dialogflow.v2.Intent.FollowupIntentInfo} message FollowupIntentInfo
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            FollowupIntentInfo.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.defaults) {
                                    object.followupIntentName = "";
                                    object.parentFollowupIntentName = "";
                                }
                                if (message.followupIntentName != null && message.hasOwnProperty("followupIntentName"))
                                    object.followupIntentName = message.followupIntentName;
                                if (message.parentFollowupIntentName != null && message.hasOwnProperty("parentFollowupIntentName"))
                                    object.parentFollowupIntentName = message.parentFollowupIntentName;
                                return object;
                            };
    
                            /**
                             * Converts this FollowupIntentInfo to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2.Intent.FollowupIntentInfo
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            FollowupIntentInfo.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for FollowupIntentInfo
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2.Intent.FollowupIntentInfo
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            FollowupIntentInfo.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2.Intent.FollowupIntentInfo";
                            };
    
                            return FollowupIntentInfo;
                        })();
    
                        return Intent;
                    })();
    
                    v2.ListIntentsRequest = (function() {
    
                        /**
                         * Properties of a ListIntentsRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IListIntentsRequest
                         * @property {string|null} [parent] ListIntentsRequest parent
                         * @property {string|null} [languageCode] ListIntentsRequest languageCode
                         * @property {google.cloud.dialogflow.v2.IntentView|null} [intentView] ListIntentsRequest intentView
                         * @property {number|null} [pageSize] ListIntentsRequest pageSize
                         * @property {string|null} [pageToken] ListIntentsRequest pageToken
                         */
    
                        /**
                         * Constructs a new ListIntentsRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a ListIntentsRequest.
                         * @implements IListIntentsRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IListIntentsRequest=} [properties] Properties to set
                         */
                        function ListIntentsRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListIntentsRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.ListIntentsRequest
                         * @instance
                         */
                        ListIntentsRequest.prototype.parent = "";
    
                        /**
                         * ListIntentsRequest languageCode.
                         * @member {string} languageCode
                         * @memberof google.cloud.dialogflow.v2.ListIntentsRequest
                         * @instance
                         */
                        ListIntentsRequest.prototype.languageCode = "";
    
                        /**
                         * ListIntentsRequest intentView.
                         * @member {google.cloud.dialogflow.v2.IntentView} intentView
                         * @memberof google.cloud.dialogflow.v2.ListIntentsRequest
                         * @instance
                         */
                        ListIntentsRequest.prototype.intentView = 0;
    
                        /**
                         * ListIntentsRequest pageSize.
                         * @member {number} pageSize
                         * @memberof google.cloud.dialogflow.v2.ListIntentsRequest
                         * @instance
                         */
                        ListIntentsRequest.prototype.pageSize = 0;
    
                        /**
                         * ListIntentsRequest pageToken.
                         * @member {string} pageToken
                         * @memberof google.cloud.dialogflow.v2.ListIntentsRequest
                         * @instance
                         */
                        ListIntentsRequest.prototype.pageToken = "";
    
                        /**
                         * Creates a new ListIntentsRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ListIntentsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListIntentsRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ListIntentsRequest} ListIntentsRequest instance
                         */
                        ListIntentsRequest.create = function create(properties) {
                            return new ListIntentsRequest(properties);
                        };
    
                        /**
                         * Encodes the specified ListIntentsRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.ListIntentsRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ListIntentsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListIntentsRequest} message ListIntentsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListIntentsRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.languageCode != null && Object.hasOwnProperty.call(message, "languageCode"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.languageCode);
                            if (message.intentView != null && Object.hasOwnProperty.call(message, "intentView"))
                                writer.uint32(/* id 3, wireType 0 =*/24).int32(message.intentView);
                            if (message.pageSize != null && Object.hasOwnProperty.call(message, "pageSize"))
                                writer.uint32(/* id 4, wireType 0 =*/32).int32(message.pageSize);
                            if (message.pageToken != null && Object.hasOwnProperty.call(message, "pageToken"))
                                writer.uint32(/* id 5, wireType 2 =*/42).string(message.pageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListIntentsRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ListIntentsRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListIntentsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListIntentsRequest} message ListIntentsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListIntentsRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListIntentsRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ListIntentsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ListIntentsRequest} ListIntentsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListIntentsRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ListIntentsRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.languageCode = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.intentView = reader.int32();
                                        break;
                                    }
                                case 4: {
                                        message.pageSize = reader.int32();
                                        break;
                                    }
                                case 5: {
                                        message.pageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListIntentsRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListIntentsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ListIntentsRequest} ListIntentsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListIntentsRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListIntentsRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ListIntentsRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListIntentsRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                if (!$util.isString(message.languageCode))
                                    return "languageCode: string expected";
                            if (message.intentView != null && message.hasOwnProperty("intentView"))
                                switch (message.intentView) {
                                default:
                                    return "intentView: enum value expected";
                                case 0:
                                case 1:
                                    break;
                                }
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                if (!$util.isInteger(message.pageSize))
                                    return "pageSize: integer expected";
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                if (!$util.isString(message.pageToken))
                                    return "pageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListIntentsRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ListIntentsRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ListIntentsRequest} ListIntentsRequest
                         */
                        ListIntentsRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ListIntentsRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ListIntentsRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.languageCode != null)
                                message.languageCode = String(object.languageCode);
                            switch (object.intentView) {
                            default:
                                if (typeof object.intentView === "number") {
                                    message.intentView = object.intentView;
                                    break;
                                }
                                break;
                            case "INTENT_VIEW_UNSPECIFIED":
                            case 0:
                                message.intentView = 0;
                                break;
                            case "INTENT_VIEW_FULL":
                            case 1:
                                message.intentView = 1;
                                break;
                            }
                            if (object.pageSize != null)
                                message.pageSize = object.pageSize | 0;
                            if (object.pageToken != null)
                                message.pageToken = String(object.pageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListIntentsRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ListIntentsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ListIntentsRequest} message ListIntentsRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListIntentsRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.languageCode = "";
                                object.intentView = options.enums === String ? "INTENT_VIEW_UNSPECIFIED" : 0;
                                object.pageSize = 0;
                                object.pageToken = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                object.languageCode = message.languageCode;
                            if (message.intentView != null && message.hasOwnProperty("intentView"))
                                object.intentView = options.enums === String ? $root.google.cloud.dialogflow.v2.IntentView[message.intentView] === undefined ? message.intentView : $root.google.cloud.dialogflow.v2.IntentView[message.intentView] : message.intentView;
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                object.pageSize = message.pageSize;
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                object.pageToken = message.pageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListIntentsRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ListIntentsRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListIntentsRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListIntentsRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ListIntentsRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListIntentsRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ListIntentsRequest";
                        };
    
                        return ListIntentsRequest;
                    })();
    
                    v2.ListIntentsResponse = (function() {
    
                        /**
                         * Properties of a ListIntentsResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IListIntentsResponse
                         * @property {Array.<google.cloud.dialogflow.v2.IIntent>|null} [intents] ListIntentsResponse intents
                         * @property {string|null} [nextPageToken] ListIntentsResponse nextPageToken
                         */
    
                        /**
                         * Constructs a new ListIntentsResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a ListIntentsResponse.
                         * @implements IListIntentsResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IListIntentsResponse=} [properties] Properties to set
                         */
                        function ListIntentsResponse(properties) {
                            this.intents = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListIntentsResponse intents.
                         * @member {Array.<google.cloud.dialogflow.v2.IIntent>} intents
                         * @memberof google.cloud.dialogflow.v2.ListIntentsResponse
                         * @instance
                         */
                        ListIntentsResponse.prototype.intents = $util.emptyArray;
    
                        /**
                         * ListIntentsResponse nextPageToken.
                         * @member {string} nextPageToken
                         * @memberof google.cloud.dialogflow.v2.ListIntentsResponse
                         * @instance
                         */
                        ListIntentsResponse.prototype.nextPageToken = "";
    
                        /**
                         * Creates a new ListIntentsResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ListIntentsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListIntentsResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ListIntentsResponse} ListIntentsResponse instance
                         */
                        ListIntentsResponse.create = function create(properties) {
                            return new ListIntentsResponse(properties);
                        };
    
                        /**
                         * Encodes the specified ListIntentsResponse message. Does not implicitly {@link google.cloud.dialogflow.v2.ListIntentsResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ListIntentsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListIntentsResponse} message ListIntentsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListIntentsResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.intents != null && message.intents.length)
                                for (var i = 0; i < message.intents.length; ++i)
                                    $root.google.cloud.dialogflow.v2.Intent.encode(message.intents[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.nextPageToken != null && Object.hasOwnProperty.call(message, "nextPageToken"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.nextPageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListIntentsResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ListIntentsResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListIntentsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListIntentsResponse} message ListIntentsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListIntentsResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListIntentsResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ListIntentsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ListIntentsResponse} ListIntentsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListIntentsResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ListIntentsResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.intents && message.intents.length))
                                            message.intents = [];
                                        message.intents.push($root.google.cloud.dialogflow.v2.Intent.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 2: {
                                        message.nextPageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListIntentsResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListIntentsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ListIntentsResponse} ListIntentsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListIntentsResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListIntentsResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ListIntentsResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListIntentsResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.intents != null && message.hasOwnProperty("intents")) {
                                if (!Array.isArray(message.intents))
                                    return "intents: array expected";
                                for (var i = 0; i < message.intents.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.Intent.verify(message.intents[i]);
                                    if (error)
                                        return "intents." + error;
                                }
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                if (!$util.isString(message.nextPageToken))
                                    return "nextPageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListIntentsResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ListIntentsResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ListIntentsResponse} ListIntentsResponse
                         */
                        ListIntentsResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ListIntentsResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ListIntentsResponse();
                            if (object.intents) {
                                if (!Array.isArray(object.intents))
                                    throw TypeError(".google.cloud.dialogflow.v2.ListIntentsResponse.intents: array expected");
                                message.intents = [];
                                for (var i = 0; i < object.intents.length; ++i) {
                                    if (typeof object.intents[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.ListIntentsResponse.intents: object expected");
                                    message.intents[i] = $root.google.cloud.dialogflow.v2.Intent.fromObject(object.intents[i]);
                                }
                            }
                            if (object.nextPageToken != null)
                                message.nextPageToken = String(object.nextPageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListIntentsResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ListIntentsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.ListIntentsResponse} message ListIntentsResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListIntentsResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.intents = [];
                            if (options.defaults)
                                object.nextPageToken = "";
                            if (message.intents && message.intents.length) {
                                object.intents = [];
                                for (var j = 0; j < message.intents.length; ++j)
                                    object.intents[j] = $root.google.cloud.dialogflow.v2.Intent.toObject(message.intents[j], options);
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                object.nextPageToken = message.nextPageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListIntentsResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ListIntentsResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListIntentsResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListIntentsResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ListIntentsResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListIntentsResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ListIntentsResponse";
                        };
    
                        return ListIntentsResponse;
                    })();
    
                    v2.GetIntentRequest = (function() {
    
                        /**
                         * Properties of a GetIntentRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IGetIntentRequest
                         * @property {string|null} [name] GetIntentRequest name
                         * @property {string|null} [languageCode] GetIntentRequest languageCode
                         * @property {google.cloud.dialogflow.v2.IntentView|null} [intentView] GetIntentRequest intentView
                         */
    
                        /**
                         * Constructs a new GetIntentRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a GetIntentRequest.
                         * @implements IGetIntentRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IGetIntentRequest=} [properties] Properties to set
                         */
                        function GetIntentRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GetIntentRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2.GetIntentRequest
                         * @instance
                         */
                        GetIntentRequest.prototype.name = "";
    
                        /**
                         * GetIntentRequest languageCode.
                         * @member {string} languageCode
                         * @memberof google.cloud.dialogflow.v2.GetIntentRequest
                         * @instance
                         */
                        GetIntentRequest.prototype.languageCode = "";
    
                        /**
                         * GetIntentRequest intentView.
                         * @member {google.cloud.dialogflow.v2.IntentView} intentView
                         * @memberof google.cloud.dialogflow.v2.GetIntentRequest
                         * @instance
                         */
                        GetIntentRequest.prototype.intentView = 0;
    
                        /**
                         * Creates a new GetIntentRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.GetIntentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetIntentRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.GetIntentRequest} GetIntentRequest instance
                         */
                        GetIntentRequest.create = function create(properties) {
                            return new GetIntentRequest(properties);
                        };
    
                        /**
                         * Encodes the specified GetIntentRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.GetIntentRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.GetIntentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetIntentRequest} message GetIntentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetIntentRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            if (message.languageCode != null && Object.hasOwnProperty.call(message, "languageCode"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.languageCode);
                            if (message.intentView != null && Object.hasOwnProperty.call(message, "intentView"))
                                writer.uint32(/* id 3, wireType 0 =*/24).int32(message.intentView);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GetIntentRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.GetIntentRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GetIntentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetIntentRequest} message GetIntentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetIntentRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GetIntentRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.GetIntentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.GetIntentRequest} GetIntentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetIntentRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.GetIntentRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.languageCode = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.intentView = reader.int32();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GetIntentRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GetIntentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.GetIntentRequest} GetIntentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetIntentRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GetIntentRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.GetIntentRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GetIntentRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                if (!$util.isString(message.languageCode))
                                    return "languageCode: string expected";
                            if (message.intentView != null && message.hasOwnProperty("intentView"))
                                switch (message.intentView) {
                                default:
                                    return "intentView: enum value expected";
                                case 0:
                                case 1:
                                    break;
                                }
                            return null;
                        };
    
                        /**
                         * Creates a GetIntentRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.GetIntentRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.GetIntentRequest} GetIntentRequest
                         */
                        GetIntentRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.GetIntentRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.GetIntentRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            if (object.languageCode != null)
                                message.languageCode = String(object.languageCode);
                            switch (object.intentView) {
                            default:
                                if (typeof object.intentView === "number") {
                                    message.intentView = object.intentView;
                                    break;
                                }
                                break;
                            case "INTENT_VIEW_UNSPECIFIED":
                            case 0:
                                message.intentView = 0;
                                break;
                            case "INTENT_VIEW_FULL":
                            case 1:
                                message.intentView = 1;
                                break;
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GetIntentRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.GetIntentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.GetIntentRequest} message GetIntentRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GetIntentRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.name = "";
                                object.languageCode = "";
                                object.intentView = options.enums === String ? "INTENT_VIEW_UNSPECIFIED" : 0;
                            }
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                object.languageCode = message.languageCode;
                            if (message.intentView != null && message.hasOwnProperty("intentView"))
                                object.intentView = options.enums === String ? $root.google.cloud.dialogflow.v2.IntentView[message.intentView] === undefined ? message.intentView : $root.google.cloud.dialogflow.v2.IntentView[message.intentView] : message.intentView;
                            return object;
                        };
    
                        /**
                         * Converts this GetIntentRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.GetIntentRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GetIntentRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GetIntentRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.GetIntentRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GetIntentRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.GetIntentRequest";
                        };
    
                        return GetIntentRequest;
                    })();
    
                    v2.CreateIntentRequest = (function() {
    
                        /**
                         * Properties of a CreateIntentRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ICreateIntentRequest
                         * @property {string|null} [parent] CreateIntentRequest parent
                         * @property {google.cloud.dialogflow.v2.IIntent|null} [intent] CreateIntentRequest intent
                         * @property {string|null} [languageCode] CreateIntentRequest languageCode
                         * @property {google.cloud.dialogflow.v2.IntentView|null} [intentView] CreateIntentRequest intentView
                         */
    
                        /**
                         * Constructs a new CreateIntentRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a CreateIntentRequest.
                         * @implements ICreateIntentRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ICreateIntentRequest=} [properties] Properties to set
                         */
                        function CreateIntentRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * CreateIntentRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.CreateIntentRequest
                         * @instance
                         */
                        CreateIntentRequest.prototype.parent = "";
    
                        /**
                         * CreateIntentRequest intent.
                         * @member {google.cloud.dialogflow.v2.IIntent|null|undefined} intent
                         * @memberof google.cloud.dialogflow.v2.CreateIntentRequest
                         * @instance
                         */
                        CreateIntentRequest.prototype.intent = null;
    
                        /**
                         * CreateIntentRequest languageCode.
                         * @member {string} languageCode
                         * @memberof google.cloud.dialogflow.v2.CreateIntentRequest
                         * @instance
                         */
                        CreateIntentRequest.prototype.languageCode = "";
    
                        /**
                         * CreateIntentRequest intentView.
                         * @member {google.cloud.dialogflow.v2.IntentView} intentView
                         * @memberof google.cloud.dialogflow.v2.CreateIntentRequest
                         * @instance
                         */
                        CreateIntentRequest.prototype.intentView = 0;
    
                        /**
                         * Creates a new CreateIntentRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.CreateIntentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICreateIntentRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.CreateIntentRequest} CreateIntentRequest instance
                         */
                        CreateIntentRequest.create = function create(properties) {
                            return new CreateIntentRequest(properties);
                        };
    
                        /**
                         * Encodes the specified CreateIntentRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.CreateIntentRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.CreateIntentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICreateIntentRequest} message CreateIntentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateIntentRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.intent != null && Object.hasOwnProperty.call(message, "intent"))
                                $root.google.cloud.dialogflow.v2.Intent.encode(message.intent, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.languageCode != null && Object.hasOwnProperty.call(message, "languageCode"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.languageCode);
                            if (message.intentView != null && Object.hasOwnProperty.call(message, "intentView"))
                                writer.uint32(/* id 4, wireType 0 =*/32).int32(message.intentView);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified CreateIntentRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.CreateIntentRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.CreateIntentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICreateIntentRequest} message CreateIntentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateIntentRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a CreateIntentRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.CreateIntentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.CreateIntentRequest} CreateIntentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateIntentRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.CreateIntentRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.intent = $root.google.cloud.dialogflow.v2.Intent.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 3: {
                                        message.languageCode = reader.string();
                                        break;
                                    }
                                case 4: {
                                        message.intentView = reader.int32();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a CreateIntentRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.CreateIntentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.CreateIntentRequest} CreateIntentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateIntentRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a CreateIntentRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.CreateIntentRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        CreateIntentRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.intent != null && message.hasOwnProperty("intent")) {
                                var error = $root.google.cloud.dialogflow.v2.Intent.verify(message.intent);
                                if (error)
                                    return "intent." + error;
                            }
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                if (!$util.isString(message.languageCode))
                                    return "languageCode: string expected";
                            if (message.intentView != null && message.hasOwnProperty("intentView"))
                                switch (message.intentView) {
                                default:
                                    return "intentView: enum value expected";
                                case 0:
                                case 1:
                                    break;
                                }
                            return null;
                        };
    
                        /**
                         * Creates a CreateIntentRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.CreateIntentRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.CreateIntentRequest} CreateIntentRequest
                         */
                        CreateIntentRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.CreateIntentRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.CreateIntentRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.intent != null) {
                                if (typeof object.intent !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.CreateIntentRequest.intent: object expected");
                                message.intent = $root.google.cloud.dialogflow.v2.Intent.fromObject(object.intent);
                            }
                            if (object.languageCode != null)
                                message.languageCode = String(object.languageCode);
                            switch (object.intentView) {
                            default:
                                if (typeof object.intentView === "number") {
                                    message.intentView = object.intentView;
                                    break;
                                }
                                break;
                            case "INTENT_VIEW_UNSPECIFIED":
                            case 0:
                                message.intentView = 0;
                                break;
                            case "INTENT_VIEW_FULL":
                            case 1:
                                message.intentView = 1;
                                break;
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a CreateIntentRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.CreateIntentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.CreateIntentRequest} message CreateIntentRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        CreateIntentRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.intent = null;
                                object.languageCode = "";
                                object.intentView = options.enums === String ? "INTENT_VIEW_UNSPECIFIED" : 0;
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.intent != null && message.hasOwnProperty("intent"))
                                object.intent = $root.google.cloud.dialogflow.v2.Intent.toObject(message.intent, options);
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                object.languageCode = message.languageCode;
                            if (message.intentView != null && message.hasOwnProperty("intentView"))
                                object.intentView = options.enums === String ? $root.google.cloud.dialogflow.v2.IntentView[message.intentView] === undefined ? message.intentView : $root.google.cloud.dialogflow.v2.IntentView[message.intentView] : message.intentView;
                            return object;
                        };
    
                        /**
                         * Converts this CreateIntentRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.CreateIntentRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        CreateIntentRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for CreateIntentRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.CreateIntentRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        CreateIntentRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.CreateIntentRequest";
                        };
    
                        return CreateIntentRequest;
                    })();
    
                    v2.UpdateIntentRequest = (function() {
    
                        /**
                         * Properties of an UpdateIntentRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IUpdateIntentRequest
                         * @property {google.cloud.dialogflow.v2.IIntent|null} [intent] UpdateIntentRequest intent
                         * @property {string|null} [languageCode] UpdateIntentRequest languageCode
                         * @property {google.protobuf.IFieldMask|null} [updateMask] UpdateIntentRequest updateMask
                         * @property {google.cloud.dialogflow.v2.IntentView|null} [intentView] UpdateIntentRequest intentView
                         */
    
                        /**
                         * Constructs a new UpdateIntentRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an UpdateIntentRequest.
                         * @implements IUpdateIntentRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IUpdateIntentRequest=} [properties] Properties to set
                         */
                        function UpdateIntentRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * UpdateIntentRequest intent.
                         * @member {google.cloud.dialogflow.v2.IIntent|null|undefined} intent
                         * @memberof google.cloud.dialogflow.v2.UpdateIntentRequest
                         * @instance
                         */
                        UpdateIntentRequest.prototype.intent = null;
    
                        /**
                         * UpdateIntentRequest languageCode.
                         * @member {string} languageCode
                         * @memberof google.cloud.dialogflow.v2.UpdateIntentRequest
                         * @instance
                         */
                        UpdateIntentRequest.prototype.languageCode = "";
    
                        /**
                         * UpdateIntentRequest updateMask.
                         * @member {google.protobuf.IFieldMask|null|undefined} updateMask
                         * @memberof google.cloud.dialogflow.v2.UpdateIntentRequest
                         * @instance
                         */
                        UpdateIntentRequest.prototype.updateMask = null;
    
                        /**
                         * UpdateIntentRequest intentView.
                         * @member {google.cloud.dialogflow.v2.IntentView} intentView
                         * @memberof google.cloud.dialogflow.v2.UpdateIntentRequest
                         * @instance
                         */
                        UpdateIntentRequest.prototype.intentView = 0;
    
                        /**
                         * Creates a new UpdateIntentRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.UpdateIntentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IUpdateIntentRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.UpdateIntentRequest} UpdateIntentRequest instance
                         */
                        UpdateIntentRequest.create = function create(properties) {
                            return new UpdateIntentRequest(properties);
                        };
    
                        /**
                         * Encodes the specified UpdateIntentRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.UpdateIntentRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.UpdateIntentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IUpdateIntentRequest} message UpdateIntentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UpdateIntentRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.intent != null && Object.hasOwnProperty.call(message, "intent"))
                                $root.google.cloud.dialogflow.v2.Intent.encode(message.intent, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.languageCode != null && Object.hasOwnProperty.call(message, "languageCode"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.languageCode);
                            if (message.updateMask != null && Object.hasOwnProperty.call(message, "updateMask"))
                                $root.google.protobuf.FieldMask.encode(message.updateMask, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            if (message.intentView != null && Object.hasOwnProperty.call(message, "intentView"))
                                writer.uint32(/* id 4, wireType 0 =*/32).int32(message.intentView);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified UpdateIntentRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.UpdateIntentRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.UpdateIntentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IUpdateIntentRequest} message UpdateIntentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UpdateIntentRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an UpdateIntentRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.UpdateIntentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.UpdateIntentRequest} UpdateIntentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UpdateIntentRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.UpdateIntentRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.intent = $root.google.cloud.dialogflow.v2.Intent.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.languageCode = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.updateMask = $root.google.protobuf.FieldMask.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 4: {
                                        message.intentView = reader.int32();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an UpdateIntentRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.UpdateIntentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.UpdateIntentRequest} UpdateIntentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UpdateIntentRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an UpdateIntentRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.UpdateIntentRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        UpdateIntentRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.intent != null && message.hasOwnProperty("intent")) {
                                var error = $root.google.cloud.dialogflow.v2.Intent.verify(message.intent);
                                if (error)
                                    return "intent." + error;
                            }
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                if (!$util.isString(message.languageCode))
                                    return "languageCode: string expected";
                            if (message.updateMask != null && message.hasOwnProperty("updateMask")) {
                                var error = $root.google.protobuf.FieldMask.verify(message.updateMask);
                                if (error)
                                    return "updateMask." + error;
                            }
                            if (message.intentView != null && message.hasOwnProperty("intentView"))
                                switch (message.intentView) {
                                default:
                                    return "intentView: enum value expected";
                                case 0:
                                case 1:
                                    break;
                                }
                            return null;
                        };
    
                        /**
                         * Creates an UpdateIntentRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.UpdateIntentRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.UpdateIntentRequest} UpdateIntentRequest
                         */
                        UpdateIntentRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.UpdateIntentRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.UpdateIntentRequest();
                            if (object.intent != null) {
                                if (typeof object.intent !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.UpdateIntentRequest.intent: object expected");
                                message.intent = $root.google.cloud.dialogflow.v2.Intent.fromObject(object.intent);
                            }
                            if (object.languageCode != null)
                                message.languageCode = String(object.languageCode);
                            if (object.updateMask != null) {
                                if (typeof object.updateMask !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.UpdateIntentRequest.updateMask: object expected");
                                message.updateMask = $root.google.protobuf.FieldMask.fromObject(object.updateMask);
                            }
                            switch (object.intentView) {
                            default:
                                if (typeof object.intentView === "number") {
                                    message.intentView = object.intentView;
                                    break;
                                }
                                break;
                            case "INTENT_VIEW_UNSPECIFIED":
                            case 0:
                                message.intentView = 0;
                                break;
                            case "INTENT_VIEW_FULL":
                            case 1:
                                message.intentView = 1;
                                break;
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an UpdateIntentRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.UpdateIntentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.UpdateIntentRequest} message UpdateIntentRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        UpdateIntentRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.intent = null;
                                object.languageCode = "";
                                object.updateMask = null;
                                object.intentView = options.enums === String ? "INTENT_VIEW_UNSPECIFIED" : 0;
                            }
                            if (message.intent != null && message.hasOwnProperty("intent"))
                                object.intent = $root.google.cloud.dialogflow.v2.Intent.toObject(message.intent, options);
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                object.languageCode = message.languageCode;
                            if (message.updateMask != null && message.hasOwnProperty("updateMask"))
                                object.updateMask = $root.google.protobuf.FieldMask.toObject(message.updateMask, options);
                            if (message.intentView != null && message.hasOwnProperty("intentView"))
                                object.intentView = options.enums === String ? $root.google.cloud.dialogflow.v2.IntentView[message.intentView] === undefined ? message.intentView : $root.google.cloud.dialogflow.v2.IntentView[message.intentView] : message.intentView;
                            return object;
                        };
    
                        /**
                         * Converts this UpdateIntentRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.UpdateIntentRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        UpdateIntentRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for UpdateIntentRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.UpdateIntentRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        UpdateIntentRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.UpdateIntentRequest";
                        };
    
                        return UpdateIntentRequest;
                    })();
    
                    v2.DeleteIntentRequest = (function() {
    
                        /**
                         * Properties of a DeleteIntentRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IDeleteIntentRequest
                         * @property {string|null} [name] DeleteIntentRequest name
                         */
    
                        /**
                         * Constructs a new DeleteIntentRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a DeleteIntentRequest.
                         * @implements IDeleteIntentRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IDeleteIntentRequest=} [properties] Properties to set
                         */
                        function DeleteIntentRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * DeleteIntentRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2.DeleteIntentRequest
                         * @instance
                         */
                        DeleteIntentRequest.prototype.name = "";
    
                        /**
                         * Creates a new DeleteIntentRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.DeleteIntentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDeleteIntentRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.DeleteIntentRequest} DeleteIntentRequest instance
                         */
                        DeleteIntentRequest.create = function create(properties) {
                            return new DeleteIntentRequest(properties);
                        };
    
                        /**
                         * Encodes the specified DeleteIntentRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.DeleteIntentRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.DeleteIntentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDeleteIntentRequest} message DeleteIntentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteIntentRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified DeleteIntentRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.DeleteIntentRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.DeleteIntentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDeleteIntentRequest} message DeleteIntentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteIntentRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a DeleteIntentRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.DeleteIntentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.DeleteIntentRequest} DeleteIntentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteIntentRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.DeleteIntentRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a DeleteIntentRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.DeleteIntentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.DeleteIntentRequest} DeleteIntentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteIntentRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a DeleteIntentRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.DeleteIntentRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        DeleteIntentRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a DeleteIntentRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.DeleteIntentRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.DeleteIntentRequest} DeleteIntentRequest
                         */
                        DeleteIntentRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.DeleteIntentRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.DeleteIntentRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a DeleteIntentRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.DeleteIntentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.DeleteIntentRequest} message DeleteIntentRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        DeleteIntentRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.name = "";
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            return object;
                        };
    
                        /**
                         * Converts this DeleteIntentRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.DeleteIntentRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        DeleteIntentRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for DeleteIntentRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.DeleteIntentRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        DeleteIntentRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.DeleteIntentRequest";
                        };
    
                        return DeleteIntentRequest;
                    })();
    
                    v2.BatchUpdateIntentsRequest = (function() {
    
                        /**
                         * Properties of a BatchUpdateIntentsRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IBatchUpdateIntentsRequest
                         * @property {string|null} [parent] BatchUpdateIntentsRequest parent
                         * @property {string|null} [intentBatchUri] BatchUpdateIntentsRequest intentBatchUri
                         * @property {google.cloud.dialogflow.v2.IIntentBatch|null} [intentBatchInline] BatchUpdateIntentsRequest intentBatchInline
                         * @property {string|null} [languageCode] BatchUpdateIntentsRequest languageCode
                         * @property {google.protobuf.IFieldMask|null} [updateMask] BatchUpdateIntentsRequest updateMask
                         * @property {google.cloud.dialogflow.v2.IntentView|null} [intentView] BatchUpdateIntentsRequest intentView
                         */
    
                        /**
                         * Constructs a new BatchUpdateIntentsRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a BatchUpdateIntentsRequest.
                         * @implements IBatchUpdateIntentsRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IBatchUpdateIntentsRequest=} [properties] Properties to set
                         */
                        function BatchUpdateIntentsRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * BatchUpdateIntentsRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateIntentsRequest
                         * @instance
                         */
                        BatchUpdateIntentsRequest.prototype.parent = "";
    
                        /**
                         * BatchUpdateIntentsRequest intentBatchUri.
                         * @member {string|null|undefined} intentBatchUri
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateIntentsRequest
                         * @instance
                         */
                        BatchUpdateIntentsRequest.prototype.intentBatchUri = null;
    
                        /**
                         * BatchUpdateIntentsRequest intentBatchInline.
                         * @member {google.cloud.dialogflow.v2.IIntentBatch|null|undefined} intentBatchInline
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateIntentsRequest
                         * @instance
                         */
                        BatchUpdateIntentsRequest.prototype.intentBatchInline = null;
    
                        /**
                         * BatchUpdateIntentsRequest languageCode.
                         * @member {string} languageCode
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateIntentsRequest
                         * @instance
                         */
                        BatchUpdateIntentsRequest.prototype.languageCode = "";
    
                        /**
                         * BatchUpdateIntentsRequest updateMask.
                         * @member {google.protobuf.IFieldMask|null|undefined} updateMask
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateIntentsRequest
                         * @instance
                         */
                        BatchUpdateIntentsRequest.prototype.updateMask = null;
    
                        /**
                         * BatchUpdateIntentsRequest intentView.
                         * @member {google.cloud.dialogflow.v2.IntentView} intentView
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateIntentsRequest
                         * @instance
                         */
                        BatchUpdateIntentsRequest.prototype.intentView = 0;
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * BatchUpdateIntentsRequest intentBatch.
                         * @member {"intentBatchUri"|"intentBatchInline"|undefined} intentBatch
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateIntentsRequest
                         * @instance
                         */
                        Object.defineProperty(BatchUpdateIntentsRequest.prototype, "intentBatch", {
                            get: $util.oneOfGetter($oneOfFields = ["intentBatchUri", "intentBatchInline"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new BatchUpdateIntentsRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateIntentsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IBatchUpdateIntentsRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.BatchUpdateIntentsRequest} BatchUpdateIntentsRequest instance
                         */
                        BatchUpdateIntentsRequest.create = function create(properties) {
                            return new BatchUpdateIntentsRequest(properties);
                        };
    
                        /**
                         * Encodes the specified BatchUpdateIntentsRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.BatchUpdateIntentsRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateIntentsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IBatchUpdateIntentsRequest} message BatchUpdateIntentsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        BatchUpdateIntentsRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.intentBatchUri != null && Object.hasOwnProperty.call(message, "intentBatchUri"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.intentBatchUri);
                            if (message.intentBatchInline != null && Object.hasOwnProperty.call(message, "intentBatchInline"))
                                $root.google.cloud.dialogflow.v2.IntentBatch.encode(message.intentBatchInline, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            if (message.languageCode != null && Object.hasOwnProperty.call(message, "languageCode"))
                                writer.uint32(/* id 4, wireType 2 =*/34).string(message.languageCode);
                            if (message.updateMask != null && Object.hasOwnProperty.call(message, "updateMask"))
                                $root.google.protobuf.FieldMask.encode(message.updateMask, writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                            if (message.intentView != null && Object.hasOwnProperty.call(message, "intentView"))
                                writer.uint32(/* id 6, wireType 0 =*/48).int32(message.intentView);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified BatchUpdateIntentsRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.BatchUpdateIntentsRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateIntentsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IBatchUpdateIntentsRequest} message BatchUpdateIntentsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        BatchUpdateIntentsRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a BatchUpdateIntentsRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateIntentsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.BatchUpdateIntentsRequest} BatchUpdateIntentsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        BatchUpdateIntentsRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.BatchUpdateIntentsRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.intentBatchUri = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.intentBatchInline = $root.google.cloud.dialogflow.v2.IntentBatch.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 4: {
                                        message.languageCode = reader.string();
                                        break;
                                    }
                                case 5: {
                                        message.updateMask = $root.google.protobuf.FieldMask.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 6: {
                                        message.intentView = reader.int32();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a BatchUpdateIntentsRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateIntentsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.BatchUpdateIntentsRequest} BatchUpdateIntentsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        BatchUpdateIntentsRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a BatchUpdateIntentsRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateIntentsRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        BatchUpdateIntentsRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.intentBatchUri != null && message.hasOwnProperty("intentBatchUri")) {
                                properties.intentBatch = 1;
                                if (!$util.isString(message.intentBatchUri))
                                    return "intentBatchUri: string expected";
                            }
                            if (message.intentBatchInline != null && message.hasOwnProperty("intentBatchInline")) {
                                if (properties.intentBatch === 1)
                                    return "intentBatch: multiple values";
                                properties.intentBatch = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2.IntentBatch.verify(message.intentBatchInline);
                                    if (error)
                                        return "intentBatchInline." + error;
                                }
                            }
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                if (!$util.isString(message.languageCode))
                                    return "languageCode: string expected";
                            if (message.updateMask != null && message.hasOwnProperty("updateMask")) {
                                var error = $root.google.protobuf.FieldMask.verify(message.updateMask);
                                if (error)
                                    return "updateMask." + error;
                            }
                            if (message.intentView != null && message.hasOwnProperty("intentView"))
                                switch (message.intentView) {
                                default:
                                    return "intentView: enum value expected";
                                case 0:
                                case 1:
                                    break;
                                }
                            return null;
                        };
    
                        /**
                         * Creates a BatchUpdateIntentsRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateIntentsRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.BatchUpdateIntentsRequest} BatchUpdateIntentsRequest
                         */
                        BatchUpdateIntentsRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.BatchUpdateIntentsRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.BatchUpdateIntentsRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.intentBatchUri != null)
                                message.intentBatchUri = String(object.intentBatchUri);
                            if (object.intentBatchInline != null) {
                                if (typeof object.intentBatchInline !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.BatchUpdateIntentsRequest.intentBatchInline: object expected");
                                message.intentBatchInline = $root.google.cloud.dialogflow.v2.IntentBatch.fromObject(object.intentBatchInline);
                            }
                            if (object.languageCode != null)
                                message.languageCode = String(object.languageCode);
                            if (object.updateMask != null) {
                                if (typeof object.updateMask !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.BatchUpdateIntentsRequest.updateMask: object expected");
                                message.updateMask = $root.google.protobuf.FieldMask.fromObject(object.updateMask);
                            }
                            switch (object.intentView) {
                            default:
                                if (typeof object.intentView === "number") {
                                    message.intentView = object.intentView;
                                    break;
                                }
                                break;
                            case "INTENT_VIEW_UNSPECIFIED":
                            case 0:
                                message.intentView = 0;
                                break;
                            case "INTENT_VIEW_FULL":
                            case 1:
                                message.intentView = 1;
                                break;
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a BatchUpdateIntentsRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateIntentsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.BatchUpdateIntentsRequest} message BatchUpdateIntentsRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        BatchUpdateIntentsRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.languageCode = "";
                                object.updateMask = null;
                                object.intentView = options.enums === String ? "INTENT_VIEW_UNSPECIFIED" : 0;
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.intentBatchUri != null && message.hasOwnProperty("intentBatchUri")) {
                                object.intentBatchUri = message.intentBatchUri;
                                if (options.oneofs)
                                    object.intentBatch = "intentBatchUri";
                            }
                            if (message.intentBatchInline != null && message.hasOwnProperty("intentBatchInline")) {
                                object.intentBatchInline = $root.google.cloud.dialogflow.v2.IntentBatch.toObject(message.intentBatchInline, options);
                                if (options.oneofs)
                                    object.intentBatch = "intentBatchInline";
                            }
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                object.languageCode = message.languageCode;
                            if (message.updateMask != null && message.hasOwnProperty("updateMask"))
                                object.updateMask = $root.google.protobuf.FieldMask.toObject(message.updateMask, options);
                            if (message.intentView != null && message.hasOwnProperty("intentView"))
                                object.intentView = options.enums === String ? $root.google.cloud.dialogflow.v2.IntentView[message.intentView] === undefined ? message.intentView : $root.google.cloud.dialogflow.v2.IntentView[message.intentView] : message.intentView;
                            return object;
                        };
    
                        /**
                         * Converts this BatchUpdateIntentsRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateIntentsRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        BatchUpdateIntentsRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for BatchUpdateIntentsRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateIntentsRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        BatchUpdateIntentsRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.BatchUpdateIntentsRequest";
                        };
    
                        return BatchUpdateIntentsRequest;
                    })();
    
                    v2.BatchUpdateIntentsResponse = (function() {
    
                        /**
                         * Properties of a BatchUpdateIntentsResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IBatchUpdateIntentsResponse
                         * @property {Array.<google.cloud.dialogflow.v2.IIntent>|null} [intents] BatchUpdateIntentsResponse intents
                         */
    
                        /**
                         * Constructs a new BatchUpdateIntentsResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a BatchUpdateIntentsResponse.
                         * @implements IBatchUpdateIntentsResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IBatchUpdateIntentsResponse=} [properties] Properties to set
                         */
                        function BatchUpdateIntentsResponse(properties) {
                            this.intents = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * BatchUpdateIntentsResponse intents.
                         * @member {Array.<google.cloud.dialogflow.v2.IIntent>} intents
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateIntentsResponse
                         * @instance
                         */
                        BatchUpdateIntentsResponse.prototype.intents = $util.emptyArray;
    
                        /**
                         * Creates a new BatchUpdateIntentsResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateIntentsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IBatchUpdateIntentsResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.BatchUpdateIntentsResponse} BatchUpdateIntentsResponse instance
                         */
                        BatchUpdateIntentsResponse.create = function create(properties) {
                            return new BatchUpdateIntentsResponse(properties);
                        };
    
                        /**
                         * Encodes the specified BatchUpdateIntentsResponse message. Does not implicitly {@link google.cloud.dialogflow.v2.BatchUpdateIntentsResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateIntentsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IBatchUpdateIntentsResponse} message BatchUpdateIntentsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        BatchUpdateIntentsResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.intents != null && message.intents.length)
                                for (var i = 0; i < message.intents.length; ++i)
                                    $root.google.cloud.dialogflow.v2.Intent.encode(message.intents[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified BatchUpdateIntentsResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.BatchUpdateIntentsResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateIntentsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IBatchUpdateIntentsResponse} message BatchUpdateIntentsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        BatchUpdateIntentsResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a BatchUpdateIntentsResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateIntentsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.BatchUpdateIntentsResponse} BatchUpdateIntentsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        BatchUpdateIntentsResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.BatchUpdateIntentsResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.intents && message.intents.length))
                                            message.intents = [];
                                        message.intents.push($root.google.cloud.dialogflow.v2.Intent.decode(reader, reader.uint32()));
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a BatchUpdateIntentsResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateIntentsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.BatchUpdateIntentsResponse} BatchUpdateIntentsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        BatchUpdateIntentsResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a BatchUpdateIntentsResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateIntentsResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        BatchUpdateIntentsResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.intents != null && message.hasOwnProperty("intents")) {
                                if (!Array.isArray(message.intents))
                                    return "intents: array expected";
                                for (var i = 0; i < message.intents.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.Intent.verify(message.intents[i]);
                                    if (error)
                                        return "intents." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates a BatchUpdateIntentsResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateIntentsResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.BatchUpdateIntentsResponse} BatchUpdateIntentsResponse
                         */
                        BatchUpdateIntentsResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.BatchUpdateIntentsResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.BatchUpdateIntentsResponse();
                            if (object.intents) {
                                if (!Array.isArray(object.intents))
                                    throw TypeError(".google.cloud.dialogflow.v2.BatchUpdateIntentsResponse.intents: array expected");
                                message.intents = [];
                                for (var i = 0; i < object.intents.length; ++i) {
                                    if (typeof object.intents[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.BatchUpdateIntentsResponse.intents: object expected");
                                    message.intents[i] = $root.google.cloud.dialogflow.v2.Intent.fromObject(object.intents[i]);
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a BatchUpdateIntentsResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateIntentsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.BatchUpdateIntentsResponse} message BatchUpdateIntentsResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        BatchUpdateIntentsResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.intents = [];
                            if (message.intents && message.intents.length) {
                                object.intents = [];
                                for (var j = 0; j < message.intents.length; ++j)
                                    object.intents[j] = $root.google.cloud.dialogflow.v2.Intent.toObject(message.intents[j], options);
                            }
                            return object;
                        };
    
                        /**
                         * Converts this BatchUpdateIntentsResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateIntentsResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        BatchUpdateIntentsResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for BatchUpdateIntentsResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateIntentsResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        BatchUpdateIntentsResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.BatchUpdateIntentsResponse";
                        };
    
                        return BatchUpdateIntentsResponse;
                    })();
    
                    v2.BatchDeleteIntentsRequest = (function() {
    
                        /**
                         * Properties of a BatchDeleteIntentsRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IBatchDeleteIntentsRequest
                         * @property {string|null} [parent] BatchDeleteIntentsRequest parent
                         * @property {Array.<google.cloud.dialogflow.v2.IIntent>|null} [intents] BatchDeleteIntentsRequest intents
                         */
    
                        /**
                         * Constructs a new BatchDeleteIntentsRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a BatchDeleteIntentsRequest.
                         * @implements IBatchDeleteIntentsRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IBatchDeleteIntentsRequest=} [properties] Properties to set
                         */
                        function BatchDeleteIntentsRequest(properties) {
                            this.intents = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * BatchDeleteIntentsRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.BatchDeleteIntentsRequest
                         * @instance
                         */
                        BatchDeleteIntentsRequest.prototype.parent = "";
    
                        /**
                         * BatchDeleteIntentsRequest intents.
                         * @member {Array.<google.cloud.dialogflow.v2.IIntent>} intents
                         * @memberof google.cloud.dialogflow.v2.BatchDeleteIntentsRequest
                         * @instance
                         */
                        BatchDeleteIntentsRequest.prototype.intents = $util.emptyArray;
    
                        /**
                         * Creates a new BatchDeleteIntentsRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.BatchDeleteIntentsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IBatchDeleteIntentsRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.BatchDeleteIntentsRequest} BatchDeleteIntentsRequest instance
                         */
                        BatchDeleteIntentsRequest.create = function create(properties) {
                            return new BatchDeleteIntentsRequest(properties);
                        };
    
                        /**
                         * Encodes the specified BatchDeleteIntentsRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.BatchDeleteIntentsRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.BatchDeleteIntentsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IBatchDeleteIntentsRequest} message BatchDeleteIntentsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        BatchDeleteIntentsRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.intents != null && message.intents.length)
                                for (var i = 0; i < message.intents.length; ++i)
                                    $root.google.cloud.dialogflow.v2.Intent.encode(message.intents[i], writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified BatchDeleteIntentsRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.BatchDeleteIntentsRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.BatchDeleteIntentsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IBatchDeleteIntentsRequest} message BatchDeleteIntentsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        BatchDeleteIntentsRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a BatchDeleteIntentsRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.BatchDeleteIntentsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.BatchDeleteIntentsRequest} BatchDeleteIntentsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        BatchDeleteIntentsRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.BatchDeleteIntentsRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        if (!(message.intents && message.intents.length))
                                            message.intents = [];
                                        message.intents.push($root.google.cloud.dialogflow.v2.Intent.decode(reader, reader.uint32()));
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a BatchDeleteIntentsRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.BatchDeleteIntentsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.BatchDeleteIntentsRequest} BatchDeleteIntentsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        BatchDeleteIntentsRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a BatchDeleteIntentsRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.BatchDeleteIntentsRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        BatchDeleteIntentsRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.intents != null && message.hasOwnProperty("intents")) {
                                if (!Array.isArray(message.intents))
                                    return "intents: array expected";
                                for (var i = 0; i < message.intents.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.Intent.verify(message.intents[i]);
                                    if (error)
                                        return "intents." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates a BatchDeleteIntentsRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.BatchDeleteIntentsRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.BatchDeleteIntentsRequest} BatchDeleteIntentsRequest
                         */
                        BatchDeleteIntentsRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.BatchDeleteIntentsRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.BatchDeleteIntentsRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.intents) {
                                if (!Array.isArray(object.intents))
                                    throw TypeError(".google.cloud.dialogflow.v2.BatchDeleteIntentsRequest.intents: array expected");
                                message.intents = [];
                                for (var i = 0; i < object.intents.length; ++i) {
                                    if (typeof object.intents[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.BatchDeleteIntentsRequest.intents: object expected");
                                    message.intents[i] = $root.google.cloud.dialogflow.v2.Intent.fromObject(object.intents[i]);
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a BatchDeleteIntentsRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.BatchDeleteIntentsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.BatchDeleteIntentsRequest} message BatchDeleteIntentsRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        BatchDeleteIntentsRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.intents = [];
                            if (options.defaults)
                                object.parent = "";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.intents && message.intents.length) {
                                object.intents = [];
                                for (var j = 0; j < message.intents.length; ++j)
                                    object.intents[j] = $root.google.cloud.dialogflow.v2.Intent.toObject(message.intents[j], options);
                            }
                            return object;
                        };
    
                        /**
                         * Converts this BatchDeleteIntentsRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.BatchDeleteIntentsRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        BatchDeleteIntentsRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for BatchDeleteIntentsRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.BatchDeleteIntentsRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        BatchDeleteIntentsRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.BatchDeleteIntentsRequest";
                        };
    
                        return BatchDeleteIntentsRequest;
                    })();
    
                    /**
                     * IntentView enum.
                     * @name google.cloud.dialogflow.v2.IntentView
                     * @enum {number}
                     * @property {number} INTENT_VIEW_UNSPECIFIED=0 INTENT_VIEW_UNSPECIFIED value
                     * @property {number} INTENT_VIEW_FULL=1 INTENT_VIEW_FULL value
                     */
                    v2.IntentView = (function() {
                        var valuesById = {}, values = Object.create(valuesById);
                        values[valuesById[0] = "INTENT_VIEW_UNSPECIFIED"] = 0;
                        values[valuesById[1] = "INTENT_VIEW_FULL"] = 1;
                        return values;
                    })();
    
                    v2.IntentBatch = (function() {
    
                        /**
                         * Properties of an IntentBatch.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IIntentBatch
                         * @property {Array.<google.cloud.dialogflow.v2.IIntent>|null} [intents] IntentBatch intents
                         */
    
                        /**
                         * Constructs a new IntentBatch.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an IntentBatch.
                         * @implements IIntentBatch
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IIntentBatch=} [properties] Properties to set
                         */
                        function IntentBatch(properties) {
                            this.intents = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * IntentBatch intents.
                         * @member {Array.<google.cloud.dialogflow.v2.IIntent>} intents
                         * @memberof google.cloud.dialogflow.v2.IntentBatch
                         * @instance
                         */
                        IntentBatch.prototype.intents = $util.emptyArray;
    
                        /**
                         * Creates a new IntentBatch instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.IntentBatch
                         * @static
                         * @param {google.cloud.dialogflow.v2.IIntentBatch=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.IntentBatch} IntentBatch instance
                         */
                        IntentBatch.create = function create(properties) {
                            return new IntentBatch(properties);
                        };
    
                        /**
                         * Encodes the specified IntentBatch message. Does not implicitly {@link google.cloud.dialogflow.v2.IntentBatch.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.IntentBatch
                         * @static
                         * @param {google.cloud.dialogflow.v2.IIntentBatch} message IntentBatch message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        IntentBatch.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.intents != null && message.intents.length)
                                for (var i = 0; i < message.intents.length; ++i)
                                    $root.google.cloud.dialogflow.v2.Intent.encode(message.intents[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified IntentBatch message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.IntentBatch.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.IntentBatch
                         * @static
                         * @param {google.cloud.dialogflow.v2.IIntentBatch} message IntentBatch message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        IntentBatch.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an IntentBatch message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.IntentBatch
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.IntentBatch} IntentBatch
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        IntentBatch.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.IntentBatch();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.intents && message.intents.length))
                                            message.intents = [];
                                        message.intents.push($root.google.cloud.dialogflow.v2.Intent.decode(reader, reader.uint32()));
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an IntentBatch message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.IntentBatch
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.IntentBatch} IntentBatch
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        IntentBatch.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an IntentBatch message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.IntentBatch
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        IntentBatch.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.intents != null && message.hasOwnProperty("intents")) {
                                if (!Array.isArray(message.intents))
                                    return "intents: array expected";
                                for (var i = 0; i < message.intents.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.Intent.verify(message.intents[i]);
                                    if (error)
                                        return "intents." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates an IntentBatch message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.IntentBatch
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.IntentBatch} IntentBatch
                         */
                        IntentBatch.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.IntentBatch)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.IntentBatch();
                            if (object.intents) {
                                if (!Array.isArray(object.intents))
                                    throw TypeError(".google.cloud.dialogflow.v2.IntentBatch.intents: array expected");
                                message.intents = [];
                                for (var i = 0; i < object.intents.length; ++i) {
                                    if (typeof object.intents[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.IntentBatch.intents: object expected");
                                    message.intents[i] = $root.google.cloud.dialogflow.v2.Intent.fromObject(object.intents[i]);
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an IntentBatch message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.IntentBatch
                         * @static
                         * @param {google.cloud.dialogflow.v2.IntentBatch} message IntentBatch
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        IntentBatch.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.intents = [];
                            if (message.intents && message.intents.length) {
                                object.intents = [];
                                for (var j = 0; j < message.intents.length; ++j)
                                    object.intents[j] = $root.google.cloud.dialogflow.v2.Intent.toObject(message.intents[j], options);
                            }
                            return object;
                        };
    
                        /**
                         * Converts this IntentBatch to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.IntentBatch
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        IntentBatch.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for IntentBatch
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.IntentBatch
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        IntentBatch.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.IntentBatch";
                        };
    
                        return IntentBatch;
                    })();
    
                    v2.SessionEntityTypes = (function() {
    
                        /**
                         * Constructs a new SessionEntityTypes service.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a SessionEntityTypes
                         * @extends $protobuf.rpc.Service
                         * @constructor
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         */
                        function SessionEntityTypes(rpcImpl, requestDelimited, responseDelimited) {
                            $protobuf.rpc.Service.call(this, rpcImpl, requestDelimited, responseDelimited);
                        }
    
                        (SessionEntityTypes.prototype = Object.create($protobuf.rpc.Service.prototype)).constructor = SessionEntityTypes;
    
                        /**
                         * Creates new SessionEntityTypes service using the specified rpc implementation.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.SessionEntityTypes
                         * @static
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         * @returns {SessionEntityTypes} RPC service. Useful where requests and/or responses are streamed.
                         */
                        SessionEntityTypes.create = function create(rpcImpl, requestDelimited, responseDelimited) {
                            return new this(rpcImpl, requestDelimited, responseDelimited);
                        };
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.SessionEntityTypes|listSessionEntityTypes}.
                         * @memberof google.cloud.dialogflow.v2.SessionEntityTypes
                         * @typedef ListSessionEntityTypesCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.ListSessionEntityTypesResponse} [response] ListSessionEntityTypesResponse
                         */
    
                        /**
                         * Calls ListSessionEntityTypes.
                         * @function listSessionEntityTypes
                         * @memberof google.cloud.dialogflow.v2.SessionEntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IListSessionEntityTypesRequest} request ListSessionEntityTypesRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.SessionEntityTypes.ListSessionEntityTypesCallback} callback Node-style callback called with the error, if any, and ListSessionEntityTypesResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(SessionEntityTypes.prototype.listSessionEntityTypes = function listSessionEntityTypes(request, callback) {
                            return this.rpcCall(listSessionEntityTypes, $root.google.cloud.dialogflow.v2.ListSessionEntityTypesRequest, $root.google.cloud.dialogflow.v2.ListSessionEntityTypesResponse, request, callback);
                        }, "name", { value: "ListSessionEntityTypes" });
    
                        /**
                         * Calls ListSessionEntityTypes.
                         * @function listSessionEntityTypes
                         * @memberof google.cloud.dialogflow.v2.SessionEntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IListSessionEntityTypesRequest} request ListSessionEntityTypesRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.ListSessionEntityTypesResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.SessionEntityTypes|getSessionEntityType}.
                         * @memberof google.cloud.dialogflow.v2.SessionEntityTypes
                         * @typedef GetSessionEntityTypeCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.SessionEntityType} [response] SessionEntityType
                         */
    
                        /**
                         * Calls GetSessionEntityType.
                         * @function getSessionEntityType
                         * @memberof google.cloud.dialogflow.v2.SessionEntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IGetSessionEntityTypeRequest} request GetSessionEntityTypeRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.SessionEntityTypes.GetSessionEntityTypeCallback} callback Node-style callback called with the error, if any, and SessionEntityType
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(SessionEntityTypes.prototype.getSessionEntityType = function getSessionEntityType(request, callback) {
                            return this.rpcCall(getSessionEntityType, $root.google.cloud.dialogflow.v2.GetSessionEntityTypeRequest, $root.google.cloud.dialogflow.v2.SessionEntityType, request, callback);
                        }, "name", { value: "GetSessionEntityType" });
    
                        /**
                         * Calls GetSessionEntityType.
                         * @function getSessionEntityType
                         * @memberof google.cloud.dialogflow.v2.SessionEntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IGetSessionEntityTypeRequest} request GetSessionEntityTypeRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.SessionEntityType>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.SessionEntityTypes|createSessionEntityType}.
                         * @memberof google.cloud.dialogflow.v2.SessionEntityTypes
                         * @typedef CreateSessionEntityTypeCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.SessionEntityType} [response] SessionEntityType
                         */
    
                        /**
                         * Calls CreateSessionEntityType.
                         * @function createSessionEntityType
                         * @memberof google.cloud.dialogflow.v2.SessionEntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2.ICreateSessionEntityTypeRequest} request CreateSessionEntityTypeRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.SessionEntityTypes.CreateSessionEntityTypeCallback} callback Node-style callback called with the error, if any, and SessionEntityType
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(SessionEntityTypes.prototype.createSessionEntityType = function createSessionEntityType(request, callback) {
                            return this.rpcCall(createSessionEntityType, $root.google.cloud.dialogflow.v2.CreateSessionEntityTypeRequest, $root.google.cloud.dialogflow.v2.SessionEntityType, request, callback);
                        }, "name", { value: "CreateSessionEntityType" });
    
                        /**
                         * Calls CreateSessionEntityType.
                         * @function createSessionEntityType
                         * @memberof google.cloud.dialogflow.v2.SessionEntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2.ICreateSessionEntityTypeRequest} request CreateSessionEntityTypeRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.SessionEntityType>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.SessionEntityTypes|updateSessionEntityType}.
                         * @memberof google.cloud.dialogflow.v2.SessionEntityTypes
                         * @typedef UpdateSessionEntityTypeCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.SessionEntityType} [response] SessionEntityType
                         */
    
                        /**
                         * Calls UpdateSessionEntityType.
                         * @function updateSessionEntityType
                         * @memberof google.cloud.dialogflow.v2.SessionEntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IUpdateSessionEntityTypeRequest} request UpdateSessionEntityTypeRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.SessionEntityTypes.UpdateSessionEntityTypeCallback} callback Node-style callback called with the error, if any, and SessionEntityType
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(SessionEntityTypes.prototype.updateSessionEntityType = function updateSessionEntityType(request, callback) {
                            return this.rpcCall(updateSessionEntityType, $root.google.cloud.dialogflow.v2.UpdateSessionEntityTypeRequest, $root.google.cloud.dialogflow.v2.SessionEntityType, request, callback);
                        }, "name", { value: "UpdateSessionEntityType" });
    
                        /**
                         * Calls UpdateSessionEntityType.
                         * @function updateSessionEntityType
                         * @memberof google.cloud.dialogflow.v2.SessionEntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IUpdateSessionEntityTypeRequest} request UpdateSessionEntityTypeRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.SessionEntityType>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.SessionEntityTypes|deleteSessionEntityType}.
                         * @memberof google.cloud.dialogflow.v2.SessionEntityTypes
                         * @typedef DeleteSessionEntityTypeCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.protobuf.Empty} [response] Empty
                         */
    
                        /**
                         * Calls DeleteSessionEntityType.
                         * @function deleteSessionEntityType
                         * @memberof google.cloud.dialogflow.v2.SessionEntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IDeleteSessionEntityTypeRequest} request DeleteSessionEntityTypeRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.SessionEntityTypes.DeleteSessionEntityTypeCallback} callback Node-style callback called with the error, if any, and Empty
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(SessionEntityTypes.prototype.deleteSessionEntityType = function deleteSessionEntityType(request, callback) {
                            return this.rpcCall(deleteSessionEntityType, $root.google.cloud.dialogflow.v2.DeleteSessionEntityTypeRequest, $root.google.protobuf.Empty, request, callback);
                        }, "name", { value: "DeleteSessionEntityType" });
    
                        /**
                         * Calls DeleteSessionEntityType.
                         * @function deleteSessionEntityType
                         * @memberof google.cloud.dialogflow.v2.SessionEntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IDeleteSessionEntityTypeRequest} request DeleteSessionEntityTypeRequest message or plain object
                         * @returns {Promise<google.protobuf.Empty>} Promise
                         * @variation 2
                         */
    
                        return SessionEntityTypes;
                    })();
    
                    v2.SessionEntityType = (function() {
    
                        /**
                         * Properties of a SessionEntityType.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ISessionEntityType
                         * @property {string|null} [name] SessionEntityType name
                         * @property {google.cloud.dialogflow.v2.SessionEntityType.EntityOverrideMode|null} [entityOverrideMode] SessionEntityType entityOverrideMode
                         * @property {Array.<google.cloud.dialogflow.v2.EntityType.IEntity>|null} [entities] SessionEntityType entities
                         */
    
                        /**
                         * Constructs a new SessionEntityType.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a SessionEntityType.
                         * @implements ISessionEntityType
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ISessionEntityType=} [properties] Properties to set
                         */
                        function SessionEntityType(properties) {
                            this.entities = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SessionEntityType name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2.SessionEntityType
                         * @instance
                         */
                        SessionEntityType.prototype.name = "";
    
                        /**
                         * SessionEntityType entityOverrideMode.
                         * @member {google.cloud.dialogflow.v2.SessionEntityType.EntityOverrideMode} entityOverrideMode
                         * @memberof google.cloud.dialogflow.v2.SessionEntityType
                         * @instance
                         */
                        SessionEntityType.prototype.entityOverrideMode = 0;
    
                        /**
                         * SessionEntityType entities.
                         * @member {Array.<google.cloud.dialogflow.v2.EntityType.IEntity>} entities
                         * @memberof google.cloud.dialogflow.v2.SessionEntityType
                         * @instance
                         */
                        SessionEntityType.prototype.entities = $util.emptyArray;
    
                        /**
                         * Creates a new SessionEntityType instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.SessionEntityType
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISessionEntityType=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.SessionEntityType} SessionEntityType instance
                         */
                        SessionEntityType.create = function create(properties) {
                            return new SessionEntityType(properties);
                        };
    
                        /**
                         * Encodes the specified SessionEntityType message. Does not implicitly {@link google.cloud.dialogflow.v2.SessionEntityType.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.SessionEntityType
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISessionEntityType} message SessionEntityType message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SessionEntityType.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            if (message.entityOverrideMode != null && Object.hasOwnProperty.call(message, "entityOverrideMode"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.entityOverrideMode);
                            if (message.entities != null && message.entities.length)
                                for (var i = 0; i < message.entities.length; ++i)
                                    $root.google.cloud.dialogflow.v2.EntityType.Entity.encode(message.entities[i], writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SessionEntityType message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.SessionEntityType.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SessionEntityType
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISessionEntityType} message SessionEntityType message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SessionEntityType.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SessionEntityType message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.SessionEntityType
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.SessionEntityType} SessionEntityType
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SessionEntityType.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.SessionEntityType();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.entityOverrideMode = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        if (!(message.entities && message.entities.length))
                                            message.entities = [];
                                        message.entities.push($root.google.cloud.dialogflow.v2.EntityType.Entity.decode(reader, reader.uint32()));
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SessionEntityType message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SessionEntityType
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.SessionEntityType} SessionEntityType
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SessionEntityType.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SessionEntityType message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.SessionEntityType
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SessionEntityType.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            if (message.entityOverrideMode != null && message.hasOwnProperty("entityOverrideMode"))
                                switch (message.entityOverrideMode) {
                                default:
                                    return "entityOverrideMode: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                    break;
                                }
                            if (message.entities != null && message.hasOwnProperty("entities")) {
                                if (!Array.isArray(message.entities))
                                    return "entities: array expected";
                                for (var i = 0; i < message.entities.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.EntityType.Entity.verify(message.entities[i]);
                                    if (error)
                                        return "entities." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates a SessionEntityType message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.SessionEntityType
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.SessionEntityType} SessionEntityType
                         */
                        SessionEntityType.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.SessionEntityType)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.SessionEntityType();
                            if (object.name != null)
                                message.name = String(object.name);
                            switch (object.entityOverrideMode) {
                            default:
                                if (typeof object.entityOverrideMode === "number") {
                                    message.entityOverrideMode = object.entityOverrideMode;
                                    break;
                                }
                                break;
                            case "ENTITY_OVERRIDE_MODE_UNSPECIFIED":
                            case 0:
                                message.entityOverrideMode = 0;
                                break;
                            case "ENTITY_OVERRIDE_MODE_OVERRIDE":
                            case 1:
                                message.entityOverrideMode = 1;
                                break;
                            case "ENTITY_OVERRIDE_MODE_SUPPLEMENT":
                            case 2:
                                message.entityOverrideMode = 2;
                                break;
                            }
                            if (object.entities) {
                                if (!Array.isArray(object.entities))
                                    throw TypeError(".google.cloud.dialogflow.v2.SessionEntityType.entities: array expected");
                                message.entities = [];
                                for (var i = 0; i < object.entities.length; ++i) {
                                    if (typeof object.entities[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.SessionEntityType.entities: object expected");
                                    message.entities[i] = $root.google.cloud.dialogflow.v2.EntityType.Entity.fromObject(object.entities[i]);
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SessionEntityType message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.SessionEntityType
                         * @static
                         * @param {google.cloud.dialogflow.v2.SessionEntityType} message SessionEntityType
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SessionEntityType.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.entities = [];
                            if (options.defaults) {
                                object.name = "";
                                object.entityOverrideMode = options.enums === String ? "ENTITY_OVERRIDE_MODE_UNSPECIFIED" : 0;
                            }
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            if (message.entityOverrideMode != null && message.hasOwnProperty("entityOverrideMode"))
                                object.entityOverrideMode = options.enums === String ? $root.google.cloud.dialogflow.v2.SessionEntityType.EntityOverrideMode[message.entityOverrideMode] === undefined ? message.entityOverrideMode : $root.google.cloud.dialogflow.v2.SessionEntityType.EntityOverrideMode[message.entityOverrideMode] : message.entityOverrideMode;
                            if (message.entities && message.entities.length) {
                                object.entities = [];
                                for (var j = 0; j < message.entities.length; ++j)
                                    object.entities[j] = $root.google.cloud.dialogflow.v2.EntityType.Entity.toObject(message.entities[j], options);
                            }
                            return object;
                        };
    
                        /**
                         * Converts this SessionEntityType to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.SessionEntityType
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SessionEntityType.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SessionEntityType
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.SessionEntityType
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SessionEntityType.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.SessionEntityType";
                        };
    
                        /**
                         * EntityOverrideMode enum.
                         * @name google.cloud.dialogflow.v2.SessionEntityType.EntityOverrideMode
                         * @enum {number}
                         * @property {number} ENTITY_OVERRIDE_MODE_UNSPECIFIED=0 ENTITY_OVERRIDE_MODE_UNSPECIFIED value
                         * @property {number} ENTITY_OVERRIDE_MODE_OVERRIDE=1 ENTITY_OVERRIDE_MODE_OVERRIDE value
                         * @property {number} ENTITY_OVERRIDE_MODE_SUPPLEMENT=2 ENTITY_OVERRIDE_MODE_SUPPLEMENT value
                         */
                        SessionEntityType.EntityOverrideMode = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "ENTITY_OVERRIDE_MODE_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "ENTITY_OVERRIDE_MODE_OVERRIDE"] = 1;
                            values[valuesById[2] = "ENTITY_OVERRIDE_MODE_SUPPLEMENT"] = 2;
                            return values;
                        })();
    
                        return SessionEntityType;
                    })();
    
                    v2.ListSessionEntityTypesRequest = (function() {
    
                        /**
                         * Properties of a ListSessionEntityTypesRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IListSessionEntityTypesRequest
                         * @property {string|null} [parent] ListSessionEntityTypesRequest parent
                         * @property {number|null} [pageSize] ListSessionEntityTypesRequest pageSize
                         * @property {string|null} [pageToken] ListSessionEntityTypesRequest pageToken
                         */
    
                        /**
                         * Constructs a new ListSessionEntityTypesRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a ListSessionEntityTypesRequest.
                         * @implements IListSessionEntityTypesRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IListSessionEntityTypesRequest=} [properties] Properties to set
                         */
                        function ListSessionEntityTypesRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListSessionEntityTypesRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.ListSessionEntityTypesRequest
                         * @instance
                         */
                        ListSessionEntityTypesRequest.prototype.parent = "";
    
                        /**
                         * ListSessionEntityTypesRequest pageSize.
                         * @member {number} pageSize
                         * @memberof google.cloud.dialogflow.v2.ListSessionEntityTypesRequest
                         * @instance
                         */
                        ListSessionEntityTypesRequest.prototype.pageSize = 0;
    
                        /**
                         * ListSessionEntityTypesRequest pageToken.
                         * @member {string} pageToken
                         * @memberof google.cloud.dialogflow.v2.ListSessionEntityTypesRequest
                         * @instance
                         */
                        ListSessionEntityTypesRequest.prototype.pageToken = "";
    
                        /**
                         * Creates a new ListSessionEntityTypesRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ListSessionEntityTypesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListSessionEntityTypesRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ListSessionEntityTypesRequest} ListSessionEntityTypesRequest instance
                         */
                        ListSessionEntityTypesRequest.create = function create(properties) {
                            return new ListSessionEntityTypesRequest(properties);
                        };
    
                        /**
                         * Encodes the specified ListSessionEntityTypesRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.ListSessionEntityTypesRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ListSessionEntityTypesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListSessionEntityTypesRequest} message ListSessionEntityTypesRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListSessionEntityTypesRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.pageSize != null && Object.hasOwnProperty.call(message, "pageSize"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.pageSize);
                            if (message.pageToken != null && Object.hasOwnProperty.call(message, "pageToken"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.pageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListSessionEntityTypesRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ListSessionEntityTypesRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListSessionEntityTypesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListSessionEntityTypesRequest} message ListSessionEntityTypesRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListSessionEntityTypesRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListSessionEntityTypesRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ListSessionEntityTypesRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ListSessionEntityTypesRequest} ListSessionEntityTypesRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListSessionEntityTypesRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ListSessionEntityTypesRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.pageSize = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.pageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListSessionEntityTypesRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListSessionEntityTypesRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ListSessionEntityTypesRequest} ListSessionEntityTypesRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListSessionEntityTypesRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListSessionEntityTypesRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ListSessionEntityTypesRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListSessionEntityTypesRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                if (!$util.isInteger(message.pageSize))
                                    return "pageSize: integer expected";
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                if (!$util.isString(message.pageToken))
                                    return "pageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListSessionEntityTypesRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ListSessionEntityTypesRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ListSessionEntityTypesRequest} ListSessionEntityTypesRequest
                         */
                        ListSessionEntityTypesRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ListSessionEntityTypesRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ListSessionEntityTypesRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.pageSize != null)
                                message.pageSize = object.pageSize | 0;
                            if (object.pageToken != null)
                                message.pageToken = String(object.pageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListSessionEntityTypesRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ListSessionEntityTypesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ListSessionEntityTypesRequest} message ListSessionEntityTypesRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListSessionEntityTypesRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.pageSize = 0;
                                object.pageToken = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                object.pageSize = message.pageSize;
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                object.pageToken = message.pageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListSessionEntityTypesRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ListSessionEntityTypesRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListSessionEntityTypesRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListSessionEntityTypesRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ListSessionEntityTypesRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListSessionEntityTypesRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ListSessionEntityTypesRequest";
                        };
    
                        return ListSessionEntityTypesRequest;
                    })();
    
                    v2.ListSessionEntityTypesResponse = (function() {
    
                        /**
                         * Properties of a ListSessionEntityTypesResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IListSessionEntityTypesResponse
                         * @property {Array.<google.cloud.dialogflow.v2.ISessionEntityType>|null} [sessionEntityTypes] ListSessionEntityTypesResponse sessionEntityTypes
                         * @property {string|null} [nextPageToken] ListSessionEntityTypesResponse nextPageToken
                         */
    
                        /**
                         * Constructs a new ListSessionEntityTypesResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a ListSessionEntityTypesResponse.
                         * @implements IListSessionEntityTypesResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IListSessionEntityTypesResponse=} [properties] Properties to set
                         */
                        function ListSessionEntityTypesResponse(properties) {
                            this.sessionEntityTypes = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListSessionEntityTypesResponse sessionEntityTypes.
                         * @member {Array.<google.cloud.dialogflow.v2.ISessionEntityType>} sessionEntityTypes
                         * @memberof google.cloud.dialogflow.v2.ListSessionEntityTypesResponse
                         * @instance
                         */
                        ListSessionEntityTypesResponse.prototype.sessionEntityTypes = $util.emptyArray;
    
                        /**
                         * ListSessionEntityTypesResponse nextPageToken.
                         * @member {string} nextPageToken
                         * @memberof google.cloud.dialogflow.v2.ListSessionEntityTypesResponse
                         * @instance
                         */
                        ListSessionEntityTypesResponse.prototype.nextPageToken = "";
    
                        /**
                         * Creates a new ListSessionEntityTypesResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ListSessionEntityTypesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListSessionEntityTypesResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ListSessionEntityTypesResponse} ListSessionEntityTypesResponse instance
                         */
                        ListSessionEntityTypesResponse.create = function create(properties) {
                            return new ListSessionEntityTypesResponse(properties);
                        };
    
                        /**
                         * Encodes the specified ListSessionEntityTypesResponse message. Does not implicitly {@link google.cloud.dialogflow.v2.ListSessionEntityTypesResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ListSessionEntityTypesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListSessionEntityTypesResponse} message ListSessionEntityTypesResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListSessionEntityTypesResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.sessionEntityTypes != null && message.sessionEntityTypes.length)
                                for (var i = 0; i < message.sessionEntityTypes.length; ++i)
                                    $root.google.cloud.dialogflow.v2.SessionEntityType.encode(message.sessionEntityTypes[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.nextPageToken != null && Object.hasOwnProperty.call(message, "nextPageToken"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.nextPageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListSessionEntityTypesResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ListSessionEntityTypesResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListSessionEntityTypesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListSessionEntityTypesResponse} message ListSessionEntityTypesResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListSessionEntityTypesResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListSessionEntityTypesResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ListSessionEntityTypesResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ListSessionEntityTypesResponse} ListSessionEntityTypesResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListSessionEntityTypesResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ListSessionEntityTypesResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.sessionEntityTypes && message.sessionEntityTypes.length))
                                            message.sessionEntityTypes = [];
                                        message.sessionEntityTypes.push($root.google.cloud.dialogflow.v2.SessionEntityType.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 2: {
                                        message.nextPageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListSessionEntityTypesResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListSessionEntityTypesResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ListSessionEntityTypesResponse} ListSessionEntityTypesResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListSessionEntityTypesResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListSessionEntityTypesResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ListSessionEntityTypesResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListSessionEntityTypesResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.sessionEntityTypes != null && message.hasOwnProperty("sessionEntityTypes")) {
                                if (!Array.isArray(message.sessionEntityTypes))
                                    return "sessionEntityTypes: array expected";
                                for (var i = 0; i < message.sessionEntityTypes.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.SessionEntityType.verify(message.sessionEntityTypes[i]);
                                    if (error)
                                        return "sessionEntityTypes." + error;
                                }
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                if (!$util.isString(message.nextPageToken))
                                    return "nextPageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListSessionEntityTypesResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ListSessionEntityTypesResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ListSessionEntityTypesResponse} ListSessionEntityTypesResponse
                         */
                        ListSessionEntityTypesResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ListSessionEntityTypesResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ListSessionEntityTypesResponse();
                            if (object.sessionEntityTypes) {
                                if (!Array.isArray(object.sessionEntityTypes))
                                    throw TypeError(".google.cloud.dialogflow.v2.ListSessionEntityTypesResponse.sessionEntityTypes: array expected");
                                message.sessionEntityTypes = [];
                                for (var i = 0; i < object.sessionEntityTypes.length; ++i) {
                                    if (typeof object.sessionEntityTypes[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.ListSessionEntityTypesResponse.sessionEntityTypes: object expected");
                                    message.sessionEntityTypes[i] = $root.google.cloud.dialogflow.v2.SessionEntityType.fromObject(object.sessionEntityTypes[i]);
                                }
                            }
                            if (object.nextPageToken != null)
                                message.nextPageToken = String(object.nextPageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListSessionEntityTypesResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ListSessionEntityTypesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.ListSessionEntityTypesResponse} message ListSessionEntityTypesResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListSessionEntityTypesResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.sessionEntityTypes = [];
                            if (options.defaults)
                                object.nextPageToken = "";
                            if (message.sessionEntityTypes && message.sessionEntityTypes.length) {
                                object.sessionEntityTypes = [];
                                for (var j = 0; j < message.sessionEntityTypes.length; ++j)
                                    object.sessionEntityTypes[j] = $root.google.cloud.dialogflow.v2.SessionEntityType.toObject(message.sessionEntityTypes[j], options);
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                object.nextPageToken = message.nextPageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListSessionEntityTypesResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ListSessionEntityTypesResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListSessionEntityTypesResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListSessionEntityTypesResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ListSessionEntityTypesResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListSessionEntityTypesResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ListSessionEntityTypesResponse";
                        };
    
                        return ListSessionEntityTypesResponse;
                    })();
    
                    v2.GetSessionEntityTypeRequest = (function() {
    
                        /**
                         * Properties of a GetSessionEntityTypeRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IGetSessionEntityTypeRequest
                         * @property {string|null} [name] GetSessionEntityTypeRequest name
                         */
    
                        /**
                         * Constructs a new GetSessionEntityTypeRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a GetSessionEntityTypeRequest.
                         * @implements IGetSessionEntityTypeRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IGetSessionEntityTypeRequest=} [properties] Properties to set
                         */
                        function GetSessionEntityTypeRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GetSessionEntityTypeRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2.GetSessionEntityTypeRequest
                         * @instance
                         */
                        GetSessionEntityTypeRequest.prototype.name = "";
    
                        /**
                         * Creates a new GetSessionEntityTypeRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.GetSessionEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetSessionEntityTypeRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.GetSessionEntityTypeRequest} GetSessionEntityTypeRequest instance
                         */
                        GetSessionEntityTypeRequest.create = function create(properties) {
                            return new GetSessionEntityTypeRequest(properties);
                        };
    
                        /**
                         * Encodes the specified GetSessionEntityTypeRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.GetSessionEntityTypeRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.GetSessionEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetSessionEntityTypeRequest} message GetSessionEntityTypeRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetSessionEntityTypeRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GetSessionEntityTypeRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.GetSessionEntityTypeRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GetSessionEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetSessionEntityTypeRequest} message GetSessionEntityTypeRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetSessionEntityTypeRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GetSessionEntityTypeRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.GetSessionEntityTypeRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.GetSessionEntityTypeRequest} GetSessionEntityTypeRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetSessionEntityTypeRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.GetSessionEntityTypeRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GetSessionEntityTypeRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GetSessionEntityTypeRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.GetSessionEntityTypeRequest} GetSessionEntityTypeRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetSessionEntityTypeRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GetSessionEntityTypeRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.GetSessionEntityTypeRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GetSessionEntityTypeRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a GetSessionEntityTypeRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.GetSessionEntityTypeRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.GetSessionEntityTypeRequest} GetSessionEntityTypeRequest
                         */
                        GetSessionEntityTypeRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.GetSessionEntityTypeRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.GetSessionEntityTypeRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GetSessionEntityTypeRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.GetSessionEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.GetSessionEntityTypeRequest} message GetSessionEntityTypeRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GetSessionEntityTypeRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.name = "";
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            return object;
                        };
    
                        /**
                         * Converts this GetSessionEntityTypeRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.GetSessionEntityTypeRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GetSessionEntityTypeRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GetSessionEntityTypeRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.GetSessionEntityTypeRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GetSessionEntityTypeRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.GetSessionEntityTypeRequest";
                        };
    
                        return GetSessionEntityTypeRequest;
                    })();
    
                    v2.CreateSessionEntityTypeRequest = (function() {
    
                        /**
                         * Properties of a CreateSessionEntityTypeRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ICreateSessionEntityTypeRequest
                         * @property {string|null} [parent] CreateSessionEntityTypeRequest parent
                         * @property {google.cloud.dialogflow.v2.ISessionEntityType|null} [sessionEntityType] CreateSessionEntityTypeRequest sessionEntityType
                         */
    
                        /**
                         * Constructs a new CreateSessionEntityTypeRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a CreateSessionEntityTypeRequest.
                         * @implements ICreateSessionEntityTypeRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ICreateSessionEntityTypeRequest=} [properties] Properties to set
                         */
                        function CreateSessionEntityTypeRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * CreateSessionEntityTypeRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.CreateSessionEntityTypeRequest
                         * @instance
                         */
                        CreateSessionEntityTypeRequest.prototype.parent = "";
    
                        /**
                         * CreateSessionEntityTypeRequest sessionEntityType.
                         * @member {google.cloud.dialogflow.v2.ISessionEntityType|null|undefined} sessionEntityType
                         * @memberof google.cloud.dialogflow.v2.CreateSessionEntityTypeRequest
                         * @instance
                         */
                        CreateSessionEntityTypeRequest.prototype.sessionEntityType = null;
    
                        /**
                         * Creates a new CreateSessionEntityTypeRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.CreateSessionEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICreateSessionEntityTypeRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.CreateSessionEntityTypeRequest} CreateSessionEntityTypeRequest instance
                         */
                        CreateSessionEntityTypeRequest.create = function create(properties) {
                            return new CreateSessionEntityTypeRequest(properties);
                        };
    
                        /**
                         * Encodes the specified CreateSessionEntityTypeRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.CreateSessionEntityTypeRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.CreateSessionEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICreateSessionEntityTypeRequest} message CreateSessionEntityTypeRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateSessionEntityTypeRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.sessionEntityType != null && Object.hasOwnProperty.call(message, "sessionEntityType"))
                                $root.google.cloud.dialogflow.v2.SessionEntityType.encode(message.sessionEntityType, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified CreateSessionEntityTypeRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.CreateSessionEntityTypeRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.CreateSessionEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICreateSessionEntityTypeRequest} message CreateSessionEntityTypeRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateSessionEntityTypeRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a CreateSessionEntityTypeRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.CreateSessionEntityTypeRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.CreateSessionEntityTypeRequest} CreateSessionEntityTypeRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateSessionEntityTypeRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.CreateSessionEntityTypeRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.sessionEntityType = $root.google.cloud.dialogflow.v2.SessionEntityType.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a CreateSessionEntityTypeRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.CreateSessionEntityTypeRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.CreateSessionEntityTypeRequest} CreateSessionEntityTypeRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateSessionEntityTypeRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a CreateSessionEntityTypeRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.CreateSessionEntityTypeRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        CreateSessionEntityTypeRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.sessionEntityType != null && message.hasOwnProperty("sessionEntityType")) {
                                var error = $root.google.cloud.dialogflow.v2.SessionEntityType.verify(message.sessionEntityType);
                                if (error)
                                    return "sessionEntityType." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a CreateSessionEntityTypeRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.CreateSessionEntityTypeRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.CreateSessionEntityTypeRequest} CreateSessionEntityTypeRequest
                         */
                        CreateSessionEntityTypeRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.CreateSessionEntityTypeRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.CreateSessionEntityTypeRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.sessionEntityType != null) {
                                if (typeof object.sessionEntityType !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.CreateSessionEntityTypeRequest.sessionEntityType: object expected");
                                message.sessionEntityType = $root.google.cloud.dialogflow.v2.SessionEntityType.fromObject(object.sessionEntityType);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a CreateSessionEntityTypeRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.CreateSessionEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.CreateSessionEntityTypeRequest} message CreateSessionEntityTypeRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        CreateSessionEntityTypeRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.sessionEntityType = null;
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.sessionEntityType != null && message.hasOwnProperty("sessionEntityType"))
                                object.sessionEntityType = $root.google.cloud.dialogflow.v2.SessionEntityType.toObject(message.sessionEntityType, options);
                            return object;
                        };
    
                        /**
                         * Converts this CreateSessionEntityTypeRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.CreateSessionEntityTypeRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        CreateSessionEntityTypeRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for CreateSessionEntityTypeRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.CreateSessionEntityTypeRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        CreateSessionEntityTypeRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.CreateSessionEntityTypeRequest";
                        };
    
                        return CreateSessionEntityTypeRequest;
                    })();
    
                    v2.UpdateSessionEntityTypeRequest = (function() {
    
                        /**
                         * Properties of an UpdateSessionEntityTypeRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IUpdateSessionEntityTypeRequest
                         * @property {google.cloud.dialogflow.v2.ISessionEntityType|null} [sessionEntityType] UpdateSessionEntityTypeRequest sessionEntityType
                         * @property {google.protobuf.IFieldMask|null} [updateMask] UpdateSessionEntityTypeRequest updateMask
                         */
    
                        /**
                         * Constructs a new UpdateSessionEntityTypeRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an UpdateSessionEntityTypeRequest.
                         * @implements IUpdateSessionEntityTypeRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IUpdateSessionEntityTypeRequest=} [properties] Properties to set
                         */
                        function UpdateSessionEntityTypeRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * UpdateSessionEntityTypeRequest sessionEntityType.
                         * @member {google.cloud.dialogflow.v2.ISessionEntityType|null|undefined} sessionEntityType
                         * @memberof google.cloud.dialogflow.v2.UpdateSessionEntityTypeRequest
                         * @instance
                         */
                        UpdateSessionEntityTypeRequest.prototype.sessionEntityType = null;
    
                        /**
                         * UpdateSessionEntityTypeRequest updateMask.
                         * @member {google.protobuf.IFieldMask|null|undefined} updateMask
                         * @memberof google.cloud.dialogflow.v2.UpdateSessionEntityTypeRequest
                         * @instance
                         */
                        UpdateSessionEntityTypeRequest.prototype.updateMask = null;
    
                        /**
                         * Creates a new UpdateSessionEntityTypeRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.UpdateSessionEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IUpdateSessionEntityTypeRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.UpdateSessionEntityTypeRequest} UpdateSessionEntityTypeRequest instance
                         */
                        UpdateSessionEntityTypeRequest.create = function create(properties) {
                            return new UpdateSessionEntityTypeRequest(properties);
                        };
    
                        /**
                         * Encodes the specified UpdateSessionEntityTypeRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.UpdateSessionEntityTypeRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.UpdateSessionEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IUpdateSessionEntityTypeRequest} message UpdateSessionEntityTypeRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UpdateSessionEntityTypeRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.sessionEntityType != null && Object.hasOwnProperty.call(message, "sessionEntityType"))
                                $root.google.cloud.dialogflow.v2.SessionEntityType.encode(message.sessionEntityType, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.updateMask != null && Object.hasOwnProperty.call(message, "updateMask"))
                                $root.google.protobuf.FieldMask.encode(message.updateMask, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified UpdateSessionEntityTypeRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.UpdateSessionEntityTypeRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.UpdateSessionEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IUpdateSessionEntityTypeRequest} message UpdateSessionEntityTypeRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UpdateSessionEntityTypeRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an UpdateSessionEntityTypeRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.UpdateSessionEntityTypeRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.UpdateSessionEntityTypeRequest} UpdateSessionEntityTypeRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UpdateSessionEntityTypeRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.UpdateSessionEntityTypeRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.sessionEntityType = $root.google.cloud.dialogflow.v2.SessionEntityType.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.updateMask = $root.google.protobuf.FieldMask.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an UpdateSessionEntityTypeRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.UpdateSessionEntityTypeRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.UpdateSessionEntityTypeRequest} UpdateSessionEntityTypeRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UpdateSessionEntityTypeRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an UpdateSessionEntityTypeRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.UpdateSessionEntityTypeRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        UpdateSessionEntityTypeRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.sessionEntityType != null && message.hasOwnProperty("sessionEntityType")) {
                                var error = $root.google.cloud.dialogflow.v2.SessionEntityType.verify(message.sessionEntityType);
                                if (error)
                                    return "sessionEntityType." + error;
                            }
                            if (message.updateMask != null && message.hasOwnProperty("updateMask")) {
                                var error = $root.google.protobuf.FieldMask.verify(message.updateMask);
                                if (error)
                                    return "updateMask." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates an UpdateSessionEntityTypeRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.UpdateSessionEntityTypeRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.UpdateSessionEntityTypeRequest} UpdateSessionEntityTypeRequest
                         */
                        UpdateSessionEntityTypeRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.UpdateSessionEntityTypeRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.UpdateSessionEntityTypeRequest();
                            if (object.sessionEntityType != null) {
                                if (typeof object.sessionEntityType !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.UpdateSessionEntityTypeRequest.sessionEntityType: object expected");
                                message.sessionEntityType = $root.google.cloud.dialogflow.v2.SessionEntityType.fromObject(object.sessionEntityType);
                            }
                            if (object.updateMask != null) {
                                if (typeof object.updateMask !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.UpdateSessionEntityTypeRequest.updateMask: object expected");
                                message.updateMask = $root.google.protobuf.FieldMask.fromObject(object.updateMask);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an UpdateSessionEntityTypeRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.UpdateSessionEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.UpdateSessionEntityTypeRequest} message UpdateSessionEntityTypeRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        UpdateSessionEntityTypeRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.sessionEntityType = null;
                                object.updateMask = null;
                            }
                            if (message.sessionEntityType != null && message.hasOwnProperty("sessionEntityType"))
                                object.sessionEntityType = $root.google.cloud.dialogflow.v2.SessionEntityType.toObject(message.sessionEntityType, options);
                            if (message.updateMask != null && message.hasOwnProperty("updateMask"))
                                object.updateMask = $root.google.protobuf.FieldMask.toObject(message.updateMask, options);
                            return object;
                        };
    
                        /**
                         * Converts this UpdateSessionEntityTypeRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.UpdateSessionEntityTypeRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        UpdateSessionEntityTypeRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for UpdateSessionEntityTypeRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.UpdateSessionEntityTypeRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        UpdateSessionEntityTypeRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.UpdateSessionEntityTypeRequest";
                        };
    
                        return UpdateSessionEntityTypeRequest;
                    })();
    
                    v2.DeleteSessionEntityTypeRequest = (function() {
    
                        /**
                         * Properties of a DeleteSessionEntityTypeRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IDeleteSessionEntityTypeRequest
                         * @property {string|null} [name] DeleteSessionEntityTypeRequest name
                         */
    
                        /**
                         * Constructs a new DeleteSessionEntityTypeRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a DeleteSessionEntityTypeRequest.
                         * @implements IDeleteSessionEntityTypeRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IDeleteSessionEntityTypeRequest=} [properties] Properties to set
                         */
                        function DeleteSessionEntityTypeRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * DeleteSessionEntityTypeRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2.DeleteSessionEntityTypeRequest
                         * @instance
                         */
                        DeleteSessionEntityTypeRequest.prototype.name = "";
    
                        /**
                         * Creates a new DeleteSessionEntityTypeRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.DeleteSessionEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDeleteSessionEntityTypeRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.DeleteSessionEntityTypeRequest} DeleteSessionEntityTypeRequest instance
                         */
                        DeleteSessionEntityTypeRequest.create = function create(properties) {
                            return new DeleteSessionEntityTypeRequest(properties);
                        };
    
                        /**
                         * Encodes the specified DeleteSessionEntityTypeRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.DeleteSessionEntityTypeRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.DeleteSessionEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDeleteSessionEntityTypeRequest} message DeleteSessionEntityTypeRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteSessionEntityTypeRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified DeleteSessionEntityTypeRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.DeleteSessionEntityTypeRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.DeleteSessionEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDeleteSessionEntityTypeRequest} message DeleteSessionEntityTypeRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteSessionEntityTypeRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a DeleteSessionEntityTypeRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.DeleteSessionEntityTypeRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.DeleteSessionEntityTypeRequest} DeleteSessionEntityTypeRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteSessionEntityTypeRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.DeleteSessionEntityTypeRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a DeleteSessionEntityTypeRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.DeleteSessionEntityTypeRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.DeleteSessionEntityTypeRequest} DeleteSessionEntityTypeRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteSessionEntityTypeRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a DeleteSessionEntityTypeRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.DeleteSessionEntityTypeRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        DeleteSessionEntityTypeRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a DeleteSessionEntityTypeRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.DeleteSessionEntityTypeRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.DeleteSessionEntityTypeRequest} DeleteSessionEntityTypeRequest
                         */
                        DeleteSessionEntityTypeRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.DeleteSessionEntityTypeRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.DeleteSessionEntityTypeRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a DeleteSessionEntityTypeRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.DeleteSessionEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.DeleteSessionEntityTypeRequest} message DeleteSessionEntityTypeRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        DeleteSessionEntityTypeRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.name = "";
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            return object;
                        };
    
                        /**
                         * Converts this DeleteSessionEntityTypeRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.DeleteSessionEntityTypeRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        DeleteSessionEntityTypeRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for DeleteSessionEntityTypeRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.DeleteSessionEntityTypeRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        DeleteSessionEntityTypeRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.DeleteSessionEntityTypeRequest";
                        };
    
                        return DeleteSessionEntityTypeRequest;
                    })();
    
                    v2.EntityTypes = (function() {
    
                        /**
                         * Constructs a new EntityTypes service.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an EntityTypes
                         * @extends $protobuf.rpc.Service
                         * @constructor
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         */
                        function EntityTypes(rpcImpl, requestDelimited, responseDelimited) {
                            $protobuf.rpc.Service.call(this, rpcImpl, requestDelimited, responseDelimited);
                        }
    
                        (EntityTypes.prototype = Object.create($protobuf.rpc.Service.prototype)).constructor = EntityTypes;
    
                        /**
                         * Creates new EntityTypes service using the specified rpc implementation.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.EntityTypes
                         * @static
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         * @returns {EntityTypes} RPC service. Useful where requests and/or responses are streamed.
                         */
                        EntityTypes.create = function create(rpcImpl, requestDelimited, responseDelimited) {
                            return new this(rpcImpl, requestDelimited, responseDelimited);
                        };
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.EntityTypes|listEntityTypes}.
                         * @memberof google.cloud.dialogflow.v2.EntityTypes
                         * @typedef ListEntityTypesCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.ListEntityTypesResponse} [response] ListEntityTypesResponse
                         */
    
                        /**
                         * Calls ListEntityTypes.
                         * @function listEntityTypes
                         * @memberof google.cloud.dialogflow.v2.EntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IListEntityTypesRequest} request ListEntityTypesRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.EntityTypes.ListEntityTypesCallback} callback Node-style callback called with the error, if any, and ListEntityTypesResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(EntityTypes.prototype.listEntityTypes = function listEntityTypes(request, callback) {
                            return this.rpcCall(listEntityTypes, $root.google.cloud.dialogflow.v2.ListEntityTypesRequest, $root.google.cloud.dialogflow.v2.ListEntityTypesResponse, request, callback);
                        }, "name", { value: "ListEntityTypes" });
    
                        /**
                         * Calls ListEntityTypes.
                         * @function listEntityTypes
                         * @memberof google.cloud.dialogflow.v2.EntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IListEntityTypesRequest} request ListEntityTypesRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.ListEntityTypesResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.EntityTypes|getEntityType}.
                         * @memberof google.cloud.dialogflow.v2.EntityTypes
                         * @typedef GetEntityTypeCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.EntityType} [response] EntityType
                         */
    
                        /**
                         * Calls GetEntityType.
                         * @function getEntityType
                         * @memberof google.cloud.dialogflow.v2.EntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IGetEntityTypeRequest} request GetEntityTypeRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.EntityTypes.GetEntityTypeCallback} callback Node-style callback called with the error, if any, and EntityType
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(EntityTypes.prototype.getEntityType = function getEntityType(request, callback) {
                            return this.rpcCall(getEntityType, $root.google.cloud.dialogflow.v2.GetEntityTypeRequest, $root.google.cloud.dialogflow.v2.EntityType, request, callback);
                        }, "name", { value: "GetEntityType" });
    
                        /**
                         * Calls GetEntityType.
                         * @function getEntityType
                         * @memberof google.cloud.dialogflow.v2.EntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IGetEntityTypeRequest} request GetEntityTypeRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.EntityType>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.EntityTypes|createEntityType}.
                         * @memberof google.cloud.dialogflow.v2.EntityTypes
                         * @typedef CreateEntityTypeCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.EntityType} [response] EntityType
                         */
    
                        /**
                         * Calls CreateEntityType.
                         * @function createEntityType
                         * @memberof google.cloud.dialogflow.v2.EntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2.ICreateEntityTypeRequest} request CreateEntityTypeRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.EntityTypes.CreateEntityTypeCallback} callback Node-style callback called with the error, if any, and EntityType
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(EntityTypes.prototype.createEntityType = function createEntityType(request, callback) {
                            return this.rpcCall(createEntityType, $root.google.cloud.dialogflow.v2.CreateEntityTypeRequest, $root.google.cloud.dialogflow.v2.EntityType, request, callback);
                        }, "name", { value: "CreateEntityType" });
    
                        /**
                         * Calls CreateEntityType.
                         * @function createEntityType
                         * @memberof google.cloud.dialogflow.v2.EntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2.ICreateEntityTypeRequest} request CreateEntityTypeRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.EntityType>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.EntityTypes|updateEntityType}.
                         * @memberof google.cloud.dialogflow.v2.EntityTypes
                         * @typedef UpdateEntityTypeCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.EntityType} [response] EntityType
                         */
    
                        /**
                         * Calls UpdateEntityType.
                         * @function updateEntityType
                         * @memberof google.cloud.dialogflow.v2.EntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IUpdateEntityTypeRequest} request UpdateEntityTypeRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.EntityTypes.UpdateEntityTypeCallback} callback Node-style callback called with the error, if any, and EntityType
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(EntityTypes.prototype.updateEntityType = function updateEntityType(request, callback) {
                            return this.rpcCall(updateEntityType, $root.google.cloud.dialogflow.v2.UpdateEntityTypeRequest, $root.google.cloud.dialogflow.v2.EntityType, request, callback);
                        }, "name", { value: "UpdateEntityType" });
    
                        /**
                         * Calls UpdateEntityType.
                         * @function updateEntityType
                         * @memberof google.cloud.dialogflow.v2.EntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IUpdateEntityTypeRequest} request UpdateEntityTypeRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.EntityType>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.EntityTypes|deleteEntityType}.
                         * @memberof google.cloud.dialogflow.v2.EntityTypes
                         * @typedef DeleteEntityTypeCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.protobuf.Empty} [response] Empty
                         */
    
                        /**
                         * Calls DeleteEntityType.
                         * @function deleteEntityType
                         * @memberof google.cloud.dialogflow.v2.EntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IDeleteEntityTypeRequest} request DeleteEntityTypeRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.EntityTypes.DeleteEntityTypeCallback} callback Node-style callback called with the error, if any, and Empty
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(EntityTypes.prototype.deleteEntityType = function deleteEntityType(request, callback) {
                            return this.rpcCall(deleteEntityType, $root.google.cloud.dialogflow.v2.DeleteEntityTypeRequest, $root.google.protobuf.Empty, request, callback);
                        }, "name", { value: "DeleteEntityType" });
    
                        /**
                         * Calls DeleteEntityType.
                         * @function deleteEntityType
                         * @memberof google.cloud.dialogflow.v2.EntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IDeleteEntityTypeRequest} request DeleteEntityTypeRequest message or plain object
                         * @returns {Promise<google.protobuf.Empty>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.EntityTypes|batchUpdateEntityTypes}.
                         * @memberof google.cloud.dialogflow.v2.EntityTypes
                         * @typedef BatchUpdateEntityTypesCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.longrunning.Operation} [response] Operation
                         */
    
                        /**
                         * Calls BatchUpdateEntityTypes.
                         * @function batchUpdateEntityTypes
                         * @memberof google.cloud.dialogflow.v2.EntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IBatchUpdateEntityTypesRequest} request BatchUpdateEntityTypesRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.EntityTypes.BatchUpdateEntityTypesCallback} callback Node-style callback called with the error, if any, and Operation
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(EntityTypes.prototype.batchUpdateEntityTypes = function batchUpdateEntityTypes(request, callback) {
                            return this.rpcCall(batchUpdateEntityTypes, $root.google.cloud.dialogflow.v2.BatchUpdateEntityTypesRequest, $root.google.longrunning.Operation, request, callback);
                        }, "name", { value: "BatchUpdateEntityTypes" });
    
                        /**
                         * Calls BatchUpdateEntityTypes.
                         * @function batchUpdateEntityTypes
                         * @memberof google.cloud.dialogflow.v2.EntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IBatchUpdateEntityTypesRequest} request BatchUpdateEntityTypesRequest message or plain object
                         * @returns {Promise<google.longrunning.Operation>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.EntityTypes|batchDeleteEntityTypes}.
                         * @memberof google.cloud.dialogflow.v2.EntityTypes
                         * @typedef BatchDeleteEntityTypesCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.longrunning.Operation} [response] Operation
                         */
    
                        /**
                         * Calls BatchDeleteEntityTypes.
                         * @function batchDeleteEntityTypes
                         * @memberof google.cloud.dialogflow.v2.EntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IBatchDeleteEntityTypesRequest} request BatchDeleteEntityTypesRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.EntityTypes.BatchDeleteEntityTypesCallback} callback Node-style callback called with the error, if any, and Operation
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(EntityTypes.prototype.batchDeleteEntityTypes = function batchDeleteEntityTypes(request, callback) {
                            return this.rpcCall(batchDeleteEntityTypes, $root.google.cloud.dialogflow.v2.BatchDeleteEntityTypesRequest, $root.google.longrunning.Operation, request, callback);
                        }, "name", { value: "BatchDeleteEntityTypes" });
    
                        /**
                         * Calls BatchDeleteEntityTypes.
                         * @function batchDeleteEntityTypes
                         * @memberof google.cloud.dialogflow.v2.EntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IBatchDeleteEntityTypesRequest} request BatchDeleteEntityTypesRequest message or plain object
                         * @returns {Promise<google.longrunning.Operation>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.EntityTypes|batchCreateEntities}.
                         * @memberof google.cloud.dialogflow.v2.EntityTypes
                         * @typedef BatchCreateEntitiesCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.longrunning.Operation} [response] Operation
                         */
    
                        /**
                         * Calls BatchCreateEntities.
                         * @function batchCreateEntities
                         * @memberof google.cloud.dialogflow.v2.EntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IBatchCreateEntitiesRequest} request BatchCreateEntitiesRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.EntityTypes.BatchCreateEntitiesCallback} callback Node-style callback called with the error, if any, and Operation
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(EntityTypes.prototype.batchCreateEntities = function batchCreateEntities(request, callback) {
                            return this.rpcCall(batchCreateEntities, $root.google.cloud.dialogflow.v2.BatchCreateEntitiesRequest, $root.google.longrunning.Operation, request, callback);
                        }, "name", { value: "BatchCreateEntities" });
    
                        /**
                         * Calls BatchCreateEntities.
                         * @function batchCreateEntities
                         * @memberof google.cloud.dialogflow.v2.EntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IBatchCreateEntitiesRequest} request BatchCreateEntitiesRequest message or plain object
                         * @returns {Promise<google.longrunning.Operation>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.EntityTypes|batchUpdateEntities}.
                         * @memberof google.cloud.dialogflow.v2.EntityTypes
                         * @typedef BatchUpdateEntitiesCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.longrunning.Operation} [response] Operation
                         */
    
                        /**
                         * Calls BatchUpdateEntities.
                         * @function batchUpdateEntities
                         * @memberof google.cloud.dialogflow.v2.EntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IBatchUpdateEntitiesRequest} request BatchUpdateEntitiesRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.EntityTypes.BatchUpdateEntitiesCallback} callback Node-style callback called with the error, if any, and Operation
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(EntityTypes.prototype.batchUpdateEntities = function batchUpdateEntities(request, callback) {
                            return this.rpcCall(batchUpdateEntities, $root.google.cloud.dialogflow.v2.BatchUpdateEntitiesRequest, $root.google.longrunning.Operation, request, callback);
                        }, "name", { value: "BatchUpdateEntities" });
    
                        /**
                         * Calls BatchUpdateEntities.
                         * @function batchUpdateEntities
                         * @memberof google.cloud.dialogflow.v2.EntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IBatchUpdateEntitiesRequest} request BatchUpdateEntitiesRequest message or plain object
                         * @returns {Promise<google.longrunning.Operation>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.EntityTypes|batchDeleteEntities}.
                         * @memberof google.cloud.dialogflow.v2.EntityTypes
                         * @typedef BatchDeleteEntitiesCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.longrunning.Operation} [response] Operation
                         */
    
                        /**
                         * Calls BatchDeleteEntities.
                         * @function batchDeleteEntities
                         * @memberof google.cloud.dialogflow.v2.EntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IBatchDeleteEntitiesRequest} request BatchDeleteEntitiesRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.EntityTypes.BatchDeleteEntitiesCallback} callback Node-style callback called with the error, if any, and Operation
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(EntityTypes.prototype.batchDeleteEntities = function batchDeleteEntities(request, callback) {
                            return this.rpcCall(batchDeleteEntities, $root.google.cloud.dialogflow.v2.BatchDeleteEntitiesRequest, $root.google.longrunning.Operation, request, callback);
                        }, "name", { value: "BatchDeleteEntities" });
    
                        /**
                         * Calls BatchDeleteEntities.
                         * @function batchDeleteEntities
                         * @memberof google.cloud.dialogflow.v2.EntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IBatchDeleteEntitiesRequest} request BatchDeleteEntitiesRequest message or plain object
                         * @returns {Promise<google.longrunning.Operation>} Promise
                         * @variation 2
                         */
    
                        return EntityTypes;
                    })();
    
                    v2.EntityType = (function() {
    
                        /**
                         * Properties of an EntityType.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IEntityType
                         * @property {string|null} [name] EntityType name
                         * @property {string|null} [displayName] EntityType displayName
                         * @property {google.cloud.dialogflow.v2.EntityType.Kind|null} [kind] EntityType kind
                         * @property {google.cloud.dialogflow.v2.EntityType.AutoExpansionMode|null} [autoExpansionMode] EntityType autoExpansionMode
                         * @property {Array.<google.cloud.dialogflow.v2.EntityType.IEntity>|null} [entities] EntityType entities
                         * @property {boolean|null} [enableFuzzyExtraction] EntityType enableFuzzyExtraction
                         */
    
                        /**
                         * Constructs a new EntityType.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an EntityType.
                         * @implements IEntityType
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IEntityType=} [properties] Properties to set
                         */
                        function EntityType(properties) {
                            this.entities = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * EntityType name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2.EntityType
                         * @instance
                         */
                        EntityType.prototype.name = "";
    
                        /**
                         * EntityType displayName.
                         * @member {string} displayName
                         * @memberof google.cloud.dialogflow.v2.EntityType
                         * @instance
                         */
                        EntityType.prototype.displayName = "";
    
                        /**
                         * EntityType kind.
                         * @member {google.cloud.dialogflow.v2.EntityType.Kind} kind
                         * @memberof google.cloud.dialogflow.v2.EntityType
                         * @instance
                         */
                        EntityType.prototype.kind = 0;
    
                        /**
                         * EntityType autoExpansionMode.
                         * @member {google.cloud.dialogflow.v2.EntityType.AutoExpansionMode} autoExpansionMode
                         * @memberof google.cloud.dialogflow.v2.EntityType
                         * @instance
                         */
                        EntityType.prototype.autoExpansionMode = 0;
    
                        /**
                         * EntityType entities.
                         * @member {Array.<google.cloud.dialogflow.v2.EntityType.IEntity>} entities
                         * @memberof google.cloud.dialogflow.v2.EntityType
                         * @instance
                         */
                        EntityType.prototype.entities = $util.emptyArray;
    
                        /**
                         * EntityType enableFuzzyExtraction.
                         * @member {boolean} enableFuzzyExtraction
                         * @memberof google.cloud.dialogflow.v2.EntityType
                         * @instance
                         */
                        EntityType.prototype.enableFuzzyExtraction = false;
    
                        /**
                         * Creates a new EntityType instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.EntityType
                         * @static
                         * @param {google.cloud.dialogflow.v2.IEntityType=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.EntityType} EntityType instance
                         */
                        EntityType.create = function create(properties) {
                            return new EntityType(properties);
                        };
    
                        /**
                         * Encodes the specified EntityType message. Does not implicitly {@link google.cloud.dialogflow.v2.EntityType.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.EntityType
                         * @static
                         * @param {google.cloud.dialogflow.v2.IEntityType} message EntityType message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        EntityType.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            if (message.displayName != null && Object.hasOwnProperty.call(message, "displayName"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.displayName);
                            if (message.kind != null && Object.hasOwnProperty.call(message, "kind"))
                                writer.uint32(/* id 3, wireType 0 =*/24).int32(message.kind);
                            if (message.autoExpansionMode != null && Object.hasOwnProperty.call(message, "autoExpansionMode"))
                                writer.uint32(/* id 4, wireType 0 =*/32).int32(message.autoExpansionMode);
                            if (message.entities != null && message.entities.length)
                                for (var i = 0; i < message.entities.length; ++i)
                                    $root.google.cloud.dialogflow.v2.EntityType.Entity.encode(message.entities[i], writer.uint32(/* id 6, wireType 2 =*/50).fork()).ldelim();
                            if (message.enableFuzzyExtraction != null && Object.hasOwnProperty.call(message, "enableFuzzyExtraction"))
                                writer.uint32(/* id 7, wireType 0 =*/56).bool(message.enableFuzzyExtraction);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified EntityType message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.EntityType.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.EntityType
                         * @static
                         * @param {google.cloud.dialogflow.v2.IEntityType} message EntityType message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        EntityType.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an EntityType message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.EntityType
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.EntityType} EntityType
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        EntityType.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.EntityType();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.displayName = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.kind = reader.int32();
                                        break;
                                    }
                                case 4: {
                                        message.autoExpansionMode = reader.int32();
                                        break;
                                    }
                                case 6: {
                                        if (!(message.entities && message.entities.length))
                                            message.entities = [];
                                        message.entities.push($root.google.cloud.dialogflow.v2.EntityType.Entity.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 7: {
                                        message.enableFuzzyExtraction = reader.bool();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an EntityType message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.EntityType
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.EntityType} EntityType
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        EntityType.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an EntityType message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.EntityType
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        EntityType.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            if (message.displayName != null && message.hasOwnProperty("displayName"))
                                if (!$util.isString(message.displayName))
                                    return "displayName: string expected";
                            if (message.kind != null && message.hasOwnProperty("kind"))
                                switch (message.kind) {
                                default:
                                    return "kind: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                    break;
                                }
                            if (message.autoExpansionMode != null && message.hasOwnProperty("autoExpansionMode"))
                                switch (message.autoExpansionMode) {
                                default:
                                    return "autoExpansionMode: enum value expected";
                                case 0:
                                case 1:
                                    break;
                                }
                            if (message.entities != null && message.hasOwnProperty("entities")) {
                                if (!Array.isArray(message.entities))
                                    return "entities: array expected";
                                for (var i = 0; i < message.entities.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.EntityType.Entity.verify(message.entities[i]);
                                    if (error)
                                        return "entities." + error;
                                }
                            }
                            if (message.enableFuzzyExtraction != null && message.hasOwnProperty("enableFuzzyExtraction"))
                                if (typeof message.enableFuzzyExtraction !== "boolean")
                                    return "enableFuzzyExtraction: boolean expected";
                            return null;
                        };
    
                        /**
                         * Creates an EntityType message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.EntityType
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.EntityType} EntityType
                         */
                        EntityType.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.EntityType)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.EntityType();
                            if (object.name != null)
                                message.name = String(object.name);
                            if (object.displayName != null)
                                message.displayName = String(object.displayName);
                            switch (object.kind) {
                            default:
                                if (typeof object.kind === "number") {
                                    message.kind = object.kind;
                                    break;
                                }
                                break;
                            case "KIND_UNSPECIFIED":
                            case 0:
                                message.kind = 0;
                                break;
                            case "KIND_MAP":
                            case 1:
                                message.kind = 1;
                                break;
                            case "KIND_LIST":
                            case 2:
                                message.kind = 2;
                                break;
                            case "KIND_REGEXP":
                            case 3:
                                message.kind = 3;
                                break;
                            }
                            switch (object.autoExpansionMode) {
                            default:
                                if (typeof object.autoExpansionMode === "number") {
                                    message.autoExpansionMode = object.autoExpansionMode;
                                    break;
                                }
                                break;
                            case "AUTO_EXPANSION_MODE_UNSPECIFIED":
                            case 0:
                                message.autoExpansionMode = 0;
                                break;
                            case "AUTO_EXPANSION_MODE_DEFAULT":
                            case 1:
                                message.autoExpansionMode = 1;
                                break;
                            }
                            if (object.entities) {
                                if (!Array.isArray(object.entities))
                                    throw TypeError(".google.cloud.dialogflow.v2.EntityType.entities: array expected");
                                message.entities = [];
                                for (var i = 0; i < object.entities.length; ++i) {
                                    if (typeof object.entities[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.EntityType.entities: object expected");
                                    message.entities[i] = $root.google.cloud.dialogflow.v2.EntityType.Entity.fromObject(object.entities[i]);
                                }
                            }
                            if (object.enableFuzzyExtraction != null)
                                message.enableFuzzyExtraction = Boolean(object.enableFuzzyExtraction);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an EntityType message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.EntityType
                         * @static
                         * @param {google.cloud.dialogflow.v2.EntityType} message EntityType
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        EntityType.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.entities = [];
                            if (options.defaults) {
                                object.name = "";
                                object.displayName = "";
                                object.kind = options.enums === String ? "KIND_UNSPECIFIED" : 0;
                                object.autoExpansionMode = options.enums === String ? "AUTO_EXPANSION_MODE_UNSPECIFIED" : 0;
                                object.enableFuzzyExtraction = false;
                            }
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            if (message.displayName != null && message.hasOwnProperty("displayName"))
                                object.displayName = message.displayName;
                            if (message.kind != null && message.hasOwnProperty("kind"))
                                object.kind = options.enums === String ? $root.google.cloud.dialogflow.v2.EntityType.Kind[message.kind] === undefined ? message.kind : $root.google.cloud.dialogflow.v2.EntityType.Kind[message.kind] : message.kind;
                            if (message.autoExpansionMode != null && message.hasOwnProperty("autoExpansionMode"))
                                object.autoExpansionMode = options.enums === String ? $root.google.cloud.dialogflow.v2.EntityType.AutoExpansionMode[message.autoExpansionMode] === undefined ? message.autoExpansionMode : $root.google.cloud.dialogflow.v2.EntityType.AutoExpansionMode[message.autoExpansionMode] : message.autoExpansionMode;
                            if (message.entities && message.entities.length) {
                                object.entities = [];
                                for (var j = 0; j < message.entities.length; ++j)
                                    object.entities[j] = $root.google.cloud.dialogflow.v2.EntityType.Entity.toObject(message.entities[j], options);
                            }
                            if (message.enableFuzzyExtraction != null && message.hasOwnProperty("enableFuzzyExtraction"))
                                object.enableFuzzyExtraction = message.enableFuzzyExtraction;
                            return object;
                        };
    
                        /**
                         * Converts this EntityType to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.EntityType
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        EntityType.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for EntityType
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.EntityType
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        EntityType.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.EntityType";
                        };
    
                        /**
                         * Kind enum.
                         * @name google.cloud.dialogflow.v2.EntityType.Kind
                         * @enum {number}
                         * @property {number} KIND_UNSPECIFIED=0 KIND_UNSPECIFIED value
                         * @property {number} KIND_MAP=1 KIND_MAP value
                         * @property {number} KIND_LIST=2 KIND_LIST value
                         * @property {number} KIND_REGEXP=3 KIND_REGEXP value
                         */
                        EntityType.Kind = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "KIND_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "KIND_MAP"] = 1;
                            values[valuesById[2] = "KIND_LIST"] = 2;
                            values[valuesById[3] = "KIND_REGEXP"] = 3;
                            return values;
                        })();
    
                        /**
                         * AutoExpansionMode enum.
                         * @name google.cloud.dialogflow.v2.EntityType.AutoExpansionMode
                         * @enum {number}
                         * @property {number} AUTO_EXPANSION_MODE_UNSPECIFIED=0 AUTO_EXPANSION_MODE_UNSPECIFIED value
                         * @property {number} AUTO_EXPANSION_MODE_DEFAULT=1 AUTO_EXPANSION_MODE_DEFAULT value
                         */
                        EntityType.AutoExpansionMode = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "AUTO_EXPANSION_MODE_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "AUTO_EXPANSION_MODE_DEFAULT"] = 1;
                            return values;
                        })();
    
                        EntityType.Entity = (function() {
    
                            /**
                             * Properties of an Entity.
                             * @memberof google.cloud.dialogflow.v2.EntityType
                             * @interface IEntity
                             * @property {string|null} [value] Entity value
                             * @property {Array.<string>|null} [synonyms] Entity synonyms
                             */
    
                            /**
                             * Constructs a new Entity.
                             * @memberof google.cloud.dialogflow.v2.EntityType
                             * @classdesc Represents an Entity.
                             * @implements IEntity
                             * @constructor
                             * @param {google.cloud.dialogflow.v2.EntityType.IEntity=} [properties] Properties to set
                             */
                            function Entity(properties) {
                                this.synonyms = [];
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * Entity value.
                             * @member {string} value
                             * @memberof google.cloud.dialogflow.v2.EntityType.Entity
                             * @instance
                             */
                            Entity.prototype.value = "";
    
                            /**
                             * Entity synonyms.
                             * @member {Array.<string>} synonyms
                             * @memberof google.cloud.dialogflow.v2.EntityType.Entity
                             * @instance
                             */
                            Entity.prototype.synonyms = $util.emptyArray;
    
                            /**
                             * Creates a new Entity instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2.EntityType.Entity
                             * @static
                             * @param {google.cloud.dialogflow.v2.EntityType.IEntity=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2.EntityType.Entity} Entity instance
                             */
                            Entity.create = function create(properties) {
                                return new Entity(properties);
                            };
    
                            /**
                             * Encodes the specified Entity message. Does not implicitly {@link google.cloud.dialogflow.v2.EntityType.Entity.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2.EntityType.Entity
                             * @static
                             * @param {google.cloud.dialogflow.v2.EntityType.IEntity} message Entity message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            Entity.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.value != null && Object.hasOwnProperty.call(message, "value"))
                                    writer.uint32(/* id 1, wireType 2 =*/10).string(message.value);
                                if (message.synonyms != null && message.synonyms.length)
                                    for (var i = 0; i < message.synonyms.length; ++i)
                                        writer.uint32(/* id 2, wireType 2 =*/18).string(message.synonyms[i]);
                                return writer;
                            };
    
                            /**
                             * Encodes the specified Entity message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.EntityType.Entity.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2.EntityType.Entity
                             * @static
                             * @param {google.cloud.dialogflow.v2.EntityType.IEntity} message Entity message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            Entity.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes an Entity message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2.EntityType.Entity
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2.EntityType.Entity} Entity
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            Entity.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.EntityType.Entity();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.value = reader.string();
                                            break;
                                        }
                                    case 2: {
                                            if (!(message.synonyms && message.synonyms.length))
                                                message.synonyms = [];
                                            message.synonyms.push(reader.string());
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes an Entity message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2.EntityType.Entity
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2.EntityType.Entity} Entity
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            Entity.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies an Entity message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2.EntityType.Entity
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            Entity.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.value != null && message.hasOwnProperty("value"))
                                    if (!$util.isString(message.value))
                                        return "value: string expected";
                                if (message.synonyms != null && message.hasOwnProperty("synonyms")) {
                                    if (!Array.isArray(message.synonyms))
                                        return "synonyms: array expected";
                                    for (var i = 0; i < message.synonyms.length; ++i)
                                        if (!$util.isString(message.synonyms[i]))
                                            return "synonyms: string[] expected";
                                }
                                return null;
                            };
    
                            /**
                             * Creates an Entity message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2.EntityType.Entity
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2.EntityType.Entity} Entity
                             */
                            Entity.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2.EntityType.Entity)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2.EntityType.Entity();
                                if (object.value != null)
                                    message.value = String(object.value);
                                if (object.synonyms) {
                                    if (!Array.isArray(object.synonyms))
                                        throw TypeError(".google.cloud.dialogflow.v2.EntityType.Entity.synonyms: array expected");
                                    message.synonyms = [];
                                    for (var i = 0; i < object.synonyms.length; ++i)
                                        message.synonyms[i] = String(object.synonyms[i]);
                                }
                                return message;
                            };
    
                            /**
                             * Creates a plain object from an Entity message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2.EntityType.Entity
                             * @static
                             * @param {google.cloud.dialogflow.v2.EntityType.Entity} message Entity
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            Entity.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.arrays || options.defaults)
                                    object.synonyms = [];
                                if (options.defaults)
                                    object.value = "";
                                if (message.value != null && message.hasOwnProperty("value"))
                                    object.value = message.value;
                                if (message.synonyms && message.synonyms.length) {
                                    object.synonyms = [];
                                    for (var j = 0; j < message.synonyms.length; ++j)
                                        object.synonyms[j] = message.synonyms[j];
                                }
                                return object;
                            };
    
                            /**
                             * Converts this Entity to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2.EntityType.Entity
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            Entity.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for Entity
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2.EntityType.Entity
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            Entity.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2.EntityType.Entity";
                            };
    
                            return Entity;
                        })();
    
                        return EntityType;
                    })();
    
                    v2.ListEntityTypesRequest = (function() {
    
                        /**
                         * Properties of a ListEntityTypesRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IListEntityTypesRequest
                         * @property {string|null} [parent] ListEntityTypesRequest parent
                         * @property {string|null} [languageCode] ListEntityTypesRequest languageCode
                         * @property {number|null} [pageSize] ListEntityTypesRequest pageSize
                         * @property {string|null} [pageToken] ListEntityTypesRequest pageToken
                         */
    
                        /**
                         * Constructs a new ListEntityTypesRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a ListEntityTypesRequest.
                         * @implements IListEntityTypesRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IListEntityTypesRequest=} [properties] Properties to set
                         */
                        function ListEntityTypesRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListEntityTypesRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.ListEntityTypesRequest
                         * @instance
                         */
                        ListEntityTypesRequest.prototype.parent = "";
    
                        /**
                         * ListEntityTypesRequest languageCode.
                         * @member {string} languageCode
                         * @memberof google.cloud.dialogflow.v2.ListEntityTypesRequest
                         * @instance
                         */
                        ListEntityTypesRequest.prototype.languageCode = "";
    
                        /**
                         * ListEntityTypesRequest pageSize.
                         * @member {number} pageSize
                         * @memberof google.cloud.dialogflow.v2.ListEntityTypesRequest
                         * @instance
                         */
                        ListEntityTypesRequest.prototype.pageSize = 0;
    
                        /**
                         * ListEntityTypesRequest pageToken.
                         * @member {string} pageToken
                         * @memberof google.cloud.dialogflow.v2.ListEntityTypesRequest
                         * @instance
                         */
                        ListEntityTypesRequest.prototype.pageToken = "";
    
                        /**
                         * Creates a new ListEntityTypesRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ListEntityTypesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListEntityTypesRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ListEntityTypesRequest} ListEntityTypesRequest instance
                         */
                        ListEntityTypesRequest.create = function create(properties) {
                            return new ListEntityTypesRequest(properties);
                        };
    
                        /**
                         * Encodes the specified ListEntityTypesRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.ListEntityTypesRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ListEntityTypesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListEntityTypesRequest} message ListEntityTypesRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListEntityTypesRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.languageCode != null && Object.hasOwnProperty.call(message, "languageCode"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.languageCode);
                            if (message.pageSize != null && Object.hasOwnProperty.call(message, "pageSize"))
                                writer.uint32(/* id 3, wireType 0 =*/24).int32(message.pageSize);
                            if (message.pageToken != null && Object.hasOwnProperty.call(message, "pageToken"))
                                writer.uint32(/* id 4, wireType 2 =*/34).string(message.pageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListEntityTypesRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ListEntityTypesRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListEntityTypesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListEntityTypesRequest} message ListEntityTypesRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListEntityTypesRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListEntityTypesRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ListEntityTypesRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ListEntityTypesRequest} ListEntityTypesRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListEntityTypesRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ListEntityTypesRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.languageCode = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.pageSize = reader.int32();
                                        break;
                                    }
                                case 4: {
                                        message.pageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListEntityTypesRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListEntityTypesRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ListEntityTypesRequest} ListEntityTypesRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListEntityTypesRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListEntityTypesRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ListEntityTypesRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListEntityTypesRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                if (!$util.isString(message.languageCode))
                                    return "languageCode: string expected";
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                if (!$util.isInteger(message.pageSize))
                                    return "pageSize: integer expected";
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                if (!$util.isString(message.pageToken))
                                    return "pageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListEntityTypesRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ListEntityTypesRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ListEntityTypesRequest} ListEntityTypesRequest
                         */
                        ListEntityTypesRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ListEntityTypesRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ListEntityTypesRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.languageCode != null)
                                message.languageCode = String(object.languageCode);
                            if (object.pageSize != null)
                                message.pageSize = object.pageSize | 0;
                            if (object.pageToken != null)
                                message.pageToken = String(object.pageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListEntityTypesRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ListEntityTypesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ListEntityTypesRequest} message ListEntityTypesRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListEntityTypesRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.languageCode = "";
                                object.pageSize = 0;
                                object.pageToken = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                object.languageCode = message.languageCode;
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                object.pageSize = message.pageSize;
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                object.pageToken = message.pageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListEntityTypesRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ListEntityTypesRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListEntityTypesRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListEntityTypesRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ListEntityTypesRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListEntityTypesRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ListEntityTypesRequest";
                        };
    
                        return ListEntityTypesRequest;
                    })();
    
                    v2.ListEntityTypesResponse = (function() {
    
                        /**
                         * Properties of a ListEntityTypesResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IListEntityTypesResponse
                         * @property {Array.<google.cloud.dialogflow.v2.IEntityType>|null} [entityTypes] ListEntityTypesResponse entityTypes
                         * @property {string|null} [nextPageToken] ListEntityTypesResponse nextPageToken
                         */
    
                        /**
                         * Constructs a new ListEntityTypesResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a ListEntityTypesResponse.
                         * @implements IListEntityTypesResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IListEntityTypesResponse=} [properties] Properties to set
                         */
                        function ListEntityTypesResponse(properties) {
                            this.entityTypes = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListEntityTypesResponse entityTypes.
                         * @member {Array.<google.cloud.dialogflow.v2.IEntityType>} entityTypes
                         * @memberof google.cloud.dialogflow.v2.ListEntityTypesResponse
                         * @instance
                         */
                        ListEntityTypesResponse.prototype.entityTypes = $util.emptyArray;
    
                        /**
                         * ListEntityTypesResponse nextPageToken.
                         * @member {string} nextPageToken
                         * @memberof google.cloud.dialogflow.v2.ListEntityTypesResponse
                         * @instance
                         */
                        ListEntityTypesResponse.prototype.nextPageToken = "";
    
                        /**
                         * Creates a new ListEntityTypesResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ListEntityTypesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListEntityTypesResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ListEntityTypesResponse} ListEntityTypesResponse instance
                         */
                        ListEntityTypesResponse.create = function create(properties) {
                            return new ListEntityTypesResponse(properties);
                        };
    
                        /**
                         * Encodes the specified ListEntityTypesResponse message. Does not implicitly {@link google.cloud.dialogflow.v2.ListEntityTypesResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ListEntityTypesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListEntityTypesResponse} message ListEntityTypesResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListEntityTypesResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.entityTypes != null && message.entityTypes.length)
                                for (var i = 0; i < message.entityTypes.length; ++i)
                                    $root.google.cloud.dialogflow.v2.EntityType.encode(message.entityTypes[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.nextPageToken != null && Object.hasOwnProperty.call(message, "nextPageToken"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.nextPageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListEntityTypesResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ListEntityTypesResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListEntityTypesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListEntityTypesResponse} message ListEntityTypesResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListEntityTypesResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListEntityTypesResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ListEntityTypesResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ListEntityTypesResponse} ListEntityTypesResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListEntityTypesResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ListEntityTypesResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.entityTypes && message.entityTypes.length))
                                            message.entityTypes = [];
                                        message.entityTypes.push($root.google.cloud.dialogflow.v2.EntityType.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 2: {
                                        message.nextPageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListEntityTypesResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListEntityTypesResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ListEntityTypesResponse} ListEntityTypesResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListEntityTypesResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListEntityTypesResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ListEntityTypesResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListEntityTypesResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.entityTypes != null && message.hasOwnProperty("entityTypes")) {
                                if (!Array.isArray(message.entityTypes))
                                    return "entityTypes: array expected";
                                for (var i = 0; i < message.entityTypes.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.EntityType.verify(message.entityTypes[i]);
                                    if (error)
                                        return "entityTypes." + error;
                                }
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                if (!$util.isString(message.nextPageToken))
                                    return "nextPageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListEntityTypesResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ListEntityTypesResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ListEntityTypesResponse} ListEntityTypesResponse
                         */
                        ListEntityTypesResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ListEntityTypesResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ListEntityTypesResponse();
                            if (object.entityTypes) {
                                if (!Array.isArray(object.entityTypes))
                                    throw TypeError(".google.cloud.dialogflow.v2.ListEntityTypesResponse.entityTypes: array expected");
                                message.entityTypes = [];
                                for (var i = 0; i < object.entityTypes.length; ++i) {
                                    if (typeof object.entityTypes[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.ListEntityTypesResponse.entityTypes: object expected");
                                    message.entityTypes[i] = $root.google.cloud.dialogflow.v2.EntityType.fromObject(object.entityTypes[i]);
                                }
                            }
                            if (object.nextPageToken != null)
                                message.nextPageToken = String(object.nextPageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListEntityTypesResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ListEntityTypesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.ListEntityTypesResponse} message ListEntityTypesResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListEntityTypesResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.entityTypes = [];
                            if (options.defaults)
                                object.nextPageToken = "";
                            if (message.entityTypes && message.entityTypes.length) {
                                object.entityTypes = [];
                                for (var j = 0; j < message.entityTypes.length; ++j)
                                    object.entityTypes[j] = $root.google.cloud.dialogflow.v2.EntityType.toObject(message.entityTypes[j], options);
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                object.nextPageToken = message.nextPageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListEntityTypesResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ListEntityTypesResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListEntityTypesResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListEntityTypesResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ListEntityTypesResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListEntityTypesResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ListEntityTypesResponse";
                        };
    
                        return ListEntityTypesResponse;
                    })();
    
                    v2.GetEntityTypeRequest = (function() {
    
                        /**
                         * Properties of a GetEntityTypeRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IGetEntityTypeRequest
                         * @property {string|null} [name] GetEntityTypeRequest name
                         * @property {string|null} [languageCode] GetEntityTypeRequest languageCode
                         */
    
                        /**
                         * Constructs a new GetEntityTypeRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a GetEntityTypeRequest.
                         * @implements IGetEntityTypeRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IGetEntityTypeRequest=} [properties] Properties to set
                         */
                        function GetEntityTypeRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GetEntityTypeRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2.GetEntityTypeRequest
                         * @instance
                         */
                        GetEntityTypeRequest.prototype.name = "";
    
                        /**
                         * GetEntityTypeRequest languageCode.
                         * @member {string} languageCode
                         * @memberof google.cloud.dialogflow.v2.GetEntityTypeRequest
                         * @instance
                         */
                        GetEntityTypeRequest.prototype.languageCode = "";
    
                        /**
                         * Creates a new GetEntityTypeRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.GetEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetEntityTypeRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.GetEntityTypeRequest} GetEntityTypeRequest instance
                         */
                        GetEntityTypeRequest.create = function create(properties) {
                            return new GetEntityTypeRequest(properties);
                        };
    
                        /**
                         * Encodes the specified GetEntityTypeRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.GetEntityTypeRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.GetEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetEntityTypeRequest} message GetEntityTypeRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetEntityTypeRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            if (message.languageCode != null && Object.hasOwnProperty.call(message, "languageCode"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.languageCode);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GetEntityTypeRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.GetEntityTypeRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GetEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetEntityTypeRequest} message GetEntityTypeRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetEntityTypeRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GetEntityTypeRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.GetEntityTypeRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.GetEntityTypeRequest} GetEntityTypeRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetEntityTypeRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.GetEntityTypeRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.languageCode = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GetEntityTypeRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GetEntityTypeRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.GetEntityTypeRequest} GetEntityTypeRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetEntityTypeRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GetEntityTypeRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.GetEntityTypeRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GetEntityTypeRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                if (!$util.isString(message.languageCode))
                                    return "languageCode: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a GetEntityTypeRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.GetEntityTypeRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.GetEntityTypeRequest} GetEntityTypeRequest
                         */
                        GetEntityTypeRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.GetEntityTypeRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.GetEntityTypeRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            if (object.languageCode != null)
                                message.languageCode = String(object.languageCode);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GetEntityTypeRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.GetEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.GetEntityTypeRequest} message GetEntityTypeRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GetEntityTypeRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.name = "";
                                object.languageCode = "";
                            }
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                object.languageCode = message.languageCode;
                            return object;
                        };
    
                        /**
                         * Converts this GetEntityTypeRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.GetEntityTypeRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GetEntityTypeRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GetEntityTypeRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.GetEntityTypeRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GetEntityTypeRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.GetEntityTypeRequest";
                        };
    
                        return GetEntityTypeRequest;
                    })();
    
                    v2.CreateEntityTypeRequest = (function() {
    
                        /**
                         * Properties of a CreateEntityTypeRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ICreateEntityTypeRequest
                         * @property {string|null} [parent] CreateEntityTypeRequest parent
                         * @property {google.cloud.dialogflow.v2.IEntityType|null} [entityType] CreateEntityTypeRequest entityType
                         * @property {string|null} [languageCode] CreateEntityTypeRequest languageCode
                         */
    
                        /**
                         * Constructs a new CreateEntityTypeRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a CreateEntityTypeRequest.
                         * @implements ICreateEntityTypeRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ICreateEntityTypeRequest=} [properties] Properties to set
                         */
                        function CreateEntityTypeRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * CreateEntityTypeRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.CreateEntityTypeRequest
                         * @instance
                         */
                        CreateEntityTypeRequest.prototype.parent = "";
    
                        /**
                         * CreateEntityTypeRequest entityType.
                         * @member {google.cloud.dialogflow.v2.IEntityType|null|undefined} entityType
                         * @memberof google.cloud.dialogflow.v2.CreateEntityTypeRequest
                         * @instance
                         */
                        CreateEntityTypeRequest.prototype.entityType = null;
    
                        /**
                         * CreateEntityTypeRequest languageCode.
                         * @member {string} languageCode
                         * @memberof google.cloud.dialogflow.v2.CreateEntityTypeRequest
                         * @instance
                         */
                        CreateEntityTypeRequest.prototype.languageCode = "";
    
                        /**
                         * Creates a new CreateEntityTypeRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.CreateEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICreateEntityTypeRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.CreateEntityTypeRequest} CreateEntityTypeRequest instance
                         */
                        CreateEntityTypeRequest.create = function create(properties) {
                            return new CreateEntityTypeRequest(properties);
                        };
    
                        /**
                         * Encodes the specified CreateEntityTypeRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.CreateEntityTypeRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.CreateEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICreateEntityTypeRequest} message CreateEntityTypeRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateEntityTypeRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.entityType != null && Object.hasOwnProperty.call(message, "entityType"))
                                $root.google.cloud.dialogflow.v2.EntityType.encode(message.entityType, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.languageCode != null && Object.hasOwnProperty.call(message, "languageCode"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.languageCode);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified CreateEntityTypeRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.CreateEntityTypeRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.CreateEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICreateEntityTypeRequest} message CreateEntityTypeRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateEntityTypeRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a CreateEntityTypeRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.CreateEntityTypeRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.CreateEntityTypeRequest} CreateEntityTypeRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateEntityTypeRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.CreateEntityTypeRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.entityType = $root.google.cloud.dialogflow.v2.EntityType.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 3: {
                                        message.languageCode = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a CreateEntityTypeRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.CreateEntityTypeRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.CreateEntityTypeRequest} CreateEntityTypeRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateEntityTypeRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a CreateEntityTypeRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.CreateEntityTypeRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        CreateEntityTypeRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.entityType != null && message.hasOwnProperty("entityType")) {
                                var error = $root.google.cloud.dialogflow.v2.EntityType.verify(message.entityType);
                                if (error)
                                    return "entityType." + error;
                            }
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                if (!$util.isString(message.languageCode))
                                    return "languageCode: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a CreateEntityTypeRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.CreateEntityTypeRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.CreateEntityTypeRequest} CreateEntityTypeRequest
                         */
                        CreateEntityTypeRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.CreateEntityTypeRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.CreateEntityTypeRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.entityType != null) {
                                if (typeof object.entityType !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.CreateEntityTypeRequest.entityType: object expected");
                                message.entityType = $root.google.cloud.dialogflow.v2.EntityType.fromObject(object.entityType);
                            }
                            if (object.languageCode != null)
                                message.languageCode = String(object.languageCode);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a CreateEntityTypeRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.CreateEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.CreateEntityTypeRequest} message CreateEntityTypeRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        CreateEntityTypeRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.entityType = null;
                                object.languageCode = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.entityType != null && message.hasOwnProperty("entityType"))
                                object.entityType = $root.google.cloud.dialogflow.v2.EntityType.toObject(message.entityType, options);
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                object.languageCode = message.languageCode;
                            return object;
                        };
    
                        /**
                         * Converts this CreateEntityTypeRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.CreateEntityTypeRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        CreateEntityTypeRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for CreateEntityTypeRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.CreateEntityTypeRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        CreateEntityTypeRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.CreateEntityTypeRequest";
                        };
    
                        return CreateEntityTypeRequest;
                    })();
    
                    v2.UpdateEntityTypeRequest = (function() {
    
                        /**
                         * Properties of an UpdateEntityTypeRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IUpdateEntityTypeRequest
                         * @property {google.cloud.dialogflow.v2.IEntityType|null} [entityType] UpdateEntityTypeRequest entityType
                         * @property {string|null} [languageCode] UpdateEntityTypeRequest languageCode
                         * @property {google.protobuf.IFieldMask|null} [updateMask] UpdateEntityTypeRequest updateMask
                         */
    
                        /**
                         * Constructs a new UpdateEntityTypeRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an UpdateEntityTypeRequest.
                         * @implements IUpdateEntityTypeRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IUpdateEntityTypeRequest=} [properties] Properties to set
                         */
                        function UpdateEntityTypeRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * UpdateEntityTypeRequest entityType.
                         * @member {google.cloud.dialogflow.v2.IEntityType|null|undefined} entityType
                         * @memberof google.cloud.dialogflow.v2.UpdateEntityTypeRequest
                         * @instance
                         */
                        UpdateEntityTypeRequest.prototype.entityType = null;
    
                        /**
                         * UpdateEntityTypeRequest languageCode.
                         * @member {string} languageCode
                         * @memberof google.cloud.dialogflow.v2.UpdateEntityTypeRequest
                         * @instance
                         */
                        UpdateEntityTypeRequest.prototype.languageCode = "";
    
                        /**
                         * UpdateEntityTypeRequest updateMask.
                         * @member {google.protobuf.IFieldMask|null|undefined} updateMask
                         * @memberof google.cloud.dialogflow.v2.UpdateEntityTypeRequest
                         * @instance
                         */
                        UpdateEntityTypeRequest.prototype.updateMask = null;
    
                        /**
                         * Creates a new UpdateEntityTypeRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.UpdateEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IUpdateEntityTypeRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.UpdateEntityTypeRequest} UpdateEntityTypeRequest instance
                         */
                        UpdateEntityTypeRequest.create = function create(properties) {
                            return new UpdateEntityTypeRequest(properties);
                        };
    
                        /**
                         * Encodes the specified UpdateEntityTypeRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.UpdateEntityTypeRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.UpdateEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IUpdateEntityTypeRequest} message UpdateEntityTypeRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UpdateEntityTypeRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.entityType != null && Object.hasOwnProperty.call(message, "entityType"))
                                $root.google.cloud.dialogflow.v2.EntityType.encode(message.entityType, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.languageCode != null && Object.hasOwnProperty.call(message, "languageCode"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.languageCode);
                            if (message.updateMask != null && Object.hasOwnProperty.call(message, "updateMask"))
                                $root.google.protobuf.FieldMask.encode(message.updateMask, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified UpdateEntityTypeRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.UpdateEntityTypeRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.UpdateEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IUpdateEntityTypeRequest} message UpdateEntityTypeRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UpdateEntityTypeRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an UpdateEntityTypeRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.UpdateEntityTypeRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.UpdateEntityTypeRequest} UpdateEntityTypeRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UpdateEntityTypeRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.UpdateEntityTypeRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.entityType = $root.google.cloud.dialogflow.v2.EntityType.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.languageCode = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.updateMask = $root.google.protobuf.FieldMask.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an UpdateEntityTypeRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.UpdateEntityTypeRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.UpdateEntityTypeRequest} UpdateEntityTypeRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UpdateEntityTypeRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an UpdateEntityTypeRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.UpdateEntityTypeRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        UpdateEntityTypeRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.entityType != null && message.hasOwnProperty("entityType")) {
                                var error = $root.google.cloud.dialogflow.v2.EntityType.verify(message.entityType);
                                if (error)
                                    return "entityType." + error;
                            }
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                if (!$util.isString(message.languageCode))
                                    return "languageCode: string expected";
                            if (message.updateMask != null && message.hasOwnProperty("updateMask")) {
                                var error = $root.google.protobuf.FieldMask.verify(message.updateMask);
                                if (error)
                                    return "updateMask." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates an UpdateEntityTypeRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.UpdateEntityTypeRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.UpdateEntityTypeRequest} UpdateEntityTypeRequest
                         */
                        UpdateEntityTypeRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.UpdateEntityTypeRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.UpdateEntityTypeRequest();
                            if (object.entityType != null) {
                                if (typeof object.entityType !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.UpdateEntityTypeRequest.entityType: object expected");
                                message.entityType = $root.google.cloud.dialogflow.v2.EntityType.fromObject(object.entityType);
                            }
                            if (object.languageCode != null)
                                message.languageCode = String(object.languageCode);
                            if (object.updateMask != null) {
                                if (typeof object.updateMask !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.UpdateEntityTypeRequest.updateMask: object expected");
                                message.updateMask = $root.google.protobuf.FieldMask.fromObject(object.updateMask);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an UpdateEntityTypeRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.UpdateEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.UpdateEntityTypeRequest} message UpdateEntityTypeRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        UpdateEntityTypeRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.entityType = null;
                                object.languageCode = "";
                                object.updateMask = null;
                            }
                            if (message.entityType != null && message.hasOwnProperty("entityType"))
                                object.entityType = $root.google.cloud.dialogflow.v2.EntityType.toObject(message.entityType, options);
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                object.languageCode = message.languageCode;
                            if (message.updateMask != null && message.hasOwnProperty("updateMask"))
                                object.updateMask = $root.google.protobuf.FieldMask.toObject(message.updateMask, options);
                            return object;
                        };
    
                        /**
                         * Converts this UpdateEntityTypeRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.UpdateEntityTypeRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        UpdateEntityTypeRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for UpdateEntityTypeRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.UpdateEntityTypeRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        UpdateEntityTypeRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.UpdateEntityTypeRequest";
                        };
    
                        return UpdateEntityTypeRequest;
                    })();
    
                    v2.DeleteEntityTypeRequest = (function() {
    
                        /**
                         * Properties of a DeleteEntityTypeRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IDeleteEntityTypeRequest
                         * @property {string|null} [name] DeleteEntityTypeRequest name
                         */
    
                        /**
                         * Constructs a new DeleteEntityTypeRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a DeleteEntityTypeRequest.
                         * @implements IDeleteEntityTypeRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IDeleteEntityTypeRequest=} [properties] Properties to set
                         */
                        function DeleteEntityTypeRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * DeleteEntityTypeRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2.DeleteEntityTypeRequest
                         * @instance
                         */
                        DeleteEntityTypeRequest.prototype.name = "";
    
                        /**
                         * Creates a new DeleteEntityTypeRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.DeleteEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDeleteEntityTypeRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.DeleteEntityTypeRequest} DeleteEntityTypeRequest instance
                         */
                        DeleteEntityTypeRequest.create = function create(properties) {
                            return new DeleteEntityTypeRequest(properties);
                        };
    
                        /**
                         * Encodes the specified DeleteEntityTypeRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.DeleteEntityTypeRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.DeleteEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDeleteEntityTypeRequest} message DeleteEntityTypeRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteEntityTypeRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified DeleteEntityTypeRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.DeleteEntityTypeRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.DeleteEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDeleteEntityTypeRequest} message DeleteEntityTypeRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteEntityTypeRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a DeleteEntityTypeRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.DeleteEntityTypeRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.DeleteEntityTypeRequest} DeleteEntityTypeRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteEntityTypeRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.DeleteEntityTypeRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a DeleteEntityTypeRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.DeleteEntityTypeRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.DeleteEntityTypeRequest} DeleteEntityTypeRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteEntityTypeRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a DeleteEntityTypeRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.DeleteEntityTypeRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        DeleteEntityTypeRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a DeleteEntityTypeRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.DeleteEntityTypeRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.DeleteEntityTypeRequest} DeleteEntityTypeRequest
                         */
                        DeleteEntityTypeRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.DeleteEntityTypeRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.DeleteEntityTypeRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a DeleteEntityTypeRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.DeleteEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.DeleteEntityTypeRequest} message DeleteEntityTypeRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        DeleteEntityTypeRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.name = "";
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            return object;
                        };
    
                        /**
                         * Converts this DeleteEntityTypeRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.DeleteEntityTypeRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        DeleteEntityTypeRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for DeleteEntityTypeRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.DeleteEntityTypeRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        DeleteEntityTypeRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.DeleteEntityTypeRequest";
                        };
    
                        return DeleteEntityTypeRequest;
                    })();
    
                    v2.BatchUpdateEntityTypesRequest = (function() {
    
                        /**
                         * Properties of a BatchUpdateEntityTypesRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IBatchUpdateEntityTypesRequest
                         * @property {string|null} [parent] BatchUpdateEntityTypesRequest parent
                         * @property {string|null} [entityTypeBatchUri] BatchUpdateEntityTypesRequest entityTypeBatchUri
                         * @property {google.cloud.dialogflow.v2.IEntityTypeBatch|null} [entityTypeBatchInline] BatchUpdateEntityTypesRequest entityTypeBatchInline
                         * @property {string|null} [languageCode] BatchUpdateEntityTypesRequest languageCode
                         * @property {google.protobuf.IFieldMask|null} [updateMask] BatchUpdateEntityTypesRequest updateMask
                         */
    
                        /**
                         * Constructs a new BatchUpdateEntityTypesRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a BatchUpdateEntityTypesRequest.
                         * @implements IBatchUpdateEntityTypesRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IBatchUpdateEntityTypesRequest=} [properties] Properties to set
                         */
                        function BatchUpdateEntityTypesRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * BatchUpdateEntityTypesRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateEntityTypesRequest
                         * @instance
                         */
                        BatchUpdateEntityTypesRequest.prototype.parent = "";
    
                        /**
                         * BatchUpdateEntityTypesRequest entityTypeBatchUri.
                         * @member {string|null|undefined} entityTypeBatchUri
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateEntityTypesRequest
                         * @instance
                         */
                        BatchUpdateEntityTypesRequest.prototype.entityTypeBatchUri = null;
    
                        /**
                         * BatchUpdateEntityTypesRequest entityTypeBatchInline.
                         * @member {google.cloud.dialogflow.v2.IEntityTypeBatch|null|undefined} entityTypeBatchInline
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateEntityTypesRequest
                         * @instance
                         */
                        BatchUpdateEntityTypesRequest.prototype.entityTypeBatchInline = null;
    
                        /**
                         * BatchUpdateEntityTypesRequest languageCode.
                         * @member {string} languageCode
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateEntityTypesRequest
                         * @instance
                         */
                        BatchUpdateEntityTypesRequest.prototype.languageCode = "";
    
                        /**
                         * BatchUpdateEntityTypesRequest updateMask.
                         * @member {google.protobuf.IFieldMask|null|undefined} updateMask
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateEntityTypesRequest
                         * @instance
                         */
                        BatchUpdateEntityTypesRequest.prototype.updateMask = null;
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * BatchUpdateEntityTypesRequest entityTypeBatch.
                         * @member {"entityTypeBatchUri"|"entityTypeBatchInline"|undefined} entityTypeBatch
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateEntityTypesRequest
                         * @instance
                         */
                        Object.defineProperty(BatchUpdateEntityTypesRequest.prototype, "entityTypeBatch", {
                            get: $util.oneOfGetter($oneOfFields = ["entityTypeBatchUri", "entityTypeBatchInline"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new BatchUpdateEntityTypesRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateEntityTypesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IBatchUpdateEntityTypesRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.BatchUpdateEntityTypesRequest} BatchUpdateEntityTypesRequest instance
                         */
                        BatchUpdateEntityTypesRequest.create = function create(properties) {
                            return new BatchUpdateEntityTypesRequest(properties);
                        };
    
                        /**
                         * Encodes the specified BatchUpdateEntityTypesRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.BatchUpdateEntityTypesRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateEntityTypesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IBatchUpdateEntityTypesRequest} message BatchUpdateEntityTypesRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        BatchUpdateEntityTypesRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.entityTypeBatchUri != null && Object.hasOwnProperty.call(message, "entityTypeBatchUri"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.entityTypeBatchUri);
                            if (message.entityTypeBatchInline != null && Object.hasOwnProperty.call(message, "entityTypeBatchInline"))
                                $root.google.cloud.dialogflow.v2.EntityTypeBatch.encode(message.entityTypeBatchInline, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            if (message.languageCode != null && Object.hasOwnProperty.call(message, "languageCode"))
                                writer.uint32(/* id 4, wireType 2 =*/34).string(message.languageCode);
                            if (message.updateMask != null && Object.hasOwnProperty.call(message, "updateMask"))
                                $root.google.protobuf.FieldMask.encode(message.updateMask, writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified BatchUpdateEntityTypesRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.BatchUpdateEntityTypesRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateEntityTypesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IBatchUpdateEntityTypesRequest} message BatchUpdateEntityTypesRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        BatchUpdateEntityTypesRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a BatchUpdateEntityTypesRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateEntityTypesRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.BatchUpdateEntityTypesRequest} BatchUpdateEntityTypesRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        BatchUpdateEntityTypesRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.BatchUpdateEntityTypesRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.entityTypeBatchUri = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.entityTypeBatchInline = $root.google.cloud.dialogflow.v2.EntityTypeBatch.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 4: {
                                        message.languageCode = reader.string();
                                        break;
                                    }
                                case 5: {
                                        message.updateMask = $root.google.protobuf.FieldMask.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a BatchUpdateEntityTypesRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateEntityTypesRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.BatchUpdateEntityTypesRequest} BatchUpdateEntityTypesRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        BatchUpdateEntityTypesRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a BatchUpdateEntityTypesRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateEntityTypesRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        BatchUpdateEntityTypesRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.entityTypeBatchUri != null && message.hasOwnProperty("entityTypeBatchUri")) {
                                properties.entityTypeBatch = 1;
                                if (!$util.isString(message.entityTypeBatchUri))
                                    return "entityTypeBatchUri: string expected";
                            }
                            if (message.entityTypeBatchInline != null && message.hasOwnProperty("entityTypeBatchInline")) {
                                if (properties.entityTypeBatch === 1)
                                    return "entityTypeBatch: multiple values";
                                properties.entityTypeBatch = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2.EntityTypeBatch.verify(message.entityTypeBatchInline);
                                    if (error)
                                        return "entityTypeBatchInline." + error;
                                }
                            }
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                if (!$util.isString(message.languageCode))
                                    return "languageCode: string expected";
                            if (message.updateMask != null && message.hasOwnProperty("updateMask")) {
                                var error = $root.google.protobuf.FieldMask.verify(message.updateMask);
                                if (error)
                                    return "updateMask." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a BatchUpdateEntityTypesRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateEntityTypesRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.BatchUpdateEntityTypesRequest} BatchUpdateEntityTypesRequest
                         */
                        BatchUpdateEntityTypesRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.BatchUpdateEntityTypesRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.BatchUpdateEntityTypesRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.entityTypeBatchUri != null)
                                message.entityTypeBatchUri = String(object.entityTypeBatchUri);
                            if (object.entityTypeBatchInline != null) {
                                if (typeof object.entityTypeBatchInline !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.BatchUpdateEntityTypesRequest.entityTypeBatchInline: object expected");
                                message.entityTypeBatchInline = $root.google.cloud.dialogflow.v2.EntityTypeBatch.fromObject(object.entityTypeBatchInline);
                            }
                            if (object.languageCode != null)
                                message.languageCode = String(object.languageCode);
                            if (object.updateMask != null) {
                                if (typeof object.updateMask !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.BatchUpdateEntityTypesRequest.updateMask: object expected");
                                message.updateMask = $root.google.protobuf.FieldMask.fromObject(object.updateMask);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a BatchUpdateEntityTypesRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateEntityTypesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.BatchUpdateEntityTypesRequest} message BatchUpdateEntityTypesRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        BatchUpdateEntityTypesRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.languageCode = "";
                                object.updateMask = null;
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.entityTypeBatchUri != null && message.hasOwnProperty("entityTypeBatchUri")) {
                                object.entityTypeBatchUri = message.entityTypeBatchUri;
                                if (options.oneofs)
                                    object.entityTypeBatch = "entityTypeBatchUri";
                            }
                            if (message.entityTypeBatchInline != null && message.hasOwnProperty("entityTypeBatchInline")) {
                                object.entityTypeBatchInline = $root.google.cloud.dialogflow.v2.EntityTypeBatch.toObject(message.entityTypeBatchInline, options);
                                if (options.oneofs)
                                    object.entityTypeBatch = "entityTypeBatchInline";
                            }
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                object.languageCode = message.languageCode;
                            if (message.updateMask != null && message.hasOwnProperty("updateMask"))
                                object.updateMask = $root.google.protobuf.FieldMask.toObject(message.updateMask, options);
                            return object;
                        };
    
                        /**
                         * Converts this BatchUpdateEntityTypesRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateEntityTypesRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        BatchUpdateEntityTypesRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for BatchUpdateEntityTypesRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateEntityTypesRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        BatchUpdateEntityTypesRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.BatchUpdateEntityTypesRequest";
                        };
    
                        return BatchUpdateEntityTypesRequest;
                    })();
    
                    v2.BatchUpdateEntityTypesResponse = (function() {
    
                        /**
                         * Properties of a BatchUpdateEntityTypesResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IBatchUpdateEntityTypesResponse
                         * @property {Array.<google.cloud.dialogflow.v2.IEntityType>|null} [entityTypes] BatchUpdateEntityTypesResponse entityTypes
                         */
    
                        /**
                         * Constructs a new BatchUpdateEntityTypesResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a BatchUpdateEntityTypesResponse.
                         * @implements IBatchUpdateEntityTypesResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IBatchUpdateEntityTypesResponse=} [properties] Properties to set
                         */
                        function BatchUpdateEntityTypesResponse(properties) {
                            this.entityTypes = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * BatchUpdateEntityTypesResponse entityTypes.
                         * @member {Array.<google.cloud.dialogflow.v2.IEntityType>} entityTypes
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateEntityTypesResponse
                         * @instance
                         */
                        BatchUpdateEntityTypesResponse.prototype.entityTypes = $util.emptyArray;
    
                        /**
                         * Creates a new BatchUpdateEntityTypesResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateEntityTypesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IBatchUpdateEntityTypesResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.BatchUpdateEntityTypesResponse} BatchUpdateEntityTypesResponse instance
                         */
                        BatchUpdateEntityTypesResponse.create = function create(properties) {
                            return new BatchUpdateEntityTypesResponse(properties);
                        };
    
                        /**
                         * Encodes the specified BatchUpdateEntityTypesResponse message. Does not implicitly {@link google.cloud.dialogflow.v2.BatchUpdateEntityTypesResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateEntityTypesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IBatchUpdateEntityTypesResponse} message BatchUpdateEntityTypesResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        BatchUpdateEntityTypesResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.entityTypes != null && message.entityTypes.length)
                                for (var i = 0; i < message.entityTypes.length; ++i)
                                    $root.google.cloud.dialogflow.v2.EntityType.encode(message.entityTypes[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified BatchUpdateEntityTypesResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.BatchUpdateEntityTypesResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateEntityTypesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IBatchUpdateEntityTypesResponse} message BatchUpdateEntityTypesResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        BatchUpdateEntityTypesResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a BatchUpdateEntityTypesResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateEntityTypesResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.BatchUpdateEntityTypesResponse} BatchUpdateEntityTypesResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        BatchUpdateEntityTypesResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.BatchUpdateEntityTypesResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.entityTypes && message.entityTypes.length))
                                            message.entityTypes = [];
                                        message.entityTypes.push($root.google.cloud.dialogflow.v2.EntityType.decode(reader, reader.uint32()));
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a BatchUpdateEntityTypesResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateEntityTypesResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.BatchUpdateEntityTypesResponse} BatchUpdateEntityTypesResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        BatchUpdateEntityTypesResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a BatchUpdateEntityTypesResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateEntityTypesResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        BatchUpdateEntityTypesResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.entityTypes != null && message.hasOwnProperty("entityTypes")) {
                                if (!Array.isArray(message.entityTypes))
                                    return "entityTypes: array expected";
                                for (var i = 0; i < message.entityTypes.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.EntityType.verify(message.entityTypes[i]);
                                    if (error)
                                        return "entityTypes." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates a BatchUpdateEntityTypesResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateEntityTypesResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.BatchUpdateEntityTypesResponse} BatchUpdateEntityTypesResponse
                         */
                        BatchUpdateEntityTypesResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.BatchUpdateEntityTypesResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.BatchUpdateEntityTypesResponse();
                            if (object.entityTypes) {
                                if (!Array.isArray(object.entityTypes))
                                    throw TypeError(".google.cloud.dialogflow.v2.BatchUpdateEntityTypesResponse.entityTypes: array expected");
                                message.entityTypes = [];
                                for (var i = 0; i < object.entityTypes.length; ++i) {
                                    if (typeof object.entityTypes[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.BatchUpdateEntityTypesResponse.entityTypes: object expected");
                                    message.entityTypes[i] = $root.google.cloud.dialogflow.v2.EntityType.fromObject(object.entityTypes[i]);
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a BatchUpdateEntityTypesResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateEntityTypesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.BatchUpdateEntityTypesResponse} message BatchUpdateEntityTypesResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        BatchUpdateEntityTypesResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.entityTypes = [];
                            if (message.entityTypes && message.entityTypes.length) {
                                object.entityTypes = [];
                                for (var j = 0; j < message.entityTypes.length; ++j)
                                    object.entityTypes[j] = $root.google.cloud.dialogflow.v2.EntityType.toObject(message.entityTypes[j], options);
                            }
                            return object;
                        };
    
                        /**
                         * Converts this BatchUpdateEntityTypesResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateEntityTypesResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        BatchUpdateEntityTypesResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for BatchUpdateEntityTypesResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateEntityTypesResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        BatchUpdateEntityTypesResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.BatchUpdateEntityTypesResponse";
                        };
    
                        return BatchUpdateEntityTypesResponse;
                    })();
    
                    v2.BatchDeleteEntityTypesRequest = (function() {
    
                        /**
                         * Properties of a BatchDeleteEntityTypesRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IBatchDeleteEntityTypesRequest
                         * @property {string|null} [parent] BatchDeleteEntityTypesRequest parent
                         * @property {Array.<string>|null} [entityTypeNames] BatchDeleteEntityTypesRequest entityTypeNames
                         */
    
                        /**
                         * Constructs a new BatchDeleteEntityTypesRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a BatchDeleteEntityTypesRequest.
                         * @implements IBatchDeleteEntityTypesRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IBatchDeleteEntityTypesRequest=} [properties] Properties to set
                         */
                        function BatchDeleteEntityTypesRequest(properties) {
                            this.entityTypeNames = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * BatchDeleteEntityTypesRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.BatchDeleteEntityTypesRequest
                         * @instance
                         */
                        BatchDeleteEntityTypesRequest.prototype.parent = "";
    
                        /**
                         * BatchDeleteEntityTypesRequest entityTypeNames.
                         * @member {Array.<string>} entityTypeNames
                         * @memberof google.cloud.dialogflow.v2.BatchDeleteEntityTypesRequest
                         * @instance
                         */
                        BatchDeleteEntityTypesRequest.prototype.entityTypeNames = $util.emptyArray;
    
                        /**
                         * Creates a new BatchDeleteEntityTypesRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.BatchDeleteEntityTypesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IBatchDeleteEntityTypesRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.BatchDeleteEntityTypesRequest} BatchDeleteEntityTypesRequest instance
                         */
                        BatchDeleteEntityTypesRequest.create = function create(properties) {
                            return new BatchDeleteEntityTypesRequest(properties);
                        };
    
                        /**
                         * Encodes the specified BatchDeleteEntityTypesRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.BatchDeleteEntityTypesRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.BatchDeleteEntityTypesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IBatchDeleteEntityTypesRequest} message BatchDeleteEntityTypesRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        BatchDeleteEntityTypesRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.entityTypeNames != null && message.entityTypeNames.length)
                                for (var i = 0; i < message.entityTypeNames.length; ++i)
                                    writer.uint32(/* id 2, wireType 2 =*/18).string(message.entityTypeNames[i]);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified BatchDeleteEntityTypesRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.BatchDeleteEntityTypesRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.BatchDeleteEntityTypesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IBatchDeleteEntityTypesRequest} message BatchDeleteEntityTypesRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        BatchDeleteEntityTypesRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a BatchDeleteEntityTypesRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.BatchDeleteEntityTypesRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.BatchDeleteEntityTypesRequest} BatchDeleteEntityTypesRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        BatchDeleteEntityTypesRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.BatchDeleteEntityTypesRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        if (!(message.entityTypeNames && message.entityTypeNames.length))
                                            message.entityTypeNames = [];
                                        message.entityTypeNames.push(reader.string());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a BatchDeleteEntityTypesRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.BatchDeleteEntityTypesRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.BatchDeleteEntityTypesRequest} BatchDeleteEntityTypesRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        BatchDeleteEntityTypesRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a BatchDeleteEntityTypesRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.BatchDeleteEntityTypesRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        BatchDeleteEntityTypesRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.entityTypeNames != null && message.hasOwnProperty("entityTypeNames")) {
                                if (!Array.isArray(message.entityTypeNames))
                                    return "entityTypeNames: array expected";
                                for (var i = 0; i < message.entityTypeNames.length; ++i)
                                    if (!$util.isString(message.entityTypeNames[i]))
                                        return "entityTypeNames: string[] expected";
                            }
                            return null;
                        };
    
                        /**
                         * Creates a BatchDeleteEntityTypesRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.BatchDeleteEntityTypesRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.BatchDeleteEntityTypesRequest} BatchDeleteEntityTypesRequest
                         */
                        BatchDeleteEntityTypesRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.BatchDeleteEntityTypesRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.BatchDeleteEntityTypesRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.entityTypeNames) {
                                if (!Array.isArray(object.entityTypeNames))
                                    throw TypeError(".google.cloud.dialogflow.v2.BatchDeleteEntityTypesRequest.entityTypeNames: array expected");
                                message.entityTypeNames = [];
                                for (var i = 0; i < object.entityTypeNames.length; ++i)
                                    message.entityTypeNames[i] = String(object.entityTypeNames[i]);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a BatchDeleteEntityTypesRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.BatchDeleteEntityTypesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.BatchDeleteEntityTypesRequest} message BatchDeleteEntityTypesRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        BatchDeleteEntityTypesRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.entityTypeNames = [];
                            if (options.defaults)
                                object.parent = "";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.entityTypeNames && message.entityTypeNames.length) {
                                object.entityTypeNames = [];
                                for (var j = 0; j < message.entityTypeNames.length; ++j)
                                    object.entityTypeNames[j] = message.entityTypeNames[j];
                            }
                            return object;
                        };
    
                        /**
                         * Converts this BatchDeleteEntityTypesRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.BatchDeleteEntityTypesRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        BatchDeleteEntityTypesRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for BatchDeleteEntityTypesRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.BatchDeleteEntityTypesRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        BatchDeleteEntityTypesRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.BatchDeleteEntityTypesRequest";
                        };
    
                        return BatchDeleteEntityTypesRequest;
                    })();
    
                    v2.BatchCreateEntitiesRequest = (function() {
    
                        /**
                         * Properties of a BatchCreateEntitiesRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IBatchCreateEntitiesRequest
                         * @property {string|null} [parent] BatchCreateEntitiesRequest parent
                         * @property {Array.<google.cloud.dialogflow.v2.EntityType.IEntity>|null} [entities] BatchCreateEntitiesRequest entities
                         * @property {string|null} [languageCode] BatchCreateEntitiesRequest languageCode
                         */
    
                        /**
                         * Constructs a new BatchCreateEntitiesRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a BatchCreateEntitiesRequest.
                         * @implements IBatchCreateEntitiesRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IBatchCreateEntitiesRequest=} [properties] Properties to set
                         */
                        function BatchCreateEntitiesRequest(properties) {
                            this.entities = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * BatchCreateEntitiesRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.BatchCreateEntitiesRequest
                         * @instance
                         */
                        BatchCreateEntitiesRequest.prototype.parent = "";
    
                        /**
                         * BatchCreateEntitiesRequest entities.
                         * @member {Array.<google.cloud.dialogflow.v2.EntityType.IEntity>} entities
                         * @memberof google.cloud.dialogflow.v2.BatchCreateEntitiesRequest
                         * @instance
                         */
                        BatchCreateEntitiesRequest.prototype.entities = $util.emptyArray;
    
                        /**
                         * BatchCreateEntitiesRequest languageCode.
                         * @member {string} languageCode
                         * @memberof google.cloud.dialogflow.v2.BatchCreateEntitiesRequest
                         * @instance
                         */
                        BatchCreateEntitiesRequest.prototype.languageCode = "";
    
                        /**
                         * Creates a new BatchCreateEntitiesRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.BatchCreateEntitiesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IBatchCreateEntitiesRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.BatchCreateEntitiesRequest} BatchCreateEntitiesRequest instance
                         */
                        BatchCreateEntitiesRequest.create = function create(properties) {
                            return new BatchCreateEntitiesRequest(properties);
                        };
    
                        /**
                         * Encodes the specified BatchCreateEntitiesRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.BatchCreateEntitiesRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.BatchCreateEntitiesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IBatchCreateEntitiesRequest} message BatchCreateEntitiesRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        BatchCreateEntitiesRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.entities != null && message.entities.length)
                                for (var i = 0; i < message.entities.length; ++i)
                                    $root.google.cloud.dialogflow.v2.EntityType.Entity.encode(message.entities[i], writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.languageCode != null && Object.hasOwnProperty.call(message, "languageCode"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.languageCode);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified BatchCreateEntitiesRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.BatchCreateEntitiesRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.BatchCreateEntitiesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IBatchCreateEntitiesRequest} message BatchCreateEntitiesRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        BatchCreateEntitiesRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a BatchCreateEntitiesRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.BatchCreateEntitiesRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.BatchCreateEntitiesRequest} BatchCreateEntitiesRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        BatchCreateEntitiesRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.BatchCreateEntitiesRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        if (!(message.entities && message.entities.length))
                                            message.entities = [];
                                        message.entities.push($root.google.cloud.dialogflow.v2.EntityType.Entity.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 3: {
                                        message.languageCode = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a BatchCreateEntitiesRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.BatchCreateEntitiesRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.BatchCreateEntitiesRequest} BatchCreateEntitiesRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        BatchCreateEntitiesRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a BatchCreateEntitiesRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.BatchCreateEntitiesRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        BatchCreateEntitiesRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.entities != null && message.hasOwnProperty("entities")) {
                                if (!Array.isArray(message.entities))
                                    return "entities: array expected";
                                for (var i = 0; i < message.entities.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.EntityType.Entity.verify(message.entities[i]);
                                    if (error)
                                        return "entities." + error;
                                }
                            }
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                if (!$util.isString(message.languageCode))
                                    return "languageCode: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a BatchCreateEntitiesRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.BatchCreateEntitiesRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.BatchCreateEntitiesRequest} BatchCreateEntitiesRequest
                         */
                        BatchCreateEntitiesRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.BatchCreateEntitiesRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.BatchCreateEntitiesRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.entities) {
                                if (!Array.isArray(object.entities))
                                    throw TypeError(".google.cloud.dialogflow.v2.BatchCreateEntitiesRequest.entities: array expected");
                                message.entities = [];
                                for (var i = 0; i < object.entities.length; ++i) {
                                    if (typeof object.entities[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.BatchCreateEntitiesRequest.entities: object expected");
                                    message.entities[i] = $root.google.cloud.dialogflow.v2.EntityType.Entity.fromObject(object.entities[i]);
                                }
                            }
                            if (object.languageCode != null)
                                message.languageCode = String(object.languageCode);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a BatchCreateEntitiesRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.BatchCreateEntitiesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.BatchCreateEntitiesRequest} message BatchCreateEntitiesRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        BatchCreateEntitiesRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.entities = [];
                            if (options.defaults) {
                                object.parent = "";
                                object.languageCode = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.entities && message.entities.length) {
                                object.entities = [];
                                for (var j = 0; j < message.entities.length; ++j)
                                    object.entities[j] = $root.google.cloud.dialogflow.v2.EntityType.Entity.toObject(message.entities[j], options);
                            }
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                object.languageCode = message.languageCode;
                            return object;
                        };
    
                        /**
                         * Converts this BatchCreateEntitiesRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.BatchCreateEntitiesRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        BatchCreateEntitiesRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for BatchCreateEntitiesRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.BatchCreateEntitiesRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        BatchCreateEntitiesRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.BatchCreateEntitiesRequest";
                        };
    
                        return BatchCreateEntitiesRequest;
                    })();
    
                    v2.BatchUpdateEntitiesRequest = (function() {
    
                        /**
                         * Properties of a BatchUpdateEntitiesRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IBatchUpdateEntitiesRequest
                         * @property {string|null} [parent] BatchUpdateEntitiesRequest parent
                         * @property {Array.<google.cloud.dialogflow.v2.EntityType.IEntity>|null} [entities] BatchUpdateEntitiesRequest entities
                         * @property {string|null} [languageCode] BatchUpdateEntitiesRequest languageCode
                         * @property {google.protobuf.IFieldMask|null} [updateMask] BatchUpdateEntitiesRequest updateMask
                         */
    
                        /**
                         * Constructs a new BatchUpdateEntitiesRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a BatchUpdateEntitiesRequest.
                         * @implements IBatchUpdateEntitiesRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IBatchUpdateEntitiesRequest=} [properties] Properties to set
                         */
                        function BatchUpdateEntitiesRequest(properties) {
                            this.entities = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * BatchUpdateEntitiesRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateEntitiesRequest
                         * @instance
                         */
                        BatchUpdateEntitiesRequest.prototype.parent = "";
    
                        /**
                         * BatchUpdateEntitiesRequest entities.
                         * @member {Array.<google.cloud.dialogflow.v2.EntityType.IEntity>} entities
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateEntitiesRequest
                         * @instance
                         */
                        BatchUpdateEntitiesRequest.prototype.entities = $util.emptyArray;
    
                        /**
                         * BatchUpdateEntitiesRequest languageCode.
                         * @member {string} languageCode
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateEntitiesRequest
                         * @instance
                         */
                        BatchUpdateEntitiesRequest.prototype.languageCode = "";
    
                        /**
                         * BatchUpdateEntitiesRequest updateMask.
                         * @member {google.protobuf.IFieldMask|null|undefined} updateMask
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateEntitiesRequest
                         * @instance
                         */
                        BatchUpdateEntitiesRequest.prototype.updateMask = null;
    
                        /**
                         * Creates a new BatchUpdateEntitiesRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateEntitiesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IBatchUpdateEntitiesRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.BatchUpdateEntitiesRequest} BatchUpdateEntitiesRequest instance
                         */
                        BatchUpdateEntitiesRequest.create = function create(properties) {
                            return new BatchUpdateEntitiesRequest(properties);
                        };
    
                        /**
                         * Encodes the specified BatchUpdateEntitiesRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.BatchUpdateEntitiesRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateEntitiesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IBatchUpdateEntitiesRequest} message BatchUpdateEntitiesRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        BatchUpdateEntitiesRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.entities != null && message.entities.length)
                                for (var i = 0; i < message.entities.length; ++i)
                                    $root.google.cloud.dialogflow.v2.EntityType.Entity.encode(message.entities[i], writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.languageCode != null && Object.hasOwnProperty.call(message, "languageCode"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.languageCode);
                            if (message.updateMask != null && Object.hasOwnProperty.call(message, "updateMask"))
                                $root.google.protobuf.FieldMask.encode(message.updateMask, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified BatchUpdateEntitiesRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.BatchUpdateEntitiesRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateEntitiesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IBatchUpdateEntitiesRequest} message BatchUpdateEntitiesRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        BatchUpdateEntitiesRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a BatchUpdateEntitiesRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateEntitiesRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.BatchUpdateEntitiesRequest} BatchUpdateEntitiesRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        BatchUpdateEntitiesRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.BatchUpdateEntitiesRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        if (!(message.entities && message.entities.length))
                                            message.entities = [];
                                        message.entities.push($root.google.cloud.dialogflow.v2.EntityType.Entity.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 3: {
                                        message.languageCode = reader.string();
                                        break;
                                    }
                                case 4: {
                                        message.updateMask = $root.google.protobuf.FieldMask.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a BatchUpdateEntitiesRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateEntitiesRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.BatchUpdateEntitiesRequest} BatchUpdateEntitiesRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        BatchUpdateEntitiesRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a BatchUpdateEntitiesRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateEntitiesRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        BatchUpdateEntitiesRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.entities != null && message.hasOwnProperty("entities")) {
                                if (!Array.isArray(message.entities))
                                    return "entities: array expected";
                                for (var i = 0; i < message.entities.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.EntityType.Entity.verify(message.entities[i]);
                                    if (error)
                                        return "entities." + error;
                                }
                            }
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                if (!$util.isString(message.languageCode))
                                    return "languageCode: string expected";
                            if (message.updateMask != null && message.hasOwnProperty("updateMask")) {
                                var error = $root.google.protobuf.FieldMask.verify(message.updateMask);
                                if (error)
                                    return "updateMask." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a BatchUpdateEntitiesRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateEntitiesRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.BatchUpdateEntitiesRequest} BatchUpdateEntitiesRequest
                         */
                        BatchUpdateEntitiesRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.BatchUpdateEntitiesRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.BatchUpdateEntitiesRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.entities) {
                                if (!Array.isArray(object.entities))
                                    throw TypeError(".google.cloud.dialogflow.v2.BatchUpdateEntitiesRequest.entities: array expected");
                                message.entities = [];
                                for (var i = 0; i < object.entities.length; ++i) {
                                    if (typeof object.entities[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.BatchUpdateEntitiesRequest.entities: object expected");
                                    message.entities[i] = $root.google.cloud.dialogflow.v2.EntityType.Entity.fromObject(object.entities[i]);
                                }
                            }
                            if (object.languageCode != null)
                                message.languageCode = String(object.languageCode);
                            if (object.updateMask != null) {
                                if (typeof object.updateMask !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.BatchUpdateEntitiesRequest.updateMask: object expected");
                                message.updateMask = $root.google.protobuf.FieldMask.fromObject(object.updateMask);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a BatchUpdateEntitiesRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateEntitiesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.BatchUpdateEntitiesRequest} message BatchUpdateEntitiesRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        BatchUpdateEntitiesRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.entities = [];
                            if (options.defaults) {
                                object.parent = "";
                                object.languageCode = "";
                                object.updateMask = null;
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.entities && message.entities.length) {
                                object.entities = [];
                                for (var j = 0; j < message.entities.length; ++j)
                                    object.entities[j] = $root.google.cloud.dialogflow.v2.EntityType.Entity.toObject(message.entities[j], options);
                            }
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                object.languageCode = message.languageCode;
                            if (message.updateMask != null && message.hasOwnProperty("updateMask"))
                                object.updateMask = $root.google.protobuf.FieldMask.toObject(message.updateMask, options);
                            return object;
                        };
    
                        /**
                         * Converts this BatchUpdateEntitiesRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateEntitiesRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        BatchUpdateEntitiesRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for BatchUpdateEntitiesRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.BatchUpdateEntitiesRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        BatchUpdateEntitiesRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.BatchUpdateEntitiesRequest";
                        };
    
                        return BatchUpdateEntitiesRequest;
                    })();
    
                    v2.BatchDeleteEntitiesRequest = (function() {
    
                        /**
                         * Properties of a BatchDeleteEntitiesRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IBatchDeleteEntitiesRequest
                         * @property {string|null} [parent] BatchDeleteEntitiesRequest parent
                         * @property {Array.<string>|null} [entityValues] BatchDeleteEntitiesRequest entityValues
                         * @property {string|null} [languageCode] BatchDeleteEntitiesRequest languageCode
                         */
    
                        /**
                         * Constructs a new BatchDeleteEntitiesRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a BatchDeleteEntitiesRequest.
                         * @implements IBatchDeleteEntitiesRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IBatchDeleteEntitiesRequest=} [properties] Properties to set
                         */
                        function BatchDeleteEntitiesRequest(properties) {
                            this.entityValues = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * BatchDeleteEntitiesRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.BatchDeleteEntitiesRequest
                         * @instance
                         */
                        BatchDeleteEntitiesRequest.prototype.parent = "";
    
                        /**
                         * BatchDeleteEntitiesRequest entityValues.
                         * @member {Array.<string>} entityValues
                         * @memberof google.cloud.dialogflow.v2.BatchDeleteEntitiesRequest
                         * @instance
                         */
                        BatchDeleteEntitiesRequest.prototype.entityValues = $util.emptyArray;
    
                        /**
                         * BatchDeleteEntitiesRequest languageCode.
                         * @member {string} languageCode
                         * @memberof google.cloud.dialogflow.v2.BatchDeleteEntitiesRequest
                         * @instance
                         */
                        BatchDeleteEntitiesRequest.prototype.languageCode = "";
    
                        /**
                         * Creates a new BatchDeleteEntitiesRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.BatchDeleteEntitiesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IBatchDeleteEntitiesRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.BatchDeleteEntitiesRequest} BatchDeleteEntitiesRequest instance
                         */
                        BatchDeleteEntitiesRequest.create = function create(properties) {
                            return new BatchDeleteEntitiesRequest(properties);
                        };
    
                        /**
                         * Encodes the specified BatchDeleteEntitiesRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.BatchDeleteEntitiesRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.BatchDeleteEntitiesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IBatchDeleteEntitiesRequest} message BatchDeleteEntitiesRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        BatchDeleteEntitiesRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.entityValues != null && message.entityValues.length)
                                for (var i = 0; i < message.entityValues.length; ++i)
                                    writer.uint32(/* id 2, wireType 2 =*/18).string(message.entityValues[i]);
                            if (message.languageCode != null && Object.hasOwnProperty.call(message, "languageCode"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.languageCode);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified BatchDeleteEntitiesRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.BatchDeleteEntitiesRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.BatchDeleteEntitiesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IBatchDeleteEntitiesRequest} message BatchDeleteEntitiesRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        BatchDeleteEntitiesRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a BatchDeleteEntitiesRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.BatchDeleteEntitiesRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.BatchDeleteEntitiesRequest} BatchDeleteEntitiesRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        BatchDeleteEntitiesRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.BatchDeleteEntitiesRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        if (!(message.entityValues && message.entityValues.length))
                                            message.entityValues = [];
                                        message.entityValues.push(reader.string());
                                        break;
                                    }
                                case 3: {
                                        message.languageCode = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a BatchDeleteEntitiesRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.BatchDeleteEntitiesRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.BatchDeleteEntitiesRequest} BatchDeleteEntitiesRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        BatchDeleteEntitiesRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a BatchDeleteEntitiesRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.BatchDeleteEntitiesRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        BatchDeleteEntitiesRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.entityValues != null && message.hasOwnProperty("entityValues")) {
                                if (!Array.isArray(message.entityValues))
                                    return "entityValues: array expected";
                                for (var i = 0; i < message.entityValues.length; ++i)
                                    if (!$util.isString(message.entityValues[i]))
                                        return "entityValues: string[] expected";
                            }
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                if (!$util.isString(message.languageCode))
                                    return "languageCode: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a BatchDeleteEntitiesRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.BatchDeleteEntitiesRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.BatchDeleteEntitiesRequest} BatchDeleteEntitiesRequest
                         */
                        BatchDeleteEntitiesRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.BatchDeleteEntitiesRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.BatchDeleteEntitiesRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.entityValues) {
                                if (!Array.isArray(object.entityValues))
                                    throw TypeError(".google.cloud.dialogflow.v2.BatchDeleteEntitiesRequest.entityValues: array expected");
                                message.entityValues = [];
                                for (var i = 0; i < object.entityValues.length; ++i)
                                    message.entityValues[i] = String(object.entityValues[i]);
                            }
                            if (object.languageCode != null)
                                message.languageCode = String(object.languageCode);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a BatchDeleteEntitiesRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.BatchDeleteEntitiesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.BatchDeleteEntitiesRequest} message BatchDeleteEntitiesRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        BatchDeleteEntitiesRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.entityValues = [];
                            if (options.defaults) {
                                object.parent = "";
                                object.languageCode = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.entityValues && message.entityValues.length) {
                                object.entityValues = [];
                                for (var j = 0; j < message.entityValues.length; ++j)
                                    object.entityValues[j] = message.entityValues[j];
                            }
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                object.languageCode = message.languageCode;
                            return object;
                        };
    
                        /**
                         * Converts this BatchDeleteEntitiesRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.BatchDeleteEntitiesRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        BatchDeleteEntitiesRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for BatchDeleteEntitiesRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.BatchDeleteEntitiesRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        BatchDeleteEntitiesRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.BatchDeleteEntitiesRequest";
                        };
    
                        return BatchDeleteEntitiesRequest;
                    })();
    
                    v2.EntityTypeBatch = (function() {
    
                        /**
                         * Properties of an EntityTypeBatch.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IEntityTypeBatch
                         * @property {Array.<google.cloud.dialogflow.v2.IEntityType>|null} [entityTypes] EntityTypeBatch entityTypes
                         */
    
                        /**
                         * Constructs a new EntityTypeBatch.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an EntityTypeBatch.
                         * @implements IEntityTypeBatch
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IEntityTypeBatch=} [properties] Properties to set
                         */
                        function EntityTypeBatch(properties) {
                            this.entityTypes = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * EntityTypeBatch entityTypes.
                         * @member {Array.<google.cloud.dialogflow.v2.IEntityType>} entityTypes
                         * @memberof google.cloud.dialogflow.v2.EntityTypeBatch
                         * @instance
                         */
                        EntityTypeBatch.prototype.entityTypes = $util.emptyArray;
    
                        /**
                         * Creates a new EntityTypeBatch instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.EntityTypeBatch
                         * @static
                         * @param {google.cloud.dialogflow.v2.IEntityTypeBatch=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.EntityTypeBatch} EntityTypeBatch instance
                         */
                        EntityTypeBatch.create = function create(properties) {
                            return new EntityTypeBatch(properties);
                        };
    
                        /**
                         * Encodes the specified EntityTypeBatch message. Does not implicitly {@link google.cloud.dialogflow.v2.EntityTypeBatch.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.EntityTypeBatch
                         * @static
                         * @param {google.cloud.dialogflow.v2.IEntityTypeBatch} message EntityTypeBatch message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        EntityTypeBatch.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.entityTypes != null && message.entityTypes.length)
                                for (var i = 0; i < message.entityTypes.length; ++i)
                                    $root.google.cloud.dialogflow.v2.EntityType.encode(message.entityTypes[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified EntityTypeBatch message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.EntityTypeBatch.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.EntityTypeBatch
                         * @static
                         * @param {google.cloud.dialogflow.v2.IEntityTypeBatch} message EntityTypeBatch message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        EntityTypeBatch.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an EntityTypeBatch message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.EntityTypeBatch
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.EntityTypeBatch} EntityTypeBatch
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        EntityTypeBatch.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.EntityTypeBatch();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.entityTypes && message.entityTypes.length))
                                            message.entityTypes = [];
                                        message.entityTypes.push($root.google.cloud.dialogflow.v2.EntityType.decode(reader, reader.uint32()));
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an EntityTypeBatch message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.EntityTypeBatch
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.EntityTypeBatch} EntityTypeBatch
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        EntityTypeBatch.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an EntityTypeBatch message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.EntityTypeBatch
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        EntityTypeBatch.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.entityTypes != null && message.hasOwnProperty("entityTypes")) {
                                if (!Array.isArray(message.entityTypes))
                                    return "entityTypes: array expected";
                                for (var i = 0; i < message.entityTypes.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.EntityType.verify(message.entityTypes[i]);
                                    if (error)
                                        return "entityTypes." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates an EntityTypeBatch message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.EntityTypeBatch
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.EntityTypeBatch} EntityTypeBatch
                         */
                        EntityTypeBatch.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.EntityTypeBatch)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.EntityTypeBatch();
                            if (object.entityTypes) {
                                if (!Array.isArray(object.entityTypes))
                                    throw TypeError(".google.cloud.dialogflow.v2.EntityTypeBatch.entityTypes: array expected");
                                message.entityTypes = [];
                                for (var i = 0; i < object.entityTypes.length; ++i) {
                                    if (typeof object.entityTypes[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.EntityTypeBatch.entityTypes: object expected");
                                    message.entityTypes[i] = $root.google.cloud.dialogflow.v2.EntityType.fromObject(object.entityTypes[i]);
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an EntityTypeBatch message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.EntityTypeBatch
                         * @static
                         * @param {google.cloud.dialogflow.v2.EntityTypeBatch} message EntityTypeBatch
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        EntityTypeBatch.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.entityTypes = [];
                            if (message.entityTypes && message.entityTypes.length) {
                                object.entityTypes = [];
                                for (var j = 0; j < message.entityTypes.length; ++j)
                                    object.entityTypes[j] = $root.google.cloud.dialogflow.v2.EntityType.toObject(message.entityTypes[j], options);
                            }
                            return object;
                        };
    
                        /**
                         * Converts this EntityTypeBatch to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.EntityTypeBatch
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        EntityTypeBatch.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for EntityTypeBatch
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.EntityTypeBatch
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        EntityTypeBatch.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.EntityTypeBatch";
                        };
    
                        return EntityTypeBatch;
                    })();
    
                    v2.Conversations = (function() {
    
                        /**
                         * Constructs a new Conversations service.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a Conversations
                         * @extends $protobuf.rpc.Service
                         * @constructor
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         */
                        function Conversations(rpcImpl, requestDelimited, responseDelimited) {
                            $protobuf.rpc.Service.call(this, rpcImpl, requestDelimited, responseDelimited);
                        }
    
                        (Conversations.prototype = Object.create($protobuf.rpc.Service.prototype)).constructor = Conversations;
    
                        /**
                         * Creates new Conversations service using the specified rpc implementation.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.Conversations
                         * @static
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         * @returns {Conversations} RPC service. Useful where requests and/or responses are streamed.
                         */
                        Conversations.create = function create(rpcImpl, requestDelimited, responseDelimited) {
                            return new this(rpcImpl, requestDelimited, responseDelimited);
                        };
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Conversations|createConversation}.
                         * @memberof google.cloud.dialogflow.v2.Conversations
                         * @typedef CreateConversationCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.Conversation} [response] Conversation
                         */
    
                        /**
                         * Calls CreateConversation.
                         * @function createConversation
                         * @memberof google.cloud.dialogflow.v2.Conversations
                         * @instance
                         * @param {google.cloud.dialogflow.v2.ICreateConversationRequest} request CreateConversationRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Conversations.CreateConversationCallback} callback Node-style callback called with the error, if any, and Conversation
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Conversations.prototype.createConversation = function createConversation(request, callback) {
                            return this.rpcCall(createConversation, $root.google.cloud.dialogflow.v2.CreateConversationRequest, $root.google.cloud.dialogflow.v2.Conversation, request, callback);
                        }, "name", { value: "CreateConversation" });
    
                        /**
                         * Calls CreateConversation.
                         * @function createConversation
                         * @memberof google.cloud.dialogflow.v2.Conversations
                         * @instance
                         * @param {google.cloud.dialogflow.v2.ICreateConversationRequest} request CreateConversationRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.Conversation>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Conversations|listConversations}.
                         * @memberof google.cloud.dialogflow.v2.Conversations
                         * @typedef ListConversationsCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.ListConversationsResponse} [response] ListConversationsResponse
                         */
    
                        /**
                         * Calls ListConversations.
                         * @function listConversations
                         * @memberof google.cloud.dialogflow.v2.Conversations
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IListConversationsRequest} request ListConversationsRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Conversations.ListConversationsCallback} callback Node-style callback called with the error, if any, and ListConversationsResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Conversations.prototype.listConversations = function listConversations(request, callback) {
                            return this.rpcCall(listConversations, $root.google.cloud.dialogflow.v2.ListConversationsRequest, $root.google.cloud.dialogflow.v2.ListConversationsResponse, request, callback);
                        }, "name", { value: "ListConversations" });
    
                        /**
                         * Calls ListConversations.
                         * @function listConversations
                         * @memberof google.cloud.dialogflow.v2.Conversations
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IListConversationsRequest} request ListConversationsRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.ListConversationsResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Conversations|getConversation}.
                         * @memberof google.cloud.dialogflow.v2.Conversations
                         * @typedef GetConversationCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.Conversation} [response] Conversation
                         */
    
                        /**
                         * Calls GetConversation.
                         * @function getConversation
                         * @memberof google.cloud.dialogflow.v2.Conversations
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IGetConversationRequest} request GetConversationRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Conversations.GetConversationCallback} callback Node-style callback called with the error, if any, and Conversation
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Conversations.prototype.getConversation = function getConversation(request, callback) {
                            return this.rpcCall(getConversation, $root.google.cloud.dialogflow.v2.GetConversationRequest, $root.google.cloud.dialogflow.v2.Conversation, request, callback);
                        }, "name", { value: "GetConversation" });
    
                        /**
                         * Calls GetConversation.
                         * @function getConversation
                         * @memberof google.cloud.dialogflow.v2.Conversations
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IGetConversationRequest} request GetConversationRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.Conversation>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Conversations|completeConversation}.
                         * @memberof google.cloud.dialogflow.v2.Conversations
                         * @typedef CompleteConversationCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.Conversation} [response] Conversation
                         */
    
                        /**
                         * Calls CompleteConversation.
                         * @function completeConversation
                         * @memberof google.cloud.dialogflow.v2.Conversations
                         * @instance
                         * @param {google.cloud.dialogflow.v2.ICompleteConversationRequest} request CompleteConversationRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Conversations.CompleteConversationCallback} callback Node-style callback called with the error, if any, and Conversation
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Conversations.prototype.completeConversation = function completeConversation(request, callback) {
                            return this.rpcCall(completeConversation, $root.google.cloud.dialogflow.v2.CompleteConversationRequest, $root.google.cloud.dialogflow.v2.Conversation, request, callback);
                        }, "name", { value: "CompleteConversation" });
    
                        /**
                         * Calls CompleteConversation.
                         * @function completeConversation
                         * @memberof google.cloud.dialogflow.v2.Conversations
                         * @instance
                         * @param {google.cloud.dialogflow.v2.ICompleteConversationRequest} request CompleteConversationRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.Conversation>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Conversations|ingestContextReferences}.
                         * @memberof google.cloud.dialogflow.v2.Conversations
                         * @typedef IngestContextReferencesCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.IngestContextReferencesResponse} [response] IngestContextReferencesResponse
                         */
    
                        /**
                         * Calls IngestContextReferences.
                         * @function ingestContextReferences
                         * @memberof google.cloud.dialogflow.v2.Conversations
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IIngestContextReferencesRequest} request IngestContextReferencesRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Conversations.IngestContextReferencesCallback} callback Node-style callback called with the error, if any, and IngestContextReferencesResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Conversations.prototype.ingestContextReferences = function ingestContextReferences(request, callback) {
                            return this.rpcCall(ingestContextReferences, $root.google.cloud.dialogflow.v2.IngestContextReferencesRequest, $root.google.cloud.dialogflow.v2.IngestContextReferencesResponse, request, callback);
                        }, "name", { value: "IngestContextReferences" });
    
                        /**
                         * Calls IngestContextReferences.
                         * @function ingestContextReferences
                         * @memberof google.cloud.dialogflow.v2.Conversations
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IIngestContextReferencesRequest} request IngestContextReferencesRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.IngestContextReferencesResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Conversations|listMessages}.
                         * @memberof google.cloud.dialogflow.v2.Conversations
                         * @typedef ListMessagesCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.ListMessagesResponse} [response] ListMessagesResponse
                         */
    
                        /**
                         * Calls ListMessages.
                         * @function listMessages
                         * @memberof google.cloud.dialogflow.v2.Conversations
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IListMessagesRequest} request ListMessagesRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Conversations.ListMessagesCallback} callback Node-style callback called with the error, if any, and ListMessagesResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Conversations.prototype.listMessages = function listMessages(request, callback) {
                            return this.rpcCall(listMessages, $root.google.cloud.dialogflow.v2.ListMessagesRequest, $root.google.cloud.dialogflow.v2.ListMessagesResponse, request, callback);
                        }, "name", { value: "ListMessages" });
    
                        /**
                         * Calls ListMessages.
                         * @function listMessages
                         * @memberof google.cloud.dialogflow.v2.Conversations
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IListMessagesRequest} request ListMessagesRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.ListMessagesResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Conversations|suggestConversationSummary}.
                         * @memberof google.cloud.dialogflow.v2.Conversations
                         * @typedef SuggestConversationSummaryCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.SuggestConversationSummaryResponse} [response] SuggestConversationSummaryResponse
                         */
    
                        /**
                         * Calls SuggestConversationSummary.
                         * @function suggestConversationSummary
                         * @memberof google.cloud.dialogflow.v2.Conversations
                         * @instance
                         * @param {google.cloud.dialogflow.v2.ISuggestConversationSummaryRequest} request SuggestConversationSummaryRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Conversations.SuggestConversationSummaryCallback} callback Node-style callback called with the error, if any, and SuggestConversationSummaryResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Conversations.prototype.suggestConversationSummary = function suggestConversationSummary(request, callback) {
                            return this.rpcCall(suggestConversationSummary, $root.google.cloud.dialogflow.v2.SuggestConversationSummaryRequest, $root.google.cloud.dialogflow.v2.SuggestConversationSummaryResponse, request, callback);
                        }, "name", { value: "SuggestConversationSummary" });
    
                        /**
                         * Calls SuggestConversationSummary.
                         * @function suggestConversationSummary
                         * @memberof google.cloud.dialogflow.v2.Conversations
                         * @instance
                         * @param {google.cloud.dialogflow.v2.ISuggestConversationSummaryRequest} request SuggestConversationSummaryRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.SuggestConversationSummaryResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Conversations|generateStatelessSummary}.
                         * @memberof google.cloud.dialogflow.v2.Conversations
                         * @typedef GenerateStatelessSummaryCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse} [response] GenerateStatelessSummaryResponse
                         */
    
                        /**
                         * Calls GenerateStatelessSummary.
                         * @function generateStatelessSummary
                         * @memberof google.cloud.dialogflow.v2.Conversations
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IGenerateStatelessSummaryRequest} request GenerateStatelessSummaryRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Conversations.GenerateStatelessSummaryCallback} callback Node-style callback called with the error, if any, and GenerateStatelessSummaryResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Conversations.prototype.generateStatelessSummary = function generateStatelessSummary(request, callback) {
                            return this.rpcCall(generateStatelessSummary, $root.google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest, $root.google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse, request, callback);
                        }, "name", { value: "GenerateStatelessSummary" });
    
                        /**
                         * Calls GenerateStatelessSummary.
                         * @function generateStatelessSummary
                         * @memberof google.cloud.dialogflow.v2.Conversations
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IGenerateStatelessSummaryRequest} request GenerateStatelessSummaryRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Conversations|generateStatelessSuggestion}.
                         * @memberof google.cloud.dialogflow.v2.Conversations
                         * @typedef GenerateStatelessSuggestionCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.GenerateStatelessSuggestionResponse} [response] GenerateStatelessSuggestionResponse
                         */
    
                        /**
                         * Calls GenerateStatelessSuggestion.
                         * @function generateStatelessSuggestion
                         * @memberof google.cloud.dialogflow.v2.Conversations
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IGenerateStatelessSuggestionRequest} request GenerateStatelessSuggestionRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Conversations.GenerateStatelessSuggestionCallback} callback Node-style callback called with the error, if any, and GenerateStatelessSuggestionResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Conversations.prototype.generateStatelessSuggestion = function generateStatelessSuggestion(request, callback) {
                            return this.rpcCall(generateStatelessSuggestion, $root.google.cloud.dialogflow.v2.GenerateStatelessSuggestionRequest, $root.google.cloud.dialogflow.v2.GenerateStatelessSuggestionResponse, request, callback);
                        }, "name", { value: "GenerateStatelessSuggestion" });
    
                        /**
                         * Calls GenerateStatelessSuggestion.
                         * @function generateStatelessSuggestion
                         * @memberof google.cloud.dialogflow.v2.Conversations
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IGenerateStatelessSuggestionRequest} request GenerateStatelessSuggestionRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.GenerateStatelessSuggestionResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Conversations|searchKnowledge}.
                         * @memberof google.cloud.dialogflow.v2.Conversations
                         * @typedef SearchKnowledgeCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.SearchKnowledgeResponse} [response] SearchKnowledgeResponse
                         */
    
                        /**
                         * Calls SearchKnowledge.
                         * @function searchKnowledge
                         * @memberof google.cloud.dialogflow.v2.Conversations
                         * @instance
                         * @param {google.cloud.dialogflow.v2.ISearchKnowledgeRequest} request SearchKnowledgeRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Conversations.SearchKnowledgeCallback} callback Node-style callback called with the error, if any, and SearchKnowledgeResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Conversations.prototype.searchKnowledge = function searchKnowledge(request, callback) {
                            return this.rpcCall(searchKnowledge, $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest, $root.google.cloud.dialogflow.v2.SearchKnowledgeResponse, request, callback);
                        }, "name", { value: "SearchKnowledge" });
    
                        /**
                         * Calls SearchKnowledge.
                         * @function searchKnowledge
                         * @memberof google.cloud.dialogflow.v2.Conversations
                         * @instance
                         * @param {google.cloud.dialogflow.v2.ISearchKnowledgeRequest} request SearchKnowledgeRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.SearchKnowledgeResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Conversations|generateSuggestions}.
                         * @memberof google.cloud.dialogflow.v2.Conversations
                         * @typedef GenerateSuggestionsCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.GenerateSuggestionsResponse} [response] GenerateSuggestionsResponse
                         */
    
                        /**
                         * Calls GenerateSuggestions.
                         * @function generateSuggestions
                         * @memberof google.cloud.dialogflow.v2.Conversations
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IGenerateSuggestionsRequest} request GenerateSuggestionsRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Conversations.GenerateSuggestionsCallback} callback Node-style callback called with the error, if any, and GenerateSuggestionsResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Conversations.prototype.generateSuggestions = function generateSuggestions(request, callback) {
                            return this.rpcCall(generateSuggestions, $root.google.cloud.dialogflow.v2.GenerateSuggestionsRequest, $root.google.cloud.dialogflow.v2.GenerateSuggestionsResponse, request, callback);
                        }, "name", { value: "GenerateSuggestions" });
    
                        /**
                         * Calls GenerateSuggestions.
                         * @function generateSuggestions
                         * @memberof google.cloud.dialogflow.v2.Conversations
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IGenerateSuggestionsRequest} request GenerateSuggestionsRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.GenerateSuggestionsResponse>} Promise
                         * @variation 2
                         */
    
                        return Conversations;
                    })();
    
                    v2.Conversation = (function() {
    
                        /**
                         * Properties of a Conversation.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IConversation
                         * @property {string|null} [name] Conversation name
                         * @property {google.cloud.dialogflow.v2.Conversation.LifecycleState|null} [lifecycleState] Conversation lifecycleState
                         * @property {string|null} [conversationProfile] Conversation conversationProfile
                         * @property {google.cloud.dialogflow.v2.IConversationPhoneNumber|null} [phoneNumber] Conversation phoneNumber
                         * @property {google.protobuf.ITimestamp|null} [startTime] Conversation startTime
                         * @property {google.protobuf.ITimestamp|null} [endTime] Conversation endTime
                         * @property {google.cloud.dialogflow.v2.Conversation.ConversationStage|null} [conversationStage] Conversation conversationStage
                         * @property {google.cloud.dialogflow.v2.Conversation.ITelephonyConnectionInfo|null} [telephonyConnectionInfo] Conversation telephonyConnectionInfo
                         * @property {Object.<string,google.cloud.dialogflow.v2.Conversation.IContextReference>|null} [ingestedContextReferences] Conversation ingestedContextReferences
                         */
    
                        /**
                         * Constructs a new Conversation.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a Conversation.
                         * @implements IConversation
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IConversation=} [properties] Properties to set
                         */
                        function Conversation(properties) {
                            this.ingestedContextReferences = {};
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * Conversation name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2.Conversation
                         * @instance
                         */
                        Conversation.prototype.name = "";
    
                        /**
                         * Conversation lifecycleState.
                         * @member {google.cloud.dialogflow.v2.Conversation.LifecycleState} lifecycleState
                         * @memberof google.cloud.dialogflow.v2.Conversation
                         * @instance
                         */
                        Conversation.prototype.lifecycleState = 0;
    
                        /**
                         * Conversation conversationProfile.
                         * @member {string} conversationProfile
                         * @memberof google.cloud.dialogflow.v2.Conversation
                         * @instance
                         */
                        Conversation.prototype.conversationProfile = "";
    
                        /**
                         * Conversation phoneNumber.
                         * @member {google.cloud.dialogflow.v2.IConversationPhoneNumber|null|undefined} phoneNumber
                         * @memberof google.cloud.dialogflow.v2.Conversation
                         * @instance
                         */
                        Conversation.prototype.phoneNumber = null;
    
                        /**
                         * Conversation startTime.
                         * @member {google.protobuf.ITimestamp|null|undefined} startTime
                         * @memberof google.cloud.dialogflow.v2.Conversation
                         * @instance
                         */
                        Conversation.prototype.startTime = null;
    
                        /**
                         * Conversation endTime.
                         * @member {google.protobuf.ITimestamp|null|undefined} endTime
                         * @memberof google.cloud.dialogflow.v2.Conversation
                         * @instance
                         */
                        Conversation.prototype.endTime = null;
    
                        /**
                         * Conversation conversationStage.
                         * @member {google.cloud.dialogflow.v2.Conversation.ConversationStage} conversationStage
                         * @memberof google.cloud.dialogflow.v2.Conversation
                         * @instance
                         */
                        Conversation.prototype.conversationStage = 0;
    
                        /**
                         * Conversation telephonyConnectionInfo.
                         * @member {google.cloud.dialogflow.v2.Conversation.ITelephonyConnectionInfo|null|undefined} telephonyConnectionInfo
                         * @memberof google.cloud.dialogflow.v2.Conversation
                         * @instance
                         */
                        Conversation.prototype.telephonyConnectionInfo = null;
    
                        /**
                         * Conversation ingestedContextReferences.
                         * @member {Object.<string,google.cloud.dialogflow.v2.Conversation.IContextReference>} ingestedContextReferences
                         * @memberof google.cloud.dialogflow.v2.Conversation
                         * @instance
                         */
                        Conversation.prototype.ingestedContextReferences = $util.emptyObject;
    
                        /**
                         * Creates a new Conversation instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.Conversation
                         * @static
                         * @param {google.cloud.dialogflow.v2.IConversation=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.Conversation} Conversation instance
                         */
                        Conversation.create = function create(properties) {
                            return new Conversation(properties);
                        };
    
                        /**
                         * Encodes the specified Conversation message. Does not implicitly {@link google.cloud.dialogflow.v2.Conversation.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.Conversation
                         * @static
                         * @param {google.cloud.dialogflow.v2.IConversation} message Conversation message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        Conversation.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            if (message.lifecycleState != null && Object.hasOwnProperty.call(message, "lifecycleState"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.lifecycleState);
                            if (message.conversationProfile != null && Object.hasOwnProperty.call(message, "conversationProfile"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.conversationProfile);
                            if (message.phoneNumber != null && Object.hasOwnProperty.call(message, "phoneNumber"))
                                $root.google.cloud.dialogflow.v2.ConversationPhoneNumber.encode(message.phoneNumber, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            if (message.startTime != null && Object.hasOwnProperty.call(message, "startTime"))
                                $root.google.protobuf.Timestamp.encode(message.startTime, writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                            if (message.endTime != null && Object.hasOwnProperty.call(message, "endTime"))
                                $root.google.protobuf.Timestamp.encode(message.endTime, writer.uint32(/* id 6, wireType 2 =*/50).fork()).ldelim();
                            if (message.conversationStage != null && Object.hasOwnProperty.call(message, "conversationStage"))
                                writer.uint32(/* id 7, wireType 0 =*/56).int32(message.conversationStage);
                            if (message.telephonyConnectionInfo != null && Object.hasOwnProperty.call(message, "telephonyConnectionInfo"))
                                $root.google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.encode(message.telephonyConnectionInfo, writer.uint32(/* id 10, wireType 2 =*/82).fork()).ldelim();
                            if (message.ingestedContextReferences != null && Object.hasOwnProperty.call(message, "ingestedContextReferences"))
                                for (var keys = Object.keys(message.ingestedContextReferences), i = 0; i < keys.length; ++i) {
                                    writer.uint32(/* id 17, wireType 2 =*/138).fork().uint32(/* id 1, wireType 2 =*/10).string(keys[i]);
                                    $root.google.cloud.dialogflow.v2.Conversation.ContextReference.encode(message.ingestedContextReferences[keys[i]], writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim().ldelim();
                                }
                            return writer;
                        };
    
                        /**
                         * Encodes the specified Conversation message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.Conversation.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.Conversation
                         * @static
                         * @param {google.cloud.dialogflow.v2.IConversation} message Conversation message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        Conversation.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a Conversation message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.Conversation
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.Conversation} Conversation
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        Conversation.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.Conversation(), key, value;
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.lifecycleState = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.conversationProfile = reader.string();
                                        break;
                                    }
                                case 4: {
                                        message.phoneNumber = $root.google.cloud.dialogflow.v2.ConversationPhoneNumber.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 5: {
                                        message.startTime = $root.google.protobuf.Timestamp.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 6: {
                                        message.endTime = $root.google.protobuf.Timestamp.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 7: {
                                        message.conversationStage = reader.int32();
                                        break;
                                    }
                                case 10: {
                                        message.telephonyConnectionInfo = $root.google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 17: {
                                        if (message.ingestedContextReferences === $util.emptyObject)
                                            message.ingestedContextReferences = {};
                                        var end2 = reader.uint32() + reader.pos;
                                        key = "";
                                        value = null;
                                        while (reader.pos < end2) {
                                            var tag2 = reader.uint32();
                                            switch (tag2 >>> 3) {
                                            case 1:
                                                key = reader.string();
                                                break;
                                            case 2:
                                                value = $root.google.cloud.dialogflow.v2.Conversation.ContextReference.decode(reader, reader.uint32());
                                                break;
                                            default:
                                                reader.skipType(tag2 & 7);
                                                break;
                                            }
                                        }
                                        message.ingestedContextReferences[key] = value;
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a Conversation message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.Conversation
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.Conversation} Conversation
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        Conversation.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a Conversation message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.Conversation
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        Conversation.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            if (message.lifecycleState != null && message.hasOwnProperty("lifecycleState"))
                                switch (message.lifecycleState) {
                                default:
                                    return "lifecycleState: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                    break;
                                }
                            if (message.conversationProfile != null && message.hasOwnProperty("conversationProfile"))
                                if (!$util.isString(message.conversationProfile))
                                    return "conversationProfile: string expected";
                            if (message.phoneNumber != null && message.hasOwnProperty("phoneNumber")) {
                                var error = $root.google.cloud.dialogflow.v2.ConversationPhoneNumber.verify(message.phoneNumber);
                                if (error)
                                    return "phoneNumber." + error;
                            }
                            if (message.startTime != null && message.hasOwnProperty("startTime")) {
                                var error = $root.google.protobuf.Timestamp.verify(message.startTime);
                                if (error)
                                    return "startTime." + error;
                            }
                            if (message.endTime != null && message.hasOwnProperty("endTime")) {
                                var error = $root.google.protobuf.Timestamp.verify(message.endTime);
                                if (error)
                                    return "endTime." + error;
                            }
                            if (message.conversationStage != null && message.hasOwnProperty("conversationStage"))
                                switch (message.conversationStage) {
                                default:
                                    return "conversationStage: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                    break;
                                }
                            if (message.telephonyConnectionInfo != null && message.hasOwnProperty("telephonyConnectionInfo")) {
                                var error = $root.google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.verify(message.telephonyConnectionInfo);
                                if (error)
                                    return "telephonyConnectionInfo." + error;
                            }
                            if (message.ingestedContextReferences != null && message.hasOwnProperty("ingestedContextReferences")) {
                                if (!$util.isObject(message.ingestedContextReferences))
                                    return "ingestedContextReferences: object expected";
                                var key = Object.keys(message.ingestedContextReferences);
                                for (var i = 0; i < key.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.Conversation.ContextReference.verify(message.ingestedContextReferences[key[i]]);
                                    if (error)
                                        return "ingestedContextReferences." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates a Conversation message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.Conversation
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.Conversation} Conversation
                         */
                        Conversation.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.Conversation)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.Conversation();
                            if (object.name != null)
                                message.name = String(object.name);
                            switch (object.lifecycleState) {
                            default:
                                if (typeof object.lifecycleState === "number") {
                                    message.lifecycleState = object.lifecycleState;
                                    break;
                                }
                                break;
                            case "LIFECYCLE_STATE_UNSPECIFIED":
                            case 0:
                                message.lifecycleState = 0;
                                break;
                            case "IN_PROGRESS":
                            case 1:
                                message.lifecycleState = 1;
                                break;
                            case "COMPLETED":
                            case 2:
                                message.lifecycleState = 2;
                                break;
                            }
                            if (object.conversationProfile != null)
                                message.conversationProfile = String(object.conversationProfile);
                            if (object.phoneNumber != null) {
                                if (typeof object.phoneNumber !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.Conversation.phoneNumber: object expected");
                                message.phoneNumber = $root.google.cloud.dialogflow.v2.ConversationPhoneNumber.fromObject(object.phoneNumber);
                            }
                            if (object.startTime != null) {
                                if (typeof object.startTime !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.Conversation.startTime: object expected");
                                message.startTime = $root.google.protobuf.Timestamp.fromObject(object.startTime);
                            }
                            if (object.endTime != null) {
                                if (typeof object.endTime !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.Conversation.endTime: object expected");
                                message.endTime = $root.google.protobuf.Timestamp.fromObject(object.endTime);
                            }
                            switch (object.conversationStage) {
                            default:
                                if (typeof object.conversationStage === "number") {
                                    message.conversationStage = object.conversationStage;
                                    break;
                                }
                                break;
                            case "CONVERSATION_STAGE_UNSPECIFIED":
                            case 0:
                                message.conversationStage = 0;
                                break;
                            case "VIRTUAL_AGENT_STAGE":
                            case 1:
                                message.conversationStage = 1;
                                break;
                            case "HUMAN_ASSIST_STAGE":
                            case 2:
                                message.conversationStage = 2;
                                break;
                            }
                            if (object.telephonyConnectionInfo != null) {
                                if (typeof object.telephonyConnectionInfo !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.Conversation.telephonyConnectionInfo: object expected");
                                message.telephonyConnectionInfo = $root.google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.fromObject(object.telephonyConnectionInfo);
                            }
                            if (object.ingestedContextReferences) {
                                if (typeof object.ingestedContextReferences !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.Conversation.ingestedContextReferences: object expected");
                                message.ingestedContextReferences = {};
                                for (var keys = Object.keys(object.ingestedContextReferences), i = 0; i < keys.length; ++i) {
                                    if (typeof object.ingestedContextReferences[keys[i]] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.Conversation.ingestedContextReferences: object expected");
                                    message.ingestedContextReferences[keys[i]] = $root.google.cloud.dialogflow.v2.Conversation.ContextReference.fromObject(object.ingestedContextReferences[keys[i]]);
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a Conversation message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.Conversation
                         * @static
                         * @param {google.cloud.dialogflow.v2.Conversation} message Conversation
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        Conversation.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.objects || options.defaults)
                                object.ingestedContextReferences = {};
                            if (options.defaults) {
                                object.name = "";
                                object.lifecycleState = options.enums === String ? "LIFECYCLE_STATE_UNSPECIFIED" : 0;
                                object.conversationProfile = "";
                                object.phoneNumber = null;
                                object.startTime = null;
                                object.endTime = null;
                                object.conversationStage = options.enums === String ? "CONVERSATION_STAGE_UNSPECIFIED" : 0;
                                object.telephonyConnectionInfo = null;
                            }
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            if (message.lifecycleState != null && message.hasOwnProperty("lifecycleState"))
                                object.lifecycleState = options.enums === String ? $root.google.cloud.dialogflow.v2.Conversation.LifecycleState[message.lifecycleState] === undefined ? message.lifecycleState : $root.google.cloud.dialogflow.v2.Conversation.LifecycleState[message.lifecycleState] : message.lifecycleState;
                            if (message.conversationProfile != null && message.hasOwnProperty("conversationProfile"))
                                object.conversationProfile = message.conversationProfile;
                            if (message.phoneNumber != null && message.hasOwnProperty("phoneNumber"))
                                object.phoneNumber = $root.google.cloud.dialogflow.v2.ConversationPhoneNumber.toObject(message.phoneNumber, options);
                            if (message.startTime != null && message.hasOwnProperty("startTime"))
                                object.startTime = $root.google.protobuf.Timestamp.toObject(message.startTime, options);
                            if (message.endTime != null && message.hasOwnProperty("endTime"))
                                object.endTime = $root.google.protobuf.Timestamp.toObject(message.endTime, options);
                            if (message.conversationStage != null && message.hasOwnProperty("conversationStage"))
                                object.conversationStage = options.enums === String ? $root.google.cloud.dialogflow.v2.Conversation.ConversationStage[message.conversationStage] === undefined ? message.conversationStage : $root.google.cloud.dialogflow.v2.Conversation.ConversationStage[message.conversationStage] : message.conversationStage;
                            if (message.telephonyConnectionInfo != null && message.hasOwnProperty("telephonyConnectionInfo"))
                                object.telephonyConnectionInfo = $root.google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.toObject(message.telephonyConnectionInfo, options);
                            var keys2;
                            if (message.ingestedContextReferences && (keys2 = Object.keys(message.ingestedContextReferences)).length) {
                                object.ingestedContextReferences = {};
                                for (var j = 0; j < keys2.length; ++j)
                                    object.ingestedContextReferences[keys2[j]] = $root.google.cloud.dialogflow.v2.Conversation.ContextReference.toObject(message.ingestedContextReferences[keys2[j]], options);
                            }
                            return object;
                        };
    
                        /**
                         * Converts this Conversation to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.Conversation
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        Conversation.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for Conversation
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.Conversation
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        Conversation.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.Conversation";
                        };
    
                        /**
                         * LifecycleState enum.
                         * @name google.cloud.dialogflow.v2.Conversation.LifecycleState
                         * @enum {number}
                         * @property {number} LIFECYCLE_STATE_UNSPECIFIED=0 LIFECYCLE_STATE_UNSPECIFIED value
                         * @property {number} IN_PROGRESS=1 IN_PROGRESS value
                         * @property {number} COMPLETED=2 COMPLETED value
                         */
                        Conversation.LifecycleState = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "LIFECYCLE_STATE_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "IN_PROGRESS"] = 1;
                            values[valuesById[2] = "COMPLETED"] = 2;
                            return values;
                        })();
    
                        /**
                         * ConversationStage enum.
                         * @name google.cloud.dialogflow.v2.Conversation.ConversationStage
                         * @enum {number}
                         * @property {number} CONVERSATION_STAGE_UNSPECIFIED=0 CONVERSATION_STAGE_UNSPECIFIED value
                         * @property {number} VIRTUAL_AGENT_STAGE=1 VIRTUAL_AGENT_STAGE value
                         * @property {number} HUMAN_ASSIST_STAGE=2 HUMAN_ASSIST_STAGE value
                         */
                        Conversation.ConversationStage = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "CONVERSATION_STAGE_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "VIRTUAL_AGENT_STAGE"] = 1;
                            values[valuesById[2] = "HUMAN_ASSIST_STAGE"] = 2;
                            return values;
                        })();
    
                        Conversation.TelephonyConnectionInfo = (function() {
    
                            /**
                             * Properties of a TelephonyConnectionInfo.
                             * @memberof google.cloud.dialogflow.v2.Conversation
                             * @interface ITelephonyConnectionInfo
                             * @property {string|null} [dialedNumber] TelephonyConnectionInfo dialedNumber
                             * @property {string|null} [sdp] TelephonyConnectionInfo sdp
                             * @property {Array.<google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.ISipHeader>|null} [sipHeaders] TelephonyConnectionInfo sipHeaders
                             * @property {Array.<google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.IMimeContent>|null} [extraMimeContents] TelephonyConnectionInfo extraMimeContents
                             */
    
                            /**
                             * Constructs a new TelephonyConnectionInfo.
                             * @memberof google.cloud.dialogflow.v2.Conversation
                             * @classdesc Represents a TelephonyConnectionInfo.
                             * @implements ITelephonyConnectionInfo
                             * @constructor
                             * @param {google.cloud.dialogflow.v2.Conversation.ITelephonyConnectionInfo=} [properties] Properties to set
                             */
                            function TelephonyConnectionInfo(properties) {
                                this.sipHeaders = [];
                                this.extraMimeContents = [];
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * TelephonyConnectionInfo dialedNumber.
                             * @member {string} dialedNumber
                             * @memberof google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo
                             * @instance
                             */
                            TelephonyConnectionInfo.prototype.dialedNumber = "";
    
                            /**
                             * TelephonyConnectionInfo sdp.
                             * @member {string} sdp
                             * @memberof google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo
                             * @instance
                             */
                            TelephonyConnectionInfo.prototype.sdp = "";
    
                            /**
                             * TelephonyConnectionInfo sipHeaders.
                             * @member {Array.<google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.ISipHeader>} sipHeaders
                             * @memberof google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo
                             * @instance
                             */
                            TelephonyConnectionInfo.prototype.sipHeaders = $util.emptyArray;
    
                            /**
                             * TelephonyConnectionInfo extraMimeContents.
                             * @member {Array.<google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.IMimeContent>} extraMimeContents
                             * @memberof google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo
                             * @instance
                             */
                            TelephonyConnectionInfo.prototype.extraMimeContents = $util.emptyArray;
    
                            /**
                             * Creates a new TelephonyConnectionInfo instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo
                             * @static
                             * @param {google.cloud.dialogflow.v2.Conversation.ITelephonyConnectionInfo=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo} TelephonyConnectionInfo instance
                             */
                            TelephonyConnectionInfo.create = function create(properties) {
                                return new TelephonyConnectionInfo(properties);
                            };
    
                            /**
                             * Encodes the specified TelephonyConnectionInfo message. Does not implicitly {@link google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo
                             * @static
                             * @param {google.cloud.dialogflow.v2.Conversation.ITelephonyConnectionInfo} message TelephonyConnectionInfo message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            TelephonyConnectionInfo.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.dialedNumber != null && Object.hasOwnProperty.call(message, "dialedNumber"))
                                    writer.uint32(/* id 2, wireType 2 =*/18).string(message.dialedNumber);
                                if (message.sdp != null && Object.hasOwnProperty.call(message, "sdp"))
                                    writer.uint32(/* id 5, wireType 2 =*/42).string(message.sdp);
                                if (message.sipHeaders != null && message.sipHeaders.length)
                                    for (var i = 0; i < message.sipHeaders.length; ++i)
                                        $root.google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.SipHeader.encode(message.sipHeaders[i], writer.uint32(/* id 12, wireType 2 =*/98).fork()).ldelim();
                                if (message.extraMimeContents != null && message.extraMimeContents.length)
                                    for (var i = 0; i < message.extraMimeContents.length; ++i)
                                        $root.google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.MimeContent.encode(message.extraMimeContents[i], writer.uint32(/* id 13, wireType 2 =*/106).fork()).ldelim();
                                return writer;
                            };
    
                            /**
                             * Encodes the specified TelephonyConnectionInfo message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo
                             * @static
                             * @param {google.cloud.dialogflow.v2.Conversation.ITelephonyConnectionInfo} message TelephonyConnectionInfo message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            TelephonyConnectionInfo.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a TelephonyConnectionInfo message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo} TelephonyConnectionInfo
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            TelephonyConnectionInfo.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 2: {
                                            message.dialedNumber = reader.string();
                                            break;
                                        }
                                    case 5: {
                                            message.sdp = reader.string();
                                            break;
                                        }
                                    case 12: {
                                            if (!(message.sipHeaders && message.sipHeaders.length))
                                                message.sipHeaders = [];
                                            message.sipHeaders.push($root.google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.SipHeader.decode(reader, reader.uint32()));
                                            break;
                                        }
                                    case 13: {
                                            if (!(message.extraMimeContents && message.extraMimeContents.length))
                                                message.extraMimeContents = [];
                                            message.extraMimeContents.push($root.google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.MimeContent.decode(reader, reader.uint32()));
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a TelephonyConnectionInfo message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo} TelephonyConnectionInfo
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            TelephonyConnectionInfo.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a TelephonyConnectionInfo message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            TelephonyConnectionInfo.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.dialedNumber != null && message.hasOwnProperty("dialedNumber"))
                                    if (!$util.isString(message.dialedNumber))
                                        return "dialedNumber: string expected";
                                if (message.sdp != null && message.hasOwnProperty("sdp"))
                                    if (!$util.isString(message.sdp))
                                        return "sdp: string expected";
                                if (message.sipHeaders != null && message.hasOwnProperty("sipHeaders")) {
                                    if (!Array.isArray(message.sipHeaders))
                                        return "sipHeaders: array expected";
                                    for (var i = 0; i < message.sipHeaders.length; ++i) {
                                        var error = $root.google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.SipHeader.verify(message.sipHeaders[i]);
                                        if (error)
                                            return "sipHeaders." + error;
                                    }
                                }
                                if (message.extraMimeContents != null && message.hasOwnProperty("extraMimeContents")) {
                                    if (!Array.isArray(message.extraMimeContents))
                                        return "extraMimeContents: array expected";
                                    for (var i = 0; i < message.extraMimeContents.length; ++i) {
                                        var error = $root.google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.MimeContent.verify(message.extraMimeContents[i]);
                                        if (error)
                                            return "extraMimeContents." + error;
                                    }
                                }
                                return null;
                            };
    
                            /**
                             * Creates a TelephonyConnectionInfo message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo} TelephonyConnectionInfo
                             */
                            TelephonyConnectionInfo.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo();
                                if (object.dialedNumber != null)
                                    message.dialedNumber = String(object.dialedNumber);
                                if (object.sdp != null)
                                    message.sdp = String(object.sdp);
                                if (object.sipHeaders) {
                                    if (!Array.isArray(object.sipHeaders))
                                        throw TypeError(".google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.sipHeaders: array expected");
                                    message.sipHeaders = [];
                                    for (var i = 0; i < object.sipHeaders.length; ++i) {
                                        if (typeof object.sipHeaders[i] !== "object")
                                            throw TypeError(".google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.sipHeaders: object expected");
                                        message.sipHeaders[i] = $root.google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.SipHeader.fromObject(object.sipHeaders[i]);
                                    }
                                }
                                if (object.extraMimeContents) {
                                    if (!Array.isArray(object.extraMimeContents))
                                        throw TypeError(".google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.extraMimeContents: array expected");
                                    message.extraMimeContents = [];
                                    for (var i = 0; i < object.extraMimeContents.length; ++i) {
                                        if (typeof object.extraMimeContents[i] !== "object")
                                            throw TypeError(".google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.extraMimeContents: object expected");
                                        message.extraMimeContents[i] = $root.google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.MimeContent.fromObject(object.extraMimeContents[i]);
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a TelephonyConnectionInfo message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo
                             * @static
                             * @param {google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo} message TelephonyConnectionInfo
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            TelephonyConnectionInfo.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.arrays || options.defaults) {
                                    object.sipHeaders = [];
                                    object.extraMimeContents = [];
                                }
                                if (options.defaults) {
                                    object.dialedNumber = "";
                                    object.sdp = "";
                                }
                                if (message.dialedNumber != null && message.hasOwnProperty("dialedNumber"))
                                    object.dialedNumber = message.dialedNumber;
                                if (message.sdp != null && message.hasOwnProperty("sdp"))
                                    object.sdp = message.sdp;
                                if (message.sipHeaders && message.sipHeaders.length) {
                                    object.sipHeaders = [];
                                    for (var j = 0; j < message.sipHeaders.length; ++j)
                                        object.sipHeaders[j] = $root.google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.SipHeader.toObject(message.sipHeaders[j], options);
                                }
                                if (message.extraMimeContents && message.extraMimeContents.length) {
                                    object.extraMimeContents = [];
                                    for (var j = 0; j < message.extraMimeContents.length; ++j)
                                        object.extraMimeContents[j] = $root.google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.MimeContent.toObject(message.extraMimeContents[j], options);
                                }
                                return object;
                            };
    
                            /**
                             * Converts this TelephonyConnectionInfo to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            TelephonyConnectionInfo.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for TelephonyConnectionInfo
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            TelephonyConnectionInfo.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo";
                            };
    
                            TelephonyConnectionInfo.SipHeader = (function() {
    
                                /**
                                 * Properties of a SipHeader.
                                 * @memberof google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo
                                 * @interface ISipHeader
                                 * @property {string|null} [name] SipHeader name
                                 * @property {string|null} [value] SipHeader value
                                 */
    
                                /**
                                 * Constructs a new SipHeader.
                                 * @memberof google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo
                                 * @classdesc Represents a SipHeader.
                                 * @implements ISipHeader
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.ISipHeader=} [properties] Properties to set
                                 */
                                function SipHeader(properties) {
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * SipHeader name.
                                 * @member {string} name
                                 * @memberof google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.SipHeader
                                 * @instance
                                 */
                                SipHeader.prototype.name = "";
    
                                /**
                                 * SipHeader value.
                                 * @member {string} value
                                 * @memberof google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.SipHeader
                                 * @instance
                                 */
                                SipHeader.prototype.value = "";
    
                                /**
                                 * Creates a new SipHeader instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.SipHeader
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.ISipHeader=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.SipHeader} SipHeader instance
                                 */
                                SipHeader.create = function create(properties) {
                                    return new SipHeader(properties);
                                };
    
                                /**
                                 * Encodes the specified SipHeader message. Does not implicitly {@link google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.SipHeader.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.SipHeader
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.ISipHeader} message SipHeader message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                SipHeader.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                                    if (message.value != null && Object.hasOwnProperty.call(message, "value"))
                                        writer.uint32(/* id 2, wireType 2 =*/18).string(message.value);
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified SipHeader message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.SipHeader.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.SipHeader
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.ISipHeader} message SipHeader message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                SipHeader.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a SipHeader message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.SipHeader
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.SipHeader} SipHeader
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                SipHeader.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.SipHeader();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                message.name = reader.string();
                                                break;
                                            }
                                        case 2: {
                                                message.value = reader.string();
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a SipHeader message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.SipHeader
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.SipHeader} SipHeader
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                SipHeader.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a SipHeader message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.SipHeader
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                SipHeader.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.name != null && message.hasOwnProperty("name"))
                                        if (!$util.isString(message.name))
                                            return "name: string expected";
                                    if (message.value != null && message.hasOwnProperty("value"))
                                        if (!$util.isString(message.value))
                                            return "value: string expected";
                                    return null;
                                };
    
                                /**
                                 * Creates a SipHeader message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.SipHeader
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.SipHeader} SipHeader
                                 */
                                SipHeader.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.SipHeader)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.SipHeader();
                                    if (object.name != null)
                                        message.name = String(object.name);
                                    if (object.value != null)
                                        message.value = String(object.value);
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a SipHeader message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.SipHeader
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.SipHeader} message SipHeader
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                SipHeader.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.defaults) {
                                        object.name = "";
                                        object.value = "";
                                    }
                                    if (message.name != null && message.hasOwnProperty("name"))
                                        object.name = message.name;
                                    if (message.value != null && message.hasOwnProperty("value"))
                                        object.value = message.value;
                                    return object;
                                };
    
                                /**
                                 * Converts this SipHeader to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.SipHeader
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                SipHeader.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for SipHeader
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.SipHeader
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                SipHeader.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.SipHeader";
                                };
    
                                return SipHeader;
                            })();
    
                            TelephonyConnectionInfo.MimeContent = (function() {
    
                                /**
                                 * Properties of a MimeContent.
                                 * @memberof google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo
                                 * @interface IMimeContent
                                 * @property {string|null} [mimeType] MimeContent mimeType
                                 * @property {Uint8Array|null} [content] MimeContent content
                                 */
    
                                /**
                                 * Constructs a new MimeContent.
                                 * @memberof google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo
                                 * @classdesc Represents a MimeContent.
                                 * @implements IMimeContent
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.IMimeContent=} [properties] Properties to set
                                 */
                                function MimeContent(properties) {
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * MimeContent mimeType.
                                 * @member {string} mimeType
                                 * @memberof google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.MimeContent
                                 * @instance
                                 */
                                MimeContent.prototype.mimeType = "";
    
                                /**
                                 * MimeContent content.
                                 * @member {Uint8Array} content
                                 * @memberof google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.MimeContent
                                 * @instance
                                 */
                                MimeContent.prototype.content = $util.newBuffer([]);
    
                                /**
                                 * Creates a new MimeContent instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.MimeContent
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.IMimeContent=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.MimeContent} MimeContent instance
                                 */
                                MimeContent.create = function create(properties) {
                                    return new MimeContent(properties);
                                };
    
                                /**
                                 * Encodes the specified MimeContent message. Does not implicitly {@link google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.MimeContent.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.MimeContent
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.IMimeContent} message MimeContent message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                MimeContent.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.mimeType != null && Object.hasOwnProperty.call(message, "mimeType"))
                                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.mimeType);
                                    if (message.content != null && Object.hasOwnProperty.call(message, "content"))
                                        writer.uint32(/* id 2, wireType 2 =*/18).bytes(message.content);
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified MimeContent message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.MimeContent.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.MimeContent
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.IMimeContent} message MimeContent message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                MimeContent.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a MimeContent message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.MimeContent
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.MimeContent} MimeContent
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                MimeContent.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.MimeContent();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                message.mimeType = reader.string();
                                                break;
                                            }
                                        case 2: {
                                                message.content = reader.bytes();
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a MimeContent message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.MimeContent
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.MimeContent} MimeContent
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                MimeContent.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a MimeContent message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.MimeContent
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                MimeContent.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.mimeType != null && message.hasOwnProperty("mimeType"))
                                        if (!$util.isString(message.mimeType))
                                            return "mimeType: string expected";
                                    if (message.content != null && message.hasOwnProperty("content"))
                                        if (!(message.content && typeof message.content.length === "number" || $util.isString(message.content)))
                                            return "content: buffer expected";
                                    return null;
                                };
    
                                /**
                                 * Creates a MimeContent message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.MimeContent
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.MimeContent} MimeContent
                                 */
                                MimeContent.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.MimeContent)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.MimeContent();
                                    if (object.mimeType != null)
                                        message.mimeType = String(object.mimeType);
                                    if (object.content != null)
                                        if (typeof object.content === "string")
                                            $util.base64.decode(object.content, message.content = $util.newBuffer($util.base64.length(object.content)), 0);
                                        else if (object.content.length >= 0)
                                            message.content = object.content;
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a MimeContent message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.MimeContent
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.MimeContent} message MimeContent
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                MimeContent.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.defaults) {
                                        object.mimeType = "";
                                        if (options.bytes === String)
                                            object.content = "";
                                        else {
                                            object.content = [];
                                            if (options.bytes !== Array)
                                                object.content = $util.newBuffer(object.content);
                                        }
                                    }
                                    if (message.mimeType != null && message.hasOwnProperty("mimeType"))
                                        object.mimeType = message.mimeType;
                                    if (message.content != null && message.hasOwnProperty("content"))
                                        object.content = options.bytes === String ? $util.base64.encode(message.content, 0, message.content.length) : options.bytes === Array ? Array.prototype.slice.call(message.content) : message.content;
                                    return object;
                                };
    
                                /**
                                 * Converts this MimeContent to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.MimeContent
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                MimeContent.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for MimeContent
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.MimeContent
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                MimeContent.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2.Conversation.TelephonyConnectionInfo.MimeContent";
                                };
    
                                return MimeContent;
                            })();
    
                            return TelephonyConnectionInfo;
                        })();
    
                        Conversation.ContextReference = (function() {
    
                            /**
                             * Properties of a ContextReference.
                             * @memberof google.cloud.dialogflow.v2.Conversation
                             * @interface IContextReference
                             * @property {Array.<google.cloud.dialogflow.v2.Conversation.ContextReference.IContextContent>|null} [contextContents] ContextReference contextContents
                             * @property {google.cloud.dialogflow.v2.Conversation.ContextReference.UpdateMode|null} [updateMode] ContextReference updateMode
                             * @property {string|null} [languageCode] ContextReference languageCode
                             * @property {google.protobuf.ITimestamp|null} [createTime] ContextReference createTime
                             */
    
                            /**
                             * Constructs a new ContextReference.
                             * @memberof google.cloud.dialogflow.v2.Conversation
                             * @classdesc Represents a ContextReference.
                             * @implements IContextReference
                             * @constructor
                             * @param {google.cloud.dialogflow.v2.Conversation.IContextReference=} [properties] Properties to set
                             */
                            function ContextReference(properties) {
                                this.contextContents = [];
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * ContextReference contextContents.
                             * @member {Array.<google.cloud.dialogflow.v2.Conversation.ContextReference.IContextContent>} contextContents
                             * @memberof google.cloud.dialogflow.v2.Conversation.ContextReference
                             * @instance
                             */
                            ContextReference.prototype.contextContents = $util.emptyArray;
    
                            /**
                             * ContextReference updateMode.
                             * @member {google.cloud.dialogflow.v2.Conversation.ContextReference.UpdateMode} updateMode
                             * @memberof google.cloud.dialogflow.v2.Conversation.ContextReference
                             * @instance
                             */
                            ContextReference.prototype.updateMode = 0;
    
                            /**
                             * ContextReference languageCode.
                             * @member {string} languageCode
                             * @memberof google.cloud.dialogflow.v2.Conversation.ContextReference
                             * @instance
                             */
                            ContextReference.prototype.languageCode = "";
    
                            /**
                             * ContextReference createTime.
                             * @member {google.protobuf.ITimestamp|null|undefined} createTime
                             * @memberof google.cloud.dialogflow.v2.Conversation.ContextReference
                             * @instance
                             */
                            ContextReference.prototype.createTime = null;
    
                            /**
                             * Creates a new ContextReference instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2.Conversation.ContextReference
                             * @static
                             * @param {google.cloud.dialogflow.v2.Conversation.IContextReference=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2.Conversation.ContextReference} ContextReference instance
                             */
                            ContextReference.create = function create(properties) {
                                return new ContextReference(properties);
                            };
    
                            /**
                             * Encodes the specified ContextReference message. Does not implicitly {@link google.cloud.dialogflow.v2.Conversation.ContextReference.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2.Conversation.ContextReference
                             * @static
                             * @param {google.cloud.dialogflow.v2.Conversation.IContextReference} message ContextReference message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            ContextReference.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.contextContents != null && message.contextContents.length)
                                    for (var i = 0; i < message.contextContents.length; ++i)
                                        $root.google.cloud.dialogflow.v2.Conversation.ContextReference.ContextContent.encode(message.contextContents[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                                if (message.updateMode != null && Object.hasOwnProperty.call(message, "updateMode"))
                                    writer.uint32(/* id 2, wireType 0 =*/16).int32(message.updateMode);
                                if (message.languageCode != null && Object.hasOwnProperty.call(message, "languageCode"))
                                    writer.uint32(/* id 3, wireType 2 =*/26).string(message.languageCode);
                                if (message.createTime != null && Object.hasOwnProperty.call(message, "createTime"))
                                    $root.google.protobuf.Timestamp.encode(message.createTime, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                                return writer;
                            };
    
                            /**
                             * Encodes the specified ContextReference message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.Conversation.ContextReference.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2.Conversation.ContextReference
                             * @static
                             * @param {google.cloud.dialogflow.v2.Conversation.IContextReference} message ContextReference message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            ContextReference.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a ContextReference message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2.Conversation.ContextReference
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2.Conversation.ContextReference} ContextReference
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            ContextReference.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.Conversation.ContextReference();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            if (!(message.contextContents && message.contextContents.length))
                                                message.contextContents = [];
                                            message.contextContents.push($root.google.cloud.dialogflow.v2.Conversation.ContextReference.ContextContent.decode(reader, reader.uint32()));
                                            break;
                                        }
                                    case 2: {
                                            message.updateMode = reader.int32();
                                            break;
                                        }
                                    case 3: {
                                            message.languageCode = reader.string();
                                            break;
                                        }
                                    case 4: {
                                            message.createTime = $root.google.protobuf.Timestamp.decode(reader, reader.uint32());
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a ContextReference message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2.Conversation.ContextReference
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2.Conversation.ContextReference} ContextReference
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            ContextReference.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a ContextReference message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2.Conversation.ContextReference
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            ContextReference.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.contextContents != null && message.hasOwnProperty("contextContents")) {
                                    if (!Array.isArray(message.contextContents))
                                        return "contextContents: array expected";
                                    for (var i = 0; i < message.contextContents.length; ++i) {
                                        var error = $root.google.cloud.dialogflow.v2.Conversation.ContextReference.ContextContent.verify(message.contextContents[i]);
                                        if (error)
                                            return "contextContents." + error;
                                    }
                                }
                                if (message.updateMode != null && message.hasOwnProperty("updateMode"))
                                    switch (message.updateMode) {
                                    default:
                                        return "updateMode: enum value expected";
                                    case 0:
                                    case 1:
                                    case 2:
                                        break;
                                    }
                                if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                    if (!$util.isString(message.languageCode))
                                        return "languageCode: string expected";
                                if (message.createTime != null && message.hasOwnProperty("createTime")) {
                                    var error = $root.google.protobuf.Timestamp.verify(message.createTime);
                                    if (error)
                                        return "createTime." + error;
                                }
                                return null;
                            };
    
                            /**
                             * Creates a ContextReference message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2.Conversation.ContextReference
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2.Conversation.ContextReference} ContextReference
                             */
                            ContextReference.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2.Conversation.ContextReference)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2.Conversation.ContextReference();
                                if (object.contextContents) {
                                    if (!Array.isArray(object.contextContents))
                                        throw TypeError(".google.cloud.dialogflow.v2.Conversation.ContextReference.contextContents: array expected");
                                    message.contextContents = [];
                                    for (var i = 0; i < object.contextContents.length; ++i) {
                                        if (typeof object.contextContents[i] !== "object")
                                            throw TypeError(".google.cloud.dialogflow.v2.Conversation.ContextReference.contextContents: object expected");
                                        message.contextContents[i] = $root.google.cloud.dialogflow.v2.Conversation.ContextReference.ContextContent.fromObject(object.contextContents[i]);
                                    }
                                }
                                switch (object.updateMode) {
                                default:
                                    if (typeof object.updateMode === "number") {
                                        message.updateMode = object.updateMode;
                                        break;
                                    }
                                    break;
                                case "UPDATE_MODE_UNSPECIFIED":
                                case 0:
                                    message.updateMode = 0;
                                    break;
                                case "APPEND":
                                case 1:
                                    message.updateMode = 1;
                                    break;
                                case "OVERWRITE":
                                case 2:
                                    message.updateMode = 2;
                                    break;
                                }
                                if (object.languageCode != null)
                                    message.languageCode = String(object.languageCode);
                                if (object.createTime != null) {
                                    if (typeof object.createTime !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.Conversation.ContextReference.createTime: object expected");
                                    message.createTime = $root.google.protobuf.Timestamp.fromObject(object.createTime);
                                }
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a ContextReference message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2.Conversation.ContextReference
                             * @static
                             * @param {google.cloud.dialogflow.v2.Conversation.ContextReference} message ContextReference
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            ContextReference.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.arrays || options.defaults)
                                    object.contextContents = [];
                                if (options.defaults) {
                                    object.updateMode = options.enums === String ? "UPDATE_MODE_UNSPECIFIED" : 0;
                                    object.languageCode = "";
                                    object.createTime = null;
                                }
                                if (message.contextContents && message.contextContents.length) {
                                    object.contextContents = [];
                                    for (var j = 0; j < message.contextContents.length; ++j)
                                        object.contextContents[j] = $root.google.cloud.dialogflow.v2.Conversation.ContextReference.ContextContent.toObject(message.contextContents[j], options);
                                }
                                if (message.updateMode != null && message.hasOwnProperty("updateMode"))
                                    object.updateMode = options.enums === String ? $root.google.cloud.dialogflow.v2.Conversation.ContextReference.UpdateMode[message.updateMode] === undefined ? message.updateMode : $root.google.cloud.dialogflow.v2.Conversation.ContextReference.UpdateMode[message.updateMode] : message.updateMode;
                                if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                    object.languageCode = message.languageCode;
                                if (message.createTime != null && message.hasOwnProperty("createTime"))
                                    object.createTime = $root.google.protobuf.Timestamp.toObject(message.createTime, options);
                                return object;
                            };
    
                            /**
                             * Converts this ContextReference to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2.Conversation.ContextReference
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            ContextReference.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for ContextReference
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2.Conversation.ContextReference
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            ContextReference.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2.Conversation.ContextReference";
                            };
    
                            ContextReference.ContextContent = (function() {
    
                                /**
                                 * Properties of a ContextContent.
                                 * @memberof google.cloud.dialogflow.v2.Conversation.ContextReference
                                 * @interface IContextContent
                                 * @property {string|null} [content] ContextContent content
                                 * @property {google.cloud.dialogflow.v2.Conversation.ContextReference.ContextContent.ContentFormat|null} [contentFormat] ContextContent contentFormat
                                 * @property {google.protobuf.ITimestamp|null} [ingestionTime] ContextContent ingestionTime
                                 */
    
                                /**
                                 * Constructs a new ContextContent.
                                 * @memberof google.cloud.dialogflow.v2.Conversation.ContextReference
                                 * @classdesc Represents a ContextContent.
                                 * @implements IContextContent
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2.Conversation.ContextReference.IContextContent=} [properties] Properties to set
                                 */
                                function ContextContent(properties) {
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * ContextContent content.
                                 * @member {string} content
                                 * @memberof google.cloud.dialogflow.v2.Conversation.ContextReference.ContextContent
                                 * @instance
                                 */
                                ContextContent.prototype.content = "";
    
                                /**
                                 * ContextContent contentFormat.
                                 * @member {google.cloud.dialogflow.v2.Conversation.ContextReference.ContextContent.ContentFormat} contentFormat
                                 * @memberof google.cloud.dialogflow.v2.Conversation.ContextReference.ContextContent
                                 * @instance
                                 */
                                ContextContent.prototype.contentFormat = 0;
    
                                /**
                                 * ContextContent ingestionTime.
                                 * @member {google.protobuf.ITimestamp|null|undefined} ingestionTime
                                 * @memberof google.cloud.dialogflow.v2.Conversation.ContextReference.ContextContent
                                 * @instance
                                 */
                                ContextContent.prototype.ingestionTime = null;
    
                                /**
                                 * Creates a new ContextContent instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2.Conversation.ContextReference.ContextContent
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Conversation.ContextReference.IContextContent=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2.Conversation.ContextReference.ContextContent} ContextContent instance
                                 */
                                ContextContent.create = function create(properties) {
                                    return new ContextContent(properties);
                                };
    
                                /**
                                 * Encodes the specified ContextContent message. Does not implicitly {@link google.cloud.dialogflow.v2.Conversation.ContextReference.ContextContent.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2.Conversation.ContextReference.ContextContent
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Conversation.ContextReference.IContextContent} message ContextContent message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                ContextContent.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.content != null && Object.hasOwnProperty.call(message, "content"))
                                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.content);
                                    if (message.contentFormat != null && Object.hasOwnProperty.call(message, "contentFormat"))
                                        writer.uint32(/* id 2, wireType 0 =*/16).int32(message.contentFormat);
                                    if (message.ingestionTime != null && Object.hasOwnProperty.call(message, "ingestionTime"))
                                        $root.google.protobuf.Timestamp.encode(message.ingestionTime, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified ContextContent message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.Conversation.ContextReference.ContextContent.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.Conversation.ContextReference.ContextContent
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Conversation.ContextReference.IContextContent} message ContextContent message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                ContextContent.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a ContextContent message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2.Conversation.ContextReference.ContextContent
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2.Conversation.ContextReference.ContextContent} ContextContent
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                ContextContent.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.Conversation.ContextReference.ContextContent();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                message.content = reader.string();
                                                break;
                                            }
                                        case 2: {
                                                message.contentFormat = reader.int32();
                                                break;
                                            }
                                        case 3: {
                                                message.ingestionTime = $root.google.protobuf.Timestamp.decode(reader, reader.uint32());
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a ContextContent message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.Conversation.ContextReference.ContextContent
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2.Conversation.ContextReference.ContextContent} ContextContent
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                ContextContent.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a ContextContent message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2.Conversation.ContextReference.ContextContent
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                ContextContent.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.content != null && message.hasOwnProperty("content"))
                                        if (!$util.isString(message.content))
                                            return "content: string expected";
                                    if (message.contentFormat != null && message.hasOwnProperty("contentFormat"))
                                        switch (message.contentFormat) {
                                        default:
                                            return "contentFormat: enum value expected";
                                        case 0:
                                        case 1:
                                        case 2:
                                            break;
                                        }
                                    if (message.ingestionTime != null && message.hasOwnProperty("ingestionTime")) {
                                        var error = $root.google.protobuf.Timestamp.verify(message.ingestionTime);
                                        if (error)
                                            return "ingestionTime." + error;
                                    }
                                    return null;
                                };
    
                                /**
                                 * Creates a ContextContent message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2.Conversation.ContextReference.ContextContent
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2.Conversation.ContextReference.ContextContent} ContextContent
                                 */
                                ContextContent.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2.Conversation.ContextReference.ContextContent)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2.Conversation.ContextReference.ContextContent();
                                    if (object.content != null)
                                        message.content = String(object.content);
                                    switch (object.contentFormat) {
                                    default:
                                        if (typeof object.contentFormat === "number") {
                                            message.contentFormat = object.contentFormat;
                                            break;
                                        }
                                        break;
                                    case "CONTENT_FORMAT_UNSPECIFIED":
                                    case 0:
                                        message.contentFormat = 0;
                                        break;
                                    case "JSON":
                                    case 1:
                                        message.contentFormat = 1;
                                        break;
                                    case "PLAIN_TEXT":
                                    case 2:
                                        message.contentFormat = 2;
                                        break;
                                    }
                                    if (object.ingestionTime != null) {
                                        if (typeof object.ingestionTime !== "object")
                                            throw TypeError(".google.cloud.dialogflow.v2.Conversation.ContextReference.ContextContent.ingestionTime: object expected");
                                        message.ingestionTime = $root.google.protobuf.Timestamp.fromObject(object.ingestionTime);
                                    }
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a ContextContent message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2.Conversation.ContextReference.ContextContent
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.Conversation.ContextReference.ContextContent} message ContextContent
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                ContextContent.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.defaults) {
                                        object.content = "";
                                        object.contentFormat = options.enums === String ? "CONTENT_FORMAT_UNSPECIFIED" : 0;
                                        object.ingestionTime = null;
                                    }
                                    if (message.content != null && message.hasOwnProperty("content"))
                                        object.content = message.content;
                                    if (message.contentFormat != null && message.hasOwnProperty("contentFormat"))
                                        object.contentFormat = options.enums === String ? $root.google.cloud.dialogflow.v2.Conversation.ContextReference.ContextContent.ContentFormat[message.contentFormat] === undefined ? message.contentFormat : $root.google.cloud.dialogflow.v2.Conversation.ContextReference.ContextContent.ContentFormat[message.contentFormat] : message.contentFormat;
                                    if (message.ingestionTime != null && message.hasOwnProperty("ingestionTime"))
                                        object.ingestionTime = $root.google.protobuf.Timestamp.toObject(message.ingestionTime, options);
                                    return object;
                                };
    
                                /**
                                 * Converts this ContextContent to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2.Conversation.ContextReference.ContextContent
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                ContextContent.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for ContextContent
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2.Conversation.ContextReference.ContextContent
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                ContextContent.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2.Conversation.ContextReference.ContextContent";
                                };
    
                                /**
                                 * ContentFormat enum.
                                 * @name google.cloud.dialogflow.v2.Conversation.ContextReference.ContextContent.ContentFormat
                                 * @enum {number}
                                 * @property {number} CONTENT_FORMAT_UNSPECIFIED=0 CONTENT_FORMAT_UNSPECIFIED value
                                 * @property {number} JSON=1 JSON value
                                 * @property {number} PLAIN_TEXT=2 PLAIN_TEXT value
                                 */
                                ContextContent.ContentFormat = (function() {
                                    var valuesById = {}, values = Object.create(valuesById);
                                    values[valuesById[0] = "CONTENT_FORMAT_UNSPECIFIED"] = 0;
                                    values[valuesById[1] = "JSON"] = 1;
                                    values[valuesById[2] = "PLAIN_TEXT"] = 2;
                                    return values;
                                })();
    
                                return ContextContent;
                            })();
    
                            /**
                             * UpdateMode enum.
                             * @name google.cloud.dialogflow.v2.Conversation.ContextReference.UpdateMode
                             * @enum {number}
                             * @property {number} UPDATE_MODE_UNSPECIFIED=0 UPDATE_MODE_UNSPECIFIED value
                             * @property {number} APPEND=1 APPEND value
                             * @property {number} OVERWRITE=2 OVERWRITE value
                             */
                            ContextReference.UpdateMode = (function() {
                                var valuesById = {}, values = Object.create(valuesById);
                                values[valuesById[0] = "UPDATE_MODE_UNSPECIFIED"] = 0;
                                values[valuesById[1] = "APPEND"] = 1;
                                values[valuesById[2] = "OVERWRITE"] = 2;
                                return values;
                            })();
    
                            return ContextReference;
                        })();
    
                        return Conversation;
                    })();
    
                    v2.CreateConversationRequest = (function() {
    
                        /**
                         * Properties of a CreateConversationRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ICreateConversationRequest
                         * @property {string|null} [parent] CreateConversationRequest parent
                         * @property {google.cloud.dialogflow.v2.IConversation|null} [conversation] CreateConversationRequest conversation
                         * @property {string|null} [conversationId] CreateConversationRequest conversationId
                         */
    
                        /**
                         * Constructs a new CreateConversationRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a CreateConversationRequest.
                         * @implements ICreateConversationRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ICreateConversationRequest=} [properties] Properties to set
                         */
                        function CreateConversationRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * CreateConversationRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.CreateConversationRequest
                         * @instance
                         */
                        CreateConversationRequest.prototype.parent = "";
    
                        /**
                         * CreateConversationRequest conversation.
                         * @member {google.cloud.dialogflow.v2.IConversation|null|undefined} conversation
                         * @memberof google.cloud.dialogflow.v2.CreateConversationRequest
                         * @instance
                         */
                        CreateConversationRequest.prototype.conversation = null;
    
                        /**
                         * CreateConversationRequest conversationId.
                         * @member {string} conversationId
                         * @memberof google.cloud.dialogflow.v2.CreateConversationRequest
                         * @instance
                         */
                        CreateConversationRequest.prototype.conversationId = "";
    
                        /**
                         * Creates a new CreateConversationRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.CreateConversationRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICreateConversationRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.CreateConversationRequest} CreateConversationRequest instance
                         */
                        CreateConversationRequest.create = function create(properties) {
                            return new CreateConversationRequest(properties);
                        };
    
                        /**
                         * Encodes the specified CreateConversationRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.CreateConversationRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.CreateConversationRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICreateConversationRequest} message CreateConversationRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateConversationRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.conversation != null && Object.hasOwnProperty.call(message, "conversation"))
                                $root.google.cloud.dialogflow.v2.Conversation.encode(message.conversation, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.conversationId != null && Object.hasOwnProperty.call(message, "conversationId"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.conversationId);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified CreateConversationRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.CreateConversationRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.CreateConversationRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICreateConversationRequest} message CreateConversationRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateConversationRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a CreateConversationRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.CreateConversationRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.CreateConversationRequest} CreateConversationRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateConversationRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.CreateConversationRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.conversation = $root.google.cloud.dialogflow.v2.Conversation.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 3: {
                                        message.conversationId = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a CreateConversationRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.CreateConversationRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.CreateConversationRequest} CreateConversationRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateConversationRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a CreateConversationRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.CreateConversationRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        CreateConversationRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.conversation != null && message.hasOwnProperty("conversation")) {
                                var error = $root.google.cloud.dialogflow.v2.Conversation.verify(message.conversation);
                                if (error)
                                    return "conversation." + error;
                            }
                            if (message.conversationId != null && message.hasOwnProperty("conversationId"))
                                if (!$util.isString(message.conversationId))
                                    return "conversationId: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a CreateConversationRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.CreateConversationRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.CreateConversationRequest} CreateConversationRequest
                         */
                        CreateConversationRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.CreateConversationRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.CreateConversationRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.conversation != null) {
                                if (typeof object.conversation !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.CreateConversationRequest.conversation: object expected");
                                message.conversation = $root.google.cloud.dialogflow.v2.Conversation.fromObject(object.conversation);
                            }
                            if (object.conversationId != null)
                                message.conversationId = String(object.conversationId);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a CreateConversationRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.CreateConversationRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.CreateConversationRequest} message CreateConversationRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        CreateConversationRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.conversation = null;
                                object.conversationId = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.conversation != null && message.hasOwnProperty("conversation"))
                                object.conversation = $root.google.cloud.dialogflow.v2.Conversation.toObject(message.conversation, options);
                            if (message.conversationId != null && message.hasOwnProperty("conversationId"))
                                object.conversationId = message.conversationId;
                            return object;
                        };
    
                        /**
                         * Converts this CreateConversationRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.CreateConversationRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        CreateConversationRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for CreateConversationRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.CreateConversationRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        CreateConversationRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.CreateConversationRequest";
                        };
    
                        return CreateConversationRequest;
                    })();
    
                    v2.ListConversationsRequest = (function() {
    
                        /**
                         * Properties of a ListConversationsRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IListConversationsRequest
                         * @property {string|null} [parent] ListConversationsRequest parent
                         * @property {number|null} [pageSize] ListConversationsRequest pageSize
                         * @property {string|null} [pageToken] ListConversationsRequest pageToken
                         * @property {string|null} [filter] ListConversationsRequest filter
                         */
    
                        /**
                         * Constructs a new ListConversationsRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a ListConversationsRequest.
                         * @implements IListConversationsRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IListConversationsRequest=} [properties] Properties to set
                         */
                        function ListConversationsRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListConversationsRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.ListConversationsRequest
                         * @instance
                         */
                        ListConversationsRequest.prototype.parent = "";
    
                        /**
                         * ListConversationsRequest pageSize.
                         * @member {number} pageSize
                         * @memberof google.cloud.dialogflow.v2.ListConversationsRequest
                         * @instance
                         */
                        ListConversationsRequest.prototype.pageSize = 0;
    
                        /**
                         * ListConversationsRequest pageToken.
                         * @member {string} pageToken
                         * @memberof google.cloud.dialogflow.v2.ListConversationsRequest
                         * @instance
                         */
                        ListConversationsRequest.prototype.pageToken = "";
    
                        /**
                         * ListConversationsRequest filter.
                         * @member {string} filter
                         * @memberof google.cloud.dialogflow.v2.ListConversationsRequest
                         * @instance
                         */
                        ListConversationsRequest.prototype.filter = "";
    
                        /**
                         * Creates a new ListConversationsRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ListConversationsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListConversationsRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ListConversationsRequest} ListConversationsRequest instance
                         */
                        ListConversationsRequest.create = function create(properties) {
                            return new ListConversationsRequest(properties);
                        };
    
                        /**
                         * Encodes the specified ListConversationsRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.ListConversationsRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ListConversationsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListConversationsRequest} message ListConversationsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListConversationsRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.pageSize != null && Object.hasOwnProperty.call(message, "pageSize"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.pageSize);
                            if (message.pageToken != null && Object.hasOwnProperty.call(message, "pageToken"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.pageToken);
                            if (message.filter != null && Object.hasOwnProperty.call(message, "filter"))
                                writer.uint32(/* id 4, wireType 2 =*/34).string(message.filter);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListConversationsRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ListConversationsRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListConversationsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListConversationsRequest} message ListConversationsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListConversationsRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListConversationsRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ListConversationsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ListConversationsRequest} ListConversationsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListConversationsRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ListConversationsRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.pageSize = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.pageToken = reader.string();
                                        break;
                                    }
                                case 4: {
                                        message.filter = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListConversationsRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListConversationsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ListConversationsRequest} ListConversationsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListConversationsRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListConversationsRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ListConversationsRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListConversationsRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                if (!$util.isInteger(message.pageSize))
                                    return "pageSize: integer expected";
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                if (!$util.isString(message.pageToken))
                                    return "pageToken: string expected";
                            if (message.filter != null && message.hasOwnProperty("filter"))
                                if (!$util.isString(message.filter))
                                    return "filter: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListConversationsRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ListConversationsRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ListConversationsRequest} ListConversationsRequest
                         */
                        ListConversationsRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ListConversationsRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ListConversationsRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.pageSize != null)
                                message.pageSize = object.pageSize | 0;
                            if (object.pageToken != null)
                                message.pageToken = String(object.pageToken);
                            if (object.filter != null)
                                message.filter = String(object.filter);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListConversationsRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ListConversationsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ListConversationsRequest} message ListConversationsRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListConversationsRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.pageSize = 0;
                                object.pageToken = "";
                                object.filter = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                object.pageSize = message.pageSize;
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                object.pageToken = message.pageToken;
                            if (message.filter != null && message.hasOwnProperty("filter"))
                                object.filter = message.filter;
                            return object;
                        };
    
                        /**
                         * Converts this ListConversationsRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ListConversationsRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListConversationsRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListConversationsRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ListConversationsRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListConversationsRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ListConversationsRequest";
                        };
    
                        return ListConversationsRequest;
                    })();
    
                    v2.ListConversationsResponse = (function() {
    
                        /**
                         * Properties of a ListConversationsResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IListConversationsResponse
                         * @property {Array.<google.cloud.dialogflow.v2.IConversation>|null} [conversations] ListConversationsResponse conversations
                         * @property {string|null} [nextPageToken] ListConversationsResponse nextPageToken
                         */
    
                        /**
                         * Constructs a new ListConversationsResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a ListConversationsResponse.
                         * @implements IListConversationsResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IListConversationsResponse=} [properties] Properties to set
                         */
                        function ListConversationsResponse(properties) {
                            this.conversations = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListConversationsResponse conversations.
                         * @member {Array.<google.cloud.dialogflow.v2.IConversation>} conversations
                         * @memberof google.cloud.dialogflow.v2.ListConversationsResponse
                         * @instance
                         */
                        ListConversationsResponse.prototype.conversations = $util.emptyArray;
    
                        /**
                         * ListConversationsResponse nextPageToken.
                         * @member {string} nextPageToken
                         * @memberof google.cloud.dialogflow.v2.ListConversationsResponse
                         * @instance
                         */
                        ListConversationsResponse.prototype.nextPageToken = "";
    
                        /**
                         * Creates a new ListConversationsResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ListConversationsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListConversationsResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ListConversationsResponse} ListConversationsResponse instance
                         */
                        ListConversationsResponse.create = function create(properties) {
                            return new ListConversationsResponse(properties);
                        };
    
                        /**
                         * Encodes the specified ListConversationsResponse message. Does not implicitly {@link google.cloud.dialogflow.v2.ListConversationsResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ListConversationsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListConversationsResponse} message ListConversationsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListConversationsResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.conversations != null && message.conversations.length)
                                for (var i = 0; i < message.conversations.length; ++i)
                                    $root.google.cloud.dialogflow.v2.Conversation.encode(message.conversations[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.nextPageToken != null && Object.hasOwnProperty.call(message, "nextPageToken"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.nextPageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListConversationsResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ListConversationsResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListConversationsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListConversationsResponse} message ListConversationsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListConversationsResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListConversationsResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ListConversationsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ListConversationsResponse} ListConversationsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListConversationsResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ListConversationsResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.conversations && message.conversations.length))
                                            message.conversations = [];
                                        message.conversations.push($root.google.cloud.dialogflow.v2.Conversation.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 2: {
                                        message.nextPageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListConversationsResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListConversationsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ListConversationsResponse} ListConversationsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListConversationsResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListConversationsResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ListConversationsResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListConversationsResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.conversations != null && message.hasOwnProperty("conversations")) {
                                if (!Array.isArray(message.conversations))
                                    return "conversations: array expected";
                                for (var i = 0; i < message.conversations.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.Conversation.verify(message.conversations[i]);
                                    if (error)
                                        return "conversations." + error;
                                }
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                if (!$util.isString(message.nextPageToken))
                                    return "nextPageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListConversationsResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ListConversationsResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ListConversationsResponse} ListConversationsResponse
                         */
                        ListConversationsResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ListConversationsResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ListConversationsResponse();
                            if (object.conversations) {
                                if (!Array.isArray(object.conversations))
                                    throw TypeError(".google.cloud.dialogflow.v2.ListConversationsResponse.conversations: array expected");
                                message.conversations = [];
                                for (var i = 0; i < object.conversations.length; ++i) {
                                    if (typeof object.conversations[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.ListConversationsResponse.conversations: object expected");
                                    message.conversations[i] = $root.google.cloud.dialogflow.v2.Conversation.fromObject(object.conversations[i]);
                                }
                            }
                            if (object.nextPageToken != null)
                                message.nextPageToken = String(object.nextPageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListConversationsResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ListConversationsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.ListConversationsResponse} message ListConversationsResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListConversationsResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.conversations = [];
                            if (options.defaults)
                                object.nextPageToken = "";
                            if (message.conversations && message.conversations.length) {
                                object.conversations = [];
                                for (var j = 0; j < message.conversations.length; ++j)
                                    object.conversations[j] = $root.google.cloud.dialogflow.v2.Conversation.toObject(message.conversations[j], options);
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                object.nextPageToken = message.nextPageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListConversationsResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ListConversationsResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListConversationsResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListConversationsResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ListConversationsResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListConversationsResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ListConversationsResponse";
                        };
    
                        return ListConversationsResponse;
                    })();
    
                    v2.GetConversationRequest = (function() {
    
                        /**
                         * Properties of a GetConversationRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IGetConversationRequest
                         * @property {string|null} [name] GetConversationRequest name
                         */
    
                        /**
                         * Constructs a new GetConversationRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a GetConversationRequest.
                         * @implements IGetConversationRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IGetConversationRequest=} [properties] Properties to set
                         */
                        function GetConversationRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GetConversationRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2.GetConversationRequest
                         * @instance
                         */
                        GetConversationRequest.prototype.name = "";
    
                        /**
                         * Creates a new GetConversationRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.GetConversationRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetConversationRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.GetConversationRequest} GetConversationRequest instance
                         */
                        GetConversationRequest.create = function create(properties) {
                            return new GetConversationRequest(properties);
                        };
    
                        /**
                         * Encodes the specified GetConversationRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.GetConversationRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.GetConversationRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetConversationRequest} message GetConversationRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetConversationRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GetConversationRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.GetConversationRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GetConversationRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetConversationRequest} message GetConversationRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetConversationRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GetConversationRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.GetConversationRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.GetConversationRequest} GetConversationRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetConversationRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.GetConversationRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GetConversationRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GetConversationRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.GetConversationRequest} GetConversationRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetConversationRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GetConversationRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.GetConversationRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GetConversationRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a GetConversationRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.GetConversationRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.GetConversationRequest} GetConversationRequest
                         */
                        GetConversationRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.GetConversationRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.GetConversationRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GetConversationRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.GetConversationRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.GetConversationRequest} message GetConversationRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GetConversationRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.name = "";
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            return object;
                        };
    
                        /**
                         * Converts this GetConversationRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.GetConversationRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GetConversationRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GetConversationRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.GetConversationRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GetConversationRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.GetConversationRequest";
                        };
    
                        return GetConversationRequest;
                    })();
    
                    v2.CompleteConversationRequest = (function() {
    
                        /**
                         * Properties of a CompleteConversationRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ICompleteConversationRequest
                         * @property {string|null} [name] CompleteConversationRequest name
                         */
    
                        /**
                         * Constructs a new CompleteConversationRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a CompleteConversationRequest.
                         * @implements ICompleteConversationRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ICompleteConversationRequest=} [properties] Properties to set
                         */
                        function CompleteConversationRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * CompleteConversationRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2.CompleteConversationRequest
                         * @instance
                         */
                        CompleteConversationRequest.prototype.name = "";
    
                        /**
                         * Creates a new CompleteConversationRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.CompleteConversationRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICompleteConversationRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.CompleteConversationRequest} CompleteConversationRequest instance
                         */
                        CompleteConversationRequest.create = function create(properties) {
                            return new CompleteConversationRequest(properties);
                        };
    
                        /**
                         * Encodes the specified CompleteConversationRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.CompleteConversationRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.CompleteConversationRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICompleteConversationRequest} message CompleteConversationRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CompleteConversationRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified CompleteConversationRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.CompleteConversationRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.CompleteConversationRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICompleteConversationRequest} message CompleteConversationRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CompleteConversationRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a CompleteConversationRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.CompleteConversationRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.CompleteConversationRequest} CompleteConversationRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CompleteConversationRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.CompleteConversationRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a CompleteConversationRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.CompleteConversationRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.CompleteConversationRequest} CompleteConversationRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CompleteConversationRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a CompleteConversationRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.CompleteConversationRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        CompleteConversationRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a CompleteConversationRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.CompleteConversationRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.CompleteConversationRequest} CompleteConversationRequest
                         */
                        CompleteConversationRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.CompleteConversationRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.CompleteConversationRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a CompleteConversationRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.CompleteConversationRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.CompleteConversationRequest} message CompleteConversationRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        CompleteConversationRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.name = "";
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            return object;
                        };
    
                        /**
                         * Converts this CompleteConversationRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.CompleteConversationRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        CompleteConversationRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for CompleteConversationRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.CompleteConversationRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        CompleteConversationRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.CompleteConversationRequest";
                        };
    
                        return CompleteConversationRequest;
                    })();
    
                    v2.ListMessagesRequest = (function() {
    
                        /**
                         * Properties of a ListMessagesRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IListMessagesRequest
                         * @property {string|null} [parent] ListMessagesRequest parent
                         * @property {string|null} [filter] ListMessagesRequest filter
                         * @property {number|null} [pageSize] ListMessagesRequest pageSize
                         * @property {string|null} [pageToken] ListMessagesRequest pageToken
                         */
    
                        /**
                         * Constructs a new ListMessagesRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a ListMessagesRequest.
                         * @implements IListMessagesRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IListMessagesRequest=} [properties] Properties to set
                         */
                        function ListMessagesRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListMessagesRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.ListMessagesRequest
                         * @instance
                         */
                        ListMessagesRequest.prototype.parent = "";
    
                        /**
                         * ListMessagesRequest filter.
                         * @member {string} filter
                         * @memberof google.cloud.dialogflow.v2.ListMessagesRequest
                         * @instance
                         */
                        ListMessagesRequest.prototype.filter = "";
    
                        /**
                         * ListMessagesRequest pageSize.
                         * @member {number} pageSize
                         * @memberof google.cloud.dialogflow.v2.ListMessagesRequest
                         * @instance
                         */
                        ListMessagesRequest.prototype.pageSize = 0;
    
                        /**
                         * ListMessagesRequest pageToken.
                         * @member {string} pageToken
                         * @memberof google.cloud.dialogflow.v2.ListMessagesRequest
                         * @instance
                         */
                        ListMessagesRequest.prototype.pageToken = "";
    
                        /**
                         * Creates a new ListMessagesRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ListMessagesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListMessagesRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ListMessagesRequest} ListMessagesRequest instance
                         */
                        ListMessagesRequest.create = function create(properties) {
                            return new ListMessagesRequest(properties);
                        };
    
                        /**
                         * Encodes the specified ListMessagesRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.ListMessagesRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ListMessagesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListMessagesRequest} message ListMessagesRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListMessagesRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.pageSize != null && Object.hasOwnProperty.call(message, "pageSize"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.pageSize);
                            if (message.pageToken != null && Object.hasOwnProperty.call(message, "pageToken"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.pageToken);
                            if (message.filter != null && Object.hasOwnProperty.call(message, "filter"))
                                writer.uint32(/* id 4, wireType 2 =*/34).string(message.filter);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListMessagesRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ListMessagesRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListMessagesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListMessagesRequest} message ListMessagesRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListMessagesRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListMessagesRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ListMessagesRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ListMessagesRequest} ListMessagesRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListMessagesRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ListMessagesRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 4: {
                                        message.filter = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.pageSize = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.pageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListMessagesRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListMessagesRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ListMessagesRequest} ListMessagesRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListMessagesRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListMessagesRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ListMessagesRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListMessagesRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.filter != null && message.hasOwnProperty("filter"))
                                if (!$util.isString(message.filter))
                                    return "filter: string expected";
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                if (!$util.isInteger(message.pageSize))
                                    return "pageSize: integer expected";
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                if (!$util.isString(message.pageToken))
                                    return "pageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListMessagesRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ListMessagesRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ListMessagesRequest} ListMessagesRequest
                         */
                        ListMessagesRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ListMessagesRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ListMessagesRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.filter != null)
                                message.filter = String(object.filter);
                            if (object.pageSize != null)
                                message.pageSize = object.pageSize | 0;
                            if (object.pageToken != null)
                                message.pageToken = String(object.pageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListMessagesRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ListMessagesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ListMessagesRequest} message ListMessagesRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListMessagesRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.pageSize = 0;
                                object.pageToken = "";
                                object.filter = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                object.pageSize = message.pageSize;
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                object.pageToken = message.pageToken;
                            if (message.filter != null && message.hasOwnProperty("filter"))
                                object.filter = message.filter;
                            return object;
                        };
    
                        /**
                         * Converts this ListMessagesRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ListMessagesRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListMessagesRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListMessagesRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ListMessagesRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListMessagesRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ListMessagesRequest";
                        };
    
                        return ListMessagesRequest;
                    })();
    
                    v2.ListMessagesResponse = (function() {
    
                        /**
                         * Properties of a ListMessagesResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IListMessagesResponse
                         * @property {Array.<google.cloud.dialogflow.v2.IMessage>|null} [messages] ListMessagesResponse messages
                         * @property {string|null} [nextPageToken] ListMessagesResponse nextPageToken
                         */
    
                        /**
                         * Constructs a new ListMessagesResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a ListMessagesResponse.
                         * @implements IListMessagesResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IListMessagesResponse=} [properties] Properties to set
                         */
                        function ListMessagesResponse(properties) {
                            this.messages = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListMessagesResponse messages.
                         * @member {Array.<google.cloud.dialogflow.v2.IMessage>} messages
                         * @memberof google.cloud.dialogflow.v2.ListMessagesResponse
                         * @instance
                         */
                        ListMessagesResponse.prototype.messages = $util.emptyArray;
    
                        /**
                         * ListMessagesResponse nextPageToken.
                         * @member {string} nextPageToken
                         * @memberof google.cloud.dialogflow.v2.ListMessagesResponse
                         * @instance
                         */
                        ListMessagesResponse.prototype.nextPageToken = "";
    
                        /**
                         * Creates a new ListMessagesResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ListMessagesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListMessagesResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ListMessagesResponse} ListMessagesResponse instance
                         */
                        ListMessagesResponse.create = function create(properties) {
                            return new ListMessagesResponse(properties);
                        };
    
                        /**
                         * Encodes the specified ListMessagesResponse message. Does not implicitly {@link google.cloud.dialogflow.v2.ListMessagesResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ListMessagesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListMessagesResponse} message ListMessagesResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListMessagesResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.messages != null && message.messages.length)
                                for (var i = 0; i < message.messages.length; ++i)
                                    $root.google.cloud.dialogflow.v2.Message.encode(message.messages[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.nextPageToken != null && Object.hasOwnProperty.call(message, "nextPageToken"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.nextPageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListMessagesResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ListMessagesResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListMessagesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListMessagesResponse} message ListMessagesResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListMessagesResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListMessagesResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ListMessagesResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ListMessagesResponse} ListMessagesResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListMessagesResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ListMessagesResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.messages && message.messages.length))
                                            message.messages = [];
                                        message.messages.push($root.google.cloud.dialogflow.v2.Message.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 2: {
                                        message.nextPageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListMessagesResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListMessagesResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ListMessagesResponse} ListMessagesResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListMessagesResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListMessagesResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ListMessagesResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListMessagesResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.messages != null && message.hasOwnProperty("messages")) {
                                if (!Array.isArray(message.messages))
                                    return "messages: array expected";
                                for (var i = 0; i < message.messages.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.Message.verify(message.messages[i]);
                                    if (error)
                                        return "messages." + error;
                                }
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                if (!$util.isString(message.nextPageToken))
                                    return "nextPageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListMessagesResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ListMessagesResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ListMessagesResponse} ListMessagesResponse
                         */
                        ListMessagesResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ListMessagesResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ListMessagesResponse();
                            if (object.messages) {
                                if (!Array.isArray(object.messages))
                                    throw TypeError(".google.cloud.dialogflow.v2.ListMessagesResponse.messages: array expected");
                                message.messages = [];
                                for (var i = 0; i < object.messages.length; ++i) {
                                    if (typeof object.messages[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.ListMessagesResponse.messages: object expected");
                                    message.messages[i] = $root.google.cloud.dialogflow.v2.Message.fromObject(object.messages[i]);
                                }
                            }
                            if (object.nextPageToken != null)
                                message.nextPageToken = String(object.nextPageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListMessagesResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ListMessagesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.ListMessagesResponse} message ListMessagesResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListMessagesResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.messages = [];
                            if (options.defaults)
                                object.nextPageToken = "";
                            if (message.messages && message.messages.length) {
                                object.messages = [];
                                for (var j = 0; j < message.messages.length; ++j)
                                    object.messages[j] = $root.google.cloud.dialogflow.v2.Message.toObject(message.messages[j], options);
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                object.nextPageToken = message.nextPageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListMessagesResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ListMessagesResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListMessagesResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListMessagesResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ListMessagesResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListMessagesResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ListMessagesResponse";
                        };
    
                        return ListMessagesResponse;
                    })();
    
                    v2.ConversationPhoneNumber = (function() {
    
                        /**
                         * Properties of a ConversationPhoneNumber.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IConversationPhoneNumber
                         * @property {number|null} [countryCode] ConversationPhoneNumber countryCode
                         * @property {string|null} [phoneNumber] ConversationPhoneNumber phoneNumber
                         */
    
                        /**
                         * Constructs a new ConversationPhoneNumber.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a ConversationPhoneNumber.
                         * @implements IConversationPhoneNumber
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IConversationPhoneNumber=} [properties] Properties to set
                         */
                        function ConversationPhoneNumber(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ConversationPhoneNumber countryCode.
                         * @member {number} countryCode
                         * @memberof google.cloud.dialogflow.v2.ConversationPhoneNumber
                         * @instance
                         */
                        ConversationPhoneNumber.prototype.countryCode = 0;
    
                        /**
                         * ConversationPhoneNumber phoneNumber.
                         * @member {string} phoneNumber
                         * @memberof google.cloud.dialogflow.v2.ConversationPhoneNumber
                         * @instance
                         */
                        ConversationPhoneNumber.prototype.phoneNumber = "";
    
                        /**
                         * Creates a new ConversationPhoneNumber instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ConversationPhoneNumber
                         * @static
                         * @param {google.cloud.dialogflow.v2.IConversationPhoneNumber=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ConversationPhoneNumber} ConversationPhoneNumber instance
                         */
                        ConversationPhoneNumber.create = function create(properties) {
                            return new ConversationPhoneNumber(properties);
                        };
    
                        /**
                         * Encodes the specified ConversationPhoneNumber message. Does not implicitly {@link google.cloud.dialogflow.v2.ConversationPhoneNumber.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ConversationPhoneNumber
                         * @static
                         * @param {google.cloud.dialogflow.v2.IConversationPhoneNumber} message ConversationPhoneNumber message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ConversationPhoneNumber.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.countryCode != null && Object.hasOwnProperty.call(message, "countryCode"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.countryCode);
                            if (message.phoneNumber != null && Object.hasOwnProperty.call(message, "phoneNumber"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.phoneNumber);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ConversationPhoneNumber message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ConversationPhoneNumber.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ConversationPhoneNumber
                         * @static
                         * @param {google.cloud.dialogflow.v2.IConversationPhoneNumber} message ConversationPhoneNumber message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ConversationPhoneNumber.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ConversationPhoneNumber message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ConversationPhoneNumber
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ConversationPhoneNumber} ConversationPhoneNumber
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ConversationPhoneNumber.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ConversationPhoneNumber();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 2: {
                                        message.countryCode = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.phoneNumber = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ConversationPhoneNumber message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ConversationPhoneNumber
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ConversationPhoneNumber} ConversationPhoneNumber
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ConversationPhoneNumber.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ConversationPhoneNumber message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ConversationPhoneNumber
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ConversationPhoneNumber.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.countryCode != null && message.hasOwnProperty("countryCode"))
                                if (!$util.isInteger(message.countryCode))
                                    return "countryCode: integer expected";
                            if (message.phoneNumber != null && message.hasOwnProperty("phoneNumber"))
                                if (!$util.isString(message.phoneNumber))
                                    return "phoneNumber: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ConversationPhoneNumber message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ConversationPhoneNumber
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ConversationPhoneNumber} ConversationPhoneNumber
                         */
                        ConversationPhoneNumber.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ConversationPhoneNumber)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ConversationPhoneNumber();
                            if (object.countryCode != null)
                                message.countryCode = object.countryCode | 0;
                            if (object.phoneNumber != null)
                                message.phoneNumber = String(object.phoneNumber);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ConversationPhoneNumber message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ConversationPhoneNumber
                         * @static
                         * @param {google.cloud.dialogflow.v2.ConversationPhoneNumber} message ConversationPhoneNumber
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ConversationPhoneNumber.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.countryCode = 0;
                                object.phoneNumber = "";
                            }
                            if (message.countryCode != null && message.hasOwnProperty("countryCode"))
                                object.countryCode = message.countryCode;
                            if (message.phoneNumber != null && message.hasOwnProperty("phoneNumber"))
                                object.phoneNumber = message.phoneNumber;
                            return object;
                        };
    
                        /**
                         * Converts this ConversationPhoneNumber to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ConversationPhoneNumber
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ConversationPhoneNumber.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ConversationPhoneNumber
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ConversationPhoneNumber
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ConversationPhoneNumber.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ConversationPhoneNumber";
                        };
    
                        return ConversationPhoneNumber;
                    })();
    
                    v2.IngestContextReferencesRequest = (function() {
    
                        /**
                         * Properties of an IngestContextReferencesRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IIngestContextReferencesRequest
                         * @property {string|null} [conversation] IngestContextReferencesRequest conversation
                         * @property {Object.<string,google.cloud.dialogflow.v2.Conversation.IContextReference>|null} [contextReferences] IngestContextReferencesRequest contextReferences
                         */
    
                        /**
                         * Constructs a new IngestContextReferencesRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an IngestContextReferencesRequest.
                         * @implements IIngestContextReferencesRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IIngestContextReferencesRequest=} [properties] Properties to set
                         */
                        function IngestContextReferencesRequest(properties) {
                            this.contextReferences = {};
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * IngestContextReferencesRequest conversation.
                         * @member {string} conversation
                         * @memberof google.cloud.dialogflow.v2.IngestContextReferencesRequest
                         * @instance
                         */
                        IngestContextReferencesRequest.prototype.conversation = "";
    
                        /**
                         * IngestContextReferencesRequest contextReferences.
                         * @member {Object.<string,google.cloud.dialogflow.v2.Conversation.IContextReference>} contextReferences
                         * @memberof google.cloud.dialogflow.v2.IngestContextReferencesRequest
                         * @instance
                         */
                        IngestContextReferencesRequest.prototype.contextReferences = $util.emptyObject;
    
                        /**
                         * Creates a new IngestContextReferencesRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.IngestContextReferencesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IIngestContextReferencesRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.IngestContextReferencesRequest} IngestContextReferencesRequest instance
                         */
                        IngestContextReferencesRequest.create = function create(properties) {
                            return new IngestContextReferencesRequest(properties);
                        };
    
                        /**
                         * Encodes the specified IngestContextReferencesRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.IngestContextReferencesRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.IngestContextReferencesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IIngestContextReferencesRequest} message IngestContextReferencesRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        IngestContextReferencesRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.conversation != null && Object.hasOwnProperty.call(message, "conversation"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.conversation);
                            if (message.contextReferences != null && Object.hasOwnProperty.call(message, "contextReferences"))
                                for (var keys = Object.keys(message.contextReferences), i = 0; i < keys.length; ++i) {
                                    writer.uint32(/* id 2, wireType 2 =*/18).fork().uint32(/* id 1, wireType 2 =*/10).string(keys[i]);
                                    $root.google.cloud.dialogflow.v2.Conversation.ContextReference.encode(message.contextReferences[keys[i]], writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim().ldelim();
                                }
                            return writer;
                        };
    
                        /**
                         * Encodes the specified IngestContextReferencesRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.IngestContextReferencesRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.IngestContextReferencesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IIngestContextReferencesRequest} message IngestContextReferencesRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        IngestContextReferencesRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an IngestContextReferencesRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.IngestContextReferencesRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.IngestContextReferencesRequest} IngestContextReferencesRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        IngestContextReferencesRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.IngestContextReferencesRequest(), key, value;
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.conversation = reader.string();
                                        break;
                                    }
                                case 2: {
                                        if (message.contextReferences === $util.emptyObject)
                                            message.contextReferences = {};
                                        var end2 = reader.uint32() + reader.pos;
                                        key = "";
                                        value = null;
                                        while (reader.pos < end2) {
                                            var tag2 = reader.uint32();
                                            switch (tag2 >>> 3) {
                                            case 1:
                                                key = reader.string();
                                                break;
                                            case 2:
                                                value = $root.google.cloud.dialogflow.v2.Conversation.ContextReference.decode(reader, reader.uint32());
                                                break;
                                            default:
                                                reader.skipType(tag2 & 7);
                                                break;
                                            }
                                        }
                                        message.contextReferences[key] = value;
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an IngestContextReferencesRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.IngestContextReferencesRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.IngestContextReferencesRequest} IngestContextReferencesRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        IngestContextReferencesRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an IngestContextReferencesRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.IngestContextReferencesRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        IngestContextReferencesRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.conversation != null && message.hasOwnProperty("conversation"))
                                if (!$util.isString(message.conversation))
                                    return "conversation: string expected";
                            if (message.contextReferences != null && message.hasOwnProperty("contextReferences")) {
                                if (!$util.isObject(message.contextReferences))
                                    return "contextReferences: object expected";
                                var key = Object.keys(message.contextReferences);
                                for (var i = 0; i < key.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.Conversation.ContextReference.verify(message.contextReferences[key[i]]);
                                    if (error)
                                        return "contextReferences." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates an IngestContextReferencesRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.IngestContextReferencesRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.IngestContextReferencesRequest} IngestContextReferencesRequest
                         */
                        IngestContextReferencesRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.IngestContextReferencesRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.IngestContextReferencesRequest();
                            if (object.conversation != null)
                                message.conversation = String(object.conversation);
                            if (object.contextReferences) {
                                if (typeof object.contextReferences !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.IngestContextReferencesRequest.contextReferences: object expected");
                                message.contextReferences = {};
                                for (var keys = Object.keys(object.contextReferences), i = 0; i < keys.length; ++i) {
                                    if (typeof object.contextReferences[keys[i]] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.IngestContextReferencesRequest.contextReferences: object expected");
                                    message.contextReferences[keys[i]] = $root.google.cloud.dialogflow.v2.Conversation.ContextReference.fromObject(object.contextReferences[keys[i]]);
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an IngestContextReferencesRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.IngestContextReferencesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IngestContextReferencesRequest} message IngestContextReferencesRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        IngestContextReferencesRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.objects || options.defaults)
                                object.contextReferences = {};
                            if (options.defaults)
                                object.conversation = "";
                            if (message.conversation != null && message.hasOwnProperty("conversation"))
                                object.conversation = message.conversation;
                            var keys2;
                            if (message.contextReferences && (keys2 = Object.keys(message.contextReferences)).length) {
                                object.contextReferences = {};
                                for (var j = 0; j < keys2.length; ++j)
                                    object.contextReferences[keys2[j]] = $root.google.cloud.dialogflow.v2.Conversation.ContextReference.toObject(message.contextReferences[keys2[j]], options);
                            }
                            return object;
                        };
    
                        /**
                         * Converts this IngestContextReferencesRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.IngestContextReferencesRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        IngestContextReferencesRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for IngestContextReferencesRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.IngestContextReferencesRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        IngestContextReferencesRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.IngestContextReferencesRequest";
                        };
    
                        return IngestContextReferencesRequest;
                    })();
    
                    v2.IngestContextReferencesResponse = (function() {
    
                        /**
                         * Properties of an IngestContextReferencesResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IIngestContextReferencesResponse
                         * @property {Object.<string,google.cloud.dialogflow.v2.Conversation.IContextReference>|null} [ingestedContextReferences] IngestContextReferencesResponse ingestedContextReferences
                         */
    
                        /**
                         * Constructs a new IngestContextReferencesResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an IngestContextReferencesResponse.
                         * @implements IIngestContextReferencesResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IIngestContextReferencesResponse=} [properties] Properties to set
                         */
                        function IngestContextReferencesResponse(properties) {
                            this.ingestedContextReferences = {};
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * IngestContextReferencesResponse ingestedContextReferences.
                         * @member {Object.<string,google.cloud.dialogflow.v2.Conversation.IContextReference>} ingestedContextReferences
                         * @memberof google.cloud.dialogflow.v2.IngestContextReferencesResponse
                         * @instance
                         */
                        IngestContextReferencesResponse.prototype.ingestedContextReferences = $util.emptyObject;
    
                        /**
                         * Creates a new IngestContextReferencesResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.IngestContextReferencesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IIngestContextReferencesResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.IngestContextReferencesResponse} IngestContextReferencesResponse instance
                         */
                        IngestContextReferencesResponse.create = function create(properties) {
                            return new IngestContextReferencesResponse(properties);
                        };
    
                        /**
                         * Encodes the specified IngestContextReferencesResponse message. Does not implicitly {@link google.cloud.dialogflow.v2.IngestContextReferencesResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.IngestContextReferencesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IIngestContextReferencesResponse} message IngestContextReferencesResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        IngestContextReferencesResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.ingestedContextReferences != null && Object.hasOwnProperty.call(message, "ingestedContextReferences"))
                                for (var keys = Object.keys(message.ingestedContextReferences), i = 0; i < keys.length; ++i) {
                                    writer.uint32(/* id 1, wireType 2 =*/10).fork().uint32(/* id 1, wireType 2 =*/10).string(keys[i]);
                                    $root.google.cloud.dialogflow.v2.Conversation.ContextReference.encode(message.ingestedContextReferences[keys[i]], writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim().ldelim();
                                }
                            return writer;
                        };
    
                        /**
                         * Encodes the specified IngestContextReferencesResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.IngestContextReferencesResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.IngestContextReferencesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IIngestContextReferencesResponse} message IngestContextReferencesResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        IngestContextReferencesResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an IngestContextReferencesResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.IngestContextReferencesResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.IngestContextReferencesResponse} IngestContextReferencesResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        IngestContextReferencesResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.IngestContextReferencesResponse(), key, value;
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (message.ingestedContextReferences === $util.emptyObject)
                                            message.ingestedContextReferences = {};
                                        var end2 = reader.uint32() + reader.pos;
                                        key = "";
                                        value = null;
                                        while (reader.pos < end2) {
                                            var tag2 = reader.uint32();
                                            switch (tag2 >>> 3) {
                                            case 1:
                                                key = reader.string();
                                                break;
                                            case 2:
                                                value = $root.google.cloud.dialogflow.v2.Conversation.ContextReference.decode(reader, reader.uint32());
                                                break;
                                            default:
                                                reader.skipType(tag2 & 7);
                                                break;
                                            }
                                        }
                                        message.ingestedContextReferences[key] = value;
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an IngestContextReferencesResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.IngestContextReferencesResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.IngestContextReferencesResponse} IngestContextReferencesResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        IngestContextReferencesResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an IngestContextReferencesResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.IngestContextReferencesResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        IngestContextReferencesResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.ingestedContextReferences != null && message.hasOwnProperty("ingestedContextReferences")) {
                                if (!$util.isObject(message.ingestedContextReferences))
                                    return "ingestedContextReferences: object expected";
                                var key = Object.keys(message.ingestedContextReferences);
                                for (var i = 0; i < key.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.Conversation.ContextReference.verify(message.ingestedContextReferences[key[i]]);
                                    if (error)
                                        return "ingestedContextReferences." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates an IngestContextReferencesResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.IngestContextReferencesResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.IngestContextReferencesResponse} IngestContextReferencesResponse
                         */
                        IngestContextReferencesResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.IngestContextReferencesResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.IngestContextReferencesResponse();
                            if (object.ingestedContextReferences) {
                                if (typeof object.ingestedContextReferences !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.IngestContextReferencesResponse.ingestedContextReferences: object expected");
                                message.ingestedContextReferences = {};
                                for (var keys = Object.keys(object.ingestedContextReferences), i = 0; i < keys.length; ++i) {
                                    if (typeof object.ingestedContextReferences[keys[i]] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.IngestContextReferencesResponse.ingestedContextReferences: object expected");
                                    message.ingestedContextReferences[keys[i]] = $root.google.cloud.dialogflow.v2.Conversation.ContextReference.fromObject(object.ingestedContextReferences[keys[i]]);
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an IngestContextReferencesResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.IngestContextReferencesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IngestContextReferencesResponse} message IngestContextReferencesResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        IngestContextReferencesResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.objects || options.defaults)
                                object.ingestedContextReferences = {};
                            var keys2;
                            if (message.ingestedContextReferences && (keys2 = Object.keys(message.ingestedContextReferences)).length) {
                                object.ingestedContextReferences = {};
                                for (var j = 0; j < keys2.length; ++j)
                                    object.ingestedContextReferences[keys2[j]] = $root.google.cloud.dialogflow.v2.Conversation.ContextReference.toObject(message.ingestedContextReferences[keys2[j]], options);
                            }
                            return object;
                        };
    
                        /**
                         * Converts this IngestContextReferencesResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.IngestContextReferencesResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        IngestContextReferencesResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for IngestContextReferencesResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.IngestContextReferencesResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        IngestContextReferencesResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.IngestContextReferencesResponse";
                        };
    
                        return IngestContextReferencesResponse;
                    })();
    
                    v2.SuggestConversationSummaryRequest = (function() {
    
                        /**
                         * Properties of a SuggestConversationSummaryRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ISuggestConversationSummaryRequest
                         * @property {string|null} [conversation] SuggestConversationSummaryRequest conversation
                         * @property {string|null} [latestMessage] SuggestConversationSummaryRequest latestMessage
                         * @property {number|null} [contextSize] SuggestConversationSummaryRequest contextSize
                         * @property {google.cloud.dialogflow.v2.IAssistQueryParameters|null} [assistQueryParams] SuggestConversationSummaryRequest assistQueryParams
                         */
    
                        /**
                         * Constructs a new SuggestConversationSummaryRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a SuggestConversationSummaryRequest.
                         * @implements ISuggestConversationSummaryRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ISuggestConversationSummaryRequest=} [properties] Properties to set
                         */
                        function SuggestConversationSummaryRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SuggestConversationSummaryRequest conversation.
                         * @member {string} conversation
                         * @memberof google.cloud.dialogflow.v2.SuggestConversationSummaryRequest
                         * @instance
                         */
                        SuggestConversationSummaryRequest.prototype.conversation = "";
    
                        /**
                         * SuggestConversationSummaryRequest latestMessage.
                         * @member {string} latestMessage
                         * @memberof google.cloud.dialogflow.v2.SuggestConversationSummaryRequest
                         * @instance
                         */
                        SuggestConversationSummaryRequest.prototype.latestMessage = "";
    
                        /**
                         * SuggestConversationSummaryRequest contextSize.
                         * @member {number} contextSize
                         * @memberof google.cloud.dialogflow.v2.SuggestConversationSummaryRequest
                         * @instance
                         */
                        SuggestConversationSummaryRequest.prototype.contextSize = 0;
    
                        /**
                         * SuggestConversationSummaryRequest assistQueryParams.
                         * @member {google.cloud.dialogflow.v2.IAssistQueryParameters|null|undefined} assistQueryParams
                         * @memberof google.cloud.dialogflow.v2.SuggestConversationSummaryRequest
                         * @instance
                         */
                        SuggestConversationSummaryRequest.prototype.assistQueryParams = null;
    
                        /**
                         * Creates a new SuggestConversationSummaryRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.SuggestConversationSummaryRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISuggestConversationSummaryRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.SuggestConversationSummaryRequest} SuggestConversationSummaryRequest instance
                         */
                        SuggestConversationSummaryRequest.create = function create(properties) {
                            return new SuggestConversationSummaryRequest(properties);
                        };
    
                        /**
                         * Encodes the specified SuggestConversationSummaryRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.SuggestConversationSummaryRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.SuggestConversationSummaryRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISuggestConversationSummaryRequest} message SuggestConversationSummaryRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SuggestConversationSummaryRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.conversation != null && Object.hasOwnProperty.call(message, "conversation"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.conversation);
                            if (message.latestMessage != null && Object.hasOwnProperty.call(message, "latestMessage"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.latestMessage);
                            if (message.contextSize != null && Object.hasOwnProperty.call(message, "contextSize"))
                                writer.uint32(/* id 4, wireType 0 =*/32).int32(message.contextSize);
                            if (message.assistQueryParams != null && Object.hasOwnProperty.call(message, "assistQueryParams"))
                                $root.google.cloud.dialogflow.v2.AssistQueryParameters.encode(message.assistQueryParams, writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SuggestConversationSummaryRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.SuggestConversationSummaryRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SuggestConversationSummaryRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISuggestConversationSummaryRequest} message SuggestConversationSummaryRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SuggestConversationSummaryRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SuggestConversationSummaryRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.SuggestConversationSummaryRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.SuggestConversationSummaryRequest} SuggestConversationSummaryRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SuggestConversationSummaryRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.SuggestConversationSummaryRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.conversation = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.latestMessage = reader.string();
                                        break;
                                    }
                                case 4: {
                                        message.contextSize = reader.int32();
                                        break;
                                    }
                                case 5: {
                                        message.assistQueryParams = $root.google.cloud.dialogflow.v2.AssistQueryParameters.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SuggestConversationSummaryRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SuggestConversationSummaryRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.SuggestConversationSummaryRequest} SuggestConversationSummaryRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SuggestConversationSummaryRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SuggestConversationSummaryRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.SuggestConversationSummaryRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SuggestConversationSummaryRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.conversation != null && message.hasOwnProperty("conversation"))
                                if (!$util.isString(message.conversation))
                                    return "conversation: string expected";
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                if (!$util.isString(message.latestMessage))
                                    return "latestMessage: string expected";
                            if (message.contextSize != null && message.hasOwnProperty("contextSize"))
                                if (!$util.isInteger(message.contextSize))
                                    return "contextSize: integer expected";
                            if (message.assistQueryParams != null && message.hasOwnProperty("assistQueryParams")) {
                                var error = $root.google.cloud.dialogflow.v2.AssistQueryParameters.verify(message.assistQueryParams);
                                if (error)
                                    return "assistQueryParams." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a SuggestConversationSummaryRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.SuggestConversationSummaryRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.SuggestConversationSummaryRequest} SuggestConversationSummaryRequest
                         */
                        SuggestConversationSummaryRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.SuggestConversationSummaryRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.SuggestConversationSummaryRequest();
                            if (object.conversation != null)
                                message.conversation = String(object.conversation);
                            if (object.latestMessage != null)
                                message.latestMessage = String(object.latestMessage);
                            if (object.contextSize != null)
                                message.contextSize = object.contextSize | 0;
                            if (object.assistQueryParams != null) {
                                if (typeof object.assistQueryParams !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.SuggestConversationSummaryRequest.assistQueryParams: object expected");
                                message.assistQueryParams = $root.google.cloud.dialogflow.v2.AssistQueryParameters.fromObject(object.assistQueryParams);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SuggestConversationSummaryRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.SuggestConversationSummaryRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.SuggestConversationSummaryRequest} message SuggestConversationSummaryRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SuggestConversationSummaryRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.conversation = "";
                                object.latestMessage = "";
                                object.contextSize = 0;
                                object.assistQueryParams = null;
                            }
                            if (message.conversation != null && message.hasOwnProperty("conversation"))
                                object.conversation = message.conversation;
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                object.latestMessage = message.latestMessage;
                            if (message.contextSize != null && message.hasOwnProperty("contextSize"))
                                object.contextSize = message.contextSize;
                            if (message.assistQueryParams != null && message.hasOwnProperty("assistQueryParams"))
                                object.assistQueryParams = $root.google.cloud.dialogflow.v2.AssistQueryParameters.toObject(message.assistQueryParams, options);
                            return object;
                        };
    
                        /**
                         * Converts this SuggestConversationSummaryRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.SuggestConversationSummaryRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SuggestConversationSummaryRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SuggestConversationSummaryRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.SuggestConversationSummaryRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SuggestConversationSummaryRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.SuggestConversationSummaryRequest";
                        };
    
                        return SuggestConversationSummaryRequest;
                    })();
    
                    v2.SuggestConversationSummaryResponse = (function() {
    
                        /**
                         * Properties of a SuggestConversationSummaryResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ISuggestConversationSummaryResponse
                         * @property {google.cloud.dialogflow.v2.SuggestConversationSummaryResponse.ISummary|null} [summary] SuggestConversationSummaryResponse summary
                         * @property {string|null} [latestMessage] SuggestConversationSummaryResponse latestMessage
                         * @property {number|null} [contextSize] SuggestConversationSummaryResponse contextSize
                         */
    
                        /**
                         * Constructs a new SuggestConversationSummaryResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a SuggestConversationSummaryResponse.
                         * @implements ISuggestConversationSummaryResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ISuggestConversationSummaryResponse=} [properties] Properties to set
                         */
                        function SuggestConversationSummaryResponse(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SuggestConversationSummaryResponse summary.
                         * @member {google.cloud.dialogflow.v2.SuggestConversationSummaryResponse.ISummary|null|undefined} summary
                         * @memberof google.cloud.dialogflow.v2.SuggestConversationSummaryResponse
                         * @instance
                         */
                        SuggestConversationSummaryResponse.prototype.summary = null;
    
                        /**
                         * SuggestConversationSummaryResponse latestMessage.
                         * @member {string} latestMessage
                         * @memberof google.cloud.dialogflow.v2.SuggestConversationSummaryResponse
                         * @instance
                         */
                        SuggestConversationSummaryResponse.prototype.latestMessage = "";
    
                        /**
                         * SuggestConversationSummaryResponse contextSize.
                         * @member {number} contextSize
                         * @memberof google.cloud.dialogflow.v2.SuggestConversationSummaryResponse
                         * @instance
                         */
                        SuggestConversationSummaryResponse.prototype.contextSize = 0;
    
                        /**
                         * Creates a new SuggestConversationSummaryResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.SuggestConversationSummaryResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISuggestConversationSummaryResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.SuggestConversationSummaryResponse} SuggestConversationSummaryResponse instance
                         */
                        SuggestConversationSummaryResponse.create = function create(properties) {
                            return new SuggestConversationSummaryResponse(properties);
                        };
    
                        /**
                         * Encodes the specified SuggestConversationSummaryResponse message. Does not implicitly {@link google.cloud.dialogflow.v2.SuggestConversationSummaryResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.SuggestConversationSummaryResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISuggestConversationSummaryResponse} message SuggestConversationSummaryResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SuggestConversationSummaryResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.summary != null && Object.hasOwnProperty.call(message, "summary"))
                                $root.google.cloud.dialogflow.v2.SuggestConversationSummaryResponse.Summary.encode(message.summary, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.latestMessage != null && Object.hasOwnProperty.call(message, "latestMessage"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.latestMessage);
                            if (message.contextSize != null && Object.hasOwnProperty.call(message, "contextSize"))
                                writer.uint32(/* id 3, wireType 0 =*/24).int32(message.contextSize);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SuggestConversationSummaryResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.SuggestConversationSummaryResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SuggestConversationSummaryResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISuggestConversationSummaryResponse} message SuggestConversationSummaryResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SuggestConversationSummaryResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SuggestConversationSummaryResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.SuggestConversationSummaryResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.SuggestConversationSummaryResponse} SuggestConversationSummaryResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SuggestConversationSummaryResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.SuggestConversationSummaryResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.summary = $root.google.cloud.dialogflow.v2.SuggestConversationSummaryResponse.Summary.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.latestMessage = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.contextSize = reader.int32();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SuggestConversationSummaryResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SuggestConversationSummaryResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.SuggestConversationSummaryResponse} SuggestConversationSummaryResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SuggestConversationSummaryResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SuggestConversationSummaryResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.SuggestConversationSummaryResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SuggestConversationSummaryResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.summary != null && message.hasOwnProperty("summary")) {
                                var error = $root.google.cloud.dialogflow.v2.SuggestConversationSummaryResponse.Summary.verify(message.summary);
                                if (error)
                                    return "summary." + error;
                            }
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                if (!$util.isString(message.latestMessage))
                                    return "latestMessage: string expected";
                            if (message.contextSize != null && message.hasOwnProperty("contextSize"))
                                if (!$util.isInteger(message.contextSize))
                                    return "contextSize: integer expected";
                            return null;
                        };
    
                        /**
                         * Creates a SuggestConversationSummaryResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.SuggestConversationSummaryResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.SuggestConversationSummaryResponse} SuggestConversationSummaryResponse
                         */
                        SuggestConversationSummaryResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.SuggestConversationSummaryResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.SuggestConversationSummaryResponse();
                            if (object.summary != null) {
                                if (typeof object.summary !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.SuggestConversationSummaryResponse.summary: object expected");
                                message.summary = $root.google.cloud.dialogflow.v2.SuggestConversationSummaryResponse.Summary.fromObject(object.summary);
                            }
                            if (object.latestMessage != null)
                                message.latestMessage = String(object.latestMessage);
                            if (object.contextSize != null)
                                message.contextSize = object.contextSize | 0;
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SuggestConversationSummaryResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.SuggestConversationSummaryResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.SuggestConversationSummaryResponse} message SuggestConversationSummaryResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SuggestConversationSummaryResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.summary = null;
                                object.latestMessage = "";
                                object.contextSize = 0;
                            }
                            if (message.summary != null && message.hasOwnProperty("summary"))
                                object.summary = $root.google.cloud.dialogflow.v2.SuggestConversationSummaryResponse.Summary.toObject(message.summary, options);
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                object.latestMessage = message.latestMessage;
                            if (message.contextSize != null && message.hasOwnProperty("contextSize"))
                                object.contextSize = message.contextSize;
                            return object;
                        };
    
                        /**
                         * Converts this SuggestConversationSummaryResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.SuggestConversationSummaryResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SuggestConversationSummaryResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SuggestConversationSummaryResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.SuggestConversationSummaryResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SuggestConversationSummaryResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.SuggestConversationSummaryResponse";
                        };
    
                        SuggestConversationSummaryResponse.Summary = (function() {
    
                            /**
                             * Properties of a Summary.
                             * @memberof google.cloud.dialogflow.v2.SuggestConversationSummaryResponse
                             * @interface ISummary
                             * @property {string|null} [text] Summary text
                             * @property {Object.<string,string>|null} [textSections] Summary textSections
                             * @property {string|null} [answerRecord] Summary answerRecord
                             * @property {string|null} [baselineModelVersion] Summary baselineModelVersion
                             */
    
                            /**
                             * Constructs a new Summary.
                             * @memberof google.cloud.dialogflow.v2.SuggestConversationSummaryResponse
                             * @classdesc Represents a Summary.
                             * @implements ISummary
                             * @constructor
                             * @param {google.cloud.dialogflow.v2.SuggestConversationSummaryResponse.ISummary=} [properties] Properties to set
                             */
                            function Summary(properties) {
                                this.textSections = {};
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * Summary text.
                             * @member {string} text
                             * @memberof google.cloud.dialogflow.v2.SuggestConversationSummaryResponse.Summary
                             * @instance
                             */
                            Summary.prototype.text = "";
    
                            /**
                             * Summary textSections.
                             * @member {Object.<string,string>} textSections
                             * @memberof google.cloud.dialogflow.v2.SuggestConversationSummaryResponse.Summary
                             * @instance
                             */
                            Summary.prototype.textSections = $util.emptyObject;
    
                            /**
                             * Summary answerRecord.
                             * @member {string} answerRecord
                             * @memberof google.cloud.dialogflow.v2.SuggestConversationSummaryResponse.Summary
                             * @instance
                             */
                            Summary.prototype.answerRecord = "";
    
                            /**
                             * Summary baselineModelVersion.
                             * @member {string} baselineModelVersion
                             * @memberof google.cloud.dialogflow.v2.SuggestConversationSummaryResponse.Summary
                             * @instance
                             */
                            Summary.prototype.baselineModelVersion = "";
    
                            /**
                             * Creates a new Summary instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2.SuggestConversationSummaryResponse.Summary
                             * @static
                             * @param {google.cloud.dialogflow.v2.SuggestConversationSummaryResponse.ISummary=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2.SuggestConversationSummaryResponse.Summary} Summary instance
                             */
                            Summary.create = function create(properties) {
                                return new Summary(properties);
                            };
    
                            /**
                             * Encodes the specified Summary message. Does not implicitly {@link google.cloud.dialogflow.v2.SuggestConversationSummaryResponse.Summary.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2.SuggestConversationSummaryResponse.Summary
                             * @static
                             * @param {google.cloud.dialogflow.v2.SuggestConversationSummaryResponse.ISummary} message Summary message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            Summary.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.text != null && Object.hasOwnProperty.call(message, "text"))
                                    writer.uint32(/* id 1, wireType 2 =*/10).string(message.text);
                                if (message.answerRecord != null && Object.hasOwnProperty.call(message, "answerRecord"))
                                    writer.uint32(/* id 3, wireType 2 =*/26).string(message.answerRecord);
                                if (message.textSections != null && Object.hasOwnProperty.call(message, "textSections"))
                                    for (var keys = Object.keys(message.textSections), i = 0; i < keys.length; ++i)
                                        writer.uint32(/* id 4, wireType 2 =*/34).fork().uint32(/* id 1, wireType 2 =*/10).string(keys[i]).uint32(/* id 2, wireType 2 =*/18).string(message.textSections[keys[i]]).ldelim();
                                if (message.baselineModelVersion != null && Object.hasOwnProperty.call(message, "baselineModelVersion"))
                                    writer.uint32(/* id 5, wireType 2 =*/42).string(message.baselineModelVersion);
                                return writer;
                            };
    
                            /**
                             * Encodes the specified Summary message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.SuggestConversationSummaryResponse.Summary.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2.SuggestConversationSummaryResponse.Summary
                             * @static
                             * @param {google.cloud.dialogflow.v2.SuggestConversationSummaryResponse.ISummary} message Summary message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            Summary.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a Summary message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2.SuggestConversationSummaryResponse.Summary
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2.SuggestConversationSummaryResponse.Summary} Summary
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            Summary.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.SuggestConversationSummaryResponse.Summary(), key, value;
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.text = reader.string();
                                            break;
                                        }
                                    case 4: {
                                            if (message.textSections === $util.emptyObject)
                                                message.textSections = {};
                                            var end2 = reader.uint32() + reader.pos;
                                            key = "";
                                            value = "";
                                            while (reader.pos < end2) {
                                                var tag2 = reader.uint32();
                                                switch (tag2 >>> 3) {
                                                case 1:
                                                    key = reader.string();
                                                    break;
                                                case 2:
                                                    value = reader.string();
                                                    break;
                                                default:
                                                    reader.skipType(tag2 & 7);
                                                    break;
                                                }
                                            }
                                            message.textSections[key] = value;
                                            break;
                                        }
                                    case 3: {
                                            message.answerRecord = reader.string();
                                            break;
                                        }
                                    case 5: {
                                            message.baselineModelVersion = reader.string();
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a Summary message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2.SuggestConversationSummaryResponse.Summary
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2.SuggestConversationSummaryResponse.Summary} Summary
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            Summary.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a Summary message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2.SuggestConversationSummaryResponse.Summary
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            Summary.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.text != null && message.hasOwnProperty("text"))
                                    if (!$util.isString(message.text))
                                        return "text: string expected";
                                if (message.textSections != null && message.hasOwnProperty("textSections")) {
                                    if (!$util.isObject(message.textSections))
                                        return "textSections: object expected";
                                    var key = Object.keys(message.textSections);
                                    for (var i = 0; i < key.length; ++i)
                                        if (!$util.isString(message.textSections[key[i]]))
                                            return "textSections: string{k:string} expected";
                                }
                                if (message.answerRecord != null && message.hasOwnProperty("answerRecord"))
                                    if (!$util.isString(message.answerRecord))
                                        return "answerRecord: string expected";
                                if (message.baselineModelVersion != null && message.hasOwnProperty("baselineModelVersion"))
                                    if (!$util.isString(message.baselineModelVersion))
                                        return "baselineModelVersion: string expected";
                                return null;
                            };
    
                            /**
                             * Creates a Summary message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2.SuggestConversationSummaryResponse.Summary
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2.SuggestConversationSummaryResponse.Summary} Summary
                             */
                            Summary.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2.SuggestConversationSummaryResponse.Summary)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2.SuggestConversationSummaryResponse.Summary();
                                if (object.text != null)
                                    message.text = String(object.text);
                                if (object.textSections) {
                                    if (typeof object.textSections !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.SuggestConversationSummaryResponse.Summary.textSections: object expected");
                                    message.textSections = {};
                                    for (var keys = Object.keys(object.textSections), i = 0; i < keys.length; ++i)
                                        message.textSections[keys[i]] = String(object.textSections[keys[i]]);
                                }
                                if (object.answerRecord != null)
                                    message.answerRecord = String(object.answerRecord);
                                if (object.baselineModelVersion != null)
                                    message.baselineModelVersion = String(object.baselineModelVersion);
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a Summary message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2.SuggestConversationSummaryResponse.Summary
                             * @static
                             * @param {google.cloud.dialogflow.v2.SuggestConversationSummaryResponse.Summary} message Summary
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            Summary.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.objects || options.defaults)
                                    object.textSections = {};
                                if (options.defaults) {
                                    object.text = "";
                                    object.answerRecord = "";
                                    object.baselineModelVersion = "";
                                }
                                if (message.text != null && message.hasOwnProperty("text"))
                                    object.text = message.text;
                                if (message.answerRecord != null && message.hasOwnProperty("answerRecord"))
                                    object.answerRecord = message.answerRecord;
                                var keys2;
                                if (message.textSections && (keys2 = Object.keys(message.textSections)).length) {
                                    object.textSections = {};
                                    for (var j = 0; j < keys2.length; ++j)
                                        object.textSections[keys2[j]] = message.textSections[keys2[j]];
                                }
                                if (message.baselineModelVersion != null && message.hasOwnProperty("baselineModelVersion"))
                                    object.baselineModelVersion = message.baselineModelVersion;
                                return object;
                            };
    
                            /**
                             * Converts this Summary to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2.SuggestConversationSummaryResponse.Summary
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            Summary.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for Summary
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2.SuggestConversationSummaryResponse.Summary
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            Summary.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2.SuggestConversationSummaryResponse.Summary";
                            };
    
                            return Summary;
                        })();
    
                        return SuggestConversationSummaryResponse;
                    })();
    
                    v2.GenerateStatelessSummaryRequest = (function() {
    
                        /**
                         * Properties of a GenerateStatelessSummaryRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IGenerateStatelessSummaryRequest
                         * @property {google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest.IMinimalConversation|null} [statelessConversation] GenerateStatelessSummaryRequest statelessConversation
                         * @property {google.cloud.dialogflow.v2.IConversationProfile|null} [conversationProfile] GenerateStatelessSummaryRequest conversationProfile
                         * @property {string|null} [latestMessage] GenerateStatelessSummaryRequest latestMessage
                         * @property {number|null} [maxContextSize] GenerateStatelessSummaryRequest maxContextSize
                         */
    
                        /**
                         * Constructs a new GenerateStatelessSummaryRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a GenerateStatelessSummaryRequest.
                         * @implements IGenerateStatelessSummaryRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IGenerateStatelessSummaryRequest=} [properties] Properties to set
                         */
                        function GenerateStatelessSummaryRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GenerateStatelessSummaryRequest statelessConversation.
                         * @member {google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest.IMinimalConversation|null|undefined} statelessConversation
                         * @memberof google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest
                         * @instance
                         */
                        GenerateStatelessSummaryRequest.prototype.statelessConversation = null;
    
                        /**
                         * GenerateStatelessSummaryRequest conversationProfile.
                         * @member {google.cloud.dialogflow.v2.IConversationProfile|null|undefined} conversationProfile
                         * @memberof google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest
                         * @instance
                         */
                        GenerateStatelessSummaryRequest.prototype.conversationProfile = null;
    
                        /**
                         * GenerateStatelessSummaryRequest latestMessage.
                         * @member {string} latestMessage
                         * @memberof google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest
                         * @instance
                         */
                        GenerateStatelessSummaryRequest.prototype.latestMessage = "";
    
                        /**
                         * GenerateStatelessSummaryRequest maxContextSize.
                         * @member {number} maxContextSize
                         * @memberof google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest
                         * @instance
                         */
                        GenerateStatelessSummaryRequest.prototype.maxContextSize = 0;
    
                        /**
                         * Creates a new GenerateStatelessSummaryRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGenerateStatelessSummaryRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest} GenerateStatelessSummaryRequest instance
                         */
                        GenerateStatelessSummaryRequest.create = function create(properties) {
                            return new GenerateStatelessSummaryRequest(properties);
                        };
    
                        /**
                         * Encodes the specified GenerateStatelessSummaryRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGenerateStatelessSummaryRequest} message GenerateStatelessSummaryRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GenerateStatelessSummaryRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.statelessConversation != null && Object.hasOwnProperty.call(message, "statelessConversation"))
                                $root.google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest.MinimalConversation.encode(message.statelessConversation, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.conversationProfile != null && Object.hasOwnProperty.call(message, "conversationProfile"))
                                $root.google.cloud.dialogflow.v2.ConversationProfile.encode(message.conversationProfile, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.latestMessage != null && Object.hasOwnProperty.call(message, "latestMessage"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.latestMessage);
                            if (message.maxContextSize != null && Object.hasOwnProperty.call(message, "maxContextSize"))
                                writer.uint32(/* id 4, wireType 0 =*/32).int32(message.maxContextSize);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GenerateStatelessSummaryRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGenerateStatelessSummaryRequest} message GenerateStatelessSummaryRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GenerateStatelessSummaryRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GenerateStatelessSummaryRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest} GenerateStatelessSummaryRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GenerateStatelessSummaryRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.statelessConversation = $root.google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest.MinimalConversation.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.conversationProfile = $root.google.cloud.dialogflow.v2.ConversationProfile.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 3: {
                                        message.latestMessage = reader.string();
                                        break;
                                    }
                                case 4: {
                                        message.maxContextSize = reader.int32();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GenerateStatelessSummaryRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest} GenerateStatelessSummaryRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GenerateStatelessSummaryRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GenerateStatelessSummaryRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GenerateStatelessSummaryRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.statelessConversation != null && message.hasOwnProperty("statelessConversation")) {
                                var error = $root.google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest.MinimalConversation.verify(message.statelessConversation);
                                if (error)
                                    return "statelessConversation." + error;
                            }
                            if (message.conversationProfile != null && message.hasOwnProperty("conversationProfile")) {
                                var error = $root.google.cloud.dialogflow.v2.ConversationProfile.verify(message.conversationProfile);
                                if (error)
                                    return "conversationProfile." + error;
                            }
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                if (!$util.isString(message.latestMessage))
                                    return "latestMessage: string expected";
                            if (message.maxContextSize != null && message.hasOwnProperty("maxContextSize"))
                                if (!$util.isInteger(message.maxContextSize))
                                    return "maxContextSize: integer expected";
                            return null;
                        };
    
                        /**
                         * Creates a GenerateStatelessSummaryRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest} GenerateStatelessSummaryRequest
                         */
                        GenerateStatelessSummaryRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest();
                            if (object.statelessConversation != null) {
                                if (typeof object.statelessConversation !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest.statelessConversation: object expected");
                                message.statelessConversation = $root.google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest.MinimalConversation.fromObject(object.statelessConversation);
                            }
                            if (object.conversationProfile != null) {
                                if (typeof object.conversationProfile !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest.conversationProfile: object expected");
                                message.conversationProfile = $root.google.cloud.dialogflow.v2.ConversationProfile.fromObject(object.conversationProfile);
                            }
                            if (object.latestMessage != null)
                                message.latestMessage = String(object.latestMessage);
                            if (object.maxContextSize != null)
                                message.maxContextSize = object.maxContextSize | 0;
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GenerateStatelessSummaryRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest} message GenerateStatelessSummaryRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GenerateStatelessSummaryRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.statelessConversation = null;
                                object.conversationProfile = null;
                                object.latestMessage = "";
                                object.maxContextSize = 0;
                            }
                            if (message.statelessConversation != null && message.hasOwnProperty("statelessConversation"))
                                object.statelessConversation = $root.google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest.MinimalConversation.toObject(message.statelessConversation, options);
                            if (message.conversationProfile != null && message.hasOwnProperty("conversationProfile"))
                                object.conversationProfile = $root.google.cloud.dialogflow.v2.ConversationProfile.toObject(message.conversationProfile, options);
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                object.latestMessage = message.latestMessage;
                            if (message.maxContextSize != null && message.hasOwnProperty("maxContextSize"))
                                object.maxContextSize = message.maxContextSize;
                            return object;
                        };
    
                        /**
                         * Converts this GenerateStatelessSummaryRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GenerateStatelessSummaryRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GenerateStatelessSummaryRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GenerateStatelessSummaryRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest";
                        };
    
                        GenerateStatelessSummaryRequest.MinimalConversation = (function() {
    
                            /**
                             * Properties of a MinimalConversation.
                             * @memberof google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest
                             * @interface IMinimalConversation
                             * @property {Array.<google.cloud.dialogflow.v2.IMessage>|null} [messages] MinimalConversation messages
                             * @property {string|null} [parent] MinimalConversation parent
                             */
    
                            /**
                             * Constructs a new MinimalConversation.
                             * @memberof google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest
                             * @classdesc Represents a MinimalConversation.
                             * @implements IMinimalConversation
                             * @constructor
                             * @param {google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest.IMinimalConversation=} [properties] Properties to set
                             */
                            function MinimalConversation(properties) {
                                this.messages = [];
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * MinimalConversation messages.
                             * @member {Array.<google.cloud.dialogflow.v2.IMessage>} messages
                             * @memberof google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest.MinimalConversation
                             * @instance
                             */
                            MinimalConversation.prototype.messages = $util.emptyArray;
    
                            /**
                             * MinimalConversation parent.
                             * @member {string} parent
                             * @memberof google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest.MinimalConversation
                             * @instance
                             */
                            MinimalConversation.prototype.parent = "";
    
                            /**
                             * Creates a new MinimalConversation instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest.MinimalConversation
                             * @static
                             * @param {google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest.IMinimalConversation=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest.MinimalConversation} MinimalConversation instance
                             */
                            MinimalConversation.create = function create(properties) {
                                return new MinimalConversation(properties);
                            };
    
                            /**
                             * Encodes the specified MinimalConversation message. Does not implicitly {@link google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest.MinimalConversation.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest.MinimalConversation
                             * @static
                             * @param {google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest.IMinimalConversation} message MinimalConversation message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            MinimalConversation.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.messages != null && message.messages.length)
                                    for (var i = 0; i < message.messages.length; ++i)
                                        $root.google.cloud.dialogflow.v2.Message.encode(message.messages[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                                if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                    writer.uint32(/* id 2, wireType 2 =*/18).string(message.parent);
                                return writer;
                            };
    
                            /**
                             * Encodes the specified MinimalConversation message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest.MinimalConversation.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest.MinimalConversation
                             * @static
                             * @param {google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest.IMinimalConversation} message MinimalConversation message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            MinimalConversation.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a MinimalConversation message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest.MinimalConversation
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest.MinimalConversation} MinimalConversation
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            MinimalConversation.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest.MinimalConversation();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            if (!(message.messages && message.messages.length))
                                                message.messages = [];
                                            message.messages.push($root.google.cloud.dialogflow.v2.Message.decode(reader, reader.uint32()));
                                            break;
                                        }
                                    case 2: {
                                            message.parent = reader.string();
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a MinimalConversation message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest.MinimalConversation
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest.MinimalConversation} MinimalConversation
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            MinimalConversation.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a MinimalConversation message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest.MinimalConversation
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            MinimalConversation.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.messages != null && message.hasOwnProperty("messages")) {
                                    if (!Array.isArray(message.messages))
                                        return "messages: array expected";
                                    for (var i = 0; i < message.messages.length; ++i) {
                                        var error = $root.google.cloud.dialogflow.v2.Message.verify(message.messages[i]);
                                        if (error)
                                            return "messages." + error;
                                    }
                                }
                                if (message.parent != null && message.hasOwnProperty("parent"))
                                    if (!$util.isString(message.parent))
                                        return "parent: string expected";
                                return null;
                            };
    
                            /**
                             * Creates a MinimalConversation message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest.MinimalConversation
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest.MinimalConversation} MinimalConversation
                             */
                            MinimalConversation.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest.MinimalConversation)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest.MinimalConversation();
                                if (object.messages) {
                                    if (!Array.isArray(object.messages))
                                        throw TypeError(".google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest.MinimalConversation.messages: array expected");
                                    message.messages = [];
                                    for (var i = 0; i < object.messages.length; ++i) {
                                        if (typeof object.messages[i] !== "object")
                                            throw TypeError(".google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest.MinimalConversation.messages: object expected");
                                        message.messages[i] = $root.google.cloud.dialogflow.v2.Message.fromObject(object.messages[i]);
                                    }
                                }
                                if (object.parent != null)
                                    message.parent = String(object.parent);
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a MinimalConversation message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest.MinimalConversation
                             * @static
                             * @param {google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest.MinimalConversation} message MinimalConversation
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            MinimalConversation.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.arrays || options.defaults)
                                    object.messages = [];
                                if (options.defaults)
                                    object.parent = "";
                                if (message.messages && message.messages.length) {
                                    object.messages = [];
                                    for (var j = 0; j < message.messages.length; ++j)
                                        object.messages[j] = $root.google.cloud.dialogflow.v2.Message.toObject(message.messages[j], options);
                                }
                                if (message.parent != null && message.hasOwnProperty("parent"))
                                    object.parent = message.parent;
                                return object;
                            };
    
                            /**
                             * Converts this MinimalConversation to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest.MinimalConversation
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            MinimalConversation.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for MinimalConversation
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest.MinimalConversation
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            MinimalConversation.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2.GenerateStatelessSummaryRequest.MinimalConversation";
                            };
    
                            return MinimalConversation;
                        })();
    
                        return GenerateStatelessSummaryRequest;
                    })();
    
                    v2.GenerateStatelessSummaryResponse = (function() {
    
                        /**
                         * Properties of a GenerateStatelessSummaryResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IGenerateStatelessSummaryResponse
                         * @property {google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse.ISummary|null} [summary] GenerateStatelessSummaryResponse summary
                         * @property {string|null} [latestMessage] GenerateStatelessSummaryResponse latestMessage
                         * @property {number|null} [contextSize] GenerateStatelessSummaryResponse contextSize
                         */
    
                        /**
                         * Constructs a new GenerateStatelessSummaryResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a GenerateStatelessSummaryResponse.
                         * @implements IGenerateStatelessSummaryResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IGenerateStatelessSummaryResponse=} [properties] Properties to set
                         */
                        function GenerateStatelessSummaryResponse(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GenerateStatelessSummaryResponse summary.
                         * @member {google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse.ISummary|null|undefined} summary
                         * @memberof google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse
                         * @instance
                         */
                        GenerateStatelessSummaryResponse.prototype.summary = null;
    
                        /**
                         * GenerateStatelessSummaryResponse latestMessage.
                         * @member {string} latestMessage
                         * @memberof google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse
                         * @instance
                         */
                        GenerateStatelessSummaryResponse.prototype.latestMessage = "";
    
                        /**
                         * GenerateStatelessSummaryResponse contextSize.
                         * @member {number} contextSize
                         * @memberof google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse
                         * @instance
                         */
                        GenerateStatelessSummaryResponse.prototype.contextSize = 0;
    
                        /**
                         * Creates a new GenerateStatelessSummaryResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGenerateStatelessSummaryResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse} GenerateStatelessSummaryResponse instance
                         */
                        GenerateStatelessSummaryResponse.create = function create(properties) {
                            return new GenerateStatelessSummaryResponse(properties);
                        };
    
                        /**
                         * Encodes the specified GenerateStatelessSummaryResponse message. Does not implicitly {@link google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGenerateStatelessSummaryResponse} message GenerateStatelessSummaryResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GenerateStatelessSummaryResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.summary != null && Object.hasOwnProperty.call(message, "summary"))
                                $root.google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse.Summary.encode(message.summary, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.latestMessage != null && Object.hasOwnProperty.call(message, "latestMessage"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.latestMessage);
                            if (message.contextSize != null && Object.hasOwnProperty.call(message, "contextSize"))
                                writer.uint32(/* id 3, wireType 0 =*/24).int32(message.contextSize);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GenerateStatelessSummaryResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGenerateStatelessSummaryResponse} message GenerateStatelessSummaryResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GenerateStatelessSummaryResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GenerateStatelessSummaryResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse} GenerateStatelessSummaryResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GenerateStatelessSummaryResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.summary = $root.google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse.Summary.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.latestMessage = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.contextSize = reader.int32();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GenerateStatelessSummaryResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse} GenerateStatelessSummaryResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GenerateStatelessSummaryResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GenerateStatelessSummaryResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GenerateStatelessSummaryResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.summary != null && message.hasOwnProperty("summary")) {
                                var error = $root.google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse.Summary.verify(message.summary);
                                if (error)
                                    return "summary." + error;
                            }
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                if (!$util.isString(message.latestMessage))
                                    return "latestMessage: string expected";
                            if (message.contextSize != null && message.hasOwnProperty("contextSize"))
                                if (!$util.isInteger(message.contextSize))
                                    return "contextSize: integer expected";
                            return null;
                        };
    
                        /**
                         * Creates a GenerateStatelessSummaryResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse} GenerateStatelessSummaryResponse
                         */
                        GenerateStatelessSummaryResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse();
                            if (object.summary != null) {
                                if (typeof object.summary !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse.summary: object expected");
                                message.summary = $root.google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse.Summary.fromObject(object.summary);
                            }
                            if (object.latestMessage != null)
                                message.latestMessage = String(object.latestMessage);
                            if (object.contextSize != null)
                                message.contextSize = object.contextSize | 0;
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GenerateStatelessSummaryResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse} message GenerateStatelessSummaryResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GenerateStatelessSummaryResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.summary = null;
                                object.latestMessage = "";
                                object.contextSize = 0;
                            }
                            if (message.summary != null && message.hasOwnProperty("summary"))
                                object.summary = $root.google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse.Summary.toObject(message.summary, options);
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                object.latestMessage = message.latestMessage;
                            if (message.contextSize != null && message.hasOwnProperty("contextSize"))
                                object.contextSize = message.contextSize;
                            return object;
                        };
    
                        /**
                         * Converts this GenerateStatelessSummaryResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GenerateStatelessSummaryResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GenerateStatelessSummaryResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GenerateStatelessSummaryResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse";
                        };
    
                        GenerateStatelessSummaryResponse.Summary = (function() {
    
                            /**
                             * Properties of a Summary.
                             * @memberof google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse
                             * @interface ISummary
                             * @property {string|null} [text] Summary text
                             * @property {Object.<string,string>|null} [textSections] Summary textSections
                             * @property {string|null} [baselineModelVersion] Summary baselineModelVersion
                             */
    
                            /**
                             * Constructs a new Summary.
                             * @memberof google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse
                             * @classdesc Represents a Summary.
                             * @implements ISummary
                             * @constructor
                             * @param {google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse.ISummary=} [properties] Properties to set
                             */
                            function Summary(properties) {
                                this.textSections = {};
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * Summary text.
                             * @member {string} text
                             * @memberof google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse.Summary
                             * @instance
                             */
                            Summary.prototype.text = "";
    
                            /**
                             * Summary textSections.
                             * @member {Object.<string,string>} textSections
                             * @memberof google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse.Summary
                             * @instance
                             */
                            Summary.prototype.textSections = $util.emptyObject;
    
                            /**
                             * Summary baselineModelVersion.
                             * @member {string} baselineModelVersion
                             * @memberof google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse.Summary
                             * @instance
                             */
                            Summary.prototype.baselineModelVersion = "";
    
                            /**
                             * Creates a new Summary instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse.Summary
                             * @static
                             * @param {google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse.ISummary=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse.Summary} Summary instance
                             */
                            Summary.create = function create(properties) {
                                return new Summary(properties);
                            };
    
                            /**
                             * Encodes the specified Summary message. Does not implicitly {@link google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse.Summary.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse.Summary
                             * @static
                             * @param {google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse.ISummary} message Summary message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            Summary.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.text != null && Object.hasOwnProperty.call(message, "text"))
                                    writer.uint32(/* id 1, wireType 2 =*/10).string(message.text);
                                if (message.textSections != null && Object.hasOwnProperty.call(message, "textSections"))
                                    for (var keys = Object.keys(message.textSections), i = 0; i < keys.length; ++i)
                                        writer.uint32(/* id 2, wireType 2 =*/18).fork().uint32(/* id 1, wireType 2 =*/10).string(keys[i]).uint32(/* id 2, wireType 2 =*/18).string(message.textSections[keys[i]]).ldelim();
                                if (message.baselineModelVersion != null && Object.hasOwnProperty.call(message, "baselineModelVersion"))
                                    writer.uint32(/* id 4, wireType 2 =*/34).string(message.baselineModelVersion);
                                return writer;
                            };
    
                            /**
                             * Encodes the specified Summary message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse.Summary.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse.Summary
                             * @static
                             * @param {google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse.ISummary} message Summary message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            Summary.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a Summary message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse.Summary
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse.Summary} Summary
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            Summary.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse.Summary(), key, value;
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.text = reader.string();
                                            break;
                                        }
                                    case 2: {
                                            if (message.textSections === $util.emptyObject)
                                                message.textSections = {};
                                            var end2 = reader.uint32() + reader.pos;
                                            key = "";
                                            value = "";
                                            while (reader.pos < end2) {
                                                var tag2 = reader.uint32();
                                                switch (tag2 >>> 3) {
                                                case 1:
                                                    key = reader.string();
                                                    break;
                                                case 2:
                                                    value = reader.string();
                                                    break;
                                                default:
                                                    reader.skipType(tag2 & 7);
                                                    break;
                                                }
                                            }
                                            message.textSections[key] = value;
                                            break;
                                        }
                                    case 4: {
                                            message.baselineModelVersion = reader.string();
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a Summary message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse.Summary
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse.Summary} Summary
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            Summary.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a Summary message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse.Summary
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            Summary.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.text != null && message.hasOwnProperty("text"))
                                    if (!$util.isString(message.text))
                                        return "text: string expected";
                                if (message.textSections != null && message.hasOwnProperty("textSections")) {
                                    if (!$util.isObject(message.textSections))
                                        return "textSections: object expected";
                                    var key = Object.keys(message.textSections);
                                    for (var i = 0; i < key.length; ++i)
                                        if (!$util.isString(message.textSections[key[i]]))
                                            return "textSections: string{k:string} expected";
                                }
                                if (message.baselineModelVersion != null && message.hasOwnProperty("baselineModelVersion"))
                                    if (!$util.isString(message.baselineModelVersion))
                                        return "baselineModelVersion: string expected";
                                return null;
                            };
    
                            /**
                             * Creates a Summary message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse.Summary
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse.Summary} Summary
                             */
                            Summary.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse.Summary)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse.Summary();
                                if (object.text != null)
                                    message.text = String(object.text);
                                if (object.textSections) {
                                    if (typeof object.textSections !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse.Summary.textSections: object expected");
                                    message.textSections = {};
                                    for (var keys = Object.keys(object.textSections), i = 0; i < keys.length; ++i)
                                        message.textSections[keys[i]] = String(object.textSections[keys[i]]);
                                }
                                if (object.baselineModelVersion != null)
                                    message.baselineModelVersion = String(object.baselineModelVersion);
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a Summary message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse.Summary
                             * @static
                             * @param {google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse.Summary} message Summary
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            Summary.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.objects || options.defaults)
                                    object.textSections = {};
                                if (options.defaults) {
                                    object.text = "";
                                    object.baselineModelVersion = "";
                                }
                                if (message.text != null && message.hasOwnProperty("text"))
                                    object.text = message.text;
                                var keys2;
                                if (message.textSections && (keys2 = Object.keys(message.textSections)).length) {
                                    object.textSections = {};
                                    for (var j = 0; j < keys2.length; ++j)
                                        object.textSections[keys2[j]] = message.textSections[keys2[j]];
                                }
                                if (message.baselineModelVersion != null && message.hasOwnProperty("baselineModelVersion"))
                                    object.baselineModelVersion = message.baselineModelVersion;
                                return object;
                            };
    
                            /**
                             * Converts this Summary to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse.Summary
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            Summary.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for Summary
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse.Summary
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            Summary.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2.GenerateStatelessSummaryResponse.Summary";
                            };
    
                            return Summary;
                        })();
    
                        return GenerateStatelessSummaryResponse;
                    })();
    
                    v2.GenerateStatelessSuggestionRequest = (function() {
    
                        /**
                         * Properties of a GenerateStatelessSuggestionRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IGenerateStatelessSuggestionRequest
                         * @property {string|null} [parent] GenerateStatelessSuggestionRequest parent
                         * @property {google.cloud.dialogflow.v2.IGenerator|null} [generator] GenerateStatelessSuggestionRequest generator
                         * @property {string|null} [generatorName] GenerateStatelessSuggestionRequest generatorName
                         * @property {Object.<string,google.cloud.dialogflow.v2.Conversation.IContextReference>|null} [contextReferences] GenerateStatelessSuggestionRequest contextReferences
                         * @property {google.cloud.dialogflow.v2.IConversationContext|null} [conversationContext] GenerateStatelessSuggestionRequest conversationContext
                         * @property {Array.<google.cloud.dialogflow.v2.TriggerEvent>|null} [triggerEvents] GenerateStatelessSuggestionRequest triggerEvents
                         */
    
                        /**
                         * Constructs a new GenerateStatelessSuggestionRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a GenerateStatelessSuggestionRequest.
                         * @implements IGenerateStatelessSuggestionRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IGenerateStatelessSuggestionRequest=} [properties] Properties to set
                         */
                        function GenerateStatelessSuggestionRequest(properties) {
                            this.contextReferences = {};
                            this.triggerEvents = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GenerateStatelessSuggestionRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.GenerateStatelessSuggestionRequest
                         * @instance
                         */
                        GenerateStatelessSuggestionRequest.prototype.parent = "";
    
                        /**
                         * GenerateStatelessSuggestionRequest generator.
                         * @member {google.cloud.dialogflow.v2.IGenerator|null|undefined} generator
                         * @memberof google.cloud.dialogflow.v2.GenerateStatelessSuggestionRequest
                         * @instance
                         */
                        GenerateStatelessSuggestionRequest.prototype.generator = null;
    
                        /**
                         * GenerateStatelessSuggestionRequest generatorName.
                         * @member {string|null|undefined} generatorName
                         * @memberof google.cloud.dialogflow.v2.GenerateStatelessSuggestionRequest
                         * @instance
                         */
                        GenerateStatelessSuggestionRequest.prototype.generatorName = null;
    
                        /**
                         * GenerateStatelessSuggestionRequest contextReferences.
                         * @member {Object.<string,google.cloud.dialogflow.v2.Conversation.IContextReference>} contextReferences
                         * @memberof google.cloud.dialogflow.v2.GenerateStatelessSuggestionRequest
                         * @instance
                         */
                        GenerateStatelessSuggestionRequest.prototype.contextReferences = $util.emptyObject;
    
                        /**
                         * GenerateStatelessSuggestionRequest conversationContext.
                         * @member {google.cloud.dialogflow.v2.IConversationContext|null|undefined} conversationContext
                         * @memberof google.cloud.dialogflow.v2.GenerateStatelessSuggestionRequest
                         * @instance
                         */
                        GenerateStatelessSuggestionRequest.prototype.conversationContext = null;
    
                        /**
                         * GenerateStatelessSuggestionRequest triggerEvents.
                         * @member {Array.<google.cloud.dialogflow.v2.TriggerEvent>} triggerEvents
                         * @memberof google.cloud.dialogflow.v2.GenerateStatelessSuggestionRequest
                         * @instance
                         */
                        GenerateStatelessSuggestionRequest.prototype.triggerEvents = $util.emptyArray;
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * GenerateStatelessSuggestionRequest generatorResource.
                         * @member {"generator"|"generatorName"|undefined} generatorResource
                         * @memberof google.cloud.dialogflow.v2.GenerateStatelessSuggestionRequest
                         * @instance
                         */
                        Object.defineProperty(GenerateStatelessSuggestionRequest.prototype, "generatorResource", {
                            get: $util.oneOfGetter($oneOfFields = ["generator", "generatorName"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new GenerateStatelessSuggestionRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.GenerateStatelessSuggestionRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGenerateStatelessSuggestionRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.GenerateStatelessSuggestionRequest} GenerateStatelessSuggestionRequest instance
                         */
                        GenerateStatelessSuggestionRequest.create = function create(properties) {
                            return new GenerateStatelessSuggestionRequest(properties);
                        };
    
                        /**
                         * Encodes the specified GenerateStatelessSuggestionRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.GenerateStatelessSuggestionRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.GenerateStatelessSuggestionRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGenerateStatelessSuggestionRequest} message GenerateStatelessSuggestionRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GenerateStatelessSuggestionRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.generator != null && Object.hasOwnProperty.call(message, "generator"))
                                $root.google.cloud.dialogflow.v2.Generator.encode(message.generator, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.generatorName != null && Object.hasOwnProperty.call(message, "generatorName"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.generatorName);
                            if (message.contextReferences != null && Object.hasOwnProperty.call(message, "contextReferences"))
                                for (var keys = Object.keys(message.contextReferences), i = 0; i < keys.length; ++i) {
                                    writer.uint32(/* id 4, wireType 2 =*/34).fork().uint32(/* id 1, wireType 2 =*/10).string(keys[i]);
                                    $root.google.cloud.dialogflow.v2.Conversation.ContextReference.encode(message.contextReferences[keys[i]], writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim().ldelim();
                                }
                            if (message.conversationContext != null && Object.hasOwnProperty.call(message, "conversationContext"))
                                $root.google.cloud.dialogflow.v2.ConversationContext.encode(message.conversationContext, writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                            if (message.triggerEvents != null && message.triggerEvents.length) {
                                writer.uint32(/* id 6, wireType 2 =*/50).fork();
                                for (var i = 0; i < message.triggerEvents.length; ++i)
                                    writer.int32(message.triggerEvents[i]);
                                writer.ldelim();
                            }
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GenerateStatelessSuggestionRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.GenerateStatelessSuggestionRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GenerateStatelessSuggestionRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGenerateStatelessSuggestionRequest} message GenerateStatelessSuggestionRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GenerateStatelessSuggestionRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GenerateStatelessSuggestionRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.GenerateStatelessSuggestionRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.GenerateStatelessSuggestionRequest} GenerateStatelessSuggestionRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GenerateStatelessSuggestionRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.GenerateStatelessSuggestionRequest(), key, value;
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.generator = $root.google.cloud.dialogflow.v2.Generator.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 3: {
                                        message.generatorName = reader.string();
                                        break;
                                    }
                                case 4: {
                                        if (message.contextReferences === $util.emptyObject)
                                            message.contextReferences = {};
                                        var end2 = reader.uint32() + reader.pos;
                                        key = "";
                                        value = null;
                                        while (reader.pos < end2) {
                                            var tag2 = reader.uint32();
                                            switch (tag2 >>> 3) {
                                            case 1:
                                                key = reader.string();
                                                break;
                                            case 2:
                                                value = $root.google.cloud.dialogflow.v2.Conversation.ContextReference.decode(reader, reader.uint32());
                                                break;
                                            default:
                                                reader.skipType(tag2 & 7);
                                                break;
                                            }
                                        }
                                        message.contextReferences[key] = value;
                                        break;
                                    }
                                case 5: {
                                        message.conversationContext = $root.google.cloud.dialogflow.v2.ConversationContext.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 6: {
                                        if (!(message.triggerEvents && message.triggerEvents.length))
                                            message.triggerEvents = [];
                                        if ((tag & 7) === 2) {
                                            var end2 = reader.uint32() + reader.pos;
                                            while (reader.pos < end2)
                                                message.triggerEvents.push(reader.int32());
                                        } else
                                            message.triggerEvents.push(reader.int32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GenerateStatelessSuggestionRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GenerateStatelessSuggestionRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.GenerateStatelessSuggestionRequest} GenerateStatelessSuggestionRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GenerateStatelessSuggestionRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GenerateStatelessSuggestionRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.GenerateStatelessSuggestionRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GenerateStatelessSuggestionRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.generator != null && message.hasOwnProperty("generator")) {
                                properties.generatorResource = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2.Generator.verify(message.generator);
                                    if (error)
                                        return "generator." + error;
                                }
                            }
                            if (message.generatorName != null && message.hasOwnProperty("generatorName")) {
                                if (properties.generatorResource === 1)
                                    return "generatorResource: multiple values";
                                properties.generatorResource = 1;
                                if (!$util.isString(message.generatorName))
                                    return "generatorName: string expected";
                            }
                            if (message.contextReferences != null && message.hasOwnProperty("contextReferences")) {
                                if (!$util.isObject(message.contextReferences))
                                    return "contextReferences: object expected";
                                var key = Object.keys(message.contextReferences);
                                for (var i = 0; i < key.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.Conversation.ContextReference.verify(message.contextReferences[key[i]]);
                                    if (error)
                                        return "contextReferences." + error;
                                }
                            }
                            if (message.conversationContext != null && message.hasOwnProperty("conversationContext")) {
                                var error = $root.google.cloud.dialogflow.v2.ConversationContext.verify(message.conversationContext);
                                if (error)
                                    return "conversationContext." + error;
                            }
                            if (message.triggerEvents != null && message.hasOwnProperty("triggerEvents")) {
                                if (!Array.isArray(message.triggerEvents))
                                    return "triggerEvents: array expected";
                                for (var i = 0; i < message.triggerEvents.length; ++i)
                                    switch (message.triggerEvents[i]) {
                                    default:
                                        return "triggerEvents: enum value[] expected";
                                    case 0:
                                    case 1:
                                    case 2:
                                    case 3:
                                    case 4:
                                        break;
                                    }
                            }
                            return null;
                        };
    
                        /**
                         * Creates a GenerateStatelessSuggestionRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.GenerateStatelessSuggestionRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.GenerateStatelessSuggestionRequest} GenerateStatelessSuggestionRequest
                         */
                        GenerateStatelessSuggestionRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.GenerateStatelessSuggestionRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.GenerateStatelessSuggestionRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.generator != null) {
                                if (typeof object.generator !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.GenerateStatelessSuggestionRequest.generator: object expected");
                                message.generator = $root.google.cloud.dialogflow.v2.Generator.fromObject(object.generator);
                            }
                            if (object.generatorName != null)
                                message.generatorName = String(object.generatorName);
                            if (object.contextReferences) {
                                if (typeof object.contextReferences !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.GenerateStatelessSuggestionRequest.contextReferences: object expected");
                                message.contextReferences = {};
                                for (var keys = Object.keys(object.contextReferences), i = 0; i < keys.length; ++i) {
                                    if (typeof object.contextReferences[keys[i]] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.GenerateStatelessSuggestionRequest.contextReferences: object expected");
                                    message.contextReferences[keys[i]] = $root.google.cloud.dialogflow.v2.Conversation.ContextReference.fromObject(object.contextReferences[keys[i]]);
                                }
                            }
                            if (object.conversationContext != null) {
                                if (typeof object.conversationContext !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.GenerateStatelessSuggestionRequest.conversationContext: object expected");
                                message.conversationContext = $root.google.cloud.dialogflow.v2.ConversationContext.fromObject(object.conversationContext);
                            }
                            if (object.triggerEvents) {
                                if (!Array.isArray(object.triggerEvents))
                                    throw TypeError(".google.cloud.dialogflow.v2.GenerateStatelessSuggestionRequest.triggerEvents: array expected");
                                message.triggerEvents = [];
                                for (var i = 0; i < object.triggerEvents.length; ++i)
                                    switch (object.triggerEvents[i]) {
                                    default:
                                        if (typeof object.triggerEvents[i] === "number") {
                                            message.triggerEvents[i] = object.triggerEvents[i];
                                            break;
                                        }
                                    case "TRIGGER_EVENT_UNSPECIFIED":
                                    case 0:
                                        message.triggerEvents[i] = 0;
                                        break;
                                    case "END_OF_UTTERANCE":
                                    case 1:
                                        message.triggerEvents[i] = 1;
                                        break;
                                    case "MANUAL_CALL":
                                    case 2:
                                        message.triggerEvents[i] = 2;
                                        break;
                                    case "CUSTOMER_MESSAGE":
                                    case 3:
                                        message.triggerEvents[i] = 3;
                                        break;
                                    case "AGENT_MESSAGE":
                                    case 4:
                                        message.triggerEvents[i] = 4;
                                        break;
                                    }
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GenerateStatelessSuggestionRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.GenerateStatelessSuggestionRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.GenerateStatelessSuggestionRequest} message GenerateStatelessSuggestionRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GenerateStatelessSuggestionRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.triggerEvents = [];
                            if (options.objects || options.defaults)
                                object.contextReferences = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.conversationContext = null;
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.generator != null && message.hasOwnProperty("generator")) {
                                object.generator = $root.google.cloud.dialogflow.v2.Generator.toObject(message.generator, options);
                                if (options.oneofs)
                                    object.generatorResource = "generator";
                            }
                            if (message.generatorName != null && message.hasOwnProperty("generatorName")) {
                                object.generatorName = message.generatorName;
                                if (options.oneofs)
                                    object.generatorResource = "generatorName";
                            }
                            var keys2;
                            if (message.contextReferences && (keys2 = Object.keys(message.contextReferences)).length) {
                                object.contextReferences = {};
                                for (var j = 0; j < keys2.length; ++j)
                                    object.contextReferences[keys2[j]] = $root.google.cloud.dialogflow.v2.Conversation.ContextReference.toObject(message.contextReferences[keys2[j]], options);
                            }
                            if (message.conversationContext != null && message.hasOwnProperty("conversationContext"))
                                object.conversationContext = $root.google.cloud.dialogflow.v2.ConversationContext.toObject(message.conversationContext, options);
                            if (message.triggerEvents && message.triggerEvents.length) {
                                object.triggerEvents = [];
                                for (var j = 0; j < message.triggerEvents.length; ++j)
                                    object.triggerEvents[j] = options.enums === String ? $root.google.cloud.dialogflow.v2.TriggerEvent[message.triggerEvents[j]] === undefined ? message.triggerEvents[j] : $root.google.cloud.dialogflow.v2.TriggerEvent[message.triggerEvents[j]] : message.triggerEvents[j];
                            }
                            return object;
                        };
    
                        /**
                         * Converts this GenerateStatelessSuggestionRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.GenerateStatelessSuggestionRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GenerateStatelessSuggestionRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GenerateStatelessSuggestionRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.GenerateStatelessSuggestionRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GenerateStatelessSuggestionRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.GenerateStatelessSuggestionRequest";
                        };
    
                        return GenerateStatelessSuggestionRequest;
                    })();
    
                    v2.GenerateStatelessSuggestionResponse = (function() {
    
                        /**
                         * Properties of a GenerateStatelessSuggestionResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IGenerateStatelessSuggestionResponse
                         * @property {google.cloud.dialogflow.v2.IGeneratorSuggestion|null} [generatorSuggestion] GenerateStatelessSuggestionResponse generatorSuggestion
                         */
    
                        /**
                         * Constructs a new GenerateStatelessSuggestionResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a GenerateStatelessSuggestionResponse.
                         * @implements IGenerateStatelessSuggestionResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IGenerateStatelessSuggestionResponse=} [properties] Properties to set
                         */
                        function GenerateStatelessSuggestionResponse(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GenerateStatelessSuggestionResponse generatorSuggestion.
                         * @member {google.cloud.dialogflow.v2.IGeneratorSuggestion|null|undefined} generatorSuggestion
                         * @memberof google.cloud.dialogflow.v2.GenerateStatelessSuggestionResponse
                         * @instance
                         */
                        GenerateStatelessSuggestionResponse.prototype.generatorSuggestion = null;
    
                        /**
                         * Creates a new GenerateStatelessSuggestionResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.GenerateStatelessSuggestionResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGenerateStatelessSuggestionResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.GenerateStatelessSuggestionResponse} GenerateStatelessSuggestionResponse instance
                         */
                        GenerateStatelessSuggestionResponse.create = function create(properties) {
                            return new GenerateStatelessSuggestionResponse(properties);
                        };
    
                        /**
                         * Encodes the specified GenerateStatelessSuggestionResponse message. Does not implicitly {@link google.cloud.dialogflow.v2.GenerateStatelessSuggestionResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.GenerateStatelessSuggestionResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGenerateStatelessSuggestionResponse} message GenerateStatelessSuggestionResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GenerateStatelessSuggestionResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.generatorSuggestion != null && Object.hasOwnProperty.call(message, "generatorSuggestion"))
                                $root.google.cloud.dialogflow.v2.GeneratorSuggestion.encode(message.generatorSuggestion, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GenerateStatelessSuggestionResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.GenerateStatelessSuggestionResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GenerateStatelessSuggestionResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGenerateStatelessSuggestionResponse} message GenerateStatelessSuggestionResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GenerateStatelessSuggestionResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GenerateStatelessSuggestionResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.GenerateStatelessSuggestionResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.GenerateStatelessSuggestionResponse} GenerateStatelessSuggestionResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GenerateStatelessSuggestionResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.GenerateStatelessSuggestionResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.generatorSuggestion = $root.google.cloud.dialogflow.v2.GeneratorSuggestion.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GenerateStatelessSuggestionResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GenerateStatelessSuggestionResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.GenerateStatelessSuggestionResponse} GenerateStatelessSuggestionResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GenerateStatelessSuggestionResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GenerateStatelessSuggestionResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.GenerateStatelessSuggestionResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GenerateStatelessSuggestionResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.generatorSuggestion != null && message.hasOwnProperty("generatorSuggestion")) {
                                var error = $root.google.cloud.dialogflow.v2.GeneratorSuggestion.verify(message.generatorSuggestion);
                                if (error)
                                    return "generatorSuggestion." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a GenerateStatelessSuggestionResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.GenerateStatelessSuggestionResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.GenerateStatelessSuggestionResponse} GenerateStatelessSuggestionResponse
                         */
                        GenerateStatelessSuggestionResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.GenerateStatelessSuggestionResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.GenerateStatelessSuggestionResponse();
                            if (object.generatorSuggestion != null) {
                                if (typeof object.generatorSuggestion !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.GenerateStatelessSuggestionResponse.generatorSuggestion: object expected");
                                message.generatorSuggestion = $root.google.cloud.dialogflow.v2.GeneratorSuggestion.fromObject(object.generatorSuggestion);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GenerateStatelessSuggestionResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.GenerateStatelessSuggestionResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.GenerateStatelessSuggestionResponse} message GenerateStatelessSuggestionResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GenerateStatelessSuggestionResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.generatorSuggestion = null;
                            if (message.generatorSuggestion != null && message.hasOwnProperty("generatorSuggestion"))
                                object.generatorSuggestion = $root.google.cloud.dialogflow.v2.GeneratorSuggestion.toObject(message.generatorSuggestion, options);
                            return object;
                        };
    
                        /**
                         * Converts this GenerateStatelessSuggestionResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.GenerateStatelessSuggestionResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GenerateStatelessSuggestionResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GenerateStatelessSuggestionResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.GenerateStatelessSuggestionResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GenerateStatelessSuggestionResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.GenerateStatelessSuggestionResponse";
                        };
    
                        return GenerateStatelessSuggestionResponse;
                    })();
    
                    v2.SearchKnowledgeRequest = (function() {
    
                        /**
                         * Properties of a SearchKnowledgeRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ISearchKnowledgeRequest
                         * @property {string|null} [parent] SearchKnowledgeRequest parent
                         * @property {google.cloud.dialogflow.v2.ITextInput|null} [query] SearchKnowledgeRequest query
                         * @property {string|null} [conversationProfile] SearchKnowledgeRequest conversationProfile
                         * @property {string|null} [sessionId] SearchKnowledgeRequest sessionId
                         * @property {string|null} [conversation] SearchKnowledgeRequest conversation
                         * @property {string|null} [latestMessage] SearchKnowledgeRequest latestMessage
                         * @property {google.cloud.dialogflow.v2.SearchKnowledgeRequest.QuerySource|null} [querySource] SearchKnowledgeRequest querySource
                         * @property {google.protobuf.IStruct|null} [endUserMetadata] SearchKnowledgeRequest endUserMetadata
                         * @property {google.cloud.dialogflow.v2.SearchKnowledgeRequest.ISearchConfig|null} [searchConfig] SearchKnowledgeRequest searchConfig
                         * @property {boolean|null} [exactSearch] SearchKnowledgeRequest exactSearch
                         */
    
                        /**
                         * Constructs a new SearchKnowledgeRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a SearchKnowledgeRequest.
                         * @implements ISearchKnowledgeRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ISearchKnowledgeRequest=} [properties] Properties to set
                         */
                        function SearchKnowledgeRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SearchKnowledgeRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest
                         * @instance
                         */
                        SearchKnowledgeRequest.prototype.parent = "";
    
                        /**
                         * SearchKnowledgeRequest query.
                         * @member {google.cloud.dialogflow.v2.ITextInput|null|undefined} query
                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest
                         * @instance
                         */
                        SearchKnowledgeRequest.prototype.query = null;
    
                        /**
                         * SearchKnowledgeRequest conversationProfile.
                         * @member {string} conversationProfile
                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest
                         * @instance
                         */
                        SearchKnowledgeRequest.prototype.conversationProfile = "";
    
                        /**
                         * SearchKnowledgeRequest sessionId.
                         * @member {string} sessionId
                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest
                         * @instance
                         */
                        SearchKnowledgeRequest.prototype.sessionId = "";
    
                        /**
                         * SearchKnowledgeRequest conversation.
                         * @member {string} conversation
                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest
                         * @instance
                         */
                        SearchKnowledgeRequest.prototype.conversation = "";
    
                        /**
                         * SearchKnowledgeRequest latestMessage.
                         * @member {string} latestMessage
                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest
                         * @instance
                         */
                        SearchKnowledgeRequest.prototype.latestMessage = "";
    
                        /**
                         * SearchKnowledgeRequest querySource.
                         * @member {google.cloud.dialogflow.v2.SearchKnowledgeRequest.QuerySource} querySource
                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest
                         * @instance
                         */
                        SearchKnowledgeRequest.prototype.querySource = 0;
    
                        /**
                         * SearchKnowledgeRequest endUserMetadata.
                         * @member {google.protobuf.IStruct|null|undefined} endUserMetadata
                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest
                         * @instance
                         */
                        SearchKnowledgeRequest.prototype.endUserMetadata = null;
    
                        /**
                         * SearchKnowledgeRequest searchConfig.
                         * @member {google.cloud.dialogflow.v2.SearchKnowledgeRequest.ISearchConfig|null|undefined} searchConfig
                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest
                         * @instance
                         */
                        SearchKnowledgeRequest.prototype.searchConfig = null;
    
                        /**
                         * SearchKnowledgeRequest exactSearch.
                         * @member {boolean} exactSearch
                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest
                         * @instance
                         */
                        SearchKnowledgeRequest.prototype.exactSearch = false;
    
                        /**
                         * Creates a new SearchKnowledgeRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISearchKnowledgeRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.SearchKnowledgeRequest} SearchKnowledgeRequest instance
                         */
                        SearchKnowledgeRequest.create = function create(properties) {
                            return new SearchKnowledgeRequest(properties);
                        };
    
                        /**
                         * Encodes the specified SearchKnowledgeRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.SearchKnowledgeRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISearchKnowledgeRequest} message SearchKnowledgeRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SearchKnowledgeRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.query != null && Object.hasOwnProperty.call(message, "query"))
                                $root.google.cloud.dialogflow.v2.TextInput.encode(message.query, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.conversationProfile != null && Object.hasOwnProperty.call(message, "conversationProfile"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.conversationProfile);
                            if (message.sessionId != null && Object.hasOwnProperty.call(message, "sessionId"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.sessionId);
                            if (message.conversation != null && Object.hasOwnProperty.call(message, "conversation"))
                                writer.uint32(/* id 4, wireType 2 =*/34).string(message.conversation);
                            if (message.latestMessage != null && Object.hasOwnProperty.call(message, "latestMessage"))
                                writer.uint32(/* id 5, wireType 2 =*/42).string(message.latestMessage);
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 6, wireType 2 =*/50).string(message.parent);
                            if (message.querySource != null && Object.hasOwnProperty.call(message, "querySource"))
                                writer.uint32(/* id 7, wireType 0 =*/56).int32(message.querySource);
                            if (message.endUserMetadata != null && Object.hasOwnProperty.call(message, "endUserMetadata"))
                                $root.google.protobuf.Struct.encode(message.endUserMetadata, writer.uint32(/* id 9, wireType 2 =*/74).fork()).ldelim();
                            if (message.searchConfig != null && Object.hasOwnProperty.call(message, "searchConfig"))
                                $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.encode(message.searchConfig, writer.uint32(/* id 11, wireType 2 =*/90).fork()).ldelim();
                            if (message.exactSearch != null && Object.hasOwnProperty.call(message, "exactSearch"))
                                writer.uint32(/* id 14, wireType 0 =*/112).bool(message.exactSearch);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SearchKnowledgeRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.SearchKnowledgeRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISearchKnowledgeRequest} message SearchKnowledgeRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SearchKnowledgeRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SearchKnowledgeRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.SearchKnowledgeRequest} SearchKnowledgeRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SearchKnowledgeRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 6: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 1: {
                                        message.query = $root.google.cloud.dialogflow.v2.TextInput.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.conversationProfile = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.sessionId = reader.string();
                                        break;
                                    }
                                case 4: {
                                        message.conversation = reader.string();
                                        break;
                                    }
                                case 5: {
                                        message.latestMessage = reader.string();
                                        break;
                                    }
                                case 7: {
                                        message.querySource = reader.int32();
                                        break;
                                    }
                                case 9: {
                                        message.endUserMetadata = $root.google.protobuf.Struct.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 11: {
                                        message.searchConfig = $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 14: {
                                        message.exactSearch = reader.bool();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SearchKnowledgeRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.SearchKnowledgeRequest} SearchKnowledgeRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SearchKnowledgeRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SearchKnowledgeRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SearchKnowledgeRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.query != null && message.hasOwnProperty("query")) {
                                var error = $root.google.cloud.dialogflow.v2.TextInput.verify(message.query);
                                if (error)
                                    return "query." + error;
                            }
                            if (message.conversationProfile != null && message.hasOwnProperty("conversationProfile"))
                                if (!$util.isString(message.conversationProfile))
                                    return "conversationProfile: string expected";
                            if (message.sessionId != null && message.hasOwnProperty("sessionId"))
                                if (!$util.isString(message.sessionId))
                                    return "sessionId: string expected";
                            if (message.conversation != null && message.hasOwnProperty("conversation"))
                                if (!$util.isString(message.conversation))
                                    return "conversation: string expected";
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                if (!$util.isString(message.latestMessage))
                                    return "latestMessage: string expected";
                            if (message.querySource != null && message.hasOwnProperty("querySource"))
                                switch (message.querySource) {
                                default:
                                    return "querySource: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                    break;
                                }
                            if (message.endUserMetadata != null && message.hasOwnProperty("endUserMetadata")) {
                                var error = $root.google.protobuf.Struct.verify(message.endUserMetadata);
                                if (error)
                                    return "endUserMetadata." + error;
                            }
                            if (message.searchConfig != null && message.hasOwnProperty("searchConfig")) {
                                var error = $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.verify(message.searchConfig);
                                if (error)
                                    return "searchConfig." + error;
                            }
                            if (message.exactSearch != null && message.hasOwnProperty("exactSearch"))
                                if (typeof message.exactSearch !== "boolean")
                                    return "exactSearch: boolean expected";
                            return null;
                        };
    
                        /**
                         * Creates a SearchKnowledgeRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.SearchKnowledgeRequest} SearchKnowledgeRequest
                         */
                        SearchKnowledgeRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.query != null) {
                                if (typeof object.query !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.SearchKnowledgeRequest.query: object expected");
                                message.query = $root.google.cloud.dialogflow.v2.TextInput.fromObject(object.query);
                            }
                            if (object.conversationProfile != null)
                                message.conversationProfile = String(object.conversationProfile);
                            if (object.sessionId != null)
                                message.sessionId = String(object.sessionId);
                            if (object.conversation != null)
                                message.conversation = String(object.conversation);
                            if (object.latestMessage != null)
                                message.latestMessage = String(object.latestMessage);
                            switch (object.querySource) {
                            default:
                                if (typeof object.querySource === "number") {
                                    message.querySource = object.querySource;
                                    break;
                                }
                                break;
                            case "QUERY_SOURCE_UNSPECIFIED":
                            case 0:
                                message.querySource = 0;
                                break;
                            case "AGENT_QUERY":
                            case 1:
                                message.querySource = 1;
                                break;
                            case "SUGGESTED_QUERY":
                            case 2:
                                message.querySource = 2;
                                break;
                            }
                            if (object.endUserMetadata != null) {
                                if (typeof object.endUserMetadata !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.SearchKnowledgeRequest.endUserMetadata: object expected");
                                message.endUserMetadata = $root.google.protobuf.Struct.fromObject(object.endUserMetadata);
                            }
                            if (object.searchConfig != null) {
                                if (typeof object.searchConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.SearchKnowledgeRequest.searchConfig: object expected");
                                message.searchConfig = $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.fromObject(object.searchConfig);
                            }
                            if (object.exactSearch != null)
                                message.exactSearch = Boolean(object.exactSearch);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SearchKnowledgeRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.SearchKnowledgeRequest} message SearchKnowledgeRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SearchKnowledgeRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.query = null;
                                object.conversationProfile = "";
                                object.sessionId = "";
                                object.conversation = "";
                                object.latestMessage = "";
                                object.parent = "";
                                object.querySource = options.enums === String ? "QUERY_SOURCE_UNSPECIFIED" : 0;
                                object.endUserMetadata = null;
                                object.searchConfig = null;
                                object.exactSearch = false;
                            }
                            if (message.query != null && message.hasOwnProperty("query"))
                                object.query = $root.google.cloud.dialogflow.v2.TextInput.toObject(message.query, options);
                            if (message.conversationProfile != null && message.hasOwnProperty("conversationProfile"))
                                object.conversationProfile = message.conversationProfile;
                            if (message.sessionId != null && message.hasOwnProperty("sessionId"))
                                object.sessionId = message.sessionId;
                            if (message.conversation != null && message.hasOwnProperty("conversation"))
                                object.conversation = message.conversation;
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                object.latestMessage = message.latestMessage;
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.querySource != null && message.hasOwnProperty("querySource"))
                                object.querySource = options.enums === String ? $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.QuerySource[message.querySource] === undefined ? message.querySource : $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.QuerySource[message.querySource] : message.querySource;
                            if (message.endUserMetadata != null && message.hasOwnProperty("endUserMetadata"))
                                object.endUserMetadata = $root.google.protobuf.Struct.toObject(message.endUserMetadata, options);
                            if (message.searchConfig != null && message.hasOwnProperty("searchConfig"))
                                object.searchConfig = $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.toObject(message.searchConfig, options);
                            if (message.exactSearch != null && message.hasOwnProperty("exactSearch"))
                                object.exactSearch = message.exactSearch;
                            return object;
                        };
    
                        /**
                         * Converts this SearchKnowledgeRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SearchKnowledgeRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SearchKnowledgeRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SearchKnowledgeRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.SearchKnowledgeRequest";
                        };
    
                        /**
                         * QuerySource enum.
                         * @name google.cloud.dialogflow.v2.SearchKnowledgeRequest.QuerySource
                         * @enum {number}
                         * @property {number} QUERY_SOURCE_UNSPECIFIED=0 QUERY_SOURCE_UNSPECIFIED value
                         * @property {number} AGENT_QUERY=1 AGENT_QUERY value
                         * @property {number} SUGGESTED_QUERY=2 SUGGESTED_QUERY value
                         */
                        SearchKnowledgeRequest.QuerySource = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "QUERY_SOURCE_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "AGENT_QUERY"] = 1;
                            values[valuesById[2] = "SUGGESTED_QUERY"] = 2;
                            return values;
                        })();
    
                        SearchKnowledgeRequest.SearchConfig = (function() {
    
                            /**
                             * Properties of a SearchConfig.
                             * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest
                             * @interface ISearchConfig
                             * @property {Array.<google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.IBoostSpecs>|null} [boostSpecs] SearchConfig boostSpecs
                             * @property {Array.<google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.IFilterSpecs>|null} [filterSpecs] SearchConfig filterSpecs
                             */
    
                            /**
                             * Constructs a new SearchConfig.
                             * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest
                             * @classdesc Represents a SearchConfig.
                             * @implements ISearchConfig
                             * @constructor
                             * @param {google.cloud.dialogflow.v2.SearchKnowledgeRequest.ISearchConfig=} [properties] Properties to set
                             */
                            function SearchConfig(properties) {
                                this.boostSpecs = [];
                                this.filterSpecs = [];
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * SearchConfig boostSpecs.
                             * @member {Array.<google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.IBoostSpecs>} boostSpecs
                             * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig
                             * @instance
                             */
                            SearchConfig.prototype.boostSpecs = $util.emptyArray;
    
                            /**
                             * SearchConfig filterSpecs.
                             * @member {Array.<google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.IFilterSpecs>} filterSpecs
                             * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig
                             * @instance
                             */
                            SearchConfig.prototype.filterSpecs = $util.emptyArray;
    
                            /**
                             * Creates a new SearchConfig instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2.SearchKnowledgeRequest.ISearchConfig=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig} SearchConfig instance
                             */
                            SearchConfig.create = function create(properties) {
                                return new SearchConfig(properties);
                            };
    
                            /**
                             * Encodes the specified SearchConfig message. Does not implicitly {@link google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2.SearchKnowledgeRequest.ISearchConfig} message SearchConfig message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            SearchConfig.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.boostSpecs != null && message.boostSpecs.length)
                                    for (var i = 0; i < message.boostSpecs.length; ++i)
                                        $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.encode(message.boostSpecs[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                                if (message.filterSpecs != null && message.filterSpecs.length)
                                    for (var i = 0; i < message.filterSpecs.length; ++i)
                                        $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.FilterSpecs.encode(message.filterSpecs[i], writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                                return writer;
                            };
    
                            /**
                             * Encodes the specified SearchConfig message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2.SearchKnowledgeRequest.ISearchConfig} message SearchConfig message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            SearchConfig.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a SearchConfig message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig} SearchConfig
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            SearchConfig.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            if (!(message.boostSpecs && message.boostSpecs.length))
                                                message.boostSpecs = [];
                                            message.boostSpecs.push($root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.decode(reader, reader.uint32()));
                                            break;
                                        }
                                    case 2: {
                                            if (!(message.filterSpecs && message.filterSpecs.length))
                                                message.filterSpecs = [];
                                            message.filterSpecs.push($root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.FilterSpecs.decode(reader, reader.uint32()));
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a SearchConfig message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig} SearchConfig
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            SearchConfig.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a SearchConfig message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            SearchConfig.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.boostSpecs != null && message.hasOwnProperty("boostSpecs")) {
                                    if (!Array.isArray(message.boostSpecs))
                                        return "boostSpecs: array expected";
                                    for (var i = 0; i < message.boostSpecs.length; ++i) {
                                        var error = $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.verify(message.boostSpecs[i]);
                                        if (error)
                                            return "boostSpecs." + error;
                                    }
                                }
                                if (message.filterSpecs != null && message.hasOwnProperty("filterSpecs")) {
                                    if (!Array.isArray(message.filterSpecs))
                                        return "filterSpecs: array expected";
                                    for (var i = 0; i < message.filterSpecs.length; ++i) {
                                        var error = $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.FilterSpecs.verify(message.filterSpecs[i]);
                                        if (error)
                                            return "filterSpecs." + error;
                                    }
                                }
                                return null;
                            };
    
                            /**
                             * Creates a SearchConfig message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig} SearchConfig
                             */
                            SearchConfig.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig();
                                if (object.boostSpecs) {
                                    if (!Array.isArray(object.boostSpecs))
                                        throw TypeError(".google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.boostSpecs: array expected");
                                    message.boostSpecs = [];
                                    for (var i = 0; i < object.boostSpecs.length; ++i) {
                                        if (typeof object.boostSpecs[i] !== "object")
                                            throw TypeError(".google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.boostSpecs: object expected");
                                        message.boostSpecs[i] = $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.fromObject(object.boostSpecs[i]);
                                    }
                                }
                                if (object.filterSpecs) {
                                    if (!Array.isArray(object.filterSpecs))
                                        throw TypeError(".google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.filterSpecs: array expected");
                                    message.filterSpecs = [];
                                    for (var i = 0; i < object.filterSpecs.length; ++i) {
                                        if (typeof object.filterSpecs[i] !== "object")
                                            throw TypeError(".google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.filterSpecs: object expected");
                                        message.filterSpecs[i] = $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.FilterSpecs.fromObject(object.filterSpecs[i]);
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a SearchConfig message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig} message SearchConfig
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            SearchConfig.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.arrays || options.defaults) {
                                    object.boostSpecs = [];
                                    object.filterSpecs = [];
                                }
                                if (message.boostSpecs && message.boostSpecs.length) {
                                    object.boostSpecs = [];
                                    for (var j = 0; j < message.boostSpecs.length; ++j)
                                        object.boostSpecs[j] = $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.toObject(message.boostSpecs[j], options);
                                }
                                if (message.filterSpecs && message.filterSpecs.length) {
                                    object.filterSpecs = [];
                                    for (var j = 0; j < message.filterSpecs.length; ++j)
                                        object.filterSpecs[j] = $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.FilterSpecs.toObject(message.filterSpecs[j], options);
                                }
                                return object;
                            };
    
                            /**
                             * Converts this SearchConfig to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            SearchConfig.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for SearchConfig
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            SearchConfig.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig";
                            };
    
                            SearchConfig.BoostSpecs = (function() {
    
                                /**
                                 * Properties of a BoostSpecs.
                                 * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig
                                 * @interface IBoostSpecs
                                 * @property {Array.<string>|null} [dataStores] BoostSpecs dataStores
                                 * @property {Array.<google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.IBoostSpec>|null} [spec] BoostSpecs spec
                                 */
    
                                /**
                                 * Constructs a new BoostSpecs.
                                 * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig
                                 * @classdesc Represents a BoostSpecs.
                                 * @implements IBoostSpecs
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.IBoostSpecs=} [properties] Properties to set
                                 */
                                function BoostSpecs(properties) {
                                    this.dataStores = [];
                                    this.spec = [];
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * BoostSpecs dataStores.
                                 * @member {Array.<string>} dataStores
                                 * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs
                                 * @instance
                                 */
                                BoostSpecs.prototype.dataStores = $util.emptyArray;
    
                                /**
                                 * BoostSpecs spec.
                                 * @member {Array.<google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.IBoostSpec>} spec
                                 * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs
                                 * @instance
                                 */
                                BoostSpecs.prototype.spec = $util.emptyArray;
    
                                /**
                                 * Creates a new BoostSpecs instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.IBoostSpecs=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs} BoostSpecs instance
                                 */
                                BoostSpecs.create = function create(properties) {
                                    return new BoostSpecs(properties);
                                };
    
                                /**
                                 * Encodes the specified BoostSpecs message. Does not implicitly {@link google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.IBoostSpecs} message BoostSpecs message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                BoostSpecs.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.dataStores != null && message.dataStores.length)
                                        for (var i = 0; i < message.dataStores.length; ++i)
                                            writer.uint32(/* id 1, wireType 2 =*/10).string(message.dataStores[i]);
                                    if (message.spec != null && message.spec.length)
                                        for (var i = 0; i < message.spec.length; ++i)
                                            $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.encode(message.spec[i], writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified BoostSpecs message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.IBoostSpecs} message BoostSpecs message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                BoostSpecs.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a BoostSpecs message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs} BoostSpecs
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                BoostSpecs.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                if (!(message.dataStores && message.dataStores.length))
                                                    message.dataStores = [];
                                                message.dataStores.push(reader.string());
                                                break;
                                            }
                                        case 2: {
                                                if (!(message.spec && message.spec.length))
                                                    message.spec = [];
                                                message.spec.push($root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.decode(reader, reader.uint32()));
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a BoostSpecs message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs} BoostSpecs
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                BoostSpecs.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a BoostSpecs message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                BoostSpecs.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.dataStores != null && message.hasOwnProperty("dataStores")) {
                                        if (!Array.isArray(message.dataStores))
                                            return "dataStores: array expected";
                                        for (var i = 0; i < message.dataStores.length; ++i)
                                            if (!$util.isString(message.dataStores[i]))
                                                return "dataStores: string[] expected";
                                    }
                                    if (message.spec != null && message.hasOwnProperty("spec")) {
                                        if (!Array.isArray(message.spec))
                                            return "spec: array expected";
                                        for (var i = 0; i < message.spec.length; ++i) {
                                            var error = $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.verify(message.spec[i]);
                                            if (error)
                                                return "spec." + error;
                                        }
                                    }
                                    return null;
                                };
    
                                /**
                                 * Creates a BoostSpecs message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs} BoostSpecs
                                 */
                                BoostSpecs.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs();
                                    if (object.dataStores) {
                                        if (!Array.isArray(object.dataStores))
                                            throw TypeError(".google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.dataStores: array expected");
                                        message.dataStores = [];
                                        for (var i = 0; i < object.dataStores.length; ++i)
                                            message.dataStores[i] = String(object.dataStores[i]);
                                    }
                                    if (object.spec) {
                                        if (!Array.isArray(object.spec))
                                            throw TypeError(".google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.spec: array expected");
                                        message.spec = [];
                                        for (var i = 0; i < object.spec.length; ++i) {
                                            if (typeof object.spec[i] !== "object")
                                                throw TypeError(".google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.spec: object expected");
                                            message.spec[i] = $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.fromObject(object.spec[i]);
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a BoostSpecs message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs} message BoostSpecs
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                BoostSpecs.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.arrays || options.defaults) {
                                        object.dataStores = [];
                                        object.spec = [];
                                    }
                                    if (message.dataStores && message.dataStores.length) {
                                        object.dataStores = [];
                                        for (var j = 0; j < message.dataStores.length; ++j)
                                            object.dataStores[j] = message.dataStores[j];
                                    }
                                    if (message.spec && message.spec.length) {
                                        object.spec = [];
                                        for (var j = 0; j < message.spec.length; ++j)
                                            object.spec[j] = $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.toObject(message.spec[j], options);
                                    }
                                    return object;
                                };
    
                                /**
                                 * Converts this BoostSpecs to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                BoostSpecs.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for BoostSpecs
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                BoostSpecs.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs";
                                };
    
                                BoostSpecs.BoostSpec = (function() {
    
                                    /**
                                     * Properties of a BoostSpec.
                                     * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs
                                     * @interface IBoostSpec
                                     * @property {Array.<google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.IConditionBoostSpec>|null} [conditionBoostSpecs] BoostSpec conditionBoostSpecs
                                     */
    
                                    /**
                                     * Constructs a new BoostSpec.
                                     * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs
                                     * @classdesc Represents a BoostSpec.
                                     * @implements IBoostSpec
                                     * @constructor
                                     * @param {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.IBoostSpec=} [properties] Properties to set
                                     */
                                    function BoostSpec(properties) {
                                        this.conditionBoostSpecs = [];
                                        if (properties)
                                            for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                                if (properties[keys[i]] != null)
                                                    this[keys[i]] = properties[keys[i]];
                                    }
    
                                    /**
                                     * BoostSpec conditionBoostSpecs.
                                     * @member {Array.<google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.IConditionBoostSpec>} conditionBoostSpecs
                                     * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec
                                     * @instance
                                     */
                                    BoostSpec.prototype.conditionBoostSpecs = $util.emptyArray;
    
                                    /**
                                     * Creates a new BoostSpec instance using the specified properties.
                                     * @function create
                                     * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec
                                     * @static
                                     * @param {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.IBoostSpec=} [properties] Properties to set
                                     * @returns {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec} BoostSpec instance
                                     */
                                    BoostSpec.create = function create(properties) {
                                        return new BoostSpec(properties);
                                    };
    
                                    /**
                                     * Encodes the specified BoostSpec message. Does not implicitly {@link google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.verify|verify} messages.
                                     * @function encode
                                     * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec
                                     * @static
                                     * @param {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.IBoostSpec} message BoostSpec message or plain object to encode
                                     * @param {$protobuf.Writer} [writer] Writer to encode to
                                     * @returns {$protobuf.Writer} Writer
                                     */
                                    BoostSpec.encode = function encode(message, writer) {
                                        if (!writer)
                                            writer = $Writer.create();
                                        if (message.conditionBoostSpecs != null && message.conditionBoostSpecs.length)
                                            for (var i = 0; i < message.conditionBoostSpecs.length; ++i)
                                                $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.encode(message.conditionBoostSpecs[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                                        return writer;
                                    };
    
                                    /**
                                     * Encodes the specified BoostSpec message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.verify|verify} messages.
                                     * @function encodeDelimited
                                     * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec
                                     * @static
                                     * @param {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.IBoostSpec} message BoostSpec message or plain object to encode
                                     * @param {$protobuf.Writer} [writer] Writer to encode to
                                     * @returns {$protobuf.Writer} Writer
                                     */
                                    BoostSpec.encodeDelimited = function encodeDelimited(message, writer) {
                                        return this.encode(message, writer).ldelim();
                                    };
    
                                    /**
                                     * Decodes a BoostSpec message from the specified reader or buffer.
                                     * @function decode
                                     * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec
                                     * @static
                                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                     * @param {number} [length] Message length if known beforehand
                                     * @returns {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec} BoostSpec
                                     * @throws {Error} If the payload is not a reader or valid buffer
                                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                     */
                                    BoostSpec.decode = function decode(reader, length) {
                                        if (!(reader instanceof $Reader))
                                            reader = $Reader.create(reader);
                                        var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec();
                                        while (reader.pos < end) {
                                            var tag = reader.uint32();
                                            switch (tag >>> 3) {
                                            case 1: {
                                                    if (!(message.conditionBoostSpecs && message.conditionBoostSpecs.length))
                                                        message.conditionBoostSpecs = [];
                                                    message.conditionBoostSpecs.push($root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.decode(reader, reader.uint32()));
                                                    break;
                                                }
                                            default:
                                                reader.skipType(tag & 7);
                                                break;
                                            }
                                        }
                                        return message;
                                    };
    
                                    /**
                                     * Decodes a BoostSpec message from the specified reader or buffer, length delimited.
                                     * @function decodeDelimited
                                     * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec
                                     * @static
                                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                     * @returns {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec} BoostSpec
                                     * @throws {Error} If the payload is not a reader or valid buffer
                                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                     */
                                    BoostSpec.decodeDelimited = function decodeDelimited(reader) {
                                        if (!(reader instanceof $Reader))
                                            reader = new $Reader(reader);
                                        return this.decode(reader, reader.uint32());
                                    };
    
                                    /**
                                     * Verifies a BoostSpec message.
                                     * @function verify
                                     * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec
                                     * @static
                                     * @param {Object.<string,*>} message Plain object to verify
                                     * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                     */
                                    BoostSpec.verify = function verify(message) {
                                        if (typeof message !== "object" || message === null)
                                            return "object expected";
                                        if (message.conditionBoostSpecs != null && message.hasOwnProperty("conditionBoostSpecs")) {
                                            if (!Array.isArray(message.conditionBoostSpecs))
                                                return "conditionBoostSpecs: array expected";
                                            for (var i = 0; i < message.conditionBoostSpecs.length; ++i) {
                                                var error = $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.verify(message.conditionBoostSpecs[i]);
                                                if (error)
                                                    return "conditionBoostSpecs." + error;
                                            }
                                        }
                                        return null;
                                    };
    
                                    /**
                                     * Creates a BoostSpec message from a plain object. Also converts values to their respective internal types.
                                     * @function fromObject
                                     * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec
                                     * @static
                                     * @param {Object.<string,*>} object Plain object
                                     * @returns {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec} BoostSpec
                                     */
                                    BoostSpec.fromObject = function fromObject(object) {
                                        if (object instanceof $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec)
                                            return object;
                                        var message = new $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec();
                                        if (object.conditionBoostSpecs) {
                                            if (!Array.isArray(object.conditionBoostSpecs))
                                                throw TypeError(".google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.conditionBoostSpecs: array expected");
                                            message.conditionBoostSpecs = [];
                                            for (var i = 0; i < object.conditionBoostSpecs.length; ++i) {
                                                if (typeof object.conditionBoostSpecs[i] !== "object")
                                                    throw TypeError(".google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.conditionBoostSpecs: object expected");
                                                message.conditionBoostSpecs[i] = $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.fromObject(object.conditionBoostSpecs[i]);
                                            }
                                        }
                                        return message;
                                    };
    
                                    /**
                                     * Creates a plain object from a BoostSpec message. Also converts values to other types if specified.
                                     * @function toObject
                                     * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec
                                     * @static
                                     * @param {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec} message BoostSpec
                                     * @param {$protobuf.IConversionOptions} [options] Conversion options
                                     * @returns {Object.<string,*>} Plain object
                                     */
                                    BoostSpec.toObject = function toObject(message, options) {
                                        if (!options)
                                            options = {};
                                        var object = {};
                                        if (options.arrays || options.defaults)
                                            object.conditionBoostSpecs = [];
                                        if (message.conditionBoostSpecs && message.conditionBoostSpecs.length) {
                                            object.conditionBoostSpecs = [];
                                            for (var j = 0; j < message.conditionBoostSpecs.length; ++j)
                                                object.conditionBoostSpecs[j] = $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.toObject(message.conditionBoostSpecs[j], options);
                                        }
                                        return object;
                                    };
    
                                    /**
                                     * Converts this BoostSpec to JSON.
                                     * @function toJSON
                                     * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec
                                     * @instance
                                     * @returns {Object.<string,*>} JSON object
                                     */
                                    BoostSpec.prototype.toJSON = function toJSON() {
                                        return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                    };
    
                                    /**
                                     * Gets the default type url for BoostSpec
                                     * @function getTypeUrl
                                     * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec
                                     * @static
                                     * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                     * @returns {string} The default type url
                                     */
                                    BoostSpec.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                        if (typeUrlPrefix === undefined) {
                                            typeUrlPrefix = "type.googleapis.com";
                                        }
                                        return typeUrlPrefix + "/google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec";
                                    };
    
                                    BoostSpec.ConditionBoostSpec = (function() {
    
                                        /**
                                         * Properties of a ConditionBoostSpec.
                                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec
                                         * @interface IConditionBoostSpec
                                         * @property {string|null} [condition] ConditionBoostSpec condition
                                         * @property {number|null} [boost] ConditionBoostSpec boost
                                         * @property {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.IBoostControlSpec|null} [boostControlSpec] ConditionBoostSpec boostControlSpec
                                         */
    
                                        /**
                                         * Constructs a new ConditionBoostSpec.
                                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec
                                         * @classdesc Represents a ConditionBoostSpec.
                                         * @implements IConditionBoostSpec
                                         * @constructor
                                         * @param {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.IConditionBoostSpec=} [properties] Properties to set
                                         */
                                        function ConditionBoostSpec(properties) {
                                            if (properties)
                                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                                    if (properties[keys[i]] != null)
                                                        this[keys[i]] = properties[keys[i]];
                                        }
    
                                        /**
                                         * ConditionBoostSpec condition.
                                         * @member {string} condition
                                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec
                                         * @instance
                                         */
                                        ConditionBoostSpec.prototype.condition = "";
    
                                        /**
                                         * ConditionBoostSpec boost.
                                         * @member {number} boost
                                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec
                                         * @instance
                                         */
                                        ConditionBoostSpec.prototype.boost = 0;
    
                                        /**
                                         * ConditionBoostSpec boostControlSpec.
                                         * @member {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.IBoostControlSpec|null|undefined} boostControlSpec
                                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec
                                         * @instance
                                         */
                                        ConditionBoostSpec.prototype.boostControlSpec = null;
    
                                        /**
                                         * Creates a new ConditionBoostSpec instance using the specified properties.
                                         * @function create
                                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec
                                         * @static
                                         * @param {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.IConditionBoostSpec=} [properties] Properties to set
                                         * @returns {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec} ConditionBoostSpec instance
                                         */
                                        ConditionBoostSpec.create = function create(properties) {
                                            return new ConditionBoostSpec(properties);
                                        };
    
                                        /**
                                         * Encodes the specified ConditionBoostSpec message. Does not implicitly {@link google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.verify|verify} messages.
                                         * @function encode
                                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec
                                         * @static
                                         * @param {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.IConditionBoostSpec} message ConditionBoostSpec message or plain object to encode
                                         * @param {$protobuf.Writer} [writer] Writer to encode to
                                         * @returns {$protobuf.Writer} Writer
                                         */
                                        ConditionBoostSpec.encode = function encode(message, writer) {
                                            if (!writer)
                                                writer = $Writer.create();
                                            if (message.condition != null && Object.hasOwnProperty.call(message, "condition"))
                                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.condition);
                                            if (message.boost != null && Object.hasOwnProperty.call(message, "boost"))
                                                writer.uint32(/* id 2, wireType 5 =*/21).float(message.boost);
                                            if (message.boostControlSpec != null && Object.hasOwnProperty.call(message, "boostControlSpec"))
                                                $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.encode(message.boostControlSpec, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                                            return writer;
                                        };
    
                                        /**
                                         * Encodes the specified ConditionBoostSpec message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.verify|verify} messages.
                                         * @function encodeDelimited
                                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec
                                         * @static
                                         * @param {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.IConditionBoostSpec} message ConditionBoostSpec message or plain object to encode
                                         * @param {$protobuf.Writer} [writer] Writer to encode to
                                         * @returns {$protobuf.Writer} Writer
                                         */
                                        ConditionBoostSpec.encodeDelimited = function encodeDelimited(message, writer) {
                                            return this.encode(message, writer).ldelim();
                                        };
    
                                        /**
                                         * Decodes a ConditionBoostSpec message from the specified reader or buffer.
                                         * @function decode
                                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec
                                         * @static
                                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                         * @param {number} [length] Message length if known beforehand
                                         * @returns {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec} ConditionBoostSpec
                                         * @throws {Error} If the payload is not a reader or valid buffer
                                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                         */
                                        ConditionBoostSpec.decode = function decode(reader, length) {
                                            if (!(reader instanceof $Reader))
                                                reader = $Reader.create(reader);
                                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec();
                                            while (reader.pos < end) {
                                                var tag = reader.uint32();
                                                switch (tag >>> 3) {
                                                case 1: {
                                                        message.condition = reader.string();
                                                        break;
                                                    }
                                                case 2: {
                                                        message.boost = reader.float();
                                                        break;
                                                    }
                                                case 4: {
                                                        message.boostControlSpec = $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.decode(reader, reader.uint32());
                                                        break;
                                                    }
                                                default:
                                                    reader.skipType(tag & 7);
                                                    break;
                                                }
                                            }
                                            return message;
                                        };
    
                                        /**
                                         * Decodes a ConditionBoostSpec message from the specified reader or buffer, length delimited.
                                         * @function decodeDelimited
                                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec
                                         * @static
                                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                         * @returns {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec} ConditionBoostSpec
                                         * @throws {Error} If the payload is not a reader or valid buffer
                                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                         */
                                        ConditionBoostSpec.decodeDelimited = function decodeDelimited(reader) {
                                            if (!(reader instanceof $Reader))
                                                reader = new $Reader(reader);
                                            return this.decode(reader, reader.uint32());
                                        };
    
                                        /**
                                         * Verifies a ConditionBoostSpec message.
                                         * @function verify
                                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec
                                         * @static
                                         * @param {Object.<string,*>} message Plain object to verify
                                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                         */
                                        ConditionBoostSpec.verify = function verify(message) {
                                            if (typeof message !== "object" || message === null)
                                                return "object expected";
                                            if (message.condition != null && message.hasOwnProperty("condition"))
                                                if (!$util.isString(message.condition))
                                                    return "condition: string expected";
                                            if (message.boost != null && message.hasOwnProperty("boost"))
                                                if (typeof message.boost !== "number")
                                                    return "boost: number expected";
                                            if (message.boostControlSpec != null && message.hasOwnProperty("boostControlSpec")) {
                                                var error = $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.verify(message.boostControlSpec);
                                                if (error)
                                                    return "boostControlSpec." + error;
                                            }
                                            return null;
                                        };
    
                                        /**
                                         * Creates a ConditionBoostSpec message from a plain object. Also converts values to their respective internal types.
                                         * @function fromObject
                                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec
                                         * @static
                                         * @param {Object.<string,*>} object Plain object
                                         * @returns {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec} ConditionBoostSpec
                                         */
                                        ConditionBoostSpec.fromObject = function fromObject(object) {
                                            if (object instanceof $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec)
                                                return object;
                                            var message = new $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec();
                                            if (object.condition != null)
                                                message.condition = String(object.condition);
                                            if (object.boost != null)
                                                message.boost = Number(object.boost);
                                            if (object.boostControlSpec != null) {
                                                if (typeof object.boostControlSpec !== "object")
                                                    throw TypeError(".google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.boostControlSpec: object expected");
                                                message.boostControlSpec = $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.fromObject(object.boostControlSpec);
                                            }
                                            return message;
                                        };
    
                                        /**
                                         * Creates a plain object from a ConditionBoostSpec message. Also converts values to other types if specified.
                                         * @function toObject
                                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec
                                         * @static
                                         * @param {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec} message ConditionBoostSpec
                                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                                         * @returns {Object.<string,*>} Plain object
                                         */
                                        ConditionBoostSpec.toObject = function toObject(message, options) {
                                            if (!options)
                                                options = {};
                                            var object = {};
                                            if (options.defaults) {
                                                object.condition = "";
                                                object.boost = 0;
                                                object.boostControlSpec = null;
                                            }
                                            if (message.condition != null && message.hasOwnProperty("condition"))
                                                object.condition = message.condition;
                                            if (message.boost != null && message.hasOwnProperty("boost"))
                                                object.boost = options.json && !isFinite(message.boost) ? String(message.boost) : message.boost;
                                            if (message.boostControlSpec != null && message.hasOwnProperty("boostControlSpec"))
                                                object.boostControlSpec = $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.toObject(message.boostControlSpec, options);
                                            return object;
                                        };
    
                                        /**
                                         * Converts this ConditionBoostSpec to JSON.
                                         * @function toJSON
                                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec
                                         * @instance
                                         * @returns {Object.<string,*>} JSON object
                                         */
                                        ConditionBoostSpec.prototype.toJSON = function toJSON() {
                                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                        };
    
                                        /**
                                         * Gets the default type url for ConditionBoostSpec
                                         * @function getTypeUrl
                                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec
                                         * @static
                                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                         * @returns {string} The default type url
                                         */
                                        ConditionBoostSpec.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                            if (typeUrlPrefix === undefined) {
                                                typeUrlPrefix = "type.googleapis.com";
                                            }
                                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec";
                                        };
    
                                        ConditionBoostSpec.BoostControlSpec = (function() {
    
                                            /**
                                             * Properties of a BoostControlSpec.
                                             * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec
                                             * @interface IBoostControlSpec
                                             * @property {string|null} [fieldName] BoostControlSpec fieldName
                                             * @property {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.AttributeType|null} [attributeType] BoostControlSpec attributeType
                                             * @property {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.InterpolationType|null} [interpolationType] BoostControlSpec interpolationType
                                             * @property {Array.<google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.IControlPoint>|null} [controlPoints] BoostControlSpec controlPoints
                                             */
    
                                            /**
                                             * Constructs a new BoostControlSpec.
                                             * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec
                                             * @classdesc Represents a BoostControlSpec.
                                             * @implements IBoostControlSpec
                                             * @constructor
                                             * @param {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.IBoostControlSpec=} [properties] Properties to set
                                             */
                                            function BoostControlSpec(properties) {
                                                this.controlPoints = [];
                                                if (properties)
                                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                                        if (properties[keys[i]] != null)
                                                            this[keys[i]] = properties[keys[i]];
                                            }
    
                                            /**
                                             * BoostControlSpec fieldName.
                                             * @member {string} fieldName
                                             * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec
                                             * @instance
                                             */
                                            BoostControlSpec.prototype.fieldName = "";
    
                                            /**
                                             * BoostControlSpec attributeType.
                                             * @member {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.AttributeType} attributeType
                                             * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec
                                             * @instance
                                             */
                                            BoostControlSpec.prototype.attributeType = 0;
    
                                            /**
                                             * BoostControlSpec interpolationType.
                                             * @member {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.InterpolationType} interpolationType
                                             * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec
                                             * @instance
                                             */
                                            BoostControlSpec.prototype.interpolationType = 0;
    
                                            /**
                                             * BoostControlSpec controlPoints.
                                             * @member {Array.<google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.IControlPoint>} controlPoints
                                             * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec
                                             * @instance
                                             */
                                            BoostControlSpec.prototype.controlPoints = $util.emptyArray;
    
                                            /**
                                             * Creates a new BoostControlSpec instance using the specified properties.
                                             * @function create
                                             * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec
                                             * @static
                                             * @param {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.IBoostControlSpec=} [properties] Properties to set
                                             * @returns {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec} BoostControlSpec instance
                                             */
                                            BoostControlSpec.create = function create(properties) {
                                                return new BoostControlSpec(properties);
                                            };
    
                                            /**
                                             * Encodes the specified BoostControlSpec message. Does not implicitly {@link google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.verify|verify} messages.
                                             * @function encode
                                             * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec
                                             * @static
                                             * @param {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.IBoostControlSpec} message BoostControlSpec message or plain object to encode
                                             * @param {$protobuf.Writer} [writer] Writer to encode to
                                             * @returns {$protobuf.Writer} Writer
                                             */
                                            BoostControlSpec.encode = function encode(message, writer) {
                                                if (!writer)
                                                    writer = $Writer.create();
                                                if (message.fieldName != null && Object.hasOwnProperty.call(message, "fieldName"))
                                                    writer.uint32(/* id 1, wireType 2 =*/10).string(message.fieldName);
                                                if (message.attributeType != null && Object.hasOwnProperty.call(message, "attributeType"))
                                                    writer.uint32(/* id 2, wireType 0 =*/16).int32(message.attributeType);
                                                if (message.interpolationType != null && Object.hasOwnProperty.call(message, "interpolationType"))
                                                    writer.uint32(/* id 3, wireType 0 =*/24).int32(message.interpolationType);
                                                if (message.controlPoints != null && message.controlPoints.length)
                                                    for (var i = 0; i < message.controlPoints.length; ++i)
                                                        $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.ControlPoint.encode(message.controlPoints[i], writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                                                return writer;
                                            };
    
                                            /**
                                             * Encodes the specified BoostControlSpec message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.verify|verify} messages.
                                             * @function encodeDelimited
                                             * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec
                                             * @static
                                             * @param {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.IBoostControlSpec} message BoostControlSpec message or plain object to encode
                                             * @param {$protobuf.Writer} [writer] Writer to encode to
                                             * @returns {$protobuf.Writer} Writer
                                             */
                                            BoostControlSpec.encodeDelimited = function encodeDelimited(message, writer) {
                                                return this.encode(message, writer).ldelim();
                                            };
    
                                            /**
                                             * Decodes a BoostControlSpec message from the specified reader or buffer.
                                             * @function decode
                                             * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec
                                             * @static
                                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                             * @param {number} [length] Message length if known beforehand
                                             * @returns {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec} BoostControlSpec
                                             * @throws {Error} If the payload is not a reader or valid buffer
                                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                             */
                                            BoostControlSpec.decode = function decode(reader, length) {
                                                if (!(reader instanceof $Reader))
                                                    reader = $Reader.create(reader);
                                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec();
                                                while (reader.pos < end) {
                                                    var tag = reader.uint32();
                                                    switch (tag >>> 3) {
                                                    case 1: {
                                                            message.fieldName = reader.string();
                                                            break;
                                                        }
                                                    case 2: {
                                                            message.attributeType = reader.int32();
                                                            break;
                                                        }
                                                    case 3: {
                                                            message.interpolationType = reader.int32();
                                                            break;
                                                        }
                                                    case 4: {
                                                            if (!(message.controlPoints && message.controlPoints.length))
                                                                message.controlPoints = [];
                                                            message.controlPoints.push($root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.ControlPoint.decode(reader, reader.uint32()));
                                                            break;
                                                        }
                                                    default:
                                                        reader.skipType(tag & 7);
                                                        break;
                                                    }
                                                }
                                                return message;
                                            };
    
                                            /**
                                             * Decodes a BoostControlSpec message from the specified reader or buffer, length delimited.
                                             * @function decodeDelimited
                                             * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec
                                             * @static
                                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                             * @returns {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec} BoostControlSpec
                                             * @throws {Error} If the payload is not a reader or valid buffer
                                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                             */
                                            BoostControlSpec.decodeDelimited = function decodeDelimited(reader) {
                                                if (!(reader instanceof $Reader))
                                                    reader = new $Reader(reader);
                                                return this.decode(reader, reader.uint32());
                                            };
    
                                            /**
                                             * Verifies a BoostControlSpec message.
                                             * @function verify
                                             * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec
                                             * @static
                                             * @param {Object.<string,*>} message Plain object to verify
                                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                             */
                                            BoostControlSpec.verify = function verify(message) {
                                                if (typeof message !== "object" || message === null)
                                                    return "object expected";
                                                if (message.fieldName != null && message.hasOwnProperty("fieldName"))
                                                    if (!$util.isString(message.fieldName))
                                                        return "fieldName: string expected";
                                                if (message.attributeType != null && message.hasOwnProperty("attributeType"))
                                                    switch (message.attributeType) {
                                                    default:
                                                        return "attributeType: enum value expected";
                                                    case 0:
                                                    case 1:
                                                    case 2:
                                                        break;
                                                    }
                                                if (message.interpolationType != null && message.hasOwnProperty("interpolationType"))
                                                    switch (message.interpolationType) {
                                                    default:
                                                        return "interpolationType: enum value expected";
                                                    case 0:
                                                    case 1:
                                                        break;
                                                    }
                                                if (message.controlPoints != null && message.hasOwnProperty("controlPoints")) {
                                                    if (!Array.isArray(message.controlPoints))
                                                        return "controlPoints: array expected";
                                                    for (var i = 0; i < message.controlPoints.length; ++i) {
                                                        var error = $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.ControlPoint.verify(message.controlPoints[i]);
                                                        if (error)
                                                            return "controlPoints." + error;
                                                    }
                                                }
                                                return null;
                                            };
    
                                            /**
                                             * Creates a BoostControlSpec message from a plain object. Also converts values to their respective internal types.
                                             * @function fromObject
                                             * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec
                                             * @static
                                             * @param {Object.<string,*>} object Plain object
                                             * @returns {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec} BoostControlSpec
                                             */
                                            BoostControlSpec.fromObject = function fromObject(object) {
                                                if (object instanceof $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec)
                                                    return object;
                                                var message = new $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec();
                                                if (object.fieldName != null)
                                                    message.fieldName = String(object.fieldName);
                                                switch (object.attributeType) {
                                                default:
                                                    if (typeof object.attributeType === "number") {
                                                        message.attributeType = object.attributeType;
                                                        break;
                                                    }
                                                    break;
                                                case "ATTRIBUTE_TYPE_UNSPECIFIED":
                                                case 0:
                                                    message.attributeType = 0;
                                                    break;
                                                case "NUMERICAL":
                                                case 1:
                                                    message.attributeType = 1;
                                                    break;
                                                case "FRESHNESS":
                                                case 2:
                                                    message.attributeType = 2;
                                                    break;
                                                }
                                                switch (object.interpolationType) {
                                                default:
                                                    if (typeof object.interpolationType === "number") {
                                                        message.interpolationType = object.interpolationType;
                                                        break;
                                                    }
                                                    break;
                                                case "INTERPOLATION_TYPE_UNSPECIFIED":
                                                case 0:
                                                    message.interpolationType = 0;
                                                    break;
                                                case "LINEAR":
                                                case 1:
                                                    message.interpolationType = 1;
                                                    break;
                                                }
                                                if (object.controlPoints) {
                                                    if (!Array.isArray(object.controlPoints))
                                                        throw TypeError(".google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.controlPoints: array expected");
                                                    message.controlPoints = [];
                                                    for (var i = 0; i < object.controlPoints.length; ++i) {
                                                        if (typeof object.controlPoints[i] !== "object")
                                                            throw TypeError(".google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.controlPoints: object expected");
                                                        message.controlPoints[i] = $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.ControlPoint.fromObject(object.controlPoints[i]);
                                                    }
                                                }
                                                return message;
                                            };
    
                                            /**
                                             * Creates a plain object from a BoostControlSpec message. Also converts values to other types if specified.
                                             * @function toObject
                                             * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec
                                             * @static
                                             * @param {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec} message BoostControlSpec
                                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                                             * @returns {Object.<string,*>} Plain object
                                             */
                                            BoostControlSpec.toObject = function toObject(message, options) {
                                                if (!options)
                                                    options = {};
                                                var object = {};
                                                if (options.arrays || options.defaults)
                                                    object.controlPoints = [];
                                                if (options.defaults) {
                                                    object.fieldName = "";
                                                    object.attributeType = options.enums === String ? "ATTRIBUTE_TYPE_UNSPECIFIED" : 0;
                                                    object.interpolationType = options.enums === String ? "INTERPOLATION_TYPE_UNSPECIFIED" : 0;
                                                }
                                                if (message.fieldName != null && message.hasOwnProperty("fieldName"))
                                                    object.fieldName = message.fieldName;
                                                if (message.attributeType != null && message.hasOwnProperty("attributeType"))
                                                    object.attributeType = options.enums === String ? $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.AttributeType[message.attributeType] === undefined ? message.attributeType : $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.AttributeType[message.attributeType] : message.attributeType;
                                                if (message.interpolationType != null && message.hasOwnProperty("interpolationType"))
                                                    object.interpolationType = options.enums === String ? $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.InterpolationType[message.interpolationType] === undefined ? message.interpolationType : $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.InterpolationType[message.interpolationType] : message.interpolationType;
                                                if (message.controlPoints && message.controlPoints.length) {
                                                    object.controlPoints = [];
                                                    for (var j = 0; j < message.controlPoints.length; ++j)
                                                        object.controlPoints[j] = $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.ControlPoint.toObject(message.controlPoints[j], options);
                                                }
                                                return object;
                                            };
    
                                            /**
                                             * Converts this BoostControlSpec to JSON.
                                             * @function toJSON
                                             * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec
                                             * @instance
                                             * @returns {Object.<string,*>} JSON object
                                             */
                                            BoostControlSpec.prototype.toJSON = function toJSON() {
                                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                            };
    
                                            /**
                                             * Gets the default type url for BoostControlSpec
                                             * @function getTypeUrl
                                             * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec
                                             * @static
                                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                             * @returns {string} The default type url
                                             */
                                            BoostControlSpec.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                                if (typeUrlPrefix === undefined) {
                                                    typeUrlPrefix = "type.googleapis.com";
                                                }
                                                return typeUrlPrefix + "/google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec";
                                            };
    
                                            /**
                                             * AttributeType enum.
                                             * @name google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.AttributeType
                                             * @enum {number}
                                             * @property {number} ATTRIBUTE_TYPE_UNSPECIFIED=0 ATTRIBUTE_TYPE_UNSPECIFIED value
                                             * @property {number} NUMERICAL=1 NUMERICAL value
                                             * @property {number} FRESHNESS=2 FRESHNESS value
                                             */
                                            BoostControlSpec.AttributeType = (function() {
                                                var valuesById = {}, values = Object.create(valuesById);
                                                values[valuesById[0] = "ATTRIBUTE_TYPE_UNSPECIFIED"] = 0;
                                                values[valuesById[1] = "NUMERICAL"] = 1;
                                                values[valuesById[2] = "FRESHNESS"] = 2;
                                                return values;
                                            })();
    
                                            /**
                                             * InterpolationType enum.
                                             * @name google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.InterpolationType
                                             * @enum {number}
                                             * @property {number} INTERPOLATION_TYPE_UNSPECIFIED=0 INTERPOLATION_TYPE_UNSPECIFIED value
                                             * @property {number} LINEAR=1 LINEAR value
                                             */
                                            BoostControlSpec.InterpolationType = (function() {
                                                var valuesById = {}, values = Object.create(valuesById);
                                                values[valuesById[0] = "INTERPOLATION_TYPE_UNSPECIFIED"] = 0;
                                                values[valuesById[1] = "LINEAR"] = 1;
                                                return values;
                                            })();
    
                                            BoostControlSpec.ControlPoint = (function() {
    
                                                /**
                                                 * Properties of a ControlPoint.
                                                 * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec
                                                 * @interface IControlPoint
                                                 * @property {string|null} [attributeValue] ControlPoint attributeValue
                                                 * @property {number|null} [boostAmount] ControlPoint boostAmount
                                                 */
    
                                                /**
                                                 * Constructs a new ControlPoint.
                                                 * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec
                                                 * @classdesc Represents a ControlPoint.
                                                 * @implements IControlPoint
                                                 * @constructor
                                                 * @param {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.IControlPoint=} [properties] Properties to set
                                                 */
                                                function ControlPoint(properties) {
                                                    if (properties)
                                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                                            if (properties[keys[i]] != null)
                                                                this[keys[i]] = properties[keys[i]];
                                                }
    
                                                /**
                                                 * ControlPoint attributeValue.
                                                 * @member {string} attributeValue
                                                 * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.ControlPoint
                                                 * @instance
                                                 */
                                                ControlPoint.prototype.attributeValue = "";
    
                                                /**
                                                 * ControlPoint boostAmount.
                                                 * @member {number} boostAmount
                                                 * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.ControlPoint
                                                 * @instance
                                                 */
                                                ControlPoint.prototype.boostAmount = 0;
    
                                                /**
                                                 * Creates a new ControlPoint instance using the specified properties.
                                                 * @function create
                                                 * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.ControlPoint
                                                 * @static
                                                 * @param {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.IControlPoint=} [properties] Properties to set
                                                 * @returns {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.ControlPoint} ControlPoint instance
                                                 */
                                                ControlPoint.create = function create(properties) {
                                                    return new ControlPoint(properties);
                                                };
    
                                                /**
                                                 * Encodes the specified ControlPoint message. Does not implicitly {@link google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.ControlPoint.verify|verify} messages.
                                                 * @function encode
                                                 * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.ControlPoint
                                                 * @static
                                                 * @param {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.IControlPoint} message ControlPoint message or plain object to encode
                                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                                 * @returns {$protobuf.Writer} Writer
                                                 */
                                                ControlPoint.encode = function encode(message, writer) {
                                                    if (!writer)
                                                        writer = $Writer.create();
                                                    if (message.attributeValue != null && Object.hasOwnProperty.call(message, "attributeValue"))
                                                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.attributeValue);
                                                    if (message.boostAmount != null && Object.hasOwnProperty.call(message, "boostAmount"))
                                                        writer.uint32(/* id 2, wireType 5 =*/21).float(message.boostAmount);
                                                    return writer;
                                                };
    
                                                /**
                                                 * Encodes the specified ControlPoint message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.ControlPoint.verify|verify} messages.
                                                 * @function encodeDelimited
                                                 * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.ControlPoint
                                                 * @static
                                                 * @param {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.IControlPoint} message ControlPoint message or plain object to encode
                                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                                 * @returns {$protobuf.Writer} Writer
                                                 */
                                                ControlPoint.encodeDelimited = function encodeDelimited(message, writer) {
                                                    return this.encode(message, writer).ldelim();
                                                };
    
                                                /**
                                                 * Decodes a ControlPoint message from the specified reader or buffer.
                                                 * @function decode
                                                 * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.ControlPoint
                                                 * @static
                                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                                 * @param {number} [length] Message length if known beforehand
                                                 * @returns {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.ControlPoint} ControlPoint
                                                 * @throws {Error} If the payload is not a reader or valid buffer
                                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                                 */
                                                ControlPoint.decode = function decode(reader, length) {
                                                    if (!(reader instanceof $Reader))
                                                        reader = $Reader.create(reader);
                                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.ControlPoint();
                                                    while (reader.pos < end) {
                                                        var tag = reader.uint32();
                                                        switch (tag >>> 3) {
                                                        case 1: {
                                                                message.attributeValue = reader.string();
                                                                break;
                                                            }
                                                        case 2: {
                                                                message.boostAmount = reader.float();
                                                                break;
                                                            }
                                                        default:
                                                            reader.skipType(tag & 7);
                                                            break;
                                                        }
                                                    }
                                                    return message;
                                                };
    
                                                /**
                                                 * Decodes a ControlPoint message from the specified reader or buffer, length delimited.
                                                 * @function decodeDelimited
                                                 * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.ControlPoint
                                                 * @static
                                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                                 * @returns {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.ControlPoint} ControlPoint
                                                 * @throws {Error} If the payload is not a reader or valid buffer
                                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                                 */
                                                ControlPoint.decodeDelimited = function decodeDelimited(reader) {
                                                    if (!(reader instanceof $Reader))
                                                        reader = new $Reader(reader);
                                                    return this.decode(reader, reader.uint32());
                                                };
    
                                                /**
                                                 * Verifies a ControlPoint message.
                                                 * @function verify
                                                 * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.ControlPoint
                                                 * @static
                                                 * @param {Object.<string,*>} message Plain object to verify
                                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                                 */
                                                ControlPoint.verify = function verify(message) {
                                                    if (typeof message !== "object" || message === null)
                                                        return "object expected";
                                                    if (message.attributeValue != null && message.hasOwnProperty("attributeValue"))
                                                        if (!$util.isString(message.attributeValue))
                                                            return "attributeValue: string expected";
                                                    if (message.boostAmount != null && message.hasOwnProperty("boostAmount"))
                                                        if (typeof message.boostAmount !== "number")
                                                            return "boostAmount: number expected";
                                                    return null;
                                                };
    
                                                /**
                                                 * Creates a ControlPoint message from a plain object. Also converts values to their respective internal types.
                                                 * @function fromObject
                                                 * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.ControlPoint
                                                 * @static
                                                 * @param {Object.<string,*>} object Plain object
                                                 * @returns {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.ControlPoint} ControlPoint
                                                 */
                                                ControlPoint.fromObject = function fromObject(object) {
                                                    if (object instanceof $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.ControlPoint)
                                                        return object;
                                                    var message = new $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.ControlPoint();
                                                    if (object.attributeValue != null)
                                                        message.attributeValue = String(object.attributeValue);
                                                    if (object.boostAmount != null)
                                                        message.boostAmount = Number(object.boostAmount);
                                                    return message;
                                                };
    
                                                /**
                                                 * Creates a plain object from a ControlPoint message. Also converts values to other types if specified.
                                                 * @function toObject
                                                 * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.ControlPoint
                                                 * @static
                                                 * @param {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.ControlPoint} message ControlPoint
                                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                                 * @returns {Object.<string,*>} Plain object
                                                 */
                                                ControlPoint.toObject = function toObject(message, options) {
                                                    if (!options)
                                                        options = {};
                                                    var object = {};
                                                    if (options.defaults) {
                                                        object.attributeValue = "";
                                                        object.boostAmount = 0;
                                                    }
                                                    if (message.attributeValue != null && message.hasOwnProperty("attributeValue"))
                                                        object.attributeValue = message.attributeValue;
                                                    if (message.boostAmount != null && message.hasOwnProperty("boostAmount"))
                                                        object.boostAmount = options.json && !isFinite(message.boostAmount) ? String(message.boostAmount) : message.boostAmount;
                                                    return object;
                                                };
    
                                                /**
                                                 * Converts this ControlPoint to JSON.
                                                 * @function toJSON
                                                 * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.ControlPoint
                                                 * @instance
                                                 * @returns {Object.<string,*>} JSON object
                                                 */
                                                ControlPoint.prototype.toJSON = function toJSON() {
                                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                                };
    
                                                /**
                                                 * Gets the default type url for ControlPoint
                                                 * @function getTypeUrl
                                                 * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.ControlPoint
                                                 * @static
                                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                                 * @returns {string} The default type url
                                                 */
                                                ControlPoint.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                                    if (typeUrlPrefix === undefined) {
                                                        typeUrlPrefix = "type.googleapis.com";
                                                    }
                                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.ControlPoint";
                                                };
    
                                                return ControlPoint;
                                            })();
    
                                            return BoostControlSpec;
                                        })();
    
                                        return ConditionBoostSpec;
                                    })();
    
                                    return BoostSpec;
                                })();
    
                                return BoostSpecs;
                            })();
    
                            SearchConfig.FilterSpecs = (function() {
    
                                /**
                                 * Properties of a FilterSpecs.
                                 * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig
                                 * @interface IFilterSpecs
                                 * @property {Array.<string>|null} [dataStores] FilterSpecs dataStores
                                 * @property {string|null} [filter] FilterSpecs filter
                                 */
    
                                /**
                                 * Constructs a new FilterSpecs.
                                 * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig
                                 * @classdesc Represents a FilterSpecs.
                                 * @implements IFilterSpecs
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.IFilterSpecs=} [properties] Properties to set
                                 */
                                function FilterSpecs(properties) {
                                    this.dataStores = [];
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * FilterSpecs dataStores.
                                 * @member {Array.<string>} dataStores
                                 * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.FilterSpecs
                                 * @instance
                                 */
                                FilterSpecs.prototype.dataStores = $util.emptyArray;
    
                                /**
                                 * FilterSpecs filter.
                                 * @member {string} filter
                                 * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.FilterSpecs
                                 * @instance
                                 */
                                FilterSpecs.prototype.filter = "";
    
                                /**
                                 * Creates a new FilterSpecs instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.FilterSpecs
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.IFilterSpecs=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.FilterSpecs} FilterSpecs instance
                                 */
                                FilterSpecs.create = function create(properties) {
                                    return new FilterSpecs(properties);
                                };
    
                                /**
                                 * Encodes the specified FilterSpecs message. Does not implicitly {@link google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.FilterSpecs.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.FilterSpecs
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.IFilterSpecs} message FilterSpecs message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                FilterSpecs.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.dataStores != null && message.dataStores.length)
                                        for (var i = 0; i < message.dataStores.length; ++i)
                                            writer.uint32(/* id 1, wireType 2 =*/10).string(message.dataStores[i]);
                                    if (message.filter != null && Object.hasOwnProperty.call(message, "filter"))
                                        writer.uint32(/* id 2, wireType 2 =*/18).string(message.filter);
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified FilterSpecs message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.FilterSpecs.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.FilterSpecs
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.IFilterSpecs} message FilterSpecs message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                FilterSpecs.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a FilterSpecs message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.FilterSpecs
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.FilterSpecs} FilterSpecs
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                FilterSpecs.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.FilterSpecs();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                if (!(message.dataStores && message.dataStores.length))
                                                    message.dataStores = [];
                                                message.dataStores.push(reader.string());
                                                break;
                                            }
                                        case 2: {
                                                message.filter = reader.string();
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a FilterSpecs message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.FilterSpecs
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.FilterSpecs} FilterSpecs
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                FilterSpecs.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a FilterSpecs message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.FilterSpecs
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                FilterSpecs.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.dataStores != null && message.hasOwnProperty("dataStores")) {
                                        if (!Array.isArray(message.dataStores))
                                            return "dataStores: array expected";
                                        for (var i = 0; i < message.dataStores.length; ++i)
                                            if (!$util.isString(message.dataStores[i]))
                                                return "dataStores: string[] expected";
                                    }
                                    if (message.filter != null && message.hasOwnProperty("filter"))
                                        if (!$util.isString(message.filter))
                                            return "filter: string expected";
                                    return null;
                                };
    
                                /**
                                 * Creates a FilterSpecs message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.FilterSpecs
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.FilterSpecs} FilterSpecs
                                 */
                                FilterSpecs.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.FilterSpecs)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.FilterSpecs();
                                    if (object.dataStores) {
                                        if (!Array.isArray(object.dataStores))
                                            throw TypeError(".google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.FilterSpecs.dataStores: array expected");
                                        message.dataStores = [];
                                        for (var i = 0; i < object.dataStores.length; ++i)
                                            message.dataStores[i] = String(object.dataStores[i]);
                                    }
                                    if (object.filter != null)
                                        message.filter = String(object.filter);
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a FilterSpecs message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.FilterSpecs
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.FilterSpecs} message FilterSpecs
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                FilterSpecs.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.arrays || options.defaults)
                                        object.dataStores = [];
                                    if (options.defaults)
                                        object.filter = "";
                                    if (message.dataStores && message.dataStores.length) {
                                        object.dataStores = [];
                                        for (var j = 0; j < message.dataStores.length; ++j)
                                            object.dataStores[j] = message.dataStores[j];
                                    }
                                    if (message.filter != null && message.hasOwnProperty("filter"))
                                        object.filter = message.filter;
                                    return object;
                                };
    
                                /**
                                 * Converts this FilterSpecs to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.FilterSpecs
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                FilterSpecs.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for FilterSpecs
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.FilterSpecs
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                FilterSpecs.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2.SearchKnowledgeRequest.SearchConfig.FilterSpecs";
                                };
    
                                return FilterSpecs;
                            })();
    
                            return SearchConfig;
                        })();
    
                        return SearchKnowledgeRequest;
                    })();
    
                    v2.SearchKnowledgeResponse = (function() {
    
                        /**
                         * Properties of a SearchKnowledgeResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ISearchKnowledgeResponse
                         * @property {Array.<google.cloud.dialogflow.v2.ISearchKnowledgeAnswer>|null} [answers] SearchKnowledgeResponse answers
                         * @property {string|null} [rewrittenQuery] SearchKnowledgeResponse rewrittenQuery
                         */
    
                        /**
                         * Constructs a new SearchKnowledgeResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a SearchKnowledgeResponse.
                         * @implements ISearchKnowledgeResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ISearchKnowledgeResponse=} [properties] Properties to set
                         */
                        function SearchKnowledgeResponse(properties) {
                            this.answers = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SearchKnowledgeResponse answers.
                         * @member {Array.<google.cloud.dialogflow.v2.ISearchKnowledgeAnswer>} answers
                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeResponse
                         * @instance
                         */
                        SearchKnowledgeResponse.prototype.answers = $util.emptyArray;
    
                        /**
                         * SearchKnowledgeResponse rewrittenQuery.
                         * @member {string} rewrittenQuery
                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeResponse
                         * @instance
                         */
                        SearchKnowledgeResponse.prototype.rewrittenQuery = "";
    
                        /**
                         * Creates a new SearchKnowledgeResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISearchKnowledgeResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.SearchKnowledgeResponse} SearchKnowledgeResponse instance
                         */
                        SearchKnowledgeResponse.create = function create(properties) {
                            return new SearchKnowledgeResponse(properties);
                        };
    
                        /**
                         * Encodes the specified SearchKnowledgeResponse message. Does not implicitly {@link google.cloud.dialogflow.v2.SearchKnowledgeResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISearchKnowledgeResponse} message SearchKnowledgeResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SearchKnowledgeResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.answers != null && message.answers.length)
                                for (var i = 0; i < message.answers.length; ++i)
                                    $root.google.cloud.dialogflow.v2.SearchKnowledgeAnswer.encode(message.answers[i], writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.rewrittenQuery != null && Object.hasOwnProperty.call(message, "rewrittenQuery"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.rewrittenQuery);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SearchKnowledgeResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.SearchKnowledgeResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISearchKnowledgeResponse} message SearchKnowledgeResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SearchKnowledgeResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SearchKnowledgeResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.SearchKnowledgeResponse} SearchKnowledgeResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SearchKnowledgeResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.SearchKnowledgeResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 2: {
                                        if (!(message.answers && message.answers.length))
                                            message.answers = [];
                                        message.answers.push($root.google.cloud.dialogflow.v2.SearchKnowledgeAnswer.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 3: {
                                        message.rewrittenQuery = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SearchKnowledgeResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.SearchKnowledgeResponse} SearchKnowledgeResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SearchKnowledgeResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SearchKnowledgeResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SearchKnowledgeResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.answers != null && message.hasOwnProperty("answers")) {
                                if (!Array.isArray(message.answers))
                                    return "answers: array expected";
                                for (var i = 0; i < message.answers.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.SearchKnowledgeAnswer.verify(message.answers[i]);
                                    if (error)
                                        return "answers." + error;
                                }
                            }
                            if (message.rewrittenQuery != null && message.hasOwnProperty("rewrittenQuery"))
                                if (!$util.isString(message.rewrittenQuery))
                                    return "rewrittenQuery: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a SearchKnowledgeResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.SearchKnowledgeResponse} SearchKnowledgeResponse
                         */
                        SearchKnowledgeResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.SearchKnowledgeResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.SearchKnowledgeResponse();
                            if (object.answers) {
                                if (!Array.isArray(object.answers))
                                    throw TypeError(".google.cloud.dialogflow.v2.SearchKnowledgeResponse.answers: array expected");
                                message.answers = [];
                                for (var i = 0; i < object.answers.length; ++i) {
                                    if (typeof object.answers[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.SearchKnowledgeResponse.answers: object expected");
                                    message.answers[i] = $root.google.cloud.dialogflow.v2.SearchKnowledgeAnswer.fromObject(object.answers[i]);
                                }
                            }
                            if (object.rewrittenQuery != null)
                                message.rewrittenQuery = String(object.rewrittenQuery);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SearchKnowledgeResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.SearchKnowledgeResponse} message SearchKnowledgeResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SearchKnowledgeResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.answers = [];
                            if (options.defaults)
                                object.rewrittenQuery = "";
                            if (message.answers && message.answers.length) {
                                object.answers = [];
                                for (var j = 0; j < message.answers.length; ++j)
                                    object.answers[j] = $root.google.cloud.dialogflow.v2.SearchKnowledgeAnswer.toObject(message.answers[j], options);
                            }
                            if (message.rewrittenQuery != null && message.hasOwnProperty("rewrittenQuery"))
                                object.rewrittenQuery = message.rewrittenQuery;
                            return object;
                        };
    
                        /**
                         * Converts this SearchKnowledgeResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SearchKnowledgeResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SearchKnowledgeResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SearchKnowledgeResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.SearchKnowledgeResponse";
                        };
    
                        return SearchKnowledgeResponse;
                    })();
    
                    v2.SearchKnowledgeAnswer = (function() {
    
                        /**
                         * Properties of a SearchKnowledgeAnswer.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ISearchKnowledgeAnswer
                         * @property {string|null} [answer] SearchKnowledgeAnswer answer
                         * @property {google.cloud.dialogflow.v2.SearchKnowledgeAnswer.AnswerType|null} [answerType] SearchKnowledgeAnswer answerType
                         * @property {Array.<google.cloud.dialogflow.v2.SearchKnowledgeAnswer.IAnswerSource>|null} [answerSources] SearchKnowledgeAnswer answerSources
                         * @property {string|null} [answerRecord] SearchKnowledgeAnswer answerRecord
                         */
    
                        /**
                         * Constructs a new SearchKnowledgeAnswer.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a SearchKnowledgeAnswer.
                         * @implements ISearchKnowledgeAnswer
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ISearchKnowledgeAnswer=} [properties] Properties to set
                         */
                        function SearchKnowledgeAnswer(properties) {
                            this.answerSources = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SearchKnowledgeAnswer answer.
                         * @member {string} answer
                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeAnswer
                         * @instance
                         */
                        SearchKnowledgeAnswer.prototype.answer = "";
    
                        /**
                         * SearchKnowledgeAnswer answerType.
                         * @member {google.cloud.dialogflow.v2.SearchKnowledgeAnswer.AnswerType} answerType
                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeAnswer
                         * @instance
                         */
                        SearchKnowledgeAnswer.prototype.answerType = 0;
    
                        /**
                         * SearchKnowledgeAnswer answerSources.
                         * @member {Array.<google.cloud.dialogflow.v2.SearchKnowledgeAnswer.IAnswerSource>} answerSources
                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeAnswer
                         * @instance
                         */
                        SearchKnowledgeAnswer.prototype.answerSources = $util.emptyArray;
    
                        /**
                         * SearchKnowledgeAnswer answerRecord.
                         * @member {string} answerRecord
                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeAnswer
                         * @instance
                         */
                        SearchKnowledgeAnswer.prototype.answerRecord = "";
    
                        /**
                         * Creates a new SearchKnowledgeAnswer instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeAnswer
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISearchKnowledgeAnswer=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.SearchKnowledgeAnswer} SearchKnowledgeAnswer instance
                         */
                        SearchKnowledgeAnswer.create = function create(properties) {
                            return new SearchKnowledgeAnswer(properties);
                        };
    
                        /**
                         * Encodes the specified SearchKnowledgeAnswer message. Does not implicitly {@link google.cloud.dialogflow.v2.SearchKnowledgeAnswer.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeAnswer
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISearchKnowledgeAnswer} message SearchKnowledgeAnswer message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SearchKnowledgeAnswer.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.answer != null && Object.hasOwnProperty.call(message, "answer"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.answer);
                            if (message.answerType != null && Object.hasOwnProperty.call(message, "answerType"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.answerType);
                            if (message.answerSources != null && message.answerSources.length)
                                for (var i = 0; i < message.answerSources.length; ++i)
                                    $root.google.cloud.dialogflow.v2.SearchKnowledgeAnswer.AnswerSource.encode(message.answerSources[i], writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            if (message.answerRecord != null && Object.hasOwnProperty.call(message, "answerRecord"))
                                writer.uint32(/* id 5, wireType 2 =*/42).string(message.answerRecord);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SearchKnowledgeAnswer message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.SearchKnowledgeAnswer.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeAnswer
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISearchKnowledgeAnswer} message SearchKnowledgeAnswer message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SearchKnowledgeAnswer.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SearchKnowledgeAnswer message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeAnswer
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.SearchKnowledgeAnswer} SearchKnowledgeAnswer
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SearchKnowledgeAnswer.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.SearchKnowledgeAnswer();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.answer = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.answerType = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        if (!(message.answerSources && message.answerSources.length))
                                            message.answerSources = [];
                                        message.answerSources.push($root.google.cloud.dialogflow.v2.SearchKnowledgeAnswer.AnswerSource.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 5: {
                                        message.answerRecord = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SearchKnowledgeAnswer message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeAnswer
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.SearchKnowledgeAnswer} SearchKnowledgeAnswer
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SearchKnowledgeAnswer.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SearchKnowledgeAnswer message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeAnswer
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SearchKnowledgeAnswer.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.answer != null && message.hasOwnProperty("answer"))
                                if (!$util.isString(message.answer))
                                    return "answer: string expected";
                            if (message.answerType != null && message.hasOwnProperty("answerType"))
                                switch (message.answerType) {
                                default:
                                    return "answerType: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                    break;
                                }
                            if (message.answerSources != null && message.hasOwnProperty("answerSources")) {
                                if (!Array.isArray(message.answerSources))
                                    return "answerSources: array expected";
                                for (var i = 0; i < message.answerSources.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.SearchKnowledgeAnswer.AnswerSource.verify(message.answerSources[i]);
                                    if (error)
                                        return "answerSources." + error;
                                }
                            }
                            if (message.answerRecord != null && message.hasOwnProperty("answerRecord"))
                                if (!$util.isString(message.answerRecord))
                                    return "answerRecord: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a SearchKnowledgeAnswer message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeAnswer
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.SearchKnowledgeAnswer} SearchKnowledgeAnswer
                         */
                        SearchKnowledgeAnswer.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.SearchKnowledgeAnswer)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.SearchKnowledgeAnswer();
                            if (object.answer != null)
                                message.answer = String(object.answer);
                            switch (object.answerType) {
                            default:
                                if (typeof object.answerType === "number") {
                                    message.answerType = object.answerType;
                                    break;
                                }
                                break;
                            case "ANSWER_TYPE_UNSPECIFIED":
                            case 0:
                                message.answerType = 0;
                                break;
                            case "FAQ":
                            case 1:
                                message.answerType = 1;
                                break;
                            case "GENERATIVE":
                            case 2:
                                message.answerType = 2;
                                break;
                            case "INTENT":
                            case 3:
                                message.answerType = 3;
                                break;
                            }
                            if (object.answerSources) {
                                if (!Array.isArray(object.answerSources))
                                    throw TypeError(".google.cloud.dialogflow.v2.SearchKnowledgeAnswer.answerSources: array expected");
                                message.answerSources = [];
                                for (var i = 0; i < object.answerSources.length; ++i) {
                                    if (typeof object.answerSources[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.SearchKnowledgeAnswer.answerSources: object expected");
                                    message.answerSources[i] = $root.google.cloud.dialogflow.v2.SearchKnowledgeAnswer.AnswerSource.fromObject(object.answerSources[i]);
                                }
                            }
                            if (object.answerRecord != null)
                                message.answerRecord = String(object.answerRecord);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SearchKnowledgeAnswer message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeAnswer
                         * @static
                         * @param {google.cloud.dialogflow.v2.SearchKnowledgeAnswer} message SearchKnowledgeAnswer
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SearchKnowledgeAnswer.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.answerSources = [];
                            if (options.defaults) {
                                object.answer = "";
                                object.answerType = options.enums === String ? "ANSWER_TYPE_UNSPECIFIED" : 0;
                                object.answerRecord = "";
                            }
                            if (message.answer != null && message.hasOwnProperty("answer"))
                                object.answer = message.answer;
                            if (message.answerType != null && message.hasOwnProperty("answerType"))
                                object.answerType = options.enums === String ? $root.google.cloud.dialogflow.v2.SearchKnowledgeAnswer.AnswerType[message.answerType] === undefined ? message.answerType : $root.google.cloud.dialogflow.v2.SearchKnowledgeAnswer.AnswerType[message.answerType] : message.answerType;
                            if (message.answerSources && message.answerSources.length) {
                                object.answerSources = [];
                                for (var j = 0; j < message.answerSources.length; ++j)
                                    object.answerSources[j] = $root.google.cloud.dialogflow.v2.SearchKnowledgeAnswer.AnswerSource.toObject(message.answerSources[j], options);
                            }
                            if (message.answerRecord != null && message.hasOwnProperty("answerRecord"))
                                object.answerRecord = message.answerRecord;
                            return object;
                        };
    
                        /**
                         * Converts this SearchKnowledgeAnswer to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeAnswer
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SearchKnowledgeAnswer.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SearchKnowledgeAnswer
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.SearchKnowledgeAnswer
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SearchKnowledgeAnswer.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.SearchKnowledgeAnswer";
                        };
    
                        /**
                         * AnswerType enum.
                         * @name google.cloud.dialogflow.v2.SearchKnowledgeAnswer.AnswerType
                         * @enum {number}
                         * @property {number} ANSWER_TYPE_UNSPECIFIED=0 ANSWER_TYPE_UNSPECIFIED value
                         * @property {number} FAQ=1 FAQ value
                         * @property {number} GENERATIVE=2 GENERATIVE value
                         * @property {number} INTENT=3 INTENT value
                         */
                        SearchKnowledgeAnswer.AnswerType = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "ANSWER_TYPE_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "FAQ"] = 1;
                            values[valuesById[2] = "GENERATIVE"] = 2;
                            values[valuesById[3] = "INTENT"] = 3;
                            return values;
                        })();
    
                        SearchKnowledgeAnswer.AnswerSource = (function() {
    
                            /**
                             * Properties of an AnswerSource.
                             * @memberof google.cloud.dialogflow.v2.SearchKnowledgeAnswer
                             * @interface IAnswerSource
                             * @property {string|null} [title] AnswerSource title
                             * @property {string|null} [uri] AnswerSource uri
                             * @property {string|null} [snippet] AnswerSource snippet
                             * @property {google.protobuf.IStruct|null} [metadata] AnswerSource metadata
                             */
    
                            /**
                             * Constructs a new AnswerSource.
                             * @memberof google.cloud.dialogflow.v2.SearchKnowledgeAnswer
                             * @classdesc Represents an AnswerSource.
                             * @implements IAnswerSource
                             * @constructor
                             * @param {google.cloud.dialogflow.v2.SearchKnowledgeAnswer.IAnswerSource=} [properties] Properties to set
                             */
                            function AnswerSource(properties) {
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * AnswerSource title.
                             * @member {string} title
                             * @memberof google.cloud.dialogflow.v2.SearchKnowledgeAnswer.AnswerSource
                             * @instance
                             */
                            AnswerSource.prototype.title = "";
    
                            /**
                             * AnswerSource uri.
                             * @member {string} uri
                             * @memberof google.cloud.dialogflow.v2.SearchKnowledgeAnswer.AnswerSource
                             * @instance
                             */
                            AnswerSource.prototype.uri = "";
    
                            /**
                             * AnswerSource snippet.
                             * @member {string} snippet
                             * @memberof google.cloud.dialogflow.v2.SearchKnowledgeAnswer.AnswerSource
                             * @instance
                             */
                            AnswerSource.prototype.snippet = "";
    
                            /**
                             * AnswerSource metadata.
                             * @member {google.protobuf.IStruct|null|undefined} metadata
                             * @memberof google.cloud.dialogflow.v2.SearchKnowledgeAnswer.AnswerSource
                             * @instance
                             */
                            AnswerSource.prototype.metadata = null;
    
                            /**
                             * Creates a new AnswerSource instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2.SearchKnowledgeAnswer.AnswerSource
                             * @static
                             * @param {google.cloud.dialogflow.v2.SearchKnowledgeAnswer.IAnswerSource=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2.SearchKnowledgeAnswer.AnswerSource} AnswerSource instance
                             */
                            AnswerSource.create = function create(properties) {
                                return new AnswerSource(properties);
                            };
    
                            /**
                             * Encodes the specified AnswerSource message. Does not implicitly {@link google.cloud.dialogflow.v2.SearchKnowledgeAnswer.AnswerSource.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2.SearchKnowledgeAnswer.AnswerSource
                             * @static
                             * @param {google.cloud.dialogflow.v2.SearchKnowledgeAnswer.IAnswerSource} message AnswerSource message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            AnswerSource.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.title != null && Object.hasOwnProperty.call(message, "title"))
                                    writer.uint32(/* id 1, wireType 2 =*/10).string(message.title);
                                if (message.uri != null && Object.hasOwnProperty.call(message, "uri"))
                                    writer.uint32(/* id 2, wireType 2 =*/18).string(message.uri);
                                if (message.snippet != null && Object.hasOwnProperty.call(message, "snippet"))
                                    writer.uint32(/* id 3, wireType 2 =*/26).string(message.snippet);
                                if (message.metadata != null && Object.hasOwnProperty.call(message, "metadata"))
                                    $root.google.protobuf.Struct.encode(message.metadata, writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                                return writer;
                            };
    
                            /**
                             * Encodes the specified AnswerSource message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.SearchKnowledgeAnswer.AnswerSource.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2.SearchKnowledgeAnswer.AnswerSource
                             * @static
                             * @param {google.cloud.dialogflow.v2.SearchKnowledgeAnswer.IAnswerSource} message AnswerSource message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            AnswerSource.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes an AnswerSource message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2.SearchKnowledgeAnswer.AnswerSource
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2.SearchKnowledgeAnswer.AnswerSource} AnswerSource
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            AnswerSource.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.SearchKnowledgeAnswer.AnswerSource();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.title = reader.string();
                                            break;
                                        }
                                    case 2: {
                                            message.uri = reader.string();
                                            break;
                                        }
                                    case 3: {
                                            message.snippet = reader.string();
                                            break;
                                        }
                                    case 5: {
                                            message.metadata = $root.google.protobuf.Struct.decode(reader, reader.uint32());
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes an AnswerSource message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2.SearchKnowledgeAnswer.AnswerSource
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2.SearchKnowledgeAnswer.AnswerSource} AnswerSource
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            AnswerSource.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies an AnswerSource message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2.SearchKnowledgeAnswer.AnswerSource
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            AnswerSource.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.title != null && message.hasOwnProperty("title"))
                                    if (!$util.isString(message.title))
                                        return "title: string expected";
                                if (message.uri != null && message.hasOwnProperty("uri"))
                                    if (!$util.isString(message.uri))
                                        return "uri: string expected";
                                if (message.snippet != null && message.hasOwnProperty("snippet"))
                                    if (!$util.isString(message.snippet))
                                        return "snippet: string expected";
                                if (message.metadata != null && message.hasOwnProperty("metadata")) {
                                    var error = $root.google.protobuf.Struct.verify(message.metadata);
                                    if (error)
                                        return "metadata." + error;
                                }
                                return null;
                            };
    
                            /**
                             * Creates an AnswerSource message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2.SearchKnowledgeAnswer.AnswerSource
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2.SearchKnowledgeAnswer.AnswerSource} AnswerSource
                             */
                            AnswerSource.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2.SearchKnowledgeAnswer.AnswerSource)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2.SearchKnowledgeAnswer.AnswerSource();
                                if (object.title != null)
                                    message.title = String(object.title);
                                if (object.uri != null)
                                    message.uri = String(object.uri);
                                if (object.snippet != null)
                                    message.snippet = String(object.snippet);
                                if (object.metadata != null) {
                                    if (typeof object.metadata !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.SearchKnowledgeAnswer.AnswerSource.metadata: object expected");
                                    message.metadata = $root.google.protobuf.Struct.fromObject(object.metadata);
                                }
                                return message;
                            };
    
                            /**
                             * Creates a plain object from an AnswerSource message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2.SearchKnowledgeAnswer.AnswerSource
                             * @static
                             * @param {google.cloud.dialogflow.v2.SearchKnowledgeAnswer.AnswerSource} message AnswerSource
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            AnswerSource.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.defaults) {
                                    object.title = "";
                                    object.uri = "";
                                    object.snippet = "";
                                    object.metadata = null;
                                }
                                if (message.title != null && message.hasOwnProperty("title"))
                                    object.title = message.title;
                                if (message.uri != null && message.hasOwnProperty("uri"))
                                    object.uri = message.uri;
                                if (message.snippet != null && message.hasOwnProperty("snippet"))
                                    object.snippet = message.snippet;
                                if (message.metadata != null && message.hasOwnProperty("metadata"))
                                    object.metadata = $root.google.protobuf.Struct.toObject(message.metadata, options);
                                return object;
                            };
    
                            /**
                             * Converts this AnswerSource to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2.SearchKnowledgeAnswer.AnswerSource
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            AnswerSource.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for AnswerSource
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2.SearchKnowledgeAnswer.AnswerSource
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            AnswerSource.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2.SearchKnowledgeAnswer.AnswerSource";
                            };
    
                            return AnswerSource;
                        })();
    
                        return SearchKnowledgeAnswer;
                    })();
    
                    v2.GenerateSuggestionsRequest = (function() {
    
                        /**
                         * Properties of a GenerateSuggestionsRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IGenerateSuggestionsRequest
                         * @property {string|null} [conversation] GenerateSuggestionsRequest conversation
                         * @property {string|null} [latestMessage] GenerateSuggestionsRequest latestMessage
                         * @property {Array.<google.cloud.dialogflow.v2.TriggerEvent>|null} [triggerEvents] GenerateSuggestionsRequest triggerEvents
                         */
    
                        /**
                         * Constructs a new GenerateSuggestionsRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a GenerateSuggestionsRequest.
                         * @implements IGenerateSuggestionsRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IGenerateSuggestionsRequest=} [properties] Properties to set
                         */
                        function GenerateSuggestionsRequest(properties) {
                            this.triggerEvents = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GenerateSuggestionsRequest conversation.
                         * @member {string} conversation
                         * @memberof google.cloud.dialogflow.v2.GenerateSuggestionsRequest
                         * @instance
                         */
                        GenerateSuggestionsRequest.prototype.conversation = "";
    
                        /**
                         * GenerateSuggestionsRequest latestMessage.
                         * @member {string} latestMessage
                         * @memberof google.cloud.dialogflow.v2.GenerateSuggestionsRequest
                         * @instance
                         */
                        GenerateSuggestionsRequest.prototype.latestMessage = "";
    
                        /**
                         * GenerateSuggestionsRequest triggerEvents.
                         * @member {Array.<google.cloud.dialogflow.v2.TriggerEvent>} triggerEvents
                         * @memberof google.cloud.dialogflow.v2.GenerateSuggestionsRequest
                         * @instance
                         */
                        GenerateSuggestionsRequest.prototype.triggerEvents = $util.emptyArray;
    
                        /**
                         * Creates a new GenerateSuggestionsRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.GenerateSuggestionsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGenerateSuggestionsRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.GenerateSuggestionsRequest} GenerateSuggestionsRequest instance
                         */
                        GenerateSuggestionsRequest.create = function create(properties) {
                            return new GenerateSuggestionsRequest(properties);
                        };
    
                        /**
                         * Encodes the specified GenerateSuggestionsRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.GenerateSuggestionsRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.GenerateSuggestionsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGenerateSuggestionsRequest} message GenerateSuggestionsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GenerateSuggestionsRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.conversation != null && Object.hasOwnProperty.call(message, "conversation"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.conversation);
                            if (message.latestMessage != null && Object.hasOwnProperty.call(message, "latestMessage"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.latestMessage);
                            if (message.triggerEvents != null && message.triggerEvents.length) {
                                writer.uint32(/* id 3, wireType 2 =*/26).fork();
                                for (var i = 0; i < message.triggerEvents.length; ++i)
                                    writer.int32(message.triggerEvents[i]);
                                writer.ldelim();
                            }
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GenerateSuggestionsRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.GenerateSuggestionsRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GenerateSuggestionsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGenerateSuggestionsRequest} message GenerateSuggestionsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GenerateSuggestionsRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GenerateSuggestionsRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.GenerateSuggestionsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.GenerateSuggestionsRequest} GenerateSuggestionsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GenerateSuggestionsRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.GenerateSuggestionsRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.conversation = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.latestMessage = reader.string();
                                        break;
                                    }
                                case 3: {
                                        if (!(message.triggerEvents && message.triggerEvents.length))
                                            message.triggerEvents = [];
                                        if ((tag & 7) === 2) {
                                            var end2 = reader.uint32() + reader.pos;
                                            while (reader.pos < end2)
                                                message.triggerEvents.push(reader.int32());
                                        } else
                                            message.triggerEvents.push(reader.int32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GenerateSuggestionsRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GenerateSuggestionsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.GenerateSuggestionsRequest} GenerateSuggestionsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GenerateSuggestionsRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GenerateSuggestionsRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.GenerateSuggestionsRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GenerateSuggestionsRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.conversation != null && message.hasOwnProperty("conversation"))
                                if (!$util.isString(message.conversation))
                                    return "conversation: string expected";
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                if (!$util.isString(message.latestMessage))
                                    return "latestMessage: string expected";
                            if (message.triggerEvents != null && message.hasOwnProperty("triggerEvents")) {
                                if (!Array.isArray(message.triggerEvents))
                                    return "triggerEvents: array expected";
                                for (var i = 0; i < message.triggerEvents.length; ++i)
                                    switch (message.triggerEvents[i]) {
                                    default:
                                        return "triggerEvents: enum value[] expected";
                                    case 0:
                                    case 1:
                                    case 2:
                                    case 3:
                                    case 4:
                                        break;
                                    }
                            }
                            return null;
                        };
    
                        /**
                         * Creates a GenerateSuggestionsRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.GenerateSuggestionsRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.GenerateSuggestionsRequest} GenerateSuggestionsRequest
                         */
                        GenerateSuggestionsRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.GenerateSuggestionsRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.GenerateSuggestionsRequest();
                            if (object.conversation != null)
                                message.conversation = String(object.conversation);
                            if (object.latestMessage != null)
                                message.latestMessage = String(object.latestMessage);
                            if (object.triggerEvents) {
                                if (!Array.isArray(object.triggerEvents))
                                    throw TypeError(".google.cloud.dialogflow.v2.GenerateSuggestionsRequest.triggerEvents: array expected");
                                message.triggerEvents = [];
                                for (var i = 0; i < object.triggerEvents.length; ++i)
                                    switch (object.triggerEvents[i]) {
                                    default:
                                        if (typeof object.triggerEvents[i] === "number") {
                                            message.triggerEvents[i] = object.triggerEvents[i];
                                            break;
                                        }
                                    case "TRIGGER_EVENT_UNSPECIFIED":
                                    case 0:
                                        message.triggerEvents[i] = 0;
                                        break;
                                    case "END_OF_UTTERANCE":
                                    case 1:
                                        message.triggerEvents[i] = 1;
                                        break;
                                    case "MANUAL_CALL":
                                    case 2:
                                        message.triggerEvents[i] = 2;
                                        break;
                                    case "CUSTOMER_MESSAGE":
                                    case 3:
                                        message.triggerEvents[i] = 3;
                                        break;
                                    case "AGENT_MESSAGE":
                                    case 4:
                                        message.triggerEvents[i] = 4;
                                        break;
                                    }
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GenerateSuggestionsRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.GenerateSuggestionsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.GenerateSuggestionsRequest} message GenerateSuggestionsRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GenerateSuggestionsRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.triggerEvents = [];
                            if (options.defaults) {
                                object.conversation = "";
                                object.latestMessage = "";
                            }
                            if (message.conversation != null && message.hasOwnProperty("conversation"))
                                object.conversation = message.conversation;
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                object.latestMessage = message.latestMessage;
                            if (message.triggerEvents && message.triggerEvents.length) {
                                object.triggerEvents = [];
                                for (var j = 0; j < message.triggerEvents.length; ++j)
                                    object.triggerEvents[j] = options.enums === String ? $root.google.cloud.dialogflow.v2.TriggerEvent[message.triggerEvents[j]] === undefined ? message.triggerEvents[j] : $root.google.cloud.dialogflow.v2.TriggerEvent[message.triggerEvents[j]] : message.triggerEvents[j];
                            }
                            return object;
                        };
    
                        /**
                         * Converts this GenerateSuggestionsRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.GenerateSuggestionsRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GenerateSuggestionsRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GenerateSuggestionsRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.GenerateSuggestionsRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GenerateSuggestionsRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.GenerateSuggestionsRequest";
                        };
    
                        return GenerateSuggestionsRequest;
                    })();
    
                    v2.ConversationProfiles = (function() {
    
                        /**
                         * Constructs a new ConversationProfiles service.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a ConversationProfiles
                         * @extends $protobuf.rpc.Service
                         * @constructor
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         */
                        function ConversationProfiles(rpcImpl, requestDelimited, responseDelimited) {
                            $protobuf.rpc.Service.call(this, rpcImpl, requestDelimited, responseDelimited);
                        }
    
                        (ConversationProfiles.prototype = Object.create($protobuf.rpc.Service.prototype)).constructor = ConversationProfiles;
    
                        /**
                         * Creates new ConversationProfiles service using the specified rpc implementation.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ConversationProfiles
                         * @static
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         * @returns {ConversationProfiles} RPC service. Useful where requests and/or responses are streamed.
                         */
                        ConversationProfiles.create = function create(rpcImpl, requestDelimited, responseDelimited) {
                            return new this(rpcImpl, requestDelimited, responseDelimited);
                        };
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.ConversationProfiles|listConversationProfiles}.
                         * @memberof google.cloud.dialogflow.v2.ConversationProfiles
                         * @typedef ListConversationProfilesCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.ListConversationProfilesResponse} [response] ListConversationProfilesResponse
                         */
    
                        /**
                         * Calls ListConversationProfiles.
                         * @function listConversationProfiles
                         * @memberof google.cloud.dialogflow.v2.ConversationProfiles
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IListConversationProfilesRequest} request ListConversationProfilesRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.ConversationProfiles.ListConversationProfilesCallback} callback Node-style callback called with the error, if any, and ListConversationProfilesResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(ConversationProfiles.prototype.listConversationProfiles = function listConversationProfiles(request, callback) {
                            return this.rpcCall(listConversationProfiles, $root.google.cloud.dialogflow.v2.ListConversationProfilesRequest, $root.google.cloud.dialogflow.v2.ListConversationProfilesResponse, request, callback);
                        }, "name", { value: "ListConversationProfiles" });
    
                        /**
                         * Calls ListConversationProfiles.
                         * @function listConversationProfiles
                         * @memberof google.cloud.dialogflow.v2.ConversationProfiles
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IListConversationProfilesRequest} request ListConversationProfilesRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.ListConversationProfilesResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.ConversationProfiles|getConversationProfile}.
                         * @memberof google.cloud.dialogflow.v2.ConversationProfiles
                         * @typedef GetConversationProfileCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.ConversationProfile} [response] ConversationProfile
                         */
    
                        /**
                         * Calls GetConversationProfile.
                         * @function getConversationProfile
                         * @memberof google.cloud.dialogflow.v2.ConversationProfiles
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IGetConversationProfileRequest} request GetConversationProfileRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.ConversationProfiles.GetConversationProfileCallback} callback Node-style callback called with the error, if any, and ConversationProfile
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(ConversationProfiles.prototype.getConversationProfile = function getConversationProfile(request, callback) {
                            return this.rpcCall(getConversationProfile, $root.google.cloud.dialogflow.v2.GetConversationProfileRequest, $root.google.cloud.dialogflow.v2.ConversationProfile, request, callback);
                        }, "name", { value: "GetConversationProfile" });
    
                        /**
                         * Calls GetConversationProfile.
                         * @function getConversationProfile
                         * @memberof google.cloud.dialogflow.v2.ConversationProfiles
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IGetConversationProfileRequest} request GetConversationProfileRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.ConversationProfile>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.ConversationProfiles|createConversationProfile}.
                         * @memberof google.cloud.dialogflow.v2.ConversationProfiles
                         * @typedef CreateConversationProfileCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.ConversationProfile} [response] ConversationProfile
                         */
    
                        /**
                         * Calls CreateConversationProfile.
                         * @function createConversationProfile
                         * @memberof google.cloud.dialogflow.v2.ConversationProfiles
                         * @instance
                         * @param {google.cloud.dialogflow.v2.ICreateConversationProfileRequest} request CreateConversationProfileRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.ConversationProfiles.CreateConversationProfileCallback} callback Node-style callback called with the error, if any, and ConversationProfile
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(ConversationProfiles.prototype.createConversationProfile = function createConversationProfile(request, callback) {
                            return this.rpcCall(createConversationProfile, $root.google.cloud.dialogflow.v2.CreateConversationProfileRequest, $root.google.cloud.dialogflow.v2.ConversationProfile, request, callback);
                        }, "name", { value: "CreateConversationProfile" });
    
                        /**
                         * Calls CreateConversationProfile.
                         * @function createConversationProfile
                         * @memberof google.cloud.dialogflow.v2.ConversationProfiles
                         * @instance
                         * @param {google.cloud.dialogflow.v2.ICreateConversationProfileRequest} request CreateConversationProfileRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.ConversationProfile>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.ConversationProfiles|updateConversationProfile}.
                         * @memberof google.cloud.dialogflow.v2.ConversationProfiles
                         * @typedef UpdateConversationProfileCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.ConversationProfile} [response] ConversationProfile
                         */
    
                        /**
                         * Calls UpdateConversationProfile.
                         * @function updateConversationProfile
                         * @memberof google.cloud.dialogflow.v2.ConversationProfiles
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IUpdateConversationProfileRequest} request UpdateConversationProfileRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.ConversationProfiles.UpdateConversationProfileCallback} callback Node-style callback called with the error, if any, and ConversationProfile
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(ConversationProfiles.prototype.updateConversationProfile = function updateConversationProfile(request, callback) {
                            return this.rpcCall(updateConversationProfile, $root.google.cloud.dialogflow.v2.UpdateConversationProfileRequest, $root.google.cloud.dialogflow.v2.ConversationProfile, request, callback);
                        }, "name", { value: "UpdateConversationProfile" });
    
                        /**
                         * Calls UpdateConversationProfile.
                         * @function updateConversationProfile
                         * @memberof google.cloud.dialogflow.v2.ConversationProfiles
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IUpdateConversationProfileRequest} request UpdateConversationProfileRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.ConversationProfile>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.ConversationProfiles|deleteConversationProfile}.
                         * @memberof google.cloud.dialogflow.v2.ConversationProfiles
                         * @typedef DeleteConversationProfileCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.protobuf.Empty} [response] Empty
                         */
    
                        /**
                         * Calls DeleteConversationProfile.
                         * @function deleteConversationProfile
                         * @memberof google.cloud.dialogflow.v2.ConversationProfiles
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IDeleteConversationProfileRequest} request DeleteConversationProfileRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.ConversationProfiles.DeleteConversationProfileCallback} callback Node-style callback called with the error, if any, and Empty
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(ConversationProfiles.prototype.deleteConversationProfile = function deleteConversationProfile(request, callback) {
                            return this.rpcCall(deleteConversationProfile, $root.google.cloud.dialogflow.v2.DeleteConversationProfileRequest, $root.google.protobuf.Empty, request, callback);
                        }, "name", { value: "DeleteConversationProfile" });
    
                        /**
                         * Calls DeleteConversationProfile.
                         * @function deleteConversationProfile
                         * @memberof google.cloud.dialogflow.v2.ConversationProfiles
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IDeleteConversationProfileRequest} request DeleteConversationProfileRequest message or plain object
                         * @returns {Promise<google.protobuf.Empty>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.ConversationProfiles|setSuggestionFeatureConfig}.
                         * @memberof google.cloud.dialogflow.v2.ConversationProfiles
                         * @typedef SetSuggestionFeatureConfigCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.longrunning.Operation} [response] Operation
                         */
    
                        /**
                         * Calls SetSuggestionFeatureConfig.
                         * @function setSuggestionFeatureConfig
                         * @memberof google.cloud.dialogflow.v2.ConversationProfiles
                         * @instance
                         * @param {google.cloud.dialogflow.v2.ISetSuggestionFeatureConfigRequest} request SetSuggestionFeatureConfigRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.ConversationProfiles.SetSuggestionFeatureConfigCallback} callback Node-style callback called with the error, if any, and Operation
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(ConversationProfiles.prototype.setSuggestionFeatureConfig = function setSuggestionFeatureConfig(request, callback) {
                            return this.rpcCall(setSuggestionFeatureConfig, $root.google.cloud.dialogflow.v2.SetSuggestionFeatureConfigRequest, $root.google.longrunning.Operation, request, callback);
                        }, "name", { value: "SetSuggestionFeatureConfig" });
    
                        /**
                         * Calls SetSuggestionFeatureConfig.
                         * @function setSuggestionFeatureConfig
                         * @memberof google.cloud.dialogflow.v2.ConversationProfiles
                         * @instance
                         * @param {google.cloud.dialogflow.v2.ISetSuggestionFeatureConfigRequest} request SetSuggestionFeatureConfigRequest message or plain object
                         * @returns {Promise<google.longrunning.Operation>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.ConversationProfiles|clearSuggestionFeatureConfig}.
                         * @memberof google.cloud.dialogflow.v2.ConversationProfiles
                         * @typedef ClearSuggestionFeatureConfigCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.longrunning.Operation} [response] Operation
                         */
    
                        /**
                         * Calls ClearSuggestionFeatureConfig.
                         * @function clearSuggestionFeatureConfig
                         * @memberof google.cloud.dialogflow.v2.ConversationProfiles
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IClearSuggestionFeatureConfigRequest} request ClearSuggestionFeatureConfigRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.ConversationProfiles.ClearSuggestionFeatureConfigCallback} callback Node-style callback called with the error, if any, and Operation
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(ConversationProfiles.prototype.clearSuggestionFeatureConfig = function clearSuggestionFeatureConfig(request, callback) {
                            return this.rpcCall(clearSuggestionFeatureConfig, $root.google.cloud.dialogflow.v2.ClearSuggestionFeatureConfigRequest, $root.google.longrunning.Operation, request, callback);
                        }, "name", { value: "ClearSuggestionFeatureConfig" });
    
                        /**
                         * Calls ClearSuggestionFeatureConfig.
                         * @function clearSuggestionFeatureConfig
                         * @memberof google.cloud.dialogflow.v2.ConversationProfiles
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IClearSuggestionFeatureConfigRequest} request ClearSuggestionFeatureConfigRequest message or plain object
                         * @returns {Promise<google.longrunning.Operation>} Promise
                         * @variation 2
                         */
    
                        return ConversationProfiles;
                    })();
    
                    v2.ConversationProfile = (function() {
    
                        /**
                         * Properties of a ConversationProfile.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IConversationProfile
                         * @property {string|null} [name] ConversationProfile name
                         * @property {string|null} [displayName] ConversationProfile displayName
                         * @property {google.protobuf.ITimestamp|null} [createTime] ConversationProfile createTime
                         * @property {google.protobuf.ITimestamp|null} [updateTime] ConversationProfile updateTime
                         * @property {google.cloud.dialogflow.v2.IAutomatedAgentConfig|null} [automatedAgentConfig] ConversationProfile automatedAgentConfig
                         * @property {google.cloud.dialogflow.v2.IHumanAgentAssistantConfig|null} [humanAgentAssistantConfig] ConversationProfile humanAgentAssistantConfig
                         * @property {google.cloud.dialogflow.v2.IHumanAgentHandoffConfig|null} [humanAgentHandoffConfig] ConversationProfile humanAgentHandoffConfig
                         * @property {google.cloud.dialogflow.v2.INotificationConfig|null} [notificationConfig] ConversationProfile notificationConfig
                         * @property {google.cloud.dialogflow.v2.ILoggingConfig|null} [loggingConfig] ConversationProfile loggingConfig
                         * @property {google.cloud.dialogflow.v2.INotificationConfig|null} [newMessageEventNotificationConfig] ConversationProfile newMessageEventNotificationConfig
                         * @property {google.cloud.dialogflow.v2.INotificationConfig|null} [newRecognitionResultNotificationConfig] ConversationProfile newRecognitionResultNotificationConfig
                         * @property {google.cloud.dialogflow.v2.ISpeechToTextConfig|null} [sttConfig] ConversationProfile sttConfig
                         * @property {string|null} [languageCode] ConversationProfile languageCode
                         * @property {string|null} [timeZone] ConversationProfile timeZone
                         * @property {string|null} [securitySettings] ConversationProfile securitySettings
                         * @property {google.cloud.dialogflow.v2.ISynthesizeSpeechConfig|null} [ttsConfig] ConversationProfile ttsConfig
                         */
    
                        /**
                         * Constructs a new ConversationProfile.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a ConversationProfile.
                         * @implements IConversationProfile
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IConversationProfile=} [properties] Properties to set
                         */
                        function ConversationProfile(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ConversationProfile name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2.ConversationProfile
                         * @instance
                         */
                        ConversationProfile.prototype.name = "";
    
                        /**
                         * ConversationProfile displayName.
                         * @member {string} displayName
                         * @memberof google.cloud.dialogflow.v2.ConversationProfile
                         * @instance
                         */
                        ConversationProfile.prototype.displayName = "";
    
                        /**
                         * ConversationProfile createTime.
                         * @member {google.protobuf.ITimestamp|null|undefined} createTime
                         * @memberof google.cloud.dialogflow.v2.ConversationProfile
                         * @instance
                         */
                        ConversationProfile.prototype.createTime = null;
    
                        /**
                         * ConversationProfile updateTime.
                         * @member {google.protobuf.ITimestamp|null|undefined} updateTime
                         * @memberof google.cloud.dialogflow.v2.ConversationProfile
                         * @instance
                         */
                        ConversationProfile.prototype.updateTime = null;
    
                        /**
                         * ConversationProfile automatedAgentConfig.
                         * @member {google.cloud.dialogflow.v2.IAutomatedAgentConfig|null|undefined} automatedAgentConfig
                         * @memberof google.cloud.dialogflow.v2.ConversationProfile
                         * @instance
                         */
                        ConversationProfile.prototype.automatedAgentConfig = null;
    
                        /**
                         * ConversationProfile humanAgentAssistantConfig.
                         * @member {google.cloud.dialogflow.v2.IHumanAgentAssistantConfig|null|undefined} humanAgentAssistantConfig
                         * @memberof google.cloud.dialogflow.v2.ConversationProfile
                         * @instance
                         */
                        ConversationProfile.prototype.humanAgentAssistantConfig = null;
    
                        /**
                         * ConversationProfile humanAgentHandoffConfig.
                         * @member {google.cloud.dialogflow.v2.IHumanAgentHandoffConfig|null|undefined} humanAgentHandoffConfig
                         * @memberof google.cloud.dialogflow.v2.ConversationProfile
                         * @instance
                         */
                        ConversationProfile.prototype.humanAgentHandoffConfig = null;
    
                        /**
                         * ConversationProfile notificationConfig.
                         * @member {google.cloud.dialogflow.v2.INotificationConfig|null|undefined} notificationConfig
                         * @memberof google.cloud.dialogflow.v2.ConversationProfile
                         * @instance
                         */
                        ConversationProfile.prototype.notificationConfig = null;
    
                        /**
                         * ConversationProfile loggingConfig.
                         * @member {google.cloud.dialogflow.v2.ILoggingConfig|null|undefined} loggingConfig
                         * @memberof google.cloud.dialogflow.v2.ConversationProfile
                         * @instance
                         */
                        ConversationProfile.prototype.loggingConfig = null;
    
                        /**
                         * ConversationProfile newMessageEventNotificationConfig.
                         * @member {google.cloud.dialogflow.v2.INotificationConfig|null|undefined} newMessageEventNotificationConfig
                         * @memberof google.cloud.dialogflow.v2.ConversationProfile
                         * @instance
                         */
                        ConversationProfile.prototype.newMessageEventNotificationConfig = null;
    
                        /**
                         * ConversationProfile newRecognitionResultNotificationConfig.
                         * @member {google.cloud.dialogflow.v2.INotificationConfig|null|undefined} newRecognitionResultNotificationConfig
                         * @memberof google.cloud.dialogflow.v2.ConversationProfile
                         * @instance
                         */
                        ConversationProfile.prototype.newRecognitionResultNotificationConfig = null;
    
                        /**
                         * ConversationProfile sttConfig.
                         * @member {google.cloud.dialogflow.v2.ISpeechToTextConfig|null|undefined} sttConfig
                         * @memberof google.cloud.dialogflow.v2.ConversationProfile
                         * @instance
                         */
                        ConversationProfile.prototype.sttConfig = null;
    
                        /**
                         * ConversationProfile languageCode.
                         * @member {string} languageCode
                         * @memberof google.cloud.dialogflow.v2.ConversationProfile
                         * @instance
                         */
                        ConversationProfile.prototype.languageCode = "";
    
                        /**
                         * ConversationProfile timeZone.
                         * @member {string} timeZone
                         * @memberof google.cloud.dialogflow.v2.ConversationProfile
                         * @instance
                         */
                        ConversationProfile.prototype.timeZone = "";
    
                        /**
                         * ConversationProfile securitySettings.
                         * @member {string} securitySettings
                         * @memberof google.cloud.dialogflow.v2.ConversationProfile
                         * @instance
                         */
                        ConversationProfile.prototype.securitySettings = "";
    
                        /**
                         * ConversationProfile ttsConfig.
                         * @member {google.cloud.dialogflow.v2.ISynthesizeSpeechConfig|null|undefined} ttsConfig
                         * @memberof google.cloud.dialogflow.v2.ConversationProfile
                         * @instance
                         */
                        ConversationProfile.prototype.ttsConfig = null;
    
                        /**
                         * Creates a new ConversationProfile instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ConversationProfile
                         * @static
                         * @param {google.cloud.dialogflow.v2.IConversationProfile=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ConversationProfile} ConversationProfile instance
                         */
                        ConversationProfile.create = function create(properties) {
                            return new ConversationProfile(properties);
                        };
    
                        /**
                         * Encodes the specified ConversationProfile message. Does not implicitly {@link google.cloud.dialogflow.v2.ConversationProfile.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ConversationProfile
                         * @static
                         * @param {google.cloud.dialogflow.v2.IConversationProfile} message ConversationProfile message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ConversationProfile.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            if (message.displayName != null && Object.hasOwnProperty.call(message, "displayName"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.displayName);
                            if (message.automatedAgentConfig != null && Object.hasOwnProperty.call(message, "automatedAgentConfig"))
                                $root.google.cloud.dialogflow.v2.AutomatedAgentConfig.encode(message.automatedAgentConfig, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            if (message.humanAgentAssistantConfig != null && Object.hasOwnProperty.call(message, "humanAgentAssistantConfig"))
                                $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.encode(message.humanAgentAssistantConfig, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            if (message.humanAgentHandoffConfig != null && Object.hasOwnProperty.call(message, "humanAgentHandoffConfig"))
                                $root.google.cloud.dialogflow.v2.HumanAgentHandoffConfig.encode(message.humanAgentHandoffConfig, writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                            if (message.notificationConfig != null && Object.hasOwnProperty.call(message, "notificationConfig"))
                                $root.google.cloud.dialogflow.v2.NotificationConfig.encode(message.notificationConfig, writer.uint32(/* id 6, wireType 2 =*/50).fork()).ldelim();
                            if (message.loggingConfig != null && Object.hasOwnProperty.call(message, "loggingConfig"))
                                $root.google.cloud.dialogflow.v2.LoggingConfig.encode(message.loggingConfig, writer.uint32(/* id 7, wireType 2 =*/58).fork()).ldelim();
                            if (message.newMessageEventNotificationConfig != null && Object.hasOwnProperty.call(message, "newMessageEventNotificationConfig"))
                                $root.google.cloud.dialogflow.v2.NotificationConfig.encode(message.newMessageEventNotificationConfig, writer.uint32(/* id 8, wireType 2 =*/66).fork()).ldelim();
                            if (message.sttConfig != null && Object.hasOwnProperty.call(message, "sttConfig"))
                                $root.google.cloud.dialogflow.v2.SpeechToTextConfig.encode(message.sttConfig, writer.uint32(/* id 9, wireType 2 =*/74).fork()).ldelim();
                            if (message.languageCode != null && Object.hasOwnProperty.call(message, "languageCode"))
                                writer.uint32(/* id 10, wireType 2 =*/82).string(message.languageCode);
                            if (message.createTime != null && Object.hasOwnProperty.call(message, "createTime"))
                                $root.google.protobuf.Timestamp.encode(message.createTime, writer.uint32(/* id 11, wireType 2 =*/90).fork()).ldelim();
                            if (message.updateTime != null && Object.hasOwnProperty.call(message, "updateTime"))
                                $root.google.protobuf.Timestamp.encode(message.updateTime, writer.uint32(/* id 12, wireType 2 =*/98).fork()).ldelim();
                            if (message.securitySettings != null && Object.hasOwnProperty.call(message, "securitySettings"))
                                writer.uint32(/* id 13, wireType 2 =*/106).string(message.securitySettings);
                            if (message.timeZone != null && Object.hasOwnProperty.call(message, "timeZone"))
                                writer.uint32(/* id 14, wireType 2 =*/114).string(message.timeZone);
                            if (message.ttsConfig != null && Object.hasOwnProperty.call(message, "ttsConfig"))
                                $root.google.cloud.dialogflow.v2.SynthesizeSpeechConfig.encode(message.ttsConfig, writer.uint32(/* id 18, wireType 2 =*/146).fork()).ldelim();
                            if (message.newRecognitionResultNotificationConfig != null && Object.hasOwnProperty.call(message, "newRecognitionResultNotificationConfig"))
                                $root.google.cloud.dialogflow.v2.NotificationConfig.encode(message.newRecognitionResultNotificationConfig, writer.uint32(/* id 21, wireType 2 =*/170).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ConversationProfile message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ConversationProfile.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ConversationProfile
                         * @static
                         * @param {google.cloud.dialogflow.v2.IConversationProfile} message ConversationProfile message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ConversationProfile.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ConversationProfile message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ConversationProfile
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ConversationProfile} ConversationProfile
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ConversationProfile.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ConversationProfile();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.displayName = reader.string();
                                        break;
                                    }
                                case 11: {
                                        message.createTime = $root.google.protobuf.Timestamp.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 12: {
                                        message.updateTime = $root.google.protobuf.Timestamp.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 3: {
                                        message.automatedAgentConfig = $root.google.cloud.dialogflow.v2.AutomatedAgentConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 4: {
                                        message.humanAgentAssistantConfig = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 5: {
                                        message.humanAgentHandoffConfig = $root.google.cloud.dialogflow.v2.HumanAgentHandoffConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 6: {
                                        message.notificationConfig = $root.google.cloud.dialogflow.v2.NotificationConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 7: {
                                        message.loggingConfig = $root.google.cloud.dialogflow.v2.LoggingConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 8: {
                                        message.newMessageEventNotificationConfig = $root.google.cloud.dialogflow.v2.NotificationConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 21: {
                                        message.newRecognitionResultNotificationConfig = $root.google.cloud.dialogflow.v2.NotificationConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 9: {
                                        message.sttConfig = $root.google.cloud.dialogflow.v2.SpeechToTextConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 10: {
                                        message.languageCode = reader.string();
                                        break;
                                    }
                                case 14: {
                                        message.timeZone = reader.string();
                                        break;
                                    }
                                case 13: {
                                        message.securitySettings = reader.string();
                                        break;
                                    }
                                case 18: {
                                        message.ttsConfig = $root.google.cloud.dialogflow.v2.SynthesizeSpeechConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ConversationProfile message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ConversationProfile
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ConversationProfile} ConversationProfile
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ConversationProfile.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ConversationProfile message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ConversationProfile
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ConversationProfile.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            if (message.displayName != null && message.hasOwnProperty("displayName"))
                                if (!$util.isString(message.displayName))
                                    return "displayName: string expected";
                            if (message.createTime != null && message.hasOwnProperty("createTime")) {
                                var error = $root.google.protobuf.Timestamp.verify(message.createTime);
                                if (error)
                                    return "createTime." + error;
                            }
                            if (message.updateTime != null && message.hasOwnProperty("updateTime")) {
                                var error = $root.google.protobuf.Timestamp.verify(message.updateTime);
                                if (error)
                                    return "updateTime." + error;
                            }
                            if (message.automatedAgentConfig != null && message.hasOwnProperty("automatedAgentConfig")) {
                                var error = $root.google.cloud.dialogflow.v2.AutomatedAgentConfig.verify(message.automatedAgentConfig);
                                if (error)
                                    return "automatedAgentConfig." + error;
                            }
                            if (message.humanAgentAssistantConfig != null && message.hasOwnProperty("humanAgentAssistantConfig")) {
                                var error = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.verify(message.humanAgentAssistantConfig);
                                if (error)
                                    return "humanAgentAssistantConfig." + error;
                            }
                            if (message.humanAgentHandoffConfig != null && message.hasOwnProperty("humanAgentHandoffConfig")) {
                                var error = $root.google.cloud.dialogflow.v2.HumanAgentHandoffConfig.verify(message.humanAgentHandoffConfig);
                                if (error)
                                    return "humanAgentHandoffConfig." + error;
                            }
                            if (message.notificationConfig != null && message.hasOwnProperty("notificationConfig")) {
                                var error = $root.google.cloud.dialogflow.v2.NotificationConfig.verify(message.notificationConfig);
                                if (error)
                                    return "notificationConfig." + error;
                            }
                            if (message.loggingConfig != null && message.hasOwnProperty("loggingConfig")) {
                                var error = $root.google.cloud.dialogflow.v2.LoggingConfig.verify(message.loggingConfig);
                                if (error)
                                    return "loggingConfig." + error;
                            }
                            if (message.newMessageEventNotificationConfig != null && message.hasOwnProperty("newMessageEventNotificationConfig")) {
                                var error = $root.google.cloud.dialogflow.v2.NotificationConfig.verify(message.newMessageEventNotificationConfig);
                                if (error)
                                    return "newMessageEventNotificationConfig." + error;
                            }
                            if (message.newRecognitionResultNotificationConfig != null && message.hasOwnProperty("newRecognitionResultNotificationConfig")) {
                                var error = $root.google.cloud.dialogflow.v2.NotificationConfig.verify(message.newRecognitionResultNotificationConfig);
                                if (error)
                                    return "newRecognitionResultNotificationConfig." + error;
                            }
                            if (message.sttConfig != null && message.hasOwnProperty("sttConfig")) {
                                var error = $root.google.cloud.dialogflow.v2.SpeechToTextConfig.verify(message.sttConfig);
                                if (error)
                                    return "sttConfig." + error;
                            }
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                if (!$util.isString(message.languageCode))
                                    return "languageCode: string expected";
                            if (message.timeZone != null && message.hasOwnProperty("timeZone"))
                                if (!$util.isString(message.timeZone))
                                    return "timeZone: string expected";
                            if (message.securitySettings != null && message.hasOwnProperty("securitySettings"))
                                if (!$util.isString(message.securitySettings))
                                    return "securitySettings: string expected";
                            if (message.ttsConfig != null && message.hasOwnProperty("ttsConfig")) {
                                var error = $root.google.cloud.dialogflow.v2.SynthesizeSpeechConfig.verify(message.ttsConfig);
                                if (error)
                                    return "ttsConfig." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a ConversationProfile message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ConversationProfile
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ConversationProfile} ConversationProfile
                         */
                        ConversationProfile.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ConversationProfile)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ConversationProfile();
                            if (object.name != null)
                                message.name = String(object.name);
                            if (object.displayName != null)
                                message.displayName = String(object.displayName);
                            if (object.createTime != null) {
                                if (typeof object.createTime !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.ConversationProfile.createTime: object expected");
                                message.createTime = $root.google.protobuf.Timestamp.fromObject(object.createTime);
                            }
                            if (object.updateTime != null) {
                                if (typeof object.updateTime !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.ConversationProfile.updateTime: object expected");
                                message.updateTime = $root.google.protobuf.Timestamp.fromObject(object.updateTime);
                            }
                            if (object.automatedAgentConfig != null) {
                                if (typeof object.automatedAgentConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.ConversationProfile.automatedAgentConfig: object expected");
                                message.automatedAgentConfig = $root.google.cloud.dialogflow.v2.AutomatedAgentConfig.fromObject(object.automatedAgentConfig);
                            }
                            if (object.humanAgentAssistantConfig != null) {
                                if (typeof object.humanAgentAssistantConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.ConversationProfile.humanAgentAssistantConfig: object expected");
                                message.humanAgentAssistantConfig = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.fromObject(object.humanAgentAssistantConfig);
                            }
                            if (object.humanAgentHandoffConfig != null) {
                                if (typeof object.humanAgentHandoffConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.ConversationProfile.humanAgentHandoffConfig: object expected");
                                message.humanAgentHandoffConfig = $root.google.cloud.dialogflow.v2.HumanAgentHandoffConfig.fromObject(object.humanAgentHandoffConfig);
                            }
                            if (object.notificationConfig != null) {
                                if (typeof object.notificationConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.ConversationProfile.notificationConfig: object expected");
                                message.notificationConfig = $root.google.cloud.dialogflow.v2.NotificationConfig.fromObject(object.notificationConfig);
                            }
                            if (object.loggingConfig != null) {
                                if (typeof object.loggingConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.ConversationProfile.loggingConfig: object expected");
                                message.loggingConfig = $root.google.cloud.dialogflow.v2.LoggingConfig.fromObject(object.loggingConfig);
                            }
                            if (object.newMessageEventNotificationConfig != null) {
                                if (typeof object.newMessageEventNotificationConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.ConversationProfile.newMessageEventNotificationConfig: object expected");
                                message.newMessageEventNotificationConfig = $root.google.cloud.dialogflow.v2.NotificationConfig.fromObject(object.newMessageEventNotificationConfig);
                            }
                            if (object.newRecognitionResultNotificationConfig != null) {
                                if (typeof object.newRecognitionResultNotificationConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.ConversationProfile.newRecognitionResultNotificationConfig: object expected");
                                message.newRecognitionResultNotificationConfig = $root.google.cloud.dialogflow.v2.NotificationConfig.fromObject(object.newRecognitionResultNotificationConfig);
                            }
                            if (object.sttConfig != null) {
                                if (typeof object.sttConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.ConversationProfile.sttConfig: object expected");
                                message.sttConfig = $root.google.cloud.dialogflow.v2.SpeechToTextConfig.fromObject(object.sttConfig);
                            }
                            if (object.languageCode != null)
                                message.languageCode = String(object.languageCode);
                            if (object.timeZone != null)
                                message.timeZone = String(object.timeZone);
                            if (object.securitySettings != null)
                                message.securitySettings = String(object.securitySettings);
                            if (object.ttsConfig != null) {
                                if (typeof object.ttsConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.ConversationProfile.ttsConfig: object expected");
                                message.ttsConfig = $root.google.cloud.dialogflow.v2.SynthesizeSpeechConfig.fromObject(object.ttsConfig);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ConversationProfile message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ConversationProfile
                         * @static
                         * @param {google.cloud.dialogflow.v2.ConversationProfile} message ConversationProfile
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ConversationProfile.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.name = "";
                                object.displayName = "";
                                object.automatedAgentConfig = null;
                                object.humanAgentAssistantConfig = null;
                                object.humanAgentHandoffConfig = null;
                                object.notificationConfig = null;
                                object.loggingConfig = null;
                                object.newMessageEventNotificationConfig = null;
                                object.sttConfig = null;
                                object.languageCode = "";
                                object.createTime = null;
                                object.updateTime = null;
                                object.securitySettings = "";
                                object.timeZone = "";
                                object.ttsConfig = null;
                                object.newRecognitionResultNotificationConfig = null;
                            }
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            if (message.displayName != null && message.hasOwnProperty("displayName"))
                                object.displayName = message.displayName;
                            if (message.automatedAgentConfig != null && message.hasOwnProperty("automatedAgentConfig"))
                                object.automatedAgentConfig = $root.google.cloud.dialogflow.v2.AutomatedAgentConfig.toObject(message.automatedAgentConfig, options);
                            if (message.humanAgentAssistantConfig != null && message.hasOwnProperty("humanAgentAssistantConfig"))
                                object.humanAgentAssistantConfig = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.toObject(message.humanAgentAssistantConfig, options);
                            if (message.humanAgentHandoffConfig != null && message.hasOwnProperty("humanAgentHandoffConfig"))
                                object.humanAgentHandoffConfig = $root.google.cloud.dialogflow.v2.HumanAgentHandoffConfig.toObject(message.humanAgentHandoffConfig, options);
                            if (message.notificationConfig != null && message.hasOwnProperty("notificationConfig"))
                                object.notificationConfig = $root.google.cloud.dialogflow.v2.NotificationConfig.toObject(message.notificationConfig, options);
                            if (message.loggingConfig != null && message.hasOwnProperty("loggingConfig"))
                                object.loggingConfig = $root.google.cloud.dialogflow.v2.LoggingConfig.toObject(message.loggingConfig, options);
                            if (message.newMessageEventNotificationConfig != null && message.hasOwnProperty("newMessageEventNotificationConfig"))
                                object.newMessageEventNotificationConfig = $root.google.cloud.dialogflow.v2.NotificationConfig.toObject(message.newMessageEventNotificationConfig, options);
                            if (message.sttConfig != null && message.hasOwnProperty("sttConfig"))
                                object.sttConfig = $root.google.cloud.dialogflow.v2.SpeechToTextConfig.toObject(message.sttConfig, options);
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                object.languageCode = message.languageCode;
                            if (message.createTime != null && message.hasOwnProperty("createTime"))
                                object.createTime = $root.google.protobuf.Timestamp.toObject(message.createTime, options);
                            if (message.updateTime != null && message.hasOwnProperty("updateTime"))
                                object.updateTime = $root.google.protobuf.Timestamp.toObject(message.updateTime, options);
                            if (message.securitySettings != null && message.hasOwnProperty("securitySettings"))
                                object.securitySettings = message.securitySettings;
                            if (message.timeZone != null && message.hasOwnProperty("timeZone"))
                                object.timeZone = message.timeZone;
                            if (message.ttsConfig != null && message.hasOwnProperty("ttsConfig"))
                                object.ttsConfig = $root.google.cloud.dialogflow.v2.SynthesizeSpeechConfig.toObject(message.ttsConfig, options);
                            if (message.newRecognitionResultNotificationConfig != null && message.hasOwnProperty("newRecognitionResultNotificationConfig"))
                                object.newRecognitionResultNotificationConfig = $root.google.cloud.dialogflow.v2.NotificationConfig.toObject(message.newRecognitionResultNotificationConfig, options);
                            return object;
                        };
    
                        /**
                         * Converts this ConversationProfile to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ConversationProfile
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ConversationProfile.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ConversationProfile
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ConversationProfile
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ConversationProfile.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ConversationProfile";
                        };
    
                        return ConversationProfile;
                    })();
    
                    v2.ListConversationProfilesRequest = (function() {
    
                        /**
                         * Properties of a ListConversationProfilesRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IListConversationProfilesRequest
                         * @property {string|null} [parent] ListConversationProfilesRequest parent
                         * @property {number|null} [pageSize] ListConversationProfilesRequest pageSize
                         * @property {string|null} [pageToken] ListConversationProfilesRequest pageToken
                         */
    
                        /**
                         * Constructs a new ListConversationProfilesRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a ListConversationProfilesRequest.
                         * @implements IListConversationProfilesRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IListConversationProfilesRequest=} [properties] Properties to set
                         */
                        function ListConversationProfilesRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListConversationProfilesRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.ListConversationProfilesRequest
                         * @instance
                         */
                        ListConversationProfilesRequest.prototype.parent = "";
    
                        /**
                         * ListConversationProfilesRequest pageSize.
                         * @member {number} pageSize
                         * @memberof google.cloud.dialogflow.v2.ListConversationProfilesRequest
                         * @instance
                         */
                        ListConversationProfilesRequest.prototype.pageSize = 0;
    
                        /**
                         * ListConversationProfilesRequest pageToken.
                         * @member {string} pageToken
                         * @memberof google.cloud.dialogflow.v2.ListConversationProfilesRequest
                         * @instance
                         */
                        ListConversationProfilesRequest.prototype.pageToken = "";
    
                        /**
                         * Creates a new ListConversationProfilesRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ListConversationProfilesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListConversationProfilesRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ListConversationProfilesRequest} ListConversationProfilesRequest instance
                         */
                        ListConversationProfilesRequest.create = function create(properties) {
                            return new ListConversationProfilesRequest(properties);
                        };
    
                        /**
                         * Encodes the specified ListConversationProfilesRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.ListConversationProfilesRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ListConversationProfilesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListConversationProfilesRequest} message ListConversationProfilesRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListConversationProfilesRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.pageSize != null && Object.hasOwnProperty.call(message, "pageSize"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.pageSize);
                            if (message.pageToken != null && Object.hasOwnProperty.call(message, "pageToken"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.pageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListConversationProfilesRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ListConversationProfilesRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListConversationProfilesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListConversationProfilesRequest} message ListConversationProfilesRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListConversationProfilesRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListConversationProfilesRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ListConversationProfilesRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ListConversationProfilesRequest} ListConversationProfilesRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListConversationProfilesRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ListConversationProfilesRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.pageSize = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.pageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListConversationProfilesRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListConversationProfilesRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ListConversationProfilesRequest} ListConversationProfilesRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListConversationProfilesRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListConversationProfilesRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ListConversationProfilesRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListConversationProfilesRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                if (!$util.isInteger(message.pageSize))
                                    return "pageSize: integer expected";
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                if (!$util.isString(message.pageToken))
                                    return "pageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListConversationProfilesRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ListConversationProfilesRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ListConversationProfilesRequest} ListConversationProfilesRequest
                         */
                        ListConversationProfilesRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ListConversationProfilesRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ListConversationProfilesRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.pageSize != null)
                                message.pageSize = object.pageSize | 0;
                            if (object.pageToken != null)
                                message.pageToken = String(object.pageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListConversationProfilesRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ListConversationProfilesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ListConversationProfilesRequest} message ListConversationProfilesRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListConversationProfilesRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.pageSize = 0;
                                object.pageToken = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                object.pageSize = message.pageSize;
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                object.pageToken = message.pageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListConversationProfilesRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ListConversationProfilesRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListConversationProfilesRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListConversationProfilesRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ListConversationProfilesRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListConversationProfilesRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ListConversationProfilesRequest";
                        };
    
                        return ListConversationProfilesRequest;
                    })();
    
                    v2.ListConversationProfilesResponse = (function() {
    
                        /**
                         * Properties of a ListConversationProfilesResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IListConversationProfilesResponse
                         * @property {Array.<google.cloud.dialogflow.v2.IConversationProfile>|null} [conversationProfiles] ListConversationProfilesResponse conversationProfiles
                         * @property {string|null} [nextPageToken] ListConversationProfilesResponse nextPageToken
                         */
    
                        /**
                         * Constructs a new ListConversationProfilesResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a ListConversationProfilesResponse.
                         * @implements IListConversationProfilesResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IListConversationProfilesResponse=} [properties] Properties to set
                         */
                        function ListConversationProfilesResponse(properties) {
                            this.conversationProfiles = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListConversationProfilesResponse conversationProfiles.
                         * @member {Array.<google.cloud.dialogflow.v2.IConversationProfile>} conversationProfiles
                         * @memberof google.cloud.dialogflow.v2.ListConversationProfilesResponse
                         * @instance
                         */
                        ListConversationProfilesResponse.prototype.conversationProfiles = $util.emptyArray;
    
                        /**
                         * ListConversationProfilesResponse nextPageToken.
                         * @member {string} nextPageToken
                         * @memberof google.cloud.dialogflow.v2.ListConversationProfilesResponse
                         * @instance
                         */
                        ListConversationProfilesResponse.prototype.nextPageToken = "";
    
                        /**
                         * Creates a new ListConversationProfilesResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ListConversationProfilesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListConversationProfilesResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ListConversationProfilesResponse} ListConversationProfilesResponse instance
                         */
                        ListConversationProfilesResponse.create = function create(properties) {
                            return new ListConversationProfilesResponse(properties);
                        };
    
                        /**
                         * Encodes the specified ListConversationProfilesResponse message. Does not implicitly {@link google.cloud.dialogflow.v2.ListConversationProfilesResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ListConversationProfilesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListConversationProfilesResponse} message ListConversationProfilesResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListConversationProfilesResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.conversationProfiles != null && message.conversationProfiles.length)
                                for (var i = 0; i < message.conversationProfiles.length; ++i)
                                    $root.google.cloud.dialogflow.v2.ConversationProfile.encode(message.conversationProfiles[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.nextPageToken != null && Object.hasOwnProperty.call(message, "nextPageToken"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.nextPageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListConversationProfilesResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ListConversationProfilesResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListConversationProfilesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListConversationProfilesResponse} message ListConversationProfilesResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListConversationProfilesResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListConversationProfilesResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ListConversationProfilesResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ListConversationProfilesResponse} ListConversationProfilesResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListConversationProfilesResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ListConversationProfilesResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.conversationProfiles && message.conversationProfiles.length))
                                            message.conversationProfiles = [];
                                        message.conversationProfiles.push($root.google.cloud.dialogflow.v2.ConversationProfile.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 2: {
                                        message.nextPageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListConversationProfilesResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListConversationProfilesResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ListConversationProfilesResponse} ListConversationProfilesResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListConversationProfilesResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListConversationProfilesResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ListConversationProfilesResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListConversationProfilesResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.conversationProfiles != null && message.hasOwnProperty("conversationProfiles")) {
                                if (!Array.isArray(message.conversationProfiles))
                                    return "conversationProfiles: array expected";
                                for (var i = 0; i < message.conversationProfiles.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.ConversationProfile.verify(message.conversationProfiles[i]);
                                    if (error)
                                        return "conversationProfiles." + error;
                                }
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                if (!$util.isString(message.nextPageToken))
                                    return "nextPageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListConversationProfilesResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ListConversationProfilesResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ListConversationProfilesResponse} ListConversationProfilesResponse
                         */
                        ListConversationProfilesResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ListConversationProfilesResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ListConversationProfilesResponse();
                            if (object.conversationProfiles) {
                                if (!Array.isArray(object.conversationProfiles))
                                    throw TypeError(".google.cloud.dialogflow.v2.ListConversationProfilesResponse.conversationProfiles: array expected");
                                message.conversationProfiles = [];
                                for (var i = 0; i < object.conversationProfiles.length; ++i) {
                                    if (typeof object.conversationProfiles[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.ListConversationProfilesResponse.conversationProfiles: object expected");
                                    message.conversationProfiles[i] = $root.google.cloud.dialogflow.v2.ConversationProfile.fromObject(object.conversationProfiles[i]);
                                }
                            }
                            if (object.nextPageToken != null)
                                message.nextPageToken = String(object.nextPageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListConversationProfilesResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ListConversationProfilesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.ListConversationProfilesResponse} message ListConversationProfilesResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListConversationProfilesResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.conversationProfiles = [];
                            if (options.defaults)
                                object.nextPageToken = "";
                            if (message.conversationProfiles && message.conversationProfiles.length) {
                                object.conversationProfiles = [];
                                for (var j = 0; j < message.conversationProfiles.length; ++j)
                                    object.conversationProfiles[j] = $root.google.cloud.dialogflow.v2.ConversationProfile.toObject(message.conversationProfiles[j], options);
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                object.nextPageToken = message.nextPageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListConversationProfilesResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ListConversationProfilesResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListConversationProfilesResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListConversationProfilesResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ListConversationProfilesResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListConversationProfilesResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ListConversationProfilesResponse";
                        };
    
                        return ListConversationProfilesResponse;
                    })();
    
                    v2.GetConversationProfileRequest = (function() {
    
                        /**
                         * Properties of a GetConversationProfileRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IGetConversationProfileRequest
                         * @property {string|null} [name] GetConversationProfileRequest name
                         */
    
                        /**
                         * Constructs a new GetConversationProfileRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a GetConversationProfileRequest.
                         * @implements IGetConversationProfileRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IGetConversationProfileRequest=} [properties] Properties to set
                         */
                        function GetConversationProfileRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GetConversationProfileRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2.GetConversationProfileRequest
                         * @instance
                         */
                        GetConversationProfileRequest.prototype.name = "";
    
                        /**
                         * Creates a new GetConversationProfileRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.GetConversationProfileRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetConversationProfileRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.GetConversationProfileRequest} GetConversationProfileRequest instance
                         */
                        GetConversationProfileRequest.create = function create(properties) {
                            return new GetConversationProfileRequest(properties);
                        };
    
                        /**
                         * Encodes the specified GetConversationProfileRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.GetConversationProfileRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.GetConversationProfileRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetConversationProfileRequest} message GetConversationProfileRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetConversationProfileRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GetConversationProfileRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.GetConversationProfileRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GetConversationProfileRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetConversationProfileRequest} message GetConversationProfileRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetConversationProfileRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GetConversationProfileRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.GetConversationProfileRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.GetConversationProfileRequest} GetConversationProfileRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetConversationProfileRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.GetConversationProfileRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GetConversationProfileRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GetConversationProfileRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.GetConversationProfileRequest} GetConversationProfileRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetConversationProfileRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GetConversationProfileRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.GetConversationProfileRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GetConversationProfileRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a GetConversationProfileRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.GetConversationProfileRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.GetConversationProfileRequest} GetConversationProfileRequest
                         */
                        GetConversationProfileRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.GetConversationProfileRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.GetConversationProfileRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GetConversationProfileRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.GetConversationProfileRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.GetConversationProfileRequest} message GetConversationProfileRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GetConversationProfileRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.name = "";
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            return object;
                        };
    
                        /**
                         * Converts this GetConversationProfileRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.GetConversationProfileRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GetConversationProfileRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GetConversationProfileRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.GetConversationProfileRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GetConversationProfileRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.GetConversationProfileRequest";
                        };
    
                        return GetConversationProfileRequest;
                    })();
    
                    v2.CreateConversationProfileRequest = (function() {
    
                        /**
                         * Properties of a CreateConversationProfileRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ICreateConversationProfileRequest
                         * @property {string|null} [parent] CreateConversationProfileRequest parent
                         * @property {google.cloud.dialogflow.v2.IConversationProfile|null} [conversationProfile] CreateConversationProfileRequest conversationProfile
                         */
    
                        /**
                         * Constructs a new CreateConversationProfileRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a CreateConversationProfileRequest.
                         * @implements ICreateConversationProfileRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ICreateConversationProfileRequest=} [properties] Properties to set
                         */
                        function CreateConversationProfileRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * CreateConversationProfileRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.CreateConversationProfileRequest
                         * @instance
                         */
                        CreateConversationProfileRequest.prototype.parent = "";
    
                        /**
                         * CreateConversationProfileRequest conversationProfile.
                         * @member {google.cloud.dialogflow.v2.IConversationProfile|null|undefined} conversationProfile
                         * @memberof google.cloud.dialogflow.v2.CreateConversationProfileRequest
                         * @instance
                         */
                        CreateConversationProfileRequest.prototype.conversationProfile = null;
    
                        /**
                         * Creates a new CreateConversationProfileRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.CreateConversationProfileRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICreateConversationProfileRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.CreateConversationProfileRequest} CreateConversationProfileRequest instance
                         */
                        CreateConversationProfileRequest.create = function create(properties) {
                            return new CreateConversationProfileRequest(properties);
                        };
    
                        /**
                         * Encodes the specified CreateConversationProfileRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.CreateConversationProfileRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.CreateConversationProfileRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICreateConversationProfileRequest} message CreateConversationProfileRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateConversationProfileRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.conversationProfile != null && Object.hasOwnProperty.call(message, "conversationProfile"))
                                $root.google.cloud.dialogflow.v2.ConversationProfile.encode(message.conversationProfile, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified CreateConversationProfileRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.CreateConversationProfileRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.CreateConversationProfileRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICreateConversationProfileRequest} message CreateConversationProfileRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateConversationProfileRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a CreateConversationProfileRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.CreateConversationProfileRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.CreateConversationProfileRequest} CreateConversationProfileRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateConversationProfileRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.CreateConversationProfileRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.conversationProfile = $root.google.cloud.dialogflow.v2.ConversationProfile.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a CreateConversationProfileRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.CreateConversationProfileRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.CreateConversationProfileRequest} CreateConversationProfileRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateConversationProfileRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a CreateConversationProfileRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.CreateConversationProfileRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        CreateConversationProfileRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.conversationProfile != null && message.hasOwnProperty("conversationProfile")) {
                                var error = $root.google.cloud.dialogflow.v2.ConversationProfile.verify(message.conversationProfile);
                                if (error)
                                    return "conversationProfile." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a CreateConversationProfileRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.CreateConversationProfileRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.CreateConversationProfileRequest} CreateConversationProfileRequest
                         */
                        CreateConversationProfileRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.CreateConversationProfileRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.CreateConversationProfileRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.conversationProfile != null) {
                                if (typeof object.conversationProfile !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.CreateConversationProfileRequest.conversationProfile: object expected");
                                message.conversationProfile = $root.google.cloud.dialogflow.v2.ConversationProfile.fromObject(object.conversationProfile);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a CreateConversationProfileRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.CreateConversationProfileRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.CreateConversationProfileRequest} message CreateConversationProfileRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        CreateConversationProfileRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.conversationProfile = null;
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.conversationProfile != null && message.hasOwnProperty("conversationProfile"))
                                object.conversationProfile = $root.google.cloud.dialogflow.v2.ConversationProfile.toObject(message.conversationProfile, options);
                            return object;
                        };
    
                        /**
                         * Converts this CreateConversationProfileRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.CreateConversationProfileRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        CreateConversationProfileRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for CreateConversationProfileRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.CreateConversationProfileRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        CreateConversationProfileRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.CreateConversationProfileRequest";
                        };
    
                        return CreateConversationProfileRequest;
                    })();
    
                    v2.UpdateConversationProfileRequest = (function() {
    
                        /**
                         * Properties of an UpdateConversationProfileRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IUpdateConversationProfileRequest
                         * @property {google.cloud.dialogflow.v2.IConversationProfile|null} [conversationProfile] UpdateConversationProfileRequest conversationProfile
                         * @property {google.protobuf.IFieldMask|null} [updateMask] UpdateConversationProfileRequest updateMask
                         */
    
                        /**
                         * Constructs a new UpdateConversationProfileRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an UpdateConversationProfileRequest.
                         * @implements IUpdateConversationProfileRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IUpdateConversationProfileRequest=} [properties] Properties to set
                         */
                        function UpdateConversationProfileRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * UpdateConversationProfileRequest conversationProfile.
                         * @member {google.cloud.dialogflow.v2.IConversationProfile|null|undefined} conversationProfile
                         * @memberof google.cloud.dialogflow.v2.UpdateConversationProfileRequest
                         * @instance
                         */
                        UpdateConversationProfileRequest.prototype.conversationProfile = null;
    
                        /**
                         * UpdateConversationProfileRequest updateMask.
                         * @member {google.protobuf.IFieldMask|null|undefined} updateMask
                         * @memberof google.cloud.dialogflow.v2.UpdateConversationProfileRequest
                         * @instance
                         */
                        UpdateConversationProfileRequest.prototype.updateMask = null;
    
                        /**
                         * Creates a new UpdateConversationProfileRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.UpdateConversationProfileRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IUpdateConversationProfileRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.UpdateConversationProfileRequest} UpdateConversationProfileRequest instance
                         */
                        UpdateConversationProfileRequest.create = function create(properties) {
                            return new UpdateConversationProfileRequest(properties);
                        };
    
                        /**
                         * Encodes the specified UpdateConversationProfileRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.UpdateConversationProfileRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.UpdateConversationProfileRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IUpdateConversationProfileRequest} message UpdateConversationProfileRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UpdateConversationProfileRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.conversationProfile != null && Object.hasOwnProperty.call(message, "conversationProfile"))
                                $root.google.cloud.dialogflow.v2.ConversationProfile.encode(message.conversationProfile, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.updateMask != null && Object.hasOwnProperty.call(message, "updateMask"))
                                $root.google.protobuf.FieldMask.encode(message.updateMask, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified UpdateConversationProfileRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.UpdateConversationProfileRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.UpdateConversationProfileRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IUpdateConversationProfileRequest} message UpdateConversationProfileRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UpdateConversationProfileRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an UpdateConversationProfileRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.UpdateConversationProfileRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.UpdateConversationProfileRequest} UpdateConversationProfileRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UpdateConversationProfileRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.UpdateConversationProfileRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.conversationProfile = $root.google.cloud.dialogflow.v2.ConversationProfile.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.updateMask = $root.google.protobuf.FieldMask.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an UpdateConversationProfileRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.UpdateConversationProfileRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.UpdateConversationProfileRequest} UpdateConversationProfileRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UpdateConversationProfileRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an UpdateConversationProfileRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.UpdateConversationProfileRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        UpdateConversationProfileRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.conversationProfile != null && message.hasOwnProperty("conversationProfile")) {
                                var error = $root.google.cloud.dialogflow.v2.ConversationProfile.verify(message.conversationProfile);
                                if (error)
                                    return "conversationProfile." + error;
                            }
                            if (message.updateMask != null && message.hasOwnProperty("updateMask")) {
                                var error = $root.google.protobuf.FieldMask.verify(message.updateMask);
                                if (error)
                                    return "updateMask." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates an UpdateConversationProfileRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.UpdateConversationProfileRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.UpdateConversationProfileRequest} UpdateConversationProfileRequest
                         */
                        UpdateConversationProfileRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.UpdateConversationProfileRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.UpdateConversationProfileRequest();
                            if (object.conversationProfile != null) {
                                if (typeof object.conversationProfile !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.UpdateConversationProfileRequest.conversationProfile: object expected");
                                message.conversationProfile = $root.google.cloud.dialogflow.v2.ConversationProfile.fromObject(object.conversationProfile);
                            }
                            if (object.updateMask != null) {
                                if (typeof object.updateMask !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.UpdateConversationProfileRequest.updateMask: object expected");
                                message.updateMask = $root.google.protobuf.FieldMask.fromObject(object.updateMask);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an UpdateConversationProfileRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.UpdateConversationProfileRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.UpdateConversationProfileRequest} message UpdateConversationProfileRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        UpdateConversationProfileRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.conversationProfile = null;
                                object.updateMask = null;
                            }
                            if (message.conversationProfile != null && message.hasOwnProperty("conversationProfile"))
                                object.conversationProfile = $root.google.cloud.dialogflow.v2.ConversationProfile.toObject(message.conversationProfile, options);
                            if (message.updateMask != null && message.hasOwnProperty("updateMask"))
                                object.updateMask = $root.google.protobuf.FieldMask.toObject(message.updateMask, options);
                            return object;
                        };
    
                        /**
                         * Converts this UpdateConversationProfileRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.UpdateConversationProfileRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        UpdateConversationProfileRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for UpdateConversationProfileRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.UpdateConversationProfileRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        UpdateConversationProfileRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.UpdateConversationProfileRequest";
                        };
    
                        return UpdateConversationProfileRequest;
                    })();
    
                    v2.DeleteConversationProfileRequest = (function() {
    
                        /**
                         * Properties of a DeleteConversationProfileRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IDeleteConversationProfileRequest
                         * @property {string|null} [name] DeleteConversationProfileRequest name
                         */
    
                        /**
                         * Constructs a new DeleteConversationProfileRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a DeleteConversationProfileRequest.
                         * @implements IDeleteConversationProfileRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IDeleteConversationProfileRequest=} [properties] Properties to set
                         */
                        function DeleteConversationProfileRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * DeleteConversationProfileRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2.DeleteConversationProfileRequest
                         * @instance
                         */
                        DeleteConversationProfileRequest.prototype.name = "";
    
                        /**
                         * Creates a new DeleteConversationProfileRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.DeleteConversationProfileRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDeleteConversationProfileRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.DeleteConversationProfileRequest} DeleteConversationProfileRequest instance
                         */
                        DeleteConversationProfileRequest.create = function create(properties) {
                            return new DeleteConversationProfileRequest(properties);
                        };
    
                        /**
                         * Encodes the specified DeleteConversationProfileRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.DeleteConversationProfileRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.DeleteConversationProfileRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDeleteConversationProfileRequest} message DeleteConversationProfileRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteConversationProfileRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified DeleteConversationProfileRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.DeleteConversationProfileRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.DeleteConversationProfileRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDeleteConversationProfileRequest} message DeleteConversationProfileRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteConversationProfileRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a DeleteConversationProfileRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.DeleteConversationProfileRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.DeleteConversationProfileRequest} DeleteConversationProfileRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteConversationProfileRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.DeleteConversationProfileRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a DeleteConversationProfileRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.DeleteConversationProfileRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.DeleteConversationProfileRequest} DeleteConversationProfileRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteConversationProfileRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a DeleteConversationProfileRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.DeleteConversationProfileRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        DeleteConversationProfileRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a DeleteConversationProfileRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.DeleteConversationProfileRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.DeleteConversationProfileRequest} DeleteConversationProfileRequest
                         */
                        DeleteConversationProfileRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.DeleteConversationProfileRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.DeleteConversationProfileRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a DeleteConversationProfileRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.DeleteConversationProfileRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.DeleteConversationProfileRequest} message DeleteConversationProfileRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        DeleteConversationProfileRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.name = "";
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            return object;
                        };
    
                        /**
                         * Converts this DeleteConversationProfileRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.DeleteConversationProfileRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        DeleteConversationProfileRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for DeleteConversationProfileRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.DeleteConversationProfileRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        DeleteConversationProfileRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.DeleteConversationProfileRequest";
                        };
    
                        return DeleteConversationProfileRequest;
                    })();
    
                    v2.AutomatedAgentConfig = (function() {
    
                        /**
                         * Properties of an AutomatedAgentConfig.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IAutomatedAgentConfig
                         * @property {string|null} [agent] AutomatedAgentConfig agent
                         * @property {google.protobuf.IDuration|null} [sessionTtl] AutomatedAgentConfig sessionTtl
                         */
    
                        /**
                         * Constructs a new AutomatedAgentConfig.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an AutomatedAgentConfig.
                         * @implements IAutomatedAgentConfig
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IAutomatedAgentConfig=} [properties] Properties to set
                         */
                        function AutomatedAgentConfig(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * AutomatedAgentConfig agent.
                         * @member {string} agent
                         * @memberof google.cloud.dialogflow.v2.AutomatedAgentConfig
                         * @instance
                         */
                        AutomatedAgentConfig.prototype.agent = "";
    
                        /**
                         * AutomatedAgentConfig sessionTtl.
                         * @member {google.protobuf.IDuration|null|undefined} sessionTtl
                         * @memberof google.cloud.dialogflow.v2.AutomatedAgentConfig
                         * @instance
                         */
                        AutomatedAgentConfig.prototype.sessionTtl = null;
    
                        /**
                         * Creates a new AutomatedAgentConfig instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.AutomatedAgentConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2.IAutomatedAgentConfig=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.AutomatedAgentConfig} AutomatedAgentConfig instance
                         */
                        AutomatedAgentConfig.create = function create(properties) {
                            return new AutomatedAgentConfig(properties);
                        };
    
                        /**
                         * Encodes the specified AutomatedAgentConfig message. Does not implicitly {@link google.cloud.dialogflow.v2.AutomatedAgentConfig.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.AutomatedAgentConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2.IAutomatedAgentConfig} message AutomatedAgentConfig message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        AutomatedAgentConfig.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.agent != null && Object.hasOwnProperty.call(message, "agent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.agent);
                            if (message.sessionTtl != null && Object.hasOwnProperty.call(message, "sessionTtl"))
                                $root.google.protobuf.Duration.encode(message.sessionTtl, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified AutomatedAgentConfig message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.AutomatedAgentConfig.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.AutomatedAgentConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2.IAutomatedAgentConfig} message AutomatedAgentConfig message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        AutomatedAgentConfig.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an AutomatedAgentConfig message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.AutomatedAgentConfig
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.AutomatedAgentConfig} AutomatedAgentConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        AutomatedAgentConfig.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.AutomatedAgentConfig();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.agent = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.sessionTtl = $root.google.protobuf.Duration.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an AutomatedAgentConfig message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.AutomatedAgentConfig
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.AutomatedAgentConfig} AutomatedAgentConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        AutomatedAgentConfig.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an AutomatedAgentConfig message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.AutomatedAgentConfig
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        AutomatedAgentConfig.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.agent != null && message.hasOwnProperty("agent"))
                                if (!$util.isString(message.agent))
                                    return "agent: string expected";
                            if (message.sessionTtl != null && message.hasOwnProperty("sessionTtl")) {
                                var error = $root.google.protobuf.Duration.verify(message.sessionTtl);
                                if (error)
                                    return "sessionTtl." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates an AutomatedAgentConfig message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.AutomatedAgentConfig
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.AutomatedAgentConfig} AutomatedAgentConfig
                         */
                        AutomatedAgentConfig.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.AutomatedAgentConfig)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.AutomatedAgentConfig();
                            if (object.agent != null)
                                message.agent = String(object.agent);
                            if (object.sessionTtl != null) {
                                if (typeof object.sessionTtl !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.AutomatedAgentConfig.sessionTtl: object expected");
                                message.sessionTtl = $root.google.protobuf.Duration.fromObject(object.sessionTtl);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an AutomatedAgentConfig message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.AutomatedAgentConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2.AutomatedAgentConfig} message AutomatedAgentConfig
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        AutomatedAgentConfig.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.agent = "";
                                object.sessionTtl = null;
                            }
                            if (message.agent != null && message.hasOwnProperty("agent"))
                                object.agent = message.agent;
                            if (message.sessionTtl != null && message.hasOwnProperty("sessionTtl"))
                                object.sessionTtl = $root.google.protobuf.Duration.toObject(message.sessionTtl, options);
                            return object;
                        };
    
                        /**
                         * Converts this AutomatedAgentConfig to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.AutomatedAgentConfig
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        AutomatedAgentConfig.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for AutomatedAgentConfig
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.AutomatedAgentConfig
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        AutomatedAgentConfig.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.AutomatedAgentConfig";
                        };
    
                        return AutomatedAgentConfig;
                    })();
    
                    v2.HumanAgentAssistantConfig = (function() {
    
                        /**
                         * Properties of a HumanAgentAssistantConfig.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IHumanAgentAssistantConfig
                         * @property {google.cloud.dialogflow.v2.INotificationConfig|null} [notificationConfig] HumanAgentAssistantConfig notificationConfig
                         * @property {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ISuggestionConfig|null} [humanAgentSuggestionConfig] HumanAgentAssistantConfig humanAgentSuggestionConfig
                         * @property {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ISuggestionConfig|null} [endUserSuggestionConfig] HumanAgentAssistantConfig endUserSuggestionConfig
                         * @property {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.IMessageAnalysisConfig|null} [messageAnalysisConfig] HumanAgentAssistantConfig messageAnalysisConfig
                         */
    
                        /**
                         * Constructs a new HumanAgentAssistantConfig.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a HumanAgentAssistantConfig.
                         * @implements IHumanAgentAssistantConfig
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IHumanAgentAssistantConfig=} [properties] Properties to set
                         */
                        function HumanAgentAssistantConfig(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * HumanAgentAssistantConfig notificationConfig.
                         * @member {google.cloud.dialogflow.v2.INotificationConfig|null|undefined} notificationConfig
                         * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig
                         * @instance
                         */
                        HumanAgentAssistantConfig.prototype.notificationConfig = null;
    
                        /**
                         * HumanAgentAssistantConfig humanAgentSuggestionConfig.
                         * @member {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ISuggestionConfig|null|undefined} humanAgentSuggestionConfig
                         * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig
                         * @instance
                         */
                        HumanAgentAssistantConfig.prototype.humanAgentSuggestionConfig = null;
    
                        /**
                         * HumanAgentAssistantConfig endUserSuggestionConfig.
                         * @member {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ISuggestionConfig|null|undefined} endUserSuggestionConfig
                         * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig
                         * @instance
                         */
                        HumanAgentAssistantConfig.prototype.endUserSuggestionConfig = null;
    
                        /**
                         * HumanAgentAssistantConfig messageAnalysisConfig.
                         * @member {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.IMessageAnalysisConfig|null|undefined} messageAnalysisConfig
                         * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig
                         * @instance
                         */
                        HumanAgentAssistantConfig.prototype.messageAnalysisConfig = null;
    
                        /**
                         * Creates a new HumanAgentAssistantConfig instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2.IHumanAgentAssistantConfig=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantConfig} HumanAgentAssistantConfig instance
                         */
                        HumanAgentAssistantConfig.create = function create(properties) {
                            return new HumanAgentAssistantConfig(properties);
                        };
    
                        /**
                         * Encodes the specified HumanAgentAssistantConfig message. Does not implicitly {@link google.cloud.dialogflow.v2.HumanAgentAssistantConfig.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2.IHumanAgentAssistantConfig} message HumanAgentAssistantConfig message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        HumanAgentAssistantConfig.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.notificationConfig != null && Object.hasOwnProperty.call(message, "notificationConfig"))
                                $root.google.cloud.dialogflow.v2.NotificationConfig.encode(message.notificationConfig, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.humanAgentSuggestionConfig != null && Object.hasOwnProperty.call(message, "humanAgentSuggestionConfig"))
                                $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionConfig.encode(message.humanAgentSuggestionConfig, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            if (message.endUserSuggestionConfig != null && Object.hasOwnProperty.call(message, "endUserSuggestionConfig"))
                                $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionConfig.encode(message.endUserSuggestionConfig, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            if (message.messageAnalysisConfig != null && Object.hasOwnProperty.call(message, "messageAnalysisConfig"))
                                $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.MessageAnalysisConfig.encode(message.messageAnalysisConfig, writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified HumanAgentAssistantConfig message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.HumanAgentAssistantConfig.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2.IHumanAgentAssistantConfig} message HumanAgentAssistantConfig message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        HumanAgentAssistantConfig.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a HumanAgentAssistantConfig message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantConfig} HumanAgentAssistantConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        HumanAgentAssistantConfig.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 2: {
                                        message.notificationConfig = $root.google.cloud.dialogflow.v2.NotificationConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 3: {
                                        message.humanAgentSuggestionConfig = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 4: {
                                        message.endUserSuggestionConfig = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 5: {
                                        message.messageAnalysisConfig = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.MessageAnalysisConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a HumanAgentAssistantConfig message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantConfig} HumanAgentAssistantConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        HumanAgentAssistantConfig.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a HumanAgentAssistantConfig message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        HumanAgentAssistantConfig.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.notificationConfig != null && message.hasOwnProperty("notificationConfig")) {
                                var error = $root.google.cloud.dialogflow.v2.NotificationConfig.verify(message.notificationConfig);
                                if (error)
                                    return "notificationConfig." + error;
                            }
                            if (message.humanAgentSuggestionConfig != null && message.hasOwnProperty("humanAgentSuggestionConfig")) {
                                var error = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionConfig.verify(message.humanAgentSuggestionConfig);
                                if (error)
                                    return "humanAgentSuggestionConfig." + error;
                            }
                            if (message.endUserSuggestionConfig != null && message.hasOwnProperty("endUserSuggestionConfig")) {
                                var error = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionConfig.verify(message.endUserSuggestionConfig);
                                if (error)
                                    return "endUserSuggestionConfig." + error;
                            }
                            if (message.messageAnalysisConfig != null && message.hasOwnProperty("messageAnalysisConfig")) {
                                var error = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.MessageAnalysisConfig.verify(message.messageAnalysisConfig);
                                if (error)
                                    return "messageAnalysisConfig." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a HumanAgentAssistantConfig message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantConfig} HumanAgentAssistantConfig
                         */
                        HumanAgentAssistantConfig.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig();
                            if (object.notificationConfig != null) {
                                if (typeof object.notificationConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.HumanAgentAssistantConfig.notificationConfig: object expected");
                                message.notificationConfig = $root.google.cloud.dialogflow.v2.NotificationConfig.fromObject(object.notificationConfig);
                            }
                            if (object.humanAgentSuggestionConfig != null) {
                                if (typeof object.humanAgentSuggestionConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.HumanAgentAssistantConfig.humanAgentSuggestionConfig: object expected");
                                message.humanAgentSuggestionConfig = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionConfig.fromObject(object.humanAgentSuggestionConfig);
                            }
                            if (object.endUserSuggestionConfig != null) {
                                if (typeof object.endUserSuggestionConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.HumanAgentAssistantConfig.endUserSuggestionConfig: object expected");
                                message.endUserSuggestionConfig = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionConfig.fromObject(object.endUserSuggestionConfig);
                            }
                            if (object.messageAnalysisConfig != null) {
                                if (typeof object.messageAnalysisConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.HumanAgentAssistantConfig.messageAnalysisConfig: object expected");
                                message.messageAnalysisConfig = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.MessageAnalysisConfig.fromObject(object.messageAnalysisConfig);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a HumanAgentAssistantConfig message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig} message HumanAgentAssistantConfig
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        HumanAgentAssistantConfig.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.notificationConfig = null;
                                object.humanAgentSuggestionConfig = null;
                                object.endUserSuggestionConfig = null;
                                object.messageAnalysisConfig = null;
                            }
                            if (message.notificationConfig != null && message.hasOwnProperty("notificationConfig"))
                                object.notificationConfig = $root.google.cloud.dialogflow.v2.NotificationConfig.toObject(message.notificationConfig, options);
                            if (message.humanAgentSuggestionConfig != null && message.hasOwnProperty("humanAgentSuggestionConfig"))
                                object.humanAgentSuggestionConfig = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionConfig.toObject(message.humanAgentSuggestionConfig, options);
                            if (message.endUserSuggestionConfig != null && message.hasOwnProperty("endUserSuggestionConfig"))
                                object.endUserSuggestionConfig = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionConfig.toObject(message.endUserSuggestionConfig, options);
                            if (message.messageAnalysisConfig != null && message.hasOwnProperty("messageAnalysisConfig"))
                                object.messageAnalysisConfig = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.MessageAnalysisConfig.toObject(message.messageAnalysisConfig, options);
                            return object;
                        };
    
                        /**
                         * Converts this HumanAgentAssistantConfig to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        HumanAgentAssistantConfig.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for HumanAgentAssistantConfig
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        HumanAgentAssistantConfig.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.HumanAgentAssistantConfig";
                        };
    
                        HumanAgentAssistantConfig.SuggestionTriggerSettings = (function() {
    
                            /**
                             * Properties of a SuggestionTriggerSettings.
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig
                             * @interface ISuggestionTriggerSettings
                             * @property {boolean|null} [noSmalltalk] SuggestionTriggerSettings noSmalltalk
                             * @property {boolean|null} [onlyEndUser] SuggestionTriggerSettings onlyEndUser
                             */
    
                            /**
                             * Constructs a new SuggestionTriggerSettings.
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig
                             * @classdesc Represents a SuggestionTriggerSettings.
                             * @implements ISuggestionTriggerSettings
                             * @constructor
                             * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ISuggestionTriggerSettings=} [properties] Properties to set
                             */
                            function SuggestionTriggerSettings(properties) {
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * SuggestionTriggerSettings noSmalltalk.
                             * @member {boolean} noSmalltalk
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionTriggerSettings
                             * @instance
                             */
                            SuggestionTriggerSettings.prototype.noSmalltalk = false;
    
                            /**
                             * SuggestionTriggerSettings onlyEndUser.
                             * @member {boolean} onlyEndUser
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionTriggerSettings
                             * @instance
                             */
                            SuggestionTriggerSettings.prototype.onlyEndUser = false;
    
                            /**
                             * Creates a new SuggestionTriggerSettings instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionTriggerSettings
                             * @static
                             * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ISuggestionTriggerSettings=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionTriggerSettings} SuggestionTriggerSettings instance
                             */
                            SuggestionTriggerSettings.create = function create(properties) {
                                return new SuggestionTriggerSettings(properties);
                            };
    
                            /**
                             * Encodes the specified SuggestionTriggerSettings message. Does not implicitly {@link google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionTriggerSettings.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionTriggerSettings
                             * @static
                             * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ISuggestionTriggerSettings} message SuggestionTriggerSettings message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            SuggestionTriggerSettings.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.noSmalltalk != null && Object.hasOwnProperty.call(message, "noSmalltalk"))
                                    writer.uint32(/* id 1, wireType 0 =*/8).bool(message.noSmalltalk);
                                if (message.onlyEndUser != null && Object.hasOwnProperty.call(message, "onlyEndUser"))
                                    writer.uint32(/* id 2, wireType 0 =*/16).bool(message.onlyEndUser);
                                return writer;
                            };
    
                            /**
                             * Encodes the specified SuggestionTriggerSettings message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionTriggerSettings.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionTriggerSettings
                             * @static
                             * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ISuggestionTriggerSettings} message SuggestionTriggerSettings message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            SuggestionTriggerSettings.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a SuggestionTriggerSettings message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionTriggerSettings
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionTriggerSettings} SuggestionTriggerSettings
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            SuggestionTriggerSettings.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionTriggerSettings();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.noSmalltalk = reader.bool();
                                            break;
                                        }
                                    case 2: {
                                            message.onlyEndUser = reader.bool();
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a SuggestionTriggerSettings message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionTriggerSettings
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionTriggerSettings} SuggestionTriggerSettings
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            SuggestionTriggerSettings.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a SuggestionTriggerSettings message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionTriggerSettings
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            SuggestionTriggerSettings.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.noSmalltalk != null && message.hasOwnProperty("noSmalltalk"))
                                    if (typeof message.noSmalltalk !== "boolean")
                                        return "noSmalltalk: boolean expected";
                                if (message.onlyEndUser != null && message.hasOwnProperty("onlyEndUser"))
                                    if (typeof message.onlyEndUser !== "boolean")
                                        return "onlyEndUser: boolean expected";
                                return null;
                            };
    
                            /**
                             * Creates a SuggestionTriggerSettings message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionTriggerSettings
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionTriggerSettings} SuggestionTriggerSettings
                             */
                            SuggestionTriggerSettings.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionTriggerSettings)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionTriggerSettings();
                                if (object.noSmalltalk != null)
                                    message.noSmalltalk = Boolean(object.noSmalltalk);
                                if (object.onlyEndUser != null)
                                    message.onlyEndUser = Boolean(object.onlyEndUser);
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a SuggestionTriggerSettings message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionTriggerSettings
                             * @static
                             * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionTriggerSettings} message SuggestionTriggerSettings
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            SuggestionTriggerSettings.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.defaults) {
                                    object.noSmalltalk = false;
                                    object.onlyEndUser = false;
                                }
                                if (message.noSmalltalk != null && message.hasOwnProperty("noSmalltalk"))
                                    object.noSmalltalk = message.noSmalltalk;
                                if (message.onlyEndUser != null && message.hasOwnProperty("onlyEndUser"))
                                    object.onlyEndUser = message.onlyEndUser;
                                return object;
                            };
    
                            /**
                             * Converts this SuggestionTriggerSettings to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionTriggerSettings
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            SuggestionTriggerSettings.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for SuggestionTriggerSettings
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionTriggerSettings
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            SuggestionTriggerSettings.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionTriggerSettings";
                            };
    
                            return SuggestionTriggerSettings;
                        })();
    
                        HumanAgentAssistantConfig.SuggestionFeatureConfig = (function() {
    
                            /**
                             * Properties of a SuggestionFeatureConfig.
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig
                             * @interface ISuggestionFeatureConfig
                             * @property {google.cloud.dialogflow.v2.ISuggestionFeature|null} [suggestionFeature] SuggestionFeatureConfig suggestionFeature
                             * @property {boolean|null} [enableEventBasedSuggestion] SuggestionFeatureConfig enableEventBasedSuggestion
                             * @property {boolean|null} [disableAgentQueryLogging] SuggestionFeatureConfig disableAgentQueryLogging
                             * @property {boolean|null} [enableQuerySuggestionWhenNoAnswer] SuggestionFeatureConfig enableQuerySuggestionWhenNoAnswer
                             * @property {boolean|null} [enableConversationAugmentedQuery] SuggestionFeatureConfig enableConversationAugmentedQuery
                             * @property {boolean|null} [enableQuerySuggestionOnly] SuggestionFeatureConfig enableQuerySuggestionOnly
                             * @property {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ISuggestionTriggerSettings|null} [suggestionTriggerSettings] SuggestionFeatureConfig suggestionTriggerSettings
                             * @property {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ISuggestionQueryConfig|null} [queryConfig] SuggestionFeatureConfig queryConfig
                             * @property {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.IConversationModelConfig|null} [conversationModelConfig] SuggestionFeatureConfig conversationModelConfig
                             * @property {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.IConversationProcessConfig|null} [conversationProcessConfig] SuggestionFeatureConfig conversationProcessConfig
                             */
    
                            /**
                             * Constructs a new SuggestionFeatureConfig.
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig
                             * @classdesc Represents a SuggestionFeatureConfig.
                             * @implements ISuggestionFeatureConfig
                             * @constructor
                             * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ISuggestionFeatureConfig=} [properties] Properties to set
                             */
                            function SuggestionFeatureConfig(properties) {
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * SuggestionFeatureConfig suggestionFeature.
                             * @member {google.cloud.dialogflow.v2.ISuggestionFeature|null|undefined} suggestionFeature
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionFeatureConfig
                             * @instance
                             */
                            SuggestionFeatureConfig.prototype.suggestionFeature = null;
    
                            /**
                             * SuggestionFeatureConfig enableEventBasedSuggestion.
                             * @member {boolean} enableEventBasedSuggestion
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionFeatureConfig
                             * @instance
                             */
                            SuggestionFeatureConfig.prototype.enableEventBasedSuggestion = false;
    
                            /**
                             * SuggestionFeatureConfig disableAgentQueryLogging.
                             * @member {boolean} disableAgentQueryLogging
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionFeatureConfig
                             * @instance
                             */
                            SuggestionFeatureConfig.prototype.disableAgentQueryLogging = false;
    
                            /**
                             * SuggestionFeatureConfig enableQuerySuggestionWhenNoAnswer.
                             * @member {boolean} enableQuerySuggestionWhenNoAnswer
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionFeatureConfig
                             * @instance
                             */
                            SuggestionFeatureConfig.prototype.enableQuerySuggestionWhenNoAnswer = false;
    
                            /**
                             * SuggestionFeatureConfig enableConversationAugmentedQuery.
                             * @member {boolean} enableConversationAugmentedQuery
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionFeatureConfig
                             * @instance
                             */
                            SuggestionFeatureConfig.prototype.enableConversationAugmentedQuery = false;
    
                            /**
                             * SuggestionFeatureConfig enableQuerySuggestionOnly.
                             * @member {boolean} enableQuerySuggestionOnly
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionFeatureConfig
                             * @instance
                             */
                            SuggestionFeatureConfig.prototype.enableQuerySuggestionOnly = false;
    
                            /**
                             * SuggestionFeatureConfig suggestionTriggerSettings.
                             * @member {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ISuggestionTriggerSettings|null|undefined} suggestionTriggerSettings
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionFeatureConfig
                             * @instance
                             */
                            SuggestionFeatureConfig.prototype.suggestionTriggerSettings = null;
    
                            /**
                             * SuggestionFeatureConfig queryConfig.
                             * @member {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ISuggestionQueryConfig|null|undefined} queryConfig
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionFeatureConfig
                             * @instance
                             */
                            SuggestionFeatureConfig.prototype.queryConfig = null;
    
                            /**
                             * SuggestionFeatureConfig conversationModelConfig.
                             * @member {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.IConversationModelConfig|null|undefined} conversationModelConfig
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionFeatureConfig
                             * @instance
                             */
                            SuggestionFeatureConfig.prototype.conversationModelConfig = null;
    
                            /**
                             * SuggestionFeatureConfig conversationProcessConfig.
                             * @member {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.IConversationProcessConfig|null|undefined} conversationProcessConfig
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionFeatureConfig
                             * @instance
                             */
                            SuggestionFeatureConfig.prototype.conversationProcessConfig = null;
    
                            /**
                             * Creates a new SuggestionFeatureConfig instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionFeatureConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ISuggestionFeatureConfig=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionFeatureConfig} SuggestionFeatureConfig instance
                             */
                            SuggestionFeatureConfig.create = function create(properties) {
                                return new SuggestionFeatureConfig(properties);
                            };
    
                            /**
                             * Encodes the specified SuggestionFeatureConfig message. Does not implicitly {@link google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionFeatureConfig.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionFeatureConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ISuggestionFeatureConfig} message SuggestionFeatureConfig message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            SuggestionFeatureConfig.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.enableEventBasedSuggestion != null && Object.hasOwnProperty.call(message, "enableEventBasedSuggestion"))
                                    writer.uint32(/* id 3, wireType 0 =*/24).bool(message.enableEventBasedSuggestion);
                                if (message.suggestionFeature != null && Object.hasOwnProperty.call(message, "suggestionFeature"))
                                    $root.google.cloud.dialogflow.v2.SuggestionFeature.encode(message.suggestionFeature, writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                                if (message.queryConfig != null && Object.hasOwnProperty.call(message, "queryConfig"))
                                    $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.encode(message.queryConfig, writer.uint32(/* id 6, wireType 2 =*/50).fork()).ldelim();
                                if (message.conversationModelConfig != null && Object.hasOwnProperty.call(message, "conversationModelConfig"))
                                    $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ConversationModelConfig.encode(message.conversationModelConfig, writer.uint32(/* id 7, wireType 2 =*/58).fork()).ldelim();
                                if (message.conversationProcessConfig != null && Object.hasOwnProperty.call(message, "conversationProcessConfig"))
                                    $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ConversationProcessConfig.encode(message.conversationProcessConfig, writer.uint32(/* id 8, wireType 2 =*/66).fork()).ldelim();
                                if (message.suggestionTriggerSettings != null && Object.hasOwnProperty.call(message, "suggestionTriggerSettings"))
                                    $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionTriggerSettings.encode(message.suggestionTriggerSettings, writer.uint32(/* id 10, wireType 2 =*/82).fork()).ldelim();
                                if (message.disableAgentQueryLogging != null && Object.hasOwnProperty.call(message, "disableAgentQueryLogging"))
                                    writer.uint32(/* id 14, wireType 0 =*/112).bool(message.disableAgentQueryLogging);
                                if (message.enableQuerySuggestionWhenNoAnswer != null && Object.hasOwnProperty.call(message, "enableQuerySuggestionWhenNoAnswer"))
                                    writer.uint32(/* id 15, wireType 0 =*/120).bool(message.enableQuerySuggestionWhenNoAnswer);
                                if (message.enableConversationAugmentedQuery != null && Object.hasOwnProperty.call(message, "enableConversationAugmentedQuery"))
                                    writer.uint32(/* id 16, wireType 0 =*/128).bool(message.enableConversationAugmentedQuery);
                                if (message.enableQuerySuggestionOnly != null && Object.hasOwnProperty.call(message, "enableQuerySuggestionOnly"))
                                    writer.uint32(/* id 17, wireType 0 =*/136).bool(message.enableQuerySuggestionOnly);
                                return writer;
                            };
    
                            /**
                             * Encodes the specified SuggestionFeatureConfig message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionFeatureConfig.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionFeatureConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ISuggestionFeatureConfig} message SuggestionFeatureConfig message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            SuggestionFeatureConfig.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a SuggestionFeatureConfig message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionFeatureConfig
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionFeatureConfig} SuggestionFeatureConfig
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            SuggestionFeatureConfig.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionFeatureConfig();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 5: {
                                            message.suggestionFeature = $root.google.cloud.dialogflow.v2.SuggestionFeature.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 3: {
                                            message.enableEventBasedSuggestion = reader.bool();
                                            break;
                                        }
                                    case 14: {
                                            message.disableAgentQueryLogging = reader.bool();
                                            break;
                                        }
                                    case 15: {
                                            message.enableQuerySuggestionWhenNoAnswer = reader.bool();
                                            break;
                                        }
                                    case 16: {
                                            message.enableConversationAugmentedQuery = reader.bool();
                                            break;
                                        }
                                    case 17: {
                                            message.enableQuerySuggestionOnly = reader.bool();
                                            break;
                                        }
                                    case 10: {
                                            message.suggestionTriggerSettings = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionTriggerSettings.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 6: {
                                            message.queryConfig = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 7: {
                                            message.conversationModelConfig = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ConversationModelConfig.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 8: {
                                            message.conversationProcessConfig = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ConversationProcessConfig.decode(reader, reader.uint32());
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a SuggestionFeatureConfig message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionFeatureConfig
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionFeatureConfig} SuggestionFeatureConfig
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            SuggestionFeatureConfig.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a SuggestionFeatureConfig message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionFeatureConfig
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            SuggestionFeatureConfig.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.suggestionFeature != null && message.hasOwnProperty("suggestionFeature")) {
                                    var error = $root.google.cloud.dialogflow.v2.SuggestionFeature.verify(message.suggestionFeature);
                                    if (error)
                                        return "suggestionFeature." + error;
                                }
                                if (message.enableEventBasedSuggestion != null && message.hasOwnProperty("enableEventBasedSuggestion"))
                                    if (typeof message.enableEventBasedSuggestion !== "boolean")
                                        return "enableEventBasedSuggestion: boolean expected";
                                if (message.disableAgentQueryLogging != null && message.hasOwnProperty("disableAgentQueryLogging"))
                                    if (typeof message.disableAgentQueryLogging !== "boolean")
                                        return "disableAgentQueryLogging: boolean expected";
                                if (message.enableQuerySuggestionWhenNoAnswer != null && message.hasOwnProperty("enableQuerySuggestionWhenNoAnswer"))
                                    if (typeof message.enableQuerySuggestionWhenNoAnswer !== "boolean")
                                        return "enableQuerySuggestionWhenNoAnswer: boolean expected";
                                if (message.enableConversationAugmentedQuery != null && message.hasOwnProperty("enableConversationAugmentedQuery"))
                                    if (typeof message.enableConversationAugmentedQuery !== "boolean")
                                        return "enableConversationAugmentedQuery: boolean expected";
                                if (message.enableQuerySuggestionOnly != null && message.hasOwnProperty("enableQuerySuggestionOnly"))
                                    if (typeof message.enableQuerySuggestionOnly !== "boolean")
                                        return "enableQuerySuggestionOnly: boolean expected";
                                if (message.suggestionTriggerSettings != null && message.hasOwnProperty("suggestionTriggerSettings")) {
                                    var error = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionTriggerSettings.verify(message.suggestionTriggerSettings);
                                    if (error)
                                        return "suggestionTriggerSettings." + error;
                                }
                                if (message.queryConfig != null && message.hasOwnProperty("queryConfig")) {
                                    var error = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.verify(message.queryConfig);
                                    if (error)
                                        return "queryConfig." + error;
                                }
                                if (message.conversationModelConfig != null && message.hasOwnProperty("conversationModelConfig")) {
                                    var error = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ConversationModelConfig.verify(message.conversationModelConfig);
                                    if (error)
                                        return "conversationModelConfig." + error;
                                }
                                if (message.conversationProcessConfig != null && message.hasOwnProperty("conversationProcessConfig")) {
                                    var error = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ConversationProcessConfig.verify(message.conversationProcessConfig);
                                    if (error)
                                        return "conversationProcessConfig." + error;
                                }
                                return null;
                            };
    
                            /**
                             * Creates a SuggestionFeatureConfig message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionFeatureConfig
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionFeatureConfig} SuggestionFeatureConfig
                             */
                            SuggestionFeatureConfig.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionFeatureConfig)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionFeatureConfig();
                                if (object.suggestionFeature != null) {
                                    if (typeof object.suggestionFeature !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionFeatureConfig.suggestionFeature: object expected");
                                    message.suggestionFeature = $root.google.cloud.dialogflow.v2.SuggestionFeature.fromObject(object.suggestionFeature);
                                }
                                if (object.enableEventBasedSuggestion != null)
                                    message.enableEventBasedSuggestion = Boolean(object.enableEventBasedSuggestion);
                                if (object.disableAgentQueryLogging != null)
                                    message.disableAgentQueryLogging = Boolean(object.disableAgentQueryLogging);
                                if (object.enableQuerySuggestionWhenNoAnswer != null)
                                    message.enableQuerySuggestionWhenNoAnswer = Boolean(object.enableQuerySuggestionWhenNoAnswer);
                                if (object.enableConversationAugmentedQuery != null)
                                    message.enableConversationAugmentedQuery = Boolean(object.enableConversationAugmentedQuery);
                                if (object.enableQuerySuggestionOnly != null)
                                    message.enableQuerySuggestionOnly = Boolean(object.enableQuerySuggestionOnly);
                                if (object.suggestionTriggerSettings != null) {
                                    if (typeof object.suggestionTriggerSettings !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionFeatureConfig.suggestionTriggerSettings: object expected");
                                    message.suggestionTriggerSettings = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionTriggerSettings.fromObject(object.suggestionTriggerSettings);
                                }
                                if (object.queryConfig != null) {
                                    if (typeof object.queryConfig !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionFeatureConfig.queryConfig: object expected");
                                    message.queryConfig = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.fromObject(object.queryConfig);
                                }
                                if (object.conversationModelConfig != null) {
                                    if (typeof object.conversationModelConfig !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionFeatureConfig.conversationModelConfig: object expected");
                                    message.conversationModelConfig = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ConversationModelConfig.fromObject(object.conversationModelConfig);
                                }
                                if (object.conversationProcessConfig != null) {
                                    if (typeof object.conversationProcessConfig !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionFeatureConfig.conversationProcessConfig: object expected");
                                    message.conversationProcessConfig = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ConversationProcessConfig.fromObject(object.conversationProcessConfig);
                                }
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a SuggestionFeatureConfig message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionFeatureConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionFeatureConfig} message SuggestionFeatureConfig
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            SuggestionFeatureConfig.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.defaults) {
                                    object.enableEventBasedSuggestion = false;
                                    object.suggestionFeature = null;
                                    object.queryConfig = null;
                                    object.conversationModelConfig = null;
                                    object.conversationProcessConfig = null;
                                    object.suggestionTriggerSettings = null;
                                    object.disableAgentQueryLogging = false;
                                    object.enableQuerySuggestionWhenNoAnswer = false;
                                    object.enableConversationAugmentedQuery = false;
                                    object.enableQuerySuggestionOnly = false;
                                }
                                if (message.enableEventBasedSuggestion != null && message.hasOwnProperty("enableEventBasedSuggestion"))
                                    object.enableEventBasedSuggestion = message.enableEventBasedSuggestion;
                                if (message.suggestionFeature != null && message.hasOwnProperty("suggestionFeature"))
                                    object.suggestionFeature = $root.google.cloud.dialogflow.v2.SuggestionFeature.toObject(message.suggestionFeature, options);
                                if (message.queryConfig != null && message.hasOwnProperty("queryConfig"))
                                    object.queryConfig = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.toObject(message.queryConfig, options);
                                if (message.conversationModelConfig != null && message.hasOwnProperty("conversationModelConfig"))
                                    object.conversationModelConfig = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ConversationModelConfig.toObject(message.conversationModelConfig, options);
                                if (message.conversationProcessConfig != null && message.hasOwnProperty("conversationProcessConfig"))
                                    object.conversationProcessConfig = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ConversationProcessConfig.toObject(message.conversationProcessConfig, options);
                                if (message.suggestionTriggerSettings != null && message.hasOwnProperty("suggestionTriggerSettings"))
                                    object.suggestionTriggerSettings = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionTriggerSettings.toObject(message.suggestionTriggerSettings, options);
                                if (message.disableAgentQueryLogging != null && message.hasOwnProperty("disableAgentQueryLogging"))
                                    object.disableAgentQueryLogging = message.disableAgentQueryLogging;
                                if (message.enableQuerySuggestionWhenNoAnswer != null && message.hasOwnProperty("enableQuerySuggestionWhenNoAnswer"))
                                    object.enableQuerySuggestionWhenNoAnswer = message.enableQuerySuggestionWhenNoAnswer;
                                if (message.enableConversationAugmentedQuery != null && message.hasOwnProperty("enableConversationAugmentedQuery"))
                                    object.enableConversationAugmentedQuery = message.enableConversationAugmentedQuery;
                                if (message.enableQuerySuggestionOnly != null && message.hasOwnProperty("enableQuerySuggestionOnly"))
                                    object.enableQuerySuggestionOnly = message.enableQuerySuggestionOnly;
                                return object;
                            };
    
                            /**
                             * Converts this SuggestionFeatureConfig to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionFeatureConfig
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            SuggestionFeatureConfig.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for SuggestionFeatureConfig
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionFeatureConfig
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            SuggestionFeatureConfig.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionFeatureConfig";
                            };
    
                            return SuggestionFeatureConfig;
                        })();
    
                        HumanAgentAssistantConfig.SuggestionConfig = (function() {
    
                            /**
                             * Properties of a SuggestionConfig.
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig
                             * @interface ISuggestionConfig
                             * @property {Array.<google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ISuggestionFeatureConfig>|null} [featureConfigs] SuggestionConfig featureConfigs
                             * @property {boolean|null} [groupSuggestionResponses] SuggestionConfig groupSuggestionResponses
                             * @property {Array.<string>|null} [generators] SuggestionConfig generators
                             * @property {boolean|null} [disableHighLatencyFeaturesSyncDelivery] SuggestionConfig disableHighLatencyFeaturesSyncDelivery
                             */
    
                            /**
                             * Constructs a new SuggestionConfig.
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig
                             * @classdesc Represents a SuggestionConfig.
                             * @implements ISuggestionConfig
                             * @constructor
                             * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ISuggestionConfig=} [properties] Properties to set
                             */
                            function SuggestionConfig(properties) {
                                this.featureConfigs = [];
                                this.generators = [];
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * SuggestionConfig featureConfigs.
                             * @member {Array.<google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ISuggestionFeatureConfig>} featureConfigs
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionConfig
                             * @instance
                             */
                            SuggestionConfig.prototype.featureConfigs = $util.emptyArray;
    
                            /**
                             * SuggestionConfig groupSuggestionResponses.
                             * @member {boolean} groupSuggestionResponses
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionConfig
                             * @instance
                             */
                            SuggestionConfig.prototype.groupSuggestionResponses = false;
    
                            /**
                             * SuggestionConfig generators.
                             * @member {Array.<string>} generators
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionConfig
                             * @instance
                             */
                            SuggestionConfig.prototype.generators = $util.emptyArray;
    
                            /**
                             * SuggestionConfig disableHighLatencyFeaturesSyncDelivery.
                             * @member {boolean} disableHighLatencyFeaturesSyncDelivery
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionConfig
                             * @instance
                             */
                            SuggestionConfig.prototype.disableHighLatencyFeaturesSyncDelivery = false;
    
                            /**
                             * Creates a new SuggestionConfig instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ISuggestionConfig=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionConfig} SuggestionConfig instance
                             */
                            SuggestionConfig.create = function create(properties) {
                                return new SuggestionConfig(properties);
                            };
    
                            /**
                             * Encodes the specified SuggestionConfig message. Does not implicitly {@link google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionConfig.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ISuggestionConfig} message SuggestionConfig message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            SuggestionConfig.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.featureConfigs != null && message.featureConfigs.length)
                                    for (var i = 0; i < message.featureConfigs.length; ++i)
                                        $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionFeatureConfig.encode(message.featureConfigs[i], writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                                if (message.groupSuggestionResponses != null && Object.hasOwnProperty.call(message, "groupSuggestionResponses"))
                                    writer.uint32(/* id 3, wireType 0 =*/24).bool(message.groupSuggestionResponses);
                                if (message.generators != null && message.generators.length)
                                    for (var i = 0; i < message.generators.length; ++i)
                                        writer.uint32(/* id 4, wireType 2 =*/34).string(message.generators[i]);
                                if (message.disableHighLatencyFeaturesSyncDelivery != null && Object.hasOwnProperty.call(message, "disableHighLatencyFeaturesSyncDelivery"))
                                    writer.uint32(/* id 5, wireType 0 =*/40).bool(message.disableHighLatencyFeaturesSyncDelivery);
                                return writer;
                            };
    
                            /**
                             * Encodes the specified SuggestionConfig message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionConfig.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ISuggestionConfig} message SuggestionConfig message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            SuggestionConfig.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a SuggestionConfig message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionConfig
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionConfig} SuggestionConfig
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            SuggestionConfig.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionConfig();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 2: {
                                            if (!(message.featureConfigs && message.featureConfigs.length))
                                                message.featureConfigs = [];
                                            message.featureConfigs.push($root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionFeatureConfig.decode(reader, reader.uint32()));
                                            break;
                                        }
                                    case 3: {
                                            message.groupSuggestionResponses = reader.bool();
                                            break;
                                        }
                                    case 4: {
                                            if (!(message.generators && message.generators.length))
                                                message.generators = [];
                                            message.generators.push(reader.string());
                                            break;
                                        }
                                    case 5: {
                                            message.disableHighLatencyFeaturesSyncDelivery = reader.bool();
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a SuggestionConfig message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionConfig
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionConfig} SuggestionConfig
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            SuggestionConfig.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a SuggestionConfig message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionConfig
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            SuggestionConfig.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.featureConfigs != null && message.hasOwnProperty("featureConfigs")) {
                                    if (!Array.isArray(message.featureConfigs))
                                        return "featureConfigs: array expected";
                                    for (var i = 0; i < message.featureConfigs.length; ++i) {
                                        var error = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionFeatureConfig.verify(message.featureConfigs[i]);
                                        if (error)
                                            return "featureConfigs." + error;
                                    }
                                }
                                if (message.groupSuggestionResponses != null && message.hasOwnProperty("groupSuggestionResponses"))
                                    if (typeof message.groupSuggestionResponses !== "boolean")
                                        return "groupSuggestionResponses: boolean expected";
                                if (message.generators != null && message.hasOwnProperty("generators")) {
                                    if (!Array.isArray(message.generators))
                                        return "generators: array expected";
                                    for (var i = 0; i < message.generators.length; ++i)
                                        if (!$util.isString(message.generators[i]))
                                            return "generators: string[] expected";
                                }
                                if (message.disableHighLatencyFeaturesSyncDelivery != null && message.hasOwnProperty("disableHighLatencyFeaturesSyncDelivery"))
                                    if (typeof message.disableHighLatencyFeaturesSyncDelivery !== "boolean")
                                        return "disableHighLatencyFeaturesSyncDelivery: boolean expected";
                                return null;
                            };
    
                            /**
                             * Creates a SuggestionConfig message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionConfig
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionConfig} SuggestionConfig
                             */
                            SuggestionConfig.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionConfig)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionConfig();
                                if (object.featureConfigs) {
                                    if (!Array.isArray(object.featureConfigs))
                                        throw TypeError(".google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionConfig.featureConfigs: array expected");
                                    message.featureConfigs = [];
                                    for (var i = 0; i < object.featureConfigs.length; ++i) {
                                        if (typeof object.featureConfigs[i] !== "object")
                                            throw TypeError(".google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionConfig.featureConfigs: object expected");
                                        message.featureConfigs[i] = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionFeatureConfig.fromObject(object.featureConfigs[i]);
                                    }
                                }
                                if (object.groupSuggestionResponses != null)
                                    message.groupSuggestionResponses = Boolean(object.groupSuggestionResponses);
                                if (object.generators) {
                                    if (!Array.isArray(object.generators))
                                        throw TypeError(".google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionConfig.generators: array expected");
                                    message.generators = [];
                                    for (var i = 0; i < object.generators.length; ++i)
                                        message.generators[i] = String(object.generators[i]);
                                }
                                if (object.disableHighLatencyFeaturesSyncDelivery != null)
                                    message.disableHighLatencyFeaturesSyncDelivery = Boolean(object.disableHighLatencyFeaturesSyncDelivery);
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a SuggestionConfig message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionConfig} message SuggestionConfig
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            SuggestionConfig.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.arrays || options.defaults) {
                                    object.featureConfigs = [];
                                    object.generators = [];
                                }
                                if (options.defaults) {
                                    object.groupSuggestionResponses = false;
                                    object.disableHighLatencyFeaturesSyncDelivery = false;
                                }
                                if (message.featureConfigs && message.featureConfigs.length) {
                                    object.featureConfigs = [];
                                    for (var j = 0; j < message.featureConfigs.length; ++j)
                                        object.featureConfigs[j] = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionFeatureConfig.toObject(message.featureConfigs[j], options);
                                }
                                if (message.groupSuggestionResponses != null && message.hasOwnProperty("groupSuggestionResponses"))
                                    object.groupSuggestionResponses = message.groupSuggestionResponses;
                                if (message.generators && message.generators.length) {
                                    object.generators = [];
                                    for (var j = 0; j < message.generators.length; ++j)
                                        object.generators[j] = message.generators[j];
                                }
                                if (message.disableHighLatencyFeaturesSyncDelivery != null && message.hasOwnProperty("disableHighLatencyFeaturesSyncDelivery"))
                                    object.disableHighLatencyFeaturesSyncDelivery = message.disableHighLatencyFeaturesSyncDelivery;
                                return object;
                            };
    
                            /**
                             * Converts this SuggestionConfig to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionConfig
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            SuggestionConfig.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for SuggestionConfig
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionConfig
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            SuggestionConfig.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionConfig";
                            };
    
                            return SuggestionConfig;
                        })();
    
                        HumanAgentAssistantConfig.SuggestionQueryConfig = (function() {
    
                            /**
                             * Properties of a SuggestionQueryConfig.
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig
                             * @interface ISuggestionQueryConfig
                             * @property {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.IKnowledgeBaseQuerySource|null} [knowledgeBaseQuerySource] SuggestionQueryConfig knowledgeBaseQuerySource
                             * @property {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.IDocumentQuerySource|null} [documentQuerySource] SuggestionQueryConfig documentQuerySource
                             * @property {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.IDialogflowQuerySource|null} [dialogflowQuerySource] SuggestionQueryConfig dialogflowQuerySource
                             * @property {number|null} [maxResults] SuggestionQueryConfig maxResults
                             * @property {number|null} [confidenceThreshold] SuggestionQueryConfig confidenceThreshold
                             * @property {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.IContextFilterSettings|null} [contextFilterSettings] SuggestionQueryConfig contextFilterSettings
                             * @property {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.ISections|null} [sections] SuggestionQueryConfig sections
                             * @property {number|null} [contextSize] SuggestionQueryConfig contextSize
                             */
    
                            /**
                             * Constructs a new SuggestionQueryConfig.
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig
                             * @classdesc Represents a SuggestionQueryConfig.
                             * @implements ISuggestionQueryConfig
                             * @constructor
                             * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ISuggestionQueryConfig=} [properties] Properties to set
                             */
                            function SuggestionQueryConfig(properties) {
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * SuggestionQueryConfig knowledgeBaseQuerySource.
                             * @member {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.IKnowledgeBaseQuerySource|null|undefined} knowledgeBaseQuerySource
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig
                             * @instance
                             */
                            SuggestionQueryConfig.prototype.knowledgeBaseQuerySource = null;
    
                            /**
                             * SuggestionQueryConfig documentQuerySource.
                             * @member {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.IDocumentQuerySource|null|undefined} documentQuerySource
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig
                             * @instance
                             */
                            SuggestionQueryConfig.prototype.documentQuerySource = null;
    
                            /**
                             * SuggestionQueryConfig dialogflowQuerySource.
                             * @member {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.IDialogflowQuerySource|null|undefined} dialogflowQuerySource
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig
                             * @instance
                             */
                            SuggestionQueryConfig.prototype.dialogflowQuerySource = null;
    
                            /**
                             * SuggestionQueryConfig maxResults.
                             * @member {number} maxResults
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig
                             * @instance
                             */
                            SuggestionQueryConfig.prototype.maxResults = 0;
    
                            /**
                             * SuggestionQueryConfig confidenceThreshold.
                             * @member {number} confidenceThreshold
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig
                             * @instance
                             */
                            SuggestionQueryConfig.prototype.confidenceThreshold = 0;
    
                            /**
                             * SuggestionQueryConfig contextFilterSettings.
                             * @member {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.IContextFilterSettings|null|undefined} contextFilterSettings
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig
                             * @instance
                             */
                            SuggestionQueryConfig.prototype.contextFilterSettings = null;
    
                            /**
                             * SuggestionQueryConfig sections.
                             * @member {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.ISections|null|undefined} sections
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig
                             * @instance
                             */
                            SuggestionQueryConfig.prototype.sections = null;
    
                            /**
                             * SuggestionQueryConfig contextSize.
                             * @member {number} contextSize
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig
                             * @instance
                             */
                            SuggestionQueryConfig.prototype.contextSize = 0;
    
                            // OneOf field names bound to virtual getters and setters
                            var $oneOfFields;
    
                            /**
                             * SuggestionQueryConfig querySource.
                             * @member {"knowledgeBaseQuerySource"|"documentQuerySource"|"dialogflowQuerySource"|undefined} querySource
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig
                             * @instance
                             */
                            Object.defineProperty(SuggestionQueryConfig.prototype, "querySource", {
                                get: $util.oneOfGetter($oneOfFields = ["knowledgeBaseQuerySource", "documentQuerySource", "dialogflowQuerySource"]),
                                set: $util.oneOfSetter($oneOfFields)
                            });
    
                            /**
                             * Creates a new SuggestionQueryConfig instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ISuggestionQueryConfig=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig} SuggestionQueryConfig instance
                             */
                            SuggestionQueryConfig.create = function create(properties) {
                                return new SuggestionQueryConfig(properties);
                            };
    
                            /**
                             * Encodes the specified SuggestionQueryConfig message. Does not implicitly {@link google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ISuggestionQueryConfig} message SuggestionQueryConfig message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            SuggestionQueryConfig.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.knowledgeBaseQuerySource != null && Object.hasOwnProperty.call(message, "knowledgeBaseQuerySource"))
                                    $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.KnowledgeBaseQuerySource.encode(message.knowledgeBaseQuerySource, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                                if (message.documentQuerySource != null && Object.hasOwnProperty.call(message, "documentQuerySource"))
                                    $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DocumentQuerySource.encode(message.documentQuerySource, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                                if (message.dialogflowQuerySource != null && Object.hasOwnProperty.call(message, "dialogflowQuerySource"))
                                    $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.encode(message.dialogflowQuerySource, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                                if (message.maxResults != null && Object.hasOwnProperty.call(message, "maxResults"))
                                    writer.uint32(/* id 4, wireType 0 =*/32).int32(message.maxResults);
                                if (message.confidenceThreshold != null && Object.hasOwnProperty.call(message, "confidenceThreshold"))
                                    writer.uint32(/* id 5, wireType 5 =*/45).float(message.confidenceThreshold);
                                if (message.contextFilterSettings != null && Object.hasOwnProperty.call(message, "contextFilterSettings"))
                                    $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings.encode(message.contextFilterSettings, writer.uint32(/* id 7, wireType 2 =*/58).fork()).ldelim();
                                if (message.sections != null && Object.hasOwnProperty.call(message, "sections"))
                                    $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections.encode(message.sections, writer.uint32(/* id 8, wireType 2 =*/66).fork()).ldelim();
                                if (message.contextSize != null && Object.hasOwnProperty.call(message, "contextSize"))
                                    writer.uint32(/* id 9, wireType 0 =*/72).int32(message.contextSize);
                                return writer;
                            };
    
                            /**
                             * Encodes the specified SuggestionQueryConfig message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ISuggestionQueryConfig} message SuggestionQueryConfig message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            SuggestionQueryConfig.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a SuggestionQueryConfig message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig} SuggestionQueryConfig
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            SuggestionQueryConfig.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.knowledgeBaseQuerySource = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.KnowledgeBaseQuerySource.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 2: {
                                            message.documentQuerySource = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DocumentQuerySource.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 3: {
                                            message.dialogflowQuerySource = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 4: {
                                            message.maxResults = reader.int32();
                                            break;
                                        }
                                    case 5: {
                                            message.confidenceThreshold = reader.float();
                                            break;
                                        }
                                    case 7: {
                                            message.contextFilterSettings = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 8: {
                                            message.sections = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 9: {
                                            message.contextSize = reader.int32();
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a SuggestionQueryConfig message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig} SuggestionQueryConfig
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            SuggestionQueryConfig.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a SuggestionQueryConfig message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            SuggestionQueryConfig.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                var properties = {};
                                if (message.knowledgeBaseQuerySource != null && message.hasOwnProperty("knowledgeBaseQuerySource")) {
                                    properties.querySource = 1;
                                    {
                                        var error = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.KnowledgeBaseQuerySource.verify(message.knowledgeBaseQuerySource);
                                        if (error)
                                            return "knowledgeBaseQuerySource." + error;
                                    }
                                }
                                if (message.documentQuerySource != null && message.hasOwnProperty("documentQuerySource")) {
                                    if (properties.querySource === 1)
                                        return "querySource: multiple values";
                                    properties.querySource = 1;
                                    {
                                        var error = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DocumentQuerySource.verify(message.documentQuerySource);
                                        if (error)
                                            return "documentQuerySource." + error;
                                    }
                                }
                                if (message.dialogflowQuerySource != null && message.hasOwnProperty("dialogflowQuerySource")) {
                                    if (properties.querySource === 1)
                                        return "querySource: multiple values";
                                    properties.querySource = 1;
                                    {
                                        var error = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.verify(message.dialogflowQuerySource);
                                        if (error)
                                            return "dialogflowQuerySource." + error;
                                    }
                                }
                                if (message.maxResults != null && message.hasOwnProperty("maxResults"))
                                    if (!$util.isInteger(message.maxResults))
                                        return "maxResults: integer expected";
                                if (message.confidenceThreshold != null && message.hasOwnProperty("confidenceThreshold"))
                                    if (typeof message.confidenceThreshold !== "number")
                                        return "confidenceThreshold: number expected";
                                if (message.contextFilterSettings != null && message.hasOwnProperty("contextFilterSettings")) {
                                    var error = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings.verify(message.contextFilterSettings);
                                    if (error)
                                        return "contextFilterSettings." + error;
                                }
                                if (message.sections != null && message.hasOwnProperty("sections")) {
                                    var error = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections.verify(message.sections);
                                    if (error)
                                        return "sections." + error;
                                }
                                if (message.contextSize != null && message.hasOwnProperty("contextSize"))
                                    if (!$util.isInteger(message.contextSize))
                                        return "contextSize: integer expected";
                                return null;
                            };
    
                            /**
                             * Creates a SuggestionQueryConfig message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig} SuggestionQueryConfig
                             */
                            SuggestionQueryConfig.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig();
                                if (object.knowledgeBaseQuerySource != null) {
                                    if (typeof object.knowledgeBaseQuerySource !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.knowledgeBaseQuerySource: object expected");
                                    message.knowledgeBaseQuerySource = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.KnowledgeBaseQuerySource.fromObject(object.knowledgeBaseQuerySource);
                                }
                                if (object.documentQuerySource != null) {
                                    if (typeof object.documentQuerySource !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.documentQuerySource: object expected");
                                    message.documentQuerySource = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DocumentQuerySource.fromObject(object.documentQuerySource);
                                }
                                if (object.dialogflowQuerySource != null) {
                                    if (typeof object.dialogflowQuerySource !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.dialogflowQuerySource: object expected");
                                    message.dialogflowQuerySource = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.fromObject(object.dialogflowQuerySource);
                                }
                                if (object.maxResults != null)
                                    message.maxResults = object.maxResults | 0;
                                if (object.confidenceThreshold != null)
                                    message.confidenceThreshold = Number(object.confidenceThreshold);
                                if (object.contextFilterSettings != null) {
                                    if (typeof object.contextFilterSettings !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.contextFilterSettings: object expected");
                                    message.contextFilterSettings = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings.fromObject(object.contextFilterSettings);
                                }
                                if (object.sections != null) {
                                    if (typeof object.sections !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.sections: object expected");
                                    message.sections = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections.fromObject(object.sections);
                                }
                                if (object.contextSize != null)
                                    message.contextSize = object.contextSize | 0;
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a SuggestionQueryConfig message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig} message SuggestionQueryConfig
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            SuggestionQueryConfig.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.defaults) {
                                    object.maxResults = 0;
                                    object.confidenceThreshold = 0;
                                    object.contextFilterSettings = null;
                                    object.sections = null;
                                    object.contextSize = 0;
                                }
                                if (message.knowledgeBaseQuerySource != null && message.hasOwnProperty("knowledgeBaseQuerySource")) {
                                    object.knowledgeBaseQuerySource = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.KnowledgeBaseQuerySource.toObject(message.knowledgeBaseQuerySource, options);
                                    if (options.oneofs)
                                        object.querySource = "knowledgeBaseQuerySource";
                                }
                                if (message.documentQuerySource != null && message.hasOwnProperty("documentQuerySource")) {
                                    object.documentQuerySource = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DocumentQuerySource.toObject(message.documentQuerySource, options);
                                    if (options.oneofs)
                                        object.querySource = "documentQuerySource";
                                }
                                if (message.dialogflowQuerySource != null && message.hasOwnProperty("dialogflowQuerySource")) {
                                    object.dialogflowQuerySource = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.toObject(message.dialogflowQuerySource, options);
                                    if (options.oneofs)
                                        object.querySource = "dialogflowQuerySource";
                                }
                                if (message.maxResults != null && message.hasOwnProperty("maxResults"))
                                    object.maxResults = message.maxResults;
                                if (message.confidenceThreshold != null && message.hasOwnProperty("confidenceThreshold"))
                                    object.confidenceThreshold = options.json && !isFinite(message.confidenceThreshold) ? String(message.confidenceThreshold) : message.confidenceThreshold;
                                if (message.contextFilterSettings != null && message.hasOwnProperty("contextFilterSettings"))
                                    object.contextFilterSettings = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings.toObject(message.contextFilterSettings, options);
                                if (message.sections != null && message.hasOwnProperty("sections"))
                                    object.sections = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections.toObject(message.sections, options);
                                if (message.contextSize != null && message.hasOwnProperty("contextSize"))
                                    object.contextSize = message.contextSize;
                                return object;
                            };
    
                            /**
                             * Converts this SuggestionQueryConfig to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            SuggestionQueryConfig.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for SuggestionQueryConfig
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            SuggestionQueryConfig.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig";
                            };
    
                            SuggestionQueryConfig.KnowledgeBaseQuerySource = (function() {
    
                                /**
                                 * Properties of a KnowledgeBaseQuerySource.
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig
                                 * @interface IKnowledgeBaseQuerySource
                                 * @property {Array.<string>|null} [knowledgeBases] KnowledgeBaseQuerySource knowledgeBases
                                 */
    
                                /**
                                 * Constructs a new KnowledgeBaseQuerySource.
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig
                                 * @classdesc Represents a KnowledgeBaseQuerySource.
                                 * @implements IKnowledgeBaseQuerySource
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.IKnowledgeBaseQuerySource=} [properties] Properties to set
                                 */
                                function KnowledgeBaseQuerySource(properties) {
                                    this.knowledgeBases = [];
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * KnowledgeBaseQuerySource knowledgeBases.
                                 * @member {Array.<string>} knowledgeBases
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.KnowledgeBaseQuerySource
                                 * @instance
                                 */
                                KnowledgeBaseQuerySource.prototype.knowledgeBases = $util.emptyArray;
    
                                /**
                                 * Creates a new KnowledgeBaseQuerySource instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.KnowledgeBaseQuerySource
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.IKnowledgeBaseQuerySource=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.KnowledgeBaseQuerySource} KnowledgeBaseQuerySource instance
                                 */
                                KnowledgeBaseQuerySource.create = function create(properties) {
                                    return new KnowledgeBaseQuerySource(properties);
                                };
    
                                /**
                                 * Encodes the specified KnowledgeBaseQuerySource message. Does not implicitly {@link google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.KnowledgeBaseQuerySource.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.KnowledgeBaseQuerySource
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.IKnowledgeBaseQuerySource} message KnowledgeBaseQuerySource message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                KnowledgeBaseQuerySource.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.knowledgeBases != null && message.knowledgeBases.length)
                                        for (var i = 0; i < message.knowledgeBases.length; ++i)
                                            writer.uint32(/* id 1, wireType 2 =*/10).string(message.knowledgeBases[i]);
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified KnowledgeBaseQuerySource message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.KnowledgeBaseQuerySource.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.KnowledgeBaseQuerySource
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.IKnowledgeBaseQuerySource} message KnowledgeBaseQuerySource message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                KnowledgeBaseQuerySource.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a KnowledgeBaseQuerySource message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.KnowledgeBaseQuerySource
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.KnowledgeBaseQuerySource} KnowledgeBaseQuerySource
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                KnowledgeBaseQuerySource.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.KnowledgeBaseQuerySource();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                if (!(message.knowledgeBases && message.knowledgeBases.length))
                                                    message.knowledgeBases = [];
                                                message.knowledgeBases.push(reader.string());
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a KnowledgeBaseQuerySource message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.KnowledgeBaseQuerySource
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.KnowledgeBaseQuerySource} KnowledgeBaseQuerySource
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                KnowledgeBaseQuerySource.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a KnowledgeBaseQuerySource message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.KnowledgeBaseQuerySource
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                KnowledgeBaseQuerySource.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.knowledgeBases != null && message.hasOwnProperty("knowledgeBases")) {
                                        if (!Array.isArray(message.knowledgeBases))
                                            return "knowledgeBases: array expected";
                                        for (var i = 0; i < message.knowledgeBases.length; ++i)
                                            if (!$util.isString(message.knowledgeBases[i]))
                                                return "knowledgeBases: string[] expected";
                                    }
                                    return null;
                                };
    
                                /**
                                 * Creates a KnowledgeBaseQuerySource message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.KnowledgeBaseQuerySource
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.KnowledgeBaseQuerySource} KnowledgeBaseQuerySource
                                 */
                                KnowledgeBaseQuerySource.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.KnowledgeBaseQuerySource)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.KnowledgeBaseQuerySource();
                                    if (object.knowledgeBases) {
                                        if (!Array.isArray(object.knowledgeBases))
                                            throw TypeError(".google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.KnowledgeBaseQuerySource.knowledgeBases: array expected");
                                        message.knowledgeBases = [];
                                        for (var i = 0; i < object.knowledgeBases.length; ++i)
                                            message.knowledgeBases[i] = String(object.knowledgeBases[i]);
                                    }
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a KnowledgeBaseQuerySource message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.KnowledgeBaseQuerySource
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.KnowledgeBaseQuerySource} message KnowledgeBaseQuerySource
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                KnowledgeBaseQuerySource.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.arrays || options.defaults)
                                        object.knowledgeBases = [];
                                    if (message.knowledgeBases && message.knowledgeBases.length) {
                                        object.knowledgeBases = [];
                                        for (var j = 0; j < message.knowledgeBases.length; ++j)
                                            object.knowledgeBases[j] = message.knowledgeBases[j];
                                    }
                                    return object;
                                };
    
                                /**
                                 * Converts this KnowledgeBaseQuerySource to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.KnowledgeBaseQuerySource
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                KnowledgeBaseQuerySource.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for KnowledgeBaseQuerySource
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.KnowledgeBaseQuerySource
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                KnowledgeBaseQuerySource.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.KnowledgeBaseQuerySource";
                                };
    
                                return KnowledgeBaseQuerySource;
                            })();
    
                            SuggestionQueryConfig.DocumentQuerySource = (function() {
    
                                /**
                                 * Properties of a DocumentQuerySource.
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig
                                 * @interface IDocumentQuerySource
                                 * @property {Array.<string>|null} [documents] DocumentQuerySource documents
                                 */
    
                                /**
                                 * Constructs a new DocumentQuerySource.
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig
                                 * @classdesc Represents a DocumentQuerySource.
                                 * @implements IDocumentQuerySource
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.IDocumentQuerySource=} [properties] Properties to set
                                 */
                                function DocumentQuerySource(properties) {
                                    this.documents = [];
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * DocumentQuerySource documents.
                                 * @member {Array.<string>} documents
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DocumentQuerySource
                                 * @instance
                                 */
                                DocumentQuerySource.prototype.documents = $util.emptyArray;
    
                                /**
                                 * Creates a new DocumentQuerySource instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DocumentQuerySource
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.IDocumentQuerySource=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DocumentQuerySource} DocumentQuerySource instance
                                 */
                                DocumentQuerySource.create = function create(properties) {
                                    return new DocumentQuerySource(properties);
                                };
    
                                /**
                                 * Encodes the specified DocumentQuerySource message. Does not implicitly {@link google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DocumentQuerySource.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DocumentQuerySource
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.IDocumentQuerySource} message DocumentQuerySource message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                DocumentQuerySource.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.documents != null && message.documents.length)
                                        for (var i = 0; i < message.documents.length; ++i)
                                            writer.uint32(/* id 1, wireType 2 =*/10).string(message.documents[i]);
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified DocumentQuerySource message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DocumentQuerySource.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DocumentQuerySource
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.IDocumentQuerySource} message DocumentQuerySource message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                DocumentQuerySource.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a DocumentQuerySource message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DocumentQuerySource
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DocumentQuerySource} DocumentQuerySource
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                DocumentQuerySource.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DocumentQuerySource();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                if (!(message.documents && message.documents.length))
                                                    message.documents = [];
                                                message.documents.push(reader.string());
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a DocumentQuerySource message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DocumentQuerySource
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DocumentQuerySource} DocumentQuerySource
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                DocumentQuerySource.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a DocumentQuerySource message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DocumentQuerySource
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                DocumentQuerySource.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.documents != null && message.hasOwnProperty("documents")) {
                                        if (!Array.isArray(message.documents))
                                            return "documents: array expected";
                                        for (var i = 0; i < message.documents.length; ++i)
                                            if (!$util.isString(message.documents[i]))
                                                return "documents: string[] expected";
                                    }
                                    return null;
                                };
    
                                /**
                                 * Creates a DocumentQuerySource message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DocumentQuerySource
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DocumentQuerySource} DocumentQuerySource
                                 */
                                DocumentQuerySource.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DocumentQuerySource)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DocumentQuerySource();
                                    if (object.documents) {
                                        if (!Array.isArray(object.documents))
                                            throw TypeError(".google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DocumentQuerySource.documents: array expected");
                                        message.documents = [];
                                        for (var i = 0; i < object.documents.length; ++i)
                                            message.documents[i] = String(object.documents[i]);
                                    }
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a DocumentQuerySource message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DocumentQuerySource
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DocumentQuerySource} message DocumentQuerySource
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                DocumentQuerySource.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.arrays || options.defaults)
                                        object.documents = [];
                                    if (message.documents && message.documents.length) {
                                        object.documents = [];
                                        for (var j = 0; j < message.documents.length; ++j)
                                            object.documents[j] = message.documents[j];
                                    }
                                    return object;
                                };
    
                                /**
                                 * Converts this DocumentQuerySource to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DocumentQuerySource
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                DocumentQuerySource.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for DocumentQuerySource
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DocumentQuerySource
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                DocumentQuerySource.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DocumentQuerySource";
                                };
    
                                return DocumentQuerySource;
                            })();
    
                            SuggestionQueryConfig.DialogflowQuerySource = (function() {
    
                                /**
                                 * Properties of a DialogflowQuerySource.
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig
                                 * @interface IDialogflowQuerySource
                                 * @property {string|null} [agent] DialogflowQuerySource agent
                                 * @property {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.IHumanAgentSideConfig|null} [humanAgentSideConfig] DialogflowQuerySource humanAgentSideConfig
                                 */
    
                                /**
                                 * Constructs a new DialogflowQuerySource.
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig
                                 * @classdesc Represents a DialogflowQuerySource.
                                 * @implements IDialogflowQuerySource
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.IDialogflowQuerySource=} [properties] Properties to set
                                 */
                                function DialogflowQuerySource(properties) {
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * DialogflowQuerySource agent.
                                 * @member {string} agent
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource
                                 * @instance
                                 */
                                DialogflowQuerySource.prototype.agent = "";
    
                                /**
                                 * DialogflowQuerySource humanAgentSideConfig.
                                 * @member {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.IHumanAgentSideConfig|null|undefined} humanAgentSideConfig
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource
                                 * @instance
                                 */
                                DialogflowQuerySource.prototype.humanAgentSideConfig = null;
    
                                /**
                                 * Creates a new DialogflowQuerySource instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.IDialogflowQuerySource=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource} DialogflowQuerySource instance
                                 */
                                DialogflowQuerySource.create = function create(properties) {
                                    return new DialogflowQuerySource(properties);
                                };
    
                                /**
                                 * Encodes the specified DialogflowQuerySource message. Does not implicitly {@link google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.IDialogflowQuerySource} message DialogflowQuerySource message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                DialogflowQuerySource.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.agent != null && Object.hasOwnProperty.call(message, "agent"))
                                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.agent);
                                    if (message.humanAgentSideConfig != null && Object.hasOwnProperty.call(message, "humanAgentSideConfig"))
                                        $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.HumanAgentSideConfig.encode(message.humanAgentSideConfig, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified DialogflowQuerySource message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.IDialogflowQuerySource} message DialogflowQuerySource message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                DialogflowQuerySource.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a DialogflowQuerySource message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource} DialogflowQuerySource
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                DialogflowQuerySource.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                message.agent = reader.string();
                                                break;
                                            }
                                        case 3: {
                                                message.humanAgentSideConfig = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.HumanAgentSideConfig.decode(reader, reader.uint32());
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a DialogflowQuerySource message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource} DialogflowQuerySource
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                DialogflowQuerySource.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a DialogflowQuerySource message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                DialogflowQuerySource.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.agent != null && message.hasOwnProperty("agent"))
                                        if (!$util.isString(message.agent))
                                            return "agent: string expected";
                                    if (message.humanAgentSideConfig != null && message.hasOwnProperty("humanAgentSideConfig")) {
                                        var error = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.HumanAgentSideConfig.verify(message.humanAgentSideConfig);
                                        if (error)
                                            return "humanAgentSideConfig." + error;
                                    }
                                    return null;
                                };
    
                                /**
                                 * Creates a DialogflowQuerySource message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource} DialogflowQuerySource
                                 */
                                DialogflowQuerySource.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource();
                                    if (object.agent != null)
                                        message.agent = String(object.agent);
                                    if (object.humanAgentSideConfig != null) {
                                        if (typeof object.humanAgentSideConfig !== "object")
                                            throw TypeError(".google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.humanAgentSideConfig: object expected");
                                        message.humanAgentSideConfig = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.HumanAgentSideConfig.fromObject(object.humanAgentSideConfig);
                                    }
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a DialogflowQuerySource message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource} message DialogflowQuerySource
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                DialogflowQuerySource.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.defaults) {
                                        object.agent = "";
                                        object.humanAgentSideConfig = null;
                                    }
                                    if (message.agent != null && message.hasOwnProperty("agent"))
                                        object.agent = message.agent;
                                    if (message.humanAgentSideConfig != null && message.hasOwnProperty("humanAgentSideConfig"))
                                        object.humanAgentSideConfig = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.HumanAgentSideConfig.toObject(message.humanAgentSideConfig, options);
                                    return object;
                                };
    
                                /**
                                 * Converts this DialogflowQuerySource to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                DialogflowQuerySource.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for DialogflowQuerySource
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                DialogflowQuerySource.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource";
                                };
    
                                DialogflowQuerySource.HumanAgentSideConfig = (function() {
    
                                    /**
                                     * Properties of a HumanAgentSideConfig.
                                     * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource
                                     * @interface IHumanAgentSideConfig
                                     * @property {string|null} [agent] HumanAgentSideConfig agent
                                     */
    
                                    /**
                                     * Constructs a new HumanAgentSideConfig.
                                     * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource
                                     * @classdesc Represents a HumanAgentSideConfig.
                                     * @implements IHumanAgentSideConfig
                                     * @constructor
                                     * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.IHumanAgentSideConfig=} [properties] Properties to set
                                     */
                                    function HumanAgentSideConfig(properties) {
                                        if (properties)
                                            for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                                if (properties[keys[i]] != null)
                                                    this[keys[i]] = properties[keys[i]];
                                    }
    
                                    /**
                                     * HumanAgentSideConfig agent.
                                     * @member {string} agent
                                     * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.HumanAgentSideConfig
                                     * @instance
                                     */
                                    HumanAgentSideConfig.prototype.agent = "";
    
                                    /**
                                     * Creates a new HumanAgentSideConfig instance using the specified properties.
                                     * @function create
                                     * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.HumanAgentSideConfig
                                     * @static
                                     * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.IHumanAgentSideConfig=} [properties] Properties to set
                                     * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.HumanAgentSideConfig} HumanAgentSideConfig instance
                                     */
                                    HumanAgentSideConfig.create = function create(properties) {
                                        return new HumanAgentSideConfig(properties);
                                    };
    
                                    /**
                                     * Encodes the specified HumanAgentSideConfig message. Does not implicitly {@link google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.HumanAgentSideConfig.verify|verify} messages.
                                     * @function encode
                                     * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.HumanAgentSideConfig
                                     * @static
                                     * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.IHumanAgentSideConfig} message HumanAgentSideConfig message or plain object to encode
                                     * @param {$protobuf.Writer} [writer] Writer to encode to
                                     * @returns {$protobuf.Writer} Writer
                                     */
                                    HumanAgentSideConfig.encode = function encode(message, writer) {
                                        if (!writer)
                                            writer = $Writer.create();
                                        if (message.agent != null && Object.hasOwnProperty.call(message, "agent"))
                                            writer.uint32(/* id 1, wireType 2 =*/10).string(message.agent);
                                        return writer;
                                    };
    
                                    /**
                                     * Encodes the specified HumanAgentSideConfig message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.HumanAgentSideConfig.verify|verify} messages.
                                     * @function encodeDelimited
                                     * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.HumanAgentSideConfig
                                     * @static
                                     * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.IHumanAgentSideConfig} message HumanAgentSideConfig message or plain object to encode
                                     * @param {$protobuf.Writer} [writer] Writer to encode to
                                     * @returns {$protobuf.Writer} Writer
                                     */
                                    HumanAgentSideConfig.encodeDelimited = function encodeDelimited(message, writer) {
                                        return this.encode(message, writer).ldelim();
                                    };
    
                                    /**
                                     * Decodes a HumanAgentSideConfig message from the specified reader or buffer.
                                     * @function decode
                                     * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.HumanAgentSideConfig
                                     * @static
                                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                     * @param {number} [length] Message length if known beforehand
                                     * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.HumanAgentSideConfig} HumanAgentSideConfig
                                     * @throws {Error} If the payload is not a reader or valid buffer
                                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                     */
                                    HumanAgentSideConfig.decode = function decode(reader, length) {
                                        if (!(reader instanceof $Reader))
                                            reader = $Reader.create(reader);
                                        var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.HumanAgentSideConfig();
                                        while (reader.pos < end) {
                                            var tag = reader.uint32();
                                            switch (tag >>> 3) {
                                            case 1: {
                                                    message.agent = reader.string();
                                                    break;
                                                }
                                            default:
                                                reader.skipType(tag & 7);
                                                break;
                                            }
                                        }
                                        return message;
                                    };
    
                                    /**
                                     * Decodes a HumanAgentSideConfig message from the specified reader or buffer, length delimited.
                                     * @function decodeDelimited
                                     * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.HumanAgentSideConfig
                                     * @static
                                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                     * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.HumanAgentSideConfig} HumanAgentSideConfig
                                     * @throws {Error} If the payload is not a reader or valid buffer
                                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                     */
                                    HumanAgentSideConfig.decodeDelimited = function decodeDelimited(reader) {
                                        if (!(reader instanceof $Reader))
                                            reader = new $Reader(reader);
                                        return this.decode(reader, reader.uint32());
                                    };
    
                                    /**
                                     * Verifies a HumanAgentSideConfig message.
                                     * @function verify
                                     * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.HumanAgentSideConfig
                                     * @static
                                     * @param {Object.<string,*>} message Plain object to verify
                                     * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                     */
                                    HumanAgentSideConfig.verify = function verify(message) {
                                        if (typeof message !== "object" || message === null)
                                            return "object expected";
                                        if (message.agent != null && message.hasOwnProperty("agent"))
                                            if (!$util.isString(message.agent))
                                                return "agent: string expected";
                                        return null;
                                    };
    
                                    /**
                                     * Creates a HumanAgentSideConfig message from a plain object. Also converts values to their respective internal types.
                                     * @function fromObject
                                     * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.HumanAgentSideConfig
                                     * @static
                                     * @param {Object.<string,*>} object Plain object
                                     * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.HumanAgentSideConfig} HumanAgentSideConfig
                                     */
                                    HumanAgentSideConfig.fromObject = function fromObject(object) {
                                        if (object instanceof $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.HumanAgentSideConfig)
                                            return object;
                                        var message = new $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.HumanAgentSideConfig();
                                        if (object.agent != null)
                                            message.agent = String(object.agent);
                                        return message;
                                    };
    
                                    /**
                                     * Creates a plain object from a HumanAgentSideConfig message. Also converts values to other types if specified.
                                     * @function toObject
                                     * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.HumanAgentSideConfig
                                     * @static
                                     * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.HumanAgentSideConfig} message HumanAgentSideConfig
                                     * @param {$protobuf.IConversionOptions} [options] Conversion options
                                     * @returns {Object.<string,*>} Plain object
                                     */
                                    HumanAgentSideConfig.toObject = function toObject(message, options) {
                                        if (!options)
                                            options = {};
                                        var object = {};
                                        if (options.defaults)
                                            object.agent = "";
                                        if (message.agent != null && message.hasOwnProperty("agent"))
                                            object.agent = message.agent;
                                        return object;
                                    };
    
                                    /**
                                     * Converts this HumanAgentSideConfig to JSON.
                                     * @function toJSON
                                     * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.HumanAgentSideConfig
                                     * @instance
                                     * @returns {Object.<string,*>} JSON object
                                     */
                                    HumanAgentSideConfig.prototype.toJSON = function toJSON() {
                                        return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                    };
    
                                    /**
                                     * Gets the default type url for HumanAgentSideConfig
                                     * @function getTypeUrl
                                     * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.HumanAgentSideConfig
                                     * @static
                                     * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                     * @returns {string} The default type url
                                     */
                                    HumanAgentSideConfig.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                        if (typeUrlPrefix === undefined) {
                                            typeUrlPrefix = "type.googleapis.com";
                                        }
                                        return typeUrlPrefix + "/google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.HumanAgentSideConfig";
                                    };
    
                                    return HumanAgentSideConfig;
                                })();
    
                                return DialogflowQuerySource;
                            })();
    
                            SuggestionQueryConfig.ContextFilterSettings = (function() {
    
                                /**
                                 * Properties of a ContextFilterSettings.
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig
                                 * @interface IContextFilterSettings
                                 * @property {boolean|null} [dropHandoffMessages] ContextFilterSettings dropHandoffMessages
                                 * @property {boolean|null} [dropVirtualAgentMessages] ContextFilterSettings dropVirtualAgentMessages
                                 * @property {boolean|null} [dropIvrMessages] ContextFilterSettings dropIvrMessages
                                 */
    
                                /**
                                 * Constructs a new ContextFilterSettings.
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig
                                 * @classdesc Represents a ContextFilterSettings.
                                 * @implements IContextFilterSettings
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.IContextFilterSettings=} [properties] Properties to set
                                 */
                                function ContextFilterSettings(properties) {
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * ContextFilterSettings dropHandoffMessages.
                                 * @member {boolean} dropHandoffMessages
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings
                                 * @instance
                                 */
                                ContextFilterSettings.prototype.dropHandoffMessages = false;
    
                                /**
                                 * ContextFilterSettings dropVirtualAgentMessages.
                                 * @member {boolean} dropVirtualAgentMessages
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings
                                 * @instance
                                 */
                                ContextFilterSettings.prototype.dropVirtualAgentMessages = false;
    
                                /**
                                 * ContextFilterSettings dropIvrMessages.
                                 * @member {boolean} dropIvrMessages
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings
                                 * @instance
                                 */
                                ContextFilterSettings.prototype.dropIvrMessages = false;
    
                                /**
                                 * Creates a new ContextFilterSettings instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.IContextFilterSettings=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings} ContextFilterSettings instance
                                 */
                                ContextFilterSettings.create = function create(properties) {
                                    return new ContextFilterSettings(properties);
                                };
    
                                /**
                                 * Encodes the specified ContextFilterSettings message. Does not implicitly {@link google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.IContextFilterSettings} message ContextFilterSettings message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                ContextFilterSettings.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.dropHandoffMessages != null && Object.hasOwnProperty.call(message, "dropHandoffMessages"))
                                        writer.uint32(/* id 1, wireType 0 =*/8).bool(message.dropHandoffMessages);
                                    if (message.dropVirtualAgentMessages != null && Object.hasOwnProperty.call(message, "dropVirtualAgentMessages"))
                                        writer.uint32(/* id 2, wireType 0 =*/16).bool(message.dropVirtualAgentMessages);
                                    if (message.dropIvrMessages != null && Object.hasOwnProperty.call(message, "dropIvrMessages"))
                                        writer.uint32(/* id 3, wireType 0 =*/24).bool(message.dropIvrMessages);
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified ContextFilterSettings message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.IContextFilterSettings} message ContextFilterSettings message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                ContextFilterSettings.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a ContextFilterSettings message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings} ContextFilterSettings
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                ContextFilterSettings.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                message.dropHandoffMessages = reader.bool();
                                                break;
                                            }
                                        case 2: {
                                                message.dropVirtualAgentMessages = reader.bool();
                                                break;
                                            }
                                        case 3: {
                                                message.dropIvrMessages = reader.bool();
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a ContextFilterSettings message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings} ContextFilterSettings
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                ContextFilterSettings.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a ContextFilterSettings message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                ContextFilterSettings.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.dropHandoffMessages != null && message.hasOwnProperty("dropHandoffMessages"))
                                        if (typeof message.dropHandoffMessages !== "boolean")
                                            return "dropHandoffMessages: boolean expected";
                                    if (message.dropVirtualAgentMessages != null && message.hasOwnProperty("dropVirtualAgentMessages"))
                                        if (typeof message.dropVirtualAgentMessages !== "boolean")
                                            return "dropVirtualAgentMessages: boolean expected";
                                    if (message.dropIvrMessages != null && message.hasOwnProperty("dropIvrMessages"))
                                        if (typeof message.dropIvrMessages !== "boolean")
                                            return "dropIvrMessages: boolean expected";
                                    return null;
                                };
    
                                /**
                                 * Creates a ContextFilterSettings message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings} ContextFilterSettings
                                 */
                                ContextFilterSettings.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings();
                                    if (object.dropHandoffMessages != null)
                                        message.dropHandoffMessages = Boolean(object.dropHandoffMessages);
                                    if (object.dropVirtualAgentMessages != null)
                                        message.dropVirtualAgentMessages = Boolean(object.dropVirtualAgentMessages);
                                    if (object.dropIvrMessages != null)
                                        message.dropIvrMessages = Boolean(object.dropIvrMessages);
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a ContextFilterSettings message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings} message ContextFilterSettings
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                ContextFilterSettings.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.defaults) {
                                        object.dropHandoffMessages = false;
                                        object.dropVirtualAgentMessages = false;
                                        object.dropIvrMessages = false;
                                    }
                                    if (message.dropHandoffMessages != null && message.hasOwnProperty("dropHandoffMessages"))
                                        object.dropHandoffMessages = message.dropHandoffMessages;
                                    if (message.dropVirtualAgentMessages != null && message.hasOwnProperty("dropVirtualAgentMessages"))
                                        object.dropVirtualAgentMessages = message.dropVirtualAgentMessages;
                                    if (message.dropIvrMessages != null && message.hasOwnProperty("dropIvrMessages"))
                                        object.dropIvrMessages = message.dropIvrMessages;
                                    return object;
                                };
    
                                /**
                                 * Converts this ContextFilterSettings to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                ContextFilterSettings.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for ContextFilterSettings
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                ContextFilterSettings.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings";
                                };
    
                                return ContextFilterSettings;
                            })();
    
                            SuggestionQueryConfig.Sections = (function() {
    
                                /**
                                 * Properties of a Sections.
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig
                                 * @interface ISections
                                 * @property {Array.<google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections.SectionType>|null} [sectionTypes] Sections sectionTypes
                                 */
    
                                /**
                                 * Constructs a new Sections.
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig
                                 * @classdesc Represents a Sections.
                                 * @implements ISections
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.ISections=} [properties] Properties to set
                                 */
                                function Sections(properties) {
                                    this.sectionTypes = [];
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * Sections sectionTypes.
                                 * @member {Array.<google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections.SectionType>} sectionTypes
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections
                                 * @instance
                                 */
                                Sections.prototype.sectionTypes = $util.emptyArray;
    
                                /**
                                 * Creates a new Sections instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.ISections=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections} Sections instance
                                 */
                                Sections.create = function create(properties) {
                                    return new Sections(properties);
                                };
    
                                /**
                                 * Encodes the specified Sections message. Does not implicitly {@link google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.ISections} message Sections message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                Sections.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.sectionTypes != null && message.sectionTypes.length) {
                                        writer.uint32(/* id 1, wireType 2 =*/10).fork();
                                        for (var i = 0; i < message.sectionTypes.length; ++i)
                                            writer.int32(message.sectionTypes[i]);
                                        writer.ldelim();
                                    }
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified Sections message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.ISections} message Sections message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                Sections.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a Sections message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections} Sections
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                Sections.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                if (!(message.sectionTypes && message.sectionTypes.length))
                                                    message.sectionTypes = [];
                                                if ((tag & 7) === 2) {
                                                    var end2 = reader.uint32() + reader.pos;
                                                    while (reader.pos < end2)
                                                        message.sectionTypes.push(reader.int32());
                                                } else
                                                    message.sectionTypes.push(reader.int32());
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a Sections message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections} Sections
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                Sections.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a Sections message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                Sections.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.sectionTypes != null && message.hasOwnProperty("sectionTypes")) {
                                        if (!Array.isArray(message.sectionTypes))
                                            return "sectionTypes: array expected";
                                        for (var i = 0; i < message.sectionTypes.length; ++i)
                                            switch (message.sectionTypes[i]) {
                                            default:
                                                return "sectionTypes: enum value[] expected";
                                            case 0:
                                            case 1:
                                            case 2:
                                            case 3:
                                            case 4:
                                            case 5:
                                            case 6:
                                                break;
                                            }
                                    }
                                    return null;
                                };
    
                                /**
                                 * Creates a Sections message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections} Sections
                                 */
                                Sections.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections();
                                    if (object.sectionTypes) {
                                        if (!Array.isArray(object.sectionTypes))
                                            throw TypeError(".google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections.sectionTypes: array expected");
                                        message.sectionTypes = [];
                                        for (var i = 0; i < object.sectionTypes.length; ++i)
                                            switch (object.sectionTypes[i]) {
                                            default:
                                                if (typeof object.sectionTypes[i] === "number") {
                                                    message.sectionTypes[i] = object.sectionTypes[i];
                                                    break;
                                                }
                                            case "SECTION_TYPE_UNSPECIFIED":
                                            case 0:
                                                message.sectionTypes[i] = 0;
                                                break;
                                            case "SITUATION":
                                            case 1:
                                                message.sectionTypes[i] = 1;
                                                break;
                                            case "ACTION":
                                            case 2:
                                                message.sectionTypes[i] = 2;
                                                break;
                                            case "RESOLUTION":
                                            case 3:
                                                message.sectionTypes[i] = 3;
                                                break;
                                            case "REASON_FOR_CANCELLATION":
                                            case 4:
                                                message.sectionTypes[i] = 4;
                                                break;
                                            case "CUSTOMER_SATISFACTION":
                                            case 5:
                                                message.sectionTypes[i] = 5;
                                                break;
                                            case "ENTITIES":
                                            case 6:
                                                message.sectionTypes[i] = 6;
                                                break;
                                            }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a Sections message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections
                                 * @static
                                 * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections} message Sections
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                Sections.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.arrays || options.defaults)
                                        object.sectionTypes = [];
                                    if (message.sectionTypes && message.sectionTypes.length) {
                                        object.sectionTypes = [];
                                        for (var j = 0; j < message.sectionTypes.length; ++j)
                                            object.sectionTypes[j] = options.enums === String ? $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections.SectionType[message.sectionTypes[j]] === undefined ? message.sectionTypes[j] : $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections.SectionType[message.sectionTypes[j]] : message.sectionTypes[j];
                                    }
                                    return object;
                                };
    
                                /**
                                 * Converts this Sections to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                Sections.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for Sections
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                Sections.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections";
                                };
    
                                /**
                                 * SectionType enum.
                                 * @name google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections.SectionType
                                 * @enum {number}
                                 * @property {number} SECTION_TYPE_UNSPECIFIED=0 SECTION_TYPE_UNSPECIFIED value
                                 * @property {number} SITUATION=1 SITUATION value
                                 * @property {number} ACTION=2 ACTION value
                                 * @property {number} RESOLUTION=3 RESOLUTION value
                                 * @property {number} REASON_FOR_CANCELLATION=4 REASON_FOR_CANCELLATION value
                                 * @property {number} CUSTOMER_SATISFACTION=5 CUSTOMER_SATISFACTION value
                                 * @property {number} ENTITIES=6 ENTITIES value
                                 */
                                Sections.SectionType = (function() {
                                    var valuesById = {}, values = Object.create(valuesById);
                                    values[valuesById[0] = "SECTION_TYPE_UNSPECIFIED"] = 0;
                                    values[valuesById[1] = "SITUATION"] = 1;
                                    values[valuesById[2] = "ACTION"] = 2;
                                    values[valuesById[3] = "RESOLUTION"] = 3;
                                    values[valuesById[4] = "REASON_FOR_CANCELLATION"] = 4;
                                    values[valuesById[5] = "CUSTOMER_SATISFACTION"] = 5;
                                    values[valuesById[6] = "ENTITIES"] = 6;
                                    return values;
                                })();
    
                                return Sections;
                            })();
    
                            return SuggestionQueryConfig;
                        })();
    
                        HumanAgentAssistantConfig.ConversationModelConfig = (function() {
    
                            /**
                             * Properties of a ConversationModelConfig.
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig
                             * @interface IConversationModelConfig
                             * @property {string|null} [model] ConversationModelConfig model
                             * @property {string|null} [baselineModelVersion] ConversationModelConfig baselineModelVersion
                             */
    
                            /**
                             * Constructs a new ConversationModelConfig.
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig
                             * @classdesc Represents a ConversationModelConfig.
                             * @implements IConversationModelConfig
                             * @constructor
                             * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.IConversationModelConfig=} [properties] Properties to set
                             */
                            function ConversationModelConfig(properties) {
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * ConversationModelConfig model.
                             * @member {string} model
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ConversationModelConfig
                             * @instance
                             */
                            ConversationModelConfig.prototype.model = "";
    
                            /**
                             * ConversationModelConfig baselineModelVersion.
                             * @member {string} baselineModelVersion
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ConversationModelConfig
                             * @instance
                             */
                            ConversationModelConfig.prototype.baselineModelVersion = "";
    
                            /**
                             * Creates a new ConversationModelConfig instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ConversationModelConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.IConversationModelConfig=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ConversationModelConfig} ConversationModelConfig instance
                             */
                            ConversationModelConfig.create = function create(properties) {
                                return new ConversationModelConfig(properties);
                            };
    
                            /**
                             * Encodes the specified ConversationModelConfig message. Does not implicitly {@link google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ConversationModelConfig.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ConversationModelConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.IConversationModelConfig} message ConversationModelConfig message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            ConversationModelConfig.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.model != null && Object.hasOwnProperty.call(message, "model"))
                                    writer.uint32(/* id 1, wireType 2 =*/10).string(message.model);
                                if (message.baselineModelVersion != null && Object.hasOwnProperty.call(message, "baselineModelVersion"))
                                    writer.uint32(/* id 8, wireType 2 =*/66).string(message.baselineModelVersion);
                                return writer;
                            };
    
                            /**
                             * Encodes the specified ConversationModelConfig message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ConversationModelConfig.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ConversationModelConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.IConversationModelConfig} message ConversationModelConfig message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            ConversationModelConfig.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a ConversationModelConfig message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ConversationModelConfig
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ConversationModelConfig} ConversationModelConfig
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            ConversationModelConfig.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ConversationModelConfig();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.model = reader.string();
                                            break;
                                        }
                                    case 8: {
                                            message.baselineModelVersion = reader.string();
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a ConversationModelConfig message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ConversationModelConfig
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ConversationModelConfig} ConversationModelConfig
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            ConversationModelConfig.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a ConversationModelConfig message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ConversationModelConfig
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            ConversationModelConfig.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.model != null && message.hasOwnProperty("model"))
                                    if (!$util.isString(message.model))
                                        return "model: string expected";
                                if (message.baselineModelVersion != null && message.hasOwnProperty("baselineModelVersion"))
                                    if (!$util.isString(message.baselineModelVersion))
                                        return "baselineModelVersion: string expected";
                                return null;
                            };
    
                            /**
                             * Creates a ConversationModelConfig message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ConversationModelConfig
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ConversationModelConfig} ConversationModelConfig
                             */
                            ConversationModelConfig.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ConversationModelConfig)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ConversationModelConfig();
                                if (object.model != null)
                                    message.model = String(object.model);
                                if (object.baselineModelVersion != null)
                                    message.baselineModelVersion = String(object.baselineModelVersion);
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a ConversationModelConfig message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ConversationModelConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ConversationModelConfig} message ConversationModelConfig
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            ConversationModelConfig.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.defaults) {
                                    object.model = "";
                                    object.baselineModelVersion = "";
                                }
                                if (message.model != null && message.hasOwnProperty("model"))
                                    object.model = message.model;
                                if (message.baselineModelVersion != null && message.hasOwnProperty("baselineModelVersion"))
                                    object.baselineModelVersion = message.baselineModelVersion;
                                return object;
                            };
    
                            /**
                             * Converts this ConversationModelConfig to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ConversationModelConfig
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            ConversationModelConfig.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for ConversationModelConfig
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ConversationModelConfig
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            ConversationModelConfig.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ConversationModelConfig";
                            };
    
                            return ConversationModelConfig;
                        })();
    
                        HumanAgentAssistantConfig.ConversationProcessConfig = (function() {
    
                            /**
                             * Properties of a ConversationProcessConfig.
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig
                             * @interface IConversationProcessConfig
                             * @property {number|null} [recentSentencesCount] ConversationProcessConfig recentSentencesCount
                             */
    
                            /**
                             * Constructs a new ConversationProcessConfig.
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig
                             * @classdesc Represents a ConversationProcessConfig.
                             * @implements IConversationProcessConfig
                             * @constructor
                             * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.IConversationProcessConfig=} [properties] Properties to set
                             */
                            function ConversationProcessConfig(properties) {
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * ConversationProcessConfig recentSentencesCount.
                             * @member {number} recentSentencesCount
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ConversationProcessConfig
                             * @instance
                             */
                            ConversationProcessConfig.prototype.recentSentencesCount = 0;
    
                            /**
                             * Creates a new ConversationProcessConfig instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ConversationProcessConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.IConversationProcessConfig=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ConversationProcessConfig} ConversationProcessConfig instance
                             */
                            ConversationProcessConfig.create = function create(properties) {
                                return new ConversationProcessConfig(properties);
                            };
    
                            /**
                             * Encodes the specified ConversationProcessConfig message. Does not implicitly {@link google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ConversationProcessConfig.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ConversationProcessConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.IConversationProcessConfig} message ConversationProcessConfig message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            ConversationProcessConfig.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.recentSentencesCount != null && Object.hasOwnProperty.call(message, "recentSentencesCount"))
                                    writer.uint32(/* id 2, wireType 0 =*/16).int32(message.recentSentencesCount);
                                return writer;
                            };
    
                            /**
                             * Encodes the specified ConversationProcessConfig message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ConversationProcessConfig.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ConversationProcessConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.IConversationProcessConfig} message ConversationProcessConfig message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            ConversationProcessConfig.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a ConversationProcessConfig message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ConversationProcessConfig
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ConversationProcessConfig} ConversationProcessConfig
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            ConversationProcessConfig.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ConversationProcessConfig();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 2: {
                                            message.recentSentencesCount = reader.int32();
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a ConversationProcessConfig message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ConversationProcessConfig
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ConversationProcessConfig} ConversationProcessConfig
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            ConversationProcessConfig.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a ConversationProcessConfig message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ConversationProcessConfig
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            ConversationProcessConfig.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.recentSentencesCount != null && message.hasOwnProperty("recentSentencesCount"))
                                    if (!$util.isInteger(message.recentSentencesCount))
                                        return "recentSentencesCount: integer expected";
                                return null;
                            };
    
                            /**
                             * Creates a ConversationProcessConfig message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ConversationProcessConfig
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ConversationProcessConfig} ConversationProcessConfig
                             */
                            ConversationProcessConfig.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ConversationProcessConfig)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ConversationProcessConfig();
                                if (object.recentSentencesCount != null)
                                    message.recentSentencesCount = object.recentSentencesCount | 0;
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a ConversationProcessConfig message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ConversationProcessConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ConversationProcessConfig} message ConversationProcessConfig
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            ConversationProcessConfig.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.defaults)
                                    object.recentSentencesCount = 0;
                                if (message.recentSentencesCount != null && message.hasOwnProperty("recentSentencesCount"))
                                    object.recentSentencesCount = message.recentSentencesCount;
                                return object;
                            };
    
                            /**
                             * Converts this ConversationProcessConfig to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ConversationProcessConfig
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            ConversationProcessConfig.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for ConversationProcessConfig
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ConversationProcessConfig
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            ConversationProcessConfig.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ConversationProcessConfig";
                            };
    
                            return ConversationProcessConfig;
                        })();
    
                        HumanAgentAssistantConfig.MessageAnalysisConfig = (function() {
    
                            /**
                             * Properties of a MessageAnalysisConfig.
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig
                             * @interface IMessageAnalysisConfig
                             * @property {boolean|null} [enableEntityExtraction] MessageAnalysisConfig enableEntityExtraction
                             * @property {boolean|null} [enableSentimentAnalysis] MessageAnalysisConfig enableSentimentAnalysis
                             */
    
                            /**
                             * Constructs a new MessageAnalysisConfig.
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig
                             * @classdesc Represents a MessageAnalysisConfig.
                             * @implements IMessageAnalysisConfig
                             * @constructor
                             * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.IMessageAnalysisConfig=} [properties] Properties to set
                             */
                            function MessageAnalysisConfig(properties) {
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * MessageAnalysisConfig enableEntityExtraction.
                             * @member {boolean} enableEntityExtraction
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.MessageAnalysisConfig
                             * @instance
                             */
                            MessageAnalysisConfig.prototype.enableEntityExtraction = false;
    
                            /**
                             * MessageAnalysisConfig enableSentimentAnalysis.
                             * @member {boolean} enableSentimentAnalysis
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.MessageAnalysisConfig
                             * @instance
                             */
                            MessageAnalysisConfig.prototype.enableSentimentAnalysis = false;
    
                            /**
                             * Creates a new MessageAnalysisConfig instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.MessageAnalysisConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.IMessageAnalysisConfig=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.MessageAnalysisConfig} MessageAnalysisConfig instance
                             */
                            MessageAnalysisConfig.create = function create(properties) {
                                return new MessageAnalysisConfig(properties);
                            };
    
                            /**
                             * Encodes the specified MessageAnalysisConfig message. Does not implicitly {@link google.cloud.dialogflow.v2.HumanAgentAssistantConfig.MessageAnalysisConfig.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.MessageAnalysisConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.IMessageAnalysisConfig} message MessageAnalysisConfig message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            MessageAnalysisConfig.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.enableEntityExtraction != null && Object.hasOwnProperty.call(message, "enableEntityExtraction"))
                                    writer.uint32(/* id 2, wireType 0 =*/16).bool(message.enableEntityExtraction);
                                if (message.enableSentimentAnalysis != null && Object.hasOwnProperty.call(message, "enableSentimentAnalysis"))
                                    writer.uint32(/* id 3, wireType 0 =*/24).bool(message.enableSentimentAnalysis);
                                return writer;
                            };
    
                            /**
                             * Encodes the specified MessageAnalysisConfig message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.HumanAgentAssistantConfig.MessageAnalysisConfig.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.MessageAnalysisConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.IMessageAnalysisConfig} message MessageAnalysisConfig message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            MessageAnalysisConfig.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a MessageAnalysisConfig message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.MessageAnalysisConfig
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.MessageAnalysisConfig} MessageAnalysisConfig
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            MessageAnalysisConfig.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.MessageAnalysisConfig();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 2: {
                                            message.enableEntityExtraction = reader.bool();
                                            break;
                                        }
                                    case 3: {
                                            message.enableSentimentAnalysis = reader.bool();
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a MessageAnalysisConfig message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.MessageAnalysisConfig
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.MessageAnalysisConfig} MessageAnalysisConfig
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            MessageAnalysisConfig.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a MessageAnalysisConfig message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.MessageAnalysisConfig
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            MessageAnalysisConfig.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.enableEntityExtraction != null && message.hasOwnProperty("enableEntityExtraction"))
                                    if (typeof message.enableEntityExtraction !== "boolean")
                                        return "enableEntityExtraction: boolean expected";
                                if (message.enableSentimentAnalysis != null && message.hasOwnProperty("enableSentimentAnalysis"))
                                    if (typeof message.enableSentimentAnalysis !== "boolean")
                                        return "enableSentimentAnalysis: boolean expected";
                                return null;
                            };
    
                            /**
                             * Creates a MessageAnalysisConfig message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.MessageAnalysisConfig
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.MessageAnalysisConfig} MessageAnalysisConfig
                             */
                            MessageAnalysisConfig.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.MessageAnalysisConfig)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.MessageAnalysisConfig();
                                if (object.enableEntityExtraction != null)
                                    message.enableEntityExtraction = Boolean(object.enableEntityExtraction);
                                if (object.enableSentimentAnalysis != null)
                                    message.enableSentimentAnalysis = Boolean(object.enableSentimentAnalysis);
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a MessageAnalysisConfig message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.MessageAnalysisConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.MessageAnalysisConfig} message MessageAnalysisConfig
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            MessageAnalysisConfig.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.defaults) {
                                    object.enableEntityExtraction = false;
                                    object.enableSentimentAnalysis = false;
                                }
                                if (message.enableEntityExtraction != null && message.hasOwnProperty("enableEntityExtraction"))
                                    object.enableEntityExtraction = message.enableEntityExtraction;
                                if (message.enableSentimentAnalysis != null && message.hasOwnProperty("enableSentimentAnalysis"))
                                    object.enableSentimentAnalysis = message.enableSentimentAnalysis;
                                return object;
                            };
    
                            /**
                             * Converts this MessageAnalysisConfig to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.MessageAnalysisConfig
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            MessageAnalysisConfig.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for MessageAnalysisConfig
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantConfig.MessageAnalysisConfig
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            MessageAnalysisConfig.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2.HumanAgentAssistantConfig.MessageAnalysisConfig";
                            };
    
                            return MessageAnalysisConfig;
                        })();
    
                        return HumanAgentAssistantConfig;
                    })();
    
                    v2.HumanAgentHandoffConfig = (function() {
    
                        /**
                         * Properties of a HumanAgentHandoffConfig.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IHumanAgentHandoffConfig
                         * @property {google.cloud.dialogflow.v2.HumanAgentHandoffConfig.ILivePersonConfig|null} [livePersonConfig] HumanAgentHandoffConfig livePersonConfig
                         * @property {google.cloud.dialogflow.v2.HumanAgentHandoffConfig.ISalesforceLiveAgentConfig|null} [salesforceLiveAgentConfig] HumanAgentHandoffConfig salesforceLiveAgentConfig
                         */
    
                        /**
                         * Constructs a new HumanAgentHandoffConfig.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a HumanAgentHandoffConfig.
                         * @implements IHumanAgentHandoffConfig
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IHumanAgentHandoffConfig=} [properties] Properties to set
                         */
                        function HumanAgentHandoffConfig(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * HumanAgentHandoffConfig livePersonConfig.
                         * @member {google.cloud.dialogflow.v2.HumanAgentHandoffConfig.ILivePersonConfig|null|undefined} livePersonConfig
                         * @memberof google.cloud.dialogflow.v2.HumanAgentHandoffConfig
                         * @instance
                         */
                        HumanAgentHandoffConfig.prototype.livePersonConfig = null;
    
                        /**
                         * HumanAgentHandoffConfig salesforceLiveAgentConfig.
                         * @member {google.cloud.dialogflow.v2.HumanAgentHandoffConfig.ISalesforceLiveAgentConfig|null|undefined} salesforceLiveAgentConfig
                         * @memberof google.cloud.dialogflow.v2.HumanAgentHandoffConfig
                         * @instance
                         */
                        HumanAgentHandoffConfig.prototype.salesforceLiveAgentConfig = null;
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * HumanAgentHandoffConfig agentService.
                         * @member {"livePersonConfig"|"salesforceLiveAgentConfig"|undefined} agentService
                         * @memberof google.cloud.dialogflow.v2.HumanAgentHandoffConfig
                         * @instance
                         */
                        Object.defineProperty(HumanAgentHandoffConfig.prototype, "agentService", {
                            get: $util.oneOfGetter($oneOfFields = ["livePersonConfig", "salesforceLiveAgentConfig"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new HumanAgentHandoffConfig instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.HumanAgentHandoffConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2.IHumanAgentHandoffConfig=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.HumanAgentHandoffConfig} HumanAgentHandoffConfig instance
                         */
                        HumanAgentHandoffConfig.create = function create(properties) {
                            return new HumanAgentHandoffConfig(properties);
                        };
    
                        /**
                         * Encodes the specified HumanAgentHandoffConfig message. Does not implicitly {@link google.cloud.dialogflow.v2.HumanAgentHandoffConfig.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.HumanAgentHandoffConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2.IHumanAgentHandoffConfig} message HumanAgentHandoffConfig message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        HumanAgentHandoffConfig.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.livePersonConfig != null && Object.hasOwnProperty.call(message, "livePersonConfig"))
                                $root.google.cloud.dialogflow.v2.HumanAgentHandoffConfig.LivePersonConfig.encode(message.livePersonConfig, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.salesforceLiveAgentConfig != null && Object.hasOwnProperty.call(message, "salesforceLiveAgentConfig"))
                                $root.google.cloud.dialogflow.v2.HumanAgentHandoffConfig.SalesforceLiveAgentConfig.encode(message.salesforceLiveAgentConfig, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified HumanAgentHandoffConfig message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.HumanAgentHandoffConfig.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.HumanAgentHandoffConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2.IHumanAgentHandoffConfig} message HumanAgentHandoffConfig message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        HumanAgentHandoffConfig.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a HumanAgentHandoffConfig message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.HumanAgentHandoffConfig
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.HumanAgentHandoffConfig} HumanAgentHandoffConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        HumanAgentHandoffConfig.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.HumanAgentHandoffConfig();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.livePersonConfig = $root.google.cloud.dialogflow.v2.HumanAgentHandoffConfig.LivePersonConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.salesforceLiveAgentConfig = $root.google.cloud.dialogflow.v2.HumanAgentHandoffConfig.SalesforceLiveAgentConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a HumanAgentHandoffConfig message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.HumanAgentHandoffConfig
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.HumanAgentHandoffConfig} HumanAgentHandoffConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        HumanAgentHandoffConfig.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a HumanAgentHandoffConfig message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.HumanAgentHandoffConfig
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        HumanAgentHandoffConfig.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.livePersonConfig != null && message.hasOwnProperty("livePersonConfig")) {
                                properties.agentService = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2.HumanAgentHandoffConfig.LivePersonConfig.verify(message.livePersonConfig);
                                    if (error)
                                        return "livePersonConfig." + error;
                                }
                            }
                            if (message.salesforceLiveAgentConfig != null && message.hasOwnProperty("salesforceLiveAgentConfig")) {
                                if (properties.agentService === 1)
                                    return "agentService: multiple values";
                                properties.agentService = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2.HumanAgentHandoffConfig.SalesforceLiveAgentConfig.verify(message.salesforceLiveAgentConfig);
                                    if (error)
                                        return "salesforceLiveAgentConfig." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates a HumanAgentHandoffConfig message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.HumanAgentHandoffConfig
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.HumanAgentHandoffConfig} HumanAgentHandoffConfig
                         */
                        HumanAgentHandoffConfig.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.HumanAgentHandoffConfig)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.HumanAgentHandoffConfig();
                            if (object.livePersonConfig != null) {
                                if (typeof object.livePersonConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.HumanAgentHandoffConfig.livePersonConfig: object expected");
                                message.livePersonConfig = $root.google.cloud.dialogflow.v2.HumanAgentHandoffConfig.LivePersonConfig.fromObject(object.livePersonConfig);
                            }
                            if (object.salesforceLiveAgentConfig != null) {
                                if (typeof object.salesforceLiveAgentConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.HumanAgentHandoffConfig.salesforceLiveAgentConfig: object expected");
                                message.salesforceLiveAgentConfig = $root.google.cloud.dialogflow.v2.HumanAgentHandoffConfig.SalesforceLiveAgentConfig.fromObject(object.salesforceLiveAgentConfig);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a HumanAgentHandoffConfig message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.HumanAgentHandoffConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2.HumanAgentHandoffConfig} message HumanAgentHandoffConfig
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        HumanAgentHandoffConfig.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (message.livePersonConfig != null && message.hasOwnProperty("livePersonConfig")) {
                                object.livePersonConfig = $root.google.cloud.dialogflow.v2.HumanAgentHandoffConfig.LivePersonConfig.toObject(message.livePersonConfig, options);
                                if (options.oneofs)
                                    object.agentService = "livePersonConfig";
                            }
                            if (message.salesforceLiveAgentConfig != null && message.hasOwnProperty("salesforceLiveAgentConfig")) {
                                object.salesforceLiveAgentConfig = $root.google.cloud.dialogflow.v2.HumanAgentHandoffConfig.SalesforceLiveAgentConfig.toObject(message.salesforceLiveAgentConfig, options);
                                if (options.oneofs)
                                    object.agentService = "salesforceLiveAgentConfig";
                            }
                            return object;
                        };
    
                        /**
                         * Converts this HumanAgentHandoffConfig to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.HumanAgentHandoffConfig
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        HumanAgentHandoffConfig.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for HumanAgentHandoffConfig
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.HumanAgentHandoffConfig
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        HumanAgentHandoffConfig.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.HumanAgentHandoffConfig";
                        };
    
                        HumanAgentHandoffConfig.LivePersonConfig = (function() {
    
                            /**
                             * Properties of a LivePersonConfig.
                             * @memberof google.cloud.dialogflow.v2.HumanAgentHandoffConfig
                             * @interface ILivePersonConfig
                             * @property {string|null} [accountNumber] LivePersonConfig accountNumber
                             */
    
                            /**
                             * Constructs a new LivePersonConfig.
                             * @memberof google.cloud.dialogflow.v2.HumanAgentHandoffConfig
                             * @classdesc Represents a LivePersonConfig.
                             * @implements ILivePersonConfig
                             * @constructor
                             * @param {google.cloud.dialogflow.v2.HumanAgentHandoffConfig.ILivePersonConfig=} [properties] Properties to set
                             */
                            function LivePersonConfig(properties) {
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * LivePersonConfig accountNumber.
                             * @member {string} accountNumber
                             * @memberof google.cloud.dialogflow.v2.HumanAgentHandoffConfig.LivePersonConfig
                             * @instance
                             */
                            LivePersonConfig.prototype.accountNumber = "";
    
                            /**
                             * Creates a new LivePersonConfig instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2.HumanAgentHandoffConfig.LivePersonConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2.HumanAgentHandoffConfig.ILivePersonConfig=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2.HumanAgentHandoffConfig.LivePersonConfig} LivePersonConfig instance
                             */
                            LivePersonConfig.create = function create(properties) {
                                return new LivePersonConfig(properties);
                            };
    
                            /**
                             * Encodes the specified LivePersonConfig message. Does not implicitly {@link google.cloud.dialogflow.v2.HumanAgentHandoffConfig.LivePersonConfig.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2.HumanAgentHandoffConfig.LivePersonConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2.HumanAgentHandoffConfig.ILivePersonConfig} message LivePersonConfig message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            LivePersonConfig.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.accountNumber != null && Object.hasOwnProperty.call(message, "accountNumber"))
                                    writer.uint32(/* id 1, wireType 2 =*/10).string(message.accountNumber);
                                return writer;
                            };
    
                            /**
                             * Encodes the specified LivePersonConfig message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.HumanAgentHandoffConfig.LivePersonConfig.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2.HumanAgentHandoffConfig.LivePersonConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2.HumanAgentHandoffConfig.ILivePersonConfig} message LivePersonConfig message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            LivePersonConfig.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a LivePersonConfig message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2.HumanAgentHandoffConfig.LivePersonConfig
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2.HumanAgentHandoffConfig.LivePersonConfig} LivePersonConfig
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            LivePersonConfig.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.HumanAgentHandoffConfig.LivePersonConfig();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.accountNumber = reader.string();
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a LivePersonConfig message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2.HumanAgentHandoffConfig.LivePersonConfig
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2.HumanAgentHandoffConfig.LivePersonConfig} LivePersonConfig
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            LivePersonConfig.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a LivePersonConfig message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2.HumanAgentHandoffConfig.LivePersonConfig
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            LivePersonConfig.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.accountNumber != null && message.hasOwnProperty("accountNumber"))
                                    if (!$util.isString(message.accountNumber))
                                        return "accountNumber: string expected";
                                return null;
                            };
    
                            /**
                             * Creates a LivePersonConfig message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2.HumanAgentHandoffConfig.LivePersonConfig
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2.HumanAgentHandoffConfig.LivePersonConfig} LivePersonConfig
                             */
                            LivePersonConfig.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2.HumanAgentHandoffConfig.LivePersonConfig)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2.HumanAgentHandoffConfig.LivePersonConfig();
                                if (object.accountNumber != null)
                                    message.accountNumber = String(object.accountNumber);
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a LivePersonConfig message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2.HumanAgentHandoffConfig.LivePersonConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2.HumanAgentHandoffConfig.LivePersonConfig} message LivePersonConfig
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            LivePersonConfig.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.defaults)
                                    object.accountNumber = "";
                                if (message.accountNumber != null && message.hasOwnProperty("accountNumber"))
                                    object.accountNumber = message.accountNumber;
                                return object;
                            };
    
                            /**
                             * Converts this LivePersonConfig to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2.HumanAgentHandoffConfig.LivePersonConfig
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            LivePersonConfig.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for LivePersonConfig
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2.HumanAgentHandoffConfig.LivePersonConfig
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            LivePersonConfig.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2.HumanAgentHandoffConfig.LivePersonConfig";
                            };
    
                            return LivePersonConfig;
                        })();
    
                        HumanAgentHandoffConfig.SalesforceLiveAgentConfig = (function() {
    
                            /**
                             * Properties of a SalesforceLiveAgentConfig.
                             * @memberof google.cloud.dialogflow.v2.HumanAgentHandoffConfig
                             * @interface ISalesforceLiveAgentConfig
                             * @property {string|null} [organizationId] SalesforceLiveAgentConfig organizationId
                             * @property {string|null} [deploymentId] SalesforceLiveAgentConfig deploymentId
                             * @property {string|null} [buttonId] SalesforceLiveAgentConfig buttonId
                             * @property {string|null} [endpointDomain] SalesforceLiveAgentConfig endpointDomain
                             */
    
                            /**
                             * Constructs a new SalesforceLiveAgentConfig.
                             * @memberof google.cloud.dialogflow.v2.HumanAgentHandoffConfig
                             * @classdesc Represents a SalesforceLiveAgentConfig.
                             * @implements ISalesforceLiveAgentConfig
                             * @constructor
                             * @param {google.cloud.dialogflow.v2.HumanAgentHandoffConfig.ISalesforceLiveAgentConfig=} [properties] Properties to set
                             */
                            function SalesforceLiveAgentConfig(properties) {
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * SalesforceLiveAgentConfig organizationId.
                             * @member {string} organizationId
                             * @memberof google.cloud.dialogflow.v2.HumanAgentHandoffConfig.SalesforceLiveAgentConfig
                             * @instance
                             */
                            SalesforceLiveAgentConfig.prototype.organizationId = "";
    
                            /**
                             * SalesforceLiveAgentConfig deploymentId.
                             * @member {string} deploymentId
                             * @memberof google.cloud.dialogflow.v2.HumanAgentHandoffConfig.SalesforceLiveAgentConfig
                             * @instance
                             */
                            SalesforceLiveAgentConfig.prototype.deploymentId = "";
    
                            /**
                             * SalesforceLiveAgentConfig buttonId.
                             * @member {string} buttonId
                             * @memberof google.cloud.dialogflow.v2.HumanAgentHandoffConfig.SalesforceLiveAgentConfig
                             * @instance
                             */
                            SalesforceLiveAgentConfig.prototype.buttonId = "";
    
                            /**
                             * SalesforceLiveAgentConfig endpointDomain.
                             * @member {string} endpointDomain
                             * @memberof google.cloud.dialogflow.v2.HumanAgentHandoffConfig.SalesforceLiveAgentConfig
                             * @instance
                             */
                            SalesforceLiveAgentConfig.prototype.endpointDomain = "";
    
                            /**
                             * Creates a new SalesforceLiveAgentConfig instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2.HumanAgentHandoffConfig.SalesforceLiveAgentConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2.HumanAgentHandoffConfig.ISalesforceLiveAgentConfig=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2.HumanAgentHandoffConfig.SalesforceLiveAgentConfig} SalesforceLiveAgentConfig instance
                             */
                            SalesforceLiveAgentConfig.create = function create(properties) {
                                return new SalesforceLiveAgentConfig(properties);
                            };
    
                            /**
                             * Encodes the specified SalesforceLiveAgentConfig message. Does not implicitly {@link google.cloud.dialogflow.v2.HumanAgentHandoffConfig.SalesforceLiveAgentConfig.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2.HumanAgentHandoffConfig.SalesforceLiveAgentConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2.HumanAgentHandoffConfig.ISalesforceLiveAgentConfig} message SalesforceLiveAgentConfig message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            SalesforceLiveAgentConfig.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.organizationId != null && Object.hasOwnProperty.call(message, "organizationId"))
                                    writer.uint32(/* id 1, wireType 2 =*/10).string(message.organizationId);
                                if (message.deploymentId != null && Object.hasOwnProperty.call(message, "deploymentId"))
                                    writer.uint32(/* id 2, wireType 2 =*/18).string(message.deploymentId);
                                if (message.buttonId != null && Object.hasOwnProperty.call(message, "buttonId"))
                                    writer.uint32(/* id 3, wireType 2 =*/26).string(message.buttonId);
                                if (message.endpointDomain != null && Object.hasOwnProperty.call(message, "endpointDomain"))
                                    writer.uint32(/* id 4, wireType 2 =*/34).string(message.endpointDomain);
                                return writer;
                            };
    
                            /**
                             * Encodes the specified SalesforceLiveAgentConfig message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.HumanAgentHandoffConfig.SalesforceLiveAgentConfig.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2.HumanAgentHandoffConfig.SalesforceLiveAgentConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2.HumanAgentHandoffConfig.ISalesforceLiveAgentConfig} message SalesforceLiveAgentConfig message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            SalesforceLiveAgentConfig.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a SalesforceLiveAgentConfig message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2.HumanAgentHandoffConfig.SalesforceLiveAgentConfig
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2.HumanAgentHandoffConfig.SalesforceLiveAgentConfig} SalesforceLiveAgentConfig
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            SalesforceLiveAgentConfig.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.HumanAgentHandoffConfig.SalesforceLiveAgentConfig();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.organizationId = reader.string();
                                            break;
                                        }
                                    case 2: {
                                            message.deploymentId = reader.string();
                                            break;
                                        }
                                    case 3: {
                                            message.buttonId = reader.string();
                                            break;
                                        }
                                    case 4: {
                                            message.endpointDomain = reader.string();
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a SalesforceLiveAgentConfig message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2.HumanAgentHandoffConfig.SalesforceLiveAgentConfig
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2.HumanAgentHandoffConfig.SalesforceLiveAgentConfig} SalesforceLiveAgentConfig
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            SalesforceLiveAgentConfig.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a SalesforceLiveAgentConfig message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2.HumanAgentHandoffConfig.SalesforceLiveAgentConfig
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            SalesforceLiveAgentConfig.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.organizationId != null && message.hasOwnProperty("organizationId"))
                                    if (!$util.isString(message.organizationId))
                                        return "organizationId: string expected";
                                if (message.deploymentId != null && message.hasOwnProperty("deploymentId"))
                                    if (!$util.isString(message.deploymentId))
                                        return "deploymentId: string expected";
                                if (message.buttonId != null && message.hasOwnProperty("buttonId"))
                                    if (!$util.isString(message.buttonId))
                                        return "buttonId: string expected";
                                if (message.endpointDomain != null && message.hasOwnProperty("endpointDomain"))
                                    if (!$util.isString(message.endpointDomain))
                                        return "endpointDomain: string expected";
                                return null;
                            };
    
                            /**
                             * Creates a SalesforceLiveAgentConfig message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2.HumanAgentHandoffConfig.SalesforceLiveAgentConfig
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2.HumanAgentHandoffConfig.SalesforceLiveAgentConfig} SalesforceLiveAgentConfig
                             */
                            SalesforceLiveAgentConfig.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2.HumanAgentHandoffConfig.SalesforceLiveAgentConfig)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2.HumanAgentHandoffConfig.SalesforceLiveAgentConfig();
                                if (object.organizationId != null)
                                    message.organizationId = String(object.organizationId);
                                if (object.deploymentId != null)
                                    message.deploymentId = String(object.deploymentId);
                                if (object.buttonId != null)
                                    message.buttonId = String(object.buttonId);
                                if (object.endpointDomain != null)
                                    message.endpointDomain = String(object.endpointDomain);
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a SalesforceLiveAgentConfig message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2.HumanAgentHandoffConfig.SalesforceLiveAgentConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2.HumanAgentHandoffConfig.SalesforceLiveAgentConfig} message SalesforceLiveAgentConfig
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            SalesforceLiveAgentConfig.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.defaults) {
                                    object.organizationId = "";
                                    object.deploymentId = "";
                                    object.buttonId = "";
                                    object.endpointDomain = "";
                                }
                                if (message.organizationId != null && message.hasOwnProperty("organizationId"))
                                    object.organizationId = message.organizationId;
                                if (message.deploymentId != null && message.hasOwnProperty("deploymentId"))
                                    object.deploymentId = message.deploymentId;
                                if (message.buttonId != null && message.hasOwnProperty("buttonId"))
                                    object.buttonId = message.buttonId;
                                if (message.endpointDomain != null && message.hasOwnProperty("endpointDomain"))
                                    object.endpointDomain = message.endpointDomain;
                                return object;
                            };
    
                            /**
                             * Converts this SalesforceLiveAgentConfig to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2.HumanAgentHandoffConfig.SalesforceLiveAgentConfig
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            SalesforceLiveAgentConfig.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for SalesforceLiveAgentConfig
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2.HumanAgentHandoffConfig.SalesforceLiveAgentConfig
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            SalesforceLiveAgentConfig.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2.HumanAgentHandoffConfig.SalesforceLiveAgentConfig";
                            };
    
                            return SalesforceLiveAgentConfig;
                        })();
    
                        return HumanAgentHandoffConfig;
                    })();
    
                    v2.NotificationConfig = (function() {
    
                        /**
                         * Properties of a NotificationConfig.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface INotificationConfig
                         * @property {string|null} [topic] NotificationConfig topic
                         * @property {google.cloud.dialogflow.v2.NotificationConfig.MessageFormat|null} [messageFormat] NotificationConfig messageFormat
                         */
    
                        /**
                         * Constructs a new NotificationConfig.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a NotificationConfig.
                         * @implements INotificationConfig
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.INotificationConfig=} [properties] Properties to set
                         */
                        function NotificationConfig(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * NotificationConfig topic.
                         * @member {string} topic
                         * @memberof google.cloud.dialogflow.v2.NotificationConfig
                         * @instance
                         */
                        NotificationConfig.prototype.topic = "";
    
                        /**
                         * NotificationConfig messageFormat.
                         * @member {google.cloud.dialogflow.v2.NotificationConfig.MessageFormat} messageFormat
                         * @memberof google.cloud.dialogflow.v2.NotificationConfig
                         * @instance
                         */
                        NotificationConfig.prototype.messageFormat = 0;
    
                        /**
                         * Creates a new NotificationConfig instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.NotificationConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2.INotificationConfig=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.NotificationConfig} NotificationConfig instance
                         */
                        NotificationConfig.create = function create(properties) {
                            return new NotificationConfig(properties);
                        };
    
                        /**
                         * Encodes the specified NotificationConfig message. Does not implicitly {@link google.cloud.dialogflow.v2.NotificationConfig.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.NotificationConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2.INotificationConfig} message NotificationConfig message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        NotificationConfig.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.topic != null && Object.hasOwnProperty.call(message, "topic"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.topic);
                            if (message.messageFormat != null && Object.hasOwnProperty.call(message, "messageFormat"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.messageFormat);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified NotificationConfig message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.NotificationConfig.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.NotificationConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2.INotificationConfig} message NotificationConfig message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        NotificationConfig.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a NotificationConfig message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.NotificationConfig
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.NotificationConfig} NotificationConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        NotificationConfig.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.NotificationConfig();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.topic = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.messageFormat = reader.int32();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a NotificationConfig message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.NotificationConfig
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.NotificationConfig} NotificationConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        NotificationConfig.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a NotificationConfig message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.NotificationConfig
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        NotificationConfig.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.topic != null && message.hasOwnProperty("topic"))
                                if (!$util.isString(message.topic))
                                    return "topic: string expected";
                            if (message.messageFormat != null && message.hasOwnProperty("messageFormat"))
                                switch (message.messageFormat) {
                                default:
                                    return "messageFormat: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                    break;
                                }
                            return null;
                        };
    
                        /**
                         * Creates a NotificationConfig message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.NotificationConfig
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.NotificationConfig} NotificationConfig
                         */
                        NotificationConfig.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.NotificationConfig)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.NotificationConfig();
                            if (object.topic != null)
                                message.topic = String(object.topic);
                            switch (object.messageFormat) {
                            default:
                                if (typeof object.messageFormat === "number") {
                                    message.messageFormat = object.messageFormat;
                                    break;
                                }
                                break;
                            case "MESSAGE_FORMAT_UNSPECIFIED":
                            case 0:
                                message.messageFormat = 0;
                                break;
                            case "PROTO":
                            case 1:
                                message.messageFormat = 1;
                                break;
                            case "JSON":
                            case 2:
                                message.messageFormat = 2;
                                break;
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a NotificationConfig message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.NotificationConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2.NotificationConfig} message NotificationConfig
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        NotificationConfig.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.topic = "";
                                object.messageFormat = options.enums === String ? "MESSAGE_FORMAT_UNSPECIFIED" : 0;
                            }
                            if (message.topic != null && message.hasOwnProperty("topic"))
                                object.topic = message.topic;
                            if (message.messageFormat != null && message.hasOwnProperty("messageFormat"))
                                object.messageFormat = options.enums === String ? $root.google.cloud.dialogflow.v2.NotificationConfig.MessageFormat[message.messageFormat] === undefined ? message.messageFormat : $root.google.cloud.dialogflow.v2.NotificationConfig.MessageFormat[message.messageFormat] : message.messageFormat;
                            return object;
                        };
    
                        /**
                         * Converts this NotificationConfig to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.NotificationConfig
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        NotificationConfig.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for NotificationConfig
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.NotificationConfig
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        NotificationConfig.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.NotificationConfig";
                        };
    
                        /**
                         * MessageFormat enum.
                         * @name google.cloud.dialogflow.v2.NotificationConfig.MessageFormat
                         * @enum {number}
                         * @property {number} MESSAGE_FORMAT_UNSPECIFIED=0 MESSAGE_FORMAT_UNSPECIFIED value
                         * @property {number} PROTO=1 PROTO value
                         * @property {number} JSON=2 JSON value
                         */
                        NotificationConfig.MessageFormat = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "MESSAGE_FORMAT_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "PROTO"] = 1;
                            values[valuesById[2] = "JSON"] = 2;
                            return values;
                        })();
    
                        return NotificationConfig;
                    })();
    
                    v2.LoggingConfig = (function() {
    
                        /**
                         * Properties of a LoggingConfig.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ILoggingConfig
                         * @property {boolean|null} [enableStackdriverLogging] LoggingConfig enableStackdriverLogging
                         */
    
                        /**
                         * Constructs a new LoggingConfig.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a LoggingConfig.
                         * @implements ILoggingConfig
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ILoggingConfig=} [properties] Properties to set
                         */
                        function LoggingConfig(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * LoggingConfig enableStackdriverLogging.
                         * @member {boolean} enableStackdriverLogging
                         * @memberof google.cloud.dialogflow.v2.LoggingConfig
                         * @instance
                         */
                        LoggingConfig.prototype.enableStackdriverLogging = false;
    
                        /**
                         * Creates a new LoggingConfig instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.LoggingConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2.ILoggingConfig=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.LoggingConfig} LoggingConfig instance
                         */
                        LoggingConfig.create = function create(properties) {
                            return new LoggingConfig(properties);
                        };
    
                        /**
                         * Encodes the specified LoggingConfig message. Does not implicitly {@link google.cloud.dialogflow.v2.LoggingConfig.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.LoggingConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2.ILoggingConfig} message LoggingConfig message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        LoggingConfig.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.enableStackdriverLogging != null && Object.hasOwnProperty.call(message, "enableStackdriverLogging"))
                                writer.uint32(/* id 3, wireType 0 =*/24).bool(message.enableStackdriverLogging);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified LoggingConfig message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.LoggingConfig.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.LoggingConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2.ILoggingConfig} message LoggingConfig message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        LoggingConfig.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a LoggingConfig message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.LoggingConfig
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.LoggingConfig} LoggingConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        LoggingConfig.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.LoggingConfig();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 3: {
                                        message.enableStackdriverLogging = reader.bool();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a LoggingConfig message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.LoggingConfig
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.LoggingConfig} LoggingConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        LoggingConfig.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a LoggingConfig message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.LoggingConfig
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        LoggingConfig.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.enableStackdriverLogging != null && message.hasOwnProperty("enableStackdriverLogging"))
                                if (typeof message.enableStackdriverLogging !== "boolean")
                                    return "enableStackdriverLogging: boolean expected";
                            return null;
                        };
    
                        /**
                         * Creates a LoggingConfig message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.LoggingConfig
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.LoggingConfig} LoggingConfig
                         */
                        LoggingConfig.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.LoggingConfig)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.LoggingConfig();
                            if (object.enableStackdriverLogging != null)
                                message.enableStackdriverLogging = Boolean(object.enableStackdriverLogging);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a LoggingConfig message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.LoggingConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2.LoggingConfig} message LoggingConfig
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        LoggingConfig.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.enableStackdriverLogging = false;
                            if (message.enableStackdriverLogging != null && message.hasOwnProperty("enableStackdriverLogging"))
                                object.enableStackdriverLogging = message.enableStackdriverLogging;
                            return object;
                        };
    
                        /**
                         * Converts this LoggingConfig to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.LoggingConfig
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        LoggingConfig.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for LoggingConfig
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.LoggingConfig
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        LoggingConfig.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.LoggingConfig";
                        };
    
                        return LoggingConfig;
                    })();
    
                    v2.SuggestionFeature = (function() {
    
                        /**
                         * Properties of a SuggestionFeature.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ISuggestionFeature
                         * @property {google.cloud.dialogflow.v2.SuggestionFeature.Type|null} [type] SuggestionFeature type
                         */
    
                        /**
                         * Constructs a new SuggestionFeature.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a SuggestionFeature.
                         * @implements ISuggestionFeature
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ISuggestionFeature=} [properties] Properties to set
                         */
                        function SuggestionFeature(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SuggestionFeature type.
                         * @member {google.cloud.dialogflow.v2.SuggestionFeature.Type} type
                         * @memberof google.cloud.dialogflow.v2.SuggestionFeature
                         * @instance
                         */
                        SuggestionFeature.prototype.type = 0;
    
                        /**
                         * Creates a new SuggestionFeature instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.SuggestionFeature
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISuggestionFeature=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.SuggestionFeature} SuggestionFeature instance
                         */
                        SuggestionFeature.create = function create(properties) {
                            return new SuggestionFeature(properties);
                        };
    
                        /**
                         * Encodes the specified SuggestionFeature message. Does not implicitly {@link google.cloud.dialogflow.v2.SuggestionFeature.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.SuggestionFeature
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISuggestionFeature} message SuggestionFeature message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SuggestionFeature.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.type != null && Object.hasOwnProperty.call(message, "type"))
                                writer.uint32(/* id 1, wireType 0 =*/8).int32(message.type);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SuggestionFeature message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.SuggestionFeature.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SuggestionFeature
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISuggestionFeature} message SuggestionFeature message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SuggestionFeature.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SuggestionFeature message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.SuggestionFeature
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.SuggestionFeature} SuggestionFeature
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SuggestionFeature.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.SuggestionFeature();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.type = reader.int32();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SuggestionFeature message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SuggestionFeature
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.SuggestionFeature} SuggestionFeature
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SuggestionFeature.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SuggestionFeature message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.SuggestionFeature
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SuggestionFeature.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.type != null && message.hasOwnProperty("type"))
                                switch (message.type) {
                                default:
                                    return "type: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                case 8:
                                case 14:
                                case 15:
                                    break;
                                }
                            return null;
                        };
    
                        /**
                         * Creates a SuggestionFeature message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.SuggestionFeature
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.SuggestionFeature} SuggestionFeature
                         */
                        SuggestionFeature.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.SuggestionFeature)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.SuggestionFeature();
                            switch (object.type) {
                            default:
                                if (typeof object.type === "number") {
                                    message.type = object.type;
                                    break;
                                }
                                break;
                            case "TYPE_UNSPECIFIED":
                            case 0:
                                message.type = 0;
                                break;
                            case "ARTICLE_SUGGESTION":
                            case 1:
                                message.type = 1;
                                break;
                            case "FAQ":
                            case 2:
                                message.type = 2;
                                break;
                            case "SMART_REPLY":
                            case 3:
                                message.type = 3;
                                break;
                            case "CONVERSATION_SUMMARIZATION":
                            case 8:
                                message.type = 8;
                                break;
                            case "KNOWLEDGE_SEARCH":
                            case 14:
                                message.type = 14;
                                break;
                            case "KNOWLEDGE_ASSIST":
                            case 15:
                                message.type = 15;
                                break;
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SuggestionFeature message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.SuggestionFeature
                         * @static
                         * @param {google.cloud.dialogflow.v2.SuggestionFeature} message SuggestionFeature
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SuggestionFeature.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.type = options.enums === String ? "TYPE_UNSPECIFIED" : 0;
                            if (message.type != null && message.hasOwnProperty("type"))
                                object.type = options.enums === String ? $root.google.cloud.dialogflow.v2.SuggestionFeature.Type[message.type] === undefined ? message.type : $root.google.cloud.dialogflow.v2.SuggestionFeature.Type[message.type] : message.type;
                            return object;
                        };
    
                        /**
                         * Converts this SuggestionFeature to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.SuggestionFeature
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SuggestionFeature.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SuggestionFeature
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.SuggestionFeature
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SuggestionFeature.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.SuggestionFeature";
                        };
    
                        /**
                         * Type enum.
                         * @name google.cloud.dialogflow.v2.SuggestionFeature.Type
                         * @enum {number}
                         * @property {number} TYPE_UNSPECIFIED=0 TYPE_UNSPECIFIED value
                         * @property {number} ARTICLE_SUGGESTION=1 ARTICLE_SUGGESTION value
                         * @property {number} FAQ=2 FAQ value
                         * @property {number} SMART_REPLY=3 SMART_REPLY value
                         * @property {number} CONVERSATION_SUMMARIZATION=8 CONVERSATION_SUMMARIZATION value
                         * @property {number} KNOWLEDGE_SEARCH=14 KNOWLEDGE_SEARCH value
                         * @property {number} KNOWLEDGE_ASSIST=15 KNOWLEDGE_ASSIST value
                         */
                        SuggestionFeature.Type = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "TYPE_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "ARTICLE_SUGGESTION"] = 1;
                            values[valuesById[2] = "FAQ"] = 2;
                            values[valuesById[3] = "SMART_REPLY"] = 3;
                            values[valuesById[8] = "CONVERSATION_SUMMARIZATION"] = 8;
                            values[valuesById[14] = "KNOWLEDGE_SEARCH"] = 14;
                            values[valuesById[15] = "KNOWLEDGE_ASSIST"] = 15;
                            return values;
                        })();
    
                        return SuggestionFeature;
                    })();
    
                    v2.SetSuggestionFeatureConfigRequest = (function() {
    
                        /**
                         * Properties of a SetSuggestionFeatureConfigRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ISetSuggestionFeatureConfigRequest
                         * @property {string|null} [conversationProfile] SetSuggestionFeatureConfigRequest conversationProfile
                         * @property {google.cloud.dialogflow.v2.Participant.Role|null} [participantRole] SetSuggestionFeatureConfigRequest participantRole
                         * @property {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ISuggestionFeatureConfig|null} [suggestionFeatureConfig] SetSuggestionFeatureConfigRequest suggestionFeatureConfig
                         */
    
                        /**
                         * Constructs a new SetSuggestionFeatureConfigRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a SetSuggestionFeatureConfigRequest.
                         * @implements ISetSuggestionFeatureConfigRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ISetSuggestionFeatureConfigRequest=} [properties] Properties to set
                         */
                        function SetSuggestionFeatureConfigRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SetSuggestionFeatureConfigRequest conversationProfile.
                         * @member {string} conversationProfile
                         * @memberof google.cloud.dialogflow.v2.SetSuggestionFeatureConfigRequest
                         * @instance
                         */
                        SetSuggestionFeatureConfigRequest.prototype.conversationProfile = "";
    
                        /**
                         * SetSuggestionFeatureConfigRequest participantRole.
                         * @member {google.cloud.dialogflow.v2.Participant.Role} participantRole
                         * @memberof google.cloud.dialogflow.v2.SetSuggestionFeatureConfigRequest
                         * @instance
                         */
                        SetSuggestionFeatureConfigRequest.prototype.participantRole = 0;
    
                        /**
                         * SetSuggestionFeatureConfigRequest suggestionFeatureConfig.
                         * @member {google.cloud.dialogflow.v2.HumanAgentAssistantConfig.ISuggestionFeatureConfig|null|undefined} suggestionFeatureConfig
                         * @memberof google.cloud.dialogflow.v2.SetSuggestionFeatureConfigRequest
                         * @instance
                         */
                        SetSuggestionFeatureConfigRequest.prototype.suggestionFeatureConfig = null;
    
                        /**
                         * Creates a new SetSuggestionFeatureConfigRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.SetSuggestionFeatureConfigRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISetSuggestionFeatureConfigRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.SetSuggestionFeatureConfigRequest} SetSuggestionFeatureConfigRequest instance
                         */
                        SetSuggestionFeatureConfigRequest.create = function create(properties) {
                            return new SetSuggestionFeatureConfigRequest(properties);
                        };
    
                        /**
                         * Encodes the specified SetSuggestionFeatureConfigRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.SetSuggestionFeatureConfigRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.SetSuggestionFeatureConfigRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISetSuggestionFeatureConfigRequest} message SetSuggestionFeatureConfigRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SetSuggestionFeatureConfigRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.conversationProfile != null && Object.hasOwnProperty.call(message, "conversationProfile"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.conversationProfile);
                            if (message.participantRole != null && Object.hasOwnProperty.call(message, "participantRole"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.participantRole);
                            if (message.suggestionFeatureConfig != null && Object.hasOwnProperty.call(message, "suggestionFeatureConfig"))
                                $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionFeatureConfig.encode(message.suggestionFeatureConfig, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SetSuggestionFeatureConfigRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.SetSuggestionFeatureConfigRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SetSuggestionFeatureConfigRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISetSuggestionFeatureConfigRequest} message SetSuggestionFeatureConfigRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SetSuggestionFeatureConfigRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SetSuggestionFeatureConfigRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.SetSuggestionFeatureConfigRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.SetSuggestionFeatureConfigRequest} SetSuggestionFeatureConfigRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SetSuggestionFeatureConfigRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.SetSuggestionFeatureConfigRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.conversationProfile = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.participantRole = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.suggestionFeatureConfig = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionFeatureConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SetSuggestionFeatureConfigRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SetSuggestionFeatureConfigRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.SetSuggestionFeatureConfigRequest} SetSuggestionFeatureConfigRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SetSuggestionFeatureConfigRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SetSuggestionFeatureConfigRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.SetSuggestionFeatureConfigRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SetSuggestionFeatureConfigRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.conversationProfile != null && message.hasOwnProperty("conversationProfile"))
                                if (!$util.isString(message.conversationProfile))
                                    return "conversationProfile: string expected";
                            if (message.participantRole != null && message.hasOwnProperty("participantRole"))
                                switch (message.participantRole) {
                                default:
                                    return "participantRole: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                    break;
                                }
                            if (message.suggestionFeatureConfig != null && message.hasOwnProperty("suggestionFeatureConfig")) {
                                var error = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionFeatureConfig.verify(message.suggestionFeatureConfig);
                                if (error)
                                    return "suggestionFeatureConfig." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a SetSuggestionFeatureConfigRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.SetSuggestionFeatureConfigRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.SetSuggestionFeatureConfigRequest} SetSuggestionFeatureConfigRequest
                         */
                        SetSuggestionFeatureConfigRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.SetSuggestionFeatureConfigRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.SetSuggestionFeatureConfigRequest();
                            if (object.conversationProfile != null)
                                message.conversationProfile = String(object.conversationProfile);
                            switch (object.participantRole) {
                            default:
                                if (typeof object.participantRole === "number") {
                                    message.participantRole = object.participantRole;
                                    break;
                                }
                                break;
                            case "ROLE_UNSPECIFIED":
                            case 0:
                                message.participantRole = 0;
                                break;
                            case "HUMAN_AGENT":
                            case 1:
                                message.participantRole = 1;
                                break;
                            case "AUTOMATED_AGENT":
                            case 2:
                                message.participantRole = 2;
                                break;
                            case "END_USER":
                            case 3:
                                message.participantRole = 3;
                                break;
                            }
                            if (object.suggestionFeatureConfig != null) {
                                if (typeof object.suggestionFeatureConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.SetSuggestionFeatureConfigRequest.suggestionFeatureConfig: object expected");
                                message.suggestionFeatureConfig = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionFeatureConfig.fromObject(object.suggestionFeatureConfig);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SetSuggestionFeatureConfigRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.SetSuggestionFeatureConfigRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.SetSuggestionFeatureConfigRequest} message SetSuggestionFeatureConfigRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SetSuggestionFeatureConfigRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.conversationProfile = "";
                                object.participantRole = options.enums === String ? "ROLE_UNSPECIFIED" : 0;
                                object.suggestionFeatureConfig = null;
                            }
                            if (message.conversationProfile != null && message.hasOwnProperty("conversationProfile"))
                                object.conversationProfile = message.conversationProfile;
                            if (message.participantRole != null && message.hasOwnProperty("participantRole"))
                                object.participantRole = options.enums === String ? $root.google.cloud.dialogflow.v2.Participant.Role[message.participantRole] === undefined ? message.participantRole : $root.google.cloud.dialogflow.v2.Participant.Role[message.participantRole] : message.participantRole;
                            if (message.suggestionFeatureConfig != null && message.hasOwnProperty("suggestionFeatureConfig"))
                                object.suggestionFeatureConfig = $root.google.cloud.dialogflow.v2.HumanAgentAssistantConfig.SuggestionFeatureConfig.toObject(message.suggestionFeatureConfig, options);
                            return object;
                        };
    
                        /**
                         * Converts this SetSuggestionFeatureConfigRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.SetSuggestionFeatureConfigRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SetSuggestionFeatureConfigRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SetSuggestionFeatureConfigRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.SetSuggestionFeatureConfigRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SetSuggestionFeatureConfigRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.SetSuggestionFeatureConfigRequest";
                        };
    
                        return SetSuggestionFeatureConfigRequest;
                    })();
    
                    v2.ClearSuggestionFeatureConfigRequest = (function() {
    
                        /**
                         * Properties of a ClearSuggestionFeatureConfigRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IClearSuggestionFeatureConfigRequest
                         * @property {string|null} [conversationProfile] ClearSuggestionFeatureConfigRequest conversationProfile
                         * @property {google.cloud.dialogflow.v2.Participant.Role|null} [participantRole] ClearSuggestionFeatureConfigRequest participantRole
                         * @property {google.cloud.dialogflow.v2.SuggestionFeature.Type|null} [suggestionFeatureType] ClearSuggestionFeatureConfigRequest suggestionFeatureType
                         */
    
                        /**
                         * Constructs a new ClearSuggestionFeatureConfigRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a ClearSuggestionFeatureConfigRequest.
                         * @implements IClearSuggestionFeatureConfigRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IClearSuggestionFeatureConfigRequest=} [properties] Properties to set
                         */
                        function ClearSuggestionFeatureConfigRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ClearSuggestionFeatureConfigRequest conversationProfile.
                         * @member {string} conversationProfile
                         * @memberof google.cloud.dialogflow.v2.ClearSuggestionFeatureConfigRequest
                         * @instance
                         */
                        ClearSuggestionFeatureConfigRequest.prototype.conversationProfile = "";
    
                        /**
                         * ClearSuggestionFeatureConfigRequest participantRole.
                         * @member {google.cloud.dialogflow.v2.Participant.Role} participantRole
                         * @memberof google.cloud.dialogflow.v2.ClearSuggestionFeatureConfigRequest
                         * @instance
                         */
                        ClearSuggestionFeatureConfigRequest.prototype.participantRole = 0;
    
                        /**
                         * ClearSuggestionFeatureConfigRequest suggestionFeatureType.
                         * @member {google.cloud.dialogflow.v2.SuggestionFeature.Type} suggestionFeatureType
                         * @memberof google.cloud.dialogflow.v2.ClearSuggestionFeatureConfigRequest
                         * @instance
                         */
                        ClearSuggestionFeatureConfigRequest.prototype.suggestionFeatureType = 0;
    
                        /**
                         * Creates a new ClearSuggestionFeatureConfigRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ClearSuggestionFeatureConfigRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IClearSuggestionFeatureConfigRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ClearSuggestionFeatureConfigRequest} ClearSuggestionFeatureConfigRequest instance
                         */
                        ClearSuggestionFeatureConfigRequest.create = function create(properties) {
                            return new ClearSuggestionFeatureConfigRequest(properties);
                        };
    
                        /**
                         * Encodes the specified ClearSuggestionFeatureConfigRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.ClearSuggestionFeatureConfigRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ClearSuggestionFeatureConfigRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IClearSuggestionFeatureConfigRequest} message ClearSuggestionFeatureConfigRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ClearSuggestionFeatureConfigRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.conversationProfile != null && Object.hasOwnProperty.call(message, "conversationProfile"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.conversationProfile);
                            if (message.participantRole != null && Object.hasOwnProperty.call(message, "participantRole"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.participantRole);
                            if (message.suggestionFeatureType != null && Object.hasOwnProperty.call(message, "suggestionFeatureType"))
                                writer.uint32(/* id 3, wireType 0 =*/24).int32(message.suggestionFeatureType);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ClearSuggestionFeatureConfigRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ClearSuggestionFeatureConfigRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ClearSuggestionFeatureConfigRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IClearSuggestionFeatureConfigRequest} message ClearSuggestionFeatureConfigRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ClearSuggestionFeatureConfigRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ClearSuggestionFeatureConfigRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ClearSuggestionFeatureConfigRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ClearSuggestionFeatureConfigRequest} ClearSuggestionFeatureConfigRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ClearSuggestionFeatureConfigRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ClearSuggestionFeatureConfigRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.conversationProfile = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.participantRole = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.suggestionFeatureType = reader.int32();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ClearSuggestionFeatureConfigRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ClearSuggestionFeatureConfigRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ClearSuggestionFeatureConfigRequest} ClearSuggestionFeatureConfigRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ClearSuggestionFeatureConfigRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ClearSuggestionFeatureConfigRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ClearSuggestionFeatureConfigRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ClearSuggestionFeatureConfigRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.conversationProfile != null && message.hasOwnProperty("conversationProfile"))
                                if (!$util.isString(message.conversationProfile))
                                    return "conversationProfile: string expected";
                            if (message.participantRole != null && message.hasOwnProperty("participantRole"))
                                switch (message.participantRole) {
                                default:
                                    return "participantRole: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                    break;
                                }
                            if (message.suggestionFeatureType != null && message.hasOwnProperty("suggestionFeatureType"))
                                switch (message.suggestionFeatureType) {
                                default:
                                    return "suggestionFeatureType: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                case 8:
                                case 14:
                                case 15:
                                    break;
                                }
                            return null;
                        };
    
                        /**
                         * Creates a ClearSuggestionFeatureConfigRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ClearSuggestionFeatureConfigRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ClearSuggestionFeatureConfigRequest} ClearSuggestionFeatureConfigRequest
                         */
                        ClearSuggestionFeatureConfigRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ClearSuggestionFeatureConfigRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ClearSuggestionFeatureConfigRequest();
                            if (object.conversationProfile != null)
                                message.conversationProfile = String(object.conversationProfile);
                            switch (object.participantRole) {
                            default:
                                if (typeof object.participantRole === "number") {
                                    message.participantRole = object.participantRole;
                                    break;
                                }
                                break;
                            case "ROLE_UNSPECIFIED":
                            case 0:
                                message.participantRole = 0;
                                break;
                            case "HUMAN_AGENT":
                            case 1:
                                message.participantRole = 1;
                                break;
                            case "AUTOMATED_AGENT":
                            case 2:
                                message.participantRole = 2;
                                break;
                            case "END_USER":
                            case 3:
                                message.participantRole = 3;
                                break;
                            }
                            switch (object.suggestionFeatureType) {
                            default:
                                if (typeof object.suggestionFeatureType === "number") {
                                    message.suggestionFeatureType = object.suggestionFeatureType;
                                    break;
                                }
                                break;
                            case "TYPE_UNSPECIFIED":
                            case 0:
                                message.suggestionFeatureType = 0;
                                break;
                            case "ARTICLE_SUGGESTION":
                            case 1:
                                message.suggestionFeatureType = 1;
                                break;
                            case "FAQ":
                            case 2:
                                message.suggestionFeatureType = 2;
                                break;
                            case "SMART_REPLY":
                            case 3:
                                message.suggestionFeatureType = 3;
                                break;
                            case "CONVERSATION_SUMMARIZATION":
                            case 8:
                                message.suggestionFeatureType = 8;
                                break;
                            case "KNOWLEDGE_SEARCH":
                            case 14:
                                message.suggestionFeatureType = 14;
                                break;
                            case "KNOWLEDGE_ASSIST":
                            case 15:
                                message.suggestionFeatureType = 15;
                                break;
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ClearSuggestionFeatureConfigRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ClearSuggestionFeatureConfigRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ClearSuggestionFeatureConfigRequest} message ClearSuggestionFeatureConfigRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ClearSuggestionFeatureConfigRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.conversationProfile = "";
                                object.participantRole = options.enums === String ? "ROLE_UNSPECIFIED" : 0;
                                object.suggestionFeatureType = options.enums === String ? "TYPE_UNSPECIFIED" : 0;
                            }
                            if (message.conversationProfile != null && message.hasOwnProperty("conversationProfile"))
                                object.conversationProfile = message.conversationProfile;
                            if (message.participantRole != null && message.hasOwnProperty("participantRole"))
                                object.participantRole = options.enums === String ? $root.google.cloud.dialogflow.v2.Participant.Role[message.participantRole] === undefined ? message.participantRole : $root.google.cloud.dialogflow.v2.Participant.Role[message.participantRole] : message.participantRole;
                            if (message.suggestionFeatureType != null && message.hasOwnProperty("suggestionFeatureType"))
                                object.suggestionFeatureType = options.enums === String ? $root.google.cloud.dialogflow.v2.SuggestionFeature.Type[message.suggestionFeatureType] === undefined ? message.suggestionFeatureType : $root.google.cloud.dialogflow.v2.SuggestionFeature.Type[message.suggestionFeatureType] : message.suggestionFeatureType;
                            return object;
                        };
    
                        /**
                         * Converts this ClearSuggestionFeatureConfigRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ClearSuggestionFeatureConfigRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ClearSuggestionFeatureConfigRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ClearSuggestionFeatureConfigRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ClearSuggestionFeatureConfigRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ClearSuggestionFeatureConfigRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ClearSuggestionFeatureConfigRequest";
                        };
    
                        return ClearSuggestionFeatureConfigRequest;
                    })();
    
                    v2.SetSuggestionFeatureConfigOperationMetadata = (function() {
    
                        /**
                         * Properties of a SetSuggestionFeatureConfigOperationMetadata.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ISetSuggestionFeatureConfigOperationMetadata
                         * @property {string|null} [conversationProfile] SetSuggestionFeatureConfigOperationMetadata conversationProfile
                         * @property {google.cloud.dialogflow.v2.Participant.Role|null} [participantRole] SetSuggestionFeatureConfigOperationMetadata participantRole
                         * @property {google.cloud.dialogflow.v2.SuggestionFeature.Type|null} [suggestionFeatureType] SetSuggestionFeatureConfigOperationMetadata suggestionFeatureType
                         * @property {google.protobuf.ITimestamp|null} [createTime] SetSuggestionFeatureConfigOperationMetadata createTime
                         */
    
                        /**
                         * Constructs a new SetSuggestionFeatureConfigOperationMetadata.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a SetSuggestionFeatureConfigOperationMetadata.
                         * @implements ISetSuggestionFeatureConfigOperationMetadata
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ISetSuggestionFeatureConfigOperationMetadata=} [properties] Properties to set
                         */
                        function SetSuggestionFeatureConfigOperationMetadata(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SetSuggestionFeatureConfigOperationMetadata conversationProfile.
                         * @member {string} conversationProfile
                         * @memberof google.cloud.dialogflow.v2.SetSuggestionFeatureConfigOperationMetadata
                         * @instance
                         */
                        SetSuggestionFeatureConfigOperationMetadata.prototype.conversationProfile = "";
    
                        /**
                         * SetSuggestionFeatureConfigOperationMetadata participantRole.
                         * @member {google.cloud.dialogflow.v2.Participant.Role} participantRole
                         * @memberof google.cloud.dialogflow.v2.SetSuggestionFeatureConfigOperationMetadata
                         * @instance
                         */
                        SetSuggestionFeatureConfigOperationMetadata.prototype.participantRole = 0;
    
                        /**
                         * SetSuggestionFeatureConfigOperationMetadata suggestionFeatureType.
                         * @member {google.cloud.dialogflow.v2.SuggestionFeature.Type} suggestionFeatureType
                         * @memberof google.cloud.dialogflow.v2.SetSuggestionFeatureConfigOperationMetadata
                         * @instance
                         */
                        SetSuggestionFeatureConfigOperationMetadata.prototype.suggestionFeatureType = 0;
    
                        /**
                         * SetSuggestionFeatureConfigOperationMetadata createTime.
                         * @member {google.protobuf.ITimestamp|null|undefined} createTime
                         * @memberof google.cloud.dialogflow.v2.SetSuggestionFeatureConfigOperationMetadata
                         * @instance
                         */
                        SetSuggestionFeatureConfigOperationMetadata.prototype.createTime = null;
    
                        /**
                         * Creates a new SetSuggestionFeatureConfigOperationMetadata instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.SetSuggestionFeatureConfigOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISetSuggestionFeatureConfigOperationMetadata=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.SetSuggestionFeatureConfigOperationMetadata} SetSuggestionFeatureConfigOperationMetadata instance
                         */
                        SetSuggestionFeatureConfigOperationMetadata.create = function create(properties) {
                            return new SetSuggestionFeatureConfigOperationMetadata(properties);
                        };
    
                        /**
                         * Encodes the specified SetSuggestionFeatureConfigOperationMetadata message. Does not implicitly {@link google.cloud.dialogflow.v2.SetSuggestionFeatureConfigOperationMetadata.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.SetSuggestionFeatureConfigOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISetSuggestionFeatureConfigOperationMetadata} message SetSuggestionFeatureConfigOperationMetadata message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SetSuggestionFeatureConfigOperationMetadata.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.conversationProfile != null && Object.hasOwnProperty.call(message, "conversationProfile"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.conversationProfile);
                            if (message.participantRole != null && Object.hasOwnProperty.call(message, "participantRole"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.participantRole);
                            if (message.suggestionFeatureType != null && Object.hasOwnProperty.call(message, "suggestionFeatureType"))
                                writer.uint32(/* id 3, wireType 0 =*/24).int32(message.suggestionFeatureType);
                            if (message.createTime != null && Object.hasOwnProperty.call(message, "createTime"))
                                $root.google.protobuf.Timestamp.encode(message.createTime, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SetSuggestionFeatureConfigOperationMetadata message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.SetSuggestionFeatureConfigOperationMetadata.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SetSuggestionFeatureConfigOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISetSuggestionFeatureConfigOperationMetadata} message SetSuggestionFeatureConfigOperationMetadata message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SetSuggestionFeatureConfigOperationMetadata.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SetSuggestionFeatureConfigOperationMetadata message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.SetSuggestionFeatureConfigOperationMetadata
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.SetSuggestionFeatureConfigOperationMetadata} SetSuggestionFeatureConfigOperationMetadata
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SetSuggestionFeatureConfigOperationMetadata.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.SetSuggestionFeatureConfigOperationMetadata();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.conversationProfile = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.participantRole = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.suggestionFeatureType = reader.int32();
                                        break;
                                    }
                                case 4: {
                                        message.createTime = $root.google.protobuf.Timestamp.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SetSuggestionFeatureConfigOperationMetadata message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SetSuggestionFeatureConfigOperationMetadata
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.SetSuggestionFeatureConfigOperationMetadata} SetSuggestionFeatureConfigOperationMetadata
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SetSuggestionFeatureConfigOperationMetadata.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SetSuggestionFeatureConfigOperationMetadata message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.SetSuggestionFeatureConfigOperationMetadata
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SetSuggestionFeatureConfigOperationMetadata.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.conversationProfile != null && message.hasOwnProperty("conversationProfile"))
                                if (!$util.isString(message.conversationProfile))
                                    return "conversationProfile: string expected";
                            if (message.participantRole != null && message.hasOwnProperty("participantRole"))
                                switch (message.participantRole) {
                                default:
                                    return "participantRole: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                    break;
                                }
                            if (message.suggestionFeatureType != null && message.hasOwnProperty("suggestionFeatureType"))
                                switch (message.suggestionFeatureType) {
                                default:
                                    return "suggestionFeatureType: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                case 8:
                                case 14:
                                case 15:
                                    break;
                                }
                            if (message.createTime != null && message.hasOwnProperty("createTime")) {
                                var error = $root.google.protobuf.Timestamp.verify(message.createTime);
                                if (error)
                                    return "createTime." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a SetSuggestionFeatureConfigOperationMetadata message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.SetSuggestionFeatureConfigOperationMetadata
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.SetSuggestionFeatureConfigOperationMetadata} SetSuggestionFeatureConfigOperationMetadata
                         */
                        SetSuggestionFeatureConfigOperationMetadata.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.SetSuggestionFeatureConfigOperationMetadata)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.SetSuggestionFeatureConfigOperationMetadata();
                            if (object.conversationProfile != null)
                                message.conversationProfile = String(object.conversationProfile);
                            switch (object.participantRole) {
                            default:
                                if (typeof object.participantRole === "number") {
                                    message.participantRole = object.participantRole;
                                    break;
                                }
                                break;
                            case "ROLE_UNSPECIFIED":
                            case 0:
                                message.participantRole = 0;
                                break;
                            case "HUMAN_AGENT":
                            case 1:
                                message.participantRole = 1;
                                break;
                            case "AUTOMATED_AGENT":
                            case 2:
                                message.participantRole = 2;
                                break;
                            case "END_USER":
                            case 3:
                                message.participantRole = 3;
                                break;
                            }
                            switch (object.suggestionFeatureType) {
                            default:
                                if (typeof object.suggestionFeatureType === "number") {
                                    message.suggestionFeatureType = object.suggestionFeatureType;
                                    break;
                                }
                                break;
                            case "TYPE_UNSPECIFIED":
                            case 0:
                                message.suggestionFeatureType = 0;
                                break;
                            case "ARTICLE_SUGGESTION":
                            case 1:
                                message.suggestionFeatureType = 1;
                                break;
                            case "FAQ":
                            case 2:
                                message.suggestionFeatureType = 2;
                                break;
                            case "SMART_REPLY":
                            case 3:
                                message.suggestionFeatureType = 3;
                                break;
                            case "CONVERSATION_SUMMARIZATION":
                            case 8:
                                message.suggestionFeatureType = 8;
                                break;
                            case "KNOWLEDGE_SEARCH":
                            case 14:
                                message.suggestionFeatureType = 14;
                                break;
                            case "KNOWLEDGE_ASSIST":
                            case 15:
                                message.suggestionFeatureType = 15;
                                break;
                            }
                            if (object.createTime != null) {
                                if (typeof object.createTime !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.SetSuggestionFeatureConfigOperationMetadata.createTime: object expected");
                                message.createTime = $root.google.protobuf.Timestamp.fromObject(object.createTime);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SetSuggestionFeatureConfigOperationMetadata message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.SetSuggestionFeatureConfigOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.SetSuggestionFeatureConfigOperationMetadata} message SetSuggestionFeatureConfigOperationMetadata
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SetSuggestionFeatureConfigOperationMetadata.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.conversationProfile = "";
                                object.participantRole = options.enums === String ? "ROLE_UNSPECIFIED" : 0;
                                object.suggestionFeatureType = options.enums === String ? "TYPE_UNSPECIFIED" : 0;
                                object.createTime = null;
                            }
                            if (message.conversationProfile != null && message.hasOwnProperty("conversationProfile"))
                                object.conversationProfile = message.conversationProfile;
                            if (message.participantRole != null && message.hasOwnProperty("participantRole"))
                                object.participantRole = options.enums === String ? $root.google.cloud.dialogflow.v2.Participant.Role[message.participantRole] === undefined ? message.participantRole : $root.google.cloud.dialogflow.v2.Participant.Role[message.participantRole] : message.participantRole;
                            if (message.suggestionFeatureType != null && message.hasOwnProperty("suggestionFeatureType"))
                                object.suggestionFeatureType = options.enums === String ? $root.google.cloud.dialogflow.v2.SuggestionFeature.Type[message.suggestionFeatureType] === undefined ? message.suggestionFeatureType : $root.google.cloud.dialogflow.v2.SuggestionFeature.Type[message.suggestionFeatureType] : message.suggestionFeatureType;
                            if (message.createTime != null && message.hasOwnProperty("createTime"))
                                object.createTime = $root.google.protobuf.Timestamp.toObject(message.createTime, options);
                            return object;
                        };
    
                        /**
                         * Converts this SetSuggestionFeatureConfigOperationMetadata to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.SetSuggestionFeatureConfigOperationMetadata
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SetSuggestionFeatureConfigOperationMetadata.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SetSuggestionFeatureConfigOperationMetadata
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.SetSuggestionFeatureConfigOperationMetadata
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SetSuggestionFeatureConfigOperationMetadata.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.SetSuggestionFeatureConfigOperationMetadata";
                        };
    
                        return SetSuggestionFeatureConfigOperationMetadata;
                    })();
    
                    v2.ClearSuggestionFeatureConfigOperationMetadata = (function() {
    
                        /**
                         * Properties of a ClearSuggestionFeatureConfigOperationMetadata.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IClearSuggestionFeatureConfigOperationMetadata
                         * @property {string|null} [conversationProfile] ClearSuggestionFeatureConfigOperationMetadata conversationProfile
                         * @property {google.cloud.dialogflow.v2.Participant.Role|null} [participantRole] ClearSuggestionFeatureConfigOperationMetadata participantRole
                         * @property {google.cloud.dialogflow.v2.SuggestionFeature.Type|null} [suggestionFeatureType] ClearSuggestionFeatureConfigOperationMetadata suggestionFeatureType
                         * @property {google.protobuf.ITimestamp|null} [createTime] ClearSuggestionFeatureConfigOperationMetadata createTime
                         */
    
                        /**
                         * Constructs a new ClearSuggestionFeatureConfigOperationMetadata.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a ClearSuggestionFeatureConfigOperationMetadata.
                         * @implements IClearSuggestionFeatureConfigOperationMetadata
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IClearSuggestionFeatureConfigOperationMetadata=} [properties] Properties to set
                         */
                        function ClearSuggestionFeatureConfigOperationMetadata(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ClearSuggestionFeatureConfigOperationMetadata conversationProfile.
                         * @member {string} conversationProfile
                         * @memberof google.cloud.dialogflow.v2.ClearSuggestionFeatureConfigOperationMetadata
                         * @instance
                         */
                        ClearSuggestionFeatureConfigOperationMetadata.prototype.conversationProfile = "";
    
                        /**
                         * ClearSuggestionFeatureConfigOperationMetadata participantRole.
                         * @member {google.cloud.dialogflow.v2.Participant.Role} participantRole
                         * @memberof google.cloud.dialogflow.v2.ClearSuggestionFeatureConfigOperationMetadata
                         * @instance
                         */
                        ClearSuggestionFeatureConfigOperationMetadata.prototype.participantRole = 0;
    
                        /**
                         * ClearSuggestionFeatureConfigOperationMetadata suggestionFeatureType.
                         * @member {google.cloud.dialogflow.v2.SuggestionFeature.Type} suggestionFeatureType
                         * @memberof google.cloud.dialogflow.v2.ClearSuggestionFeatureConfigOperationMetadata
                         * @instance
                         */
                        ClearSuggestionFeatureConfigOperationMetadata.prototype.suggestionFeatureType = 0;
    
                        /**
                         * ClearSuggestionFeatureConfigOperationMetadata createTime.
                         * @member {google.protobuf.ITimestamp|null|undefined} createTime
                         * @memberof google.cloud.dialogflow.v2.ClearSuggestionFeatureConfigOperationMetadata
                         * @instance
                         */
                        ClearSuggestionFeatureConfigOperationMetadata.prototype.createTime = null;
    
                        /**
                         * Creates a new ClearSuggestionFeatureConfigOperationMetadata instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ClearSuggestionFeatureConfigOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.IClearSuggestionFeatureConfigOperationMetadata=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ClearSuggestionFeatureConfigOperationMetadata} ClearSuggestionFeatureConfigOperationMetadata instance
                         */
                        ClearSuggestionFeatureConfigOperationMetadata.create = function create(properties) {
                            return new ClearSuggestionFeatureConfigOperationMetadata(properties);
                        };
    
                        /**
                         * Encodes the specified ClearSuggestionFeatureConfigOperationMetadata message. Does not implicitly {@link google.cloud.dialogflow.v2.ClearSuggestionFeatureConfigOperationMetadata.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ClearSuggestionFeatureConfigOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.IClearSuggestionFeatureConfigOperationMetadata} message ClearSuggestionFeatureConfigOperationMetadata message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ClearSuggestionFeatureConfigOperationMetadata.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.conversationProfile != null && Object.hasOwnProperty.call(message, "conversationProfile"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.conversationProfile);
                            if (message.participantRole != null && Object.hasOwnProperty.call(message, "participantRole"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.participantRole);
                            if (message.suggestionFeatureType != null && Object.hasOwnProperty.call(message, "suggestionFeatureType"))
                                writer.uint32(/* id 3, wireType 0 =*/24).int32(message.suggestionFeatureType);
                            if (message.createTime != null && Object.hasOwnProperty.call(message, "createTime"))
                                $root.google.protobuf.Timestamp.encode(message.createTime, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ClearSuggestionFeatureConfigOperationMetadata message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ClearSuggestionFeatureConfigOperationMetadata.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ClearSuggestionFeatureConfigOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.IClearSuggestionFeatureConfigOperationMetadata} message ClearSuggestionFeatureConfigOperationMetadata message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ClearSuggestionFeatureConfigOperationMetadata.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ClearSuggestionFeatureConfigOperationMetadata message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ClearSuggestionFeatureConfigOperationMetadata
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ClearSuggestionFeatureConfigOperationMetadata} ClearSuggestionFeatureConfigOperationMetadata
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ClearSuggestionFeatureConfigOperationMetadata.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ClearSuggestionFeatureConfigOperationMetadata();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.conversationProfile = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.participantRole = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.suggestionFeatureType = reader.int32();
                                        break;
                                    }
                                case 4: {
                                        message.createTime = $root.google.protobuf.Timestamp.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ClearSuggestionFeatureConfigOperationMetadata message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ClearSuggestionFeatureConfigOperationMetadata
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ClearSuggestionFeatureConfigOperationMetadata} ClearSuggestionFeatureConfigOperationMetadata
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ClearSuggestionFeatureConfigOperationMetadata.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ClearSuggestionFeatureConfigOperationMetadata message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ClearSuggestionFeatureConfigOperationMetadata
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ClearSuggestionFeatureConfigOperationMetadata.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.conversationProfile != null && message.hasOwnProperty("conversationProfile"))
                                if (!$util.isString(message.conversationProfile))
                                    return "conversationProfile: string expected";
                            if (message.participantRole != null && message.hasOwnProperty("participantRole"))
                                switch (message.participantRole) {
                                default:
                                    return "participantRole: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                    break;
                                }
                            if (message.suggestionFeatureType != null && message.hasOwnProperty("suggestionFeatureType"))
                                switch (message.suggestionFeatureType) {
                                default:
                                    return "suggestionFeatureType: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                case 8:
                                case 14:
                                case 15:
                                    break;
                                }
                            if (message.createTime != null && message.hasOwnProperty("createTime")) {
                                var error = $root.google.protobuf.Timestamp.verify(message.createTime);
                                if (error)
                                    return "createTime." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a ClearSuggestionFeatureConfigOperationMetadata message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ClearSuggestionFeatureConfigOperationMetadata
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ClearSuggestionFeatureConfigOperationMetadata} ClearSuggestionFeatureConfigOperationMetadata
                         */
                        ClearSuggestionFeatureConfigOperationMetadata.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ClearSuggestionFeatureConfigOperationMetadata)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ClearSuggestionFeatureConfigOperationMetadata();
                            if (object.conversationProfile != null)
                                message.conversationProfile = String(object.conversationProfile);
                            switch (object.participantRole) {
                            default:
                                if (typeof object.participantRole === "number") {
                                    message.participantRole = object.participantRole;
                                    break;
                                }
                                break;
                            case "ROLE_UNSPECIFIED":
                            case 0:
                                message.participantRole = 0;
                                break;
                            case "HUMAN_AGENT":
                            case 1:
                                message.participantRole = 1;
                                break;
                            case "AUTOMATED_AGENT":
                            case 2:
                                message.participantRole = 2;
                                break;
                            case "END_USER":
                            case 3:
                                message.participantRole = 3;
                                break;
                            }
                            switch (object.suggestionFeatureType) {
                            default:
                                if (typeof object.suggestionFeatureType === "number") {
                                    message.suggestionFeatureType = object.suggestionFeatureType;
                                    break;
                                }
                                break;
                            case "TYPE_UNSPECIFIED":
                            case 0:
                                message.suggestionFeatureType = 0;
                                break;
                            case "ARTICLE_SUGGESTION":
                            case 1:
                                message.suggestionFeatureType = 1;
                                break;
                            case "FAQ":
                            case 2:
                                message.suggestionFeatureType = 2;
                                break;
                            case "SMART_REPLY":
                            case 3:
                                message.suggestionFeatureType = 3;
                                break;
                            case "CONVERSATION_SUMMARIZATION":
                            case 8:
                                message.suggestionFeatureType = 8;
                                break;
                            case "KNOWLEDGE_SEARCH":
                            case 14:
                                message.suggestionFeatureType = 14;
                                break;
                            case "KNOWLEDGE_ASSIST":
                            case 15:
                                message.suggestionFeatureType = 15;
                                break;
                            }
                            if (object.createTime != null) {
                                if (typeof object.createTime !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.ClearSuggestionFeatureConfigOperationMetadata.createTime: object expected");
                                message.createTime = $root.google.protobuf.Timestamp.fromObject(object.createTime);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ClearSuggestionFeatureConfigOperationMetadata message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ClearSuggestionFeatureConfigOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.ClearSuggestionFeatureConfigOperationMetadata} message ClearSuggestionFeatureConfigOperationMetadata
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ClearSuggestionFeatureConfigOperationMetadata.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.conversationProfile = "";
                                object.participantRole = options.enums === String ? "ROLE_UNSPECIFIED" : 0;
                                object.suggestionFeatureType = options.enums === String ? "TYPE_UNSPECIFIED" : 0;
                                object.createTime = null;
                            }
                            if (message.conversationProfile != null && message.hasOwnProperty("conversationProfile"))
                                object.conversationProfile = message.conversationProfile;
                            if (message.participantRole != null && message.hasOwnProperty("participantRole"))
                                object.participantRole = options.enums === String ? $root.google.cloud.dialogflow.v2.Participant.Role[message.participantRole] === undefined ? message.participantRole : $root.google.cloud.dialogflow.v2.Participant.Role[message.participantRole] : message.participantRole;
                            if (message.suggestionFeatureType != null && message.hasOwnProperty("suggestionFeatureType"))
                                object.suggestionFeatureType = options.enums === String ? $root.google.cloud.dialogflow.v2.SuggestionFeature.Type[message.suggestionFeatureType] === undefined ? message.suggestionFeatureType : $root.google.cloud.dialogflow.v2.SuggestionFeature.Type[message.suggestionFeatureType] : message.suggestionFeatureType;
                            if (message.createTime != null && message.hasOwnProperty("createTime"))
                                object.createTime = $root.google.protobuf.Timestamp.toObject(message.createTime, options);
                            return object;
                        };
    
                        /**
                         * Converts this ClearSuggestionFeatureConfigOperationMetadata to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ClearSuggestionFeatureConfigOperationMetadata
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ClearSuggestionFeatureConfigOperationMetadata.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ClearSuggestionFeatureConfigOperationMetadata
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ClearSuggestionFeatureConfigOperationMetadata
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ClearSuggestionFeatureConfigOperationMetadata.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ClearSuggestionFeatureConfigOperationMetadata";
                        };
    
                        return ClearSuggestionFeatureConfigOperationMetadata;
                    })();
    
                    v2.ConversationDatasets = (function() {
    
                        /**
                         * Constructs a new ConversationDatasets service.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a ConversationDatasets
                         * @extends $protobuf.rpc.Service
                         * @constructor
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         */
                        function ConversationDatasets(rpcImpl, requestDelimited, responseDelimited) {
                            $protobuf.rpc.Service.call(this, rpcImpl, requestDelimited, responseDelimited);
                        }
    
                        (ConversationDatasets.prototype = Object.create($protobuf.rpc.Service.prototype)).constructor = ConversationDatasets;
    
                        /**
                         * Creates new ConversationDatasets service using the specified rpc implementation.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ConversationDatasets
                         * @static
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         * @returns {ConversationDatasets} RPC service. Useful where requests and/or responses are streamed.
                         */
                        ConversationDatasets.create = function create(rpcImpl, requestDelimited, responseDelimited) {
                            return new this(rpcImpl, requestDelimited, responseDelimited);
                        };
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.ConversationDatasets|createConversationDataset}.
                         * @memberof google.cloud.dialogflow.v2.ConversationDatasets
                         * @typedef CreateConversationDatasetCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.longrunning.Operation} [response] Operation
                         */
    
                        /**
                         * Calls CreateConversationDataset.
                         * @function createConversationDataset
                         * @memberof google.cloud.dialogflow.v2.ConversationDatasets
                         * @instance
                         * @param {google.cloud.dialogflow.v2.ICreateConversationDatasetRequest} request CreateConversationDatasetRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.ConversationDatasets.CreateConversationDatasetCallback} callback Node-style callback called with the error, if any, and Operation
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(ConversationDatasets.prototype.createConversationDataset = function createConversationDataset(request, callback) {
                            return this.rpcCall(createConversationDataset, $root.google.cloud.dialogflow.v2.CreateConversationDatasetRequest, $root.google.longrunning.Operation, request, callback);
                        }, "name", { value: "CreateConversationDataset" });
    
                        /**
                         * Calls CreateConversationDataset.
                         * @function createConversationDataset
                         * @memberof google.cloud.dialogflow.v2.ConversationDatasets
                         * @instance
                         * @param {google.cloud.dialogflow.v2.ICreateConversationDatasetRequest} request CreateConversationDatasetRequest message or plain object
                         * @returns {Promise<google.longrunning.Operation>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.ConversationDatasets|getConversationDataset}.
                         * @memberof google.cloud.dialogflow.v2.ConversationDatasets
                         * @typedef GetConversationDatasetCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.ConversationDataset} [response] ConversationDataset
                         */
    
                        /**
                         * Calls GetConversationDataset.
                         * @function getConversationDataset
                         * @memberof google.cloud.dialogflow.v2.ConversationDatasets
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IGetConversationDatasetRequest} request GetConversationDatasetRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.ConversationDatasets.GetConversationDatasetCallback} callback Node-style callback called with the error, if any, and ConversationDataset
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(ConversationDatasets.prototype.getConversationDataset = function getConversationDataset(request, callback) {
                            return this.rpcCall(getConversationDataset, $root.google.cloud.dialogflow.v2.GetConversationDatasetRequest, $root.google.cloud.dialogflow.v2.ConversationDataset, request, callback);
                        }, "name", { value: "GetConversationDataset" });
    
                        /**
                         * Calls GetConversationDataset.
                         * @function getConversationDataset
                         * @memberof google.cloud.dialogflow.v2.ConversationDatasets
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IGetConversationDatasetRequest} request GetConversationDatasetRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.ConversationDataset>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.ConversationDatasets|listConversationDatasets}.
                         * @memberof google.cloud.dialogflow.v2.ConversationDatasets
                         * @typedef ListConversationDatasetsCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.ListConversationDatasetsResponse} [response] ListConversationDatasetsResponse
                         */
    
                        /**
                         * Calls ListConversationDatasets.
                         * @function listConversationDatasets
                         * @memberof google.cloud.dialogflow.v2.ConversationDatasets
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IListConversationDatasetsRequest} request ListConversationDatasetsRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.ConversationDatasets.ListConversationDatasetsCallback} callback Node-style callback called with the error, if any, and ListConversationDatasetsResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(ConversationDatasets.prototype.listConversationDatasets = function listConversationDatasets(request, callback) {
                            return this.rpcCall(listConversationDatasets, $root.google.cloud.dialogflow.v2.ListConversationDatasetsRequest, $root.google.cloud.dialogflow.v2.ListConversationDatasetsResponse, request, callback);
                        }, "name", { value: "ListConversationDatasets" });
    
                        /**
                         * Calls ListConversationDatasets.
                         * @function listConversationDatasets
                         * @memberof google.cloud.dialogflow.v2.ConversationDatasets
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IListConversationDatasetsRequest} request ListConversationDatasetsRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.ListConversationDatasetsResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.ConversationDatasets|deleteConversationDataset}.
                         * @memberof google.cloud.dialogflow.v2.ConversationDatasets
                         * @typedef DeleteConversationDatasetCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.longrunning.Operation} [response] Operation
                         */
    
                        /**
                         * Calls DeleteConversationDataset.
                         * @function deleteConversationDataset
                         * @memberof google.cloud.dialogflow.v2.ConversationDatasets
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IDeleteConversationDatasetRequest} request DeleteConversationDatasetRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.ConversationDatasets.DeleteConversationDatasetCallback} callback Node-style callback called with the error, if any, and Operation
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(ConversationDatasets.prototype.deleteConversationDataset = function deleteConversationDataset(request, callback) {
                            return this.rpcCall(deleteConversationDataset, $root.google.cloud.dialogflow.v2.DeleteConversationDatasetRequest, $root.google.longrunning.Operation, request, callback);
                        }, "name", { value: "DeleteConversationDataset" });
    
                        /**
                         * Calls DeleteConversationDataset.
                         * @function deleteConversationDataset
                         * @memberof google.cloud.dialogflow.v2.ConversationDatasets
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IDeleteConversationDatasetRequest} request DeleteConversationDatasetRequest message or plain object
                         * @returns {Promise<google.longrunning.Operation>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.ConversationDatasets|importConversationData}.
                         * @memberof google.cloud.dialogflow.v2.ConversationDatasets
                         * @typedef ImportConversationDataCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.longrunning.Operation} [response] Operation
                         */
    
                        /**
                         * Calls ImportConversationData.
                         * @function importConversationData
                         * @memberof google.cloud.dialogflow.v2.ConversationDatasets
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IImportConversationDataRequest} request ImportConversationDataRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.ConversationDatasets.ImportConversationDataCallback} callback Node-style callback called with the error, if any, and Operation
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(ConversationDatasets.prototype.importConversationData = function importConversationData(request, callback) {
                            return this.rpcCall(importConversationData, $root.google.cloud.dialogflow.v2.ImportConversationDataRequest, $root.google.longrunning.Operation, request, callback);
                        }, "name", { value: "ImportConversationData" });
    
                        /**
                         * Calls ImportConversationData.
                         * @function importConversationData
                         * @memberof google.cloud.dialogflow.v2.ConversationDatasets
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IImportConversationDataRequest} request ImportConversationDataRequest message or plain object
                         * @returns {Promise<google.longrunning.Operation>} Promise
                         * @variation 2
                         */
    
                        return ConversationDatasets;
                    })();
    
                    v2.ConversationInfo = (function() {
    
                        /**
                         * Properties of a ConversationInfo.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IConversationInfo
                         * @property {string|null} [languageCode] ConversationInfo languageCode
                         */
    
                        /**
                         * Constructs a new ConversationInfo.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a ConversationInfo.
                         * @implements IConversationInfo
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IConversationInfo=} [properties] Properties to set
                         */
                        function ConversationInfo(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ConversationInfo languageCode.
                         * @member {string} languageCode
                         * @memberof google.cloud.dialogflow.v2.ConversationInfo
                         * @instance
                         */
                        ConversationInfo.prototype.languageCode = "";
    
                        /**
                         * Creates a new ConversationInfo instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ConversationInfo
                         * @static
                         * @param {google.cloud.dialogflow.v2.IConversationInfo=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ConversationInfo} ConversationInfo instance
                         */
                        ConversationInfo.create = function create(properties) {
                            return new ConversationInfo(properties);
                        };
    
                        /**
                         * Encodes the specified ConversationInfo message. Does not implicitly {@link google.cloud.dialogflow.v2.ConversationInfo.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ConversationInfo
                         * @static
                         * @param {google.cloud.dialogflow.v2.IConversationInfo} message ConversationInfo message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ConversationInfo.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.languageCode != null && Object.hasOwnProperty.call(message, "languageCode"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.languageCode);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ConversationInfo message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ConversationInfo.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ConversationInfo
                         * @static
                         * @param {google.cloud.dialogflow.v2.IConversationInfo} message ConversationInfo message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ConversationInfo.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ConversationInfo message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ConversationInfo
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ConversationInfo} ConversationInfo
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ConversationInfo.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ConversationInfo();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.languageCode = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ConversationInfo message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ConversationInfo
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ConversationInfo} ConversationInfo
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ConversationInfo.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ConversationInfo message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ConversationInfo
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ConversationInfo.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                if (!$util.isString(message.languageCode))
                                    return "languageCode: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ConversationInfo message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ConversationInfo
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ConversationInfo} ConversationInfo
                         */
                        ConversationInfo.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ConversationInfo)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ConversationInfo();
                            if (object.languageCode != null)
                                message.languageCode = String(object.languageCode);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ConversationInfo message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ConversationInfo
                         * @static
                         * @param {google.cloud.dialogflow.v2.ConversationInfo} message ConversationInfo
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ConversationInfo.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.languageCode = "";
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                object.languageCode = message.languageCode;
                            return object;
                        };
    
                        /**
                         * Converts this ConversationInfo to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ConversationInfo
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ConversationInfo.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ConversationInfo
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ConversationInfo
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ConversationInfo.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ConversationInfo";
                        };
    
                        return ConversationInfo;
                    })();
    
                    v2.InputConfig = (function() {
    
                        /**
                         * Properties of an InputConfig.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IInputConfig
                         * @property {google.cloud.dialogflow.v2.IGcsSources|null} [gcsSource] InputConfig gcsSource
                         */
    
                        /**
                         * Constructs a new InputConfig.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an InputConfig.
                         * @implements IInputConfig
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IInputConfig=} [properties] Properties to set
                         */
                        function InputConfig(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * InputConfig gcsSource.
                         * @member {google.cloud.dialogflow.v2.IGcsSources|null|undefined} gcsSource
                         * @memberof google.cloud.dialogflow.v2.InputConfig
                         * @instance
                         */
                        InputConfig.prototype.gcsSource = null;
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * InputConfig source.
                         * @member {"gcsSource"|undefined} source
                         * @memberof google.cloud.dialogflow.v2.InputConfig
                         * @instance
                         */
                        Object.defineProperty(InputConfig.prototype, "source", {
                            get: $util.oneOfGetter($oneOfFields = ["gcsSource"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new InputConfig instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.InputConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2.IInputConfig=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.InputConfig} InputConfig instance
                         */
                        InputConfig.create = function create(properties) {
                            return new InputConfig(properties);
                        };
    
                        /**
                         * Encodes the specified InputConfig message. Does not implicitly {@link google.cloud.dialogflow.v2.InputConfig.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.InputConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2.IInputConfig} message InputConfig message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        InputConfig.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.gcsSource != null && Object.hasOwnProperty.call(message, "gcsSource"))
                                $root.google.cloud.dialogflow.v2.GcsSources.encode(message.gcsSource, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified InputConfig message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.InputConfig.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.InputConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2.IInputConfig} message InputConfig message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        InputConfig.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an InputConfig message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.InputConfig
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.InputConfig} InputConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        InputConfig.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.InputConfig();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.gcsSource = $root.google.cloud.dialogflow.v2.GcsSources.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an InputConfig message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.InputConfig
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.InputConfig} InputConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        InputConfig.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an InputConfig message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.InputConfig
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        InputConfig.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.gcsSource != null && message.hasOwnProperty("gcsSource")) {
                                properties.source = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2.GcsSources.verify(message.gcsSource);
                                    if (error)
                                        return "gcsSource." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates an InputConfig message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.InputConfig
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.InputConfig} InputConfig
                         */
                        InputConfig.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.InputConfig)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.InputConfig();
                            if (object.gcsSource != null) {
                                if (typeof object.gcsSource !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.InputConfig.gcsSource: object expected");
                                message.gcsSource = $root.google.cloud.dialogflow.v2.GcsSources.fromObject(object.gcsSource);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an InputConfig message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.InputConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2.InputConfig} message InputConfig
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        InputConfig.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (message.gcsSource != null && message.hasOwnProperty("gcsSource")) {
                                object.gcsSource = $root.google.cloud.dialogflow.v2.GcsSources.toObject(message.gcsSource, options);
                                if (options.oneofs)
                                    object.source = "gcsSource";
                            }
                            return object;
                        };
    
                        /**
                         * Converts this InputConfig to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.InputConfig
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        InputConfig.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for InputConfig
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.InputConfig
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        InputConfig.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.InputConfig";
                        };
    
                        return InputConfig;
                    })();
    
                    v2.ConversationDataset = (function() {
    
                        /**
                         * Properties of a ConversationDataset.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IConversationDataset
                         * @property {string|null} [name] ConversationDataset name
                         * @property {string|null} [displayName] ConversationDataset displayName
                         * @property {string|null} [description] ConversationDataset description
                         * @property {google.protobuf.ITimestamp|null} [createTime] ConversationDataset createTime
                         * @property {google.cloud.dialogflow.v2.IInputConfig|null} [inputConfig] ConversationDataset inputConfig
                         * @property {google.cloud.dialogflow.v2.IConversationInfo|null} [conversationInfo] ConversationDataset conversationInfo
                         * @property {number|Long|null} [conversationCount] ConversationDataset conversationCount
                         * @property {boolean|null} [satisfiesPzi] ConversationDataset satisfiesPzi
                         * @property {boolean|null} [satisfiesPzs] ConversationDataset satisfiesPzs
                         */
    
                        /**
                         * Constructs a new ConversationDataset.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a ConversationDataset.
                         * @implements IConversationDataset
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IConversationDataset=} [properties] Properties to set
                         */
                        function ConversationDataset(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ConversationDataset name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2.ConversationDataset
                         * @instance
                         */
                        ConversationDataset.prototype.name = "";
    
                        /**
                         * ConversationDataset displayName.
                         * @member {string} displayName
                         * @memberof google.cloud.dialogflow.v2.ConversationDataset
                         * @instance
                         */
                        ConversationDataset.prototype.displayName = "";
    
                        /**
                         * ConversationDataset description.
                         * @member {string} description
                         * @memberof google.cloud.dialogflow.v2.ConversationDataset
                         * @instance
                         */
                        ConversationDataset.prototype.description = "";
    
                        /**
                         * ConversationDataset createTime.
                         * @member {google.protobuf.ITimestamp|null|undefined} createTime
                         * @memberof google.cloud.dialogflow.v2.ConversationDataset
                         * @instance
                         */
                        ConversationDataset.prototype.createTime = null;
    
                        /**
                         * ConversationDataset inputConfig.
                         * @member {google.cloud.dialogflow.v2.IInputConfig|null|undefined} inputConfig
                         * @memberof google.cloud.dialogflow.v2.ConversationDataset
                         * @instance
                         */
                        ConversationDataset.prototype.inputConfig = null;
    
                        /**
                         * ConversationDataset conversationInfo.
                         * @member {google.cloud.dialogflow.v2.IConversationInfo|null|undefined} conversationInfo
                         * @memberof google.cloud.dialogflow.v2.ConversationDataset
                         * @instance
                         */
                        ConversationDataset.prototype.conversationInfo = null;
    
                        /**
                         * ConversationDataset conversationCount.
                         * @member {number|Long} conversationCount
                         * @memberof google.cloud.dialogflow.v2.ConversationDataset
                         * @instance
                         */
                        ConversationDataset.prototype.conversationCount = $util.Long ? $util.Long.fromBits(0,0,false) : 0;
    
                        /**
                         * ConversationDataset satisfiesPzi.
                         * @member {boolean|null|undefined} satisfiesPzi
                         * @memberof google.cloud.dialogflow.v2.ConversationDataset
                         * @instance
                         */
                        ConversationDataset.prototype.satisfiesPzi = null;
    
                        /**
                         * ConversationDataset satisfiesPzs.
                         * @member {boolean|null|undefined} satisfiesPzs
                         * @memberof google.cloud.dialogflow.v2.ConversationDataset
                         * @instance
                         */
                        ConversationDataset.prototype.satisfiesPzs = null;
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * ConversationDataset _satisfiesPzi.
                         * @member {"satisfiesPzi"|undefined} _satisfiesPzi
                         * @memberof google.cloud.dialogflow.v2.ConversationDataset
                         * @instance
                         */
                        Object.defineProperty(ConversationDataset.prototype, "_satisfiesPzi", {
                            get: $util.oneOfGetter($oneOfFields = ["satisfiesPzi"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * ConversationDataset _satisfiesPzs.
                         * @member {"satisfiesPzs"|undefined} _satisfiesPzs
                         * @memberof google.cloud.dialogflow.v2.ConversationDataset
                         * @instance
                         */
                        Object.defineProperty(ConversationDataset.prototype, "_satisfiesPzs", {
                            get: $util.oneOfGetter($oneOfFields = ["satisfiesPzs"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new ConversationDataset instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ConversationDataset
                         * @static
                         * @param {google.cloud.dialogflow.v2.IConversationDataset=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ConversationDataset} ConversationDataset instance
                         */
                        ConversationDataset.create = function create(properties) {
                            return new ConversationDataset(properties);
                        };
    
                        /**
                         * Encodes the specified ConversationDataset message. Does not implicitly {@link google.cloud.dialogflow.v2.ConversationDataset.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ConversationDataset
                         * @static
                         * @param {google.cloud.dialogflow.v2.IConversationDataset} message ConversationDataset message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ConversationDataset.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            if (message.displayName != null && Object.hasOwnProperty.call(message, "displayName"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.displayName);
                            if (message.description != null && Object.hasOwnProperty.call(message, "description"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.description);
                            if (message.createTime != null && Object.hasOwnProperty.call(message, "createTime"))
                                $root.google.protobuf.Timestamp.encode(message.createTime, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            if (message.inputConfig != null && Object.hasOwnProperty.call(message, "inputConfig"))
                                $root.google.cloud.dialogflow.v2.InputConfig.encode(message.inputConfig, writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                            if (message.conversationInfo != null && Object.hasOwnProperty.call(message, "conversationInfo"))
                                $root.google.cloud.dialogflow.v2.ConversationInfo.encode(message.conversationInfo, writer.uint32(/* id 6, wireType 2 =*/50).fork()).ldelim();
                            if (message.conversationCount != null && Object.hasOwnProperty.call(message, "conversationCount"))
                                writer.uint32(/* id 7, wireType 0 =*/56).int64(message.conversationCount);
                            if (message.satisfiesPzi != null && Object.hasOwnProperty.call(message, "satisfiesPzi"))
                                writer.uint32(/* id 8, wireType 0 =*/64).bool(message.satisfiesPzi);
                            if (message.satisfiesPzs != null && Object.hasOwnProperty.call(message, "satisfiesPzs"))
                                writer.uint32(/* id 9, wireType 0 =*/72).bool(message.satisfiesPzs);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ConversationDataset message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ConversationDataset.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ConversationDataset
                         * @static
                         * @param {google.cloud.dialogflow.v2.IConversationDataset} message ConversationDataset message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ConversationDataset.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ConversationDataset message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ConversationDataset
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ConversationDataset} ConversationDataset
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ConversationDataset.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ConversationDataset();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.displayName = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.description = reader.string();
                                        break;
                                    }
                                case 4: {
                                        message.createTime = $root.google.protobuf.Timestamp.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 5: {
                                        message.inputConfig = $root.google.cloud.dialogflow.v2.InputConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 6: {
                                        message.conversationInfo = $root.google.cloud.dialogflow.v2.ConversationInfo.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 7: {
                                        message.conversationCount = reader.int64();
                                        break;
                                    }
                                case 8: {
                                        message.satisfiesPzi = reader.bool();
                                        break;
                                    }
                                case 9: {
                                        message.satisfiesPzs = reader.bool();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ConversationDataset message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ConversationDataset
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ConversationDataset} ConversationDataset
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ConversationDataset.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ConversationDataset message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ConversationDataset
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ConversationDataset.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            if (message.displayName != null && message.hasOwnProperty("displayName"))
                                if (!$util.isString(message.displayName))
                                    return "displayName: string expected";
                            if (message.description != null && message.hasOwnProperty("description"))
                                if (!$util.isString(message.description))
                                    return "description: string expected";
                            if (message.createTime != null && message.hasOwnProperty("createTime")) {
                                var error = $root.google.protobuf.Timestamp.verify(message.createTime);
                                if (error)
                                    return "createTime." + error;
                            }
                            if (message.inputConfig != null && message.hasOwnProperty("inputConfig")) {
                                var error = $root.google.cloud.dialogflow.v2.InputConfig.verify(message.inputConfig);
                                if (error)
                                    return "inputConfig." + error;
                            }
                            if (message.conversationInfo != null && message.hasOwnProperty("conversationInfo")) {
                                var error = $root.google.cloud.dialogflow.v2.ConversationInfo.verify(message.conversationInfo);
                                if (error)
                                    return "conversationInfo." + error;
                            }
                            if (message.conversationCount != null && message.hasOwnProperty("conversationCount"))
                                if (!$util.isInteger(message.conversationCount) && !(message.conversationCount && $util.isInteger(message.conversationCount.low) && $util.isInteger(message.conversationCount.high)))
                                    return "conversationCount: integer|Long expected";
                            if (message.satisfiesPzi != null && message.hasOwnProperty("satisfiesPzi")) {
                                properties._satisfiesPzi = 1;
                                if (typeof message.satisfiesPzi !== "boolean")
                                    return "satisfiesPzi: boolean expected";
                            }
                            if (message.satisfiesPzs != null && message.hasOwnProperty("satisfiesPzs")) {
                                properties._satisfiesPzs = 1;
                                if (typeof message.satisfiesPzs !== "boolean")
                                    return "satisfiesPzs: boolean expected";
                            }
                            return null;
                        };
    
                        /**
                         * Creates a ConversationDataset message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ConversationDataset
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ConversationDataset} ConversationDataset
                         */
                        ConversationDataset.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ConversationDataset)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ConversationDataset();
                            if (object.name != null)
                                message.name = String(object.name);
                            if (object.displayName != null)
                                message.displayName = String(object.displayName);
                            if (object.description != null)
                                message.description = String(object.description);
                            if (object.createTime != null) {
                                if (typeof object.createTime !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.ConversationDataset.createTime: object expected");
                                message.createTime = $root.google.protobuf.Timestamp.fromObject(object.createTime);
                            }
                            if (object.inputConfig != null) {
                                if (typeof object.inputConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.ConversationDataset.inputConfig: object expected");
                                message.inputConfig = $root.google.cloud.dialogflow.v2.InputConfig.fromObject(object.inputConfig);
                            }
                            if (object.conversationInfo != null) {
                                if (typeof object.conversationInfo !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.ConversationDataset.conversationInfo: object expected");
                                message.conversationInfo = $root.google.cloud.dialogflow.v2.ConversationInfo.fromObject(object.conversationInfo);
                            }
                            if (object.conversationCount != null)
                                if ($util.Long)
                                    (message.conversationCount = $util.Long.fromValue(object.conversationCount)).unsigned = false;
                                else if (typeof object.conversationCount === "string")
                                    message.conversationCount = parseInt(object.conversationCount, 10);
                                else if (typeof object.conversationCount === "number")
                                    message.conversationCount = object.conversationCount;
                                else if (typeof object.conversationCount === "object")
                                    message.conversationCount = new $util.LongBits(object.conversationCount.low >>> 0, object.conversationCount.high >>> 0).toNumber();
                            if (object.satisfiesPzi != null)
                                message.satisfiesPzi = Boolean(object.satisfiesPzi);
                            if (object.satisfiesPzs != null)
                                message.satisfiesPzs = Boolean(object.satisfiesPzs);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ConversationDataset message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ConversationDataset
                         * @static
                         * @param {google.cloud.dialogflow.v2.ConversationDataset} message ConversationDataset
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ConversationDataset.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.name = "";
                                object.displayName = "";
                                object.description = "";
                                object.createTime = null;
                                object.inputConfig = null;
                                object.conversationInfo = null;
                                if ($util.Long) {
                                    var long = new $util.Long(0, 0, false);
                                    object.conversationCount = options.longs === String ? long.toString() : options.longs === Number ? long.toNumber() : long;
                                } else
                                    object.conversationCount = options.longs === String ? "0" : 0;
                            }
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            if (message.displayName != null && message.hasOwnProperty("displayName"))
                                object.displayName = message.displayName;
                            if (message.description != null && message.hasOwnProperty("description"))
                                object.description = message.description;
                            if (message.createTime != null && message.hasOwnProperty("createTime"))
                                object.createTime = $root.google.protobuf.Timestamp.toObject(message.createTime, options);
                            if (message.inputConfig != null && message.hasOwnProperty("inputConfig"))
                                object.inputConfig = $root.google.cloud.dialogflow.v2.InputConfig.toObject(message.inputConfig, options);
                            if (message.conversationInfo != null && message.hasOwnProperty("conversationInfo"))
                                object.conversationInfo = $root.google.cloud.dialogflow.v2.ConversationInfo.toObject(message.conversationInfo, options);
                            if (message.conversationCount != null && message.hasOwnProperty("conversationCount"))
                                if (typeof message.conversationCount === "number")
                                    object.conversationCount = options.longs === String ? String(message.conversationCount) : message.conversationCount;
                                else
                                    object.conversationCount = options.longs === String ? $util.Long.prototype.toString.call(message.conversationCount) : options.longs === Number ? new $util.LongBits(message.conversationCount.low >>> 0, message.conversationCount.high >>> 0).toNumber() : message.conversationCount;
                            if (message.satisfiesPzi != null && message.hasOwnProperty("satisfiesPzi")) {
                                object.satisfiesPzi = message.satisfiesPzi;
                                if (options.oneofs)
                                    object._satisfiesPzi = "satisfiesPzi";
                            }
                            if (message.satisfiesPzs != null && message.hasOwnProperty("satisfiesPzs")) {
                                object.satisfiesPzs = message.satisfiesPzs;
                                if (options.oneofs)
                                    object._satisfiesPzs = "satisfiesPzs";
                            }
                            return object;
                        };
    
                        /**
                         * Converts this ConversationDataset to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ConversationDataset
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ConversationDataset.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ConversationDataset
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ConversationDataset
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ConversationDataset.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ConversationDataset";
                        };
    
                        return ConversationDataset;
                    })();
    
                    v2.CreateConversationDatasetRequest = (function() {
    
                        /**
                         * Properties of a CreateConversationDatasetRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ICreateConversationDatasetRequest
                         * @property {string|null} [parent] CreateConversationDatasetRequest parent
                         * @property {google.cloud.dialogflow.v2.IConversationDataset|null} [conversationDataset] CreateConversationDatasetRequest conversationDataset
                         */
    
                        /**
                         * Constructs a new CreateConversationDatasetRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a CreateConversationDatasetRequest.
                         * @implements ICreateConversationDatasetRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ICreateConversationDatasetRequest=} [properties] Properties to set
                         */
                        function CreateConversationDatasetRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * CreateConversationDatasetRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.CreateConversationDatasetRequest
                         * @instance
                         */
                        CreateConversationDatasetRequest.prototype.parent = "";
    
                        /**
                         * CreateConversationDatasetRequest conversationDataset.
                         * @member {google.cloud.dialogflow.v2.IConversationDataset|null|undefined} conversationDataset
                         * @memberof google.cloud.dialogflow.v2.CreateConversationDatasetRequest
                         * @instance
                         */
                        CreateConversationDatasetRequest.prototype.conversationDataset = null;
    
                        /**
                         * Creates a new CreateConversationDatasetRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.CreateConversationDatasetRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICreateConversationDatasetRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.CreateConversationDatasetRequest} CreateConversationDatasetRequest instance
                         */
                        CreateConversationDatasetRequest.create = function create(properties) {
                            return new CreateConversationDatasetRequest(properties);
                        };
    
                        /**
                         * Encodes the specified CreateConversationDatasetRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.CreateConversationDatasetRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.CreateConversationDatasetRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICreateConversationDatasetRequest} message CreateConversationDatasetRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateConversationDatasetRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.conversationDataset != null && Object.hasOwnProperty.call(message, "conversationDataset"))
                                $root.google.cloud.dialogflow.v2.ConversationDataset.encode(message.conversationDataset, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified CreateConversationDatasetRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.CreateConversationDatasetRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.CreateConversationDatasetRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICreateConversationDatasetRequest} message CreateConversationDatasetRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateConversationDatasetRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a CreateConversationDatasetRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.CreateConversationDatasetRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.CreateConversationDatasetRequest} CreateConversationDatasetRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateConversationDatasetRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.CreateConversationDatasetRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.conversationDataset = $root.google.cloud.dialogflow.v2.ConversationDataset.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a CreateConversationDatasetRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.CreateConversationDatasetRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.CreateConversationDatasetRequest} CreateConversationDatasetRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateConversationDatasetRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a CreateConversationDatasetRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.CreateConversationDatasetRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        CreateConversationDatasetRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.conversationDataset != null && message.hasOwnProperty("conversationDataset")) {
                                var error = $root.google.cloud.dialogflow.v2.ConversationDataset.verify(message.conversationDataset);
                                if (error)
                                    return "conversationDataset." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a CreateConversationDatasetRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.CreateConversationDatasetRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.CreateConversationDatasetRequest} CreateConversationDatasetRequest
                         */
                        CreateConversationDatasetRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.CreateConversationDatasetRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.CreateConversationDatasetRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.conversationDataset != null) {
                                if (typeof object.conversationDataset !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.CreateConversationDatasetRequest.conversationDataset: object expected");
                                message.conversationDataset = $root.google.cloud.dialogflow.v2.ConversationDataset.fromObject(object.conversationDataset);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a CreateConversationDatasetRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.CreateConversationDatasetRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.CreateConversationDatasetRequest} message CreateConversationDatasetRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        CreateConversationDatasetRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.conversationDataset = null;
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.conversationDataset != null && message.hasOwnProperty("conversationDataset"))
                                object.conversationDataset = $root.google.cloud.dialogflow.v2.ConversationDataset.toObject(message.conversationDataset, options);
                            return object;
                        };
    
                        /**
                         * Converts this CreateConversationDatasetRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.CreateConversationDatasetRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        CreateConversationDatasetRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for CreateConversationDatasetRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.CreateConversationDatasetRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        CreateConversationDatasetRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.CreateConversationDatasetRequest";
                        };
    
                        return CreateConversationDatasetRequest;
                    })();
    
                    v2.GetConversationDatasetRequest = (function() {
    
                        /**
                         * Properties of a GetConversationDatasetRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IGetConversationDatasetRequest
                         * @property {string|null} [name] GetConversationDatasetRequest name
                         */
    
                        /**
                         * Constructs a new GetConversationDatasetRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a GetConversationDatasetRequest.
                         * @implements IGetConversationDatasetRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IGetConversationDatasetRequest=} [properties] Properties to set
                         */
                        function GetConversationDatasetRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GetConversationDatasetRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2.GetConversationDatasetRequest
                         * @instance
                         */
                        GetConversationDatasetRequest.prototype.name = "";
    
                        /**
                         * Creates a new GetConversationDatasetRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.GetConversationDatasetRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetConversationDatasetRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.GetConversationDatasetRequest} GetConversationDatasetRequest instance
                         */
                        GetConversationDatasetRequest.create = function create(properties) {
                            return new GetConversationDatasetRequest(properties);
                        };
    
                        /**
                         * Encodes the specified GetConversationDatasetRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.GetConversationDatasetRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.GetConversationDatasetRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetConversationDatasetRequest} message GetConversationDatasetRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetConversationDatasetRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GetConversationDatasetRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.GetConversationDatasetRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GetConversationDatasetRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetConversationDatasetRequest} message GetConversationDatasetRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetConversationDatasetRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GetConversationDatasetRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.GetConversationDatasetRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.GetConversationDatasetRequest} GetConversationDatasetRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetConversationDatasetRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.GetConversationDatasetRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GetConversationDatasetRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GetConversationDatasetRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.GetConversationDatasetRequest} GetConversationDatasetRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetConversationDatasetRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GetConversationDatasetRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.GetConversationDatasetRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GetConversationDatasetRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a GetConversationDatasetRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.GetConversationDatasetRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.GetConversationDatasetRequest} GetConversationDatasetRequest
                         */
                        GetConversationDatasetRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.GetConversationDatasetRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.GetConversationDatasetRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GetConversationDatasetRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.GetConversationDatasetRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.GetConversationDatasetRequest} message GetConversationDatasetRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GetConversationDatasetRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.name = "";
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            return object;
                        };
    
                        /**
                         * Converts this GetConversationDatasetRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.GetConversationDatasetRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GetConversationDatasetRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GetConversationDatasetRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.GetConversationDatasetRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GetConversationDatasetRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.GetConversationDatasetRequest";
                        };
    
                        return GetConversationDatasetRequest;
                    })();
    
                    v2.ListConversationDatasetsRequest = (function() {
    
                        /**
                         * Properties of a ListConversationDatasetsRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IListConversationDatasetsRequest
                         * @property {string|null} [parent] ListConversationDatasetsRequest parent
                         * @property {number|null} [pageSize] ListConversationDatasetsRequest pageSize
                         * @property {string|null} [pageToken] ListConversationDatasetsRequest pageToken
                         */
    
                        /**
                         * Constructs a new ListConversationDatasetsRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a ListConversationDatasetsRequest.
                         * @implements IListConversationDatasetsRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IListConversationDatasetsRequest=} [properties] Properties to set
                         */
                        function ListConversationDatasetsRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListConversationDatasetsRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.ListConversationDatasetsRequest
                         * @instance
                         */
                        ListConversationDatasetsRequest.prototype.parent = "";
    
                        /**
                         * ListConversationDatasetsRequest pageSize.
                         * @member {number} pageSize
                         * @memberof google.cloud.dialogflow.v2.ListConversationDatasetsRequest
                         * @instance
                         */
                        ListConversationDatasetsRequest.prototype.pageSize = 0;
    
                        /**
                         * ListConversationDatasetsRequest pageToken.
                         * @member {string} pageToken
                         * @memberof google.cloud.dialogflow.v2.ListConversationDatasetsRequest
                         * @instance
                         */
                        ListConversationDatasetsRequest.prototype.pageToken = "";
    
                        /**
                         * Creates a new ListConversationDatasetsRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ListConversationDatasetsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListConversationDatasetsRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ListConversationDatasetsRequest} ListConversationDatasetsRequest instance
                         */
                        ListConversationDatasetsRequest.create = function create(properties) {
                            return new ListConversationDatasetsRequest(properties);
                        };
    
                        /**
                         * Encodes the specified ListConversationDatasetsRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.ListConversationDatasetsRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ListConversationDatasetsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListConversationDatasetsRequest} message ListConversationDatasetsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListConversationDatasetsRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.pageSize != null && Object.hasOwnProperty.call(message, "pageSize"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.pageSize);
                            if (message.pageToken != null && Object.hasOwnProperty.call(message, "pageToken"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.pageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListConversationDatasetsRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ListConversationDatasetsRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListConversationDatasetsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListConversationDatasetsRequest} message ListConversationDatasetsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListConversationDatasetsRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListConversationDatasetsRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ListConversationDatasetsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ListConversationDatasetsRequest} ListConversationDatasetsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListConversationDatasetsRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ListConversationDatasetsRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.pageSize = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.pageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListConversationDatasetsRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListConversationDatasetsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ListConversationDatasetsRequest} ListConversationDatasetsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListConversationDatasetsRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListConversationDatasetsRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ListConversationDatasetsRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListConversationDatasetsRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                if (!$util.isInteger(message.pageSize))
                                    return "pageSize: integer expected";
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                if (!$util.isString(message.pageToken))
                                    return "pageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListConversationDatasetsRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ListConversationDatasetsRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ListConversationDatasetsRequest} ListConversationDatasetsRequest
                         */
                        ListConversationDatasetsRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ListConversationDatasetsRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ListConversationDatasetsRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.pageSize != null)
                                message.pageSize = object.pageSize | 0;
                            if (object.pageToken != null)
                                message.pageToken = String(object.pageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListConversationDatasetsRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ListConversationDatasetsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ListConversationDatasetsRequest} message ListConversationDatasetsRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListConversationDatasetsRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.pageSize = 0;
                                object.pageToken = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                object.pageSize = message.pageSize;
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                object.pageToken = message.pageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListConversationDatasetsRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ListConversationDatasetsRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListConversationDatasetsRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListConversationDatasetsRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ListConversationDatasetsRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListConversationDatasetsRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ListConversationDatasetsRequest";
                        };
    
                        return ListConversationDatasetsRequest;
                    })();
    
                    v2.ListConversationDatasetsResponse = (function() {
    
                        /**
                         * Properties of a ListConversationDatasetsResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IListConversationDatasetsResponse
                         * @property {Array.<google.cloud.dialogflow.v2.IConversationDataset>|null} [conversationDatasets] ListConversationDatasetsResponse conversationDatasets
                         * @property {string|null} [nextPageToken] ListConversationDatasetsResponse nextPageToken
                         */
    
                        /**
                         * Constructs a new ListConversationDatasetsResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a ListConversationDatasetsResponse.
                         * @implements IListConversationDatasetsResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IListConversationDatasetsResponse=} [properties] Properties to set
                         */
                        function ListConversationDatasetsResponse(properties) {
                            this.conversationDatasets = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListConversationDatasetsResponse conversationDatasets.
                         * @member {Array.<google.cloud.dialogflow.v2.IConversationDataset>} conversationDatasets
                         * @memberof google.cloud.dialogflow.v2.ListConversationDatasetsResponse
                         * @instance
                         */
                        ListConversationDatasetsResponse.prototype.conversationDatasets = $util.emptyArray;
    
                        /**
                         * ListConversationDatasetsResponse nextPageToken.
                         * @member {string} nextPageToken
                         * @memberof google.cloud.dialogflow.v2.ListConversationDatasetsResponse
                         * @instance
                         */
                        ListConversationDatasetsResponse.prototype.nextPageToken = "";
    
                        /**
                         * Creates a new ListConversationDatasetsResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ListConversationDatasetsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListConversationDatasetsResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ListConversationDatasetsResponse} ListConversationDatasetsResponse instance
                         */
                        ListConversationDatasetsResponse.create = function create(properties) {
                            return new ListConversationDatasetsResponse(properties);
                        };
    
                        /**
                         * Encodes the specified ListConversationDatasetsResponse message. Does not implicitly {@link google.cloud.dialogflow.v2.ListConversationDatasetsResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ListConversationDatasetsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListConversationDatasetsResponse} message ListConversationDatasetsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListConversationDatasetsResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.conversationDatasets != null && message.conversationDatasets.length)
                                for (var i = 0; i < message.conversationDatasets.length; ++i)
                                    $root.google.cloud.dialogflow.v2.ConversationDataset.encode(message.conversationDatasets[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.nextPageToken != null && Object.hasOwnProperty.call(message, "nextPageToken"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.nextPageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListConversationDatasetsResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ListConversationDatasetsResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListConversationDatasetsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListConversationDatasetsResponse} message ListConversationDatasetsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListConversationDatasetsResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListConversationDatasetsResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ListConversationDatasetsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ListConversationDatasetsResponse} ListConversationDatasetsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListConversationDatasetsResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ListConversationDatasetsResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.conversationDatasets && message.conversationDatasets.length))
                                            message.conversationDatasets = [];
                                        message.conversationDatasets.push($root.google.cloud.dialogflow.v2.ConversationDataset.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 2: {
                                        message.nextPageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListConversationDatasetsResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListConversationDatasetsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ListConversationDatasetsResponse} ListConversationDatasetsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListConversationDatasetsResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListConversationDatasetsResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ListConversationDatasetsResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListConversationDatasetsResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.conversationDatasets != null && message.hasOwnProperty("conversationDatasets")) {
                                if (!Array.isArray(message.conversationDatasets))
                                    return "conversationDatasets: array expected";
                                for (var i = 0; i < message.conversationDatasets.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.ConversationDataset.verify(message.conversationDatasets[i]);
                                    if (error)
                                        return "conversationDatasets." + error;
                                }
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                if (!$util.isString(message.nextPageToken))
                                    return "nextPageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListConversationDatasetsResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ListConversationDatasetsResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ListConversationDatasetsResponse} ListConversationDatasetsResponse
                         */
                        ListConversationDatasetsResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ListConversationDatasetsResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ListConversationDatasetsResponse();
                            if (object.conversationDatasets) {
                                if (!Array.isArray(object.conversationDatasets))
                                    throw TypeError(".google.cloud.dialogflow.v2.ListConversationDatasetsResponse.conversationDatasets: array expected");
                                message.conversationDatasets = [];
                                for (var i = 0; i < object.conversationDatasets.length; ++i) {
                                    if (typeof object.conversationDatasets[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.ListConversationDatasetsResponse.conversationDatasets: object expected");
                                    message.conversationDatasets[i] = $root.google.cloud.dialogflow.v2.ConversationDataset.fromObject(object.conversationDatasets[i]);
                                }
                            }
                            if (object.nextPageToken != null)
                                message.nextPageToken = String(object.nextPageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListConversationDatasetsResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ListConversationDatasetsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.ListConversationDatasetsResponse} message ListConversationDatasetsResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListConversationDatasetsResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.conversationDatasets = [];
                            if (options.defaults)
                                object.nextPageToken = "";
                            if (message.conversationDatasets && message.conversationDatasets.length) {
                                object.conversationDatasets = [];
                                for (var j = 0; j < message.conversationDatasets.length; ++j)
                                    object.conversationDatasets[j] = $root.google.cloud.dialogflow.v2.ConversationDataset.toObject(message.conversationDatasets[j], options);
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                object.nextPageToken = message.nextPageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListConversationDatasetsResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ListConversationDatasetsResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListConversationDatasetsResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListConversationDatasetsResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ListConversationDatasetsResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListConversationDatasetsResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ListConversationDatasetsResponse";
                        };
    
                        return ListConversationDatasetsResponse;
                    })();
    
                    v2.DeleteConversationDatasetRequest = (function() {
    
                        /**
                         * Properties of a DeleteConversationDatasetRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IDeleteConversationDatasetRequest
                         * @property {string|null} [name] DeleteConversationDatasetRequest name
                         */
    
                        /**
                         * Constructs a new DeleteConversationDatasetRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a DeleteConversationDatasetRequest.
                         * @implements IDeleteConversationDatasetRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IDeleteConversationDatasetRequest=} [properties] Properties to set
                         */
                        function DeleteConversationDatasetRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * DeleteConversationDatasetRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2.DeleteConversationDatasetRequest
                         * @instance
                         */
                        DeleteConversationDatasetRequest.prototype.name = "";
    
                        /**
                         * Creates a new DeleteConversationDatasetRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.DeleteConversationDatasetRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDeleteConversationDatasetRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.DeleteConversationDatasetRequest} DeleteConversationDatasetRequest instance
                         */
                        DeleteConversationDatasetRequest.create = function create(properties) {
                            return new DeleteConversationDatasetRequest(properties);
                        };
    
                        /**
                         * Encodes the specified DeleteConversationDatasetRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.DeleteConversationDatasetRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.DeleteConversationDatasetRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDeleteConversationDatasetRequest} message DeleteConversationDatasetRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteConversationDatasetRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified DeleteConversationDatasetRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.DeleteConversationDatasetRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.DeleteConversationDatasetRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDeleteConversationDatasetRequest} message DeleteConversationDatasetRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteConversationDatasetRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a DeleteConversationDatasetRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.DeleteConversationDatasetRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.DeleteConversationDatasetRequest} DeleteConversationDatasetRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteConversationDatasetRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.DeleteConversationDatasetRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a DeleteConversationDatasetRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.DeleteConversationDatasetRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.DeleteConversationDatasetRequest} DeleteConversationDatasetRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteConversationDatasetRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a DeleteConversationDatasetRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.DeleteConversationDatasetRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        DeleteConversationDatasetRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a DeleteConversationDatasetRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.DeleteConversationDatasetRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.DeleteConversationDatasetRequest} DeleteConversationDatasetRequest
                         */
                        DeleteConversationDatasetRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.DeleteConversationDatasetRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.DeleteConversationDatasetRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a DeleteConversationDatasetRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.DeleteConversationDatasetRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.DeleteConversationDatasetRequest} message DeleteConversationDatasetRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        DeleteConversationDatasetRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.name = "";
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            return object;
                        };
    
                        /**
                         * Converts this DeleteConversationDatasetRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.DeleteConversationDatasetRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        DeleteConversationDatasetRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for DeleteConversationDatasetRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.DeleteConversationDatasetRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        DeleteConversationDatasetRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.DeleteConversationDatasetRequest";
                        };
    
                        return DeleteConversationDatasetRequest;
                    })();
    
                    v2.ImportConversationDataRequest = (function() {
    
                        /**
                         * Properties of an ImportConversationDataRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IImportConversationDataRequest
                         * @property {string|null} [name] ImportConversationDataRequest name
                         * @property {google.cloud.dialogflow.v2.IInputConfig|null} [inputConfig] ImportConversationDataRequest inputConfig
                         */
    
                        /**
                         * Constructs a new ImportConversationDataRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an ImportConversationDataRequest.
                         * @implements IImportConversationDataRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IImportConversationDataRequest=} [properties] Properties to set
                         */
                        function ImportConversationDataRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ImportConversationDataRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2.ImportConversationDataRequest
                         * @instance
                         */
                        ImportConversationDataRequest.prototype.name = "";
    
                        /**
                         * ImportConversationDataRequest inputConfig.
                         * @member {google.cloud.dialogflow.v2.IInputConfig|null|undefined} inputConfig
                         * @memberof google.cloud.dialogflow.v2.ImportConversationDataRequest
                         * @instance
                         */
                        ImportConversationDataRequest.prototype.inputConfig = null;
    
                        /**
                         * Creates a new ImportConversationDataRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ImportConversationDataRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IImportConversationDataRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ImportConversationDataRequest} ImportConversationDataRequest instance
                         */
                        ImportConversationDataRequest.create = function create(properties) {
                            return new ImportConversationDataRequest(properties);
                        };
    
                        /**
                         * Encodes the specified ImportConversationDataRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.ImportConversationDataRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ImportConversationDataRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IImportConversationDataRequest} message ImportConversationDataRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ImportConversationDataRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            if (message.inputConfig != null && Object.hasOwnProperty.call(message, "inputConfig"))
                                $root.google.cloud.dialogflow.v2.InputConfig.encode(message.inputConfig, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ImportConversationDataRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ImportConversationDataRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ImportConversationDataRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IImportConversationDataRequest} message ImportConversationDataRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ImportConversationDataRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an ImportConversationDataRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ImportConversationDataRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ImportConversationDataRequest} ImportConversationDataRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ImportConversationDataRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ImportConversationDataRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.inputConfig = $root.google.cloud.dialogflow.v2.InputConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an ImportConversationDataRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ImportConversationDataRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ImportConversationDataRequest} ImportConversationDataRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ImportConversationDataRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an ImportConversationDataRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ImportConversationDataRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ImportConversationDataRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            if (message.inputConfig != null && message.hasOwnProperty("inputConfig")) {
                                var error = $root.google.cloud.dialogflow.v2.InputConfig.verify(message.inputConfig);
                                if (error)
                                    return "inputConfig." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates an ImportConversationDataRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ImportConversationDataRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ImportConversationDataRequest} ImportConversationDataRequest
                         */
                        ImportConversationDataRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ImportConversationDataRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ImportConversationDataRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            if (object.inputConfig != null) {
                                if (typeof object.inputConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.ImportConversationDataRequest.inputConfig: object expected");
                                message.inputConfig = $root.google.cloud.dialogflow.v2.InputConfig.fromObject(object.inputConfig);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an ImportConversationDataRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ImportConversationDataRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ImportConversationDataRequest} message ImportConversationDataRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ImportConversationDataRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.name = "";
                                object.inputConfig = null;
                            }
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            if (message.inputConfig != null && message.hasOwnProperty("inputConfig"))
                                object.inputConfig = $root.google.cloud.dialogflow.v2.InputConfig.toObject(message.inputConfig, options);
                            return object;
                        };
    
                        /**
                         * Converts this ImportConversationDataRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ImportConversationDataRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ImportConversationDataRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ImportConversationDataRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ImportConversationDataRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ImportConversationDataRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ImportConversationDataRequest";
                        };
    
                        return ImportConversationDataRequest;
                    })();
    
                    v2.ImportConversationDataOperationMetadata = (function() {
    
                        /**
                         * Properties of an ImportConversationDataOperationMetadata.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IImportConversationDataOperationMetadata
                         * @property {string|null} [conversationDataset] ImportConversationDataOperationMetadata conversationDataset
                         * @property {Array.<google.rpc.IStatus>|null} [partialFailures] ImportConversationDataOperationMetadata partialFailures
                         * @property {google.protobuf.ITimestamp|null} [createTime] ImportConversationDataOperationMetadata createTime
                         */
    
                        /**
                         * Constructs a new ImportConversationDataOperationMetadata.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an ImportConversationDataOperationMetadata.
                         * @implements IImportConversationDataOperationMetadata
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IImportConversationDataOperationMetadata=} [properties] Properties to set
                         */
                        function ImportConversationDataOperationMetadata(properties) {
                            this.partialFailures = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ImportConversationDataOperationMetadata conversationDataset.
                         * @member {string} conversationDataset
                         * @memberof google.cloud.dialogflow.v2.ImportConversationDataOperationMetadata
                         * @instance
                         */
                        ImportConversationDataOperationMetadata.prototype.conversationDataset = "";
    
                        /**
                         * ImportConversationDataOperationMetadata partialFailures.
                         * @member {Array.<google.rpc.IStatus>} partialFailures
                         * @memberof google.cloud.dialogflow.v2.ImportConversationDataOperationMetadata
                         * @instance
                         */
                        ImportConversationDataOperationMetadata.prototype.partialFailures = $util.emptyArray;
    
                        /**
                         * ImportConversationDataOperationMetadata createTime.
                         * @member {google.protobuf.ITimestamp|null|undefined} createTime
                         * @memberof google.cloud.dialogflow.v2.ImportConversationDataOperationMetadata
                         * @instance
                         */
                        ImportConversationDataOperationMetadata.prototype.createTime = null;
    
                        /**
                         * Creates a new ImportConversationDataOperationMetadata instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ImportConversationDataOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.IImportConversationDataOperationMetadata=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ImportConversationDataOperationMetadata} ImportConversationDataOperationMetadata instance
                         */
                        ImportConversationDataOperationMetadata.create = function create(properties) {
                            return new ImportConversationDataOperationMetadata(properties);
                        };
    
                        /**
                         * Encodes the specified ImportConversationDataOperationMetadata message. Does not implicitly {@link google.cloud.dialogflow.v2.ImportConversationDataOperationMetadata.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ImportConversationDataOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.IImportConversationDataOperationMetadata} message ImportConversationDataOperationMetadata message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ImportConversationDataOperationMetadata.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.conversationDataset != null && Object.hasOwnProperty.call(message, "conversationDataset"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.conversationDataset);
                            if (message.partialFailures != null && message.partialFailures.length)
                                for (var i = 0; i < message.partialFailures.length; ++i)
                                    $root.google.rpc.Status.encode(message.partialFailures[i], writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.createTime != null && Object.hasOwnProperty.call(message, "createTime"))
                                $root.google.protobuf.Timestamp.encode(message.createTime, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ImportConversationDataOperationMetadata message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ImportConversationDataOperationMetadata.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ImportConversationDataOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.IImportConversationDataOperationMetadata} message ImportConversationDataOperationMetadata message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ImportConversationDataOperationMetadata.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an ImportConversationDataOperationMetadata message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ImportConversationDataOperationMetadata
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ImportConversationDataOperationMetadata} ImportConversationDataOperationMetadata
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ImportConversationDataOperationMetadata.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ImportConversationDataOperationMetadata();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.conversationDataset = reader.string();
                                        break;
                                    }
                                case 2: {
                                        if (!(message.partialFailures && message.partialFailures.length))
                                            message.partialFailures = [];
                                        message.partialFailures.push($root.google.rpc.Status.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 3: {
                                        message.createTime = $root.google.protobuf.Timestamp.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an ImportConversationDataOperationMetadata message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ImportConversationDataOperationMetadata
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ImportConversationDataOperationMetadata} ImportConversationDataOperationMetadata
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ImportConversationDataOperationMetadata.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an ImportConversationDataOperationMetadata message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ImportConversationDataOperationMetadata
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ImportConversationDataOperationMetadata.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.conversationDataset != null && message.hasOwnProperty("conversationDataset"))
                                if (!$util.isString(message.conversationDataset))
                                    return "conversationDataset: string expected";
                            if (message.partialFailures != null && message.hasOwnProperty("partialFailures")) {
                                if (!Array.isArray(message.partialFailures))
                                    return "partialFailures: array expected";
                                for (var i = 0; i < message.partialFailures.length; ++i) {
                                    var error = $root.google.rpc.Status.verify(message.partialFailures[i]);
                                    if (error)
                                        return "partialFailures." + error;
                                }
                            }
                            if (message.createTime != null && message.hasOwnProperty("createTime")) {
                                var error = $root.google.protobuf.Timestamp.verify(message.createTime);
                                if (error)
                                    return "createTime." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates an ImportConversationDataOperationMetadata message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ImportConversationDataOperationMetadata
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ImportConversationDataOperationMetadata} ImportConversationDataOperationMetadata
                         */
                        ImportConversationDataOperationMetadata.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ImportConversationDataOperationMetadata)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ImportConversationDataOperationMetadata();
                            if (object.conversationDataset != null)
                                message.conversationDataset = String(object.conversationDataset);
                            if (object.partialFailures) {
                                if (!Array.isArray(object.partialFailures))
                                    throw TypeError(".google.cloud.dialogflow.v2.ImportConversationDataOperationMetadata.partialFailures: array expected");
                                message.partialFailures = [];
                                for (var i = 0; i < object.partialFailures.length; ++i) {
                                    if (typeof object.partialFailures[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.ImportConversationDataOperationMetadata.partialFailures: object expected");
                                    message.partialFailures[i] = $root.google.rpc.Status.fromObject(object.partialFailures[i]);
                                }
                            }
                            if (object.createTime != null) {
                                if (typeof object.createTime !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.ImportConversationDataOperationMetadata.createTime: object expected");
                                message.createTime = $root.google.protobuf.Timestamp.fromObject(object.createTime);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an ImportConversationDataOperationMetadata message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ImportConversationDataOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.ImportConversationDataOperationMetadata} message ImportConversationDataOperationMetadata
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ImportConversationDataOperationMetadata.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.partialFailures = [];
                            if (options.defaults) {
                                object.conversationDataset = "";
                                object.createTime = null;
                            }
                            if (message.conversationDataset != null && message.hasOwnProperty("conversationDataset"))
                                object.conversationDataset = message.conversationDataset;
                            if (message.partialFailures && message.partialFailures.length) {
                                object.partialFailures = [];
                                for (var j = 0; j < message.partialFailures.length; ++j)
                                    object.partialFailures[j] = $root.google.rpc.Status.toObject(message.partialFailures[j], options);
                            }
                            if (message.createTime != null && message.hasOwnProperty("createTime"))
                                object.createTime = $root.google.protobuf.Timestamp.toObject(message.createTime, options);
                            return object;
                        };
    
                        /**
                         * Converts this ImportConversationDataOperationMetadata to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ImportConversationDataOperationMetadata
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ImportConversationDataOperationMetadata.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ImportConversationDataOperationMetadata
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ImportConversationDataOperationMetadata
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ImportConversationDataOperationMetadata.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ImportConversationDataOperationMetadata";
                        };
    
                        return ImportConversationDataOperationMetadata;
                    })();
    
                    v2.ImportConversationDataOperationResponse = (function() {
    
                        /**
                         * Properties of an ImportConversationDataOperationResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IImportConversationDataOperationResponse
                         * @property {string|null} [conversationDataset] ImportConversationDataOperationResponse conversationDataset
                         * @property {number|null} [importCount] ImportConversationDataOperationResponse importCount
                         */
    
                        /**
                         * Constructs a new ImportConversationDataOperationResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an ImportConversationDataOperationResponse.
                         * @implements IImportConversationDataOperationResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IImportConversationDataOperationResponse=} [properties] Properties to set
                         */
                        function ImportConversationDataOperationResponse(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ImportConversationDataOperationResponse conversationDataset.
                         * @member {string} conversationDataset
                         * @memberof google.cloud.dialogflow.v2.ImportConversationDataOperationResponse
                         * @instance
                         */
                        ImportConversationDataOperationResponse.prototype.conversationDataset = "";
    
                        /**
                         * ImportConversationDataOperationResponse importCount.
                         * @member {number} importCount
                         * @memberof google.cloud.dialogflow.v2.ImportConversationDataOperationResponse
                         * @instance
                         */
                        ImportConversationDataOperationResponse.prototype.importCount = 0;
    
                        /**
                         * Creates a new ImportConversationDataOperationResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ImportConversationDataOperationResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IImportConversationDataOperationResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ImportConversationDataOperationResponse} ImportConversationDataOperationResponse instance
                         */
                        ImportConversationDataOperationResponse.create = function create(properties) {
                            return new ImportConversationDataOperationResponse(properties);
                        };
    
                        /**
                         * Encodes the specified ImportConversationDataOperationResponse message. Does not implicitly {@link google.cloud.dialogflow.v2.ImportConversationDataOperationResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ImportConversationDataOperationResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IImportConversationDataOperationResponse} message ImportConversationDataOperationResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ImportConversationDataOperationResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.conversationDataset != null && Object.hasOwnProperty.call(message, "conversationDataset"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.conversationDataset);
                            if (message.importCount != null && Object.hasOwnProperty.call(message, "importCount"))
                                writer.uint32(/* id 3, wireType 0 =*/24).int32(message.importCount);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ImportConversationDataOperationResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ImportConversationDataOperationResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ImportConversationDataOperationResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IImportConversationDataOperationResponse} message ImportConversationDataOperationResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ImportConversationDataOperationResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an ImportConversationDataOperationResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ImportConversationDataOperationResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ImportConversationDataOperationResponse} ImportConversationDataOperationResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ImportConversationDataOperationResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ImportConversationDataOperationResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.conversationDataset = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.importCount = reader.int32();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an ImportConversationDataOperationResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ImportConversationDataOperationResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ImportConversationDataOperationResponse} ImportConversationDataOperationResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ImportConversationDataOperationResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an ImportConversationDataOperationResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ImportConversationDataOperationResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ImportConversationDataOperationResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.conversationDataset != null && message.hasOwnProperty("conversationDataset"))
                                if (!$util.isString(message.conversationDataset))
                                    return "conversationDataset: string expected";
                            if (message.importCount != null && message.hasOwnProperty("importCount"))
                                if (!$util.isInteger(message.importCount))
                                    return "importCount: integer expected";
                            return null;
                        };
    
                        /**
                         * Creates an ImportConversationDataOperationResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ImportConversationDataOperationResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ImportConversationDataOperationResponse} ImportConversationDataOperationResponse
                         */
                        ImportConversationDataOperationResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ImportConversationDataOperationResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ImportConversationDataOperationResponse();
                            if (object.conversationDataset != null)
                                message.conversationDataset = String(object.conversationDataset);
                            if (object.importCount != null)
                                message.importCount = object.importCount | 0;
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an ImportConversationDataOperationResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ImportConversationDataOperationResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.ImportConversationDataOperationResponse} message ImportConversationDataOperationResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ImportConversationDataOperationResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.conversationDataset = "";
                                object.importCount = 0;
                            }
                            if (message.conversationDataset != null && message.hasOwnProperty("conversationDataset"))
                                object.conversationDataset = message.conversationDataset;
                            if (message.importCount != null && message.hasOwnProperty("importCount"))
                                object.importCount = message.importCount;
                            return object;
                        };
    
                        /**
                         * Converts this ImportConversationDataOperationResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ImportConversationDataOperationResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ImportConversationDataOperationResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ImportConversationDataOperationResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ImportConversationDataOperationResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ImportConversationDataOperationResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ImportConversationDataOperationResponse";
                        };
    
                        return ImportConversationDataOperationResponse;
                    })();
    
                    v2.CreateConversationDatasetOperationMetadata = (function() {
    
                        /**
                         * Properties of a CreateConversationDatasetOperationMetadata.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ICreateConversationDatasetOperationMetadata
                         * @property {string|null} [conversationDataset] CreateConversationDatasetOperationMetadata conversationDataset
                         */
    
                        /**
                         * Constructs a new CreateConversationDatasetOperationMetadata.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a CreateConversationDatasetOperationMetadata.
                         * @implements ICreateConversationDatasetOperationMetadata
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ICreateConversationDatasetOperationMetadata=} [properties] Properties to set
                         */
                        function CreateConversationDatasetOperationMetadata(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * CreateConversationDatasetOperationMetadata conversationDataset.
                         * @member {string} conversationDataset
                         * @memberof google.cloud.dialogflow.v2.CreateConversationDatasetOperationMetadata
                         * @instance
                         */
                        CreateConversationDatasetOperationMetadata.prototype.conversationDataset = "";
    
                        /**
                         * Creates a new CreateConversationDatasetOperationMetadata instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.CreateConversationDatasetOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICreateConversationDatasetOperationMetadata=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.CreateConversationDatasetOperationMetadata} CreateConversationDatasetOperationMetadata instance
                         */
                        CreateConversationDatasetOperationMetadata.create = function create(properties) {
                            return new CreateConversationDatasetOperationMetadata(properties);
                        };
    
                        /**
                         * Encodes the specified CreateConversationDatasetOperationMetadata message. Does not implicitly {@link google.cloud.dialogflow.v2.CreateConversationDatasetOperationMetadata.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.CreateConversationDatasetOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICreateConversationDatasetOperationMetadata} message CreateConversationDatasetOperationMetadata message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateConversationDatasetOperationMetadata.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.conversationDataset != null && Object.hasOwnProperty.call(message, "conversationDataset"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.conversationDataset);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified CreateConversationDatasetOperationMetadata message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.CreateConversationDatasetOperationMetadata.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.CreateConversationDatasetOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICreateConversationDatasetOperationMetadata} message CreateConversationDatasetOperationMetadata message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateConversationDatasetOperationMetadata.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a CreateConversationDatasetOperationMetadata message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.CreateConversationDatasetOperationMetadata
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.CreateConversationDatasetOperationMetadata} CreateConversationDatasetOperationMetadata
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateConversationDatasetOperationMetadata.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.CreateConversationDatasetOperationMetadata();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.conversationDataset = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a CreateConversationDatasetOperationMetadata message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.CreateConversationDatasetOperationMetadata
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.CreateConversationDatasetOperationMetadata} CreateConversationDatasetOperationMetadata
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateConversationDatasetOperationMetadata.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a CreateConversationDatasetOperationMetadata message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.CreateConversationDatasetOperationMetadata
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        CreateConversationDatasetOperationMetadata.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.conversationDataset != null && message.hasOwnProperty("conversationDataset"))
                                if (!$util.isString(message.conversationDataset))
                                    return "conversationDataset: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a CreateConversationDatasetOperationMetadata message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.CreateConversationDatasetOperationMetadata
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.CreateConversationDatasetOperationMetadata} CreateConversationDatasetOperationMetadata
                         */
                        CreateConversationDatasetOperationMetadata.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.CreateConversationDatasetOperationMetadata)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.CreateConversationDatasetOperationMetadata();
                            if (object.conversationDataset != null)
                                message.conversationDataset = String(object.conversationDataset);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a CreateConversationDatasetOperationMetadata message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.CreateConversationDatasetOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.CreateConversationDatasetOperationMetadata} message CreateConversationDatasetOperationMetadata
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        CreateConversationDatasetOperationMetadata.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.conversationDataset = "";
                            if (message.conversationDataset != null && message.hasOwnProperty("conversationDataset"))
                                object.conversationDataset = message.conversationDataset;
                            return object;
                        };
    
                        /**
                         * Converts this CreateConversationDatasetOperationMetadata to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.CreateConversationDatasetOperationMetadata
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        CreateConversationDatasetOperationMetadata.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for CreateConversationDatasetOperationMetadata
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.CreateConversationDatasetOperationMetadata
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        CreateConversationDatasetOperationMetadata.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.CreateConversationDatasetOperationMetadata";
                        };
    
                        return CreateConversationDatasetOperationMetadata;
                    })();
    
                    v2.DeleteConversationDatasetOperationMetadata = (function() {
    
                        /**
                         * Properties of a DeleteConversationDatasetOperationMetadata.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IDeleteConversationDatasetOperationMetadata
                         */
    
                        /**
                         * Constructs a new DeleteConversationDatasetOperationMetadata.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a DeleteConversationDatasetOperationMetadata.
                         * @implements IDeleteConversationDatasetOperationMetadata
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IDeleteConversationDatasetOperationMetadata=} [properties] Properties to set
                         */
                        function DeleteConversationDatasetOperationMetadata(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * Creates a new DeleteConversationDatasetOperationMetadata instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.DeleteConversationDatasetOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDeleteConversationDatasetOperationMetadata=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.DeleteConversationDatasetOperationMetadata} DeleteConversationDatasetOperationMetadata instance
                         */
                        DeleteConversationDatasetOperationMetadata.create = function create(properties) {
                            return new DeleteConversationDatasetOperationMetadata(properties);
                        };
    
                        /**
                         * Encodes the specified DeleteConversationDatasetOperationMetadata message. Does not implicitly {@link google.cloud.dialogflow.v2.DeleteConversationDatasetOperationMetadata.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.DeleteConversationDatasetOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDeleteConversationDatasetOperationMetadata} message DeleteConversationDatasetOperationMetadata message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteConversationDatasetOperationMetadata.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified DeleteConversationDatasetOperationMetadata message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.DeleteConversationDatasetOperationMetadata.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.DeleteConversationDatasetOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDeleteConversationDatasetOperationMetadata} message DeleteConversationDatasetOperationMetadata message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteConversationDatasetOperationMetadata.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a DeleteConversationDatasetOperationMetadata message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.DeleteConversationDatasetOperationMetadata
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.DeleteConversationDatasetOperationMetadata} DeleteConversationDatasetOperationMetadata
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteConversationDatasetOperationMetadata.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.DeleteConversationDatasetOperationMetadata();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a DeleteConversationDatasetOperationMetadata message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.DeleteConversationDatasetOperationMetadata
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.DeleteConversationDatasetOperationMetadata} DeleteConversationDatasetOperationMetadata
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteConversationDatasetOperationMetadata.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a DeleteConversationDatasetOperationMetadata message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.DeleteConversationDatasetOperationMetadata
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        DeleteConversationDatasetOperationMetadata.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            return null;
                        };
    
                        /**
                         * Creates a DeleteConversationDatasetOperationMetadata message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.DeleteConversationDatasetOperationMetadata
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.DeleteConversationDatasetOperationMetadata} DeleteConversationDatasetOperationMetadata
                         */
                        DeleteConversationDatasetOperationMetadata.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.DeleteConversationDatasetOperationMetadata)
                                return object;
                            return new $root.google.cloud.dialogflow.v2.DeleteConversationDatasetOperationMetadata();
                        };
    
                        /**
                         * Creates a plain object from a DeleteConversationDatasetOperationMetadata message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.DeleteConversationDatasetOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.DeleteConversationDatasetOperationMetadata} message DeleteConversationDatasetOperationMetadata
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        DeleteConversationDatasetOperationMetadata.toObject = function toObject() {
                            return {};
                        };
    
                        /**
                         * Converts this DeleteConversationDatasetOperationMetadata to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.DeleteConversationDatasetOperationMetadata
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        DeleteConversationDatasetOperationMetadata.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for DeleteConversationDatasetOperationMetadata
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.DeleteConversationDatasetOperationMetadata
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        DeleteConversationDatasetOperationMetadata.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.DeleteConversationDatasetOperationMetadata";
                        };
    
                        return DeleteConversationDatasetOperationMetadata;
                    })();
    
                    v2.GcsSources = (function() {
    
                        /**
                         * Properties of a GcsSources.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IGcsSources
                         * @property {Array.<string>|null} [uris] GcsSources uris
                         */
    
                        /**
                         * Constructs a new GcsSources.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a GcsSources.
                         * @implements IGcsSources
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IGcsSources=} [properties] Properties to set
                         */
                        function GcsSources(properties) {
                            this.uris = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GcsSources uris.
                         * @member {Array.<string>} uris
                         * @memberof google.cloud.dialogflow.v2.GcsSources
                         * @instance
                         */
                        GcsSources.prototype.uris = $util.emptyArray;
    
                        /**
                         * Creates a new GcsSources instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.GcsSources
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGcsSources=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.GcsSources} GcsSources instance
                         */
                        GcsSources.create = function create(properties) {
                            return new GcsSources(properties);
                        };
    
                        /**
                         * Encodes the specified GcsSources message. Does not implicitly {@link google.cloud.dialogflow.v2.GcsSources.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.GcsSources
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGcsSources} message GcsSources message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GcsSources.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.uris != null && message.uris.length)
                                for (var i = 0; i < message.uris.length; ++i)
                                    writer.uint32(/* id 2, wireType 2 =*/18).string(message.uris[i]);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GcsSources message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.GcsSources.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GcsSources
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGcsSources} message GcsSources message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GcsSources.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GcsSources message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.GcsSources
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.GcsSources} GcsSources
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GcsSources.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.GcsSources();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 2: {
                                        if (!(message.uris && message.uris.length))
                                            message.uris = [];
                                        message.uris.push(reader.string());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GcsSources message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GcsSources
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.GcsSources} GcsSources
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GcsSources.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GcsSources message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.GcsSources
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GcsSources.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.uris != null && message.hasOwnProperty("uris")) {
                                if (!Array.isArray(message.uris))
                                    return "uris: array expected";
                                for (var i = 0; i < message.uris.length; ++i)
                                    if (!$util.isString(message.uris[i]))
                                        return "uris: string[] expected";
                            }
                            return null;
                        };
    
                        /**
                         * Creates a GcsSources message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.GcsSources
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.GcsSources} GcsSources
                         */
                        GcsSources.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.GcsSources)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.GcsSources();
                            if (object.uris) {
                                if (!Array.isArray(object.uris))
                                    throw TypeError(".google.cloud.dialogflow.v2.GcsSources.uris: array expected");
                                message.uris = [];
                                for (var i = 0; i < object.uris.length; ++i)
                                    message.uris[i] = String(object.uris[i]);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GcsSources message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.GcsSources
                         * @static
                         * @param {google.cloud.dialogflow.v2.GcsSources} message GcsSources
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GcsSources.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.uris = [];
                            if (message.uris && message.uris.length) {
                                object.uris = [];
                                for (var j = 0; j < message.uris.length; ++j)
                                    object.uris[j] = message.uris[j];
                            }
                            return object;
                        };
    
                        /**
                         * Converts this GcsSources to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.GcsSources
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GcsSources.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GcsSources
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.GcsSources
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GcsSources.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.GcsSources";
                        };
    
                        return GcsSources;
                    })();
    
                    v2.GcsDestination = (function() {
    
                        /**
                         * Properties of a GcsDestination.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IGcsDestination
                         * @property {string|null} [uri] GcsDestination uri
                         */
    
                        /**
                         * Constructs a new GcsDestination.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a GcsDestination.
                         * @implements IGcsDestination
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IGcsDestination=} [properties] Properties to set
                         */
                        function GcsDestination(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GcsDestination uri.
                         * @member {string} uri
                         * @memberof google.cloud.dialogflow.v2.GcsDestination
                         * @instance
                         */
                        GcsDestination.prototype.uri = "";
    
                        /**
                         * Creates a new GcsDestination instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.GcsDestination
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGcsDestination=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.GcsDestination} GcsDestination instance
                         */
                        GcsDestination.create = function create(properties) {
                            return new GcsDestination(properties);
                        };
    
                        /**
                         * Encodes the specified GcsDestination message. Does not implicitly {@link google.cloud.dialogflow.v2.GcsDestination.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.GcsDestination
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGcsDestination} message GcsDestination message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GcsDestination.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.uri != null && Object.hasOwnProperty.call(message, "uri"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.uri);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GcsDestination message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.GcsDestination.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GcsDestination
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGcsDestination} message GcsDestination message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GcsDestination.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GcsDestination message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.GcsDestination
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.GcsDestination} GcsDestination
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GcsDestination.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.GcsDestination();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.uri = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GcsDestination message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GcsDestination
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.GcsDestination} GcsDestination
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GcsDestination.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GcsDestination message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.GcsDestination
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GcsDestination.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.uri != null && message.hasOwnProperty("uri"))
                                if (!$util.isString(message.uri))
                                    return "uri: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a GcsDestination message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.GcsDestination
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.GcsDestination} GcsDestination
                         */
                        GcsDestination.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.GcsDestination)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.GcsDestination();
                            if (object.uri != null)
                                message.uri = String(object.uri);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GcsDestination message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.GcsDestination
                         * @static
                         * @param {google.cloud.dialogflow.v2.GcsDestination} message GcsDestination
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GcsDestination.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.uri = "";
                            if (message.uri != null && message.hasOwnProperty("uri"))
                                object.uri = message.uri;
                            return object;
                        };
    
                        /**
                         * Converts this GcsDestination to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.GcsDestination
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GcsDestination.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GcsDestination
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.GcsDestination
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GcsDestination.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.GcsDestination";
                        };
    
                        return GcsDestination;
                    })();
    
                    v2.ConversationEvent = (function() {
    
                        /**
                         * Properties of a ConversationEvent.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IConversationEvent
                         * @property {string|null} [conversation] ConversationEvent conversation
                         * @property {google.cloud.dialogflow.v2.ConversationEvent.Type|null} [type] ConversationEvent type
                         * @property {google.rpc.IStatus|null} [errorStatus] ConversationEvent errorStatus
                         * @property {google.cloud.dialogflow.v2.IMessage|null} [newMessagePayload] ConversationEvent newMessagePayload
                         * @property {google.cloud.dialogflow.v2.IStreamingRecognitionResult|null} [newRecognitionResultPayload] ConversationEvent newRecognitionResultPayload
                         */
    
                        /**
                         * Constructs a new ConversationEvent.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a ConversationEvent.
                         * @implements IConversationEvent
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IConversationEvent=} [properties] Properties to set
                         */
                        function ConversationEvent(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ConversationEvent conversation.
                         * @member {string} conversation
                         * @memberof google.cloud.dialogflow.v2.ConversationEvent
                         * @instance
                         */
                        ConversationEvent.prototype.conversation = "";
    
                        /**
                         * ConversationEvent type.
                         * @member {google.cloud.dialogflow.v2.ConversationEvent.Type} type
                         * @memberof google.cloud.dialogflow.v2.ConversationEvent
                         * @instance
                         */
                        ConversationEvent.prototype.type = 0;
    
                        /**
                         * ConversationEvent errorStatus.
                         * @member {google.rpc.IStatus|null|undefined} errorStatus
                         * @memberof google.cloud.dialogflow.v2.ConversationEvent
                         * @instance
                         */
                        ConversationEvent.prototype.errorStatus = null;
    
                        /**
                         * ConversationEvent newMessagePayload.
                         * @member {google.cloud.dialogflow.v2.IMessage|null|undefined} newMessagePayload
                         * @memberof google.cloud.dialogflow.v2.ConversationEvent
                         * @instance
                         */
                        ConversationEvent.prototype.newMessagePayload = null;
    
                        /**
                         * ConversationEvent newRecognitionResultPayload.
                         * @member {google.cloud.dialogflow.v2.IStreamingRecognitionResult|null|undefined} newRecognitionResultPayload
                         * @memberof google.cloud.dialogflow.v2.ConversationEvent
                         * @instance
                         */
                        ConversationEvent.prototype.newRecognitionResultPayload = null;
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * ConversationEvent payload.
                         * @member {"newMessagePayload"|"newRecognitionResultPayload"|undefined} payload
                         * @memberof google.cloud.dialogflow.v2.ConversationEvent
                         * @instance
                         */
                        Object.defineProperty(ConversationEvent.prototype, "payload", {
                            get: $util.oneOfGetter($oneOfFields = ["newMessagePayload", "newRecognitionResultPayload"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new ConversationEvent instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ConversationEvent
                         * @static
                         * @param {google.cloud.dialogflow.v2.IConversationEvent=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ConversationEvent} ConversationEvent instance
                         */
                        ConversationEvent.create = function create(properties) {
                            return new ConversationEvent(properties);
                        };
    
                        /**
                         * Encodes the specified ConversationEvent message. Does not implicitly {@link google.cloud.dialogflow.v2.ConversationEvent.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ConversationEvent
                         * @static
                         * @param {google.cloud.dialogflow.v2.IConversationEvent} message ConversationEvent message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ConversationEvent.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.conversation != null && Object.hasOwnProperty.call(message, "conversation"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.conversation);
                            if (message.type != null && Object.hasOwnProperty.call(message, "type"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.type);
                            if (message.errorStatus != null && Object.hasOwnProperty.call(message, "errorStatus"))
                                $root.google.rpc.Status.encode(message.errorStatus, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            if (message.newMessagePayload != null && Object.hasOwnProperty.call(message, "newMessagePayload"))
                                $root.google.cloud.dialogflow.v2.Message.encode(message.newMessagePayload, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            if (message.newRecognitionResultPayload != null && Object.hasOwnProperty.call(message, "newRecognitionResultPayload"))
                                $root.google.cloud.dialogflow.v2.StreamingRecognitionResult.encode(message.newRecognitionResultPayload, writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ConversationEvent message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ConversationEvent.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ConversationEvent
                         * @static
                         * @param {google.cloud.dialogflow.v2.IConversationEvent} message ConversationEvent message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ConversationEvent.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ConversationEvent message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ConversationEvent
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ConversationEvent} ConversationEvent
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ConversationEvent.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ConversationEvent();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.conversation = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.type = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.errorStatus = $root.google.rpc.Status.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 4: {
                                        message.newMessagePayload = $root.google.cloud.dialogflow.v2.Message.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 5: {
                                        message.newRecognitionResultPayload = $root.google.cloud.dialogflow.v2.StreamingRecognitionResult.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ConversationEvent message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ConversationEvent
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ConversationEvent} ConversationEvent
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ConversationEvent.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ConversationEvent message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ConversationEvent
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ConversationEvent.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.conversation != null && message.hasOwnProperty("conversation"))
                                if (!$util.isString(message.conversation))
                                    return "conversation: string expected";
                            if (message.type != null && message.hasOwnProperty("type"))
                                switch (message.type) {
                                default:
                                    return "type: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                case 5:
                                case 7:
                                case 4:
                                    break;
                                }
                            if (message.errorStatus != null && message.hasOwnProperty("errorStatus")) {
                                var error = $root.google.rpc.Status.verify(message.errorStatus);
                                if (error)
                                    return "errorStatus." + error;
                            }
                            if (message.newMessagePayload != null && message.hasOwnProperty("newMessagePayload")) {
                                properties.payload = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2.Message.verify(message.newMessagePayload);
                                    if (error)
                                        return "newMessagePayload." + error;
                                }
                            }
                            if (message.newRecognitionResultPayload != null && message.hasOwnProperty("newRecognitionResultPayload")) {
                                if (properties.payload === 1)
                                    return "payload: multiple values";
                                properties.payload = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2.StreamingRecognitionResult.verify(message.newRecognitionResultPayload);
                                    if (error)
                                        return "newRecognitionResultPayload." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates a ConversationEvent message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ConversationEvent
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ConversationEvent} ConversationEvent
                         */
                        ConversationEvent.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ConversationEvent)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ConversationEvent();
                            if (object.conversation != null)
                                message.conversation = String(object.conversation);
                            switch (object.type) {
                            default:
                                if (typeof object.type === "number") {
                                    message.type = object.type;
                                    break;
                                }
                                break;
                            case "TYPE_UNSPECIFIED":
                            case 0:
                                message.type = 0;
                                break;
                            case "CONVERSATION_STARTED":
                            case 1:
                                message.type = 1;
                                break;
                            case "CONVERSATION_FINISHED":
                            case 2:
                                message.type = 2;
                                break;
                            case "HUMAN_INTERVENTION_NEEDED":
                            case 3:
                                message.type = 3;
                                break;
                            case "NEW_MESSAGE":
                            case 5:
                                message.type = 5;
                                break;
                            case "NEW_RECOGNITION_RESULT":
                            case 7:
                                message.type = 7;
                                break;
                            case "UNRECOVERABLE_ERROR":
                            case 4:
                                message.type = 4;
                                break;
                            }
                            if (object.errorStatus != null) {
                                if (typeof object.errorStatus !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.ConversationEvent.errorStatus: object expected");
                                message.errorStatus = $root.google.rpc.Status.fromObject(object.errorStatus);
                            }
                            if (object.newMessagePayload != null) {
                                if (typeof object.newMessagePayload !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.ConversationEvent.newMessagePayload: object expected");
                                message.newMessagePayload = $root.google.cloud.dialogflow.v2.Message.fromObject(object.newMessagePayload);
                            }
                            if (object.newRecognitionResultPayload != null) {
                                if (typeof object.newRecognitionResultPayload !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.ConversationEvent.newRecognitionResultPayload: object expected");
                                message.newRecognitionResultPayload = $root.google.cloud.dialogflow.v2.StreamingRecognitionResult.fromObject(object.newRecognitionResultPayload);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ConversationEvent message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ConversationEvent
                         * @static
                         * @param {google.cloud.dialogflow.v2.ConversationEvent} message ConversationEvent
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ConversationEvent.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.conversation = "";
                                object.type = options.enums === String ? "TYPE_UNSPECIFIED" : 0;
                                object.errorStatus = null;
                            }
                            if (message.conversation != null && message.hasOwnProperty("conversation"))
                                object.conversation = message.conversation;
                            if (message.type != null && message.hasOwnProperty("type"))
                                object.type = options.enums === String ? $root.google.cloud.dialogflow.v2.ConversationEvent.Type[message.type] === undefined ? message.type : $root.google.cloud.dialogflow.v2.ConversationEvent.Type[message.type] : message.type;
                            if (message.errorStatus != null && message.hasOwnProperty("errorStatus"))
                                object.errorStatus = $root.google.rpc.Status.toObject(message.errorStatus, options);
                            if (message.newMessagePayload != null && message.hasOwnProperty("newMessagePayload")) {
                                object.newMessagePayload = $root.google.cloud.dialogflow.v2.Message.toObject(message.newMessagePayload, options);
                                if (options.oneofs)
                                    object.payload = "newMessagePayload";
                            }
                            if (message.newRecognitionResultPayload != null && message.hasOwnProperty("newRecognitionResultPayload")) {
                                object.newRecognitionResultPayload = $root.google.cloud.dialogflow.v2.StreamingRecognitionResult.toObject(message.newRecognitionResultPayload, options);
                                if (options.oneofs)
                                    object.payload = "newRecognitionResultPayload";
                            }
                            return object;
                        };
    
                        /**
                         * Converts this ConversationEvent to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ConversationEvent
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ConversationEvent.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ConversationEvent
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ConversationEvent
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ConversationEvent.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ConversationEvent";
                        };
    
                        /**
                         * Type enum.
                         * @name google.cloud.dialogflow.v2.ConversationEvent.Type
                         * @enum {number}
                         * @property {number} TYPE_UNSPECIFIED=0 TYPE_UNSPECIFIED value
                         * @property {number} CONVERSATION_STARTED=1 CONVERSATION_STARTED value
                         * @property {number} CONVERSATION_FINISHED=2 CONVERSATION_FINISHED value
                         * @property {number} HUMAN_INTERVENTION_NEEDED=3 HUMAN_INTERVENTION_NEEDED value
                         * @property {number} NEW_MESSAGE=5 NEW_MESSAGE value
                         * @property {number} NEW_RECOGNITION_RESULT=7 NEW_RECOGNITION_RESULT value
                         * @property {number} UNRECOVERABLE_ERROR=4 UNRECOVERABLE_ERROR value
                         */
                        ConversationEvent.Type = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "TYPE_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "CONVERSATION_STARTED"] = 1;
                            values[valuesById[2] = "CONVERSATION_FINISHED"] = 2;
                            values[valuesById[3] = "HUMAN_INTERVENTION_NEEDED"] = 3;
                            values[valuesById[5] = "NEW_MESSAGE"] = 5;
                            values[valuesById[7] = "NEW_RECOGNITION_RESULT"] = 7;
                            values[valuesById[4] = "UNRECOVERABLE_ERROR"] = 4;
                            return values;
                        })();
    
                        return ConversationEvent;
                    })();
    
                    v2.ConversationModels = (function() {
    
                        /**
                         * Constructs a new ConversationModels service.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a ConversationModels
                         * @extends $protobuf.rpc.Service
                         * @constructor
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         */
                        function ConversationModels(rpcImpl, requestDelimited, responseDelimited) {
                            $protobuf.rpc.Service.call(this, rpcImpl, requestDelimited, responseDelimited);
                        }
    
                        (ConversationModels.prototype = Object.create($protobuf.rpc.Service.prototype)).constructor = ConversationModels;
    
                        /**
                         * Creates new ConversationModels service using the specified rpc implementation.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ConversationModels
                         * @static
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         * @returns {ConversationModels} RPC service. Useful where requests and/or responses are streamed.
                         */
                        ConversationModels.create = function create(rpcImpl, requestDelimited, responseDelimited) {
                            return new this(rpcImpl, requestDelimited, responseDelimited);
                        };
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.ConversationModels|createConversationModel}.
                         * @memberof google.cloud.dialogflow.v2.ConversationModels
                         * @typedef CreateConversationModelCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.longrunning.Operation} [response] Operation
                         */
    
                        /**
                         * Calls CreateConversationModel.
                         * @function createConversationModel
                         * @memberof google.cloud.dialogflow.v2.ConversationModels
                         * @instance
                         * @param {google.cloud.dialogflow.v2.ICreateConversationModelRequest} request CreateConversationModelRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.ConversationModels.CreateConversationModelCallback} callback Node-style callback called with the error, if any, and Operation
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(ConversationModels.prototype.createConversationModel = function createConversationModel(request, callback) {
                            return this.rpcCall(createConversationModel, $root.google.cloud.dialogflow.v2.CreateConversationModelRequest, $root.google.longrunning.Operation, request, callback);
                        }, "name", { value: "CreateConversationModel" });
    
                        /**
                         * Calls CreateConversationModel.
                         * @function createConversationModel
                         * @memberof google.cloud.dialogflow.v2.ConversationModels
                         * @instance
                         * @param {google.cloud.dialogflow.v2.ICreateConversationModelRequest} request CreateConversationModelRequest message or plain object
                         * @returns {Promise<google.longrunning.Operation>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.ConversationModels|getConversationModel}.
                         * @memberof google.cloud.dialogflow.v2.ConversationModels
                         * @typedef GetConversationModelCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.ConversationModel} [response] ConversationModel
                         */
    
                        /**
                         * Calls GetConversationModel.
                         * @function getConversationModel
                         * @memberof google.cloud.dialogflow.v2.ConversationModels
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IGetConversationModelRequest} request GetConversationModelRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.ConversationModels.GetConversationModelCallback} callback Node-style callback called with the error, if any, and ConversationModel
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(ConversationModels.prototype.getConversationModel = function getConversationModel(request, callback) {
                            return this.rpcCall(getConversationModel, $root.google.cloud.dialogflow.v2.GetConversationModelRequest, $root.google.cloud.dialogflow.v2.ConversationModel, request, callback);
                        }, "name", { value: "GetConversationModel" });
    
                        /**
                         * Calls GetConversationModel.
                         * @function getConversationModel
                         * @memberof google.cloud.dialogflow.v2.ConversationModels
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IGetConversationModelRequest} request GetConversationModelRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.ConversationModel>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.ConversationModels|listConversationModels}.
                         * @memberof google.cloud.dialogflow.v2.ConversationModels
                         * @typedef ListConversationModelsCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.ListConversationModelsResponse} [response] ListConversationModelsResponse
                         */
    
                        /**
                         * Calls ListConversationModels.
                         * @function listConversationModels
                         * @memberof google.cloud.dialogflow.v2.ConversationModels
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IListConversationModelsRequest} request ListConversationModelsRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.ConversationModels.ListConversationModelsCallback} callback Node-style callback called with the error, if any, and ListConversationModelsResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(ConversationModels.prototype.listConversationModels = function listConversationModels(request, callback) {
                            return this.rpcCall(listConversationModels, $root.google.cloud.dialogflow.v2.ListConversationModelsRequest, $root.google.cloud.dialogflow.v2.ListConversationModelsResponse, request, callback);
                        }, "name", { value: "ListConversationModels" });
    
                        /**
                         * Calls ListConversationModels.
                         * @function listConversationModels
                         * @memberof google.cloud.dialogflow.v2.ConversationModels
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IListConversationModelsRequest} request ListConversationModelsRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.ListConversationModelsResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.ConversationModels|deleteConversationModel}.
                         * @memberof google.cloud.dialogflow.v2.ConversationModels
                         * @typedef DeleteConversationModelCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.longrunning.Operation} [response] Operation
                         */
    
                        /**
                         * Calls DeleteConversationModel.
                         * @function deleteConversationModel
                         * @memberof google.cloud.dialogflow.v2.ConversationModels
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IDeleteConversationModelRequest} request DeleteConversationModelRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.ConversationModels.DeleteConversationModelCallback} callback Node-style callback called with the error, if any, and Operation
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(ConversationModels.prototype.deleteConversationModel = function deleteConversationModel(request, callback) {
                            return this.rpcCall(deleteConversationModel, $root.google.cloud.dialogflow.v2.DeleteConversationModelRequest, $root.google.longrunning.Operation, request, callback);
                        }, "name", { value: "DeleteConversationModel" });
    
                        /**
                         * Calls DeleteConversationModel.
                         * @function deleteConversationModel
                         * @memberof google.cloud.dialogflow.v2.ConversationModels
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IDeleteConversationModelRequest} request DeleteConversationModelRequest message or plain object
                         * @returns {Promise<google.longrunning.Operation>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.ConversationModels|deployConversationModel}.
                         * @memberof google.cloud.dialogflow.v2.ConversationModels
                         * @typedef DeployConversationModelCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.longrunning.Operation} [response] Operation
                         */
    
                        /**
                         * Calls DeployConversationModel.
                         * @function deployConversationModel
                         * @memberof google.cloud.dialogflow.v2.ConversationModels
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IDeployConversationModelRequest} request DeployConversationModelRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.ConversationModels.DeployConversationModelCallback} callback Node-style callback called with the error, if any, and Operation
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(ConversationModels.prototype.deployConversationModel = function deployConversationModel(request, callback) {
                            return this.rpcCall(deployConversationModel, $root.google.cloud.dialogflow.v2.DeployConversationModelRequest, $root.google.longrunning.Operation, request, callback);
                        }, "name", { value: "DeployConversationModel" });
    
                        /**
                         * Calls DeployConversationModel.
                         * @function deployConversationModel
                         * @memberof google.cloud.dialogflow.v2.ConversationModels
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IDeployConversationModelRequest} request DeployConversationModelRequest message or plain object
                         * @returns {Promise<google.longrunning.Operation>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.ConversationModels|undeployConversationModel}.
                         * @memberof google.cloud.dialogflow.v2.ConversationModels
                         * @typedef UndeployConversationModelCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.longrunning.Operation} [response] Operation
                         */
    
                        /**
                         * Calls UndeployConversationModel.
                         * @function undeployConversationModel
                         * @memberof google.cloud.dialogflow.v2.ConversationModels
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IUndeployConversationModelRequest} request UndeployConversationModelRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.ConversationModels.UndeployConversationModelCallback} callback Node-style callback called with the error, if any, and Operation
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(ConversationModels.prototype.undeployConversationModel = function undeployConversationModel(request, callback) {
                            return this.rpcCall(undeployConversationModel, $root.google.cloud.dialogflow.v2.UndeployConversationModelRequest, $root.google.longrunning.Operation, request, callback);
                        }, "name", { value: "UndeployConversationModel" });
    
                        /**
                         * Calls UndeployConversationModel.
                         * @function undeployConversationModel
                         * @memberof google.cloud.dialogflow.v2.ConversationModels
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IUndeployConversationModelRequest} request UndeployConversationModelRequest message or plain object
                         * @returns {Promise<google.longrunning.Operation>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.ConversationModels|getConversationModelEvaluation}.
                         * @memberof google.cloud.dialogflow.v2.ConversationModels
                         * @typedef GetConversationModelEvaluationCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.ConversationModelEvaluation} [response] ConversationModelEvaluation
                         */
    
                        /**
                         * Calls GetConversationModelEvaluation.
                         * @function getConversationModelEvaluation
                         * @memberof google.cloud.dialogflow.v2.ConversationModels
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IGetConversationModelEvaluationRequest} request GetConversationModelEvaluationRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.ConversationModels.GetConversationModelEvaluationCallback} callback Node-style callback called with the error, if any, and ConversationModelEvaluation
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(ConversationModels.prototype.getConversationModelEvaluation = function getConversationModelEvaluation(request, callback) {
                            return this.rpcCall(getConversationModelEvaluation, $root.google.cloud.dialogflow.v2.GetConversationModelEvaluationRequest, $root.google.cloud.dialogflow.v2.ConversationModelEvaluation, request, callback);
                        }, "name", { value: "GetConversationModelEvaluation" });
    
                        /**
                         * Calls GetConversationModelEvaluation.
                         * @function getConversationModelEvaluation
                         * @memberof google.cloud.dialogflow.v2.ConversationModels
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IGetConversationModelEvaluationRequest} request GetConversationModelEvaluationRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.ConversationModelEvaluation>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.ConversationModels|listConversationModelEvaluations}.
                         * @memberof google.cloud.dialogflow.v2.ConversationModels
                         * @typedef ListConversationModelEvaluationsCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.ListConversationModelEvaluationsResponse} [response] ListConversationModelEvaluationsResponse
                         */
    
                        /**
                         * Calls ListConversationModelEvaluations.
                         * @function listConversationModelEvaluations
                         * @memberof google.cloud.dialogflow.v2.ConversationModels
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IListConversationModelEvaluationsRequest} request ListConversationModelEvaluationsRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.ConversationModels.ListConversationModelEvaluationsCallback} callback Node-style callback called with the error, if any, and ListConversationModelEvaluationsResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(ConversationModels.prototype.listConversationModelEvaluations = function listConversationModelEvaluations(request, callback) {
                            return this.rpcCall(listConversationModelEvaluations, $root.google.cloud.dialogflow.v2.ListConversationModelEvaluationsRequest, $root.google.cloud.dialogflow.v2.ListConversationModelEvaluationsResponse, request, callback);
                        }, "name", { value: "ListConversationModelEvaluations" });
    
                        /**
                         * Calls ListConversationModelEvaluations.
                         * @function listConversationModelEvaluations
                         * @memberof google.cloud.dialogflow.v2.ConversationModels
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IListConversationModelEvaluationsRequest} request ListConversationModelEvaluationsRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.ListConversationModelEvaluationsResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.ConversationModels|createConversationModelEvaluation}.
                         * @memberof google.cloud.dialogflow.v2.ConversationModels
                         * @typedef CreateConversationModelEvaluationCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.longrunning.Operation} [response] Operation
                         */
    
                        /**
                         * Calls CreateConversationModelEvaluation.
                         * @function createConversationModelEvaluation
                         * @memberof google.cloud.dialogflow.v2.ConversationModels
                         * @instance
                         * @param {google.cloud.dialogflow.v2.ICreateConversationModelEvaluationRequest} request CreateConversationModelEvaluationRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.ConversationModels.CreateConversationModelEvaluationCallback} callback Node-style callback called with the error, if any, and Operation
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(ConversationModels.prototype.createConversationModelEvaluation = function createConversationModelEvaluation(request, callback) {
                            return this.rpcCall(createConversationModelEvaluation, $root.google.cloud.dialogflow.v2.CreateConversationModelEvaluationRequest, $root.google.longrunning.Operation, request, callback);
                        }, "name", { value: "CreateConversationModelEvaluation" });
    
                        /**
                         * Calls CreateConversationModelEvaluation.
                         * @function createConversationModelEvaluation
                         * @memberof google.cloud.dialogflow.v2.ConversationModels
                         * @instance
                         * @param {google.cloud.dialogflow.v2.ICreateConversationModelEvaluationRequest} request CreateConversationModelEvaluationRequest message or plain object
                         * @returns {Promise<google.longrunning.Operation>} Promise
                         * @variation 2
                         */
    
                        return ConversationModels;
                    })();
    
                    v2.ConversationModel = (function() {
    
                        /**
                         * Properties of a ConversationModel.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IConversationModel
                         * @property {string|null} [name] ConversationModel name
                         * @property {string|null} [displayName] ConversationModel displayName
                         * @property {google.protobuf.ITimestamp|null} [createTime] ConversationModel createTime
                         * @property {Array.<google.cloud.dialogflow.v2.IInputDataset>|null} [datasets] ConversationModel datasets
                         * @property {google.cloud.dialogflow.v2.ConversationModel.State|null} [state] ConversationModel state
                         * @property {string|null} [languageCode] ConversationModel languageCode
                         * @property {google.cloud.dialogflow.v2.IArticleSuggestionModelMetadata|null} [articleSuggestionModelMetadata] ConversationModel articleSuggestionModelMetadata
                         * @property {google.cloud.dialogflow.v2.ISmartReplyModelMetadata|null} [smartReplyModelMetadata] ConversationModel smartReplyModelMetadata
                         * @property {boolean|null} [satisfiesPzs] ConversationModel satisfiesPzs
                         * @property {boolean|null} [satisfiesPzi] ConversationModel satisfiesPzi
                         */
    
                        /**
                         * Constructs a new ConversationModel.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a ConversationModel.
                         * @implements IConversationModel
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IConversationModel=} [properties] Properties to set
                         */
                        function ConversationModel(properties) {
                            this.datasets = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ConversationModel name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2.ConversationModel
                         * @instance
                         */
                        ConversationModel.prototype.name = "";
    
                        /**
                         * ConversationModel displayName.
                         * @member {string} displayName
                         * @memberof google.cloud.dialogflow.v2.ConversationModel
                         * @instance
                         */
                        ConversationModel.prototype.displayName = "";
    
                        /**
                         * ConversationModel createTime.
                         * @member {google.protobuf.ITimestamp|null|undefined} createTime
                         * @memberof google.cloud.dialogflow.v2.ConversationModel
                         * @instance
                         */
                        ConversationModel.prototype.createTime = null;
    
                        /**
                         * ConversationModel datasets.
                         * @member {Array.<google.cloud.dialogflow.v2.IInputDataset>} datasets
                         * @memberof google.cloud.dialogflow.v2.ConversationModel
                         * @instance
                         */
                        ConversationModel.prototype.datasets = $util.emptyArray;
    
                        /**
                         * ConversationModel state.
                         * @member {google.cloud.dialogflow.v2.ConversationModel.State} state
                         * @memberof google.cloud.dialogflow.v2.ConversationModel
                         * @instance
                         */
                        ConversationModel.prototype.state = 0;
    
                        /**
                         * ConversationModel languageCode.
                         * @member {string} languageCode
                         * @memberof google.cloud.dialogflow.v2.ConversationModel
                         * @instance
                         */
                        ConversationModel.prototype.languageCode = "";
    
                        /**
                         * ConversationModel articleSuggestionModelMetadata.
                         * @member {google.cloud.dialogflow.v2.IArticleSuggestionModelMetadata|null|undefined} articleSuggestionModelMetadata
                         * @memberof google.cloud.dialogflow.v2.ConversationModel
                         * @instance
                         */
                        ConversationModel.prototype.articleSuggestionModelMetadata = null;
    
                        /**
                         * ConversationModel smartReplyModelMetadata.
                         * @member {google.cloud.dialogflow.v2.ISmartReplyModelMetadata|null|undefined} smartReplyModelMetadata
                         * @memberof google.cloud.dialogflow.v2.ConversationModel
                         * @instance
                         */
                        ConversationModel.prototype.smartReplyModelMetadata = null;
    
                        /**
                         * ConversationModel satisfiesPzs.
                         * @member {boolean|null|undefined} satisfiesPzs
                         * @memberof google.cloud.dialogflow.v2.ConversationModel
                         * @instance
                         */
                        ConversationModel.prototype.satisfiesPzs = null;
    
                        /**
                         * ConversationModel satisfiesPzi.
                         * @member {boolean|null|undefined} satisfiesPzi
                         * @memberof google.cloud.dialogflow.v2.ConversationModel
                         * @instance
                         */
                        ConversationModel.prototype.satisfiesPzi = null;
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * ConversationModel modelMetadata.
                         * @member {"articleSuggestionModelMetadata"|"smartReplyModelMetadata"|undefined} modelMetadata
                         * @memberof google.cloud.dialogflow.v2.ConversationModel
                         * @instance
                         */
                        Object.defineProperty(ConversationModel.prototype, "modelMetadata", {
                            get: $util.oneOfGetter($oneOfFields = ["articleSuggestionModelMetadata", "smartReplyModelMetadata"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * ConversationModel _satisfiesPzs.
                         * @member {"satisfiesPzs"|undefined} _satisfiesPzs
                         * @memberof google.cloud.dialogflow.v2.ConversationModel
                         * @instance
                         */
                        Object.defineProperty(ConversationModel.prototype, "_satisfiesPzs", {
                            get: $util.oneOfGetter($oneOfFields = ["satisfiesPzs"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * ConversationModel _satisfiesPzi.
                         * @member {"satisfiesPzi"|undefined} _satisfiesPzi
                         * @memberof google.cloud.dialogflow.v2.ConversationModel
                         * @instance
                         */
                        Object.defineProperty(ConversationModel.prototype, "_satisfiesPzi", {
                            get: $util.oneOfGetter($oneOfFields = ["satisfiesPzi"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new ConversationModel instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ConversationModel
                         * @static
                         * @param {google.cloud.dialogflow.v2.IConversationModel=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ConversationModel} ConversationModel instance
                         */
                        ConversationModel.create = function create(properties) {
                            return new ConversationModel(properties);
                        };
    
                        /**
                         * Encodes the specified ConversationModel message. Does not implicitly {@link google.cloud.dialogflow.v2.ConversationModel.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ConversationModel
                         * @static
                         * @param {google.cloud.dialogflow.v2.IConversationModel} message ConversationModel message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ConversationModel.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            if (message.displayName != null && Object.hasOwnProperty.call(message, "displayName"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.displayName);
                            if (message.createTime != null && Object.hasOwnProperty.call(message, "createTime"))
                                $root.google.protobuf.Timestamp.encode(message.createTime, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            if (message.datasets != null && message.datasets.length)
                                for (var i = 0; i < message.datasets.length; ++i)
                                    $root.google.cloud.dialogflow.v2.InputDataset.encode(message.datasets[i], writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            if (message.state != null && Object.hasOwnProperty.call(message, "state"))
                                writer.uint32(/* id 7, wireType 0 =*/56).int32(message.state);
                            if (message.articleSuggestionModelMetadata != null && Object.hasOwnProperty.call(message, "articleSuggestionModelMetadata"))
                                $root.google.cloud.dialogflow.v2.ArticleSuggestionModelMetadata.encode(message.articleSuggestionModelMetadata, writer.uint32(/* id 8, wireType 2 =*/66).fork()).ldelim();
                            if (message.smartReplyModelMetadata != null && Object.hasOwnProperty.call(message, "smartReplyModelMetadata"))
                                $root.google.cloud.dialogflow.v2.SmartReplyModelMetadata.encode(message.smartReplyModelMetadata, writer.uint32(/* id 9, wireType 2 =*/74).fork()).ldelim();
                            if (message.languageCode != null && Object.hasOwnProperty.call(message, "languageCode"))
                                writer.uint32(/* id 19, wireType 2 =*/154).string(message.languageCode);
                            if (message.satisfiesPzs != null && Object.hasOwnProperty.call(message, "satisfiesPzs"))
                                writer.uint32(/* id 25, wireType 0 =*/200).bool(message.satisfiesPzs);
                            if (message.satisfiesPzi != null && Object.hasOwnProperty.call(message, "satisfiesPzi"))
                                writer.uint32(/* id 26, wireType 0 =*/208).bool(message.satisfiesPzi);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ConversationModel message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ConversationModel.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ConversationModel
                         * @static
                         * @param {google.cloud.dialogflow.v2.IConversationModel} message ConversationModel message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ConversationModel.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ConversationModel message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ConversationModel
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ConversationModel} ConversationModel
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ConversationModel.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ConversationModel();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.displayName = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.createTime = $root.google.protobuf.Timestamp.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 4: {
                                        if (!(message.datasets && message.datasets.length))
                                            message.datasets = [];
                                        message.datasets.push($root.google.cloud.dialogflow.v2.InputDataset.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 7: {
                                        message.state = reader.int32();
                                        break;
                                    }
                                case 19: {
                                        message.languageCode = reader.string();
                                        break;
                                    }
                                case 8: {
                                        message.articleSuggestionModelMetadata = $root.google.cloud.dialogflow.v2.ArticleSuggestionModelMetadata.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 9: {
                                        message.smartReplyModelMetadata = $root.google.cloud.dialogflow.v2.SmartReplyModelMetadata.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 25: {
                                        message.satisfiesPzs = reader.bool();
                                        break;
                                    }
                                case 26: {
                                        message.satisfiesPzi = reader.bool();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ConversationModel message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ConversationModel
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ConversationModel} ConversationModel
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ConversationModel.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ConversationModel message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ConversationModel
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ConversationModel.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            if (message.displayName != null && message.hasOwnProperty("displayName"))
                                if (!$util.isString(message.displayName))
                                    return "displayName: string expected";
                            if (message.createTime != null && message.hasOwnProperty("createTime")) {
                                var error = $root.google.protobuf.Timestamp.verify(message.createTime);
                                if (error)
                                    return "createTime." + error;
                            }
                            if (message.datasets != null && message.hasOwnProperty("datasets")) {
                                if (!Array.isArray(message.datasets))
                                    return "datasets: array expected";
                                for (var i = 0; i < message.datasets.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.InputDataset.verify(message.datasets[i]);
                                    if (error)
                                        return "datasets." + error;
                                }
                            }
                            if (message.state != null && message.hasOwnProperty("state"))
                                switch (message.state) {
                                default:
                                    return "state: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                case 4:
                                case 5:
                                case 6:
                                case 7:
                                case 8:
                                    break;
                                }
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                if (!$util.isString(message.languageCode))
                                    return "languageCode: string expected";
                            if (message.articleSuggestionModelMetadata != null && message.hasOwnProperty("articleSuggestionModelMetadata")) {
                                properties.modelMetadata = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2.ArticleSuggestionModelMetadata.verify(message.articleSuggestionModelMetadata);
                                    if (error)
                                        return "articleSuggestionModelMetadata." + error;
                                }
                            }
                            if (message.smartReplyModelMetadata != null && message.hasOwnProperty("smartReplyModelMetadata")) {
                                if (properties.modelMetadata === 1)
                                    return "modelMetadata: multiple values";
                                properties.modelMetadata = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2.SmartReplyModelMetadata.verify(message.smartReplyModelMetadata);
                                    if (error)
                                        return "smartReplyModelMetadata." + error;
                                }
                            }
                            if (message.satisfiesPzs != null && message.hasOwnProperty("satisfiesPzs")) {
                                properties._satisfiesPzs = 1;
                                if (typeof message.satisfiesPzs !== "boolean")
                                    return "satisfiesPzs: boolean expected";
                            }
                            if (message.satisfiesPzi != null && message.hasOwnProperty("satisfiesPzi")) {
                                properties._satisfiesPzi = 1;
                                if (typeof message.satisfiesPzi !== "boolean")
                                    return "satisfiesPzi: boolean expected";
                            }
                            return null;
                        };
    
                        /**
                         * Creates a ConversationModel message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ConversationModel
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ConversationModel} ConversationModel
                         */
                        ConversationModel.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ConversationModel)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ConversationModel();
                            if (object.name != null)
                                message.name = String(object.name);
                            if (object.displayName != null)
                                message.displayName = String(object.displayName);
                            if (object.createTime != null) {
                                if (typeof object.createTime !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.ConversationModel.createTime: object expected");
                                message.createTime = $root.google.protobuf.Timestamp.fromObject(object.createTime);
                            }
                            if (object.datasets) {
                                if (!Array.isArray(object.datasets))
                                    throw TypeError(".google.cloud.dialogflow.v2.ConversationModel.datasets: array expected");
                                message.datasets = [];
                                for (var i = 0; i < object.datasets.length; ++i) {
                                    if (typeof object.datasets[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.ConversationModel.datasets: object expected");
                                    message.datasets[i] = $root.google.cloud.dialogflow.v2.InputDataset.fromObject(object.datasets[i]);
                                }
                            }
                            switch (object.state) {
                            default:
                                if (typeof object.state === "number") {
                                    message.state = object.state;
                                    break;
                                }
                                break;
                            case "STATE_UNSPECIFIED":
                            case 0:
                                message.state = 0;
                                break;
                            case "CREATING":
                            case 1:
                                message.state = 1;
                                break;
                            case "UNDEPLOYED":
                            case 2:
                                message.state = 2;
                                break;
                            case "DEPLOYING":
                            case 3:
                                message.state = 3;
                                break;
                            case "DEPLOYED":
                            case 4:
                                message.state = 4;
                                break;
                            case "UNDEPLOYING":
                            case 5:
                                message.state = 5;
                                break;
                            case "DELETING":
                            case 6:
                                message.state = 6;
                                break;
                            case "FAILED":
                            case 7:
                                message.state = 7;
                                break;
                            case "PENDING":
                            case 8:
                                message.state = 8;
                                break;
                            }
                            if (object.languageCode != null)
                                message.languageCode = String(object.languageCode);
                            if (object.articleSuggestionModelMetadata != null) {
                                if (typeof object.articleSuggestionModelMetadata !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.ConversationModel.articleSuggestionModelMetadata: object expected");
                                message.articleSuggestionModelMetadata = $root.google.cloud.dialogflow.v2.ArticleSuggestionModelMetadata.fromObject(object.articleSuggestionModelMetadata);
                            }
                            if (object.smartReplyModelMetadata != null) {
                                if (typeof object.smartReplyModelMetadata !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.ConversationModel.smartReplyModelMetadata: object expected");
                                message.smartReplyModelMetadata = $root.google.cloud.dialogflow.v2.SmartReplyModelMetadata.fromObject(object.smartReplyModelMetadata);
                            }
                            if (object.satisfiesPzs != null)
                                message.satisfiesPzs = Boolean(object.satisfiesPzs);
                            if (object.satisfiesPzi != null)
                                message.satisfiesPzi = Boolean(object.satisfiesPzi);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ConversationModel message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ConversationModel
                         * @static
                         * @param {google.cloud.dialogflow.v2.ConversationModel} message ConversationModel
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ConversationModel.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.datasets = [];
                            if (options.defaults) {
                                object.name = "";
                                object.displayName = "";
                                object.createTime = null;
                                object.state = options.enums === String ? "STATE_UNSPECIFIED" : 0;
                                object.languageCode = "";
                            }
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            if (message.displayName != null && message.hasOwnProperty("displayName"))
                                object.displayName = message.displayName;
                            if (message.createTime != null && message.hasOwnProperty("createTime"))
                                object.createTime = $root.google.protobuf.Timestamp.toObject(message.createTime, options);
                            if (message.datasets && message.datasets.length) {
                                object.datasets = [];
                                for (var j = 0; j < message.datasets.length; ++j)
                                    object.datasets[j] = $root.google.cloud.dialogflow.v2.InputDataset.toObject(message.datasets[j], options);
                            }
                            if (message.state != null && message.hasOwnProperty("state"))
                                object.state = options.enums === String ? $root.google.cloud.dialogflow.v2.ConversationModel.State[message.state] === undefined ? message.state : $root.google.cloud.dialogflow.v2.ConversationModel.State[message.state] : message.state;
                            if (message.articleSuggestionModelMetadata != null && message.hasOwnProperty("articleSuggestionModelMetadata")) {
                                object.articleSuggestionModelMetadata = $root.google.cloud.dialogflow.v2.ArticleSuggestionModelMetadata.toObject(message.articleSuggestionModelMetadata, options);
                                if (options.oneofs)
                                    object.modelMetadata = "articleSuggestionModelMetadata";
                            }
                            if (message.smartReplyModelMetadata != null && message.hasOwnProperty("smartReplyModelMetadata")) {
                                object.smartReplyModelMetadata = $root.google.cloud.dialogflow.v2.SmartReplyModelMetadata.toObject(message.smartReplyModelMetadata, options);
                                if (options.oneofs)
                                    object.modelMetadata = "smartReplyModelMetadata";
                            }
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                object.languageCode = message.languageCode;
                            if (message.satisfiesPzs != null && message.hasOwnProperty("satisfiesPzs")) {
                                object.satisfiesPzs = message.satisfiesPzs;
                                if (options.oneofs)
                                    object._satisfiesPzs = "satisfiesPzs";
                            }
                            if (message.satisfiesPzi != null && message.hasOwnProperty("satisfiesPzi")) {
                                object.satisfiesPzi = message.satisfiesPzi;
                                if (options.oneofs)
                                    object._satisfiesPzi = "satisfiesPzi";
                            }
                            return object;
                        };
    
                        /**
                         * Converts this ConversationModel to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ConversationModel
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ConversationModel.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ConversationModel
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ConversationModel
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ConversationModel.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ConversationModel";
                        };
    
                        /**
                         * State enum.
                         * @name google.cloud.dialogflow.v2.ConversationModel.State
                         * @enum {number}
                         * @property {number} STATE_UNSPECIFIED=0 STATE_UNSPECIFIED value
                         * @property {number} CREATING=1 CREATING value
                         * @property {number} UNDEPLOYED=2 UNDEPLOYED value
                         * @property {number} DEPLOYING=3 DEPLOYING value
                         * @property {number} DEPLOYED=4 DEPLOYED value
                         * @property {number} UNDEPLOYING=5 UNDEPLOYING value
                         * @property {number} DELETING=6 DELETING value
                         * @property {number} FAILED=7 FAILED value
                         * @property {number} PENDING=8 PENDING value
                         */
                        ConversationModel.State = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "STATE_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "CREATING"] = 1;
                            values[valuesById[2] = "UNDEPLOYED"] = 2;
                            values[valuesById[3] = "DEPLOYING"] = 3;
                            values[valuesById[4] = "DEPLOYED"] = 4;
                            values[valuesById[5] = "UNDEPLOYING"] = 5;
                            values[valuesById[6] = "DELETING"] = 6;
                            values[valuesById[7] = "FAILED"] = 7;
                            values[valuesById[8] = "PENDING"] = 8;
                            return values;
                        })();
    
                        /**
                         * ModelType enum.
                         * @name google.cloud.dialogflow.v2.ConversationModel.ModelType
                         * @enum {number}
                         * @property {number} MODEL_TYPE_UNSPECIFIED=0 MODEL_TYPE_UNSPECIFIED value
                         * @property {number} SMART_REPLY_DUAL_ENCODER_MODEL=2 SMART_REPLY_DUAL_ENCODER_MODEL value
                         * @property {number} SMART_REPLY_BERT_MODEL=6 SMART_REPLY_BERT_MODEL value
                         */
                        ConversationModel.ModelType = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "MODEL_TYPE_UNSPECIFIED"] = 0;
                            values[valuesById[2] = "SMART_REPLY_DUAL_ENCODER_MODEL"] = 2;
                            values[valuesById[6] = "SMART_REPLY_BERT_MODEL"] = 6;
                            return values;
                        })();
    
                        return ConversationModel;
                    })();
    
                    v2.ConversationModelEvaluation = (function() {
    
                        /**
                         * Properties of a ConversationModelEvaluation.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IConversationModelEvaluation
                         * @property {string|null} [name] ConversationModelEvaluation name
                         * @property {string|null} [displayName] ConversationModelEvaluation displayName
                         * @property {google.cloud.dialogflow.v2.IEvaluationConfig|null} [evaluationConfig] ConversationModelEvaluation evaluationConfig
                         * @property {google.protobuf.ITimestamp|null} [createTime] ConversationModelEvaluation createTime
                         * @property {google.cloud.dialogflow.v2.ISmartReplyMetrics|null} [smartReplyMetrics] ConversationModelEvaluation smartReplyMetrics
                         * @property {string|null} [rawHumanEvalTemplateCsv] ConversationModelEvaluation rawHumanEvalTemplateCsv
                         */
    
                        /**
                         * Constructs a new ConversationModelEvaluation.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a ConversationModelEvaluation.
                         * @implements IConversationModelEvaluation
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IConversationModelEvaluation=} [properties] Properties to set
                         */
                        function ConversationModelEvaluation(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ConversationModelEvaluation name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2.ConversationModelEvaluation
                         * @instance
                         */
                        ConversationModelEvaluation.prototype.name = "";
    
                        /**
                         * ConversationModelEvaluation displayName.
                         * @member {string} displayName
                         * @memberof google.cloud.dialogflow.v2.ConversationModelEvaluation
                         * @instance
                         */
                        ConversationModelEvaluation.prototype.displayName = "";
    
                        /**
                         * ConversationModelEvaluation evaluationConfig.
                         * @member {google.cloud.dialogflow.v2.IEvaluationConfig|null|undefined} evaluationConfig
                         * @memberof google.cloud.dialogflow.v2.ConversationModelEvaluation
                         * @instance
                         */
                        ConversationModelEvaluation.prototype.evaluationConfig = null;
    
                        /**
                         * ConversationModelEvaluation createTime.
                         * @member {google.protobuf.ITimestamp|null|undefined} createTime
                         * @memberof google.cloud.dialogflow.v2.ConversationModelEvaluation
                         * @instance
                         */
                        ConversationModelEvaluation.prototype.createTime = null;
    
                        /**
                         * ConversationModelEvaluation smartReplyMetrics.
                         * @member {google.cloud.dialogflow.v2.ISmartReplyMetrics|null|undefined} smartReplyMetrics
                         * @memberof google.cloud.dialogflow.v2.ConversationModelEvaluation
                         * @instance
                         */
                        ConversationModelEvaluation.prototype.smartReplyMetrics = null;
    
                        /**
                         * ConversationModelEvaluation rawHumanEvalTemplateCsv.
                         * @member {string} rawHumanEvalTemplateCsv
                         * @memberof google.cloud.dialogflow.v2.ConversationModelEvaluation
                         * @instance
                         */
                        ConversationModelEvaluation.prototype.rawHumanEvalTemplateCsv = "";
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * ConversationModelEvaluation metrics.
                         * @member {"smartReplyMetrics"|undefined} metrics
                         * @memberof google.cloud.dialogflow.v2.ConversationModelEvaluation
                         * @instance
                         */
                        Object.defineProperty(ConversationModelEvaluation.prototype, "metrics", {
                            get: $util.oneOfGetter($oneOfFields = ["smartReplyMetrics"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new ConversationModelEvaluation instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ConversationModelEvaluation
                         * @static
                         * @param {google.cloud.dialogflow.v2.IConversationModelEvaluation=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ConversationModelEvaluation} ConversationModelEvaluation instance
                         */
                        ConversationModelEvaluation.create = function create(properties) {
                            return new ConversationModelEvaluation(properties);
                        };
    
                        /**
                         * Encodes the specified ConversationModelEvaluation message. Does not implicitly {@link google.cloud.dialogflow.v2.ConversationModelEvaluation.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ConversationModelEvaluation
                         * @static
                         * @param {google.cloud.dialogflow.v2.IConversationModelEvaluation} message ConversationModelEvaluation message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ConversationModelEvaluation.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            if (message.displayName != null && Object.hasOwnProperty.call(message, "displayName"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.displayName);
                            if (message.createTime != null && Object.hasOwnProperty.call(message, "createTime"))
                                $root.google.protobuf.Timestamp.encode(message.createTime, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            if (message.smartReplyMetrics != null && Object.hasOwnProperty.call(message, "smartReplyMetrics"))
                                $root.google.cloud.dialogflow.v2.SmartReplyMetrics.encode(message.smartReplyMetrics, writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                            if (message.evaluationConfig != null && Object.hasOwnProperty.call(message, "evaluationConfig"))
                                $root.google.cloud.dialogflow.v2.EvaluationConfig.encode(message.evaluationConfig, writer.uint32(/* id 6, wireType 2 =*/50).fork()).ldelim();
                            if (message.rawHumanEvalTemplateCsv != null && Object.hasOwnProperty.call(message, "rawHumanEvalTemplateCsv"))
                                writer.uint32(/* id 8, wireType 2 =*/66).string(message.rawHumanEvalTemplateCsv);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ConversationModelEvaluation message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ConversationModelEvaluation.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ConversationModelEvaluation
                         * @static
                         * @param {google.cloud.dialogflow.v2.IConversationModelEvaluation} message ConversationModelEvaluation message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ConversationModelEvaluation.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ConversationModelEvaluation message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ConversationModelEvaluation
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ConversationModelEvaluation} ConversationModelEvaluation
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ConversationModelEvaluation.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ConversationModelEvaluation();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.displayName = reader.string();
                                        break;
                                    }
                                case 6: {
                                        message.evaluationConfig = $root.google.cloud.dialogflow.v2.EvaluationConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 3: {
                                        message.createTime = $root.google.protobuf.Timestamp.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 5: {
                                        message.smartReplyMetrics = $root.google.cloud.dialogflow.v2.SmartReplyMetrics.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 8: {
                                        message.rawHumanEvalTemplateCsv = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ConversationModelEvaluation message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ConversationModelEvaluation
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ConversationModelEvaluation} ConversationModelEvaluation
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ConversationModelEvaluation.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ConversationModelEvaluation message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ConversationModelEvaluation
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ConversationModelEvaluation.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            if (message.displayName != null && message.hasOwnProperty("displayName"))
                                if (!$util.isString(message.displayName))
                                    return "displayName: string expected";
                            if (message.evaluationConfig != null && message.hasOwnProperty("evaluationConfig")) {
                                var error = $root.google.cloud.dialogflow.v2.EvaluationConfig.verify(message.evaluationConfig);
                                if (error)
                                    return "evaluationConfig." + error;
                            }
                            if (message.createTime != null && message.hasOwnProperty("createTime")) {
                                var error = $root.google.protobuf.Timestamp.verify(message.createTime);
                                if (error)
                                    return "createTime." + error;
                            }
                            if (message.smartReplyMetrics != null && message.hasOwnProperty("smartReplyMetrics")) {
                                properties.metrics = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2.SmartReplyMetrics.verify(message.smartReplyMetrics);
                                    if (error)
                                        return "smartReplyMetrics." + error;
                                }
                            }
                            if (message.rawHumanEvalTemplateCsv != null && message.hasOwnProperty("rawHumanEvalTemplateCsv"))
                                if (!$util.isString(message.rawHumanEvalTemplateCsv))
                                    return "rawHumanEvalTemplateCsv: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ConversationModelEvaluation message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ConversationModelEvaluation
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ConversationModelEvaluation} ConversationModelEvaluation
                         */
                        ConversationModelEvaluation.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ConversationModelEvaluation)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ConversationModelEvaluation();
                            if (object.name != null)
                                message.name = String(object.name);
                            if (object.displayName != null)
                                message.displayName = String(object.displayName);
                            if (object.evaluationConfig != null) {
                                if (typeof object.evaluationConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.ConversationModelEvaluation.evaluationConfig: object expected");
                                message.evaluationConfig = $root.google.cloud.dialogflow.v2.EvaluationConfig.fromObject(object.evaluationConfig);
                            }
                            if (object.createTime != null) {
                                if (typeof object.createTime !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.ConversationModelEvaluation.createTime: object expected");
                                message.createTime = $root.google.protobuf.Timestamp.fromObject(object.createTime);
                            }
                            if (object.smartReplyMetrics != null) {
                                if (typeof object.smartReplyMetrics !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.ConversationModelEvaluation.smartReplyMetrics: object expected");
                                message.smartReplyMetrics = $root.google.cloud.dialogflow.v2.SmartReplyMetrics.fromObject(object.smartReplyMetrics);
                            }
                            if (object.rawHumanEvalTemplateCsv != null)
                                message.rawHumanEvalTemplateCsv = String(object.rawHumanEvalTemplateCsv);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ConversationModelEvaluation message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ConversationModelEvaluation
                         * @static
                         * @param {google.cloud.dialogflow.v2.ConversationModelEvaluation} message ConversationModelEvaluation
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ConversationModelEvaluation.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.name = "";
                                object.displayName = "";
                                object.createTime = null;
                                object.evaluationConfig = null;
                                object.rawHumanEvalTemplateCsv = "";
                            }
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            if (message.displayName != null && message.hasOwnProperty("displayName"))
                                object.displayName = message.displayName;
                            if (message.createTime != null && message.hasOwnProperty("createTime"))
                                object.createTime = $root.google.protobuf.Timestamp.toObject(message.createTime, options);
                            if (message.smartReplyMetrics != null && message.hasOwnProperty("smartReplyMetrics")) {
                                object.smartReplyMetrics = $root.google.cloud.dialogflow.v2.SmartReplyMetrics.toObject(message.smartReplyMetrics, options);
                                if (options.oneofs)
                                    object.metrics = "smartReplyMetrics";
                            }
                            if (message.evaluationConfig != null && message.hasOwnProperty("evaluationConfig"))
                                object.evaluationConfig = $root.google.cloud.dialogflow.v2.EvaluationConfig.toObject(message.evaluationConfig, options);
                            if (message.rawHumanEvalTemplateCsv != null && message.hasOwnProperty("rawHumanEvalTemplateCsv"))
                                object.rawHumanEvalTemplateCsv = message.rawHumanEvalTemplateCsv;
                            return object;
                        };
    
                        /**
                         * Converts this ConversationModelEvaluation to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ConversationModelEvaluation
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ConversationModelEvaluation.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ConversationModelEvaluation
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ConversationModelEvaluation
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ConversationModelEvaluation.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ConversationModelEvaluation";
                        };
    
                        return ConversationModelEvaluation;
                    })();
    
                    v2.EvaluationConfig = (function() {
    
                        /**
                         * Properties of an EvaluationConfig.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IEvaluationConfig
                         * @property {Array.<google.cloud.dialogflow.v2.IInputDataset>|null} [datasets] EvaluationConfig datasets
                         * @property {google.cloud.dialogflow.v2.EvaluationConfig.ISmartReplyConfig|null} [smartReplyConfig] EvaluationConfig smartReplyConfig
                         * @property {google.cloud.dialogflow.v2.EvaluationConfig.ISmartComposeConfig|null} [smartComposeConfig] EvaluationConfig smartComposeConfig
                         */
    
                        /**
                         * Constructs a new EvaluationConfig.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an EvaluationConfig.
                         * @implements IEvaluationConfig
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IEvaluationConfig=} [properties] Properties to set
                         */
                        function EvaluationConfig(properties) {
                            this.datasets = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * EvaluationConfig datasets.
                         * @member {Array.<google.cloud.dialogflow.v2.IInputDataset>} datasets
                         * @memberof google.cloud.dialogflow.v2.EvaluationConfig
                         * @instance
                         */
                        EvaluationConfig.prototype.datasets = $util.emptyArray;
    
                        /**
                         * EvaluationConfig smartReplyConfig.
                         * @member {google.cloud.dialogflow.v2.EvaluationConfig.ISmartReplyConfig|null|undefined} smartReplyConfig
                         * @memberof google.cloud.dialogflow.v2.EvaluationConfig
                         * @instance
                         */
                        EvaluationConfig.prototype.smartReplyConfig = null;
    
                        /**
                         * EvaluationConfig smartComposeConfig.
                         * @member {google.cloud.dialogflow.v2.EvaluationConfig.ISmartComposeConfig|null|undefined} smartComposeConfig
                         * @memberof google.cloud.dialogflow.v2.EvaluationConfig
                         * @instance
                         */
                        EvaluationConfig.prototype.smartComposeConfig = null;
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * EvaluationConfig modelSpecificConfig.
                         * @member {"smartReplyConfig"|"smartComposeConfig"|undefined} modelSpecificConfig
                         * @memberof google.cloud.dialogflow.v2.EvaluationConfig
                         * @instance
                         */
                        Object.defineProperty(EvaluationConfig.prototype, "modelSpecificConfig", {
                            get: $util.oneOfGetter($oneOfFields = ["smartReplyConfig", "smartComposeConfig"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new EvaluationConfig instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.EvaluationConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2.IEvaluationConfig=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.EvaluationConfig} EvaluationConfig instance
                         */
                        EvaluationConfig.create = function create(properties) {
                            return new EvaluationConfig(properties);
                        };
    
                        /**
                         * Encodes the specified EvaluationConfig message. Does not implicitly {@link google.cloud.dialogflow.v2.EvaluationConfig.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.EvaluationConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2.IEvaluationConfig} message EvaluationConfig message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        EvaluationConfig.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.smartReplyConfig != null && Object.hasOwnProperty.call(message, "smartReplyConfig"))
                                $root.google.cloud.dialogflow.v2.EvaluationConfig.SmartReplyConfig.encode(message.smartReplyConfig, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.datasets != null && message.datasets.length)
                                for (var i = 0; i < message.datasets.length; ++i)
                                    $root.google.cloud.dialogflow.v2.InputDataset.encode(message.datasets[i], writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            if (message.smartComposeConfig != null && Object.hasOwnProperty.call(message, "smartComposeConfig"))
                                $root.google.cloud.dialogflow.v2.EvaluationConfig.SmartComposeConfig.encode(message.smartComposeConfig, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified EvaluationConfig message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.EvaluationConfig.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.EvaluationConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2.IEvaluationConfig} message EvaluationConfig message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        EvaluationConfig.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an EvaluationConfig message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.EvaluationConfig
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.EvaluationConfig} EvaluationConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        EvaluationConfig.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.EvaluationConfig();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 3: {
                                        if (!(message.datasets && message.datasets.length))
                                            message.datasets = [];
                                        message.datasets.push($root.google.cloud.dialogflow.v2.InputDataset.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 2: {
                                        message.smartReplyConfig = $root.google.cloud.dialogflow.v2.EvaluationConfig.SmartReplyConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 4: {
                                        message.smartComposeConfig = $root.google.cloud.dialogflow.v2.EvaluationConfig.SmartComposeConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an EvaluationConfig message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.EvaluationConfig
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.EvaluationConfig} EvaluationConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        EvaluationConfig.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an EvaluationConfig message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.EvaluationConfig
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        EvaluationConfig.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.datasets != null && message.hasOwnProperty("datasets")) {
                                if (!Array.isArray(message.datasets))
                                    return "datasets: array expected";
                                for (var i = 0; i < message.datasets.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.InputDataset.verify(message.datasets[i]);
                                    if (error)
                                        return "datasets." + error;
                                }
                            }
                            if (message.smartReplyConfig != null && message.hasOwnProperty("smartReplyConfig")) {
                                properties.modelSpecificConfig = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2.EvaluationConfig.SmartReplyConfig.verify(message.smartReplyConfig);
                                    if (error)
                                        return "smartReplyConfig." + error;
                                }
                            }
                            if (message.smartComposeConfig != null && message.hasOwnProperty("smartComposeConfig")) {
                                if (properties.modelSpecificConfig === 1)
                                    return "modelSpecificConfig: multiple values";
                                properties.modelSpecificConfig = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2.EvaluationConfig.SmartComposeConfig.verify(message.smartComposeConfig);
                                    if (error)
                                        return "smartComposeConfig." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates an EvaluationConfig message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.EvaluationConfig
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.EvaluationConfig} EvaluationConfig
                         */
                        EvaluationConfig.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.EvaluationConfig)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.EvaluationConfig();
                            if (object.datasets) {
                                if (!Array.isArray(object.datasets))
                                    throw TypeError(".google.cloud.dialogflow.v2.EvaluationConfig.datasets: array expected");
                                message.datasets = [];
                                for (var i = 0; i < object.datasets.length; ++i) {
                                    if (typeof object.datasets[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.EvaluationConfig.datasets: object expected");
                                    message.datasets[i] = $root.google.cloud.dialogflow.v2.InputDataset.fromObject(object.datasets[i]);
                                }
                            }
                            if (object.smartReplyConfig != null) {
                                if (typeof object.smartReplyConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.EvaluationConfig.smartReplyConfig: object expected");
                                message.smartReplyConfig = $root.google.cloud.dialogflow.v2.EvaluationConfig.SmartReplyConfig.fromObject(object.smartReplyConfig);
                            }
                            if (object.smartComposeConfig != null) {
                                if (typeof object.smartComposeConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.EvaluationConfig.smartComposeConfig: object expected");
                                message.smartComposeConfig = $root.google.cloud.dialogflow.v2.EvaluationConfig.SmartComposeConfig.fromObject(object.smartComposeConfig);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an EvaluationConfig message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.EvaluationConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2.EvaluationConfig} message EvaluationConfig
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        EvaluationConfig.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.datasets = [];
                            if (message.smartReplyConfig != null && message.hasOwnProperty("smartReplyConfig")) {
                                object.smartReplyConfig = $root.google.cloud.dialogflow.v2.EvaluationConfig.SmartReplyConfig.toObject(message.smartReplyConfig, options);
                                if (options.oneofs)
                                    object.modelSpecificConfig = "smartReplyConfig";
                            }
                            if (message.datasets && message.datasets.length) {
                                object.datasets = [];
                                for (var j = 0; j < message.datasets.length; ++j)
                                    object.datasets[j] = $root.google.cloud.dialogflow.v2.InputDataset.toObject(message.datasets[j], options);
                            }
                            if (message.smartComposeConfig != null && message.hasOwnProperty("smartComposeConfig")) {
                                object.smartComposeConfig = $root.google.cloud.dialogflow.v2.EvaluationConfig.SmartComposeConfig.toObject(message.smartComposeConfig, options);
                                if (options.oneofs)
                                    object.modelSpecificConfig = "smartComposeConfig";
                            }
                            return object;
                        };
    
                        /**
                         * Converts this EvaluationConfig to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.EvaluationConfig
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        EvaluationConfig.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for EvaluationConfig
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.EvaluationConfig
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        EvaluationConfig.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.EvaluationConfig";
                        };
    
                        EvaluationConfig.SmartReplyConfig = (function() {
    
                            /**
                             * Properties of a SmartReplyConfig.
                             * @memberof google.cloud.dialogflow.v2.EvaluationConfig
                             * @interface ISmartReplyConfig
                             * @property {string|null} [allowlistDocument] SmartReplyConfig allowlistDocument
                             * @property {number|null} [maxResultCount] SmartReplyConfig maxResultCount
                             */
    
                            /**
                             * Constructs a new SmartReplyConfig.
                             * @memberof google.cloud.dialogflow.v2.EvaluationConfig
                             * @classdesc Represents a SmartReplyConfig.
                             * @implements ISmartReplyConfig
                             * @constructor
                             * @param {google.cloud.dialogflow.v2.EvaluationConfig.ISmartReplyConfig=} [properties] Properties to set
                             */
                            function SmartReplyConfig(properties) {
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * SmartReplyConfig allowlistDocument.
                             * @member {string} allowlistDocument
                             * @memberof google.cloud.dialogflow.v2.EvaluationConfig.SmartReplyConfig
                             * @instance
                             */
                            SmartReplyConfig.prototype.allowlistDocument = "";
    
                            /**
                             * SmartReplyConfig maxResultCount.
                             * @member {number} maxResultCount
                             * @memberof google.cloud.dialogflow.v2.EvaluationConfig.SmartReplyConfig
                             * @instance
                             */
                            SmartReplyConfig.prototype.maxResultCount = 0;
    
                            /**
                             * Creates a new SmartReplyConfig instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2.EvaluationConfig.SmartReplyConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2.EvaluationConfig.ISmartReplyConfig=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2.EvaluationConfig.SmartReplyConfig} SmartReplyConfig instance
                             */
                            SmartReplyConfig.create = function create(properties) {
                                return new SmartReplyConfig(properties);
                            };
    
                            /**
                             * Encodes the specified SmartReplyConfig message. Does not implicitly {@link google.cloud.dialogflow.v2.EvaluationConfig.SmartReplyConfig.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2.EvaluationConfig.SmartReplyConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2.EvaluationConfig.ISmartReplyConfig} message SmartReplyConfig message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            SmartReplyConfig.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.allowlistDocument != null && Object.hasOwnProperty.call(message, "allowlistDocument"))
                                    writer.uint32(/* id 1, wireType 2 =*/10).string(message.allowlistDocument);
                                if (message.maxResultCount != null && Object.hasOwnProperty.call(message, "maxResultCount"))
                                    writer.uint32(/* id 2, wireType 0 =*/16).int32(message.maxResultCount);
                                return writer;
                            };
    
                            /**
                             * Encodes the specified SmartReplyConfig message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.EvaluationConfig.SmartReplyConfig.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2.EvaluationConfig.SmartReplyConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2.EvaluationConfig.ISmartReplyConfig} message SmartReplyConfig message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            SmartReplyConfig.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a SmartReplyConfig message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2.EvaluationConfig.SmartReplyConfig
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2.EvaluationConfig.SmartReplyConfig} SmartReplyConfig
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            SmartReplyConfig.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.EvaluationConfig.SmartReplyConfig();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.allowlistDocument = reader.string();
                                            break;
                                        }
                                    case 2: {
                                            message.maxResultCount = reader.int32();
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a SmartReplyConfig message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2.EvaluationConfig.SmartReplyConfig
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2.EvaluationConfig.SmartReplyConfig} SmartReplyConfig
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            SmartReplyConfig.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a SmartReplyConfig message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2.EvaluationConfig.SmartReplyConfig
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            SmartReplyConfig.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.allowlistDocument != null && message.hasOwnProperty("allowlistDocument"))
                                    if (!$util.isString(message.allowlistDocument))
                                        return "allowlistDocument: string expected";
                                if (message.maxResultCount != null && message.hasOwnProperty("maxResultCount"))
                                    if (!$util.isInteger(message.maxResultCount))
                                        return "maxResultCount: integer expected";
                                return null;
                            };
    
                            /**
                             * Creates a SmartReplyConfig message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2.EvaluationConfig.SmartReplyConfig
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2.EvaluationConfig.SmartReplyConfig} SmartReplyConfig
                             */
                            SmartReplyConfig.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2.EvaluationConfig.SmartReplyConfig)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2.EvaluationConfig.SmartReplyConfig();
                                if (object.allowlistDocument != null)
                                    message.allowlistDocument = String(object.allowlistDocument);
                                if (object.maxResultCount != null)
                                    message.maxResultCount = object.maxResultCount | 0;
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a SmartReplyConfig message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2.EvaluationConfig.SmartReplyConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2.EvaluationConfig.SmartReplyConfig} message SmartReplyConfig
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            SmartReplyConfig.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.defaults) {
                                    object.allowlistDocument = "";
                                    object.maxResultCount = 0;
                                }
                                if (message.allowlistDocument != null && message.hasOwnProperty("allowlistDocument"))
                                    object.allowlistDocument = message.allowlistDocument;
                                if (message.maxResultCount != null && message.hasOwnProperty("maxResultCount"))
                                    object.maxResultCount = message.maxResultCount;
                                return object;
                            };
    
                            /**
                             * Converts this SmartReplyConfig to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2.EvaluationConfig.SmartReplyConfig
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            SmartReplyConfig.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for SmartReplyConfig
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2.EvaluationConfig.SmartReplyConfig
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            SmartReplyConfig.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2.EvaluationConfig.SmartReplyConfig";
                            };
    
                            return SmartReplyConfig;
                        })();
    
                        EvaluationConfig.SmartComposeConfig = (function() {
    
                            /**
                             * Properties of a SmartComposeConfig.
                             * @memberof google.cloud.dialogflow.v2.EvaluationConfig
                             * @interface ISmartComposeConfig
                             * @property {string|null} [allowlistDocument] SmartComposeConfig allowlistDocument
                             * @property {number|null} [maxResultCount] SmartComposeConfig maxResultCount
                             */
    
                            /**
                             * Constructs a new SmartComposeConfig.
                             * @memberof google.cloud.dialogflow.v2.EvaluationConfig
                             * @classdesc Represents a SmartComposeConfig.
                             * @implements ISmartComposeConfig
                             * @constructor
                             * @param {google.cloud.dialogflow.v2.EvaluationConfig.ISmartComposeConfig=} [properties] Properties to set
                             */
                            function SmartComposeConfig(properties) {
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * SmartComposeConfig allowlistDocument.
                             * @member {string} allowlistDocument
                             * @memberof google.cloud.dialogflow.v2.EvaluationConfig.SmartComposeConfig
                             * @instance
                             */
                            SmartComposeConfig.prototype.allowlistDocument = "";
    
                            /**
                             * SmartComposeConfig maxResultCount.
                             * @member {number} maxResultCount
                             * @memberof google.cloud.dialogflow.v2.EvaluationConfig.SmartComposeConfig
                             * @instance
                             */
                            SmartComposeConfig.prototype.maxResultCount = 0;
    
                            /**
                             * Creates a new SmartComposeConfig instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2.EvaluationConfig.SmartComposeConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2.EvaluationConfig.ISmartComposeConfig=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2.EvaluationConfig.SmartComposeConfig} SmartComposeConfig instance
                             */
                            SmartComposeConfig.create = function create(properties) {
                                return new SmartComposeConfig(properties);
                            };
    
                            /**
                             * Encodes the specified SmartComposeConfig message. Does not implicitly {@link google.cloud.dialogflow.v2.EvaluationConfig.SmartComposeConfig.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2.EvaluationConfig.SmartComposeConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2.EvaluationConfig.ISmartComposeConfig} message SmartComposeConfig message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            SmartComposeConfig.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.allowlistDocument != null && Object.hasOwnProperty.call(message, "allowlistDocument"))
                                    writer.uint32(/* id 1, wireType 2 =*/10).string(message.allowlistDocument);
                                if (message.maxResultCount != null && Object.hasOwnProperty.call(message, "maxResultCount"))
                                    writer.uint32(/* id 2, wireType 0 =*/16).int32(message.maxResultCount);
                                return writer;
                            };
    
                            /**
                             * Encodes the specified SmartComposeConfig message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.EvaluationConfig.SmartComposeConfig.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2.EvaluationConfig.SmartComposeConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2.EvaluationConfig.ISmartComposeConfig} message SmartComposeConfig message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            SmartComposeConfig.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a SmartComposeConfig message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2.EvaluationConfig.SmartComposeConfig
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2.EvaluationConfig.SmartComposeConfig} SmartComposeConfig
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            SmartComposeConfig.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.EvaluationConfig.SmartComposeConfig();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.allowlistDocument = reader.string();
                                            break;
                                        }
                                    case 2: {
                                            message.maxResultCount = reader.int32();
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a SmartComposeConfig message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2.EvaluationConfig.SmartComposeConfig
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2.EvaluationConfig.SmartComposeConfig} SmartComposeConfig
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            SmartComposeConfig.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a SmartComposeConfig message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2.EvaluationConfig.SmartComposeConfig
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            SmartComposeConfig.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.allowlistDocument != null && message.hasOwnProperty("allowlistDocument"))
                                    if (!$util.isString(message.allowlistDocument))
                                        return "allowlistDocument: string expected";
                                if (message.maxResultCount != null && message.hasOwnProperty("maxResultCount"))
                                    if (!$util.isInteger(message.maxResultCount))
                                        return "maxResultCount: integer expected";
                                return null;
                            };
    
                            /**
                             * Creates a SmartComposeConfig message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2.EvaluationConfig.SmartComposeConfig
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2.EvaluationConfig.SmartComposeConfig} SmartComposeConfig
                             */
                            SmartComposeConfig.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2.EvaluationConfig.SmartComposeConfig)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2.EvaluationConfig.SmartComposeConfig();
                                if (object.allowlistDocument != null)
                                    message.allowlistDocument = String(object.allowlistDocument);
                                if (object.maxResultCount != null)
                                    message.maxResultCount = object.maxResultCount | 0;
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a SmartComposeConfig message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2.EvaluationConfig.SmartComposeConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2.EvaluationConfig.SmartComposeConfig} message SmartComposeConfig
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            SmartComposeConfig.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.defaults) {
                                    object.allowlistDocument = "";
                                    object.maxResultCount = 0;
                                }
                                if (message.allowlistDocument != null && message.hasOwnProperty("allowlistDocument"))
                                    object.allowlistDocument = message.allowlistDocument;
                                if (message.maxResultCount != null && message.hasOwnProperty("maxResultCount"))
                                    object.maxResultCount = message.maxResultCount;
                                return object;
                            };
    
                            /**
                             * Converts this SmartComposeConfig to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2.EvaluationConfig.SmartComposeConfig
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            SmartComposeConfig.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for SmartComposeConfig
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2.EvaluationConfig.SmartComposeConfig
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            SmartComposeConfig.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2.EvaluationConfig.SmartComposeConfig";
                            };
    
                            return SmartComposeConfig;
                        })();
    
                        return EvaluationConfig;
                    })();
    
                    v2.InputDataset = (function() {
    
                        /**
                         * Properties of an InputDataset.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IInputDataset
                         * @property {string|null} [dataset] InputDataset dataset
                         */
    
                        /**
                         * Constructs a new InputDataset.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an InputDataset.
                         * @implements IInputDataset
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IInputDataset=} [properties] Properties to set
                         */
                        function InputDataset(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * InputDataset dataset.
                         * @member {string} dataset
                         * @memberof google.cloud.dialogflow.v2.InputDataset
                         * @instance
                         */
                        InputDataset.prototype.dataset = "";
    
                        /**
                         * Creates a new InputDataset instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.InputDataset
                         * @static
                         * @param {google.cloud.dialogflow.v2.IInputDataset=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.InputDataset} InputDataset instance
                         */
                        InputDataset.create = function create(properties) {
                            return new InputDataset(properties);
                        };
    
                        /**
                         * Encodes the specified InputDataset message. Does not implicitly {@link google.cloud.dialogflow.v2.InputDataset.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.InputDataset
                         * @static
                         * @param {google.cloud.dialogflow.v2.IInputDataset} message InputDataset message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        InputDataset.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.dataset != null && Object.hasOwnProperty.call(message, "dataset"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.dataset);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified InputDataset message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.InputDataset.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.InputDataset
                         * @static
                         * @param {google.cloud.dialogflow.v2.IInputDataset} message InputDataset message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        InputDataset.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an InputDataset message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.InputDataset
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.InputDataset} InputDataset
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        InputDataset.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.InputDataset();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.dataset = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an InputDataset message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.InputDataset
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.InputDataset} InputDataset
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        InputDataset.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an InputDataset message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.InputDataset
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        InputDataset.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.dataset != null && message.hasOwnProperty("dataset"))
                                if (!$util.isString(message.dataset))
                                    return "dataset: string expected";
                            return null;
                        };
    
                        /**
                         * Creates an InputDataset message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.InputDataset
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.InputDataset} InputDataset
                         */
                        InputDataset.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.InputDataset)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.InputDataset();
                            if (object.dataset != null)
                                message.dataset = String(object.dataset);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an InputDataset message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.InputDataset
                         * @static
                         * @param {google.cloud.dialogflow.v2.InputDataset} message InputDataset
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        InputDataset.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.dataset = "";
                            if (message.dataset != null && message.hasOwnProperty("dataset"))
                                object.dataset = message.dataset;
                            return object;
                        };
    
                        /**
                         * Converts this InputDataset to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.InputDataset
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        InputDataset.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for InputDataset
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.InputDataset
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        InputDataset.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.InputDataset";
                        };
    
                        return InputDataset;
                    })();
    
                    v2.ArticleSuggestionModelMetadata = (function() {
    
                        /**
                         * Properties of an ArticleSuggestionModelMetadata.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IArticleSuggestionModelMetadata
                         * @property {google.cloud.dialogflow.v2.ConversationModel.ModelType|null} [trainingModelType] ArticleSuggestionModelMetadata trainingModelType
                         */
    
                        /**
                         * Constructs a new ArticleSuggestionModelMetadata.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an ArticleSuggestionModelMetadata.
                         * @implements IArticleSuggestionModelMetadata
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IArticleSuggestionModelMetadata=} [properties] Properties to set
                         */
                        function ArticleSuggestionModelMetadata(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ArticleSuggestionModelMetadata trainingModelType.
                         * @member {google.cloud.dialogflow.v2.ConversationModel.ModelType} trainingModelType
                         * @memberof google.cloud.dialogflow.v2.ArticleSuggestionModelMetadata
                         * @instance
                         */
                        ArticleSuggestionModelMetadata.prototype.trainingModelType = 0;
    
                        /**
                         * Creates a new ArticleSuggestionModelMetadata instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ArticleSuggestionModelMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.IArticleSuggestionModelMetadata=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ArticleSuggestionModelMetadata} ArticleSuggestionModelMetadata instance
                         */
                        ArticleSuggestionModelMetadata.create = function create(properties) {
                            return new ArticleSuggestionModelMetadata(properties);
                        };
    
                        /**
                         * Encodes the specified ArticleSuggestionModelMetadata message. Does not implicitly {@link google.cloud.dialogflow.v2.ArticleSuggestionModelMetadata.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ArticleSuggestionModelMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.IArticleSuggestionModelMetadata} message ArticleSuggestionModelMetadata message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ArticleSuggestionModelMetadata.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.trainingModelType != null && Object.hasOwnProperty.call(message, "trainingModelType"))
                                writer.uint32(/* id 3, wireType 0 =*/24).int32(message.trainingModelType);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ArticleSuggestionModelMetadata message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ArticleSuggestionModelMetadata.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ArticleSuggestionModelMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.IArticleSuggestionModelMetadata} message ArticleSuggestionModelMetadata message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ArticleSuggestionModelMetadata.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an ArticleSuggestionModelMetadata message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ArticleSuggestionModelMetadata
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ArticleSuggestionModelMetadata} ArticleSuggestionModelMetadata
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ArticleSuggestionModelMetadata.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ArticleSuggestionModelMetadata();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 3: {
                                        message.trainingModelType = reader.int32();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an ArticleSuggestionModelMetadata message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ArticleSuggestionModelMetadata
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ArticleSuggestionModelMetadata} ArticleSuggestionModelMetadata
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ArticleSuggestionModelMetadata.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an ArticleSuggestionModelMetadata message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ArticleSuggestionModelMetadata
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ArticleSuggestionModelMetadata.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.trainingModelType != null && message.hasOwnProperty("trainingModelType"))
                                switch (message.trainingModelType) {
                                default:
                                    return "trainingModelType: enum value expected";
                                case 0:
                                case 2:
                                case 6:
                                    break;
                                }
                            return null;
                        };
    
                        /**
                         * Creates an ArticleSuggestionModelMetadata message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ArticleSuggestionModelMetadata
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ArticleSuggestionModelMetadata} ArticleSuggestionModelMetadata
                         */
                        ArticleSuggestionModelMetadata.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ArticleSuggestionModelMetadata)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ArticleSuggestionModelMetadata();
                            switch (object.trainingModelType) {
                            default:
                                if (typeof object.trainingModelType === "number") {
                                    message.trainingModelType = object.trainingModelType;
                                    break;
                                }
                                break;
                            case "MODEL_TYPE_UNSPECIFIED":
                            case 0:
                                message.trainingModelType = 0;
                                break;
                            case "SMART_REPLY_DUAL_ENCODER_MODEL":
                            case 2:
                                message.trainingModelType = 2;
                                break;
                            case "SMART_REPLY_BERT_MODEL":
                            case 6:
                                message.trainingModelType = 6;
                                break;
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an ArticleSuggestionModelMetadata message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ArticleSuggestionModelMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.ArticleSuggestionModelMetadata} message ArticleSuggestionModelMetadata
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ArticleSuggestionModelMetadata.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.trainingModelType = options.enums === String ? "MODEL_TYPE_UNSPECIFIED" : 0;
                            if (message.trainingModelType != null && message.hasOwnProperty("trainingModelType"))
                                object.trainingModelType = options.enums === String ? $root.google.cloud.dialogflow.v2.ConversationModel.ModelType[message.trainingModelType] === undefined ? message.trainingModelType : $root.google.cloud.dialogflow.v2.ConversationModel.ModelType[message.trainingModelType] : message.trainingModelType;
                            return object;
                        };
    
                        /**
                         * Converts this ArticleSuggestionModelMetadata to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ArticleSuggestionModelMetadata
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ArticleSuggestionModelMetadata.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ArticleSuggestionModelMetadata
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ArticleSuggestionModelMetadata
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ArticleSuggestionModelMetadata.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ArticleSuggestionModelMetadata";
                        };
    
                        return ArticleSuggestionModelMetadata;
                    })();
    
                    v2.SmartReplyModelMetadata = (function() {
    
                        /**
                         * Properties of a SmartReplyModelMetadata.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ISmartReplyModelMetadata
                         * @property {google.cloud.dialogflow.v2.ConversationModel.ModelType|null} [trainingModelType] SmartReplyModelMetadata trainingModelType
                         */
    
                        /**
                         * Constructs a new SmartReplyModelMetadata.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a SmartReplyModelMetadata.
                         * @implements ISmartReplyModelMetadata
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ISmartReplyModelMetadata=} [properties] Properties to set
                         */
                        function SmartReplyModelMetadata(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SmartReplyModelMetadata trainingModelType.
                         * @member {google.cloud.dialogflow.v2.ConversationModel.ModelType} trainingModelType
                         * @memberof google.cloud.dialogflow.v2.SmartReplyModelMetadata
                         * @instance
                         */
                        SmartReplyModelMetadata.prototype.trainingModelType = 0;
    
                        /**
                         * Creates a new SmartReplyModelMetadata instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.SmartReplyModelMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISmartReplyModelMetadata=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.SmartReplyModelMetadata} SmartReplyModelMetadata instance
                         */
                        SmartReplyModelMetadata.create = function create(properties) {
                            return new SmartReplyModelMetadata(properties);
                        };
    
                        /**
                         * Encodes the specified SmartReplyModelMetadata message. Does not implicitly {@link google.cloud.dialogflow.v2.SmartReplyModelMetadata.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.SmartReplyModelMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISmartReplyModelMetadata} message SmartReplyModelMetadata message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SmartReplyModelMetadata.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.trainingModelType != null && Object.hasOwnProperty.call(message, "trainingModelType"))
                                writer.uint32(/* id 6, wireType 0 =*/48).int32(message.trainingModelType);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SmartReplyModelMetadata message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.SmartReplyModelMetadata.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SmartReplyModelMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISmartReplyModelMetadata} message SmartReplyModelMetadata message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SmartReplyModelMetadata.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SmartReplyModelMetadata message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.SmartReplyModelMetadata
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.SmartReplyModelMetadata} SmartReplyModelMetadata
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SmartReplyModelMetadata.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.SmartReplyModelMetadata();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 6: {
                                        message.trainingModelType = reader.int32();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SmartReplyModelMetadata message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SmartReplyModelMetadata
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.SmartReplyModelMetadata} SmartReplyModelMetadata
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SmartReplyModelMetadata.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SmartReplyModelMetadata message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.SmartReplyModelMetadata
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SmartReplyModelMetadata.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.trainingModelType != null && message.hasOwnProperty("trainingModelType"))
                                switch (message.trainingModelType) {
                                default:
                                    return "trainingModelType: enum value expected";
                                case 0:
                                case 2:
                                case 6:
                                    break;
                                }
                            return null;
                        };
    
                        /**
                         * Creates a SmartReplyModelMetadata message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.SmartReplyModelMetadata
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.SmartReplyModelMetadata} SmartReplyModelMetadata
                         */
                        SmartReplyModelMetadata.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.SmartReplyModelMetadata)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.SmartReplyModelMetadata();
                            switch (object.trainingModelType) {
                            default:
                                if (typeof object.trainingModelType === "number") {
                                    message.trainingModelType = object.trainingModelType;
                                    break;
                                }
                                break;
                            case "MODEL_TYPE_UNSPECIFIED":
                            case 0:
                                message.trainingModelType = 0;
                                break;
                            case "SMART_REPLY_DUAL_ENCODER_MODEL":
                            case 2:
                                message.trainingModelType = 2;
                                break;
                            case "SMART_REPLY_BERT_MODEL":
                            case 6:
                                message.trainingModelType = 6;
                                break;
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SmartReplyModelMetadata message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.SmartReplyModelMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.SmartReplyModelMetadata} message SmartReplyModelMetadata
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SmartReplyModelMetadata.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.trainingModelType = options.enums === String ? "MODEL_TYPE_UNSPECIFIED" : 0;
                            if (message.trainingModelType != null && message.hasOwnProperty("trainingModelType"))
                                object.trainingModelType = options.enums === String ? $root.google.cloud.dialogflow.v2.ConversationModel.ModelType[message.trainingModelType] === undefined ? message.trainingModelType : $root.google.cloud.dialogflow.v2.ConversationModel.ModelType[message.trainingModelType] : message.trainingModelType;
                            return object;
                        };
    
                        /**
                         * Converts this SmartReplyModelMetadata to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.SmartReplyModelMetadata
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SmartReplyModelMetadata.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SmartReplyModelMetadata
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.SmartReplyModelMetadata
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SmartReplyModelMetadata.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.SmartReplyModelMetadata";
                        };
    
                        return SmartReplyModelMetadata;
                    })();
    
                    v2.SmartReplyMetrics = (function() {
    
                        /**
                         * Properties of a SmartReplyMetrics.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ISmartReplyMetrics
                         * @property {number|null} [allowlistCoverage] SmartReplyMetrics allowlistCoverage
                         * @property {Array.<google.cloud.dialogflow.v2.SmartReplyMetrics.ITopNMetrics>|null} [topNMetrics] SmartReplyMetrics topNMetrics
                         * @property {number|Long|null} [conversationCount] SmartReplyMetrics conversationCount
                         */
    
                        /**
                         * Constructs a new SmartReplyMetrics.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a SmartReplyMetrics.
                         * @implements ISmartReplyMetrics
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ISmartReplyMetrics=} [properties] Properties to set
                         */
                        function SmartReplyMetrics(properties) {
                            this.topNMetrics = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SmartReplyMetrics allowlistCoverage.
                         * @member {number} allowlistCoverage
                         * @memberof google.cloud.dialogflow.v2.SmartReplyMetrics
                         * @instance
                         */
                        SmartReplyMetrics.prototype.allowlistCoverage = 0;
    
                        /**
                         * SmartReplyMetrics topNMetrics.
                         * @member {Array.<google.cloud.dialogflow.v2.SmartReplyMetrics.ITopNMetrics>} topNMetrics
                         * @memberof google.cloud.dialogflow.v2.SmartReplyMetrics
                         * @instance
                         */
                        SmartReplyMetrics.prototype.topNMetrics = $util.emptyArray;
    
                        /**
                         * SmartReplyMetrics conversationCount.
                         * @member {number|Long} conversationCount
                         * @memberof google.cloud.dialogflow.v2.SmartReplyMetrics
                         * @instance
                         */
                        SmartReplyMetrics.prototype.conversationCount = $util.Long ? $util.Long.fromBits(0,0,false) : 0;
    
                        /**
                         * Creates a new SmartReplyMetrics instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.SmartReplyMetrics
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISmartReplyMetrics=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.SmartReplyMetrics} SmartReplyMetrics instance
                         */
                        SmartReplyMetrics.create = function create(properties) {
                            return new SmartReplyMetrics(properties);
                        };
    
                        /**
                         * Encodes the specified SmartReplyMetrics message. Does not implicitly {@link google.cloud.dialogflow.v2.SmartReplyMetrics.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.SmartReplyMetrics
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISmartReplyMetrics} message SmartReplyMetrics message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SmartReplyMetrics.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.allowlistCoverage != null && Object.hasOwnProperty.call(message, "allowlistCoverage"))
                                writer.uint32(/* id 1, wireType 5 =*/13).float(message.allowlistCoverage);
                            if (message.topNMetrics != null && message.topNMetrics.length)
                                for (var i = 0; i < message.topNMetrics.length; ++i)
                                    $root.google.cloud.dialogflow.v2.SmartReplyMetrics.TopNMetrics.encode(message.topNMetrics[i], writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.conversationCount != null && Object.hasOwnProperty.call(message, "conversationCount"))
                                writer.uint32(/* id 3, wireType 0 =*/24).int64(message.conversationCount);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SmartReplyMetrics message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.SmartReplyMetrics.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SmartReplyMetrics
                         * @static
                         * @param {google.cloud.dialogflow.v2.ISmartReplyMetrics} message SmartReplyMetrics message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SmartReplyMetrics.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SmartReplyMetrics message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.SmartReplyMetrics
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.SmartReplyMetrics} SmartReplyMetrics
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SmartReplyMetrics.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.SmartReplyMetrics();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.allowlistCoverage = reader.float();
                                        break;
                                    }
                                case 2: {
                                        if (!(message.topNMetrics && message.topNMetrics.length))
                                            message.topNMetrics = [];
                                        message.topNMetrics.push($root.google.cloud.dialogflow.v2.SmartReplyMetrics.TopNMetrics.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 3: {
                                        message.conversationCount = reader.int64();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SmartReplyMetrics message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.SmartReplyMetrics
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.SmartReplyMetrics} SmartReplyMetrics
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SmartReplyMetrics.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SmartReplyMetrics message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.SmartReplyMetrics
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SmartReplyMetrics.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.allowlistCoverage != null && message.hasOwnProperty("allowlistCoverage"))
                                if (typeof message.allowlistCoverage !== "number")
                                    return "allowlistCoverage: number expected";
                            if (message.topNMetrics != null && message.hasOwnProperty("topNMetrics")) {
                                if (!Array.isArray(message.topNMetrics))
                                    return "topNMetrics: array expected";
                                for (var i = 0; i < message.topNMetrics.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.SmartReplyMetrics.TopNMetrics.verify(message.topNMetrics[i]);
                                    if (error)
                                        return "topNMetrics." + error;
                                }
                            }
                            if (message.conversationCount != null && message.hasOwnProperty("conversationCount"))
                                if (!$util.isInteger(message.conversationCount) && !(message.conversationCount && $util.isInteger(message.conversationCount.low) && $util.isInteger(message.conversationCount.high)))
                                    return "conversationCount: integer|Long expected";
                            return null;
                        };
    
                        /**
                         * Creates a SmartReplyMetrics message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.SmartReplyMetrics
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.SmartReplyMetrics} SmartReplyMetrics
                         */
                        SmartReplyMetrics.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.SmartReplyMetrics)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.SmartReplyMetrics();
                            if (object.allowlistCoverage != null)
                                message.allowlistCoverage = Number(object.allowlistCoverage);
                            if (object.topNMetrics) {
                                if (!Array.isArray(object.topNMetrics))
                                    throw TypeError(".google.cloud.dialogflow.v2.SmartReplyMetrics.topNMetrics: array expected");
                                message.topNMetrics = [];
                                for (var i = 0; i < object.topNMetrics.length; ++i) {
                                    if (typeof object.topNMetrics[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.SmartReplyMetrics.topNMetrics: object expected");
                                    message.topNMetrics[i] = $root.google.cloud.dialogflow.v2.SmartReplyMetrics.TopNMetrics.fromObject(object.topNMetrics[i]);
                                }
                            }
                            if (object.conversationCount != null)
                                if ($util.Long)
                                    (message.conversationCount = $util.Long.fromValue(object.conversationCount)).unsigned = false;
                                else if (typeof object.conversationCount === "string")
                                    message.conversationCount = parseInt(object.conversationCount, 10);
                                else if (typeof object.conversationCount === "number")
                                    message.conversationCount = object.conversationCount;
                                else if (typeof object.conversationCount === "object")
                                    message.conversationCount = new $util.LongBits(object.conversationCount.low >>> 0, object.conversationCount.high >>> 0).toNumber();
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SmartReplyMetrics message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.SmartReplyMetrics
                         * @static
                         * @param {google.cloud.dialogflow.v2.SmartReplyMetrics} message SmartReplyMetrics
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SmartReplyMetrics.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.topNMetrics = [];
                            if (options.defaults) {
                                object.allowlistCoverage = 0;
                                if ($util.Long) {
                                    var long = new $util.Long(0, 0, false);
                                    object.conversationCount = options.longs === String ? long.toString() : options.longs === Number ? long.toNumber() : long;
                                } else
                                    object.conversationCount = options.longs === String ? "0" : 0;
                            }
                            if (message.allowlistCoverage != null && message.hasOwnProperty("allowlistCoverage"))
                                object.allowlistCoverage = options.json && !isFinite(message.allowlistCoverage) ? String(message.allowlistCoverage) : message.allowlistCoverage;
                            if (message.topNMetrics && message.topNMetrics.length) {
                                object.topNMetrics = [];
                                for (var j = 0; j < message.topNMetrics.length; ++j)
                                    object.topNMetrics[j] = $root.google.cloud.dialogflow.v2.SmartReplyMetrics.TopNMetrics.toObject(message.topNMetrics[j], options);
                            }
                            if (message.conversationCount != null && message.hasOwnProperty("conversationCount"))
                                if (typeof message.conversationCount === "number")
                                    object.conversationCount = options.longs === String ? String(message.conversationCount) : message.conversationCount;
                                else
                                    object.conversationCount = options.longs === String ? $util.Long.prototype.toString.call(message.conversationCount) : options.longs === Number ? new $util.LongBits(message.conversationCount.low >>> 0, message.conversationCount.high >>> 0).toNumber() : message.conversationCount;
                            return object;
                        };
    
                        /**
                         * Converts this SmartReplyMetrics to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.SmartReplyMetrics
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SmartReplyMetrics.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SmartReplyMetrics
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.SmartReplyMetrics
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SmartReplyMetrics.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.SmartReplyMetrics";
                        };
    
                        SmartReplyMetrics.TopNMetrics = (function() {
    
                            /**
                             * Properties of a TopNMetrics.
                             * @memberof google.cloud.dialogflow.v2.SmartReplyMetrics
                             * @interface ITopNMetrics
                             * @property {number|null} [n] TopNMetrics n
                             * @property {number|null} [recall] TopNMetrics recall
                             */
    
                            /**
                             * Constructs a new TopNMetrics.
                             * @memberof google.cloud.dialogflow.v2.SmartReplyMetrics
                             * @classdesc Represents a TopNMetrics.
                             * @implements ITopNMetrics
                             * @constructor
                             * @param {google.cloud.dialogflow.v2.SmartReplyMetrics.ITopNMetrics=} [properties] Properties to set
                             */
                            function TopNMetrics(properties) {
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * TopNMetrics n.
                             * @member {number} n
                             * @memberof google.cloud.dialogflow.v2.SmartReplyMetrics.TopNMetrics
                             * @instance
                             */
                            TopNMetrics.prototype.n = 0;
    
                            /**
                             * TopNMetrics recall.
                             * @member {number} recall
                             * @memberof google.cloud.dialogflow.v2.SmartReplyMetrics.TopNMetrics
                             * @instance
                             */
                            TopNMetrics.prototype.recall = 0;
    
                            /**
                             * Creates a new TopNMetrics instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2.SmartReplyMetrics.TopNMetrics
                             * @static
                             * @param {google.cloud.dialogflow.v2.SmartReplyMetrics.ITopNMetrics=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2.SmartReplyMetrics.TopNMetrics} TopNMetrics instance
                             */
                            TopNMetrics.create = function create(properties) {
                                return new TopNMetrics(properties);
                            };
    
                            /**
                             * Encodes the specified TopNMetrics message. Does not implicitly {@link google.cloud.dialogflow.v2.SmartReplyMetrics.TopNMetrics.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2.SmartReplyMetrics.TopNMetrics
                             * @static
                             * @param {google.cloud.dialogflow.v2.SmartReplyMetrics.ITopNMetrics} message TopNMetrics message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            TopNMetrics.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.n != null && Object.hasOwnProperty.call(message, "n"))
                                    writer.uint32(/* id 1, wireType 0 =*/8).int32(message.n);
                                if (message.recall != null && Object.hasOwnProperty.call(message, "recall"))
                                    writer.uint32(/* id 2, wireType 5 =*/21).float(message.recall);
                                return writer;
                            };
    
                            /**
                             * Encodes the specified TopNMetrics message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.SmartReplyMetrics.TopNMetrics.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2.SmartReplyMetrics.TopNMetrics
                             * @static
                             * @param {google.cloud.dialogflow.v2.SmartReplyMetrics.ITopNMetrics} message TopNMetrics message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            TopNMetrics.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a TopNMetrics message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2.SmartReplyMetrics.TopNMetrics
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2.SmartReplyMetrics.TopNMetrics} TopNMetrics
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            TopNMetrics.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.SmartReplyMetrics.TopNMetrics();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.n = reader.int32();
                                            break;
                                        }
                                    case 2: {
                                            message.recall = reader.float();
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a TopNMetrics message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2.SmartReplyMetrics.TopNMetrics
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2.SmartReplyMetrics.TopNMetrics} TopNMetrics
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            TopNMetrics.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a TopNMetrics message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2.SmartReplyMetrics.TopNMetrics
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            TopNMetrics.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.n != null && message.hasOwnProperty("n"))
                                    if (!$util.isInteger(message.n))
                                        return "n: integer expected";
                                if (message.recall != null && message.hasOwnProperty("recall"))
                                    if (typeof message.recall !== "number")
                                        return "recall: number expected";
                                return null;
                            };
    
                            /**
                             * Creates a TopNMetrics message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2.SmartReplyMetrics.TopNMetrics
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2.SmartReplyMetrics.TopNMetrics} TopNMetrics
                             */
                            TopNMetrics.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2.SmartReplyMetrics.TopNMetrics)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2.SmartReplyMetrics.TopNMetrics();
                                if (object.n != null)
                                    message.n = object.n | 0;
                                if (object.recall != null)
                                    message.recall = Number(object.recall);
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a TopNMetrics message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2.SmartReplyMetrics.TopNMetrics
                             * @static
                             * @param {google.cloud.dialogflow.v2.SmartReplyMetrics.TopNMetrics} message TopNMetrics
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            TopNMetrics.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.defaults) {
                                    object.n = 0;
                                    object.recall = 0;
                                }
                                if (message.n != null && message.hasOwnProperty("n"))
                                    object.n = message.n;
                                if (message.recall != null && message.hasOwnProperty("recall"))
                                    object.recall = options.json && !isFinite(message.recall) ? String(message.recall) : message.recall;
                                return object;
                            };
    
                            /**
                             * Converts this TopNMetrics to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2.SmartReplyMetrics.TopNMetrics
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            TopNMetrics.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for TopNMetrics
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2.SmartReplyMetrics.TopNMetrics
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            TopNMetrics.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2.SmartReplyMetrics.TopNMetrics";
                            };
    
                            return TopNMetrics;
                        })();
    
                        return SmartReplyMetrics;
                    })();
    
                    v2.CreateConversationModelRequest = (function() {
    
                        /**
                         * Properties of a CreateConversationModelRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ICreateConversationModelRequest
                         * @property {string|null} [parent] CreateConversationModelRequest parent
                         * @property {google.cloud.dialogflow.v2.IConversationModel|null} [conversationModel] CreateConversationModelRequest conversationModel
                         */
    
                        /**
                         * Constructs a new CreateConversationModelRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a CreateConversationModelRequest.
                         * @implements ICreateConversationModelRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ICreateConversationModelRequest=} [properties] Properties to set
                         */
                        function CreateConversationModelRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * CreateConversationModelRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.CreateConversationModelRequest
                         * @instance
                         */
                        CreateConversationModelRequest.prototype.parent = "";
    
                        /**
                         * CreateConversationModelRequest conversationModel.
                         * @member {google.cloud.dialogflow.v2.IConversationModel|null|undefined} conversationModel
                         * @memberof google.cloud.dialogflow.v2.CreateConversationModelRequest
                         * @instance
                         */
                        CreateConversationModelRequest.prototype.conversationModel = null;
    
                        /**
                         * Creates a new CreateConversationModelRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.CreateConversationModelRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICreateConversationModelRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.CreateConversationModelRequest} CreateConversationModelRequest instance
                         */
                        CreateConversationModelRequest.create = function create(properties) {
                            return new CreateConversationModelRequest(properties);
                        };
    
                        /**
                         * Encodes the specified CreateConversationModelRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.CreateConversationModelRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.CreateConversationModelRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICreateConversationModelRequest} message CreateConversationModelRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateConversationModelRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.conversationModel != null && Object.hasOwnProperty.call(message, "conversationModel"))
                                $root.google.cloud.dialogflow.v2.ConversationModel.encode(message.conversationModel, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified CreateConversationModelRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.CreateConversationModelRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.CreateConversationModelRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICreateConversationModelRequest} message CreateConversationModelRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateConversationModelRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a CreateConversationModelRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.CreateConversationModelRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.CreateConversationModelRequest} CreateConversationModelRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateConversationModelRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.CreateConversationModelRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.conversationModel = $root.google.cloud.dialogflow.v2.ConversationModel.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a CreateConversationModelRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.CreateConversationModelRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.CreateConversationModelRequest} CreateConversationModelRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateConversationModelRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a CreateConversationModelRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.CreateConversationModelRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        CreateConversationModelRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.conversationModel != null && message.hasOwnProperty("conversationModel")) {
                                var error = $root.google.cloud.dialogflow.v2.ConversationModel.verify(message.conversationModel);
                                if (error)
                                    return "conversationModel." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a CreateConversationModelRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.CreateConversationModelRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.CreateConversationModelRequest} CreateConversationModelRequest
                         */
                        CreateConversationModelRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.CreateConversationModelRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.CreateConversationModelRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.conversationModel != null) {
                                if (typeof object.conversationModel !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.CreateConversationModelRequest.conversationModel: object expected");
                                message.conversationModel = $root.google.cloud.dialogflow.v2.ConversationModel.fromObject(object.conversationModel);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a CreateConversationModelRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.CreateConversationModelRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.CreateConversationModelRequest} message CreateConversationModelRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        CreateConversationModelRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.conversationModel = null;
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.conversationModel != null && message.hasOwnProperty("conversationModel"))
                                object.conversationModel = $root.google.cloud.dialogflow.v2.ConversationModel.toObject(message.conversationModel, options);
                            return object;
                        };
    
                        /**
                         * Converts this CreateConversationModelRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.CreateConversationModelRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        CreateConversationModelRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for CreateConversationModelRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.CreateConversationModelRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        CreateConversationModelRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.CreateConversationModelRequest";
                        };
    
                        return CreateConversationModelRequest;
                    })();
    
                    v2.GetConversationModelRequest = (function() {
    
                        /**
                         * Properties of a GetConversationModelRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IGetConversationModelRequest
                         * @property {string|null} [name] GetConversationModelRequest name
                         */
    
                        /**
                         * Constructs a new GetConversationModelRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a GetConversationModelRequest.
                         * @implements IGetConversationModelRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IGetConversationModelRequest=} [properties] Properties to set
                         */
                        function GetConversationModelRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GetConversationModelRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2.GetConversationModelRequest
                         * @instance
                         */
                        GetConversationModelRequest.prototype.name = "";
    
                        /**
                         * Creates a new GetConversationModelRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.GetConversationModelRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetConversationModelRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.GetConversationModelRequest} GetConversationModelRequest instance
                         */
                        GetConversationModelRequest.create = function create(properties) {
                            return new GetConversationModelRequest(properties);
                        };
    
                        /**
                         * Encodes the specified GetConversationModelRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.GetConversationModelRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.GetConversationModelRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetConversationModelRequest} message GetConversationModelRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetConversationModelRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GetConversationModelRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.GetConversationModelRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GetConversationModelRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetConversationModelRequest} message GetConversationModelRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetConversationModelRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GetConversationModelRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.GetConversationModelRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.GetConversationModelRequest} GetConversationModelRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetConversationModelRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.GetConversationModelRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GetConversationModelRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GetConversationModelRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.GetConversationModelRequest} GetConversationModelRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetConversationModelRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GetConversationModelRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.GetConversationModelRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GetConversationModelRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a GetConversationModelRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.GetConversationModelRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.GetConversationModelRequest} GetConversationModelRequest
                         */
                        GetConversationModelRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.GetConversationModelRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.GetConversationModelRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GetConversationModelRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.GetConversationModelRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.GetConversationModelRequest} message GetConversationModelRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GetConversationModelRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.name = "";
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            return object;
                        };
    
                        /**
                         * Converts this GetConversationModelRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.GetConversationModelRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GetConversationModelRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GetConversationModelRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.GetConversationModelRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GetConversationModelRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.GetConversationModelRequest";
                        };
    
                        return GetConversationModelRequest;
                    })();
    
                    v2.ListConversationModelsRequest = (function() {
    
                        /**
                         * Properties of a ListConversationModelsRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IListConversationModelsRequest
                         * @property {string|null} [parent] ListConversationModelsRequest parent
                         * @property {number|null} [pageSize] ListConversationModelsRequest pageSize
                         * @property {string|null} [pageToken] ListConversationModelsRequest pageToken
                         */
    
                        /**
                         * Constructs a new ListConversationModelsRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a ListConversationModelsRequest.
                         * @implements IListConversationModelsRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IListConversationModelsRequest=} [properties] Properties to set
                         */
                        function ListConversationModelsRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListConversationModelsRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.ListConversationModelsRequest
                         * @instance
                         */
                        ListConversationModelsRequest.prototype.parent = "";
    
                        /**
                         * ListConversationModelsRequest pageSize.
                         * @member {number} pageSize
                         * @memberof google.cloud.dialogflow.v2.ListConversationModelsRequest
                         * @instance
                         */
                        ListConversationModelsRequest.prototype.pageSize = 0;
    
                        /**
                         * ListConversationModelsRequest pageToken.
                         * @member {string} pageToken
                         * @memberof google.cloud.dialogflow.v2.ListConversationModelsRequest
                         * @instance
                         */
                        ListConversationModelsRequest.prototype.pageToken = "";
    
                        /**
                         * Creates a new ListConversationModelsRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ListConversationModelsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListConversationModelsRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ListConversationModelsRequest} ListConversationModelsRequest instance
                         */
                        ListConversationModelsRequest.create = function create(properties) {
                            return new ListConversationModelsRequest(properties);
                        };
    
                        /**
                         * Encodes the specified ListConversationModelsRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.ListConversationModelsRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ListConversationModelsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListConversationModelsRequest} message ListConversationModelsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListConversationModelsRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.pageSize != null && Object.hasOwnProperty.call(message, "pageSize"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.pageSize);
                            if (message.pageToken != null && Object.hasOwnProperty.call(message, "pageToken"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.pageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListConversationModelsRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ListConversationModelsRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListConversationModelsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListConversationModelsRequest} message ListConversationModelsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListConversationModelsRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListConversationModelsRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ListConversationModelsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ListConversationModelsRequest} ListConversationModelsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListConversationModelsRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ListConversationModelsRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.pageSize = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.pageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListConversationModelsRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListConversationModelsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ListConversationModelsRequest} ListConversationModelsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListConversationModelsRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListConversationModelsRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ListConversationModelsRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListConversationModelsRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                if (!$util.isInteger(message.pageSize))
                                    return "pageSize: integer expected";
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                if (!$util.isString(message.pageToken))
                                    return "pageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListConversationModelsRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ListConversationModelsRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ListConversationModelsRequest} ListConversationModelsRequest
                         */
                        ListConversationModelsRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ListConversationModelsRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ListConversationModelsRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.pageSize != null)
                                message.pageSize = object.pageSize | 0;
                            if (object.pageToken != null)
                                message.pageToken = String(object.pageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListConversationModelsRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ListConversationModelsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ListConversationModelsRequest} message ListConversationModelsRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListConversationModelsRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.pageSize = 0;
                                object.pageToken = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                object.pageSize = message.pageSize;
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                object.pageToken = message.pageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListConversationModelsRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ListConversationModelsRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListConversationModelsRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListConversationModelsRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ListConversationModelsRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListConversationModelsRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ListConversationModelsRequest";
                        };
    
                        return ListConversationModelsRequest;
                    })();
    
                    v2.ListConversationModelsResponse = (function() {
    
                        /**
                         * Properties of a ListConversationModelsResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IListConversationModelsResponse
                         * @property {Array.<google.cloud.dialogflow.v2.IConversationModel>|null} [conversationModels] ListConversationModelsResponse conversationModels
                         * @property {string|null} [nextPageToken] ListConversationModelsResponse nextPageToken
                         */
    
                        /**
                         * Constructs a new ListConversationModelsResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a ListConversationModelsResponse.
                         * @implements IListConversationModelsResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IListConversationModelsResponse=} [properties] Properties to set
                         */
                        function ListConversationModelsResponse(properties) {
                            this.conversationModels = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListConversationModelsResponse conversationModels.
                         * @member {Array.<google.cloud.dialogflow.v2.IConversationModel>} conversationModels
                         * @memberof google.cloud.dialogflow.v2.ListConversationModelsResponse
                         * @instance
                         */
                        ListConversationModelsResponse.prototype.conversationModels = $util.emptyArray;
    
                        /**
                         * ListConversationModelsResponse nextPageToken.
                         * @member {string} nextPageToken
                         * @memberof google.cloud.dialogflow.v2.ListConversationModelsResponse
                         * @instance
                         */
                        ListConversationModelsResponse.prototype.nextPageToken = "";
    
                        /**
                         * Creates a new ListConversationModelsResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ListConversationModelsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListConversationModelsResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ListConversationModelsResponse} ListConversationModelsResponse instance
                         */
                        ListConversationModelsResponse.create = function create(properties) {
                            return new ListConversationModelsResponse(properties);
                        };
    
                        /**
                         * Encodes the specified ListConversationModelsResponse message. Does not implicitly {@link google.cloud.dialogflow.v2.ListConversationModelsResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ListConversationModelsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListConversationModelsResponse} message ListConversationModelsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListConversationModelsResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.conversationModels != null && message.conversationModels.length)
                                for (var i = 0; i < message.conversationModels.length; ++i)
                                    $root.google.cloud.dialogflow.v2.ConversationModel.encode(message.conversationModels[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.nextPageToken != null && Object.hasOwnProperty.call(message, "nextPageToken"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.nextPageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListConversationModelsResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ListConversationModelsResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListConversationModelsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListConversationModelsResponse} message ListConversationModelsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListConversationModelsResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListConversationModelsResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ListConversationModelsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ListConversationModelsResponse} ListConversationModelsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListConversationModelsResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ListConversationModelsResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.conversationModels && message.conversationModels.length))
                                            message.conversationModels = [];
                                        message.conversationModels.push($root.google.cloud.dialogflow.v2.ConversationModel.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 2: {
                                        message.nextPageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListConversationModelsResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListConversationModelsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ListConversationModelsResponse} ListConversationModelsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListConversationModelsResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListConversationModelsResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ListConversationModelsResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListConversationModelsResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.conversationModels != null && message.hasOwnProperty("conversationModels")) {
                                if (!Array.isArray(message.conversationModels))
                                    return "conversationModels: array expected";
                                for (var i = 0; i < message.conversationModels.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.ConversationModel.verify(message.conversationModels[i]);
                                    if (error)
                                        return "conversationModels." + error;
                                }
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                if (!$util.isString(message.nextPageToken))
                                    return "nextPageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListConversationModelsResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ListConversationModelsResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ListConversationModelsResponse} ListConversationModelsResponse
                         */
                        ListConversationModelsResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ListConversationModelsResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ListConversationModelsResponse();
                            if (object.conversationModels) {
                                if (!Array.isArray(object.conversationModels))
                                    throw TypeError(".google.cloud.dialogflow.v2.ListConversationModelsResponse.conversationModels: array expected");
                                message.conversationModels = [];
                                for (var i = 0; i < object.conversationModels.length; ++i) {
                                    if (typeof object.conversationModels[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.ListConversationModelsResponse.conversationModels: object expected");
                                    message.conversationModels[i] = $root.google.cloud.dialogflow.v2.ConversationModel.fromObject(object.conversationModels[i]);
                                }
                            }
                            if (object.nextPageToken != null)
                                message.nextPageToken = String(object.nextPageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListConversationModelsResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ListConversationModelsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.ListConversationModelsResponse} message ListConversationModelsResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListConversationModelsResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.conversationModels = [];
                            if (options.defaults)
                                object.nextPageToken = "";
                            if (message.conversationModels && message.conversationModels.length) {
                                object.conversationModels = [];
                                for (var j = 0; j < message.conversationModels.length; ++j)
                                    object.conversationModels[j] = $root.google.cloud.dialogflow.v2.ConversationModel.toObject(message.conversationModels[j], options);
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                object.nextPageToken = message.nextPageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListConversationModelsResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ListConversationModelsResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListConversationModelsResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListConversationModelsResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ListConversationModelsResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListConversationModelsResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ListConversationModelsResponse";
                        };
    
                        return ListConversationModelsResponse;
                    })();
    
                    v2.DeleteConversationModelRequest = (function() {
    
                        /**
                         * Properties of a DeleteConversationModelRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IDeleteConversationModelRequest
                         * @property {string|null} [name] DeleteConversationModelRequest name
                         */
    
                        /**
                         * Constructs a new DeleteConversationModelRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a DeleteConversationModelRequest.
                         * @implements IDeleteConversationModelRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IDeleteConversationModelRequest=} [properties] Properties to set
                         */
                        function DeleteConversationModelRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * DeleteConversationModelRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2.DeleteConversationModelRequest
                         * @instance
                         */
                        DeleteConversationModelRequest.prototype.name = "";
    
                        /**
                         * Creates a new DeleteConversationModelRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.DeleteConversationModelRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDeleteConversationModelRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.DeleteConversationModelRequest} DeleteConversationModelRequest instance
                         */
                        DeleteConversationModelRequest.create = function create(properties) {
                            return new DeleteConversationModelRequest(properties);
                        };
    
                        /**
                         * Encodes the specified DeleteConversationModelRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.DeleteConversationModelRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.DeleteConversationModelRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDeleteConversationModelRequest} message DeleteConversationModelRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteConversationModelRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified DeleteConversationModelRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.DeleteConversationModelRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.DeleteConversationModelRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDeleteConversationModelRequest} message DeleteConversationModelRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteConversationModelRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a DeleteConversationModelRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.DeleteConversationModelRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.DeleteConversationModelRequest} DeleteConversationModelRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteConversationModelRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.DeleteConversationModelRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a DeleteConversationModelRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.DeleteConversationModelRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.DeleteConversationModelRequest} DeleteConversationModelRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteConversationModelRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a DeleteConversationModelRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.DeleteConversationModelRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        DeleteConversationModelRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a DeleteConversationModelRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.DeleteConversationModelRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.DeleteConversationModelRequest} DeleteConversationModelRequest
                         */
                        DeleteConversationModelRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.DeleteConversationModelRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.DeleteConversationModelRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a DeleteConversationModelRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.DeleteConversationModelRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.DeleteConversationModelRequest} message DeleteConversationModelRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        DeleteConversationModelRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.name = "";
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            return object;
                        };
    
                        /**
                         * Converts this DeleteConversationModelRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.DeleteConversationModelRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        DeleteConversationModelRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for DeleteConversationModelRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.DeleteConversationModelRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        DeleteConversationModelRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.DeleteConversationModelRequest";
                        };
    
                        return DeleteConversationModelRequest;
                    })();
    
                    v2.DeployConversationModelRequest = (function() {
    
                        /**
                         * Properties of a DeployConversationModelRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IDeployConversationModelRequest
                         * @property {string|null} [name] DeployConversationModelRequest name
                         */
    
                        /**
                         * Constructs a new DeployConversationModelRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a DeployConversationModelRequest.
                         * @implements IDeployConversationModelRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IDeployConversationModelRequest=} [properties] Properties to set
                         */
                        function DeployConversationModelRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * DeployConversationModelRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2.DeployConversationModelRequest
                         * @instance
                         */
                        DeployConversationModelRequest.prototype.name = "";
    
                        /**
                         * Creates a new DeployConversationModelRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.DeployConversationModelRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDeployConversationModelRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.DeployConversationModelRequest} DeployConversationModelRequest instance
                         */
                        DeployConversationModelRequest.create = function create(properties) {
                            return new DeployConversationModelRequest(properties);
                        };
    
                        /**
                         * Encodes the specified DeployConversationModelRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.DeployConversationModelRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.DeployConversationModelRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDeployConversationModelRequest} message DeployConversationModelRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeployConversationModelRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified DeployConversationModelRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.DeployConversationModelRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.DeployConversationModelRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDeployConversationModelRequest} message DeployConversationModelRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeployConversationModelRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a DeployConversationModelRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.DeployConversationModelRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.DeployConversationModelRequest} DeployConversationModelRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeployConversationModelRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.DeployConversationModelRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a DeployConversationModelRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.DeployConversationModelRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.DeployConversationModelRequest} DeployConversationModelRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeployConversationModelRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a DeployConversationModelRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.DeployConversationModelRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        DeployConversationModelRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a DeployConversationModelRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.DeployConversationModelRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.DeployConversationModelRequest} DeployConversationModelRequest
                         */
                        DeployConversationModelRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.DeployConversationModelRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.DeployConversationModelRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a DeployConversationModelRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.DeployConversationModelRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.DeployConversationModelRequest} message DeployConversationModelRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        DeployConversationModelRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.name = "";
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            return object;
                        };
    
                        /**
                         * Converts this DeployConversationModelRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.DeployConversationModelRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        DeployConversationModelRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for DeployConversationModelRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.DeployConversationModelRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        DeployConversationModelRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.DeployConversationModelRequest";
                        };
    
                        return DeployConversationModelRequest;
                    })();
    
                    v2.UndeployConversationModelRequest = (function() {
    
                        /**
                         * Properties of an UndeployConversationModelRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IUndeployConversationModelRequest
                         * @property {string|null} [name] UndeployConversationModelRequest name
                         */
    
                        /**
                         * Constructs a new UndeployConversationModelRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an UndeployConversationModelRequest.
                         * @implements IUndeployConversationModelRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IUndeployConversationModelRequest=} [properties] Properties to set
                         */
                        function UndeployConversationModelRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * UndeployConversationModelRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2.UndeployConversationModelRequest
                         * @instance
                         */
                        UndeployConversationModelRequest.prototype.name = "";
    
                        /**
                         * Creates a new UndeployConversationModelRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.UndeployConversationModelRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IUndeployConversationModelRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.UndeployConversationModelRequest} UndeployConversationModelRequest instance
                         */
                        UndeployConversationModelRequest.create = function create(properties) {
                            return new UndeployConversationModelRequest(properties);
                        };
    
                        /**
                         * Encodes the specified UndeployConversationModelRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.UndeployConversationModelRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.UndeployConversationModelRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IUndeployConversationModelRequest} message UndeployConversationModelRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UndeployConversationModelRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified UndeployConversationModelRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.UndeployConversationModelRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.UndeployConversationModelRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IUndeployConversationModelRequest} message UndeployConversationModelRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UndeployConversationModelRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an UndeployConversationModelRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.UndeployConversationModelRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.UndeployConversationModelRequest} UndeployConversationModelRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UndeployConversationModelRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.UndeployConversationModelRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an UndeployConversationModelRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.UndeployConversationModelRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.UndeployConversationModelRequest} UndeployConversationModelRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UndeployConversationModelRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an UndeployConversationModelRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.UndeployConversationModelRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        UndeployConversationModelRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            return null;
                        };
    
                        /**
                         * Creates an UndeployConversationModelRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.UndeployConversationModelRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.UndeployConversationModelRequest} UndeployConversationModelRequest
                         */
                        UndeployConversationModelRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.UndeployConversationModelRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.UndeployConversationModelRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an UndeployConversationModelRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.UndeployConversationModelRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.UndeployConversationModelRequest} message UndeployConversationModelRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        UndeployConversationModelRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.name = "";
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            return object;
                        };
    
                        /**
                         * Converts this UndeployConversationModelRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.UndeployConversationModelRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        UndeployConversationModelRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for UndeployConversationModelRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.UndeployConversationModelRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        UndeployConversationModelRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.UndeployConversationModelRequest";
                        };
    
                        return UndeployConversationModelRequest;
                    })();
    
                    v2.GetConversationModelEvaluationRequest = (function() {
    
                        /**
                         * Properties of a GetConversationModelEvaluationRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IGetConversationModelEvaluationRequest
                         * @property {string|null} [name] GetConversationModelEvaluationRequest name
                         */
    
                        /**
                         * Constructs a new GetConversationModelEvaluationRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a GetConversationModelEvaluationRequest.
                         * @implements IGetConversationModelEvaluationRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IGetConversationModelEvaluationRequest=} [properties] Properties to set
                         */
                        function GetConversationModelEvaluationRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GetConversationModelEvaluationRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2.GetConversationModelEvaluationRequest
                         * @instance
                         */
                        GetConversationModelEvaluationRequest.prototype.name = "";
    
                        /**
                         * Creates a new GetConversationModelEvaluationRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.GetConversationModelEvaluationRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetConversationModelEvaluationRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.GetConversationModelEvaluationRequest} GetConversationModelEvaluationRequest instance
                         */
                        GetConversationModelEvaluationRequest.create = function create(properties) {
                            return new GetConversationModelEvaluationRequest(properties);
                        };
    
                        /**
                         * Encodes the specified GetConversationModelEvaluationRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.GetConversationModelEvaluationRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.GetConversationModelEvaluationRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetConversationModelEvaluationRequest} message GetConversationModelEvaluationRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetConversationModelEvaluationRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GetConversationModelEvaluationRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.GetConversationModelEvaluationRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GetConversationModelEvaluationRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetConversationModelEvaluationRequest} message GetConversationModelEvaluationRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetConversationModelEvaluationRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GetConversationModelEvaluationRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.GetConversationModelEvaluationRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.GetConversationModelEvaluationRequest} GetConversationModelEvaluationRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetConversationModelEvaluationRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.GetConversationModelEvaluationRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GetConversationModelEvaluationRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GetConversationModelEvaluationRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.GetConversationModelEvaluationRequest} GetConversationModelEvaluationRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetConversationModelEvaluationRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GetConversationModelEvaluationRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.GetConversationModelEvaluationRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GetConversationModelEvaluationRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a GetConversationModelEvaluationRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.GetConversationModelEvaluationRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.GetConversationModelEvaluationRequest} GetConversationModelEvaluationRequest
                         */
                        GetConversationModelEvaluationRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.GetConversationModelEvaluationRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.GetConversationModelEvaluationRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GetConversationModelEvaluationRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.GetConversationModelEvaluationRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.GetConversationModelEvaluationRequest} message GetConversationModelEvaluationRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GetConversationModelEvaluationRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.name = "";
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            return object;
                        };
    
                        /**
                         * Converts this GetConversationModelEvaluationRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.GetConversationModelEvaluationRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GetConversationModelEvaluationRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GetConversationModelEvaluationRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.GetConversationModelEvaluationRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GetConversationModelEvaluationRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.GetConversationModelEvaluationRequest";
                        };
    
                        return GetConversationModelEvaluationRequest;
                    })();
    
                    v2.ListConversationModelEvaluationsRequest = (function() {
    
                        /**
                         * Properties of a ListConversationModelEvaluationsRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IListConversationModelEvaluationsRequest
                         * @property {string|null} [parent] ListConversationModelEvaluationsRequest parent
                         * @property {number|null} [pageSize] ListConversationModelEvaluationsRequest pageSize
                         * @property {string|null} [pageToken] ListConversationModelEvaluationsRequest pageToken
                         */
    
                        /**
                         * Constructs a new ListConversationModelEvaluationsRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a ListConversationModelEvaluationsRequest.
                         * @implements IListConversationModelEvaluationsRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IListConversationModelEvaluationsRequest=} [properties] Properties to set
                         */
                        function ListConversationModelEvaluationsRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListConversationModelEvaluationsRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.ListConversationModelEvaluationsRequest
                         * @instance
                         */
                        ListConversationModelEvaluationsRequest.prototype.parent = "";
    
                        /**
                         * ListConversationModelEvaluationsRequest pageSize.
                         * @member {number} pageSize
                         * @memberof google.cloud.dialogflow.v2.ListConversationModelEvaluationsRequest
                         * @instance
                         */
                        ListConversationModelEvaluationsRequest.prototype.pageSize = 0;
    
                        /**
                         * ListConversationModelEvaluationsRequest pageToken.
                         * @member {string} pageToken
                         * @memberof google.cloud.dialogflow.v2.ListConversationModelEvaluationsRequest
                         * @instance
                         */
                        ListConversationModelEvaluationsRequest.prototype.pageToken = "";
    
                        /**
                         * Creates a new ListConversationModelEvaluationsRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ListConversationModelEvaluationsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListConversationModelEvaluationsRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ListConversationModelEvaluationsRequest} ListConversationModelEvaluationsRequest instance
                         */
                        ListConversationModelEvaluationsRequest.create = function create(properties) {
                            return new ListConversationModelEvaluationsRequest(properties);
                        };
    
                        /**
                         * Encodes the specified ListConversationModelEvaluationsRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.ListConversationModelEvaluationsRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ListConversationModelEvaluationsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListConversationModelEvaluationsRequest} message ListConversationModelEvaluationsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListConversationModelEvaluationsRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.pageSize != null && Object.hasOwnProperty.call(message, "pageSize"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.pageSize);
                            if (message.pageToken != null && Object.hasOwnProperty.call(message, "pageToken"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.pageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListConversationModelEvaluationsRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ListConversationModelEvaluationsRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListConversationModelEvaluationsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListConversationModelEvaluationsRequest} message ListConversationModelEvaluationsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListConversationModelEvaluationsRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListConversationModelEvaluationsRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ListConversationModelEvaluationsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ListConversationModelEvaluationsRequest} ListConversationModelEvaluationsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListConversationModelEvaluationsRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ListConversationModelEvaluationsRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.pageSize = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.pageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListConversationModelEvaluationsRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListConversationModelEvaluationsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ListConversationModelEvaluationsRequest} ListConversationModelEvaluationsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListConversationModelEvaluationsRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListConversationModelEvaluationsRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ListConversationModelEvaluationsRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListConversationModelEvaluationsRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                if (!$util.isInteger(message.pageSize))
                                    return "pageSize: integer expected";
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                if (!$util.isString(message.pageToken))
                                    return "pageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListConversationModelEvaluationsRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ListConversationModelEvaluationsRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ListConversationModelEvaluationsRequest} ListConversationModelEvaluationsRequest
                         */
                        ListConversationModelEvaluationsRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ListConversationModelEvaluationsRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ListConversationModelEvaluationsRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.pageSize != null)
                                message.pageSize = object.pageSize | 0;
                            if (object.pageToken != null)
                                message.pageToken = String(object.pageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListConversationModelEvaluationsRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ListConversationModelEvaluationsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ListConversationModelEvaluationsRequest} message ListConversationModelEvaluationsRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListConversationModelEvaluationsRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.pageSize = 0;
                                object.pageToken = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                object.pageSize = message.pageSize;
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                object.pageToken = message.pageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListConversationModelEvaluationsRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ListConversationModelEvaluationsRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListConversationModelEvaluationsRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListConversationModelEvaluationsRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ListConversationModelEvaluationsRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListConversationModelEvaluationsRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ListConversationModelEvaluationsRequest";
                        };
    
                        return ListConversationModelEvaluationsRequest;
                    })();
    
                    v2.ListConversationModelEvaluationsResponse = (function() {
    
                        /**
                         * Properties of a ListConversationModelEvaluationsResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IListConversationModelEvaluationsResponse
                         * @property {Array.<google.cloud.dialogflow.v2.IConversationModelEvaluation>|null} [conversationModelEvaluations] ListConversationModelEvaluationsResponse conversationModelEvaluations
                         * @property {string|null} [nextPageToken] ListConversationModelEvaluationsResponse nextPageToken
                         */
    
                        /**
                         * Constructs a new ListConversationModelEvaluationsResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a ListConversationModelEvaluationsResponse.
                         * @implements IListConversationModelEvaluationsResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IListConversationModelEvaluationsResponse=} [properties] Properties to set
                         */
                        function ListConversationModelEvaluationsResponse(properties) {
                            this.conversationModelEvaluations = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListConversationModelEvaluationsResponse conversationModelEvaluations.
                         * @member {Array.<google.cloud.dialogflow.v2.IConversationModelEvaluation>} conversationModelEvaluations
                         * @memberof google.cloud.dialogflow.v2.ListConversationModelEvaluationsResponse
                         * @instance
                         */
                        ListConversationModelEvaluationsResponse.prototype.conversationModelEvaluations = $util.emptyArray;
    
                        /**
                         * ListConversationModelEvaluationsResponse nextPageToken.
                         * @member {string} nextPageToken
                         * @memberof google.cloud.dialogflow.v2.ListConversationModelEvaluationsResponse
                         * @instance
                         */
                        ListConversationModelEvaluationsResponse.prototype.nextPageToken = "";
    
                        /**
                         * Creates a new ListConversationModelEvaluationsResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ListConversationModelEvaluationsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListConversationModelEvaluationsResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ListConversationModelEvaluationsResponse} ListConversationModelEvaluationsResponse instance
                         */
                        ListConversationModelEvaluationsResponse.create = function create(properties) {
                            return new ListConversationModelEvaluationsResponse(properties);
                        };
    
                        /**
                         * Encodes the specified ListConversationModelEvaluationsResponse message. Does not implicitly {@link google.cloud.dialogflow.v2.ListConversationModelEvaluationsResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ListConversationModelEvaluationsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListConversationModelEvaluationsResponse} message ListConversationModelEvaluationsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListConversationModelEvaluationsResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.conversationModelEvaluations != null && message.conversationModelEvaluations.length)
                                for (var i = 0; i < message.conversationModelEvaluations.length; ++i)
                                    $root.google.cloud.dialogflow.v2.ConversationModelEvaluation.encode(message.conversationModelEvaluations[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.nextPageToken != null && Object.hasOwnProperty.call(message, "nextPageToken"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.nextPageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListConversationModelEvaluationsResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ListConversationModelEvaluationsResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListConversationModelEvaluationsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListConversationModelEvaluationsResponse} message ListConversationModelEvaluationsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListConversationModelEvaluationsResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListConversationModelEvaluationsResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ListConversationModelEvaluationsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ListConversationModelEvaluationsResponse} ListConversationModelEvaluationsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListConversationModelEvaluationsResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ListConversationModelEvaluationsResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.conversationModelEvaluations && message.conversationModelEvaluations.length))
                                            message.conversationModelEvaluations = [];
                                        message.conversationModelEvaluations.push($root.google.cloud.dialogflow.v2.ConversationModelEvaluation.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 2: {
                                        message.nextPageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListConversationModelEvaluationsResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListConversationModelEvaluationsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ListConversationModelEvaluationsResponse} ListConversationModelEvaluationsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListConversationModelEvaluationsResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListConversationModelEvaluationsResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ListConversationModelEvaluationsResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListConversationModelEvaluationsResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.conversationModelEvaluations != null && message.hasOwnProperty("conversationModelEvaluations")) {
                                if (!Array.isArray(message.conversationModelEvaluations))
                                    return "conversationModelEvaluations: array expected";
                                for (var i = 0; i < message.conversationModelEvaluations.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.ConversationModelEvaluation.verify(message.conversationModelEvaluations[i]);
                                    if (error)
                                        return "conversationModelEvaluations." + error;
                                }
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                if (!$util.isString(message.nextPageToken))
                                    return "nextPageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListConversationModelEvaluationsResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ListConversationModelEvaluationsResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ListConversationModelEvaluationsResponse} ListConversationModelEvaluationsResponse
                         */
                        ListConversationModelEvaluationsResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ListConversationModelEvaluationsResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ListConversationModelEvaluationsResponse();
                            if (object.conversationModelEvaluations) {
                                if (!Array.isArray(object.conversationModelEvaluations))
                                    throw TypeError(".google.cloud.dialogflow.v2.ListConversationModelEvaluationsResponse.conversationModelEvaluations: array expected");
                                message.conversationModelEvaluations = [];
                                for (var i = 0; i < object.conversationModelEvaluations.length; ++i) {
                                    if (typeof object.conversationModelEvaluations[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.ListConversationModelEvaluationsResponse.conversationModelEvaluations: object expected");
                                    message.conversationModelEvaluations[i] = $root.google.cloud.dialogflow.v2.ConversationModelEvaluation.fromObject(object.conversationModelEvaluations[i]);
                                }
                            }
                            if (object.nextPageToken != null)
                                message.nextPageToken = String(object.nextPageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListConversationModelEvaluationsResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ListConversationModelEvaluationsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.ListConversationModelEvaluationsResponse} message ListConversationModelEvaluationsResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListConversationModelEvaluationsResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.conversationModelEvaluations = [];
                            if (options.defaults)
                                object.nextPageToken = "";
                            if (message.conversationModelEvaluations && message.conversationModelEvaluations.length) {
                                object.conversationModelEvaluations = [];
                                for (var j = 0; j < message.conversationModelEvaluations.length; ++j)
                                    object.conversationModelEvaluations[j] = $root.google.cloud.dialogflow.v2.ConversationModelEvaluation.toObject(message.conversationModelEvaluations[j], options);
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                object.nextPageToken = message.nextPageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListConversationModelEvaluationsResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ListConversationModelEvaluationsResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListConversationModelEvaluationsResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListConversationModelEvaluationsResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ListConversationModelEvaluationsResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListConversationModelEvaluationsResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ListConversationModelEvaluationsResponse";
                        };
    
                        return ListConversationModelEvaluationsResponse;
                    })();
    
                    v2.CreateConversationModelEvaluationRequest = (function() {
    
                        /**
                         * Properties of a CreateConversationModelEvaluationRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ICreateConversationModelEvaluationRequest
                         * @property {string|null} [parent] CreateConversationModelEvaluationRequest parent
                         * @property {google.cloud.dialogflow.v2.IConversationModelEvaluation|null} [conversationModelEvaluation] CreateConversationModelEvaluationRequest conversationModelEvaluation
                         */
    
                        /**
                         * Constructs a new CreateConversationModelEvaluationRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a CreateConversationModelEvaluationRequest.
                         * @implements ICreateConversationModelEvaluationRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ICreateConversationModelEvaluationRequest=} [properties] Properties to set
                         */
                        function CreateConversationModelEvaluationRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * CreateConversationModelEvaluationRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.CreateConversationModelEvaluationRequest
                         * @instance
                         */
                        CreateConversationModelEvaluationRequest.prototype.parent = "";
    
                        /**
                         * CreateConversationModelEvaluationRequest conversationModelEvaluation.
                         * @member {google.cloud.dialogflow.v2.IConversationModelEvaluation|null|undefined} conversationModelEvaluation
                         * @memberof google.cloud.dialogflow.v2.CreateConversationModelEvaluationRequest
                         * @instance
                         */
                        CreateConversationModelEvaluationRequest.prototype.conversationModelEvaluation = null;
    
                        /**
                         * Creates a new CreateConversationModelEvaluationRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.CreateConversationModelEvaluationRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICreateConversationModelEvaluationRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.CreateConversationModelEvaluationRequest} CreateConversationModelEvaluationRequest instance
                         */
                        CreateConversationModelEvaluationRequest.create = function create(properties) {
                            return new CreateConversationModelEvaluationRequest(properties);
                        };
    
                        /**
                         * Encodes the specified CreateConversationModelEvaluationRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.CreateConversationModelEvaluationRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.CreateConversationModelEvaluationRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICreateConversationModelEvaluationRequest} message CreateConversationModelEvaluationRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateConversationModelEvaluationRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.conversationModelEvaluation != null && Object.hasOwnProperty.call(message, "conversationModelEvaluation"))
                                $root.google.cloud.dialogflow.v2.ConversationModelEvaluation.encode(message.conversationModelEvaluation, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified CreateConversationModelEvaluationRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.CreateConversationModelEvaluationRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.CreateConversationModelEvaluationRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICreateConversationModelEvaluationRequest} message CreateConversationModelEvaluationRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateConversationModelEvaluationRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a CreateConversationModelEvaluationRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.CreateConversationModelEvaluationRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.CreateConversationModelEvaluationRequest} CreateConversationModelEvaluationRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateConversationModelEvaluationRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.CreateConversationModelEvaluationRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.conversationModelEvaluation = $root.google.cloud.dialogflow.v2.ConversationModelEvaluation.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a CreateConversationModelEvaluationRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.CreateConversationModelEvaluationRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.CreateConversationModelEvaluationRequest} CreateConversationModelEvaluationRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateConversationModelEvaluationRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a CreateConversationModelEvaluationRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.CreateConversationModelEvaluationRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        CreateConversationModelEvaluationRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.conversationModelEvaluation != null && message.hasOwnProperty("conversationModelEvaluation")) {
                                var error = $root.google.cloud.dialogflow.v2.ConversationModelEvaluation.verify(message.conversationModelEvaluation);
                                if (error)
                                    return "conversationModelEvaluation." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a CreateConversationModelEvaluationRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.CreateConversationModelEvaluationRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.CreateConversationModelEvaluationRequest} CreateConversationModelEvaluationRequest
                         */
                        CreateConversationModelEvaluationRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.CreateConversationModelEvaluationRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.CreateConversationModelEvaluationRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.conversationModelEvaluation != null) {
                                if (typeof object.conversationModelEvaluation !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.CreateConversationModelEvaluationRequest.conversationModelEvaluation: object expected");
                                message.conversationModelEvaluation = $root.google.cloud.dialogflow.v2.ConversationModelEvaluation.fromObject(object.conversationModelEvaluation);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a CreateConversationModelEvaluationRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.CreateConversationModelEvaluationRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.CreateConversationModelEvaluationRequest} message CreateConversationModelEvaluationRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        CreateConversationModelEvaluationRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.conversationModelEvaluation = null;
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.conversationModelEvaluation != null && message.hasOwnProperty("conversationModelEvaluation"))
                                object.conversationModelEvaluation = $root.google.cloud.dialogflow.v2.ConversationModelEvaluation.toObject(message.conversationModelEvaluation, options);
                            return object;
                        };
    
                        /**
                         * Converts this CreateConversationModelEvaluationRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.CreateConversationModelEvaluationRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        CreateConversationModelEvaluationRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for CreateConversationModelEvaluationRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.CreateConversationModelEvaluationRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        CreateConversationModelEvaluationRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.CreateConversationModelEvaluationRequest";
                        };
    
                        return CreateConversationModelEvaluationRequest;
                    })();
    
                    v2.CreateConversationModelOperationMetadata = (function() {
    
                        /**
                         * Properties of a CreateConversationModelOperationMetadata.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ICreateConversationModelOperationMetadata
                         * @property {string|null} [conversationModel] CreateConversationModelOperationMetadata conversationModel
                         * @property {google.cloud.dialogflow.v2.CreateConversationModelOperationMetadata.State|null} [state] CreateConversationModelOperationMetadata state
                         * @property {google.protobuf.ITimestamp|null} [createTime] CreateConversationModelOperationMetadata createTime
                         */
    
                        /**
                         * Constructs a new CreateConversationModelOperationMetadata.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a CreateConversationModelOperationMetadata.
                         * @implements ICreateConversationModelOperationMetadata
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ICreateConversationModelOperationMetadata=} [properties] Properties to set
                         */
                        function CreateConversationModelOperationMetadata(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * CreateConversationModelOperationMetadata conversationModel.
                         * @member {string} conversationModel
                         * @memberof google.cloud.dialogflow.v2.CreateConversationModelOperationMetadata
                         * @instance
                         */
                        CreateConversationModelOperationMetadata.prototype.conversationModel = "";
    
                        /**
                         * CreateConversationModelOperationMetadata state.
                         * @member {google.cloud.dialogflow.v2.CreateConversationModelOperationMetadata.State} state
                         * @memberof google.cloud.dialogflow.v2.CreateConversationModelOperationMetadata
                         * @instance
                         */
                        CreateConversationModelOperationMetadata.prototype.state = 0;
    
                        /**
                         * CreateConversationModelOperationMetadata createTime.
                         * @member {google.protobuf.ITimestamp|null|undefined} createTime
                         * @memberof google.cloud.dialogflow.v2.CreateConversationModelOperationMetadata
                         * @instance
                         */
                        CreateConversationModelOperationMetadata.prototype.createTime = null;
    
                        /**
                         * Creates a new CreateConversationModelOperationMetadata instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.CreateConversationModelOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICreateConversationModelOperationMetadata=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.CreateConversationModelOperationMetadata} CreateConversationModelOperationMetadata instance
                         */
                        CreateConversationModelOperationMetadata.create = function create(properties) {
                            return new CreateConversationModelOperationMetadata(properties);
                        };
    
                        /**
                         * Encodes the specified CreateConversationModelOperationMetadata message. Does not implicitly {@link google.cloud.dialogflow.v2.CreateConversationModelOperationMetadata.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.CreateConversationModelOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICreateConversationModelOperationMetadata} message CreateConversationModelOperationMetadata message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateConversationModelOperationMetadata.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.conversationModel != null && Object.hasOwnProperty.call(message, "conversationModel"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.conversationModel);
                            if (message.state != null && Object.hasOwnProperty.call(message, "state"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.state);
                            if (message.createTime != null && Object.hasOwnProperty.call(message, "createTime"))
                                $root.google.protobuf.Timestamp.encode(message.createTime, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified CreateConversationModelOperationMetadata message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.CreateConversationModelOperationMetadata.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.CreateConversationModelOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICreateConversationModelOperationMetadata} message CreateConversationModelOperationMetadata message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateConversationModelOperationMetadata.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a CreateConversationModelOperationMetadata message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.CreateConversationModelOperationMetadata
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.CreateConversationModelOperationMetadata} CreateConversationModelOperationMetadata
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateConversationModelOperationMetadata.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.CreateConversationModelOperationMetadata();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.conversationModel = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.state = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.createTime = $root.google.protobuf.Timestamp.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a CreateConversationModelOperationMetadata message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.CreateConversationModelOperationMetadata
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.CreateConversationModelOperationMetadata} CreateConversationModelOperationMetadata
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateConversationModelOperationMetadata.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a CreateConversationModelOperationMetadata message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.CreateConversationModelOperationMetadata
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        CreateConversationModelOperationMetadata.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.conversationModel != null && message.hasOwnProperty("conversationModel"))
                                if (!$util.isString(message.conversationModel))
                                    return "conversationModel: string expected";
                            if (message.state != null && message.hasOwnProperty("state"))
                                switch (message.state) {
                                default:
                                    return "state: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                case 4:
                                case 5:
                                case 6:
                                    break;
                                }
                            if (message.createTime != null && message.hasOwnProperty("createTime")) {
                                var error = $root.google.protobuf.Timestamp.verify(message.createTime);
                                if (error)
                                    return "createTime." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a CreateConversationModelOperationMetadata message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.CreateConversationModelOperationMetadata
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.CreateConversationModelOperationMetadata} CreateConversationModelOperationMetadata
                         */
                        CreateConversationModelOperationMetadata.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.CreateConversationModelOperationMetadata)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.CreateConversationModelOperationMetadata();
                            if (object.conversationModel != null)
                                message.conversationModel = String(object.conversationModel);
                            switch (object.state) {
                            default:
                                if (typeof object.state === "number") {
                                    message.state = object.state;
                                    break;
                                }
                                break;
                            case "STATE_UNSPECIFIED":
                            case 0:
                                message.state = 0;
                                break;
                            case "PENDING":
                            case 1:
                                message.state = 1;
                                break;
                            case "SUCCEEDED":
                            case 2:
                                message.state = 2;
                                break;
                            case "FAILED":
                            case 3:
                                message.state = 3;
                                break;
                            case "CANCELLED":
                            case 4:
                                message.state = 4;
                                break;
                            case "CANCELLING":
                            case 5:
                                message.state = 5;
                                break;
                            case "TRAINING":
                            case 6:
                                message.state = 6;
                                break;
                            }
                            if (object.createTime != null) {
                                if (typeof object.createTime !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.CreateConversationModelOperationMetadata.createTime: object expected");
                                message.createTime = $root.google.protobuf.Timestamp.fromObject(object.createTime);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a CreateConversationModelOperationMetadata message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.CreateConversationModelOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.CreateConversationModelOperationMetadata} message CreateConversationModelOperationMetadata
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        CreateConversationModelOperationMetadata.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.conversationModel = "";
                                object.state = options.enums === String ? "STATE_UNSPECIFIED" : 0;
                                object.createTime = null;
                            }
                            if (message.conversationModel != null && message.hasOwnProperty("conversationModel"))
                                object.conversationModel = message.conversationModel;
                            if (message.state != null && message.hasOwnProperty("state"))
                                object.state = options.enums === String ? $root.google.cloud.dialogflow.v2.CreateConversationModelOperationMetadata.State[message.state] === undefined ? message.state : $root.google.cloud.dialogflow.v2.CreateConversationModelOperationMetadata.State[message.state] : message.state;
                            if (message.createTime != null && message.hasOwnProperty("createTime"))
                                object.createTime = $root.google.protobuf.Timestamp.toObject(message.createTime, options);
                            return object;
                        };
    
                        /**
                         * Converts this CreateConversationModelOperationMetadata to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.CreateConversationModelOperationMetadata
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        CreateConversationModelOperationMetadata.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for CreateConversationModelOperationMetadata
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.CreateConversationModelOperationMetadata
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        CreateConversationModelOperationMetadata.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.CreateConversationModelOperationMetadata";
                        };
    
                        /**
                         * State enum.
                         * @name google.cloud.dialogflow.v2.CreateConversationModelOperationMetadata.State
                         * @enum {number}
                         * @property {number} STATE_UNSPECIFIED=0 STATE_UNSPECIFIED value
                         * @property {number} PENDING=1 PENDING value
                         * @property {number} SUCCEEDED=2 SUCCEEDED value
                         * @property {number} FAILED=3 FAILED value
                         * @property {number} CANCELLED=4 CANCELLED value
                         * @property {number} CANCELLING=5 CANCELLING value
                         * @property {number} TRAINING=6 TRAINING value
                         */
                        CreateConversationModelOperationMetadata.State = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "STATE_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "PENDING"] = 1;
                            values[valuesById[2] = "SUCCEEDED"] = 2;
                            values[valuesById[3] = "FAILED"] = 3;
                            values[valuesById[4] = "CANCELLED"] = 4;
                            values[valuesById[5] = "CANCELLING"] = 5;
                            values[valuesById[6] = "TRAINING"] = 6;
                            return values;
                        })();
    
                        return CreateConversationModelOperationMetadata;
                    })();
    
                    v2.DeployConversationModelOperationMetadata = (function() {
    
                        /**
                         * Properties of a DeployConversationModelOperationMetadata.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IDeployConversationModelOperationMetadata
                         * @property {string|null} [conversationModel] DeployConversationModelOperationMetadata conversationModel
                         * @property {google.protobuf.ITimestamp|null} [createTime] DeployConversationModelOperationMetadata createTime
                         */
    
                        /**
                         * Constructs a new DeployConversationModelOperationMetadata.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a DeployConversationModelOperationMetadata.
                         * @implements IDeployConversationModelOperationMetadata
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IDeployConversationModelOperationMetadata=} [properties] Properties to set
                         */
                        function DeployConversationModelOperationMetadata(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * DeployConversationModelOperationMetadata conversationModel.
                         * @member {string} conversationModel
                         * @memberof google.cloud.dialogflow.v2.DeployConversationModelOperationMetadata
                         * @instance
                         */
                        DeployConversationModelOperationMetadata.prototype.conversationModel = "";
    
                        /**
                         * DeployConversationModelOperationMetadata createTime.
                         * @member {google.protobuf.ITimestamp|null|undefined} createTime
                         * @memberof google.cloud.dialogflow.v2.DeployConversationModelOperationMetadata
                         * @instance
                         */
                        DeployConversationModelOperationMetadata.prototype.createTime = null;
    
                        /**
                         * Creates a new DeployConversationModelOperationMetadata instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.DeployConversationModelOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDeployConversationModelOperationMetadata=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.DeployConversationModelOperationMetadata} DeployConversationModelOperationMetadata instance
                         */
                        DeployConversationModelOperationMetadata.create = function create(properties) {
                            return new DeployConversationModelOperationMetadata(properties);
                        };
    
                        /**
                         * Encodes the specified DeployConversationModelOperationMetadata message. Does not implicitly {@link google.cloud.dialogflow.v2.DeployConversationModelOperationMetadata.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.DeployConversationModelOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDeployConversationModelOperationMetadata} message DeployConversationModelOperationMetadata message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeployConversationModelOperationMetadata.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.conversationModel != null && Object.hasOwnProperty.call(message, "conversationModel"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.conversationModel);
                            if (message.createTime != null && Object.hasOwnProperty.call(message, "createTime"))
                                $root.google.protobuf.Timestamp.encode(message.createTime, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified DeployConversationModelOperationMetadata message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.DeployConversationModelOperationMetadata.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.DeployConversationModelOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDeployConversationModelOperationMetadata} message DeployConversationModelOperationMetadata message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeployConversationModelOperationMetadata.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a DeployConversationModelOperationMetadata message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.DeployConversationModelOperationMetadata
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.DeployConversationModelOperationMetadata} DeployConversationModelOperationMetadata
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeployConversationModelOperationMetadata.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.DeployConversationModelOperationMetadata();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.conversationModel = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.createTime = $root.google.protobuf.Timestamp.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a DeployConversationModelOperationMetadata message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.DeployConversationModelOperationMetadata
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.DeployConversationModelOperationMetadata} DeployConversationModelOperationMetadata
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeployConversationModelOperationMetadata.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a DeployConversationModelOperationMetadata message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.DeployConversationModelOperationMetadata
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        DeployConversationModelOperationMetadata.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.conversationModel != null && message.hasOwnProperty("conversationModel"))
                                if (!$util.isString(message.conversationModel))
                                    return "conversationModel: string expected";
                            if (message.createTime != null && message.hasOwnProperty("createTime")) {
                                var error = $root.google.protobuf.Timestamp.verify(message.createTime);
                                if (error)
                                    return "createTime." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a DeployConversationModelOperationMetadata message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.DeployConversationModelOperationMetadata
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.DeployConversationModelOperationMetadata} DeployConversationModelOperationMetadata
                         */
                        DeployConversationModelOperationMetadata.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.DeployConversationModelOperationMetadata)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.DeployConversationModelOperationMetadata();
                            if (object.conversationModel != null)
                                message.conversationModel = String(object.conversationModel);
                            if (object.createTime != null) {
                                if (typeof object.createTime !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.DeployConversationModelOperationMetadata.createTime: object expected");
                                message.createTime = $root.google.protobuf.Timestamp.fromObject(object.createTime);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a DeployConversationModelOperationMetadata message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.DeployConversationModelOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.DeployConversationModelOperationMetadata} message DeployConversationModelOperationMetadata
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        DeployConversationModelOperationMetadata.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.conversationModel = "";
                                object.createTime = null;
                            }
                            if (message.conversationModel != null && message.hasOwnProperty("conversationModel"))
                                object.conversationModel = message.conversationModel;
                            if (message.createTime != null && message.hasOwnProperty("createTime"))
                                object.createTime = $root.google.protobuf.Timestamp.toObject(message.createTime, options);
                            return object;
                        };
    
                        /**
                         * Converts this DeployConversationModelOperationMetadata to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.DeployConversationModelOperationMetadata
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        DeployConversationModelOperationMetadata.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for DeployConversationModelOperationMetadata
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.DeployConversationModelOperationMetadata
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        DeployConversationModelOperationMetadata.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.DeployConversationModelOperationMetadata";
                        };
    
                        return DeployConversationModelOperationMetadata;
                    })();
    
                    v2.UndeployConversationModelOperationMetadata = (function() {
    
                        /**
                         * Properties of an UndeployConversationModelOperationMetadata.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IUndeployConversationModelOperationMetadata
                         * @property {string|null} [conversationModel] UndeployConversationModelOperationMetadata conversationModel
                         * @property {google.protobuf.ITimestamp|null} [createTime] UndeployConversationModelOperationMetadata createTime
                         */
    
                        /**
                         * Constructs a new UndeployConversationModelOperationMetadata.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an UndeployConversationModelOperationMetadata.
                         * @implements IUndeployConversationModelOperationMetadata
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IUndeployConversationModelOperationMetadata=} [properties] Properties to set
                         */
                        function UndeployConversationModelOperationMetadata(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * UndeployConversationModelOperationMetadata conversationModel.
                         * @member {string} conversationModel
                         * @memberof google.cloud.dialogflow.v2.UndeployConversationModelOperationMetadata
                         * @instance
                         */
                        UndeployConversationModelOperationMetadata.prototype.conversationModel = "";
    
                        /**
                         * UndeployConversationModelOperationMetadata createTime.
                         * @member {google.protobuf.ITimestamp|null|undefined} createTime
                         * @memberof google.cloud.dialogflow.v2.UndeployConversationModelOperationMetadata
                         * @instance
                         */
                        UndeployConversationModelOperationMetadata.prototype.createTime = null;
    
                        /**
                         * Creates a new UndeployConversationModelOperationMetadata instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.UndeployConversationModelOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.IUndeployConversationModelOperationMetadata=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.UndeployConversationModelOperationMetadata} UndeployConversationModelOperationMetadata instance
                         */
                        UndeployConversationModelOperationMetadata.create = function create(properties) {
                            return new UndeployConversationModelOperationMetadata(properties);
                        };
    
                        /**
                         * Encodes the specified UndeployConversationModelOperationMetadata message. Does not implicitly {@link google.cloud.dialogflow.v2.UndeployConversationModelOperationMetadata.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.UndeployConversationModelOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.IUndeployConversationModelOperationMetadata} message UndeployConversationModelOperationMetadata message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UndeployConversationModelOperationMetadata.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.conversationModel != null && Object.hasOwnProperty.call(message, "conversationModel"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.conversationModel);
                            if (message.createTime != null && Object.hasOwnProperty.call(message, "createTime"))
                                $root.google.protobuf.Timestamp.encode(message.createTime, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified UndeployConversationModelOperationMetadata message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.UndeployConversationModelOperationMetadata.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.UndeployConversationModelOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.IUndeployConversationModelOperationMetadata} message UndeployConversationModelOperationMetadata message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UndeployConversationModelOperationMetadata.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an UndeployConversationModelOperationMetadata message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.UndeployConversationModelOperationMetadata
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.UndeployConversationModelOperationMetadata} UndeployConversationModelOperationMetadata
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UndeployConversationModelOperationMetadata.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.UndeployConversationModelOperationMetadata();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.conversationModel = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.createTime = $root.google.protobuf.Timestamp.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an UndeployConversationModelOperationMetadata message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.UndeployConversationModelOperationMetadata
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.UndeployConversationModelOperationMetadata} UndeployConversationModelOperationMetadata
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UndeployConversationModelOperationMetadata.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an UndeployConversationModelOperationMetadata message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.UndeployConversationModelOperationMetadata
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        UndeployConversationModelOperationMetadata.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.conversationModel != null && message.hasOwnProperty("conversationModel"))
                                if (!$util.isString(message.conversationModel))
                                    return "conversationModel: string expected";
                            if (message.createTime != null && message.hasOwnProperty("createTime")) {
                                var error = $root.google.protobuf.Timestamp.verify(message.createTime);
                                if (error)
                                    return "createTime." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates an UndeployConversationModelOperationMetadata message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.UndeployConversationModelOperationMetadata
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.UndeployConversationModelOperationMetadata} UndeployConversationModelOperationMetadata
                         */
                        UndeployConversationModelOperationMetadata.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.UndeployConversationModelOperationMetadata)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.UndeployConversationModelOperationMetadata();
                            if (object.conversationModel != null)
                                message.conversationModel = String(object.conversationModel);
                            if (object.createTime != null) {
                                if (typeof object.createTime !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.UndeployConversationModelOperationMetadata.createTime: object expected");
                                message.createTime = $root.google.protobuf.Timestamp.fromObject(object.createTime);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an UndeployConversationModelOperationMetadata message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.UndeployConversationModelOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.UndeployConversationModelOperationMetadata} message UndeployConversationModelOperationMetadata
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        UndeployConversationModelOperationMetadata.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.conversationModel = "";
                                object.createTime = null;
                            }
                            if (message.conversationModel != null && message.hasOwnProperty("conversationModel"))
                                object.conversationModel = message.conversationModel;
                            if (message.createTime != null && message.hasOwnProperty("createTime"))
                                object.createTime = $root.google.protobuf.Timestamp.toObject(message.createTime, options);
                            return object;
                        };
    
                        /**
                         * Converts this UndeployConversationModelOperationMetadata to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.UndeployConversationModelOperationMetadata
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        UndeployConversationModelOperationMetadata.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for UndeployConversationModelOperationMetadata
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.UndeployConversationModelOperationMetadata
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        UndeployConversationModelOperationMetadata.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.UndeployConversationModelOperationMetadata";
                        };
    
                        return UndeployConversationModelOperationMetadata;
                    })();
    
                    v2.DeleteConversationModelOperationMetadata = (function() {
    
                        /**
                         * Properties of a DeleteConversationModelOperationMetadata.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IDeleteConversationModelOperationMetadata
                         * @property {string|null} [conversationModel] DeleteConversationModelOperationMetadata conversationModel
                         * @property {google.protobuf.ITimestamp|null} [createTime] DeleteConversationModelOperationMetadata createTime
                         */
    
                        /**
                         * Constructs a new DeleteConversationModelOperationMetadata.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a DeleteConversationModelOperationMetadata.
                         * @implements IDeleteConversationModelOperationMetadata
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IDeleteConversationModelOperationMetadata=} [properties] Properties to set
                         */
                        function DeleteConversationModelOperationMetadata(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * DeleteConversationModelOperationMetadata conversationModel.
                         * @member {string} conversationModel
                         * @memberof google.cloud.dialogflow.v2.DeleteConversationModelOperationMetadata
                         * @instance
                         */
                        DeleteConversationModelOperationMetadata.prototype.conversationModel = "";
    
                        /**
                         * DeleteConversationModelOperationMetadata createTime.
                         * @member {google.protobuf.ITimestamp|null|undefined} createTime
                         * @memberof google.cloud.dialogflow.v2.DeleteConversationModelOperationMetadata
                         * @instance
                         */
                        DeleteConversationModelOperationMetadata.prototype.createTime = null;
    
                        /**
                         * Creates a new DeleteConversationModelOperationMetadata instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.DeleteConversationModelOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDeleteConversationModelOperationMetadata=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.DeleteConversationModelOperationMetadata} DeleteConversationModelOperationMetadata instance
                         */
                        DeleteConversationModelOperationMetadata.create = function create(properties) {
                            return new DeleteConversationModelOperationMetadata(properties);
                        };
    
                        /**
                         * Encodes the specified DeleteConversationModelOperationMetadata message. Does not implicitly {@link google.cloud.dialogflow.v2.DeleteConversationModelOperationMetadata.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.DeleteConversationModelOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDeleteConversationModelOperationMetadata} message DeleteConversationModelOperationMetadata message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteConversationModelOperationMetadata.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.conversationModel != null && Object.hasOwnProperty.call(message, "conversationModel"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.conversationModel);
                            if (message.createTime != null && Object.hasOwnProperty.call(message, "createTime"))
                                $root.google.protobuf.Timestamp.encode(message.createTime, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified DeleteConversationModelOperationMetadata message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.DeleteConversationModelOperationMetadata.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.DeleteConversationModelOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDeleteConversationModelOperationMetadata} message DeleteConversationModelOperationMetadata message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteConversationModelOperationMetadata.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a DeleteConversationModelOperationMetadata message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.DeleteConversationModelOperationMetadata
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.DeleteConversationModelOperationMetadata} DeleteConversationModelOperationMetadata
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteConversationModelOperationMetadata.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.DeleteConversationModelOperationMetadata();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.conversationModel = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.createTime = $root.google.protobuf.Timestamp.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a DeleteConversationModelOperationMetadata message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.DeleteConversationModelOperationMetadata
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.DeleteConversationModelOperationMetadata} DeleteConversationModelOperationMetadata
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteConversationModelOperationMetadata.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a DeleteConversationModelOperationMetadata message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.DeleteConversationModelOperationMetadata
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        DeleteConversationModelOperationMetadata.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.conversationModel != null && message.hasOwnProperty("conversationModel"))
                                if (!$util.isString(message.conversationModel))
                                    return "conversationModel: string expected";
                            if (message.createTime != null && message.hasOwnProperty("createTime")) {
                                var error = $root.google.protobuf.Timestamp.verify(message.createTime);
                                if (error)
                                    return "createTime." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a DeleteConversationModelOperationMetadata message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.DeleteConversationModelOperationMetadata
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.DeleteConversationModelOperationMetadata} DeleteConversationModelOperationMetadata
                         */
                        DeleteConversationModelOperationMetadata.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.DeleteConversationModelOperationMetadata)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.DeleteConversationModelOperationMetadata();
                            if (object.conversationModel != null)
                                message.conversationModel = String(object.conversationModel);
                            if (object.createTime != null) {
                                if (typeof object.createTime !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.DeleteConversationModelOperationMetadata.createTime: object expected");
                                message.createTime = $root.google.protobuf.Timestamp.fromObject(object.createTime);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a DeleteConversationModelOperationMetadata message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.DeleteConversationModelOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.DeleteConversationModelOperationMetadata} message DeleteConversationModelOperationMetadata
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        DeleteConversationModelOperationMetadata.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.conversationModel = "";
                                object.createTime = null;
                            }
                            if (message.conversationModel != null && message.hasOwnProperty("conversationModel"))
                                object.conversationModel = message.conversationModel;
                            if (message.createTime != null && message.hasOwnProperty("createTime"))
                                object.createTime = $root.google.protobuf.Timestamp.toObject(message.createTime, options);
                            return object;
                        };
    
                        /**
                         * Converts this DeleteConversationModelOperationMetadata to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.DeleteConversationModelOperationMetadata
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        DeleteConversationModelOperationMetadata.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for DeleteConversationModelOperationMetadata
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.DeleteConversationModelOperationMetadata
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        DeleteConversationModelOperationMetadata.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.DeleteConversationModelOperationMetadata";
                        };
    
                        return DeleteConversationModelOperationMetadata;
                    })();
    
                    v2.CreateConversationModelEvaluationOperationMetadata = (function() {
    
                        /**
                         * Properties of a CreateConversationModelEvaluationOperationMetadata.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ICreateConversationModelEvaluationOperationMetadata
                         * @property {string|null} [conversationModelEvaluation] CreateConversationModelEvaluationOperationMetadata conversationModelEvaluation
                         * @property {string|null} [conversationModel] CreateConversationModelEvaluationOperationMetadata conversationModel
                         * @property {google.cloud.dialogflow.v2.CreateConversationModelEvaluationOperationMetadata.State|null} [state] CreateConversationModelEvaluationOperationMetadata state
                         * @property {google.protobuf.ITimestamp|null} [createTime] CreateConversationModelEvaluationOperationMetadata createTime
                         */
    
                        /**
                         * Constructs a new CreateConversationModelEvaluationOperationMetadata.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a CreateConversationModelEvaluationOperationMetadata.
                         * @implements ICreateConversationModelEvaluationOperationMetadata
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ICreateConversationModelEvaluationOperationMetadata=} [properties] Properties to set
                         */
                        function CreateConversationModelEvaluationOperationMetadata(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * CreateConversationModelEvaluationOperationMetadata conversationModelEvaluation.
                         * @member {string} conversationModelEvaluation
                         * @memberof google.cloud.dialogflow.v2.CreateConversationModelEvaluationOperationMetadata
                         * @instance
                         */
                        CreateConversationModelEvaluationOperationMetadata.prototype.conversationModelEvaluation = "";
    
                        /**
                         * CreateConversationModelEvaluationOperationMetadata conversationModel.
                         * @member {string} conversationModel
                         * @memberof google.cloud.dialogflow.v2.CreateConversationModelEvaluationOperationMetadata
                         * @instance
                         */
                        CreateConversationModelEvaluationOperationMetadata.prototype.conversationModel = "";
    
                        /**
                         * CreateConversationModelEvaluationOperationMetadata state.
                         * @member {google.cloud.dialogflow.v2.CreateConversationModelEvaluationOperationMetadata.State} state
                         * @memberof google.cloud.dialogflow.v2.CreateConversationModelEvaluationOperationMetadata
                         * @instance
                         */
                        CreateConversationModelEvaluationOperationMetadata.prototype.state = 0;
    
                        /**
                         * CreateConversationModelEvaluationOperationMetadata createTime.
                         * @member {google.protobuf.ITimestamp|null|undefined} createTime
                         * @memberof google.cloud.dialogflow.v2.CreateConversationModelEvaluationOperationMetadata
                         * @instance
                         */
                        CreateConversationModelEvaluationOperationMetadata.prototype.createTime = null;
    
                        /**
                         * Creates a new CreateConversationModelEvaluationOperationMetadata instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.CreateConversationModelEvaluationOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICreateConversationModelEvaluationOperationMetadata=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.CreateConversationModelEvaluationOperationMetadata} CreateConversationModelEvaluationOperationMetadata instance
                         */
                        CreateConversationModelEvaluationOperationMetadata.create = function create(properties) {
                            return new CreateConversationModelEvaluationOperationMetadata(properties);
                        };
    
                        /**
                         * Encodes the specified CreateConversationModelEvaluationOperationMetadata message. Does not implicitly {@link google.cloud.dialogflow.v2.CreateConversationModelEvaluationOperationMetadata.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.CreateConversationModelEvaluationOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICreateConversationModelEvaluationOperationMetadata} message CreateConversationModelEvaluationOperationMetadata message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateConversationModelEvaluationOperationMetadata.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.conversationModelEvaluation != null && Object.hasOwnProperty.call(message, "conversationModelEvaluation"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.conversationModelEvaluation);
                            if (message.state != null && Object.hasOwnProperty.call(message, "state"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.state);
                            if (message.createTime != null && Object.hasOwnProperty.call(message, "createTime"))
                                $root.google.protobuf.Timestamp.encode(message.createTime, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            if (message.conversationModel != null && Object.hasOwnProperty.call(message, "conversationModel"))
                                writer.uint32(/* id 4, wireType 2 =*/34).string(message.conversationModel);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified CreateConversationModelEvaluationOperationMetadata message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.CreateConversationModelEvaluationOperationMetadata.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.CreateConversationModelEvaluationOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICreateConversationModelEvaluationOperationMetadata} message CreateConversationModelEvaluationOperationMetadata message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateConversationModelEvaluationOperationMetadata.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a CreateConversationModelEvaluationOperationMetadata message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.CreateConversationModelEvaluationOperationMetadata
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.CreateConversationModelEvaluationOperationMetadata} CreateConversationModelEvaluationOperationMetadata
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateConversationModelEvaluationOperationMetadata.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.CreateConversationModelEvaluationOperationMetadata();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.conversationModelEvaluation = reader.string();
                                        break;
                                    }
                                case 4: {
                                        message.conversationModel = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.state = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.createTime = $root.google.protobuf.Timestamp.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a CreateConversationModelEvaluationOperationMetadata message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.CreateConversationModelEvaluationOperationMetadata
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.CreateConversationModelEvaluationOperationMetadata} CreateConversationModelEvaluationOperationMetadata
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateConversationModelEvaluationOperationMetadata.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a CreateConversationModelEvaluationOperationMetadata message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.CreateConversationModelEvaluationOperationMetadata
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        CreateConversationModelEvaluationOperationMetadata.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.conversationModelEvaluation != null && message.hasOwnProperty("conversationModelEvaluation"))
                                if (!$util.isString(message.conversationModelEvaluation))
                                    return "conversationModelEvaluation: string expected";
                            if (message.conversationModel != null && message.hasOwnProperty("conversationModel"))
                                if (!$util.isString(message.conversationModel))
                                    return "conversationModel: string expected";
                            if (message.state != null && message.hasOwnProperty("state"))
                                switch (message.state) {
                                default:
                                    return "state: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                case 4:
                                case 5:
                                    break;
                                }
                            if (message.createTime != null && message.hasOwnProperty("createTime")) {
                                var error = $root.google.protobuf.Timestamp.verify(message.createTime);
                                if (error)
                                    return "createTime." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a CreateConversationModelEvaluationOperationMetadata message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.CreateConversationModelEvaluationOperationMetadata
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.CreateConversationModelEvaluationOperationMetadata} CreateConversationModelEvaluationOperationMetadata
                         */
                        CreateConversationModelEvaluationOperationMetadata.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.CreateConversationModelEvaluationOperationMetadata)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.CreateConversationModelEvaluationOperationMetadata();
                            if (object.conversationModelEvaluation != null)
                                message.conversationModelEvaluation = String(object.conversationModelEvaluation);
                            if (object.conversationModel != null)
                                message.conversationModel = String(object.conversationModel);
                            switch (object.state) {
                            default:
                                if (typeof object.state === "number") {
                                    message.state = object.state;
                                    break;
                                }
                                break;
                            case "STATE_UNSPECIFIED":
                            case 0:
                                message.state = 0;
                                break;
                            case "INITIALIZING":
                            case 1:
                                message.state = 1;
                                break;
                            case "RUNNING":
                            case 2:
                                message.state = 2;
                                break;
                            case "CANCELLED":
                            case 3:
                                message.state = 3;
                                break;
                            case "SUCCEEDED":
                            case 4:
                                message.state = 4;
                                break;
                            case "FAILED":
                            case 5:
                                message.state = 5;
                                break;
                            }
                            if (object.createTime != null) {
                                if (typeof object.createTime !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.CreateConversationModelEvaluationOperationMetadata.createTime: object expected");
                                message.createTime = $root.google.protobuf.Timestamp.fromObject(object.createTime);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a CreateConversationModelEvaluationOperationMetadata message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.CreateConversationModelEvaluationOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.CreateConversationModelEvaluationOperationMetadata} message CreateConversationModelEvaluationOperationMetadata
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        CreateConversationModelEvaluationOperationMetadata.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.conversationModelEvaluation = "";
                                object.state = options.enums === String ? "STATE_UNSPECIFIED" : 0;
                                object.createTime = null;
                                object.conversationModel = "";
                            }
                            if (message.conversationModelEvaluation != null && message.hasOwnProperty("conversationModelEvaluation"))
                                object.conversationModelEvaluation = message.conversationModelEvaluation;
                            if (message.state != null && message.hasOwnProperty("state"))
                                object.state = options.enums === String ? $root.google.cloud.dialogflow.v2.CreateConversationModelEvaluationOperationMetadata.State[message.state] === undefined ? message.state : $root.google.cloud.dialogflow.v2.CreateConversationModelEvaluationOperationMetadata.State[message.state] : message.state;
                            if (message.createTime != null && message.hasOwnProperty("createTime"))
                                object.createTime = $root.google.protobuf.Timestamp.toObject(message.createTime, options);
                            if (message.conversationModel != null && message.hasOwnProperty("conversationModel"))
                                object.conversationModel = message.conversationModel;
                            return object;
                        };
    
                        /**
                         * Converts this CreateConversationModelEvaluationOperationMetadata to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.CreateConversationModelEvaluationOperationMetadata
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        CreateConversationModelEvaluationOperationMetadata.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for CreateConversationModelEvaluationOperationMetadata
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.CreateConversationModelEvaluationOperationMetadata
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        CreateConversationModelEvaluationOperationMetadata.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.CreateConversationModelEvaluationOperationMetadata";
                        };
    
                        /**
                         * State enum.
                         * @name google.cloud.dialogflow.v2.CreateConversationModelEvaluationOperationMetadata.State
                         * @enum {number}
                         * @property {number} STATE_UNSPECIFIED=0 STATE_UNSPECIFIED value
                         * @property {number} INITIALIZING=1 INITIALIZING value
                         * @property {number} RUNNING=2 RUNNING value
                         * @property {number} CANCELLED=3 CANCELLED value
                         * @property {number} SUCCEEDED=4 SUCCEEDED value
                         * @property {number} FAILED=5 FAILED value
                         */
                        CreateConversationModelEvaluationOperationMetadata.State = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "STATE_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "INITIALIZING"] = 1;
                            values[valuesById[2] = "RUNNING"] = 2;
                            values[valuesById[3] = "CANCELLED"] = 3;
                            values[valuesById[4] = "SUCCEEDED"] = 4;
                            values[valuesById[5] = "FAILED"] = 5;
                            return values;
                        })();
    
                        return CreateConversationModelEvaluationOperationMetadata;
                    })();
    
                    v2.Documents = (function() {
    
                        /**
                         * Constructs a new Documents service.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a Documents
                         * @extends $protobuf.rpc.Service
                         * @constructor
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         */
                        function Documents(rpcImpl, requestDelimited, responseDelimited) {
                            $protobuf.rpc.Service.call(this, rpcImpl, requestDelimited, responseDelimited);
                        }
    
                        (Documents.prototype = Object.create($protobuf.rpc.Service.prototype)).constructor = Documents;
    
                        /**
                         * Creates new Documents service using the specified rpc implementation.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.Documents
                         * @static
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         * @returns {Documents} RPC service. Useful where requests and/or responses are streamed.
                         */
                        Documents.create = function create(rpcImpl, requestDelimited, responseDelimited) {
                            return new this(rpcImpl, requestDelimited, responseDelimited);
                        };
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Documents|listDocuments}.
                         * @memberof google.cloud.dialogflow.v2.Documents
                         * @typedef ListDocumentsCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.ListDocumentsResponse} [response] ListDocumentsResponse
                         */
    
                        /**
                         * Calls ListDocuments.
                         * @function listDocuments
                         * @memberof google.cloud.dialogflow.v2.Documents
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IListDocumentsRequest} request ListDocumentsRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Documents.ListDocumentsCallback} callback Node-style callback called with the error, if any, and ListDocumentsResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Documents.prototype.listDocuments = function listDocuments(request, callback) {
                            return this.rpcCall(listDocuments, $root.google.cloud.dialogflow.v2.ListDocumentsRequest, $root.google.cloud.dialogflow.v2.ListDocumentsResponse, request, callback);
                        }, "name", { value: "ListDocuments" });
    
                        /**
                         * Calls ListDocuments.
                         * @function listDocuments
                         * @memberof google.cloud.dialogflow.v2.Documents
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IListDocumentsRequest} request ListDocumentsRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.ListDocumentsResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Documents|getDocument}.
                         * @memberof google.cloud.dialogflow.v2.Documents
                         * @typedef GetDocumentCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.Document} [response] Document
                         */
    
                        /**
                         * Calls GetDocument.
                         * @function getDocument
                         * @memberof google.cloud.dialogflow.v2.Documents
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IGetDocumentRequest} request GetDocumentRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Documents.GetDocumentCallback} callback Node-style callback called with the error, if any, and Document
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Documents.prototype.getDocument = function getDocument(request, callback) {
                            return this.rpcCall(getDocument, $root.google.cloud.dialogflow.v2.GetDocumentRequest, $root.google.cloud.dialogflow.v2.Document, request, callback);
                        }, "name", { value: "GetDocument" });
    
                        /**
                         * Calls GetDocument.
                         * @function getDocument
                         * @memberof google.cloud.dialogflow.v2.Documents
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IGetDocumentRequest} request GetDocumentRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.Document>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Documents|createDocument}.
                         * @memberof google.cloud.dialogflow.v2.Documents
                         * @typedef CreateDocumentCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.longrunning.Operation} [response] Operation
                         */
    
                        /**
                         * Calls CreateDocument.
                         * @function createDocument
                         * @memberof google.cloud.dialogflow.v2.Documents
                         * @instance
                         * @param {google.cloud.dialogflow.v2.ICreateDocumentRequest} request CreateDocumentRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Documents.CreateDocumentCallback} callback Node-style callback called with the error, if any, and Operation
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Documents.prototype.createDocument = function createDocument(request, callback) {
                            return this.rpcCall(createDocument, $root.google.cloud.dialogflow.v2.CreateDocumentRequest, $root.google.longrunning.Operation, request, callback);
                        }, "name", { value: "CreateDocument" });
    
                        /**
                         * Calls CreateDocument.
                         * @function createDocument
                         * @memberof google.cloud.dialogflow.v2.Documents
                         * @instance
                         * @param {google.cloud.dialogflow.v2.ICreateDocumentRequest} request CreateDocumentRequest message or plain object
                         * @returns {Promise<google.longrunning.Operation>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Documents|importDocuments}.
                         * @memberof google.cloud.dialogflow.v2.Documents
                         * @typedef ImportDocumentsCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.longrunning.Operation} [response] Operation
                         */
    
                        /**
                         * Calls ImportDocuments.
                         * @function importDocuments
                         * @memberof google.cloud.dialogflow.v2.Documents
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IImportDocumentsRequest} request ImportDocumentsRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Documents.ImportDocumentsCallback} callback Node-style callback called with the error, if any, and Operation
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Documents.prototype.importDocuments = function importDocuments(request, callback) {
                            return this.rpcCall(importDocuments, $root.google.cloud.dialogflow.v2.ImportDocumentsRequest, $root.google.longrunning.Operation, request, callback);
                        }, "name", { value: "ImportDocuments" });
    
                        /**
                         * Calls ImportDocuments.
                         * @function importDocuments
                         * @memberof google.cloud.dialogflow.v2.Documents
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IImportDocumentsRequest} request ImportDocumentsRequest message or plain object
                         * @returns {Promise<google.longrunning.Operation>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Documents|deleteDocument}.
                         * @memberof google.cloud.dialogflow.v2.Documents
                         * @typedef DeleteDocumentCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.longrunning.Operation} [response] Operation
                         */
    
                        /**
                         * Calls DeleteDocument.
                         * @function deleteDocument
                         * @memberof google.cloud.dialogflow.v2.Documents
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IDeleteDocumentRequest} request DeleteDocumentRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Documents.DeleteDocumentCallback} callback Node-style callback called with the error, if any, and Operation
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Documents.prototype.deleteDocument = function deleteDocument(request, callback) {
                            return this.rpcCall(deleteDocument, $root.google.cloud.dialogflow.v2.DeleteDocumentRequest, $root.google.longrunning.Operation, request, callback);
                        }, "name", { value: "DeleteDocument" });
    
                        /**
                         * Calls DeleteDocument.
                         * @function deleteDocument
                         * @memberof google.cloud.dialogflow.v2.Documents
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IDeleteDocumentRequest} request DeleteDocumentRequest message or plain object
                         * @returns {Promise<google.longrunning.Operation>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Documents|updateDocument}.
                         * @memberof google.cloud.dialogflow.v2.Documents
                         * @typedef UpdateDocumentCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.longrunning.Operation} [response] Operation
                         */
    
                        /**
                         * Calls UpdateDocument.
                         * @function updateDocument
                         * @memberof google.cloud.dialogflow.v2.Documents
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IUpdateDocumentRequest} request UpdateDocumentRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Documents.UpdateDocumentCallback} callback Node-style callback called with the error, if any, and Operation
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Documents.prototype.updateDocument = function updateDocument(request, callback) {
                            return this.rpcCall(updateDocument, $root.google.cloud.dialogflow.v2.UpdateDocumentRequest, $root.google.longrunning.Operation, request, callback);
                        }, "name", { value: "UpdateDocument" });
    
                        /**
                         * Calls UpdateDocument.
                         * @function updateDocument
                         * @memberof google.cloud.dialogflow.v2.Documents
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IUpdateDocumentRequest} request UpdateDocumentRequest message or plain object
                         * @returns {Promise<google.longrunning.Operation>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Documents|reloadDocument}.
                         * @memberof google.cloud.dialogflow.v2.Documents
                         * @typedef ReloadDocumentCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.longrunning.Operation} [response] Operation
                         */
    
                        /**
                         * Calls ReloadDocument.
                         * @function reloadDocument
                         * @memberof google.cloud.dialogflow.v2.Documents
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IReloadDocumentRequest} request ReloadDocumentRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Documents.ReloadDocumentCallback} callback Node-style callback called with the error, if any, and Operation
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Documents.prototype.reloadDocument = function reloadDocument(request, callback) {
                            return this.rpcCall(reloadDocument, $root.google.cloud.dialogflow.v2.ReloadDocumentRequest, $root.google.longrunning.Operation, request, callback);
                        }, "name", { value: "ReloadDocument" });
    
                        /**
                         * Calls ReloadDocument.
                         * @function reloadDocument
                         * @memberof google.cloud.dialogflow.v2.Documents
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IReloadDocumentRequest} request ReloadDocumentRequest message or plain object
                         * @returns {Promise<google.longrunning.Operation>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Documents|exportDocument}.
                         * @memberof google.cloud.dialogflow.v2.Documents
                         * @typedef ExportDocumentCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.longrunning.Operation} [response] Operation
                         */
    
                        /**
                         * Calls ExportDocument.
                         * @function exportDocument
                         * @memberof google.cloud.dialogflow.v2.Documents
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IExportDocumentRequest} request ExportDocumentRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Documents.ExportDocumentCallback} callback Node-style callback called with the error, if any, and Operation
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Documents.prototype.exportDocument = function exportDocument(request, callback) {
                            return this.rpcCall(exportDocument, $root.google.cloud.dialogflow.v2.ExportDocumentRequest, $root.google.longrunning.Operation, request, callback);
                        }, "name", { value: "ExportDocument" });
    
                        /**
                         * Calls ExportDocument.
                         * @function exportDocument
                         * @memberof google.cloud.dialogflow.v2.Documents
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IExportDocumentRequest} request ExportDocumentRequest message or plain object
                         * @returns {Promise<google.longrunning.Operation>} Promise
                         * @variation 2
                         */
    
                        return Documents;
                    })();
    
                    v2.Document = (function() {
    
                        /**
                         * Properties of a Document.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IDocument
                         * @property {string|null} [name] Document name
                         * @property {string|null} [displayName] Document displayName
                         * @property {string|null} [mimeType] Document mimeType
                         * @property {Array.<google.cloud.dialogflow.v2.Document.KnowledgeType>|null} [knowledgeTypes] Document knowledgeTypes
                         * @property {string|null} [contentUri] Document contentUri
                         * @property {Uint8Array|null} [rawContent] Document rawContent
                         * @property {boolean|null} [enableAutoReload] Document enableAutoReload
                         * @property {google.cloud.dialogflow.v2.Document.IReloadStatus|null} [latestReloadStatus] Document latestReloadStatus
                         * @property {Object.<string,string>|null} [metadata] Document metadata
                         * @property {google.cloud.dialogflow.v2.Document.State|null} [state] Document state
                         */
    
                        /**
                         * Constructs a new Document.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a Document.
                         * @implements IDocument
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IDocument=} [properties] Properties to set
                         */
                        function Document(properties) {
                            this.knowledgeTypes = [];
                            this.metadata = {};
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * Document name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2.Document
                         * @instance
                         */
                        Document.prototype.name = "";
    
                        /**
                         * Document displayName.
                         * @member {string} displayName
                         * @memberof google.cloud.dialogflow.v2.Document
                         * @instance
                         */
                        Document.prototype.displayName = "";
    
                        /**
                         * Document mimeType.
                         * @member {string} mimeType
                         * @memberof google.cloud.dialogflow.v2.Document
                         * @instance
                         */
                        Document.prototype.mimeType = "";
    
                        /**
                         * Document knowledgeTypes.
                         * @member {Array.<google.cloud.dialogflow.v2.Document.KnowledgeType>} knowledgeTypes
                         * @memberof google.cloud.dialogflow.v2.Document
                         * @instance
                         */
                        Document.prototype.knowledgeTypes = $util.emptyArray;
    
                        /**
                         * Document contentUri.
                         * @member {string|null|undefined} contentUri
                         * @memberof google.cloud.dialogflow.v2.Document
                         * @instance
                         */
                        Document.prototype.contentUri = null;
    
                        /**
                         * Document rawContent.
                         * @member {Uint8Array|null|undefined} rawContent
                         * @memberof google.cloud.dialogflow.v2.Document
                         * @instance
                         */
                        Document.prototype.rawContent = null;
    
                        /**
                         * Document enableAutoReload.
                         * @member {boolean} enableAutoReload
                         * @memberof google.cloud.dialogflow.v2.Document
                         * @instance
                         */
                        Document.prototype.enableAutoReload = false;
    
                        /**
                         * Document latestReloadStatus.
                         * @member {google.cloud.dialogflow.v2.Document.IReloadStatus|null|undefined} latestReloadStatus
                         * @memberof google.cloud.dialogflow.v2.Document
                         * @instance
                         */
                        Document.prototype.latestReloadStatus = null;
    
                        /**
                         * Document metadata.
                         * @member {Object.<string,string>} metadata
                         * @memberof google.cloud.dialogflow.v2.Document
                         * @instance
                         */
                        Document.prototype.metadata = $util.emptyObject;
    
                        /**
                         * Document state.
                         * @member {google.cloud.dialogflow.v2.Document.State} state
                         * @memberof google.cloud.dialogflow.v2.Document
                         * @instance
                         */
                        Document.prototype.state = 0;
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * Document source.
                         * @member {"contentUri"|"rawContent"|undefined} source
                         * @memberof google.cloud.dialogflow.v2.Document
                         * @instance
                         */
                        Object.defineProperty(Document.prototype, "source", {
                            get: $util.oneOfGetter($oneOfFields = ["contentUri", "rawContent"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new Document instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.Document
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDocument=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.Document} Document instance
                         */
                        Document.create = function create(properties) {
                            return new Document(properties);
                        };
    
                        /**
                         * Encodes the specified Document message. Does not implicitly {@link google.cloud.dialogflow.v2.Document.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.Document
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDocument} message Document message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        Document.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            if (message.displayName != null && Object.hasOwnProperty.call(message, "displayName"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.displayName);
                            if (message.mimeType != null && Object.hasOwnProperty.call(message, "mimeType"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.mimeType);
                            if (message.knowledgeTypes != null && message.knowledgeTypes.length) {
                                writer.uint32(/* id 4, wireType 2 =*/34).fork();
                                for (var i = 0; i < message.knowledgeTypes.length; ++i)
                                    writer.int32(message.knowledgeTypes[i]);
                                writer.ldelim();
                            }
                            if (message.contentUri != null && Object.hasOwnProperty.call(message, "contentUri"))
                                writer.uint32(/* id 5, wireType 2 =*/42).string(message.contentUri);
                            if (message.metadata != null && Object.hasOwnProperty.call(message, "metadata"))
                                for (var keys = Object.keys(message.metadata), i = 0; i < keys.length; ++i)
                                    writer.uint32(/* id 7, wireType 2 =*/58).fork().uint32(/* id 1, wireType 2 =*/10).string(keys[i]).uint32(/* id 2, wireType 2 =*/18).string(message.metadata[keys[i]]).ldelim();
                            if (message.rawContent != null && Object.hasOwnProperty.call(message, "rawContent"))
                                writer.uint32(/* id 9, wireType 2 =*/74).bytes(message.rawContent);
                            if (message.enableAutoReload != null && Object.hasOwnProperty.call(message, "enableAutoReload"))
                                writer.uint32(/* id 11, wireType 0 =*/88).bool(message.enableAutoReload);
                            if (message.latestReloadStatus != null && Object.hasOwnProperty.call(message, "latestReloadStatus"))
                                $root.google.cloud.dialogflow.v2.Document.ReloadStatus.encode(message.latestReloadStatus, writer.uint32(/* id 12, wireType 2 =*/98).fork()).ldelim();
                            if (message.state != null && Object.hasOwnProperty.call(message, "state"))
                                writer.uint32(/* id 13, wireType 0 =*/104).int32(message.state);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified Document message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.Document.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.Document
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDocument} message Document message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        Document.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a Document message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.Document
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.Document} Document
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        Document.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.Document(), key, value;
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.displayName = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.mimeType = reader.string();
                                        break;
                                    }
                                case 4: {
                                        if (!(message.knowledgeTypes && message.knowledgeTypes.length))
                                            message.knowledgeTypes = [];
                                        if ((tag & 7) === 2) {
                                            var end2 = reader.uint32() + reader.pos;
                                            while (reader.pos < end2)
                                                message.knowledgeTypes.push(reader.int32());
                                        } else
                                            message.knowledgeTypes.push(reader.int32());
                                        break;
                                    }
                                case 5: {
                                        message.contentUri = reader.string();
                                        break;
                                    }
                                case 9: {
                                        message.rawContent = reader.bytes();
                                        break;
                                    }
                                case 11: {
                                        message.enableAutoReload = reader.bool();
                                        break;
                                    }
                                case 12: {
                                        message.latestReloadStatus = $root.google.cloud.dialogflow.v2.Document.ReloadStatus.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 7: {
                                        if (message.metadata === $util.emptyObject)
                                            message.metadata = {};
                                        var end2 = reader.uint32() + reader.pos;
                                        key = "";
                                        value = "";
                                        while (reader.pos < end2) {
                                            var tag2 = reader.uint32();
                                            switch (tag2 >>> 3) {
                                            case 1:
                                                key = reader.string();
                                                break;
                                            case 2:
                                                value = reader.string();
                                                break;
                                            default:
                                                reader.skipType(tag2 & 7);
                                                break;
                                            }
                                        }
                                        message.metadata[key] = value;
                                        break;
                                    }
                                case 13: {
                                        message.state = reader.int32();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a Document message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.Document
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.Document} Document
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        Document.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a Document message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.Document
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        Document.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            if (message.displayName != null && message.hasOwnProperty("displayName"))
                                if (!$util.isString(message.displayName))
                                    return "displayName: string expected";
                            if (message.mimeType != null && message.hasOwnProperty("mimeType"))
                                if (!$util.isString(message.mimeType))
                                    return "mimeType: string expected";
                            if (message.knowledgeTypes != null && message.hasOwnProperty("knowledgeTypes")) {
                                if (!Array.isArray(message.knowledgeTypes))
                                    return "knowledgeTypes: array expected";
                                for (var i = 0; i < message.knowledgeTypes.length; ++i)
                                    switch (message.knowledgeTypes[i]) {
                                    default:
                                        return "knowledgeTypes: enum value[] expected";
                                    case 0:
                                    case 1:
                                    case 2:
                                    case 3:
                                    case 4:
                                        break;
                                    }
                            }
                            if (message.contentUri != null && message.hasOwnProperty("contentUri")) {
                                properties.source = 1;
                                if (!$util.isString(message.contentUri))
                                    return "contentUri: string expected";
                            }
                            if (message.rawContent != null && message.hasOwnProperty("rawContent")) {
                                if (properties.source === 1)
                                    return "source: multiple values";
                                properties.source = 1;
                                if (!(message.rawContent && typeof message.rawContent.length === "number" || $util.isString(message.rawContent)))
                                    return "rawContent: buffer expected";
                            }
                            if (message.enableAutoReload != null && message.hasOwnProperty("enableAutoReload"))
                                if (typeof message.enableAutoReload !== "boolean")
                                    return "enableAutoReload: boolean expected";
                            if (message.latestReloadStatus != null && message.hasOwnProperty("latestReloadStatus")) {
                                var error = $root.google.cloud.dialogflow.v2.Document.ReloadStatus.verify(message.latestReloadStatus);
                                if (error)
                                    return "latestReloadStatus." + error;
                            }
                            if (message.metadata != null && message.hasOwnProperty("metadata")) {
                                if (!$util.isObject(message.metadata))
                                    return "metadata: object expected";
                                var key = Object.keys(message.metadata);
                                for (var i = 0; i < key.length; ++i)
                                    if (!$util.isString(message.metadata[key[i]]))
                                        return "metadata: string{k:string} expected";
                            }
                            if (message.state != null && message.hasOwnProperty("state"))
                                switch (message.state) {
                                default:
                                    return "state: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                case 4:
                                case 5:
                                    break;
                                }
                            return null;
                        };
    
                        /**
                         * Creates a Document message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.Document
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.Document} Document
                         */
                        Document.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.Document)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.Document();
                            if (object.name != null)
                                message.name = String(object.name);
                            if (object.displayName != null)
                                message.displayName = String(object.displayName);
                            if (object.mimeType != null)
                                message.mimeType = String(object.mimeType);
                            if (object.knowledgeTypes) {
                                if (!Array.isArray(object.knowledgeTypes))
                                    throw TypeError(".google.cloud.dialogflow.v2.Document.knowledgeTypes: array expected");
                                message.knowledgeTypes = [];
                                for (var i = 0; i < object.knowledgeTypes.length; ++i)
                                    switch (object.knowledgeTypes[i]) {
                                    default:
                                        if (typeof object.knowledgeTypes[i] === "number") {
                                            message.knowledgeTypes[i] = object.knowledgeTypes[i];
                                            break;
                                        }
                                    case "KNOWLEDGE_TYPE_UNSPECIFIED":
                                    case 0:
                                        message.knowledgeTypes[i] = 0;
                                        break;
                                    case "FAQ":
                                    case 1:
                                        message.knowledgeTypes[i] = 1;
                                        break;
                                    case "EXTRACTIVE_QA":
                                    case 2:
                                        message.knowledgeTypes[i] = 2;
                                        break;
                                    case "ARTICLE_SUGGESTION":
                                    case 3:
                                        message.knowledgeTypes[i] = 3;
                                        break;
                                    case "AGENT_FACING_SMART_REPLY":
                                    case 4:
                                        message.knowledgeTypes[i] = 4;
                                        break;
                                    }
                            }
                            if (object.contentUri != null)
                                message.contentUri = String(object.contentUri);
                            if (object.rawContent != null)
                                if (typeof object.rawContent === "string")
                                    $util.base64.decode(object.rawContent, message.rawContent = $util.newBuffer($util.base64.length(object.rawContent)), 0);
                                else if (object.rawContent.length >= 0)
                                    message.rawContent = object.rawContent;
                            if (object.enableAutoReload != null)
                                message.enableAutoReload = Boolean(object.enableAutoReload);
                            if (object.latestReloadStatus != null) {
                                if (typeof object.latestReloadStatus !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.Document.latestReloadStatus: object expected");
                                message.latestReloadStatus = $root.google.cloud.dialogflow.v2.Document.ReloadStatus.fromObject(object.latestReloadStatus);
                            }
                            if (object.metadata) {
                                if (typeof object.metadata !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.Document.metadata: object expected");
                                message.metadata = {};
                                for (var keys = Object.keys(object.metadata), i = 0; i < keys.length; ++i)
                                    message.metadata[keys[i]] = String(object.metadata[keys[i]]);
                            }
                            switch (object.state) {
                            default:
                                if (typeof object.state === "number") {
                                    message.state = object.state;
                                    break;
                                }
                                break;
                            case "STATE_UNSPECIFIED":
                            case 0:
                                message.state = 0;
                                break;
                            case "CREATING":
                            case 1:
                                message.state = 1;
                                break;
                            case "ACTIVE":
                            case 2:
                                message.state = 2;
                                break;
                            case "UPDATING":
                            case 3:
                                message.state = 3;
                                break;
                            case "RELOADING":
                            case 4:
                                message.state = 4;
                                break;
                            case "DELETING":
                            case 5:
                                message.state = 5;
                                break;
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a Document message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.Document
                         * @static
                         * @param {google.cloud.dialogflow.v2.Document} message Document
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        Document.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.knowledgeTypes = [];
                            if (options.objects || options.defaults)
                                object.metadata = {};
                            if (options.defaults) {
                                object.name = "";
                                object.displayName = "";
                                object.mimeType = "";
                                object.enableAutoReload = false;
                                object.latestReloadStatus = null;
                                object.state = options.enums === String ? "STATE_UNSPECIFIED" : 0;
                            }
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            if (message.displayName != null && message.hasOwnProperty("displayName"))
                                object.displayName = message.displayName;
                            if (message.mimeType != null && message.hasOwnProperty("mimeType"))
                                object.mimeType = message.mimeType;
                            if (message.knowledgeTypes && message.knowledgeTypes.length) {
                                object.knowledgeTypes = [];
                                for (var j = 0; j < message.knowledgeTypes.length; ++j)
                                    object.knowledgeTypes[j] = options.enums === String ? $root.google.cloud.dialogflow.v2.Document.KnowledgeType[message.knowledgeTypes[j]] === undefined ? message.knowledgeTypes[j] : $root.google.cloud.dialogflow.v2.Document.KnowledgeType[message.knowledgeTypes[j]] : message.knowledgeTypes[j];
                            }
                            if (message.contentUri != null && message.hasOwnProperty("contentUri")) {
                                object.contentUri = message.contentUri;
                                if (options.oneofs)
                                    object.source = "contentUri";
                            }
                            var keys2;
                            if (message.metadata && (keys2 = Object.keys(message.metadata)).length) {
                                object.metadata = {};
                                for (var j = 0; j < keys2.length; ++j)
                                    object.metadata[keys2[j]] = message.metadata[keys2[j]];
                            }
                            if (message.rawContent != null && message.hasOwnProperty("rawContent")) {
                                object.rawContent = options.bytes === String ? $util.base64.encode(message.rawContent, 0, message.rawContent.length) : options.bytes === Array ? Array.prototype.slice.call(message.rawContent) : message.rawContent;
                                if (options.oneofs)
                                    object.source = "rawContent";
                            }
                            if (message.enableAutoReload != null && message.hasOwnProperty("enableAutoReload"))
                                object.enableAutoReload = message.enableAutoReload;
                            if (message.latestReloadStatus != null && message.hasOwnProperty("latestReloadStatus"))
                                object.latestReloadStatus = $root.google.cloud.dialogflow.v2.Document.ReloadStatus.toObject(message.latestReloadStatus, options);
                            if (message.state != null && message.hasOwnProperty("state"))
                                object.state = options.enums === String ? $root.google.cloud.dialogflow.v2.Document.State[message.state] === undefined ? message.state : $root.google.cloud.dialogflow.v2.Document.State[message.state] : message.state;
                            return object;
                        };
    
                        /**
                         * Converts this Document to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.Document
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        Document.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for Document
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.Document
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        Document.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.Document";
                        };
    
                        /**
                         * KnowledgeType enum.
                         * @name google.cloud.dialogflow.v2.Document.KnowledgeType
                         * @enum {number}
                         * @property {number} KNOWLEDGE_TYPE_UNSPECIFIED=0 KNOWLEDGE_TYPE_UNSPECIFIED value
                         * @property {number} FAQ=1 FAQ value
                         * @property {number} EXTRACTIVE_QA=2 EXTRACTIVE_QA value
                         * @property {number} ARTICLE_SUGGESTION=3 ARTICLE_SUGGESTION value
                         * @property {number} AGENT_FACING_SMART_REPLY=4 AGENT_FACING_SMART_REPLY value
                         */
                        Document.KnowledgeType = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "KNOWLEDGE_TYPE_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "FAQ"] = 1;
                            values[valuesById[2] = "EXTRACTIVE_QA"] = 2;
                            values[valuesById[3] = "ARTICLE_SUGGESTION"] = 3;
                            values[valuesById[4] = "AGENT_FACING_SMART_REPLY"] = 4;
                            return values;
                        })();
    
                        Document.ReloadStatus = (function() {
    
                            /**
                             * Properties of a ReloadStatus.
                             * @memberof google.cloud.dialogflow.v2.Document
                             * @interface IReloadStatus
                             * @property {google.protobuf.ITimestamp|null} [time] ReloadStatus time
                             * @property {google.rpc.IStatus|null} [status] ReloadStatus status
                             */
    
                            /**
                             * Constructs a new ReloadStatus.
                             * @memberof google.cloud.dialogflow.v2.Document
                             * @classdesc Represents a ReloadStatus.
                             * @implements IReloadStatus
                             * @constructor
                             * @param {google.cloud.dialogflow.v2.Document.IReloadStatus=} [properties] Properties to set
                             */
                            function ReloadStatus(properties) {
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * ReloadStatus time.
                             * @member {google.protobuf.ITimestamp|null|undefined} time
                             * @memberof google.cloud.dialogflow.v2.Document.ReloadStatus
                             * @instance
                             */
                            ReloadStatus.prototype.time = null;
    
                            /**
                             * ReloadStatus status.
                             * @member {google.rpc.IStatus|null|undefined} status
                             * @memberof google.cloud.dialogflow.v2.Document.ReloadStatus
                             * @instance
                             */
                            ReloadStatus.prototype.status = null;
    
                            /**
                             * Creates a new ReloadStatus instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2.Document.ReloadStatus
                             * @static
                             * @param {google.cloud.dialogflow.v2.Document.IReloadStatus=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2.Document.ReloadStatus} ReloadStatus instance
                             */
                            ReloadStatus.create = function create(properties) {
                                return new ReloadStatus(properties);
                            };
    
                            /**
                             * Encodes the specified ReloadStatus message. Does not implicitly {@link google.cloud.dialogflow.v2.Document.ReloadStatus.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2.Document.ReloadStatus
                             * @static
                             * @param {google.cloud.dialogflow.v2.Document.IReloadStatus} message ReloadStatus message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            ReloadStatus.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.time != null && Object.hasOwnProperty.call(message, "time"))
                                    $root.google.protobuf.Timestamp.encode(message.time, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                                if (message.status != null && Object.hasOwnProperty.call(message, "status"))
                                    $root.google.rpc.Status.encode(message.status, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                                return writer;
                            };
    
                            /**
                             * Encodes the specified ReloadStatus message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.Document.ReloadStatus.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2.Document.ReloadStatus
                             * @static
                             * @param {google.cloud.dialogflow.v2.Document.IReloadStatus} message ReloadStatus message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            ReloadStatus.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a ReloadStatus message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2.Document.ReloadStatus
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2.Document.ReloadStatus} ReloadStatus
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            ReloadStatus.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.Document.ReloadStatus();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.time = $root.google.protobuf.Timestamp.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 2: {
                                            message.status = $root.google.rpc.Status.decode(reader, reader.uint32());
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a ReloadStatus message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2.Document.ReloadStatus
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2.Document.ReloadStatus} ReloadStatus
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            ReloadStatus.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a ReloadStatus message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2.Document.ReloadStatus
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            ReloadStatus.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.time != null && message.hasOwnProperty("time")) {
                                    var error = $root.google.protobuf.Timestamp.verify(message.time);
                                    if (error)
                                        return "time." + error;
                                }
                                if (message.status != null && message.hasOwnProperty("status")) {
                                    var error = $root.google.rpc.Status.verify(message.status);
                                    if (error)
                                        return "status." + error;
                                }
                                return null;
                            };
    
                            /**
                             * Creates a ReloadStatus message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2.Document.ReloadStatus
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2.Document.ReloadStatus} ReloadStatus
                             */
                            ReloadStatus.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2.Document.ReloadStatus)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2.Document.ReloadStatus();
                                if (object.time != null) {
                                    if (typeof object.time !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.Document.ReloadStatus.time: object expected");
                                    message.time = $root.google.protobuf.Timestamp.fromObject(object.time);
                                }
                                if (object.status != null) {
                                    if (typeof object.status !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.Document.ReloadStatus.status: object expected");
                                    message.status = $root.google.rpc.Status.fromObject(object.status);
                                }
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a ReloadStatus message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2.Document.ReloadStatus
                             * @static
                             * @param {google.cloud.dialogflow.v2.Document.ReloadStatus} message ReloadStatus
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            ReloadStatus.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.defaults) {
                                    object.time = null;
                                    object.status = null;
                                }
                                if (message.time != null && message.hasOwnProperty("time"))
                                    object.time = $root.google.protobuf.Timestamp.toObject(message.time, options);
                                if (message.status != null && message.hasOwnProperty("status"))
                                    object.status = $root.google.rpc.Status.toObject(message.status, options);
                                return object;
                            };
    
                            /**
                             * Converts this ReloadStatus to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2.Document.ReloadStatus
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            ReloadStatus.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for ReloadStatus
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2.Document.ReloadStatus
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            ReloadStatus.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2.Document.ReloadStatus";
                            };
    
                            return ReloadStatus;
                        })();
    
                        /**
                         * State enum.
                         * @name google.cloud.dialogflow.v2.Document.State
                         * @enum {number}
                         * @property {number} STATE_UNSPECIFIED=0 STATE_UNSPECIFIED value
                         * @property {number} CREATING=1 CREATING value
                         * @property {number} ACTIVE=2 ACTIVE value
                         * @property {number} UPDATING=3 UPDATING value
                         * @property {number} RELOADING=4 RELOADING value
                         * @property {number} DELETING=5 DELETING value
                         */
                        Document.State = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "STATE_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "CREATING"] = 1;
                            values[valuesById[2] = "ACTIVE"] = 2;
                            values[valuesById[3] = "UPDATING"] = 3;
                            values[valuesById[4] = "RELOADING"] = 4;
                            values[valuesById[5] = "DELETING"] = 5;
                            return values;
                        })();
    
                        return Document;
                    })();
    
                    v2.GetDocumentRequest = (function() {
    
                        /**
                         * Properties of a GetDocumentRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IGetDocumentRequest
                         * @property {string|null} [name] GetDocumentRequest name
                         */
    
                        /**
                         * Constructs a new GetDocumentRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a GetDocumentRequest.
                         * @implements IGetDocumentRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IGetDocumentRequest=} [properties] Properties to set
                         */
                        function GetDocumentRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GetDocumentRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2.GetDocumentRequest
                         * @instance
                         */
                        GetDocumentRequest.prototype.name = "";
    
                        /**
                         * Creates a new GetDocumentRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.GetDocumentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetDocumentRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.GetDocumentRequest} GetDocumentRequest instance
                         */
                        GetDocumentRequest.create = function create(properties) {
                            return new GetDocumentRequest(properties);
                        };
    
                        /**
                         * Encodes the specified GetDocumentRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.GetDocumentRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.GetDocumentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetDocumentRequest} message GetDocumentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetDocumentRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GetDocumentRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.GetDocumentRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GetDocumentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetDocumentRequest} message GetDocumentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetDocumentRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GetDocumentRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.GetDocumentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.GetDocumentRequest} GetDocumentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetDocumentRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.GetDocumentRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GetDocumentRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GetDocumentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.GetDocumentRequest} GetDocumentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetDocumentRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GetDocumentRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.GetDocumentRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GetDocumentRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a GetDocumentRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.GetDocumentRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.GetDocumentRequest} GetDocumentRequest
                         */
                        GetDocumentRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.GetDocumentRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.GetDocumentRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GetDocumentRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.GetDocumentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.GetDocumentRequest} message GetDocumentRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GetDocumentRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.name = "";
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            return object;
                        };
    
                        /**
                         * Converts this GetDocumentRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.GetDocumentRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GetDocumentRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GetDocumentRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.GetDocumentRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GetDocumentRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.GetDocumentRequest";
                        };
    
                        return GetDocumentRequest;
                    })();
    
                    v2.ListDocumentsRequest = (function() {
    
                        /**
                         * Properties of a ListDocumentsRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IListDocumentsRequest
                         * @property {string|null} [parent] ListDocumentsRequest parent
                         * @property {number|null} [pageSize] ListDocumentsRequest pageSize
                         * @property {string|null} [pageToken] ListDocumentsRequest pageToken
                         * @property {string|null} [filter] ListDocumentsRequest filter
                         */
    
                        /**
                         * Constructs a new ListDocumentsRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a ListDocumentsRequest.
                         * @implements IListDocumentsRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IListDocumentsRequest=} [properties] Properties to set
                         */
                        function ListDocumentsRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListDocumentsRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.ListDocumentsRequest
                         * @instance
                         */
                        ListDocumentsRequest.prototype.parent = "";
    
                        /**
                         * ListDocumentsRequest pageSize.
                         * @member {number} pageSize
                         * @memberof google.cloud.dialogflow.v2.ListDocumentsRequest
                         * @instance
                         */
                        ListDocumentsRequest.prototype.pageSize = 0;
    
                        /**
                         * ListDocumentsRequest pageToken.
                         * @member {string} pageToken
                         * @memberof google.cloud.dialogflow.v2.ListDocumentsRequest
                         * @instance
                         */
                        ListDocumentsRequest.prototype.pageToken = "";
    
                        /**
                         * ListDocumentsRequest filter.
                         * @member {string} filter
                         * @memberof google.cloud.dialogflow.v2.ListDocumentsRequest
                         * @instance
                         */
                        ListDocumentsRequest.prototype.filter = "";
    
                        /**
                         * Creates a new ListDocumentsRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ListDocumentsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListDocumentsRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ListDocumentsRequest} ListDocumentsRequest instance
                         */
                        ListDocumentsRequest.create = function create(properties) {
                            return new ListDocumentsRequest(properties);
                        };
    
                        /**
                         * Encodes the specified ListDocumentsRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.ListDocumentsRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ListDocumentsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListDocumentsRequest} message ListDocumentsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListDocumentsRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.pageSize != null && Object.hasOwnProperty.call(message, "pageSize"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.pageSize);
                            if (message.pageToken != null && Object.hasOwnProperty.call(message, "pageToken"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.pageToken);
                            if (message.filter != null && Object.hasOwnProperty.call(message, "filter"))
                                writer.uint32(/* id 4, wireType 2 =*/34).string(message.filter);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListDocumentsRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ListDocumentsRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListDocumentsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListDocumentsRequest} message ListDocumentsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListDocumentsRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListDocumentsRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ListDocumentsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ListDocumentsRequest} ListDocumentsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListDocumentsRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ListDocumentsRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.pageSize = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.pageToken = reader.string();
                                        break;
                                    }
                                case 4: {
                                        message.filter = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListDocumentsRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListDocumentsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ListDocumentsRequest} ListDocumentsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListDocumentsRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListDocumentsRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ListDocumentsRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListDocumentsRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                if (!$util.isInteger(message.pageSize))
                                    return "pageSize: integer expected";
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                if (!$util.isString(message.pageToken))
                                    return "pageToken: string expected";
                            if (message.filter != null && message.hasOwnProperty("filter"))
                                if (!$util.isString(message.filter))
                                    return "filter: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListDocumentsRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ListDocumentsRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ListDocumentsRequest} ListDocumentsRequest
                         */
                        ListDocumentsRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ListDocumentsRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ListDocumentsRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.pageSize != null)
                                message.pageSize = object.pageSize | 0;
                            if (object.pageToken != null)
                                message.pageToken = String(object.pageToken);
                            if (object.filter != null)
                                message.filter = String(object.filter);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListDocumentsRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ListDocumentsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ListDocumentsRequest} message ListDocumentsRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListDocumentsRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.pageSize = 0;
                                object.pageToken = "";
                                object.filter = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                object.pageSize = message.pageSize;
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                object.pageToken = message.pageToken;
                            if (message.filter != null && message.hasOwnProperty("filter"))
                                object.filter = message.filter;
                            return object;
                        };
    
                        /**
                         * Converts this ListDocumentsRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ListDocumentsRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListDocumentsRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListDocumentsRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ListDocumentsRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListDocumentsRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ListDocumentsRequest";
                        };
    
                        return ListDocumentsRequest;
                    })();
    
                    v2.ListDocumentsResponse = (function() {
    
                        /**
                         * Properties of a ListDocumentsResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IListDocumentsResponse
                         * @property {Array.<google.cloud.dialogflow.v2.IDocument>|null} [documents] ListDocumentsResponse documents
                         * @property {string|null} [nextPageToken] ListDocumentsResponse nextPageToken
                         */
    
                        /**
                         * Constructs a new ListDocumentsResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a ListDocumentsResponse.
                         * @implements IListDocumentsResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IListDocumentsResponse=} [properties] Properties to set
                         */
                        function ListDocumentsResponse(properties) {
                            this.documents = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListDocumentsResponse documents.
                         * @member {Array.<google.cloud.dialogflow.v2.IDocument>} documents
                         * @memberof google.cloud.dialogflow.v2.ListDocumentsResponse
                         * @instance
                         */
                        ListDocumentsResponse.prototype.documents = $util.emptyArray;
    
                        /**
                         * ListDocumentsResponse nextPageToken.
                         * @member {string} nextPageToken
                         * @memberof google.cloud.dialogflow.v2.ListDocumentsResponse
                         * @instance
                         */
                        ListDocumentsResponse.prototype.nextPageToken = "";
    
                        /**
                         * Creates a new ListDocumentsResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ListDocumentsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListDocumentsResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ListDocumentsResponse} ListDocumentsResponse instance
                         */
                        ListDocumentsResponse.create = function create(properties) {
                            return new ListDocumentsResponse(properties);
                        };
    
                        /**
                         * Encodes the specified ListDocumentsResponse message. Does not implicitly {@link google.cloud.dialogflow.v2.ListDocumentsResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ListDocumentsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListDocumentsResponse} message ListDocumentsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListDocumentsResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.documents != null && message.documents.length)
                                for (var i = 0; i < message.documents.length; ++i)
                                    $root.google.cloud.dialogflow.v2.Document.encode(message.documents[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.nextPageToken != null && Object.hasOwnProperty.call(message, "nextPageToken"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.nextPageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListDocumentsResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ListDocumentsResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListDocumentsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListDocumentsResponse} message ListDocumentsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListDocumentsResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListDocumentsResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ListDocumentsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ListDocumentsResponse} ListDocumentsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListDocumentsResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ListDocumentsResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.documents && message.documents.length))
                                            message.documents = [];
                                        message.documents.push($root.google.cloud.dialogflow.v2.Document.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 2: {
                                        message.nextPageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListDocumentsResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListDocumentsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ListDocumentsResponse} ListDocumentsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListDocumentsResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListDocumentsResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ListDocumentsResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListDocumentsResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.documents != null && message.hasOwnProperty("documents")) {
                                if (!Array.isArray(message.documents))
                                    return "documents: array expected";
                                for (var i = 0; i < message.documents.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.Document.verify(message.documents[i]);
                                    if (error)
                                        return "documents." + error;
                                }
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                if (!$util.isString(message.nextPageToken))
                                    return "nextPageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListDocumentsResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ListDocumentsResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ListDocumentsResponse} ListDocumentsResponse
                         */
                        ListDocumentsResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ListDocumentsResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ListDocumentsResponse();
                            if (object.documents) {
                                if (!Array.isArray(object.documents))
                                    throw TypeError(".google.cloud.dialogflow.v2.ListDocumentsResponse.documents: array expected");
                                message.documents = [];
                                for (var i = 0; i < object.documents.length; ++i) {
                                    if (typeof object.documents[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.ListDocumentsResponse.documents: object expected");
                                    message.documents[i] = $root.google.cloud.dialogflow.v2.Document.fromObject(object.documents[i]);
                                }
                            }
                            if (object.nextPageToken != null)
                                message.nextPageToken = String(object.nextPageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListDocumentsResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ListDocumentsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.ListDocumentsResponse} message ListDocumentsResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListDocumentsResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.documents = [];
                            if (options.defaults)
                                object.nextPageToken = "";
                            if (message.documents && message.documents.length) {
                                object.documents = [];
                                for (var j = 0; j < message.documents.length; ++j)
                                    object.documents[j] = $root.google.cloud.dialogflow.v2.Document.toObject(message.documents[j], options);
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                object.nextPageToken = message.nextPageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListDocumentsResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ListDocumentsResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListDocumentsResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListDocumentsResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ListDocumentsResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListDocumentsResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ListDocumentsResponse";
                        };
    
                        return ListDocumentsResponse;
                    })();
    
                    v2.CreateDocumentRequest = (function() {
    
                        /**
                         * Properties of a CreateDocumentRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ICreateDocumentRequest
                         * @property {string|null} [parent] CreateDocumentRequest parent
                         * @property {google.cloud.dialogflow.v2.IDocument|null} [document] CreateDocumentRequest document
                         */
    
                        /**
                         * Constructs a new CreateDocumentRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a CreateDocumentRequest.
                         * @implements ICreateDocumentRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ICreateDocumentRequest=} [properties] Properties to set
                         */
                        function CreateDocumentRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * CreateDocumentRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.CreateDocumentRequest
                         * @instance
                         */
                        CreateDocumentRequest.prototype.parent = "";
    
                        /**
                         * CreateDocumentRequest document.
                         * @member {google.cloud.dialogflow.v2.IDocument|null|undefined} document
                         * @memberof google.cloud.dialogflow.v2.CreateDocumentRequest
                         * @instance
                         */
                        CreateDocumentRequest.prototype.document = null;
    
                        /**
                         * Creates a new CreateDocumentRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.CreateDocumentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICreateDocumentRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.CreateDocumentRequest} CreateDocumentRequest instance
                         */
                        CreateDocumentRequest.create = function create(properties) {
                            return new CreateDocumentRequest(properties);
                        };
    
                        /**
                         * Encodes the specified CreateDocumentRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.CreateDocumentRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.CreateDocumentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICreateDocumentRequest} message CreateDocumentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateDocumentRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.document != null && Object.hasOwnProperty.call(message, "document"))
                                $root.google.cloud.dialogflow.v2.Document.encode(message.document, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified CreateDocumentRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.CreateDocumentRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.CreateDocumentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICreateDocumentRequest} message CreateDocumentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateDocumentRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a CreateDocumentRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.CreateDocumentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.CreateDocumentRequest} CreateDocumentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateDocumentRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.CreateDocumentRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.document = $root.google.cloud.dialogflow.v2.Document.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a CreateDocumentRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.CreateDocumentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.CreateDocumentRequest} CreateDocumentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateDocumentRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a CreateDocumentRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.CreateDocumentRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        CreateDocumentRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.document != null && message.hasOwnProperty("document")) {
                                var error = $root.google.cloud.dialogflow.v2.Document.verify(message.document);
                                if (error)
                                    return "document." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a CreateDocumentRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.CreateDocumentRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.CreateDocumentRequest} CreateDocumentRequest
                         */
                        CreateDocumentRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.CreateDocumentRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.CreateDocumentRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.document != null) {
                                if (typeof object.document !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.CreateDocumentRequest.document: object expected");
                                message.document = $root.google.cloud.dialogflow.v2.Document.fromObject(object.document);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a CreateDocumentRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.CreateDocumentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.CreateDocumentRequest} message CreateDocumentRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        CreateDocumentRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.document = null;
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.document != null && message.hasOwnProperty("document"))
                                object.document = $root.google.cloud.dialogflow.v2.Document.toObject(message.document, options);
                            return object;
                        };
    
                        /**
                         * Converts this CreateDocumentRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.CreateDocumentRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        CreateDocumentRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for CreateDocumentRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.CreateDocumentRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        CreateDocumentRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.CreateDocumentRequest";
                        };
    
                        return CreateDocumentRequest;
                    })();
    
                    v2.ImportDocumentsRequest = (function() {
    
                        /**
                         * Properties of an ImportDocumentsRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IImportDocumentsRequest
                         * @property {string|null} [parent] ImportDocumentsRequest parent
                         * @property {google.cloud.dialogflow.v2.IGcsSources|null} [gcsSource] ImportDocumentsRequest gcsSource
                         * @property {google.cloud.dialogflow.v2.IImportDocumentTemplate|null} [documentTemplate] ImportDocumentsRequest documentTemplate
                         * @property {boolean|null} [importGcsCustomMetadata] ImportDocumentsRequest importGcsCustomMetadata
                         */
    
                        /**
                         * Constructs a new ImportDocumentsRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an ImportDocumentsRequest.
                         * @implements IImportDocumentsRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IImportDocumentsRequest=} [properties] Properties to set
                         */
                        function ImportDocumentsRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ImportDocumentsRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.ImportDocumentsRequest
                         * @instance
                         */
                        ImportDocumentsRequest.prototype.parent = "";
    
                        /**
                         * ImportDocumentsRequest gcsSource.
                         * @member {google.cloud.dialogflow.v2.IGcsSources|null|undefined} gcsSource
                         * @memberof google.cloud.dialogflow.v2.ImportDocumentsRequest
                         * @instance
                         */
                        ImportDocumentsRequest.prototype.gcsSource = null;
    
                        /**
                         * ImportDocumentsRequest documentTemplate.
                         * @member {google.cloud.dialogflow.v2.IImportDocumentTemplate|null|undefined} documentTemplate
                         * @memberof google.cloud.dialogflow.v2.ImportDocumentsRequest
                         * @instance
                         */
                        ImportDocumentsRequest.prototype.documentTemplate = null;
    
                        /**
                         * ImportDocumentsRequest importGcsCustomMetadata.
                         * @member {boolean} importGcsCustomMetadata
                         * @memberof google.cloud.dialogflow.v2.ImportDocumentsRequest
                         * @instance
                         */
                        ImportDocumentsRequest.prototype.importGcsCustomMetadata = false;
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * ImportDocumentsRequest source.
                         * @member {"gcsSource"|undefined} source
                         * @memberof google.cloud.dialogflow.v2.ImportDocumentsRequest
                         * @instance
                         */
                        Object.defineProperty(ImportDocumentsRequest.prototype, "source", {
                            get: $util.oneOfGetter($oneOfFields = ["gcsSource"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new ImportDocumentsRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ImportDocumentsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IImportDocumentsRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ImportDocumentsRequest} ImportDocumentsRequest instance
                         */
                        ImportDocumentsRequest.create = function create(properties) {
                            return new ImportDocumentsRequest(properties);
                        };
    
                        /**
                         * Encodes the specified ImportDocumentsRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.ImportDocumentsRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ImportDocumentsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IImportDocumentsRequest} message ImportDocumentsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ImportDocumentsRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.gcsSource != null && Object.hasOwnProperty.call(message, "gcsSource"))
                                $root.google.cloud.dialogflow.v2.GcsSources.encode(message.gcsSource, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.documentTemplate != null && Object.hasOwnProperty.call(message, "documentTemplate"))
                                $root.google.cloud.dialogflow.v2.ImportDocumentTemplate.encode(message.documentTemplate, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            if (message.importGcsCustomMetadata != null && Object.hasOwnProperty.call(message, "importGcsCustomMetadata"))
                                writer.uint32(/* id 4, wireType 0 =*/32).bool(message.importGcsCustomMetadata);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ImportDocumentsRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ImportDocumentsRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ImportDocumentsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IImportDocumentsRequest} message ImportDocumentsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ImportDocumentsRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an ImportDocumentsRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ImportDocumentsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ImportDocumentsRequest} ImportDocumentsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ImportDocumentsRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ImportDocumentsRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.gcsSource = $root.google.cloud.dialogflow.v2.GcsSources.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 3: {
                                        message.documentTemplate = $root.google.cloud.dialogflow.v2.ImportDocumentTemplate.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 4: {
                                        message.importGcsCustomMetadata = reader.bool();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an ImportDocumentsRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ImportDocumentsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ImportDocumentsRequest} ImportDocumentsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ImportDocumentsRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an ImportDocumentsRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ImportDocumentsRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ImportDocumentsRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.gcsSource != null && message.hasOwnProperty("gcsSource")) {
                                properties.source = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2.GcsSources.verify(message.gcsSource);
                                    if (error)
                                        return "gcsSource." + error;
                                }
                            }
                            if (message.documentTemplate != null && message.hasOwnProperty("documentTemplate")) {
                                var error = $root.google.cloud.dialogflow.v2.ImportDocumentTemplate.verify(message.documentTemplate);
                                if (error)
                                    return "documentTemplate." + error;
                            }
                            if (message.importGcsCustomMetadata != null && message.hasOwnProperty("importGcsCustomMetadata"))
                                if (typeof message.importGcsCustomMetadata !== "boolean")
                                    return "importGcsCustomMetadata: boolean expected";
                            return null;
                        };
    
                        /**
                         * Creates an ImportDocumentsRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ImportDocumentsRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ImportDocumentsRequest} ImportDocumentsRequest
                         */
                        ImportDocumentsRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ImportDocumentsRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ImportDocumentsRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.gcsSource != null) {
                                if (typeof object.gcsSource !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.ImportDocumentsRequest.gcsSource: object expected");
                                message.gcsSource = $root.google.cloud.dialogflow.v2.GcsSources.fromObject(object.gcsSource);
                            }
                            if (object.documentTemplate != null) {
                                if (typeof object.documentTemplate !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.ImportDocumentsRequest.documentTemplate: object expected");
                                message.documentTemplate = $root.google.cloud.dialogflow.v2.ImportDocumentTemplate.fromObject(object.documentTemplate);
                            }
                            if (object.importGcsCustomMetadata != null)
                                message.importGcsCustomMetadata = Boolean(object.importGcsCustomMetadata);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an ImportDocumentsRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ImportDocumentsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ImportDocumentsRequest} message ImportDocumentsRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ImportDocumentsRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.documentTemplate = null;
                                object.importGcsCustomMetadata = false;
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.gcsSource != null && message.hasOwnProperty("gcsSource")) {
                                object.gcsSource = $root.google.cloud.dialogflow.v2.GcsSources.toObject(message.gcsSource, options);
                                if (options.oneofs)
                                    object.source = "gcsSource";
                            }
                            if (message.documentTemplate != null && message.hasOwnProperty("documentTemplate"))
                                object.documentTemplate = $root.google.cloud.dialogflow.v2.ImportDocumentTemplate.toObject(message.documentTemplate, options);
                            if (message.importGcsCustomMetadata != null && message.hasOwnProperty("importGcsCustomMetadata"))
                                object.importGcsCustomMetadata = message.importGcsCustomMetadata;
                            return object;
                        };
    
                        /**
                         * Converts this ImportDocumentsRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ImportDocumentsRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ImportDocumentsRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ImportDocumentsRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ImportDocumentsRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ImportDocumentsRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ImportDocumentsRequest";
                        };
    
                        return ImportDocumentsRequest;
                    })();
    
                    v2.ImportDocumentTemplate = (function() {
    
                        /**
                         * Properties of an ImportDocumentTemplate.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IImportDocumentTemplate
                         * @property {string|null} [mimeType] ImportDocumentTemplate mimeType
                         * @property {Array.<google.cloud.dialogflow.v2.Document.KnowledgeType>|null} [knowledgeTypes] ImportDocumentTemplate knowledgeTypes
                         * @property {Object.<string,string>|null} [metadata] ImportDocumentTemplate metadata
                         */
    
                        /**
                         * Constructs a new ImportDocumentTemplate.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an ImportDocumentTemplate.
                         * @implements IImportDocumentTemplate
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IImportDocumentTemplate=} [properties] Properties to set
                         */
                        function ImportDocumentTemplate(properties) {
                            this.knowledgeTypes = [];
                            this.metadata = {};
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ImportDocumentTemplate mimeType.
                         * @member {string} mimeType
                         * @memberof google.cloud.dialogflow.v2.ImportDocumentTemplate
                         * @instance
                         */
                        ImportDocumentTemplate.prototype.mimeType = "";
    
                        /**
                         * ImportDocumentTemplate knowledgeTypes.
                         * @member {Array.<google.cloud.dialogflow.v2.Document.KnowledgeType>} knowledgeTypes
                         * @memberof google.cloud.dialogflow.v2.ImportDocumentTemplate
                         * @instance
                         */
                        ImportDocumentTemplate.prototype.knowledgeTypes = $util.emptyArray;
    
                        /**
                         * ImportDocumentTemplate metadata.
                         * @member {Object.<string,string>} metadata
                         * @memberof google.cloud.dialogflow.v2.ImportDocumentTemplate
                         * @instance
                         */
                        ImportDocumentTemplate.prototype.metadata = $util.emptyObject;
    
                        /**
                         * Creates a new ImportDocumentTemplate instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ImportDocumentTemplate
                         * @static
                         * @param {google.cloud.dialogflow.v2.IImportDocumentTemplate=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ImportDocumentTemplate} ImportDocumentTemplate instance
                         */
                        ImportDocumentTemplate.create = function create(properties) {
                            return new ImportDocumentTemplate(properties);
                        };
    
                        /**
                         * Encodes the specified ImportDocumentTemplate message. Does not implicitly {@link google.cloud.dialogflow.v2.ImportDocumentTemplate.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ImportDocumentTemplate
                         * @static
                         * @param {google.cloud.dialogflow.v2.IImportDocumentTemplate} message ImportDocumentTemplate message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ImportDocumentTemplate.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.mimeType != null && Object.hasOwnProperty.call(message, "mimeType"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.mimeType);
                            if (message.knowledgeTypes != null && message.knowledgeTypes.length) {
                                writer.uint32(/* id 2, wireType 2 =*/18).fork();
                                for (var i = 0; i < message.knowledgeTypes.length; ++i)
                                    writer.int32(message.knowledgeTypes[i]);
                                writer.ldelim();
                            }
                            if (message.metadata != null && Object.hasOwnProperty.call(message, "metadata"))
                                for (var keys = Object.keys(message.metadata), i = 0; i < keys.length; ++i)
                                    writer.uint32(/* id 3, wireType 2 =*/26).fork().uint32(/* id 1, wireType 2 =*/10).string(keys[i]).uint32(/* id 2, wireType 2 =*/18).string(message.metadata[keys[i]]).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ImportDocumentTemplate message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ImportDocumentTemplate.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ImportDocumentTemplate
                         * @static
                         * @param {google.cloud.dialogflow.v2.IImportDocumentTemplate} message ImportDocumentTemplate message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ImportDocumentTemplate.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an ImportDocumentTemplate message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ImportDocumentTemplate
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ImportDocumentTemplate} ImportDocumentTemplate
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ImportDocumentTemplate.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ImportDocumentTemplate(), key, value;
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.mimeType = reader.string();
                                        break;
                                    }
                                case 2: {
                                        if (!(message.knowledgeTypes && message.knowledgeTypes.length))
                                            message.knowledgeTypes = [];
                                        if ((tag & 7) === 2) {
                                            var end2 = reader.uint32() + reader.pos;
                                            while (reader.pos < end2)
                                                message.knowledgeTypes.push(reader.int32());
                                        } else
                                            message.knowledgeTypes.push(reader.int32());
                                        break;
                                    }
                                case 3: {
                                        if (message.metadata === $util.emptyObject)
                                            message.metadata = {};
                                        var end2 = reader.uint32() + reader.pos;
                                        key = "";
                                        value = "";
                                        while (reader.pos < end2) {
                                            var tag2 = reader.uint32();
                                            switch (tag2 >>> 3) {
                                            case 1:
                                                key = reader.string();
                                                break;
                                            case 2:
                                                value = reader.string();
                                                break;
                                            default:
                                                reader.skipType(tag2 & 7);
                                                break;
                                            }
                                        }
                                        message.metadata[key] = value;
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an ImportDocumentTemplate message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ImportDocumentTemplate
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ImportDocumentTemplate} ImportDocumentTemplate
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ImportDocumentTemplate.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an ImportDocumentTemplate message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ImportDocumentTemplate
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ImportDocumentTemplate.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.mimeType != null && message.hasOwnProperty("mimeType"))
                                if (!$util.isString(message.mimeType))
                                    return "mimeType: string expected";
                            if (message.knowledgeTypes != null && message.hasOwnProperty("knowledgeTypes")) {
                                if (!Array.isArray(message.knowledgeTypes))
                                    return "knowledgeTypes: array expected";
                                for (var i = 0; i < message.knowledgeTypes.length; ++i)
                                    switch (message.knowledgeTypes[i]) {
                                    default:
                                        return "knowledgeTypes: enum value[] expected";
                                    case 0:
                                    case 1:
                                    case 2:
                                    case 3:
                                    case 4:
                                        break;
                                    }
                            }
                            if (message.metadata != null && message.hasOwnProperty("metadata")) {
                                if (!$util.isObject(message.metadata))
                                    return "metadata: object expected";
                                var key = Object.keys(message.metadata);
                                for (var i = 0; i < key.length; ++i)
                                    if (!$util.isString(message.metadata[key[i]]))
                                        return "metadata: string{k:string} expected";
                            }
                            return null;
                        };
    
                        /**
                         * Creates an ImportDocumentTemplate message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ImportDocumentTemplate
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ImportDocumentTemplate} ImportDocumentTemplate
                         */
                        ImportDocumentTemplate.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ImportDocumentTemplate)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ImportDocumentTemplate();
                            if (object.mimeType != null)
                                message.mimeType = String(object.mimeType);
                            if (object.knowledgeTypes) {
                                if (!Array.isArray(object.knowledgeTypes))
                                    throw TypeError(".google.cloud.dialogflow.v2.ImportDocumentTemplate.knowledgeTypes: array expected");
                                message.knowledgeTypes = [];
                                for (var i = 0; i < object.knowledgeTypes.length; ++i)
                                    switch (object.knowledgeTypes[i]) {
                                    default:
                                        if (typeof object.knowledgeTypes[i] === "number") {
                                            message.knowledgeTypes[i] = object.knowledgeTypes[i];
                                            break;
                                        }
                                    case "KNOWLEDGE_TYPE_UNSPECIFIED":
                                    case 0:
                                        message.knowledgeTypes[i] = 0;
                                        break;
                                    case "FAQ":
                                    case 1:
                                        message.knowledgeTypes[i] = 1;
                                        break;
                                    case "EXTRACTIVE_QA":
                                    case 2:
                                        message.knowledgeTypes[i] = 2;
                                        break;
                                    case "ARTICLE_SUGGESTION":
                                    case 3:
                                        message.knowledgeTypes[i] = 3;
                                        break;
                                    case "AGENT_FACING_SMART_REPLY":
                                    case 4:
                                        message.knowledgeTypes[i] = 4;
                                        break;
                                    }
                            }
                            if (object.metadata) {
                                if (typeof object.metadata !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.ImportDocumentTemplate.metadata: object expected");
                                message.metadata = {};
                                for (var keys = Object.keys(object.metadata), i = 0; i < keys.length; ++i)
                                    message.metadata[keys[i]] = String(object.metadata[keys[i]]);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an ImportDocumentTemplate message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ImportDocumentTemplate
                         * @static
                         * @param {google.cloud.dialogflow.v2.ImportDocumentTemplate} message ImportDocumentTemplate
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ImportDocumentTemplate.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.knowledgeTypes = [];
                            if (options.objects || options.defaults)
                                object.metadata = {};
                            if (options.defaults)
                                object.mimeType = "";
                            if (message.mimeType != null && message.hasOwnProperty("mimeType"))
                                object.mimeType = message.mimeType;
                            if (message.knowledgeTypes && message.knowledgeTypes.length) {
                                object.knowledgeTypes = [];
                                for (var j = 0; j < message.knowledgeTypes.length; ++j)
                                    object.knowledgeTypes[j] = options.enums === String ? $root.google.cloud.dialogflow.v2.Document.KnowledgeType[message.knowledgeTypes[j]] === undefined ? message.knowledgeTypes[j] : $root.google.cloud.dialogflow.v2.Document.KnowledgeType[message.knowledgeTypes[j]] : message.knowledgeTypes[j];
                            }
                            var keys2;
                            if (message.metadata && (keys2 = Object.keys(message.metadata)).length) {
                                object.metadata = {};
                                for (var j = 0; j < keys2.length; ++j)
                                    object.metadata[keys2[j]] = message.metadata[keys2[j]];
                            }
                            return object;
                        };
    
                        /**
                         * Converts this ImportDocumentTemplate to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ImportDocumentTemplate
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ImportDocumentTemplate.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ImportDocumentTemplate
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ImportDocumentTemplate
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ImportDocumentTemplate.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ImportDocumentTemplate";
                        };
    
                        return ImportDocumentTemplate;
                    })();
    
                    v2.ImportDocumentsResponse = (function() {
    
                        /**
                         * Properties of an ImportDocumentsResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IImportDocumentsResponse
                         * @property {Array.<google.rpc.IStatus>|null} [warnings] ImportDocumentsResponse warnings
                         */
    
                        /**
                         * Constructs a new ImportDocumentsResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an ImportDocumentsResponse.
                         * @implements IImportDocumentsResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IImportDocumentsResponse=} [properties] Properties to set
                         */
                        function ImportDocumentsResponse(properties) {
                            this.warnings = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ImportDocumentsResponse warnings.
                         * @member {Array.<google.rpc.IStatus>} warnings
                         * @memberof google.cloud.dialogflow.v2.ImportDocumentsResponse
                         * @instance
                         */
                        ImportDocumentsResponse.prototype.warnings = $util.emptyArray;
    
                        /**
                         * Creates a new ImportDocumentsResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ImportDocumentsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IImportDocumentsResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ImportDocumentsResponse} ImportDocumentsResponse instance
                         */
                        ImportDocumentsResponse.create = function create(properties) {
                            return new ImportDocumentsResponse(properties);
                        };
    
                        /**
                         * Encodes the specified ImportDocumentsResponse message. Does not implicitly {@link google.cloud.dialogflow.v2.ImportDocumentsResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ImportDocumentsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IImportDocumentsResponse} message ImportDocumentsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ImportDocumentsResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.warnings != null && message.warnings.length)
                                for (var i = 0; i < message.warnings.length; ++i)
                                    $root.google.rpc.Status.encode(message.warnings[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ImportDocumentsResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ImportDocumentsResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ImportDocumentsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IImportDocumentsResponse} message ImportDocumentsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ImportDocumentsResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an ImportDocumentsResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ImportDocumentsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ImportDocumentsResponse} ImportDocumentsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ImportDocumentsResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ImportDocumentsResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.warnings && message.warnings.length))
                                            message.warnings = [];
                                        message.warnings.push($root.google.rpc.Status.decode(reader, reader.uint32()));
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an ImportDocumentsResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ImportDocumentsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ImportDocumentsResponse} ImportDocumentsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ImportDocumentsResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an ImportDocumentsResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ImportDocumentsResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ImportDocumentsResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.warnings != null && message.hasOwnProperty("warnings")) {
                                if (!Array.isArray(message.warnings))
                                    return "warnings: array expected";
                                for (var i = 0; i < message.warnings.length; ++i) {
                                    var error = $root.google.rpc.Status.verify(message.warnings[i]);
                                    if (error)
                                        return "warnings." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates an ImportDocumentsResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ImportDocumentsResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ImportDocumentsResponse} ImportDocumentsResponse
                         */
                        ImportDocumentsResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ImportDocumentsResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ImportDocumentsResponse();
                            if (object.warnings) {
                                if (!Array.isArray(object.warnings))
                                    throw TypeError(".google.cloud.dialogflow.v2.ImportDocumentsResponse.warnings: array expected");
                                message.warnings = [];
                                for (var i = 0; i < object.warnings.length; ++i) {
                                    if (typeof object.warnings[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.ImportDocumentsResponse.warnings: object expected");
                                    message.warnings[i] = $root.google.rpc.Status.fromObject(object.warnings[i]);
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an ImportDocumentsResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ImportDocumentsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.ImportDocumentsResponse} message ImportDocumentsResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ImportDocumentsResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.warnings = [];
                            if (message.warnings && message.warnings.length) {
                                object.warnings = [];
                                for (var j = 0; j < message.warnings.length; ++j)
                                    object.warnings[j] = $root.google.rpc.Status.toObject(message.warnings[j], options);
                            }
                            return object;
                        };
    
                        /**
                         * Converts this ImportDocumentsResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ImportDocumentsResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ImportDocumentsResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ImportDocumentsResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ImportDocumentsResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ImportDocumentsResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ImportDocumentsResponse";
                        };
    
                        return ImportDocumentsResponse;
                    })();
    
                    v2.DeleteDocumentRequest = (function() {
    
                        /**
                         * Properties of a DeleteDocumentRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IDeleteDocumentRequest
                         * @property {string|null} [name] DeleteDocumentRequest name
                         */
    
                        /**
                         * Constructs a new DeleteDocumentRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a DeleteDocumentRequest.
                         * @implements IDeleteDocumentRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IDeleteDocumentRequest=} [properties] Properties to set
                         */
                        function DeleteDocumentRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * DeleteDocumentRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2.DeleteDocumentRequest
                         * @instance
                         */
                        DeleteDocumentRequest.prototype.name = "";
    
                        /**
                         * Creates a new DeleteDocumentRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.DeleteDocumentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDeleteDocumentRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.DeleteDocumentRequest} DeleteDocumentRequest instance
                         */
                        DeleteDocumentRequest.create = function create(properties) {
                            return new DeleteDocumentRequest(properties);
                        };
    
                        /**
                         * Encodes the specified DeleteDocumentRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.DeleteDocumentRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.DeleteDocumentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDeleteDocumentRequest} message DeleteDocumentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteDocumentRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified DeleteDocumentRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.DeleteDocumentRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.DeleteDocumentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDeleteDocumentRequest} message DeleteDocumentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteDocumentRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a DeleteDocumentRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.DeleteDocumentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.DeleteDocumentRequest} DeleteDocumentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteDocumentRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.DeleteDocumentRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a DeleteDocumentRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.DeleteDocumentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.DeleteDocumentRequest} DeleteDocumentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteDocumentRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a DeleteDocumentRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.DeleteDocumentRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        DeleteDocumentRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a DeleteDocumentRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.DeleteDocumentRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.DeleteDocumentRequest} DeleteDocumentRequest
                         */
                        DeleteDocumentRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.DeleteDocumentRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.DeleteDocumentRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a DeleteDocumentRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.DeleteDocumentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.DeleteDocumentRequest} message DeleteDocumentRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        DeleteDocumentRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.name = "";
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            return object;
                        };
    
                        /**
                         * Converts this DeleteDocumentRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.DeleteDocumentRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        DeleteDocumentRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for DeleteDocumentRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.DeleteDocumentRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        DeleteDocumentRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.DeleteDocumentRequest";
                        };
    
                        return DeleteDocumentRequest;
                    })();
    
                    v2.UpdateDocumentRequest = (function() {
    
                        /**
                         * Properties of an UpdateDocumentRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IUpdateDocumentRequest
                         * @property {google.cloud.dialogflow.v2.IDocument|null} [document] UpdateDocumentRequest document
                         * @property {google.protobuf.IFieldMask|null} [updateMask] UpdateDocumentRequest updateMask
                         */
    
                        /**
                         * Constructs a new UpdateDocumentRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an UpdateDocumentRequest.
                         * @implements IUpdateDocumentRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IUpdateDocumentRequest=} [properties] Properties to set
                         */
                        function UpdateDocumentRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * UpdateDocumentRequest document.
                         * @member {google.cloud.dialogflow.v2.IDocument|null|undefined} document
                         * @memberof google.cloud.dialogflow.v2.UpdateDocumentRequest
                         * @instance
                         */
                        UpdateDocumentRequest.prototype.document = null;
    
                        /**
                         * UpdateDocumentRequest updateMask.
                         * @member {google.protobuf.IFieldMask|null|undefined} updateMask
                         * @memberof google.cloud.dialogflow.v2.UpdateDocumentRequest
                         * @instance
                         */
                        UpdateDocumentRequest.prototype.updateMask = null;
    
                        /**
                         * Creates a new UpdateDocumentRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.UpdateDocumentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IUpdateDocumentRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.UpdateDocumentRequest} UpdateDocumentRequest instance
                         */
                        UpdateDocumentRequest.create = function create(properties) {
                            return new UpdateDocumentRequest(properties);
                        };
    
                        /**
                         * Encodes the specified UpdateDocumentRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.UpdateDocumentRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.UpdateDocumentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IUpdateDocumentRequest} message UpdateDocumentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UpdateDocumentRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.document != null && Object.hasOwnProperty.call(message, "document"))
                                $root.google.cloud.dialogflow.v2.Document.encode(message.document, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.updateMask != null && Object.hasOwnProperty.call(message, "updateMask"))
                                $root.google.protobuf.FieldMask.encode(message.updateMask, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified UpdateDocumentRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.UpdateDocumentRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.UpdateDocumentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IUpdateDocumentRequest} message UpdateDocumentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UpdateDocumentRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an UpdateDocumentRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.UpdateDocumentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.UpdateDocumentRequest} UpdateDocumentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UpdateDocumentRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.UpdateDocumentRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.document = $root.google.cloud.dialogflow.v2.Document.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.updateMask = $root.google.protobuf.FieldMask.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an UpdateDocumentRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.UpdateDocumentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.UpdateDocumentRequest} UpdateDocumentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UpdateDocumentRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an UpdateDocumentRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.UpdateDocumentRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        UpdateDocumentRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.document != null && message.hasOwnProperty("document")) {
                                var error = $root.google.cloud.dialogflow.v2.Document.verify(message.document);
                                if (error)
                                    return "document." + error;
                            }
                            if (message.updateMask != null && message.hasOwnProperty("updateMask")) {
                                var error = $root.google.protobuf.FieldMask.verify(message.updateMask);
                                if (error)
                                    return "updateMask." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates an UpdateDocumentRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.UpdateDocumentRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.UpdateDocumentRequest} UpdateDocumentRequest
                         */
                        UpdateDocumentRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.UpdateDocumentRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.UpdateDocumentRequest();
                            if (object.document != null) {
                                if (typeof object.document !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.UpdateDocumentRequest.document: object expected");
                                message.document = $root.google.cloud.dialogflow.v2.Document.fromObject(object.document);
                            }
                            if (object.updateMask != null) {
                                if (typeof object.updateMask !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.UpdateDocumentRequest.updateMask: object expected");
                                message.updateMask = $root.google.protobuf.FieldMask.fromObject(object.updateMask);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an UpdateDocumentRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.UpdateDocumentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.UpdateDocumentRequest} message UpdateDocumentRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        UpdateDocumentRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.document = null;
                                object.updateMask = null;
                            }
                            if (message.document != null && message.hasOwnProperty("document"))
                                object.document = $root.google.cloud.dialogflow.v2.Document.toObject(message.document, options);
                            if (message.updateMask != null && message.hasOwnProperty("updateMask"))
                                object.updateMask = $root.google.protobuf.FieldMask.toObject(message.updateMask, options);
                            return object;
                        };
    
                        /**
                         * Converts this UpdateDocumentRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.UpdateDocumentRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        UpdateDocumentRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for UpdateDocumentRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.UpdateDocumentRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        UpdateDocumentRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.UpdateDocumentRequest";
                        };
    
                        return UpdateDocumentRequest;
                    })();
    
                    v2.ReloadDocumentRequest = (function() {
    
                        /**
                         * Properties of a ReloadDocumentRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IReloadDocumentRequest
                         * @property {string|null} [name] ReloadDocumentRequest name
                         * @property {string|null} [contentUri] ReloadDocumentRequest contentUri
                         * @property {boolean|null} [importGcsCustomMetadata] ReloadDocumentRequest importGcsCustomMetadata
                         * @property {boolean|null} [smartMessagingPartialUpdate] ReloadDocumentRequest smartMessagingPartialUpdate
                         */
    
                        /**
                         * Constructs a new ReloadDocumentRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a ReloadDocumentRequest.
                         * @implements IReloadDocumentRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IReloadDocumentRequest=} [properties] Properties to set
                         */
                        function ReloadDocumentRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ReloadDocumentRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2.ReloadDocumentRequest
                         * @instance
                         */
                        ReloadDocumentRequest.prototype.name = "";
    
                        /**
                         * ReloadDocumentRequest contentUri.
                         * @member {string|null|undefined} contentUri
                         * @memberof google.cloud.dialogflow.v2.ReloadDocumentRequest
                         * @instance
                         */
                        ReloadDocumentRequest.prototype.contentUri = null;
    
                        /**
                         * ReloadDocumentRequest importGcsCustomMetadata.
                         * @member {boolean} importGcsCustomMetadata
                         * @memberof google.cloud.dialogflow.v2.ReloadDocumentRequest
                         * @instance
                         */
                        ReloadDocumentRequest.prototype.importGcsCustomMetadata = false;
    
                        /**
                         * ReloadDocumentRequest smartMessagingPartialUpdate.
                         * @member {boolean} smartMessagingPartialUpdate
                         * @memberof google.cloud.dialogflow.v2.ReloadDocumentRequest
                         * @instance
                         */
                        ReloadDocumentRequest.prototype.smartMessagingPartialUpdate = false;
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * ReloadDocumentRequest source.
                         * @member {"contentUri"|undefined} source
                         * @memberof google.cloud.dialogflow.v2.ReloadDocumentRequest
                         * @instance
                         */
                        Object.defineProperty(ReloadDocumentRequest.prototype, "source", {
                            get: $util.oneOfGetter($oneOfFields = ["contentUri"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new ReloadDocumentRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ReloadDocumentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IReloadDocumentRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ReloadDocumentRequest} ReloadDocumentRequest instance
                         */
                        ReloadDocumentRequest.create = function create(properties) {
                            return new ReloadDocumentRequest(properties);
                        };
    
                        /**
                         * Encodes the specified ReloadDocumentRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.ReloadDocumentRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ReloadDocumentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IReloadDocumentRequest} message ReloadDocumentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ReloadDocumentRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            if (message.contentUri != null && Object.hasOwnProperty.call(message, "contentUri"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.contentUri);
                            if (message.importGcsCustomMetadata != null && Object.hasOwnProperty.call(message, "importGcsCustomMetadata"))
                                writer.uint32(/* id 4, wireType 0 =*/32).bool(message.importGcsCustomMetadata);
                            if (message.smartMessagingPartialUpdate != null && Object.hasOwnProperty.call(message, "smartMessagingPartialUpdate"))
                                writer.uint32(/* id 5, wireType 0 =*/40).bool(message.smartMessagingPartialUpdate);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ReloadDocumentRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ReloadDocumentRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ReloadDocumentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IReloadDocumentRequest} message ReloadDocumentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ReloadDocumentRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ReloadDocumentRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ReloadDocumentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ReloadDocumentRequest} ReloadDocumentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ReloadDocumentRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ReloadDocumentRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.contentUri = reader.string();
                                        break;
                                    }
                                case 4: {
                                        message.importGcsCustomMetadata = reader.bool();
                                        break;
                                    }
                                case 5: {
                                        message.smartMessagingPartialUpdate = reader.bool();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ReloadDocumentRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ReloadDocumentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ReloadDocumentRequest} ReloadDocumentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ReloadDocumentRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ReloadDocumentRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ReloadDocumentRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ReloadDocumentRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            if (message.contentUri != null && message.hasOwnProperty("contentUri")) {
                                properties.source = 1;
                                if (!$util.isString(message.contentUri))
                                    return "contentUri: string expected";
                            }
                            if (message.importGcsCustomMetadata != null && message.hasOwnProperty("importGcsCustomMetadata"))
                                if (typeof message.importGcsCustomMetadata !== "boolean")
                                    return "importGcsCustomMetadata: boolean expected";
                            if (message.smartMessagingPartialUpdate != null && message.hasOwnProperty("smartMessagingPartialUpdate"))
                                if (typeof message.smartMessagingPartialUpdate !== "boolean")
                                    return "smartMessagingPartialUpdate: boolean expected";
                            return null;
                        };
    
                        /**
                         * Creates a ReloadDocumentRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ReloadDocumentRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ReloadDocumentRequest} ReloadDocumentRequest
                         */
                        ReloadDocumentRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ReloadDocumentRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ReloadDocumentRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            if (object.contentUri != null)
                                message.contentUri = String(object.contentUri);
                            if (object.importGcsCustomMetadata != null)
                                message.importGcsCustomMetadata = Boolean(object.importGcsCustomMetadata);
                            if (object.smartMessagingPartialUpdate != null)
                                message.smartMessagingPartialUpdate = Boolean(object.smartMessagingPartialUpdate);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ReloadDocumentRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ReloadDocumentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ReloadDocumentRequest} message ReloadDocumentRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ReloadDocumentRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.name = "";
                                object.importGcsCustomMetadata = false;
                                object.smartMessagingPartialUpdate = false;
                            }
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            if (message.contentUri != null && message.hasOwnProperty("contentUri")) {
                                object.contentUri = message.contentUri;
                                if (options.oneofs)
                                    object.source = "contentUri";
                            }
                            if (message.importGcsCustomMetadata != null && message.hasOwnProperty("importGcsCustomMetadata"))
                                object.importGcsCustomMetadata = message.importGcsCustomMetadata;
                            if (message.smartMessagingPartialUpdate != null && message.hasOwnProperty("smartMessagingPartialUpdate"))
                                object.smartMessagingPartialUpdate = message.smartMessagingPartialUpdate;
                            return object;
                        };
    
                        /**
                         * Converts this ReloadDocumentRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ReloadDocumentRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ReloadDocumentRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ReloadDocumentRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ReloadDocumentRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ReloadDocumentRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ReloadDocumentRequest";
                        };
    
                        return ReloadDocumentRequest;
                    })();
    
                    v2.ExportDocumentRequest = (function() {
    
                        /**
                         * Properties of an ExportDocumentRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IExportDocumentRequest
                         * @property {string|null} [name] ExportDocumentRequest name
                         * @property {google.cloud.dialogflow.v2.IGcsDestination|null} [gcsDestination] ExportDocumentRequest gcsDestination
                         * @property {boolean|null} [exportFullContent] ExportDocumentRequest exportFullContent
                         * @property {boolean|null} [smartMessagingPartialUpdate] ExportDocumentRequest smartMessagingPartialUpdate
                         */
    
                        /**
                         * Constructs a new ExportDocumentRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an ExportDocumentRequest.
                         * @implements IExportDocumentRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IExportDocumentRequest=} [properties] Properties to set
                         */
                        function ExportDocumentRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ExportDocumentRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2.ExportDocumentRequest
                         * @instance
                         */
                        ExportDocumentRequest.prototype.name = "";
    
                        /**
                         * ExportDocumentRequest gcsDestination.
                         * @member {google.cloud.dialogflow.v2.IGcsDestination|null|undefined} gcsDestination
                         * @memberof google.cloud.dialogflow.v2.ExportDocumentRequest
                         * @instance
                         */
                        ExportDocumentRequest.prototype.gcsDestination = null;
    
                        /**
                         * ExportDocumentRequest exportFullContent.
                         * @member {boolean} exportFullContent
                         * @memberof google.cloud.dialogflow.v2.ExportDocumentRequest
                         * @instance
                         */
                        ExportDocumentRequest.prototype.exportFullContent = false;
    
                        /**
                         * ExportDocumentRequest smartMessagingPartialUpdate.
                         * @member {boolean} smartMessagingPartialUpdate
                         * @memberof google.cloud.dialogflow.v2.ExportDocumentRequest
                         * @instance
                         */
                        ExportDocumentRequest.prototype.smartMessagingPartialUpdate = false;
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * ExportDocumentRequest destination.
                         * @member {"gcsDestination"|undefined} destination
                         * @memberof google.cloud.dialogflow.v2.ExportDocumentRequest
                         * @instance
                         */
                        Object.defineProperty(ExportDocumentRequest.prototype, "destination", {
                            get: $util.oneOfGetter($oneOfFields = ["gcsDestination"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new ExportDocumentRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ExportDocumentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IExportDocumentRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ExportDocumentRequest} ExportDocumentRequest instance
                         */
                        ExportDocumentRequest.create = function create(properties) {
                            return new ExportDocumentRequest(properties);
                        };
    
                        /**
                         * Encodes the specified ExportDocumentRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.ExportDocumentRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ExportDocumentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IExportDocumentRequest} message ExportDocumentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ExportDocumentRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            if (message.gcsDestination != null && Object.hasOwnProperty.call(message, "gcsDestination"))
                                $root.google.cloud.dialogflow.v2.GcsDestination.encode(message.gcsDestination, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.exportFullContent != null && Object.hasOwnProperty.call(message, "exportFullContent"))
                                writer.uint32(/* id 3, wireType 0 =*/24).bool(message.exportFullContent);
                            if (message.smartMessagingPartialUpdate != null && Object.hasOwnProperty.call(message, "smartMessagingPartialUpdate"))
                                writer.uint32(/* id 5, wireType 0 =*/40).bool(message.smartMessagingPartialUpdate);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ExportDocumentRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ExportDocumentRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ExportDocumentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IExportDocumentRequest} message ExportDocumentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ExportDocumentRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an ExportDocumentRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ExportDocumentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ExportDocumentRequest} ExportDocumentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ExportDocumentRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ExportDocumentRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.gcsDestination = $root.google.cloud.dialogflow.v2.GcsDestination.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 3: {
                                        message.exportFullContent = reader.bool();
                                        break;
                                    }
                                case 5: {
                                        message.smartMessagingPartialUpdate = reader.bool();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an ExportDocumentRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ExportDocumentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ExportDocumentRequest} ExportDocumentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ExportDocumentRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an ExportDocumentRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ExportDocumentRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ExportDocumentRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            if (message.gcsDestination != null && message.hasOwnProperty("gcsDestination")) {
                                properties.destination = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2.GcsDestination.verify(message.gcsDestination);
                                    if (error)
                                        return "gcsDestination." + error;
                                }
                            }
                            if (message.exportFullContent != null && message.hasOwnProperty("exportFullContent"))
                                if (typeof message.exportFullContent !== "boolean")
                                    return "exportFullContent: boolean expected";
                            if (message.smartMessagingPartialUpdate != null && message.hasOwnProperty("smartMessagingPartialUpdate"))
                                if (typeof message.smartMessagingPartialUpdate !== "boolean")
                                    return "smartMessagingPartialUpdate: boolean expected";
                            return null;
                        };
    
                        /**
                         * Creates an ExportDocumentRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ExportDocumentRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ExportDocumentRequest} ExportDocumentRequest
                         */
                        ExportDocumentRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ExportDocumentRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ExportDocumentRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            if (object.gcsDestination != null) {
                                if (typeof object.gcsDestination !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.ExportDocumentRequest.gcsDestination: object expected");
                                message.gcsDestination = $root.google.cloud.dialogflow.v2.GcsDestination.fromObject(object.gcsDestination);
                            }
                            if (object.exportFullContent != null)
                                message.exportFullContent = Boolean(object.exportFullContent);
                            if (object.smartMessagingPartialUpdate != null)
                                message.smartMessagingPartialUpdate = Boolean(object.smartMessagingPartialUpdate);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an ExportDocumentRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ExportDocumentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ExportDocumentRequest} message ExportDocumentRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ExportDocumentRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.name = "";
                                object.exportFullContent = false;
                                object.smartMessagingPartialUpdate = false;
                            }
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            if (message.gcsDestination != null && message.hasOwnProperty("gcsDestination")) {
                                object.gcsDestination = $root.google.cloud.dialogflow.v2.GcsDestination.toObject(message.gcsDestination, options);
                                if (options.oneofs)
                                    object.destination = "gcsDestination";
                            }
                            if (message.exportFullContent != null && message.hasOwnProperty("exportFullContent"))
                                object.exportFullContent = message.exportFullContent;
                            if (message.smartMessagingPartialUpdate != null && message.hasOwnProperty("smartMessagingPartialUpdate"))
                                object.smartMessagingPartialUpdate = message.smartMessagingPartialUpdate;
                            return object;
                        };
    
                        /**
                         * Converts this ExportDocumentRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ExportDocumentRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ExportDocumentRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ExportDocumentRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ExportDocumentRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ExportDocumentRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ExportDocumentRequest";
                        };
    
                        return ExportDocumentRequest;
                    })();
    
                    v2.ExportOperationMetadata = (function() {
    
                        /**
                         * Properties of an ExportOperationMetadata.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IExportOperationMetadata
                         * @property {google.cloud.dialogflow.v2.IGcsDestination|null} [exportedGcsDestination] ExportOperationMetadata exportedGcsDestination
                         */
    
                        /**
                         * Constructs a new ExportOperationMetadata.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an ExportOperationMetadata.
                         * @implements IExportOperationMetadata
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IExportOperationMetadata=} [properties] Properties to set
                         */
                        function ExportOperationMetadata(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ExportOperationMetadata exportedGcsDestination.
                         * @member {google.cloud.dialogflow.v2.IGcsDestination|null|undefined} exportedGcsDestination
                         * @memberof google.cloud.dialogflow.v2.ExportOperationMetadata
                         * @instance
                         */
                        ExportOperationMetadata.prototype.exportedGcsDestination = null;
    
                        /**
                         * Creates a new ExportOperationMetadata instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ExportOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.IExportOperationMetadata=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ExportOperationMetadata} ExportOperationMetadata instance
                         */
                        ExportOperationMetadata.create = function create(properties) {
                            return new ExportOperationMetadata(properties);
                        };
    
                        /**
                         * Encodes the specified ExportOperationMetadata message. Does not implicitly {@link google.cloud.dialogflow.v2.ExportOperationMetadata.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ExportOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.IExportOperationMetadata} message ExportOperationMetadata message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ExportOperationMetadata.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.exportedGcsDestination != null && Object.hasOwnProperty.call(message, "exportedGcsDestination"))
                                $root.google.cloud.dialogflow.v2.GcsDestination.encode(message.exportedGcsDestination, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ExportOperationMetadata message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ExportOperationMetadata.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ExportOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.IExportOperationMetadata} message ExportOperationMetadata message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ExportOperationMetadata.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an ExportOperationMetadata message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ExportOperationMetadata
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ExportOperationMetadata} ExportOperationMetadata
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ExportOperationMetadata.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ExportOperationMetadata();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.exportedGcsDestination = $root.google.cloud.dialogflow.v2.GcsDestination.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an ExportOperationMetadata message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ExportOperationMetadata
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ExportOperationMetadata} ExportOperationMetadata
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ExportOperationMetadata.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an ExportOperationMetadata message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ExportOperationMetadata
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ExportOperationMetadata.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.exportedGcsDestination != null && message.hasOwnProperty("exportedGcsDestination")) {
                                var error = $root.google.cloud.dialogflow.v2.GcsDestination.verify(message.exportedGcsDestination);
                                if (error)
                                    return "exportedGcsDestination." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates an ExportOperationMetadata message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ExportOperationMetadata
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ExportOperationMetadata} ExportOperationMetadata
                         */
                        ExportOperationMetadata.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ExportOperationMetadata)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ExportOperationMetadata();
                            if (object.exportedGcsDestination != null) {
                                if (typeof object.exportedGcsDestination !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.ExportOperationMetadata.exportedGcsDestination: object expected");
                                message.exportedGcsDestination = $root.google.cloud.dialogflow.v2.GcsDestination.fromObject(object.exportedGcsDestination);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an ExportOperationMetadata message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ExportOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.ExportOperationMetadata} message ExportOperationMetadata
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ExportOperationMetadata.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.exportedGcsDestination = null;
                            if (message.exportedGcsDestination != null && message.hasOwnProperty("exportedGcsDestination"))
                                object.exportedGcsDestination = $root.google.cloud.dialogflow.v2.GcsDestination.toObject(message.exportedGcsDestination, options);
                            return object;
                        };
    
                        /**
                         * Converts this ExportOperationMetadata to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ExportOperationMetadata
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ExportOperationMetadata.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ExportOperationMetadata
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ExportOperationMetadata
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ExportOperationMetadata.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ExportOperationMetadata";
                        };
    
                        return ExportOperationMetadata;
                    })();
    
                    v2.KnowledgeOperationMetadata = (function() {
    
                        /**
                         * Properties of a KnowledgeOperationMetadata.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IKnowledgeOperationMetadata
                         * @property {google.cloud.dialogflow.v2.KnowledgeOperationMetadata.State|null} [state] KnowledgeOperationMetadata state
                         * @property {string|null} [knowledgeBase] KnowledgeOperationMetadata knowledgeBase
                         * @property {google.cloud.dialogflow.v2.IExportOperationMetadata|null} [exportOperationMetadata] KnowledgeOperationMetadata exportOperationMetadata
                         */
    
                        /**
                         * Constructs a new KnowledgeOperationMetadata.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a KnowledgeOperationMetadata.
                         * @implements IKnowledgeOperationMetadata
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IKnowledgeOperationMetadata=} [properties] Properties to set
                         */
                        function KnowledgeOperationMetadata(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * KnowledgeOperationMetadata state.
                         * @member {google.cloud.dialogflow.v2.KnowledgeOperationMetadata.State} state
                         * @memberof google.cloud.dialogflow.v2.KnowledgeOperationMetadata
                         * @instance
                         */
                        KnowledgeOperationMetadata.prototype.state = 0;
    
                        /**
                         * KnowledgeOperationMetadata knowledgeBase.
                         * @member {string} knowledgeBase
                         * @memberof google.cloud.dialogflow.v2.KnowledgeOperationMetadata
                         * @instance
                         */
                        KnowledgeOperationMetadata.prototype.knowledgeBase = "";
    
                        /**
                         * KnowledgeOperationMetadata exportOperationMetadata.
                         * @member {google.cloud.dialogflow.v2.IExportOperationMetadata|null|undefined} exportOperationMetadata
                         * @memberof google.cloud.dialogflow.v2.KnowledgeOperationMetadata
                         * @instance
                         */
                        KnowledgeOperationMetadata.prototype.exportOperationMetadata = null;
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * KnowledgeOperationMetadata operationMetadata.
                         * @member {"exportOperationMetadata"|undefined} operationMetadata
                         * @memberof google.cloud.dialogflow.v2.KnowledgeOperationMetadata
                         * @instance
                         */
                        Object.defineProperty(KnowledgeOperationMetadata.prototype, "operationMetadata", {
                            get: $util.oneOfGetter($oneOfFields = ["exportOperationMetadata"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new KnowledgeOperationMetadata instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.KnowledgeOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.IKnowledgeOperationMetadata=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.KnowledgeOperationMetadata} KnowledgeOperationMetadata instance
                         */
                        KnowledgeOperationMetadata.create = function create(properties) {
                            return new KnowledgeOperationMetadata(properties);
                        };
    
                        /**
                         * Encodes the specified KnowledgeOperationMetadata message. Does not implicitly {@link google.cloud.dialogflow.v2.KnowledgeOperationMetadata.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.KnowledgeOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.IKnowledgeOperationMetadata} message KnowledgeOperationMetadata message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        KnowledgeOperationMetadata.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.state != null && Object.hasOwnProperty.call(message, "state"))
                                writer.uint32(/* id 1, wireType 0 =*/8).int32(message.state);
                            if (message.knowledgeBase != null && Object.hasOwnProperty.call(message, "knowledgeBase"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.knowledgeBase);
                            if (message.exportOperationMetadata != null && Object.hasOwnProperty.call(message, "exportOperationMetadata"))
                                $root.google.cloud.dialogflow.v2.ExportOperationMetadata.encode(message.exportOperationMetadata, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified KnowledgeOperationMetadata message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.KnowledgeOperationMetadata.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.KnowledgeOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.IKnowledgeOperationMetadata} message KnowledgeOperationMetadata message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        KnowledgeOperationMetadata.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a KnowledgeOperationMetadata message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.KnowledgeOperationMetadata
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.KnowledgeOperationMetadata} KnowledgeOperationMetadata
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        KnowledgeOperationMetadata.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.KnowledgeOperationMetadata();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.state = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.knowledgeBase = reader.string();
                                        break;
                                    }
                                case 4: {
                                        message.exportOperationMetadata = $root.google.cloud.dialogflow.v2.ExportOperationMetadata.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a KnowledgeOperationMetadata message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.KnowledgeOperationMetadata
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.KnowledgeOperationMetadata} KnowledgeOperationMetadata
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        KnowledgeOperationMetadata.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a KnowledgeOperationMetadata message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.KnowledgeOperationMetadata
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        KnowledgeOperationMetadata.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.state != null && message.hasOwnProperty("state"))
                                switch (message.state) {
                                default:
                                    return "state: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                    break;
                                }
                            if (message.knowledgeBase != null && message.hasOwnProperty("knowledgeBase"))
                                if (!$util.isString(message.knowledgeBase))
                                    return "knowledgeBase: string expected";
                            if (message.exportOperationMetadata != null && message.hasOwnProperty("exportOperationMetadata")) {
                                properties.operationMetadata = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2.ExportOperationMetadata.verify(message.exportOperationMetadata);
                                    if (error)
                                        return "exportOperationMetadata." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates a KnowledgeOperationMetadata message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.KnowledgeOperationMetadata
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.KnowledgeOperationMetadata} KnowledgeOperationMetadata
                         */
                        KnowledgeOperationMetadata.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.KnowledgeOperationMetadata)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.KnowledgeOperationMetadata();
                            switch (object.state) {
                            default:
                                if (typeof object.state === "number") {
                                    message.state = object.state;
                                    break;
                                }
                                break;
                            case "STATE_UNSPECIFIED":
                            case 0:
                                message.state = 0;
                                break;
                            case "PENDING":
                            case 1:
                                message.state = 1;
                                break;
                            case "RUNNING":
                            case 2:
                                message.state = 2;
                                break;
                            case "DONE":
                            case 3:
                                message.state = 3;
                                break;
                            }
                            if (object.knowledgeBase != null)
                                message.knowledgeBase = String(object.knowledgeBase);
                            if (object.exportOperationMetadata != null) {
                                if (typeof object.exportOperationMetadata !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.KnowledgeOperationMetadata.exportOperationMetadata: object expected");
                                message.exportOperationMetadata = $root.google.cloud.dialogflow.v2.ExportOperationMetadata.fromObject(object.exportOperationMetadata);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a KnowledgeOperationMetadata message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.KnowledgeOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.KnowledgeOperationMetadata} message KnowledgeOperationMetadata
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        KnowledgeOperationMetadata.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.state = options.enums === String ? "STATE_UNSPECIFIED" : 0;
                                object.knowledgeBase = "";
                            }
                            if (message.state != null && message.hasOwnProperty("state"))
                                object.state = options.enums === String ? $root.google.cloud.dialogflow.v2.KnowledgeOperationMetadata.State[message.state] === undefined ? message.state : $root.google.cloud.dialogflow.v2.KnowledgeOperationMetadata.State[message.state] : message.state;
                            if (message.knowledgeBase != null && message.hasOwnProperty("knowledgeBase"))
                                object.knowledgeBase = message.knowledgeBase;
                            if (message.exportOperationMetadata != null && message.hasOwnProperty("exportOperationMetadata")) {
                                object.exportOperationMetadata = $root.google.cloud.dialogflow.v2.ExportOperationMetadata.toObject(message.exportOperationMetadata, options);
                                if (options.oneofs)
                                    object.operationMetadata = "exportOperationMetadata";
                            }
                            return object;
                        };
    
                        /**
                         * Converts this KnowledgeOperationMetadata to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.KnowledgeOperationMetadata
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        KnowledgeOperationMetadata.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for KnowledgeOperationMetadata
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.KnowledgeOperationMetadata
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        KnowledgeOperationMetadata.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.KnowledgeOperationMetadata";
                        };
    
                        /**
                         * State enum.
                         * @name google.cloud.dialogflow.v2.KnowledgeOperationMetadata.State
                         * @enum {number}
                         * @property {number} STATE_UNSPECIFIED=0 STATE_UNSPECIFIED value
                         * @property {number} PENDING=1 PENDING value
                         * @property {number} RUNNING=2 RUNNING value
                         * @property {number} DONE=3 DONE value
                         */
                        KnowledgeOperationMetadata.State = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "STATE_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "PENDING"] = 1;
                            values[valuesById[2] = "RUNNING"] = 2;
                            values[valuesById[3] = "DONE"] = 3;
                            return values;
                        })();
    
                        return KnowledgeOperationMetadata;
                    })();
    
                    v2.EncryptionSpecService = (function() {
    
                        /**
                         * Constructs a new EncryptionSpecService service.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an EncryptionSpecService
                         * @extends $protobuf.rpc.Service
                         * @constructor
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         */
                        function EncryptionSpecService(rpcImpl, requestDelimited, responseDelimited) {
                            $protobuf.rpc.Service.call(this, rpcImpl, requestDelimited, responseDelimited);
                        }
    
                        (EncryptionSpecService.prototype = Object.create($protobuf.rpc.Service.prototype)).constructor = EncryptionSpecService;
    
                        /**
                         * Creates new EncryptionSpecService service using the specified rpc implementation.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.EncryptionSpecService
                         * @static
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         * @returns {EncryptionSpecService} RPC service. Useful where requests and/or responses are streamed.
                         */
                        EncryptionSpecService.create = function create(rpcImpl, requestDelimited, responseDelimited) {
                            return new this(rpcImpl, requestDelimited, responseDelimited);
                        };
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.EncryptionSpecService|getEncryptionSpec}.
                         * @memberof google.cloud.dialogflow.v2.EncryptionSpecService
                         * @typedef GetEncryptionSpecCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.EncryptionSpec} [response] EncryptionSpec
                         */
    
                        /**
                         * Calls GetEncryptionSpec.
                         * @function getEncryptionSpec
                         * @memberof google.cloud.dialogflow.v2.EncryptionSpecService
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IGetEncryptionSpecRequest} request GetEncryptionSpecRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.EncryptionSpecService.GetEncryptionSpecCallback} callback Node-style callback called with the error, if any, and EncryptionSpec
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(EncryptionSpecService.prototype.getEncryptionSpec = function getEncryptionSpec(request, callback) {
                            return this.rpcCall(getEncryptionSpec, $root.google.cloud.dialogflow.v2.GetEncryptionSpecRequest, $root.google.cloud.dialogflow.v2.EncryptionSpec, request, callback);
                        }, "name", { value: "GetEncryptionSpec" });
    
                        /**
                         * Calls GetEncryptionSpec.
                         * @function getEncryptionSpec
                         * @memberof google.cloud.dialogflow.v2.EncryptionSpecService
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IGetEncryptionSpecRequest} request GetEncryptionSpecRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.EncryptionSpec>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.EncryptionSpecService|initializeEncryptionSpec}.
                         * @memberof google.cloud.dialogflow.v2.EncryptionSpecService
                         * @typedef InitializeEncryptionSpecCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.longrunning.Operation} [response] Operation
                         */
    
                        /**
                         * Calls InitializeEncryptionSpec.
                         * @function initializeEncryptionSpec
                         * @memberof google.cloud.dialogflow.v2.EncryptionSpecService
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IInitializeEncryptionSpecRequest} request InitializeEncryptionSpecRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.EncryptionSpecService.InitializeEncryptionSpecCallback} callback Node-style callback called with the error, if any, and Operation
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(EncryptionSpecService.prototype.initializeEncryptionSpec = function initializeEncryptionSpec(request, callback) {
                            return this.rpcCall(initializeEncryptionSpec, $root.google.cloud.dialogflow.v2.InitializeEncryptionSpecRequest, $root.google.longrunning.Operation, request, callback);
                        }, "name", { value: "InitializeEncryptionSpec" });
    
                        /**
                         * Calls InitializeEncryptionSpec.
                         * @function initializeEncryptionSpec
                         * @memberof google.cloud.dialogflow.v2.EncryptionSpecService
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IInitializeEncryptionSpecRequest} request InitializeEncryptionSpecRequest message or plain object
                         * @returns {Promise<google.longrunning.Operation>} Promise
                         * @variation 2
                         */
    
                        return EncryptionSpecService;
                    })();
    
                    v2.GetEncryptionSpecRequest = (function() {
    
                        /**
                         * Properties of a GetEncryptionSpecRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IGetEncryptionSpecRequest
                         * @property {string|null} [name] GetEncryptionSpecRequest name
                         */
    
                        /**
                         * Constructs a new GetEncryptionSpecRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a GetEncryptionSpecRequest.
                         * @implements IGetEncryptionSpecRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IGetEncryptionSpecRequest=} [properties] Properties to set
                         */
                        function GetEncryptionSpecRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GetEncryptionSpecRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2.GetEncryptionSpecRequest
                         * @instance
                         */
                        GetEncryptionSpecRequest.prototype.name = "";
    
                        /**
                         * Creates a new GetEncryptionSpecRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.GetEncryptionSpecRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetEncryptionSpecRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.GetEncryptionSpecRequest} GetEncryptionSpecRequest instance
                         */
                        GetEncryptionSpecRequest.create = function create(properties) {
                            return new GetEncryptionSpecRequest(properties);
                        };
    
                        /**
                         * Encodes the specified GetEncryptionSpecRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.GetEncryptionSpecRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.GetEncryptionSpecRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetEncryptionSpecRequest} message GetEncryptionSpecRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetEncryptionSpecRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GetEncryptionSpecRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.GetEncryptionSpecRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GetEncryptionSpecRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetEncryptionSpecRequest} message GetEncryptionSpecRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetEncryptionSpecRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GetEncryptionSpecRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.GetEncryptionSpecRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.GetEncryptionSpecRequest} GetEncryptionSpecRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetEncryptionSpecRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.GetEncryptionSpecRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GetEncryptionSpecRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GetEncryptionSpecRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.GetEncryptionSpecRequest} GetEncryptionSpecRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetEncryptionSpecRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GetEncryptionSpecRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.GetEncryptionSpecRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GetEncryptionSpecRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a GetEncryptionSpecRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.GetEncryptionSpecRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.GetEncryptionSpecRequest} GetEncryptionSpecRequest
                         */
                        GetEncryptionSpecRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.GetEncryptionSpecRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.GetEncryptionSpecRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GetEncryptionSpecRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.GetEncryptionSpecRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.GetEncryptionSpecRequest} message GetEncryptionSpecRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GetEncryptionSpecRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.name = "";
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            return object;
                        };
    
                        /**
                         * Converts this GetEncryptionSpecRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.GetEncryptionSpecRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GetEncryptionSpecRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GetEncryptionSpecRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.GetEncryptionSpecRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GetEncryptionSpecRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.GetEncryptionSpecRequest";
                        };
    
                        return GetEncryptionSpecRequest;
                    })();
    
                    v2.EncryptionSpec = (function() {
    
                        /**
                         * Properties of an EncryptionSpec.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IEncryptionSpec
                         * @property {string|null} [name] EncryptionSpec name
                         * @property {string|null} [kmsKey] EncryptionSpec kmsKey
                         */
    
                        /**
                         * Constructs a new EncryptionSpec.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an EncryptionSpec.
                         * @implements IEncryptionSpec
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IEncryptionSpec=} [properties] Properties to set
                         */
                        function EncryptionSpec(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * EncryptionSpec name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2.EncryptionSpec
                         * @instance
                         */
                        EncryptionSpec.prototype.name = "";
    
                        /**
                         * EncryptionSpec kmsKey.
                         * @member {string} kmsKey
                         * @memberof google.cloud.dialogflow.v2.EncryptionSpec
                         * @instance
                         */
                        EncryptionSpec.prototype.kmsKey = "";
    
                        /**
                         * Creates a new EncryptionSpec instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.EncryptionSpec
                         * @static
                         * @param {google.cloud.dialogflow.v2.IEncryptionSpec=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.EncryptionSpec} EncryptionSpec instance
                         */
                        EncryptionSpec.create = function create(properties) {
                            return new EncryptionSpec(properties);
                        };
    
                        /**
                         * Encodes the specified EncryptionSpec message. Does not implicitly {@link google.cloud.dialogflow.v2.EncryptionSpec.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.EncryptionSpec
                         * @static
                         * @param {google.cloud.dialogflow.v2.IEncryptionSpec} message EncryptionSpec message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        EncryptionSpec.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            if (message.kmsKey != null && Object.hasOwnProperty.call(message, "kmsKey"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.kmsKey);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified EncryptionSpec message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.EncryptionSpec.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.EncryptionSpec
                         * @static
                         * @param {google.cloud.dialogflow.v2.IEncryptionSpec} message EncryptionSpec message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        EncryptionSpec.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an EncryptionSpec message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.EncryptionSpec
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.EncryptionSpec} EncryptionSpec
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        EncryptionSpec.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.EncryptionSpec();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.kmsKey = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an EncryptionSpec message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.EncryptionSpec
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.EncryptionSpec} EncryptionSpec
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        EncryptionSpec.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an EncryptionSpec message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.EncryptionSpec
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        EncryptionSpec.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            if (message.kmsKey != null && message.hasOwnProperty("kmsKey"))
                                if (!$util.isString(message.kmsKey))
                                    return "kmsKey: string expected";
                            return null;
                        };
    
                        /**
                         * Creates an EncryptionSpec message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.EncryptionSpec
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.EncryptionSpec} EncryptionSpec
                         */
                        EncryptionSpec.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.EncryptionSpec)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.EncryptionSpec();
                            if (object.name != null)
                                message.name = String(object.name);
                            if (object.kmsKey != null)
                                message.kmsKey = String(object.kmsKey);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an EncryptionSpec message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.EncryptionSpec
                         * @static
                         * @param {google.cloud.dialogflow.v2.EncryptionSpec} message EncryptionSpec
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        EncryptionSpec.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.name = "";
                                object.kmsKey = "";
                            }
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            if (message.kmsKey != null && message.hasOwnProperty("kmsKey"))
                                object.kmsKey = message.kmsKey;
                            return object;
                        };
    
                        /**
                         * Converts this EncryptionSpec to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.EncryptionSpec
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        EncryptionSpec.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for EncryptionSpec
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.EncryptionSpec
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        EncryptionSpec.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.EncryptionSpec";
                        };
    
                        return EncryptionSpec;
                    })();
    
                    v2.InitializeEncryptionSpecRequest = (function() {
    
                        /**
                         * Properties of an InitializeEncryptionSpecRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IInitializeEncryptionSpecRequest
                         * @property {google.cloud.dialogflow.v2.IEncryptionSpec|null} [encryptionSpec] InitializeEncryptionSpecRequest encryptionSpec
                         */
    
                        /**
                         * Constructs a new InitializeEncryptionSpecRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an InitializeEncryptionSpecRequest.
                         * @implements IInitializeEncryptionSpecRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IInitializeEncryptionSpecRequest=} [properties] Properties to set
                         */
                        function InitializeEncryptionSpecRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * InitializeEncryptionSpecRequest encryptionSpec.
                         * @member {google.cloud.dialogflow.v2.IEncryptionSpec|null|undefined} encryptionSpec
                         * @memberof google.cloud.dialogflow.v2.InitializeEncryptionSpecRequest
                         * @instance
                         */
                        InitializeEncryptionSpecRequest.prototype.encryptionSpec = null;
    
                        /**
                         * Creates a new InitializeEncryptionSpecRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.InitializeEncryptionSpecRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IInitializeEncryptionSpecRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.InitializeEncryptionSpecRequest} InitializeEncryptionSpecRequest instance
                         */
                        InitializeEncryptionSpecRequest.create = function create(properties) {
                            return new InitializeEncryptionSpecRequest(properties);
                        };
    
                        /**
                         * Encodes the specified InitializeEncryptionSpecRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.InitializeEncryptionSpecRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.InitializeEncryptionSpecRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IInitializeEncryptionSpecRequest} message InitializeEncryptionSpecRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        InitializeEncryptionSpecRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.encryptionSpec != null && Object.hasOwnProperty.call(message, "encryptionSpec"))
                                $root.google.cloud.dialogflow.v2.EncryptionSpec.encode(message.encryptionSpec, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified InitializeEncryptionSpecRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.InitializeEncryptionSpecRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.InitializeEncryptionSpecRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IInitializeEncryptionSpecRequest} message InitializeEncryptionSpecRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        InitializeEncryptionSpecRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an InitializeEncryptionSpecRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.InitializeEncryptionSpecRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.InitializeEncryptionSpecRequest} InitializeEncryptionSpecRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        InitializeEncryptionSpecRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.InitializeEncryptionSpecRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.encryptionSpec = $root.google.cloud.dialogflow.v2.EncryptionSpec.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an InitializeEncryptionSpecRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.InitializeEncryptionSpecRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.InitializeEncryptionSpecRequest} InitializeEncryptionSpecRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        InitializeEncryptionSpecRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an InitializeEncryptionSpecRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.InitializeEncryptionSpecRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        InitializeEncryptionSpecRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.encryptionSpec != null && message.hasOwnProperty("encryptionSpec")) {
                                var error = $root.google.cloud.dialogflow.v2.EncryptionSpec.verify(message.encryptionSpec);
                                if (error)
                                    return "encryptionSpec." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates an InitializeEncryptionSpecRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.InitializeEncryptionSpecRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.InitializeEncryptionSpecRequest} InitializeEncryptionSpecRequest
                         */
                        InitializeEncryptionSpecRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.InitializeEncryptionSpecRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.InitializeEncryptionSpecRequest();
                            if (object.encryptionSpec != null) {
                                if (typeof object.encryptionSpec !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.InitializeEncryptionSpecRequest.encryptionSpec: object expected");
                                message.encryptionSpec = $root.google.cloud.dialogflow.v2.EncryptionSpec.fromObject(object.encryptionSpec);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an InitializeEncryptionSpecRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.InitializeEncryptionSpecRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.InitializeEncryptionSpecRequest} message InitializeEncryptionSpecRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        InitializeEncryptionSpecRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.encryptionSpec = null;
                            if (message.encryptionSpec != null && message.hasOwnProperty("encryptionSpec"))
                                object.encryptionSpec = $root.google.cloud.dialogflow.v2.EncryptionSpec.toObject(message.encryptionSpec, options);
                            return object;
                        };
    
                        /**
                         * Converts this InitializeEncryptionSpecRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.InitializeEncryptionSpecRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        InitializeEncryptionSpecRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for InitializeEncryptionSpecRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.InitializeEncryptionSpecRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        InitializeEncryptionSpecRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.InitializeEncryptionSpecRequest";
                        };
    
                        return InitializeEncryptionSpecRequest;
                    })();
    
                    v2.InitializeEncryptionSpecResponse = (function() {
    
                        /**
                         * Properties of an InitializeEncryptionSpecResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IInitializeEncryptionSpecResponse
                         */
    
                        /**
                         * Constructs a new InitializeEncryptionSpecResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an InitializeEncryptionSpecResponse.
                         * @implements IInitializeEncryptionSpecResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IInitializeEncryptionSpecResponse=} [properties] Properties to set
                         */
                        function InitializeEncryptionSpecResponse(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * Creates a new InitializeEncryptionSpecResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.InitializeEncryptionSpecResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IInitializeEncryptionSpecResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.InitializeEncryptionSpecResponse} InitializeEncryptionSpecResponse instance
                         */
                        InitializeEncryptionSpecResponse.create = function create(properties) {
                            return new InitializeEncryptionSpecResponse(properties);
                        };
    
                        /**
                         * Encodes the specified InitializeEncryptionSpecResponse message. Does not implicitly {@link google.cloud.dialogflow.v2.InitializeEncryptionSpecResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.InitializeEncryptionSpecResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IInitializeEncryptionSpecResponse} message InitializeEncryptionSpecResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        InitializeEncryptionSpecResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified InitializeEncryptionSpecResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.InitializeEncryptionSpecResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.InitializeEncryptionSpecResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IInitializeEncryptionSpecResponse} message InitializeEncryptionSpecResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        InitializeEncryptionSpecResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an InitializeEncryptionSpecResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.InitializeEncryptionSpecResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.InitializeEncryptionSpecResponse} InitializeEncryptionSpecResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        InitializeEncryptionSpecResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.InitializeEncryptionSpecResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an InitializeEncryptionSpecResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.InitializeEncryptionSpecResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.InitializeEncryptionSpecResponse} InitializeEncryptionSpecResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        InitializeEncryptionSpecResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an InitializeEncryptionSpecResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.InitializeEncryptionSpecResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        InitializeEncryptionSpecResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            return null;
                        };
    
                        /**
                         * Creates an InitializeEncryptionSpecResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.InitializeEncryptionSpecResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.InitializeEncryptionSpecResponse} InitializeEncryptionSpecResponse
                         */
                        InitializeEncryptionSpecResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.InitializeEncryptionSpecResponse)
                                return object;
                            return new $root.google.cloud.dialogflow.v2.InitializeEncryptionSpecResponse();
                        };
    
                        /**
                         * Creates a plain object from an InitializeEncryptionSpecResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.InitializeEncryptionSpecResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.InitializeEncryptionSpecResponse} message InitializeEncryptionSpecResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        InitializeEncryptionSpecResponse.toObject = function toObject() {
                            return {};
                        };
    
                        /**
                         * Converts this InitializeEncryptionSpecResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.InitializeEncryptionSpecResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        InitializeEncryptionSpecResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for InitializeEncryptionSpecResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.InitializeEncryptionSpecResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        InitializeEncryptionSpecResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.InitializeEncryptionSpecResponse";
                        };
    
                        return InitializeEncryptionSpecResponse;
                    })();
    
                    v2.InitializeEncryptionSpecMetadata = (function() {
    
                        /**
                         * Properties of an InitializeEncryptionSpecMetadata.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IInitializeEncryptionSpecMetadata
                         * @property {google.cloud.dialogflow.v2.IInitializeEncryptionSpecRequest|null} [request] InitializeEncryptionSpecMetadata request
                         */
    
                        /**
                         * Constructs a new InitializeEncryptionSpecMetadata.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an InitializeEncryptionSpecMetadata.
                         * @implements IInitializeEncryptionSpecMetadata
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IInitializeEncryptionSpecMetadata=} [properties] Properties to set
                         */
                        function InitializeEncryptionSpecMetadata(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * InitializeEncryptionSpecMetadata request.
                         * @member {google.cloud.dialogflow.v2.IInitializeEncryptionSpecRequest|null|undefined} request
                         * @memberof google.cloud.dialogflow.v2.InitializeEncryptionSpecMetadata
                         * @instance
                         */
                        InitializeEncryptionSpecMetadata.prototype.request = null;
    
                        /**
                         * Creates a new InitializeEncryptionSpecMetadata instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.InitializeEncryptionSpecMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.IInitializeEncryptionSpecMetadata=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.InitializeEncryptionSpecMetadata} InitializeEncryptionSpecMetadata instance
                         */
                        InitializeEncryptionSpecMetadata.create = function create(properties) {
                            return new InitializeEncryptionSpecMetadata(properties);
                        };
    
                        /**
                         * Encodes the specified InitializeEncryptionSpecMetadata message. Does not implicitly {@link google.cloud.dialogflow.v2.InitializeEncryptionSpecMetadata.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.InitializeEncryptionSpecMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.IInitializeEncryptionSpecMetadata} message InitializeEncryptionSpecMetadata message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        InitializeEncryptionSpecMetadata.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.request != null && Object.hasOwnProperty.call(message, "request"))
                                $root.google.cloud.dialogflow.v2.InitializeEncryptionSpecRequest.encode(message.request, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified InitializeEncryptionSpecMetadata message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.InitializeEncryptionSpecMetadata.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.InitializeEncryptionSpecMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.IInitializeEncryptionSpecMetadata} message InitializeEncryptionSpecMetadata message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        InitializeEncryptionSpecMetadata.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an InitializeEncryptionSpecMetadata message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.InitializeEncryptionSpecMetadata
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.InitializeEncryptionSpecMetadata} InitializeEncryptionSpecMetadata
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        InitializeEncryptionSpecMetadata.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.InitializeEncryptionSpecMetadata();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 4: {
                                        message.request = $root.google.cloud.dialogflow.v2.InitializeEncryptionSpecRequest.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an InitializeEncryptionSpecMetadata message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.InitializeEncryptionSpecMetadata
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.InitializeEncryptionSpecMetadata} InitializeEncryptionSpecMetadata
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        InitializeEncryptionSpecMetadata.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an InitializeEncryptionSpecMetadata message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.InitializeEncryptionSpecMetadata
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        InitializeEncryptionSpecMetadata.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.request != null && message.hasOwnProperty("request")) {
                                var error = $root.google.cloud.dialogflow.v2.InitializeEncryptionSpecRequest.verify(message.request);
                                if (error)
                                    return "request." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates an InitializeEncryptionSpecMetadata message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.InitializeEncryptionSpecMetadata
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.InitializeEncryptionSpecMetadata} InitializeEncryptionSpecMetadata
                         */
                        InitializeEncryptionSpecMetadata.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.InitializeEncryptionSpecMetadata)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.InitializeEncryptionSpecMetadata();
                            if (object.request != null) {
                                if (typeof object.request !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.InitializeEncryptionSpecMetadata.request: object expected");
                                message.request = $root.google.cloud.dialogflow.v2.InitializeEncryptionSpecRequest.fromObject(object.request);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an InitializeEncryptionSpecMetadata message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.InitializeEncryptionSpecMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2.InitializeEncryptionSpecMetadata} message InitializeEncryptionSpecMetadata
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        InitializeEncryptionSpecMetadata.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.request = null;
                            if (message.request != null && message.hasOwnProperty("request"))
                                object.request = $root.google.cloud.dialogflow.v2.InitializeEncryptionSpecRequest.toObject(message.request, options);
                            return object;
                        };
    
                        /**
                         * Converts this InitializeEncryptionSpecMetadata to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.InitializeEncryptionSpecMetadata
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        InitializeEncryptionSpecMetadata.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for InitializeEncryptionSpecMetadata
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.InitializeEncryptionSpecMetadata
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        InitializeEncryptionSpecMetadata.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.InitializeEncryptionSpecMetadata";
                        };
    
                        return InitializeEncryptionSpecMetadata;
                    })();
    
                    v2.Environments = (function() {
    
                        /**
                         * Constructs a new Environments service.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an Environments
                         * @extends $protobuf.rpc.Service
                         * @constructor
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         */
                        function Environments(rpcImpl, requestDelimited, responseDelimited) {
                            $protobuf.rpc.Service.call(this, rpcImpl, requestDelimited, responseDelimited);
                        }
    
                        (Environments.prototype = Object.create($protobuf.rpc.Service.prototype)).constructor = Environments;
    
                        /**
                         * Creates new Environments service using the specified rpc implementation.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.Environments
                         * @static
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         * @returns {Environments} RPC service. Useful where requests and/or responses are streamed.
                         */
                        Environments.create = function create(rpcImpl, requestDelimited, responseDelimited) {
                            return new this(rpcImpl, requestDelimited, responseDelimited);
                        };
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Environments|listEnvironments}.
                         * @memberof google.cloud.dialogflow.v2.Environments
                         * @typedef ListEnvironmentsCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.ListEnvironmentsResponse} [response] ListEnvironmentsResponse
                         */
    
                        /**
                         * Calls ListEnvironments.
                         * @function listEnvironments
                         * @memberof google.cloud.dialogflow.v2.Environments
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IListEnvironmentsRequest} request ListEnvironmentsRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Environments.ListEnvironmentsCallback} callback Node-style callback called with the error, if any, and ListEnvironmentsResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Environments.prototype.listEnvironments = function listEnvironments(request, callback) {
                            return this.rpcCall(listEnvironments, $root.google.cloud.dialogflow.v2.ListEnvironmentsRequest, $root.google.cloud.dialogflow.v2.ListEnvironmentsResponse, request, callback);
                        }, "name", { value: "ListEnvironments" });
    
                        /**
                         * Calls ListEnvironments.
                         * @function listEnvironments
                         * @memberof google.cloud.dialogflow.v2.Environments
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IListEnvironmentsRequest} request ListEnvironmentsRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.ListEnvironmentsResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Environments|getEnvironment}.
                         * @memberof google.cloud.dialogflow.v2.Environments
                         * @typedef GetEnvironmentCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.Environment} [response] Environment
                         */
    
                        /**
                         * Calls GetEnvironment.
                         * @function getEnvironment
                         * @memberof google.cloud.dialogflow.v2.Environments
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IGetEnvironmentRequest} request GetEnvironmentRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Environments.GetEnvironmentCallback} callback Node-style callback called with the error, if any, and Environment
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Environments.prototype.getEnvironment = function getEnvironment(request, callback) {
                            return this.rpcCall(getEnvironment, $root.google.cloud.dialogflow.v2.GetEnvironmentRequest, $root.google.cloud.dialogflow.v2.Environment, request, callback);
                        }, "name", { value: "GetEnvironment" });
    
                        /**
                         * Calls GetEnvironment.
                         * @function getEnvironment
                         * @memberof google.cloud.dialogflow.v2.Environments
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IGetEnvironmentRequest} request GetEnvironmentRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.Environment>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Environments|createEnvironment}.
                         * @memberof google.cloud.dialogflow.v2.Environments
                         * @typedef CreateEnvironmentCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.Environment} [response] Environment
                         */
    
                        /**
                         * Calls CreateEnvironment.
                         * @function createEnvironment
                         * @memberof google.cloud.dialogflow.v2.Environments
                         * @instance
                         * @param {google.cloud.dialogflow.v2.ICreateEnvironmentRequest} request CreateEnvironmentRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Environments.CreateEnvironmentCallback} callback Node-style callback called with the error, if any, and Environment
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Environments.prototype.createEnvironment = function createEnvironment(request, callback) {
                            return this.rpcCall(createEnvironment, $root.google.cloud.dialogflow.v2.CreateEnvironmentRequest, $root.google.cloud.dialogflow.v2.Environment, request, callback);
                        }, "name", { value: "CreateEnvironment" });
    
                        /**
                         * Calls CreateEnvironment.
                         * @function createEnvironment
                         * @memberof google.cloud.dialogflow.v2.Environments
                         * @instance
                         * @param {google.cloud.dialogflow.v2.ICreateEnvironmentRequest} request CreateEnvironmentRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.Environment>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Environments|updateEnvironment}.
                         * @memberof google.cloud.dialogflow.v2.Environments
                         * @typedef UpdateEnvironmentCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.Environment} [response] Environment
                         */
    
                        /**
                         * Calls UpdateEnvironment.
                         * @function updateEnvironment
                         * @memberof google.cloud.dialogflow.v2.Environments
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IUpdateEnvironmentRequest} request UpdateEnvironmentRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Environments.UpdateEnvironmentCallback} callback Node-style callback called with the error, if any, and Environment
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Environments.prototype.updateEnvironment = function updateEnvironment(request, callback) {
                            return this.rpcCall(updateEnvironment, $root.google.cloud.dialogflow.v2.UpdateEnvironmentRequest, $root.google.cloud.dialogflow.v2.Environment, request, callback);
                        }, "name", { value: "UpdateEnvironment" });
    
                        /**
                         * Calls UpdateEnvironment.
                         * @function updateEnvironment
                         * @memberof google.cloud.dialogflow.v2.Environments
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IUpdateEnvironmentRequest} request UpdateEnvironmentRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.Environment>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Environments|deleteEnvironment}.
                         * @memberof google.cloud.dialogflow.v2.Environments
                         * @typedef DeleteEnvironmentCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.protobuf.Empty} [response] Empty
                         */
    
                        /**
                         * Calls DeleteEnvironment.
                         * @function deleteEnvironment
                         * @memberof google.cloud.dialogflow.v2.Environments
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IDeleteEnvironmentRequest} request DeleteEnvironmentRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Environments.DeleteEnvironmentCallback} callback Node-style callback called with the error, if any, and Empty
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Environments.prototype.deleteEnvironment = function deleteEnvironment(request, callback) {
                            return this.rpcCall(deleteEnvironment, $root.google.cloud.dialogflow.v2.DeleteEnvironmentRequest, $root.google.protobuf.Empty, request, callback);
                        }, "name", { value: "DeleteEnvironment" });
    
                        /**
                         * Calls DeleteEnvironment.
                         * @function deleteEnvironment
                         * @memberof google.cloud.dialogflow.v2.Environments
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IDeleteEnvironmentRequest} request DeleteEnvironmentRequest message or plain object
                         * @returns {Promise<google.protobuf.Empty>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Environments|getEnvironmentHistory}.
                         * @memberof google.cloud.dialogflow.v2.Environments
                         * @typedef GetEnvironmentHistoryCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.EnvironmentHistory} [response] EnvironmentHistory
                         */
    
                        /**
                         * Calls GetEnvironmentHistory.
                         * @function getEnvironmentHistory
                         * @memberof google.cloud.dialogflow.v2.Environments
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IGetEnvironmentHistoryRequest} request GetEnvironmentHistoryRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Environments.GetEnvironmentHistoryCallback} callback Node-style callback called with the error, if any, and EnvironmentHistory
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Environments.prototype.getEnvironmentHistory = function getEnvironmentHistory(request, callback) {
                            return this.rpcCall(getEnvironmentHistory, $root.google.cloud.dialogflow.v2.GetEnvironmentHistoryRequest, $root.google.cloud.dialogflow.v2.EnvironmentHistory, request, callback);
                        }, "name", { value: "GetEnvironmentHistory" });
    
                        /**
                         * Calls GetEnvironmentHistory.
                         * @function getEnvironmentHistory
                         * @memberof google.cloud.dialogflow.v2.Environments
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IGetEnvironmentHistoryRequest} request GetEnvironmentHistoryRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.EnvironmentHistory>} Promise
                         * @variation 2
                         */
    
                        return Environments;
                    })();
    
                    v2.Environment = (function() {
    
                        /**
                         * Properties of an Environment.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IEnvironment
                         * @property {string|null} [name] Environment name
                         * @property {string|null} [description] Environment description
                         * @property {string|null} [agentVersion] Environment agentVersion
                         * @property {google.cloud.dialogflow.v2.Environment.State|null} [state] Environment state
                         * @property {google.protobuf.ITimestamp|null} [updateTime] Environment updateTime
                         * @property {google.cloud.dialogflow.v2.ITextToSpeechSettings|null} [textToSpeechSettings] Environment textToSpeechSettings
                         * @property {google.cloud.dialogflow.v2.IFulfillment|null} [fulfillment] Environment fulfillment
                         */
    
                        /**
                         * Constructs a new Environment.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an Environment.
                         * @implements IEnvironment
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IEnvironment=} [properties] Properties to set
                         */
                        function Environment(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * Environment name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2.Environment
                         * @instance
                         */
                        Environment.prototype.name = "";
    
                        /**
                         * Environment description.
                         * @member {string} description
                         * @memberof google.cloud.dialogflow.v2.Environment
                         * @instance
                         */
                        Environment.prototype.description = "";
    
                        /**
                         * Environment agentVersion.
                         * @member {string} agentVersion
                         * @memberof google.cloud.dialogflow.v2.Environment
                         * @instance
                         */
                        Environment.prototype.agentVersion = "";
    
                        /**
                         * Environment state.
                         * @member {google.cloud.dialogflow.v2.Environment.State} state
                         * @memberof google.cloud.dialogflow.v2.Environment
                         * @instance
                         */
                        Environment.prototype.state = 0;
    
                        /**
                         * Environment updateTime.
                         * @member {google.protobuf.ITimestamp|null|undefined} updateTime
                         * @memberof google.cloud.dialogflow.v2.Environment
                         * @instance
                         */
                        Environment.prototype.updateTime = null;
    
                        /**
                         * Environment textToSpeechSettings.
                         * @member {google.cloud.dialogflow.v2.ITextToSpeechSettings|null|undefined} textToSpeechSettings
                         * @memberof google.cloud.dialogflow.v2.Environment
                         * @instance
                         */
                        Environment.prototype.textToSpeechSettings = null;
    
                        /**
                         * Environment fulfillment.
                         * @member {google.cloud.dialogflow.v2.IFulfillment|null|undefined} fulfillment
                         * @memberof google.cloud.dialogflow.v2.Environment
                         * @instance
                         */
                        Environment.prototype.fulfillment = null;
    
                        /**
                         * Creates a new Environment instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.Environment
                         * @static
                         * @param {google.cloud.dialogflow.v2.IEnvironment=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.Environment} Environment instance
                         */
                        Environment.create = function create(properties) {
                            return new Environment(properties);
                        };
    
                        /**
                         * Encodes the specified Environment message. Does not implicitly {@link google.cloud.dialogflow.v2.Environment.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.Environment
                         * @static
                         * @param {google.cloud.dialogflow.v2.IEnvironment} message Environment message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        Environment.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            if (message.description != null && Object.hasOwnProperty.call(message, "description"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.description);
                            if (message.agentVersion != null && Object.hasOwnProperty.call(message, "agentVersion"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.agentVersion);
                            if (message.state != null && Object.hasOwnProperty.call(message, "state"))
                                writer.uint32(/* id 4, wireType 0 =*/32).int32(message.state);
                            if (message.updateTime != null && Object.hasOwnProperty.call(message, "updateTime"))
                                $root.google.protobuf.Timestamp.encode(message.updateTime, writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                            if (message.textToSpeechSettings != null && Object.hasOwnProperty.call(message, "textToSpeechSettings"))
                                $root.google.cloud.dialogflow.v2.TextToSpeechSettings.encode(message.textToSpeechSettings, writer.uint32(/* id 7, wireType 2 =*/58).fork()).ldelim();
                            if (message.fulfillment != null && Object.hasOwnProperty.call(message, "fulfillment"))
                                $root.google.cloud.dialogflow.v2.Fulfillment.encode(message.fulfillment, writer.uint32(/* id 8, wireType 2 =*/66).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified Environment message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.Environment.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.Environment
                         * @static
                         * @param {google.cloud.dialogflow.v2.IEnvironment} message Environment message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        Environment.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an Environment message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.Environment
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.Environment} Environment
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        Environment.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.Environment();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.description = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.agentVersion = reader.string();
                                        break;
                                    }
                                case 4: {
                                        message.state = reader.int32();
                                        break;
                                    }
                                case 5: {
                                        message.updateTime = $root.google.protobuf.Timestamp.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 7: {
                                        message.textToSpeechSettings = $root.google.cloud.dialogflow.v2.TextToSpeechSettings.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 8: {
                                        message.fulfillment = $root.google.cloud.dialogflow.v2.Fulfillment.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an Environment message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.Environment
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.Environment} Environment
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        Environment.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an Environment message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.Environment
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        Environment.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            if (message.description != null && message.hasOwnProperty("description"))
                                if (!$util.isString(message.description))
                                    return "description: string expected";
                            if (message.agentVersion != null && message.hasOwnProperty("agentVersion"))
                                if (!$util.isString(message.agentVersion))
                                    return "agentVersion: string expected";
                            if (message.state != null && message.hasOwnProperty("state"))
                                switch (message.state) {
                                default:
                                    return "state: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                    break;
                                }
                            if (message.updateTime != null && message.hasOwnProperty("updateTime")) {
                                var error = $root.google.protobuf.Timestamp.verify(message.updateTime);
                                if (error)
                                    return "updateTime." + error;
                            }
                            if (message.textToSpeechSettings != null && message.hasOwnProperty("textToSpeechSettings")) {
                                var error = $root.google.cloud.dialogflow.v2.TextToSpeechSettings.verify(message.textToSpeechSettings);
                                if (error)
                                    return "textToSpeechSettings." + error;
                            }
                            if (message.fulfillment != null && message.hasOwnProperty("fulfillment")) {
                                var error = $root.google.cloud.dialogflow.v2.Fulfillment.verify(message.fulfillment);
                                if (error)
                                    return "fulfillment." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates an Environment message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.Environment
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.Environment} Environment
                         */
                        Environment.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.Environment)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.Environment();
                            if (object.name != null)
                                message.name = String(object.name);
                            if (object.description != null)
                                message.description = String(object.description);
                            if (object.agentVersion != null)
                                message.agentVersion = String(object.agentVersion);
                            switch (object.state) {
                            default:
                                if (typeof object.state === "number") {
                                    message.state = object.state;
                                    break;
                                }
                                break;
                            case "STATE_UNSPECIFIED":
                            case 0:
                                message.state = 0;
                                break;
                            case "STOPPED":
                            case 1:
                                message.state = 1;
                                break;
                            case "LOADING":
                            case 2:
                                message.state = 2;
                                break;
                            case "RUNNING":
                            case 3:
                                message.state = 3;
                                break;
                            }
                            if (object.updateTime != null) {
                                if (typeof object.updateTime !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.Environment.updateTime: object expected");
                                message.updateTime = $root.google.protobuf.Timestamp.fromObject(object.updateTime);
                            }
                            if (object.textToSpeechSettings != null) {
                                if (typeof object.textToSpeechSettings !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.Environment.textToSpeechSettings: object expected");
                                message.textToSpeechSettings = $root.google.cloud.dialogflow.v2.TextToSpeechSettings.fromObject(object.textToSpeechSettings);
                            }
                            if (object.fulfillment != null) {
                                if (typeof object.fulfillment !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.Environment.fulfillment: object expected");
                                message.fulfillment = $root.google.cloud.dialogflow.v2.Fulfillment.fromObject(object.fulfillment);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an Environment message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.Environment
                         * @static
                         * @param {google.cloud.dialogflow.v2.Environment} message Environment
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        Environment.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.name = "";
                                object.description = "";
                                object.agentVersion = "";
                                object.state = options.enums === String ? "STATE_UNSPECIFIED" : 0;
                                object.updateTime = null;
                                object.textToSpeechSettings = null;
                                object.fulfillment = null;
                            }
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            if (message.description != null && message.hasOwnProperty("description"))
                                object.description = message.description;
                            if (message.agentVersion != null && message.hasOwnProperty("agentVersion"))
                                object.agentVersion = message.agentVersion;
                            if (message.state != null && message.hasOwnProperty("state"))
                                object.state = options.enums === String ? $root.google.cloud.dialogflow.v2.Environment.State[message.state] === undefined ? message.state : $root.google.cloud.dialogflow.v2.Environment.State[message.state] : message.state;
                            if (message.updateTime != null && message.hasOwnProperty("updateTime"))
                                object.updateTime = $root.google.protobuf.Timestamp.toObject(message.updateTime, options);
                            if (message.textToSpeechSettings != null && message.hasOwnProperty("textToSpeechSettings"))
                                object.textToSpeechSettings = $root.google.cloud.dialogflow.v2.TextToSpeechSettings.toObject(message.textToSpeechSettings, options);
                            if (message.fulfillment != null && message.hasOwnProperty("fulfillment"))
                                object.fulfillment = $root.google.cloud.dialogflow.v2.Fulfillment.toObject(message.fulfillment, options);
                            return object;
                        };
    
                        /**
                         * Converts this Environment to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.Environment
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        Environment.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for Environment
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.Environment
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        Environment.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.Environment";
                        };
    
                        /**
                         * State enum.
                         * @name google.cloud.dialogflow.v2.Environment.State
                         * @enum {number}
                         * @property {number} STATE_UNSPECIFIED=0 STATE_UNSPECIFIED value
                         * @property {number} STOPPED=1 STOPPED value
                         * @property {number} LOADING=2 LOADING value
                         * @property {number} RUNNING=3 RUNNING value
                         */
                        Environment.State = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "STATE_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "STOPPED"] = 1;
                            values[valuesById[2] = "LOADING"] = 2;
                            values[valuesById[3] = "RUNNING"] = 3;
                            return values;
                        })();
    
                        return Environment;
                    })();
    
                    v2.TextToSpeechSettings = (function() {
    
                        /**
                         * Properties of a TextToSpeechSettings.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ITextToSpeechSettings
                         * @property {boolean|null} [enableTextToSpeech] TextToSpeechSettings enableTextToSpeech
                         * @property {google.cloud.dialogflow.v2.OutputAudioEncoding|null} [outputAudioEncoding] TextToSpeechSettings outputAudioEncoding
                         * @property {number|null} [sampleRateHertz] TextToSpeechSettings sampleRateHertz
                         * @property {Object.<string,google.cloud.dialogflow.v2.ISynthesizeSpeechConfig>|null} [synthesizeSpeechConfigs] TextToSpeechSettings synthesizeSpeechConfigs
                         */
    
                        /**
                         * Constructs a new TextToSpeechSettings.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a TextToSpeechSettings.
                         * @implements ITextToSpeechSettings
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ITextToSpeechSettings=} [properties] Properties to set
                         */
                        function TextToSpeechSettings(properties) {
                            this.synthesizeSpeechConfigs = {};
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * TextToSpeechSettings enableTextToSpeech.
                         * @member {boolean} enableTextToSpeech
                         * @memberof google.cloud.dialogflow.v2.TextToSpeechSettings
                         * @instance
                         */
                        TextToSpeechSettings.prototype.enableTextToSpeech = false;
    
                        /**
                         * TextToSpeechSettings outputAudioEncoding.
                         * @member {google.cloud.dialogflow.v2.OutputAudioEncoding} outputAudioEncoding
                         * @memberof google.cloud.dialogflow.v2.TextToSpeechSettings
                         * @instance
                         */
                        TextToSpeechSettings.prototype.outputAudioEncoding = 0;
    
                        /**
                         * TextToSpeechSettings sampleRateHertz.
                         * @member {number} sampleRateHertz
                         * @memberof google.cloud.dialogflow.v2.TextToSpeechSettings
                         * @instance
                         */
                        TextToSpeechSettings.prototype.sampleRateHertz = 0;
    
                        /**
                         * TextToSpeechSettings synthesizeSpeechConfigs.
                         * @member {Object.<string,google.cloud.dialogflow.v2.ISynthesizeSpeechConfig>} synthesizeSpeechConfigs
                         * @memberof google.cloud.dialogflow.v2.TextToSpeechSettings
                         * @instance
                         */
                        TextToSpeechSettings.prototype.synthesizeSpeechConfigs = $util.emptyObject;
    
                        /**
                         * Creates a new TextToSpeechSettings instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.TextToSpeechSettings
                         * @static
                         * @param {google.cloud.dialogflow.v2.ITextToSpeechSettings=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.TextToSpeechSettings} TextToSpeechSettings instance
                         */
                        TextToSpeechSettings.create = function create(properties) {
                            return new TextToSpeechSettings(properties);
                        };
    
                        /**
                         * Encodes the specified TextToSpeechSettings message. Does not implicitly {@link google.cloud.dialogflow.v2.TextToSpeechSettings.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.TextToSpeechSettings
                         * @static
                         * @param {google.cloud.dialogflow.v2.ITextToSpeechSettings} message TextToSpeechSettings message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        TextToSpeechSettings.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.enableTextToSpeech != null && Object.hasOwnProperty.call(message, "enableTextToSpeech"))
                                writer.uint32(/* id 1, wireType 0 =*/8).bool(message.enableTextToSpeech);
                            if (message.outputAudioEncoding != null && Object.hasOwnProperty.call(message, "outputAudioEncoding"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.outputAudioEncoding);
                            if (message.sampleRateHertz != null && Object.hasOwnProperty.call(message, "sampleRateHertz"))
                                writer.uint32(/* id 3, wireType 0 =*/24).int32(message.sampleRateHertz);
                            if (message.synthesizeSpeechConfigs != null && Object.hasOwnProperty.call(message, "synthesizeSpeechConfigs"))
                                for (var keys = Object.keys(message.synthesizeSpeechConfigs), i = 0; i < keys.length; ++i) {
                                    writer.uint32(/* id 4, wireType 2 =*/34).fork().uint32(/* id 1, wireType 2 =*/10).string(keys[i]);
                                    $root.google.cloud.dialogflow.v2.SynthesizeSpeechConfig.encode(message.synthesizeSpeechConfigs[keys[i]], writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim().ldelim();
                                }
                            return writer;
                        };
    
                        /**
                         * Encodes the specified TextToSpeechSettings message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.TextToSpeechSettings.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.TextToSpeechSettings
                         * @static
                         * @param {google.cloud.dialogflow.v2.ITextToSpeechSettings} message TextToSpeechSettings message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        TextToSpeechSettings.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a TextToSpeechSettings message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.TextToSpeechSettings
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.TextToSpeechSettings} TextToSpeechSettings
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        TextToSpeechSettings.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.TextToSpeechSettings(), key, value;
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.enableTextToSpeech = reader.bool();
                                        break;
                                    }
                                case 2: {
                                        message.outputAudioEncoding = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.sampleRateHertz = reader.int32();
                                        break;
                                    }
                                case 4: {
                                        if (message.synthesizeSpeechConfigs === $util.emptyObject)
                                            message.synthesizeSpeechConfigs = {};
                                        var end2 = reader.uint32() + reader.pos;
                                        key = "";
                                        value = null;
                                        while (reader.pos < end2) {
                                            var tag2 = reader.uint32();
                                            switch (tag2 >>> 3) {
                                            case 1:
                                                key = reader.string();
                                                break;
                                            case 2:
                                                value = $root.google.cloud.dialogflow.v2.SynthesizeSpeechConfig.decode(reader, reader.uint32());
                                                break;
                                            default:
                                                reader.skipType(tag2 & 7);
                                                break;
                                            }
                                        }
                                        message.synthesizeSpeechConfigs[key] = value;
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a TextToSpeechSettings message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.TextToSpeechSettings
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.TextToSpeechSettings} TextToSpeechSettings
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        TextToSpeechSettings.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a TextToSpeechSettings message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.TextToSpeechSettings
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        TextToSpeechSettings.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.enableTextToSpeech != null && message.hasOwnProperty("enableTextToSpeech"))
                                if (typeof message.enableTextToSpeech !== "boolean")
                                    return "enableTextToSpeech: boolean expected";
                            if (message.outputAudioEncoding != null && message.hasOwnProperty("outputAudioEncoding"))
                                switch (message.outputAudioEncoding) {
                                default:
                                    return "outputAudioEncoding: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 4:
                                case 3:
                                case 5:
                                case 6:
                                    break;
                                }
                            if (message.sampleRateHertz != null && message.hasOwnProperty("sampleRateHertz"))
                                if (!$util.isInteger(message.sampleRateHertz))
                                    return "sampleRateHertz: integer expected";
                            if (message.synthesizeSpeechConfigs != null && message.hasOwnProperty("synthesizeSpeechConfigs")) {
                                if (!$util.isObject(message.synthesizeSpeechConfigs))
                                    return "synthesizeSpeechConfigs: object expected";
                                var key = Object.keys(message.synthesizeSpeechConfigs);
                                for (var i = 0; i < key.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.SynthesizeSpeechConfig.verify(message.synthesizeSpeechConfigs[key[i]]);
                                    if (error)
                                        return "synthesizeSpeechConfigs." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates a TextToSpeechSettings message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.TextToSpeechSettings
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.TextToSpeechSettings} TextToSpeechSettings
                         */
                        TextToSpeechSettings.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.TextToSpeechSettings)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.TextToSpeechSettings();
                            if (object.enableTextToSpeech != null)
                                message.enableTextToSpeech = Boolean(object.enableTextToSpeech);
                            switch (object.outputAudioEncoding) {
                            default:
                                if (typeof object.outputAudioEncoding === "number") {
                                    message.outputAudioEncoding = object.outputAudioEncoding;
                                    break;
                                }
                                break;
                            case "OUTPUT_AUDIO_ENCODING_UNSPECIFIED":
                            case 0:
                                message.outputAudioEncoding = 0;
                                break;
                            case "OUTPUT_AUDIO_ENCODING_LINEAR_16":
                            case 1:
                                message.outputAudioEncoding = 1;
                                break;
                            case "OUTPUT_AUDIO_ENCODING_MP3":
                            case 2:
                                message.outputAudioEncoding = 2;
                                break;
                            case "OUTPUT_AUDIO_ENCODING_MP3_64_KBPS":
                            case 4:
                                message.outputAudioEncoding = 4;
                                break;
                            case "OUTPUT_AUDIO_ENCODING_OGG_OPUS":
                            case 3:
                                message.outputAudioEncoding = 3;
                                break;
                            case "OUTPUT_AUDIO_ENCODING_MULAW":
                            case 5:
                                message.outputAudioEncoding = 5;
                                break;
                            case "OUTPUT_AUDIO_ENCODING_ALAW":
                            case 6:
                                message.outputAudioEncoding = 6;
                                break;
                            }
                            if (object.sampleRateHertz != null)
                                message.sampleRateHertz = object.sampleRateHertz | 0;
                            if (object.synthesizeSpeechConfigs) {
                                if (typeof object.synthesizeSpeechConfigs !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.TextToSpeechSettings.synthesizeSpeechConfigs: object expected");
                                message.synthesizeSpeechConfigs = {};
                                for (var keys = Object.keys(object.synthesizeSpeechConfigs), i = 0; i < keys.length; ++i) {
                                    if (typeof object.synthesizeSpeechConfigs[keys[i]] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.TextToSpeechSettings.synthesizeSpeechConfigs: object expected");
                                    message.synthesizeSpeechConfigs[keys[i]] = $root.google.cloud.dialogflow.v2.SynthesizeSpeechConfig.fromObject(object.synthesizeSpeechConfigs[keys[i]]);
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a TextToSpeechSettings message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.TextToSpeechSettings
                         * @static
                         * @param {google.cloud.dialogflow.v2.TextToSpeechSettings} message TextToSpeechSettings
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        TextToSpeechSettings.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.objects || options.defaults)
                                object.synthesizeSpeechConfigs = {};
                            if (options.defaults) {
                                object.enableTextToSpeech = false;
                                object.outputAudioEncoding = options.enums === String ? "OUTPUT_AUDIO_ENCODING_UNSPECIFIED" : 0;
                                object.sampleRateHertz = 0;
                            }
                            if (message.enableTextToSpeech != null && message.hasOwnProperty("enableTextToSpeech"))
                                object.enableTextToSpeech = message.enableTextToSpeech;
                            if (message.outputAudioEncoding != null && message.hasOwnProperty("outputAudioEncoding"))
                                object.outputAudioEncoding = options.enums === String ? $root.google.cloud.dialogflow.v2.OutputAudioEncoding[message.outputAudioEncoding] === undefined ? message.outputAudioEncoding : $root.google.cloud.dialogflow.v2.OutputAudioEncoding[message.outputAudioEncoding] : message.outputAudioEncoding;
                            if (message.sampleRateHertz != null && message.hasOwnProperty("sampleRateHertz"))
                                object.sampleRateHertz = message.sampleRateHertz;
                            var keys2;
                            if (message.synthesizeSpeechConfigs && (keys2 = Object.keys(message.synthesizeSpeechConfigs)).length) {
                                object.synthesizeSpeechConfigs = {};
                                for (var j = 0; j < keys2.length; ++j)
                                    object.synthesizeSpeechConfigs[keys2[j]] = $root.google.cloud.dialogflow.v2.SynthesizeSpeechConfig.toObject(message.synthesizeSpeechConfigs[keys2[j]], options);
                            }
                            return object;
                        };
    
                        /**
                         * Converts this TextToSpeechSettings to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.TextToSpeechSettings
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        TextToSpeechSettings.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for TextToSpeechSettings
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.TextToSpeechSettings
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        TextToSpeechSettings.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.TextToSpeechSettings";
                        };
    
                        return TextToSpeechSettings;
                    })();
    
                    v2.ListEnvironmentsRequest = (function() {
    
                        /**
                         * Properties of a ListEnvironmentsRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IListEnvironmentsRequest
                         * @property {string|null} [parent] ListEnvironmentsRequest parent
                         * @property {number|null} [pageSize] ListEnvironmentsRequest pageSize
                         * @property {string|null} [pageToken] ListEnvironmentsRequest pageToken
                         */
    
                        /**
                         * Constructs a new ListEnvironmentsRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a ListEnvironmentsRequest.
                         * @implements IListEnvironmentsRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IListEnvironmentsRequest=} [properties] Properties to set
                         */
                        function ListEnvironmentsRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListEnvironmentsRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.ListEnvironmentsRequest
                         * @instance
                         */
                        ListEnvironmentsRequest.prototype.parent = "";
    
                        /**
                         * ListEnvironmentsRequest pageSize.
                         * @member {number} pageSize
                         * @memberof google.cloud.dialogflow.v2.ListEnvironmentsRequest
                         * @instance
                         */
                        ListEnvironmentsRequest.prototype.pageSize = 0;
    
                        /**
                         * ListEnvironmentsRequest pageToken.
                         * @member {string} pageToken
                         * @memberof google.cloud.dialogflow.v2.ListEnvironmentsRequest
                         * @instance
                         */
                        ListEnvironmentsRequest.prototype.pageToken = "";
    
                        /**
                         * Creates a new ListEnvironmentsRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ListEnvironmentsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListEnvironmentsRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ListEnvironmentsRequest} ListEnvironmentsRequest instance
                         */
                        ListEnvironmentsRequest.create = function create(properties) {
                            return new ListEnvironmentsRequest(properties);
                        };
    
                        /**
                         * Encodes the specified ListEnvironmentsRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.ListEnvironmentsRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ListEnvironmentsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListEnvironmentsRequest} message ListEnvironmentsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListEnvironmentsRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.pageSize != null && Object.hasOwnProperty.call(message, "pageSize"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.pageSize);
                            if (message.pageToken != null && Object.hasOwnProperty.call(message, "pageToken"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.pageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListEnvironmentsRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ListEnvironmentsRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListEnvironmentsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListEnvironmentsRequest} message ListEnvironmentsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListEnvironmentsRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListEnvironmentsRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ListEnvironmentsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ListEnvironmentsRequest} ListEnvironmentsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListEnvironmentsRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ListEnvironmentsRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.pageSize = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.pageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListEnvironmentsRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListEnvironmentsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ListEnvironmentsRequest} ListEnvironmentsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListEnvironmentsRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListEnvironmentsRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ListEnvironmentsRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListEnvironmentsRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                if (!$util.isInteger(message.pageSize))
                                    return "pageSize: integer expected";
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                if (!$util.isString(message.pageToken))
                                    return "pageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListEnvironmentsRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ListEnvironmentsRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ListEnvironmentsRequest} ListEnvironmentsRequest
                         */
                        ListEnvironmentsRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ListEnvironmentsRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ListEnvironmentsRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.pageSize != null)
                                message.pageSize = object.pageSize | 0;
                            if (object.pageToken != null)
                                message.pageToken = String(object.pageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListEnvironmentsRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ListEnvironmentsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ListEnvironmentsRequest} message ListEnvironmentsRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListEnvironmentsRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.pageSize = 0;
                                object.pageToken = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                object.pageSize = message.pageSize;
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                object.pageToken = message.pageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListEnvironmentsRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ListEnvironmentsRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListEnvironmentsRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListEnvironmentsRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ListEnvironmentsRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListEnvironmentsRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ListEnvironmentsRequest";
                        };
    
                        return ListEnvironmentsRequest;
                    })();
    
                    v2.ListEnvironmentsResponse = (function() {
    
                        /**
                         * Properties of a ListEnvironmentsResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IListEnvironmentsResponse
                         * @property {Array.<google.cloud.dialogflow.v2.IEnvironment>|null} [environments] ListEnvironmentsResponse environments
                         * @property {string|null} [nextPageToken] ListEnvironmentsResponse nextPageToken
                         */
    
                        /**
                         * Constructs a new ListEnvironmentsResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a ListEnvironmentsResponse.
                         * @implements IListEnvironmentsResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IListEnvironmentsResponse=} [properties] Properties to set
                         */
                        function ListEnvironmentsResponse(properties) {
                            this.environments = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListEnvironmentsResponse environments.
                         * @member {Array.<google.cloud.dialogflow.v2.IEnvironment>} environments
                         * @memberof google.cloud.dialogflow.v2.ListEnvironmentsResponse
                         * @instance
                         */
                        ListEnvironmentsResponse.prototype.environments = $util.emptyArray;
    
                        /**
                         * ListEnvironmentsResponse nextPageToken.
                         * @member {string} nextPageToken
                         * @memberof google.cloud.dialogflow.v2.ListEnvironmentsResponse
                         * @instance
                         */
                        ListEnvironmentsResponse.prototype.nextPageToken = "";
    
                        /**
                         * Creates a new ListEnvironmentsResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ListEnvironmentsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListEnvironmentsResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ListEnvironmentsResponse} ListEnvironmentsResponse instance
                         */
                        ListEnvironmentsResponse.create = function create(properties) {
                            return new ListEnvironmentsResponse(properties);
                        };
    
                        /**
                         * Encodes the specified ListEnvironmentsResponse message. Does not implicitly {@link google.cloud.dialogflow.v2.ListEnvironmentsResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ListEnvironmentsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListEnvironmentsResponse} message ListEnvironmentsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListEnvironmentsResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.environments != null && message.environments.length)
                                for (var i = 0; i < message.environments.length; ++i)
                                    $root.google.cloud.dialogflow.v2.Environment.encode(message.environments[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.nextPageToken != null && Object.hasOwnProperty.call(message, "nextPageToken"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.nextPageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListEnvironmentsResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ListEnvironmentsResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListEnvironmentsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListEnvironmentsResponse} message ListEnvironmentsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListEnvironmentsResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListEnvironmentsResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ListEnvironmentsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ListEnvironmentsResponse} ListEnvironmentsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListEnvironmentsResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ListEnvironmentsResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.environments && message.environments.length))
                                            message.environments = [];
                                        message.environments.push($root.google.cloud.dialogflow.v2.Environment.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 2: {
                                        message.nextPageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListEnvironmentsResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListEnvironmentsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ListEnvironmentsResponse} ListEnvironmentsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListEnvironmentsResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListEnvironmentsResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ListEnvironmentsResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListEnvironmentsResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.environments != null && message.hasOwnProperty("environments")) {
                                if (!Array.isArray(message.environments))
                                    return "environments: array expected";
                                for (var i = 0; i < message.environments.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.Environment.verify(message.environments[i]);
                                    if (error)
                                        return "environments." + error;
                                }
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                if (!$util.isString(message.nextPageToken))
                                    return "nextPageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListEnvironmentsResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ListEnvironmentsResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ListEnvironmentsResponse} ListEnvironmentsResponse
                         */
                        ListEnvironmentsResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ListEnvironmentsResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ListEnvironmentsResponse();
                            if (object.environments) {
                                if (!Array.isArray(object.environments))
                                    throw TypeError(".google.cloud.dialogflow.v2.ListEnvironmentsResponse.environments: array expected");
                                message.environments = [];
                                for (var i = 0; i < object.environments.length; ++i) {
                                    if (typeof object.environments[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.ListEnvironmentsResponse.environments: object expected");
                                    message.environments[i] = $root.google.cloud.dialogflow.v2.Environment.fromObject(object.environments[i]);
                                }
                            }
                            if (object.nextPageToken != null)
                                message.nextPageToken = String(object.nextPageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListEnvironmentsResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ListEnvironmentsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.ListEnvironmentsResponse} message ListEnvironmentsResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListEnvironmentsResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.environments = [];
                            if (options.defaults)
                                object.nextPageToken = "";
                            if (message.environments && message.environments.length) {
                                object.environments = [];
                                for (var j = 0; j < message.environments.length; ++j)
                                    object.environments[j] = $root.google.cloud.dialogflow.v2.Environment.toObject(message.environments[j], options);
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                object.nextPageToken = message.nextPageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListEnvironmentsResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ListEnvironmentsResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListEnvironmentsResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListEnvironmentsResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ListEnvironmentsResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListEnvironmentsResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ListEnvironmentsResponse";
                        };
    
                        return ListEnvironmentsResponse;
                    })();
    
                    v2.GetEnvironmentRequest = (function() {
    
                        /**
                         * Properties of a GetEnvironmentRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IGetEnvironmentRequest
                         * @property {string|null} [name] GetEnvironmentRequest name
                         */
    
                        /**
                         * Constructs a new GetEnvironmentRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a GetEnvironmentRequest.
                         * @implements IGetEnvironmentRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IGetEnvironmentRequest=} [properties] Properties to set
                         */
                        function GetEnvironmentRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GetEnvironmentRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2.GetEnvironmentRequest
                         * @instance
                         */
                        GetEnvironmentRequest.prototype.name = "";
    
                        /**
                         * Creates a new GetEnvironmentRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.GetEnvironmentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetEnvironmentRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.GetEnvironmentRequest} GetEnvironmentRequest instance
                         */
                        GetEnvironmentRequest.create = function create(properties) {
                            return new GetEnvironmentRequest(properties);
                        };
    
                        /**
                         * Encodes the specified GetEnvironmentRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.GetEnvironmentRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.GetEnvironmentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetEnvironmentRequest} message GetEnvironmentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetEnvironmentRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GetEnvironmentRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.GetEnvironmentRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GetEnvironmentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetEnvironmentRequest} message GetEnvironmentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetEnvironmentRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GetEnvironmentRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.GetEnvironmentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.GetEnvironmentRequest} GetEnvironmentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetEnvironmentRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.GetEnvironmentRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GetEnvironmentRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GetEnvironmentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.GetEnvironmentRequest} GetEnvironmentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetEnvironmentRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GetEnvironmentRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.GetEnvironmentRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GetEnvironmentRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a GetEnvironmentRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.GetEnvironmentRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.GetEnvironmentRequest} GetEnvironmentRequest
                         */
                        GetEnvironmentRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.GetEnvironmentRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.GetEnvironmentRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GetEnvironmentRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.GetEnvironmentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.GetEnvironmentRequest} message GetEnvironmentRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GetEnvironmentRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.name = "";
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            return object;
                        };
    
                        /**
                         * Converts this GetEnvironmentRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.GetEnvironmentRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GetEnvironmentRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GetEnvironmentRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.GetEnvironmentRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GetEnvironmentRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.GetEnvironmentRequest";
                        };
    
                        return GetEnvironmentRequest;
                    })();
    
                    v2.CreateEnvironmentRequest = (function() {
    
                        /**
                         * Properties of a CreateEnvironmentRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ICreateEnvironmentRequest
                         * @property {string|null} [parent] CreateEnvironmentRequest parent
                         * @property {google.cloud.dialogflow.v2.IEnvironment|null} [environment] CreateEnvironmentRequest environment
                         * @property {string|null} [environmentId] CreateEnvironmentRequest environmentId
                         */
    
                        /**
                         * Constructs a new CreateEnvironmentRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a CreateEnvironmentRequest.
                         * @implements ICreateEnvironmentRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ICreateEnvironmentRequest=} [properties] Properties to set
                         */
                        function CreateEnvironmentRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * CreateEnvironmentRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.CreateEnvironmentRequest
                         * @instance
                         */
                        CreateEnvironmentRequest.prototype.parent = "";
    
                        /**
                         * CreateEnvironmentRequest environment.
                         * @member {google.cloud.dialogflow.v2.IEnvironment|null|undefined} environment
                         * @memberof google.cloud.dialogflow.v2.CreateEnvironmentRequest
                         * @instance
                         */
                        CreateEnvironmentRequest.prototype.environment = null;
    
                        /**
                         * CreateEnvironmentRequest environmentId.
                         * @member {string} environmentId
                         * @memberof google.cloud.dialogflow.v2.CreateEnvironmentRequest
                         * @instance
                         */
                        CreateEnvironmentRequest.prototype.environmentId = "";
    
                        /**
                         * Creates a new CreateEnvironmentRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.CreateEnvironmentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICreateEnvironmentRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.CreateEnvironmentRequest} CreateEnvironmentRequest instance
                         */
                        CreateEnvironmentRequest.create = function create(properties) {
                            return new CreateEnvironmentRequest(properties);
                        };
    
                        /**
                         * Encodes the specified CreateEnvironmentRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.CreateEnvironmentRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.CreateEnvironmentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICreateEnvironmentRequest} message CreateEnvironmentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateEnvironmentRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.environment != null && Object.hasOwnProperty.call(message, "environment"))
                                $root.google.cloud.dialogflow.v2.Environment.encode(message.environment, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.environmentId != null && Object.hasOwnProperty.call(message, "environmentId"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.environmentId);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified CreateEnvironmentRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.CreateEnvironmentRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.CreateEnvironmentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICreateEnvironmentRequest} message CreateEnvironmentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateEnvironmentRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a CreateEnvironmentRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.CreateEnvironmentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.CreateEnvironmentRequest} CreateEnvironmentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateEnvironmentRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.CreateEnvironmentRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.environment = $root.google.cloud.dialogflow.v2.Environment.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 3: {
                                        message.environmentId = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a CreateEnvironmentRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.CreateEnvironmentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.CreateEnvironmentRequest} CreateEnvironmentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateEnvironmentRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a CreateEnvironmentRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.CreateEnvironmentRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        CreateEnvironmentRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.environment != null && message.hasOwnProperty("environment")) {
                                var error = $root.google.cloud.dialogflow.v2.Environment.verify(message.environment);
                                if (error)
                                    return "environment." + error;
                            }
                            if (message.environmentId != null && message.hasOwnProperty("environmentId"))
                                if (!$util.isString(message.environmentId))
                                    return "environmentId: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a CreateEnvironmentRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.CreateEnvironmentRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.CreateEnvironmentRequest} CreateEnvironmentRequest
                         */
                        CreateEnvironmentRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.CreateEnvironmentRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.CreateEnvironmentRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.environment != null) {
                                if (typeof object.environment !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.CreateEnvironmentRequest.environment: object expected");
                                message.environment = $root.google.cloud.dialogflow.v2.Environment.fromObject(object.environment);
                            }
                            if (object.environmentId != null)
                                message.environmentId = String(object.environmentId);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a CreateEnvironmentRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.CreateEnvironmentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.CreateEnvironmentRequest} message CreateEnvironmentRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        CreateEnvironmentRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.environment = null;
                                object.environmentId = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.environment != null && message.hasOwnProperty("environment"))
                                object.environment = $root.google.cloud.dialogflow.v2.Environment.toObject(message.environment, options);
                            if (message.environmentId != null && message.hasOwnProperty("environmentId"))
                                object.environmentId = message.environmentId;
                            return object;
                        };
    
                        /**
                         * Converts this CreateEnvironmentRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.CreateEnvironmentRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        CreateEnvironmentRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for CreateEnvironmentRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.CreateEnvironmentRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        CreateEnvironmentRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.CreateEnvironmentRequest";
                        };
    
                        return CreateEnvironmentRequest;
                    })();
    
                    v2.UpdateEnvironmentRequest = (function() {
    
                        /**
                         * Properties of an UpdateEnvironmentRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IUpdateEnvironmentRequest
                         * @property {google.cloud.dialogflow.v2.IEnvironment|null} [environment] UpdateEnvironmentRequest environment
                         * @property {google.protobuf.IFieldMask|null} [updateMask] UpdateEnvironmentRequest updateMask
                         * @property {boolean|null} [allowLoadToDraftAndDiscardChanges] UpdateEnvironmentRequest allowLoadToDraftAndDiscardChanges
                         */
    
                        /**
                         * Constructs a new UpdateEnvironmentRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an UpdateEnvironmentRequest.
                         * @implements IUpdateEnvironmentRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IUpdateEnvironmentRequest=} [properties] Properties to set
                         */
                        function UpdateEnvironmentRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * UpdateEnvironmentRequest environment.
                         * @member {google.cloud.dialogflow.v2.IEnvironment|null|undefined} environment
                         * @memberof google.cloud.dialogflow.v2.UpdateEnvironmentRequest
                         * @instance
                         */
                        UpdateEnvironmentRequest.prototype.environment = null;
    
                        /**
                         * UpdateEnvironmentRequest updateMask.
                         * @member {google.protobuf.IFieldMask|null|undefined} updateMask
                         * @memberof google.cloud.dialogflow.v2.UpdateEnvironmentRequest
                         * @instance
                         */
                        UpdateEnvironmentRequest.prototype.updateMask = null;
    
                        /**
                         * UpdateEnvironmentRequest allowLoadToDraftAndDiscardChanges.
                         * @member {boolean} allowLoadToDraftAndDiscardChanges
                         * @memberof google.cloud.dialogflow.v2.UpdateEnvironmentRequest
                         * @instance
                         */
                        UpdateEnvironmentRequest.prototype.allowLoadToDraftAndDiscardChanges = false;
    
                        /**
                         * Creates a new UpdateEnvironmentRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.UpdateEnvironmentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IUpdateEnvironmentRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.UpdateEnvironmentRequest} UpdateEnvironmentRequest instance
                         */
                        UpdateEnvironmentRequest.create = function create(properties) {
                            return new UpdateEnvironmentRequest(properties);
                        };
    
                        /**
                         * Encodes the specified UpdateEnvironmentRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.UpdateEnvironmentRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.UpdateEnvironmentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IUpdateEnvironmentRequest} message UpdateEnvironmentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UpdateEnvironmentRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.environment != null && Object.hasOwnProperty.call(message, "environment"))
                                $root.google.cloud.dialogflow.v2.Environment.encode(message.environment, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.updateMask != null && Object.hasOwnProperty.call(message, "updateMask"))
                                $root.google.protobuf.FieldMask.encode(message.updateMask, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.allowLoadToDraftAndDiscardChanges != null && Object.hasOwnProperty.call(message, "allowLoadToDraftAndDiscardChanges"))
                                writer.uint32(/* id 3, wireType 0 =*/24).bool(message.allowLoadToDraftAndDiscardChanges);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified UpdateEnvironmentRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.UpdateEnvironmentRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.UpdateEnvironmentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IUpdateEnvironmentRequest} message UpdateEnvironmentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UpdateEnvironmentRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an UpdateEnvironmentRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.UpdateEnvironmentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.UpdateEnvironmentRequest} UpdateEnvironmentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UpdateEnvironmentRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.UpdateEnvironmentRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.environment = $root.google.cloud.dialogflow.v2.Environment.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.updateMask = $root.google.protobuf.FieldMask.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 3: {
                                        message.allowLoadToDraftAndDiscardChanges = reader.bool();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an UpdateEnvironmentRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.UpdateEnvironmentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.UpdateEnvironmentRequest} UpdateEnvironmentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UpdateEnvironmentRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an UpdateEnvironmentRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.UpdateEnvironmentRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        UpdateEnvironmentRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.environment != null && message.hasOwnProperty("environment")) {
                                var error = $root.google.cloud.dialogflow.v2.Environment.verify(message.environment);
                                if (error)
                                    return "environment." + error;
                            }
                            if (message.updateMask != null && message.hasOwnProperty("updateMask")) {
                                var error = $root.google.protobuf.FieldMask.verify(message.updateMask);
                                if (error)
                                    return "updateMask." + error;
                            }
                            if (message.allowLoadToDraftAndDiscardChanges != null && message.hasOwnProperty("allowLoadToDraftAndDiscardChanges"))
                                if (typeof message.allowLoadToDraftAndDiscardChanges !== "boolean")
                                    return "allowLoadToDraftAndDiscardChanges: boolean expected";
                            return null;
                        };
    
                        /**
                         * Creates an UpdateEnvironmentRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.UpdateEnvironmentRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.UpdateEnvironmentRequest} UpdateEnvironmentRequest
                         */
                        UpdateEnvironmentRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.UpdateEnvironmentRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.UpdateEnvironmentRequest();
                            if (object.environment != null) {
                                if (typeof object.environment !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.UpdateEnvironmentRequest.environment: object expected");
                                message.environment = $root.google.cloud.dialogflow.v2.Environment.fromObject(object.environment);
                            }
                            if (object.updateMask != null) {
                                if (typeof object.updateMask !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.UpdateEnvironmentRequest.updateMask: object expected");
                                message.updateMask = $root.google.protobuf.FieldMask.fromObject(object.updateMask);
                            }
                            if (object.allowLoadToDraftAndDiscardChanges != null)
                                message.allowLoadToDraftAndDiscardChanges = Boolean(object.allowLoadToDraftAndDiscardChanges);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an UpdateEnvironmentRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.UpdateEnvironmentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.UpdateEnvironmentRequest} message UpdateEnvironmentRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        UpdateEnvironmentRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.environment = null;
                                object.updateMask = null;
                                object.allowLoadToDraftAndDiscardChanges = false;
                            }
                            if (message.environment != null && message.hasOwnProperty("environment"))
                                object.environment = $root.google.cloud.dialogflow.v2.Environment.toObject(message.environment, options);
                            if (message.updateMask != null && message.hasOwnProperty("updateMask"))
                                object.updateMask = $root.google.protobuf.FieldMask.toObject(message.updateMask, options);
                            if (message.allowLoadToDraftAndDiscardChanges != null && message.hasOwnProperty("allowLoadToDraftAndDiscardChanges"))
                                object.allowLoadToDraftAndDiscardChanges = message.allowLoadToDraftAndDiscardChanges;
                            return object;
                        };
    
                        /**
                         * Converts this UpdateEnvironmentRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.UpdateEnvironmentRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        UpdateEnvironmentRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for UpdateEnvironmentRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.UpdateEnvironmentRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        UpdateEnvironmentRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.UpdateEnvironmentRequest";
                        };
    
                        return UpdateEnvironmentRequest;
                    })();
    
                    v2.DeleteEnvironmentRequest = (function() {
    
                        /**
                         * Properties of a DeleteEnvironmentRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IDeleteEnvironmentRequest
                         * @property {string|null} [name] DeleteEnvironmentRequest name
                         */
    
                        /**
                         * Constructs a new DeleteEnvironmentRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a DeleteEnvironmentRequest.
                         * @implements IDeleteEnvironmentRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IDeleteEnvironmentRequest=} [properties] Properties to set
                         */
                        function DeleteEnvironmentRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * DeleteEnvironmentRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2.DeleteEnvironmentRequest
                         * @instance
                         */
                        DeleteEnvironmentRequest.prototype.name = "";
    
                        /**
                         * Creates a new DeleteEnvironmentRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.DeleteEnvironmentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDeleteEnvironmentRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.DeleteEnvironmentRequest} DeleteEnvironmentRequest instance
                         */
                        DeleteEnvironmentRequest.create = function create(properties) {
                            return new DeleteEnvironmentRequest(properties);
                        };
    
                        /**
                         * Encodes the specified DeleteEnvironmentRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.DeleteEnvironmentRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.DeleteEnvironmentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDeleteEnvironmentRequest} message DeleteEnvironmentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteEnvironmentRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified DeleteEnvironmentRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.DeleteEnvironmentRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.DeleteEnvironmentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDeleteEnvironmentRequest} message DeleteEnvironmentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteEnvironmentRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a DeleteEnvironmentRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.DeleteEnvironmentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.DeleteEnvironmentRequest} DeleteEnvironmentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteEnvironmentRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.DeleteEnvironmentRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a DeleteEnvironmentRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.DeleteEnvironmentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.DeleteEnvironmentRequest} DeleteEnvironmentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteEnvironmentRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a DeleteEnvironmentRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.DeleteEnvironmentRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        DeleteEnvironmentRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a DeleteEnvironmentRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.DeleteEnvironmentRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.DeleteEnvironmentRequest} DeleteEnvironmentRequest
                         */
                        DeleteEnvironmentRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.DeleteEnvironmentRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.DeleteEnvironmentRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a DeleteEnvironmentRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.DeleteEnvironmentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.DeleteEnvironmentRequest} message DeleteEnvironmentRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        DeleteEnvironmentRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.name = "";
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            return object;
                        };
    
                        /**
                         * Converts this DeleteEnvironmentRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.DeleteEnvironmentRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        DeleteEnvironmentRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for DeleteEnvironmentRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.DeleteEnvironmentRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        DeleteEnvironmentRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.DeleteEnvironmentRequest";
                        };
    
                        return DeleteEnvironmentRequest;
                    })();
    
                    v2.GetEnvironmentHistoryRequest = (function() {
    
                        /**
                         * Properties of a GetEnvironmentHistoryRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IGetEnvironmentHistoryRequest
                         * @property {string|null} [parent] GetEnvironmentHistoryRequest parent
                         * @property {number|null} [pageSize] GetEnvironmentHistoryRequest pageSize
                         * @property {string|null} [pageToken] GetEnvironmentHistoryRequest pageToken
                         */
    
                        /**
                         * Constructs a new GetEnvironmentHistoryRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a GetEnvironmentHistoryRequest.
                         * @implements IGetEnvironmentHistoryRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IGetEnvironmentHistoryRequest=} [properties] Properties to set
                         */
                        function GetEnvironmentHistoryRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GetEnvironmentHistoryRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.GetEnvironmentHistoryRequest
                         * @instance
                         */
                        GetEnvironmentHistoryRequest.prototype.parent = "";
    
                        /**
                         * GetEnvironmentHistoryRequest pageSize.
                         * @member {number} pageSize
                         * @memberof google.cloud.dialogflow.v2.GetEnvironmentHistoryRequest
                         * @instance
                         */
                        GetEnvironmentHistoryRequest.prototype.pageSize = 0;
    
                        /**
                         * GetEnvironmentHistoryRequest pageToken.
                         * @member {string} pageToken
                         * @memberof google.cloud.dialogflow.v2.GetEnvironmentHistoryRequest
                         * @instance
                         */
                        GetEnvironmentHistoryRequest.prototype.pageToken = "";
    
                        /**
                         * Creates a new GetEnvironmentHistoryRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.GetEnvironmentHistoryRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetEnvironmentHistoryRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.GetEnvironmentHistoryRequest} GetEnvironmentHistoryRequest instance
                         */
                        GetEnvironmentHistoryRequest.create = function create(properties) {
                            return new GetEnvironmentHistoryRequest(properties);
                        };
    
                        /**
                         * Encodes the specified GetEnvironmentHistoryRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.GetEnvironmentHistoryRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.GetEnvironmentHistoryRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetEnvironmentHistoryRequest} message GetEnvironmentHistoryRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetEnvironmentHistoryRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.pageSize != null && Object.hasOwnProperty.call(message, "pageSize"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.pageSize);
                            if (message.pageToken != null && Object.hasOwnProperty.call(message, "pageToken"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.pageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GetEnvironmentHistoryRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.GetEnvironmentHistoryRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GetEnvironmentHistoryRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetEnvironmentHistoryRequest} message GetEnvironmentHistoryRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetEnvironmentHistoryRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GetEnvironmentHistoryRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.GetEnvironmentHistoryRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.GetEnvironmentHistoryRequest} GetEnvironmentHistoryRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetEnvironmentHistoryRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.GetEnvironmentHistoryRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.pageSize = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.pageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GetEnvironmentHistoryRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GetEnvironmentHistoryRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.GetEnvironmentHistoryRequest} GetEnvironmentHistoryRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetEnvironmentHistoryRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GetEnvironmentHistoryRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.GetEnvironmentHistoryRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GetEnvironmentHistoryRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                if (!$util.isInteger(message.pageSize))
                                    return "pageSize: integer expected";
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                if (!$util.isString(message.pageToken))
                                    return "pageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a GetEnvironmentHistoryRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.GetEnvironmentHistoryRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.GetEnvironmentHistoryRequest} GetEnvironmentHistoryRequest
                         */
                        GetEnvironmentHistoryRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.GetEnvironmentHistoryRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.GetEnvironmentHistoryRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.pageSize != null)
                                message.pageSize = object.pageSize | 0;
                            if (object.pageToken != null)
                                message.pageToken = String(object.pageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GetEnvironmentHistoryRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.GetEnvironmentHistoryRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.GetEnvironmentHistoryRequest} message GetEnvironmentHistoryRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GetEnvironmentHistoryRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.pageSize = 0;
                                object.pageToken = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                object.pageSize = message.pageSize;
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                object.pageToken = message.pageToken;
                            return object;
                        };
    
                        /**
                         * Converts this GetEnvironmentHistoryRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.GetEnvironmentHistoryRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GetEnvironmentHistoryRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GetEnvironmentHistoryRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.GetEnvironmentHistoryRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GetEnvironmentHistoryRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.GetEnvironmentHistoryRequest";
                        };
    
                        return GetEnvironmentHistoryRequest;
                    })();
    
                    v2.EnvironmentHistory = (function() {
    
                        /**
                         * Properties of an EnvironmentHistory.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IEnvironmentHistory
                         * @property {string|null} [parent] EnvironmentHistory parent
                         * @property {Array.<google.cloud.dialogflow.v2.EnvironmentHistory.IEntry>|null} [entries] EnvironmentHistory entries
                         * @property {string|null} [nextPageToken] EnvironmentHistory nextPageToken
                         */
    
                        /**
                         * Constructs a new EnvironmentHistory.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an EnvironmentHistory.
                         * @implements IEnvironmentHistory
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IEnvironmentHistory=} [properties] Properties to set
                         */
                        function EnvironmentHistory(properties) {
                            this.entries = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * EnvironmentHistory parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.EnvironmentHistory
                         * @instance
                         */
                        EnvironmentHistory.prototype.parent = "";
    
                        /**
                         * EnvironmentHistory entries.
                         * @member {Array.<google.cloud.dialogflow.v2.EnvironmentHistory.IEntry>} entries
                         * @memberof google.cloud.dialogflow.v2.EnvironmentHistory
                         * @instance
                         */
                        EnvironmentHistory.prototype.entries = $util.emptyArray;
    
                        /**
                         * EnvironmentHistory nextPageToken.
                         * @member {string} nextPageToken
                         * @memberof google.cloud.dialogflow.v2.EnvironmentHistory
                         * @instance
                         */
                        EnvironmentHistory.prototype.nextPageToken = "";
    
                        /**
                         * Creates a new EnvironmentHistory instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.EnvironmentHistory
                         * @static
                         * @param {google.cloud.dialogflow.v2.IEnvironmentHistory=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.EnvironmentHistory} EnvironmentHistory instance
                         */
                        EnvironmentHistory.create = function create(properties) {
                            return new EnvironmentHistory(properties);
                        };
    
                        /**
                         * Encodes the specified EnvironmentHistory message. Does not implicitly {@link google.cloud.dialogflow.v2.EnvironmentHistory.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.EnvironmentHistory
                         * @static
                         * @param {google.cloud.dialogflow.v2.IEnvironmentHistory} message EnvironmentHistory message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        EnvironmentHistory.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.entries != null && message.entries.length)
                                for (var i = 0; i < message.entries.length; ++i)
                                    $root.google.cloud.dialogflow.v2.EnvironmentHistory.Entry.encode(message.entries[i], writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.nextPageToken != null && Object.hasOwnProperty.call(message, "nextPageToken"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.nextPageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified EnvironmentHistory message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.EnvironmentHistory.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.EnvironmentHistory
                         * @static
                         * @param {google.cloud.dialogflow.v2.IEnvironmentHistory} message EnvironmentHistory message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        EnvironmentHistory.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an EnvironmentHistory message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.EnvironmentHistory
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.EnvironmentHistory} EnvironmentHistory
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        EnvironmentHistory.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.EnvironmentHistory();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        if (!(message.entries && message.entries.length))
                                            message.entries = [];
                                        message.entries.push($root.google.cloud.dialogflow.v2.EnvironmentHistory.Entry.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 3: {
                                        message.nextPageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an EnvironmentHistory message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.EnvironmentHistory
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.EnvironmentHistory} EnvironmentHistory
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        EnvironmentHistory.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an EnvironmentHistory message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.EnvironmentHistory
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        EnvironmentHistory.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.entries != null && message.hasOwnProperty("entries")) {
                                if (!Array.isArray(message.entries))
                                    return "entries: array expected";
                                for (var i = 0; i < message.entries.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.EnvironmentHistory.Entry.verify(message.entries[i]);
                                    if (error)
                                        return "entries." + error;
                                }
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                if (!$util.isString(message.nextPageToken))
                                    return "nextPageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates an EnvironmentHistory message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.EnvironmentHistory
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.EnvironmentHistory} EnvironmentHistory
                         */
                        EnvironmentHistory.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.EnvironmentHistory)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.EnvironmentHistory();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.entries) {
                                if (!Array.isArray(object.entries))
                                    throw TypeError(".google.cloud.dialogflow.v2.EnvironmentHistory.entries: array expected");
                                message.entries = [];
                                for (var i = 0; i < object.entries.length; ++i) {
                                    if (typeof object.entries[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.EnvironmentHistory.entries: object expected");
                                    message.entries[i] = $root.google.cloud.dialogflow.v2.EnvironmentHistory.Entry.fromObject(object.entries[i]);
                                }
                            }
                            if (object.nextPageToken != null)
                                message.nextPageToken = String(object.nextPageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an EnvironmentHistory message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.EnvironmentHistory
                         * @static
                         * @param {google.cloud.dialogflow.v2.EnvironmentHistory} message EnvironmentHistory
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        EnvironmentHistory.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.entries = [];
                            if (options.defaults) {
                                object.parent = "";
                                object.nextPageToken = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.entries && message.entries.length) {
                                object.entries = [];
                                for (var j = 0; j < message.entries.length; ++j)
                                    object.entries[j] = $root.google.cloud.dialogflow.v2.EnvironmentHistory.Entry.toObject(message.entries[j], options);
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                object.nextPageToken = message.nextPageToken;
                            return object;
                        };
    
                        /**
                         * Converts this EnvironmentHistory to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.EnvironmentHistory
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        EnvironmentHistory.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for EnvironmentHistory
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.EnvironmentHistory
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        EnvironmentHistory.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.EnvironmentHistory";
                        };
    
                        EnvironmentHistory.Entry = (function() {
    
                            /**
                             * Properties of an Entry.
                             * @memberof google.cloud.dialogflow.v2.EnvironmentHistory
                             * @interface IEntry
                             * @property {string|null} [agentVersion] Entry agentVersion
                             * @property {string|null} [description] Entry description
                             * @property {google.protobuf.ITimestamp|null} [createTime] Entry createTime
                             */
    
                            /**
                             * Constructs a new Entry.
                             * @memberof google.cloud.dialogflow.v2.EnvironmentHistory
                             * @classdesc Represents an Entry.
                             * @implements IEntry
                             * @constructor
                             * @param {google.cloud.dialogflow.v2.EnvironmentHistory.IEntry=} [properties] Properties to set
                             */
                            function Entry(properties) {
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * Entry agentVersion.
                             * @member {string} agentVersion
                             * @memberof google.cloud.dialogflow.v2.EnvironmentHistory.Entry
                             * @instance
                             */
                            Entry.prototype.agentVersion = "";
    
                            /**
                             * Entry description.
                             * @member {string} description
                             * @memberof google.cloud.dialogflow.v2.EnvironmentHistory.Entry
                             * @instance
                             */
                            Entry.prototype.description = "";
    
                            /**
                             * Entry createTime.
                             * @member {google.protobuf.ITimestamp|null|undefined} createTime
                             * @memberof google.cloud.dialogflow.v2.EnvironmentHistory.Entry
                             * @instance
                             */
                            Entry.prototype.createTime = null;
    
                            /**
                             * Creates a new Entry instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2.EnvironmentHistory.Entry
                             * @static
                             * @param {google.cloud.dialogflow.v2.EnvironmentHistory.IEntry=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2.EnvironmentHistory.Entry} Entry instance
                             */
                            Entry.create = function create(properties) {
                                return new Entry(properties);
                            };
    
                            /**
                             * Encodes the specified Entry message. Does not implicitly {@link google.cloud.dialogflow.v2.EnvironmentHistory.Entry.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2.EnvironmentHistory.Entry
                             * @static
                             * @param {google.cloud.dialogflow.v2.EnvironmentHistory.IEntry} message Entry message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            Entry.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.agentVersion != null && Object.hasOwnProperty.call(message, "agentVersion"))
                                    writer.uint32(/* id 1, wireType 2 =*/10).string(message.agentVersion);
                                if (message.description != null && Object.hasOwnProperty.call(message, "description"))
                                    writer.uint32(/* id 2, wireType 2 =*/18).string(message.description);
                                if (message.createTime != null && Object.hasOwnProperty.call(message, "createTime"))
                                    $root.google.protobuf.Timestamp.encode(message.createTime, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                                return writer;
                            };
    
                            /**
                             * Encodes the specified Entry message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.EnvironmentHistory.Entry.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2.EnvironmentHistory.Entry
                             * @static
                             * @param {google.cloud.dialogflow.v2.EnvironmentHistory.IEntry} message Entry message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            Entry.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes an Entry message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2.EnvironmentHistory.Entry
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2.EnvironmentHistory.Entry} Entry
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            Entry.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.EnvironmentHistory.Entry();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.agentVersion = reader.string();
                                            break;
                                        }
                                    case 2: {
                                            message.description = reader.string();
                                            break;
                                        }
                                    case 3: {
                                            message.createTime = $root.google.protobuf.Timestamp.decode(reader, reader.uint32());
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes an Entry message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2.EnvironmentHistory.Entry
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2.EnvironmentHistory.Entry} Entry
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            Entry.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies an Entry message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2.EnvironmentHistory.Entry
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            Entry.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.agentVersion != null && message.hasOwnProperty("agentVersion"))
                                    if (!$util.isString(message.agentVersion))
                                        return "agentVersion: string expected";
                                if (message.description != null && message.hasOwnProperty("description"))
                                    if (!$util.isString(message.description))
                                        return "description: string expected";
                                if (message.createTime != null && message.hasOwnProperty("createTime")) {
                                    var error = $root.google.protobuf.Timestamp.verify(message.createTime);
                                    if (error)
                                        return "createTime." + error;
                                }
                                return null;
                            };
    
                            /**
                             * Creates an Entry message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2.EnvironmentHistory.Entry
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2.EnvironmentHistory.Entry} Entry
                             */
                            Entry.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2.EnvironmentHistory.Entry)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2.EnvironmentHistory.Entry();
                                if (object.agentVersion != null)
                                    message.agentVersion = String(object.agentVersion);
                                if (object.description != null)
                                    message.description = String(object.description);
                                if (object.createTime != null) {
                                    if (typeof object.createTime !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.EnvironmentHistory.Entry.createTime: object expected");
                                    message.createTime = $root.google.protobuf.Timestamp.fromObject(object.createTime);
                                }
                                return message;
                            };
    
                            /**
                             * Creates a plain object from an Entry message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2.EnvironmentHistory.Entry
                             * @static
                             * @param {google.cloud.dialogflow.v2.EnvironmentHistory.Entry} message Entry
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            Entry.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.defaults) {
                                    object.agentVersion = "";
                                    object.description = "";
                                    object.createTime = null;
                                }
                                if (message.agentVersion != null && message.hasOwnProperty("agentVersion"))
                                    object.agentVersion = message.agentVersion;
                                if (message.description != null && message.hasOwnProperty("description"))
                                    object.description = message.description;
                                if (message.createTime != null && message.hasOwnProperty("createTime"))
                                    object.createTime = $root.google.protobuf.Timestamp.toObject(message.createTime, options);
                                return object;
                            };
    
                            /**
                             * Converts this Entry to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2.EnvironmentHistory.Entry
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            Entry.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for Entry
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2.EnvironmentHistory.Entry
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            Entry.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2.EnvironmentHistory.Entry";
                            };
    
                            return Entry;
                        })();
    
                        return EnvironmentHistory;
                    })();
    
                    v2.Fulfillments = (function() {
    
                        /**
                         * Constructs a new Fulfillments service.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a Fulfillments
                         * @extends $protobuf.rpc.Service
                         * @constructor
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         */
                        function Fulfillments(rpcImpl, requestDelimited, responseDelimited) {
                            $protobuf.rpc.Service.call(this, rpcImpl, requestDelimited, responseDelimited);
                        }
    
                        (Fulfillments.prototype = Object.create($protobuf.rpc.Service.prototype)).constructor = Fulfillments;
    
                        /**
                         * Creates new Fulfillments service using the specified rpc implementation.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.Fulfillments
                         * @static
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         * @returns {Fulfillments} RPC service. Useful where requests and/or responses are streamed.
                         */
                        Fulfillments.create = function create(rpcImpl, requestDelimited, responseDelimited) {
                            return new this(rpcImpl, requestDelimited, responseDelimited);
                        };
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Fulfillments|getFulfillment}.
                         * @memberof google.cloud.dialogflow.v2.Fulfillments
                         * @typedef GetFulfillmentCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.Fulfillment} [response] Fulfillment
                         */
    
                        /**
                         * Calls GetFulfillment.
                         * @function getFulfillment
                         * @memberof google.cloud.dialogflow.v2.Fulfillments
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IGetFulfillmentRequest} request GetFulfillmentRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Fulfillments.GetFulfillmentCallback} callback Node-style callback called with the error, if any, and Fulfillment
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Fulfillments.prototype.getFulfillment = function getFulfillment(request, callback) {
                            return this.rpcCall(getFulfillment, $root.google.cloud.dialogflow.v2.GetFulfillmentRequest, $root.google.cloud.dialogflow.v2.Fulfillment, request, callback);
                        }, "name", { value: "GetFulfillment" });
    
                        /**
                         * Calls GetFulfillment.
                         * @function getFulfillment
                         * @memberof google.cloud.dialogflow.v2.Fulfillments
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IGetFulfillmentRequest} request GetFulfillmentRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.Fulfillment>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Fulfillments|updateFulfillment}.
                         * @memberof google.cloud.dialogflow.v2.Fulfillments
                         * @typedef UpdateFulfillmentCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.Fulfillment} [response] Fulfillment
                         */
    
                        /**
                         * Calls UpdateFulfillment.
                         * @function updateFulfillment
                         * @memberof google.cloud.dialogflow.v2.Fulfillments
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IUpdateFulfillmentRequest} request UpdateFulfillmentRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Fulfillments.UpdateFulfillmentCallback} callback Node-style callback called with the error, if any, and Fulfillment
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Fulfillments.prototype.updateFulfillment = function updateFulfillment(request, callback) {
                            return this.rpcCall(updateFulfillment, $root.google.cloud.dialogflow.v2.UpdateFulfillmentRequest, $root.google.cloud.dialogflow.v2.Fulfillment, request, callback);
                        }, "name", { value: "UpdateFulfillment" });
    
                        /**
                         * Calls UpdateFulfillment.
                         * @function updateFulfillment
                         * @memberof google.cloud.dialogflow.v2.Fulfillments
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IUpdateFulfillmentRequest} request UpdateFulfillmentRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.Fulfillment>} Promise
                         * @variation 2
                         */
    
                        return Fulfillments;
                    })();
    
                    v2.Fulfillment = (function() {
    
                        /**
                         * Properties of a Fulfillment.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IFulfillment
                         * @property {string|null} [name] Fulfillment name
                         * @property {string|null} [displayName] Fulfillment displayName
                         * @property {google.cloud.dialogflow.v2.Fulfillment.IGenericWebService|null} [genericWebService] Fulfillment genericWebService
                         * @property {boolean|null} [enabled] Fulfillment enabled
                         * @property {Array.<google.cloud.dialogflow.v2.Fulfillment.IFeature>|null} [features] Fulfillment features
                         */
    
                        /**
                         * Constructs a new Fulfillment.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a Fulfillment.
                         * @implements IFulfillment
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IFulfillment=} [properties] Properties to set
                         */
                        function Fulfillment(properties) {
                            this.features = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * Fulfillment name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2.Fulfillment
                         * @instance
                         */
                        Fulfillment.prototype.name = "";
    
                        /**
                         * Fulfillment displayName.
                         * @member {string} displayName
                         * @memberof google.cloud.dialogflow.v2.Fulfillment
                         * @instance
                         */
                        Fulfillment.prototype.displayName = "";
    
                        /**
                         * Fulfillment genericWebService.
                         * @member {google.cloud.dialogflow.v2.Fulfillment.IGenericWebService|null|undefined} genericWebService
                         * @memberof google.cloud.dialogflow.v2.Fulfillment
                         * @instance
                         */
                        Fulfillment.prototype.genericWebService = null;
    
                        /**
                         * Fulfillment enabled.
                         * @member {boolean} enabled
                         * @memberof google.cloud.dialogflow.v2.Fulfillment
                         * @instance
                         */
                        Fulfillment.prototype.enabled = false;
    
                        /**
                         * Fulfillment features.
                         * @member {Array.<google.cloud.dialogflow.v2.Fulfillment.IFeature>} features
                         * @memberof google.cloud.dialogflow.v2.Fulfillment
                         * @instance
                         */
                        Fulfillment.prototype.features = $util.emptyArray;
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * Fulfillment fulfillment.
                         * @member {"genericWebService"|undefined} fulfillment
                         * @memberof google.cloud.dialogflow.v2.Fulfillment
                         * @instance
                         */
                        Object.defineProperty(Fulfillment.prototype, "fulfillment", {
                            get: $util.oneOfGetter($oneOfFields = ["genericWebService"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new Fulfillment instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.Fulfillment
                         * @static
                         * @param {google.cloud.dialogflow.v2.IFulfillment=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.Fulfillment} Fulfillment instance
                         */
                        Fulfillment.create = function create(properties) {
                            return new Fulfillment(properties);
                        };
    
                        /**
                         * Encodes the specified Fulfillment message. Does not implicitly {@link google.cloud.dialogflow.v2.Fulfillment.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.Fulfillment
                         * @static
                         * @param {google.cloud.dialogflow.v2.IFulfillment} message Fulfillment message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        Fulfillment.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            if (message.displayName != null && Object.hasOwnProperty.call(message, "displayName"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.displayName);
                            if (message.genericWebService != null && Object.hasOwnProperty.call(message, "genericWebService"))
                                $root.google.cloud.dialogflow.v2.Fulfillment.GenericWebService.encode(message.genericWebService, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            if (message.enabled != null && Object.hasOwnProperty.call(message, "enabled"))
                                writer.uint32(/* id 4, wireType 0 =*/32).bool(message.enabled);
                            if (message.features != null && message.features.length)
                                for (var i = 0; i < message.features.length; ++i)
                                    $root.google.cloud.dialogflow.v2.Fulfillment.Feature.encode(message.features[i], writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified Fulfillment message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.Fulfillment.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.Fulfillment
                         * @static
                         * @param {google.cloud.dialogflow.v2.IFulfillment} message Fulfillment message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        Fulfillment.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a Fulfillment message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.Fulfillment
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.Fulfillment} Fulfillment
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        Fulfillment.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.Fulfillment();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.displayName = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.genericWebService = $root.google.cloud.dialogflow.v2.Fulfillment.GenericWebService.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 4: {
                                        message.enabled = reader.bool();
                                        break;
                                    }
                                case 5: {
                                        if (!(message.features && message.features.length))
                                            message.features = [];
                                        message.features.push($root.google.cloud.dialogflow.v2.Fulfillment.Feature.decode(reader, reader.uint32()));
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a Fulfillment message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.Fulfillment
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.Fulfillment} Fulfillment
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        Fulfillment.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a Fulfillment message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.Fulfillment
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        Fulfillment.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            if (message.displayName != null && message.hasOwnProperty("displayName"))
                                if (!$util.isString(message.displayName))
                                    return "displayName: string expected";
                            if (message.genericWebService != null && message.hasOwnProperty("genericWebService")) {
                                properties.fulfillment = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2.Fulfillment.GenericWebService.verify(message.genericWebService);
                                    if (error)
                                        return "genericWebService." + error;
                                }
                            }
                            if (message.enabled != null && message.hasOwnProperty("enabled"))
                                if (typeof message.enabled !== "boolean")
                                    return "enabled: boolean expected";
                            if (message.features != null && message.hasOwnProperty("features")) {
                                if (!Array.isArray(message.features))
                                    return "features: array expected";
                                for (var i = 0; i < message.features.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.Fulfillment.Feature.verify(message.features[i]);
                                    if (error)
                                        return "features." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates a Fulfillment message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.Fulfillment
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.Fulfillment} Fulfillment
                         */
                        Fulfillment.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.Fulfillment)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.Fulfillment();
                            if (object.name != null)
                                message.name = String(object.name);
                            if (object.displayName != null)
                                message.displayName = String(object.displayName);
                            if (object.genericWebService != null) {
                                if (typeof object.genericWebService !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.Fulfillment.genericWebService: object expected");
                                message.genericWebService = $root.google.cloud.dialogflow.v2.Fulfillment.GenericWebService.fromObject(object.genericWebService);
                            }
                            if (object.enabled != null)
                                message.enabled = Boolean(object.enabled);
                            if (object.features) {
                                if (!Array.isArray(object.features))
                                    throw TypeError(".google.cloud.dialogflow.v2.Fulfillment.features: array expected");
                                message.features = [];
                                for (var i = 0; i < object.features.length; ++i) {
                                    if (typeof object.features[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.Fulfillment.features: object expected");
                                    message.features[i] = $root.google.cloud.dialogflow.v2.Fulfillment.Feature.fromObject(object.features[i]);
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a Fulfillment message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.Fulfillment
                         * @static
                         * @param {google.cloud.dialogflow.v2.Fulfillment} message Fulfillment
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        Fulfillment.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.features = [];
                            if (options.defaults) {
                                object.name = "";
                                object.displayName = "";
                                object.enabled = false;
                            }
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            if (message.displayName != null && message.hasOwnProperty("displayName"))
                                object.displayName = message.displayName;
                            if (message.genericWebService != null && message.hasOwnProperty("genericWebService")) {
                                object.genericWebService = $root.google.cloud.dialogflow.v2.Fulfillment.GenericWebService.toObject(message.genericWebService, options);
                                if (options.oneofs)
                                    object.fulfillment = "genericWebService";
                            }
                            if (message.enabled != null && message.hasOwnProperty("enabled"))
                                object.enabled = message.enabled;
                            if (message.features && message.features.length) {
                                object.features = [];
                                for (var j = 0; j < message.features.length; ++j)
                                    object.features[j] = $root.google.cloud.dialogflow.v2.Fulfillment.Feature.toObject(message.features[j], options);
                            }
                            return object;
                        };
    
                        /**
                         * Converts this Fulfillment to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.Fulfillment
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        Fulfillment.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for Fulfillment
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.Fulfillment
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        Fulfillment.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.Fulfillment";
                        };
    
                        Fulfillment.GenericWebService = (function() {
    
                            /**
                             * Properties of a GenericWebService.
                             * @memberof google.cloud.dialogflow.v2.Fulfillment
                             * @interface IGenericWebService
                             * @property {string|null} [uri] GenericWebService uri
                             * @property {string|null} [username] GenericWebService username
                             * @property {string|null} [password] GenericWebService password
                             * @property {Object.<string,string>|null} [requestHeaders] GenericWebService requestHeaders
                             * @property {boolean|null} [isCloudFunction] GenericWebService isCloudFunction
                             */
    
                            /**
                             * Constructs a new GenericWebService.
                             * @memberof google.cloud.dialogflow.v2.Fulfillment
                             * @classdesc Represents a GenericWebService.
                             * @implements IGenericWebService
                             * @constructor
                             * @param {google.cloud.dialogflow.v2.Fulfillment.IGenericWebService=} [properties] Properties to set
                             */
                            function GenericWebService(properties) {
                                this.requestHeaders = {};
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * GenericWebService uri.
                             * @member {string} uri
                             * @memberof google.cloud.dialogflow.v2.Fulfillment.GenericWebService
                             * @instance
                             */
                            GenericWebService.prototype.uri = "";
    
                            /**
                             * GenericWebService username.
                             * @member {string} username
                             * @memberof google.cloud.dialogflow.v2.Fulfillment.GenericWebService
                             * @instance
                             */
                            GenericWebService.prototype.username = "";
    
                            /**
                             * GenericWebService password.
                             * @member {string} password
                             * @memberof google.cloud.dialogflow.v2.Fulfillment.GenericWebService
                             * @instance
                             */
                            GenericWebService.prototype.password = "";
    
                            /**
                             * GenericWebService requestHeaders.
                             * @member {Object.<string,string>} requestHeaders
                             * @memberof google.cloud.dialogflow.v2.Fulfillment.GenericWebService
                             * @instance
                             */
                            GenericWebService.prototype.requestHeaders = $util.emptyObject;
    
                            /**
                             * GenericWebService isCloudFunction.
                             * @member {boolean} isCloudFunction
                             * @memberof google.cloud.dialogflow.v2.Fulfillment.GenericWebService
                             * @instance
                             */
                            GenericWebService.prototype.isCloudFunction = false;
    
                            /**
                             * Creates a new GenericWebService instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2.Fulfillment.GenericWebService
                             * @static
                             * @param {google.cloud.dialogflow.v2.Fulfillment.IGenericWebService=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2.Fulfillment.GenericWebService} GenericWebService instance
                             */
                            GenericWebService.create = function create(properties) {
                                return new GenericWebService(properties);
                            };
    
                            /**
                             * Encodes the specified GenericWebService message. Does not implicitly {@link google.cloud.dialogflow.v2.Fulfillment.GenericWebService.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2.Fulfillment.GenericWebService
                             * @static
                             * @param {google.cloud.dialogflow.v2.Fulfillment.IGenericWebService} message GenericWebService message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            GenericWebService.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.uri != null && Object.hasOwnProperty.call(message, "uri"))
                                    writer.uint32(/* id 1, wireType 2 =*/10).string(message.uri);
                                if (message.username != null && Object.hasOwnProperty.call(message, "username"))
                                    writer.uint32(/* id 2, wireType 2 =*/18).string(message.username);
                                if (message.password != null && Object.hasOwnProperty.call(message, "password"))
                                    writer.uint32(/* id 3, wireType 2 =*/26).string(message.password);
                                if (message.requestHeaders != null && Object.hasOwnProperty.call(message, "requestHeaders"))
                                    for (var keys = Object.keys(message.requestHeaders), i = 0; i < keys.length; ++i)
                                        writer.uint32(/* id 4, wireType 2 =*/34).fork().uint32(/* id 1, wireType 2 =*/10).string(keys[i]).uint32(/* id 2, wireType 2 =*/18).string(message.requestHeaders[keys[i]]).ldelim();
                                if (message.isCloudFunction != null && Object.hasOwnProperty.call(message, "isCloudFunction"))
                                    writer.uint32(/* id 5, wireType 0 =*/40).bool(message.isCloudFunction);
                                return writer;
                            };
    
                            /**
                             * Encodes the specified GenericWebService message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.Fulfillment.GenericWebService.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2.Fulfillment.GenericWebService
                             * @static
                             * @param {google.cloud.dialogflow.v2.Fulfillment.IGenericWebService} message GenericWebService message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            GenericWebService.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a GenericWebService message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2.Fulfillment.GenericWebService
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2.Fulfillment.GenericWebService} GenericWebService
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            GenericWebService.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.Fulfillment.GenericWebService(), key, value;
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.uri = reader.string();
                                            break;
                                        }
                                    case 2: {
                                            message.username = reader.string();
                                            break;
                                        }
                                    case 3: {
                                            message.password = reader.string();
                                            break;
                                        }
                                    case 4: {
                                            if (message.requestHeaders === $util.emptyObject)
                                                message.requestHeaders = {};
                                            var end2 = reader.uint32() + reader.pos;
                                            key = "";
                                            value = "";
                                            while (reader.pos < end2) {
                                                var tag2 = reader.uint32();
                                                switch (tag2 >>> 3) {
                                                case 1:
                                                    key = reader.string();
                                                    break;
                                                case 2:
                                                    value = reader.string();
                                                    break;
                                                default:
                                                    reader.skipType(tag2 & 7);
                                                    break;
                                                }
                                            }
                                            message.requestHeaders[key] = value;
                                            break;
                                        }
                                    case 5: {
                                            message.isCloudFunction = reader.bool();
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a GenericWebService message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2.Fulfillment.GenericWebService
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2.Fulfillment.GenericWebService} GenericWebService
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            GenericWebService.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a GenericWebService message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2.Fulfillment.GenericWebService
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            GenericWebService.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.uri != null && message.hasOwnProperty("uri"))
                                    if (!$util.isString(message.uri))
                                        return "uri: string expected";
                                if (message.username != null && message.hasOwnProperty("username"))
                                    if (!$util.isString(message.username))
                                        return "username: string expected";
                                if (message.password != null && message.hasOwnProperty("password"))
                                    if (!$util.isString(message.password))
                                        return "password: string expected";
                                if (message.requestHeaders != null && message.hasOwnProperty("requestHeaders")) {
                                    if (!$util.isObject(message.requestHeaders))
                                        return "requestHeaders: object expected";
                                    var key = Object.keys(message.requestHeaders);
                                    for (var i = 0; i < key.length; ++i)
                                        if (!$util.isString(message.requestHeaders[key[i]]))
                                            return "requestHeaders: string{k:string} expected";
                                }
                                if (message.isCloudFunction != null && message.hasOwnProperty("isCloudFunction"))
                                    if (typeof message.isCloudFunction !== "boolean")
                                        return "isCloudFunction: boolean expected";
                                return null;
                            };
    
                            /**
                             * Creates a GenericWebService message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2.Fulfillment.GenericWebService
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2.Fulfillment.GenericWebService} GenericWebService
                             */
                            GenericWebService.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2.Fulfillment.GenericWebService)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2.Fulfillment.GenericWebService();
                                if (object.uri != null)
                                    message.uri = String(object.uri);
                                if (object.username != null)
                                    message.username = String(object.username);
                                if (object.password != null)
                                    message.password = String(object.password);
                                if (object.requestHeaders) {
                                    if (typeof object.requestHeaders !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.Fulfillment.GenericWebService.requestHeaders: object expected");
                                    message.requestHeaders = {};
                                    for (var keys = Object.keys(object.requestHeaders), i = 0; i < keys.length; ++i)
                                        message.requestHeaders[keys[i]] = String(object.requestHeaders[keys[i]]);
                                }
                                if (object.isCloudFunction != null)
                                    message.isCloudFunction = Boolean(object.isCloudFunction);
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a GenericWebService message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2.Fulfillment.GenericWebService
                             * @static
                             * @param {google.cloud.dialogflow.v2.Fulfillment.GenericWebService} message GenericWebService
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            GenericWebService.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.objects || options.defaults)
                                    object.requestHeaders = {};
                                if (options.defaults) {
                                    object.uri = "";
                                    object.username = "";
                                    object.password = "";
                                    object.isCloudFunction = false;
                                }
                                if (message.uri != null && message.hasOwnProperty("uri"))
                                    object.uri = message.uri;
                                if (message.username != null && message.hasOwnProperty("username"))
                                    object.username = message.username;
                                if (message.password != null && message.hasOwnProperty("password"))
                                    object.password = message.password;
                                var keys2;
                                if (message.requestHeaders && (keys2 = Object.keys(message.requestHeaders)).length) {
                                    object.requestHeaders = {};
                                    for (var j = 0; j < keys2.length; ++j)
                                        object.requestHeaders[keys2[j]] = message.requestHeaders[keys2[j]];
                                }
                                if (message.isCloudFunction != null && message.hasOwnProperty("isCloudFunction"))
                                    object.isCloudFunction = message.isCloudFunction;
                                return object;
                            };
    
                            /**
                             * Converts this GenericWebService to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2.Fulfillment.GenericWebService
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            GenericWebService.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for GenericWebService
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2.Fulfillment.GenericWebService
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            GenericWebService.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2.Fulfillment.GenericWebService";
                            };
    
                            return GenericWebService;
                        })();
    
                        Fulfillment.Feature = (function() {
    
                            /**
                             * Properties of a Feature.
                             * @memberof google.cloud.dialogflow.v2.Fulfillment
                             * @interface IFeature
                             * @property {google.cloud.dialogflow.v2.Fulfillment.Feature.Type|null} [type] Feature type
                             */
    
                            /**
                             * Constructs a new Feature.
                             * @memberof google.cloud.dialogflow.v2.Fulfillment
                             * @classdesc Represents a Feature.
                             * @implements IFeature
                             * @constructor
                             * @param {google.cloud.dialogflow.v2.Fulfillment.IFeature=} [properties] Properties to set
                             */
                            function Feature(properties) {
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * Feature type.
                             * @member {google.cloud.dialogflow.v2.Fulfillment.Feature.Type} type
                             * @memberof google.cloud.dialogflow.v2.Fulfillment.Feature
                             * @instance
                             */
                            Feature.prototype.type = 0;
    
                            /**
                             * Creates a new Feature instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2.Fulfillment.Feature
                             * @static
                             * @param {google.cloud.dialogflow.v2.Fulfillment.IFeature=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2.Fulfillment.Feature} Feature instance
                             */
                            Feature.create = function create(properties) {
                                return new Feature(properties);
                            };
    
                            /**
                             * Encodes the specified Feature message. Does not implicitly {@link google.cloud.dialogflow.v2.Fulfillment.Feature.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2.Fulfillment.Feature
                             * @static
                             * @param {google.cloud.dialogflow.v2.Fulfillment.IFeature} message Feature message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            Feature.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.type != null && Object.hasOwnProperty.call(message, "type"))
                                    writer.uint32(/* id 1, wireType 0 =*/8).int32(message.type);
                                return writer;
                            };
    
                            /**
                             * Encodes the specified Feature message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.Fulfillment.Feature.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2.Fulfillment.Feature
                             * @static
                             * @param {google.cloud.dialogflow.v2.Fulfillment.IFeature} message Feature message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            Feature.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a Feature message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2.Fulfillment.Feature
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2.Fulfillment.Feature} Feature
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            Feature.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.Fulfillment.Feature();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.type = reader.int32();
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a Feature message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2.Fulfillment.Feature
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2.Fulfillment.Feature} Feature
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            Feature.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a Feature message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2.Fulfillment.Feature
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            Feature.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.type != null && message.hasOwnProperty("type"))
                                    switch (message.type) {
                                    default:
                                        return "type: enum value expected";
                                    case 0:
                                    case 1:
                                        break;
                                    }
                                return null;
                            };
    
                            /**
                             * Creates a Feature message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2.Fulfillment.Feature
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2.Fulfillment.Feature} Feature
                             */
                            Feature.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2.Fulfillment.Feature)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2.Fulfillment.Feature();
                                switch (object.type) {
                                default:
                                    if (typeof object.type === "number") {
                                        message.type = object.type;
                                        break;
                                    }
                                    break;
                                case "TYPE_UNSPECIFIED":
                                case 0:
                                    message.type = 0;
                                    break;
                                case "SMALLTALK":
                                case 1:
                                    message.type = 1;
                                    break;
                                }
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a Feature message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2.Fulfillment.Feature
                             * @static
                             * @param {google.cloud.dialogflow.v2.Fulfillment.Feature} message Feature
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            Feature.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.defaults)
                                    object.type = options.enums === String ? "TYPE_UNSPECIFIED" : 0;
                                if (message.type != null && message.hasOwnProperty("type"))
                                    object.type = options.enums === String ? $root.google.cloud.dialogflow.v2.Fulfillment.Feature.Type[message.type] === undefined ? message.type : $root.google.cloud.dialogflow.v2.Fulfillment.Feature.Type[message.type] : message.type;
                                return object;
                            };
    
                            /**
                             * Converts this Feature to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2.Fulfillment.Feature
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            Feature.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for Feature
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2.Fulfillment.Feature
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            Feature.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2.Fulfillment.Feature";
                            };
    
                            /**
                             * Type enum.
                             * @name google.cloud.dialogflow.v2.Fulfillment.Feature.Type
                             * @enum {number}
                             * @property {number} TYPE_UNSPECIFIED=0 TYPE_UNSPECIFIED value
                             * @property {number} SMALLTALK=1 SMALLTALK value
                             */
                            Feature.Type = (function() {
                                var valuesById = {}, values = Object.create(valuesById);
                                values[valuesById[0] = "TYPE_UNSPECIFIED"] = 0;
                                values[valuesById[1] = "SMALLTALK"] = 1;
                                return values;
                            })();
    
                            return Feature;
                        })();
    
                        return Fulfillment;
                    })();
    
                    v2.GetFulfillmentRequest = (function() {
    
                        /**
                         * Properties of a GetFulfillmentRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IGetFulfillmentRequest
                         * @property {string|null} [name] GetFulfillmentRequest name
                         */
    
                        /**
                         * Constructs a new GetFulfillmentRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a GetFulfillmentRequest.
                         * @implements IGetFulfillmentRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IGetFulfillmentRequest=} [properties] Properties to set
                         */
                        function GetFulfillmentRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GetFulfillmentRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2.GetFulfillmentRequest
                         * @instance
                         */
                        GetFulfillmentRequest.prototype.name = "";
    
                        /**
                         * Creates a new GetFulfillmentRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.GetFulfillmentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetFulfillmentRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.GetFulfillmentRequest} GetFulfillmentRequest instance
                         */
                        GetFulfillmentRequest.create = function create(properties) {
                            return new GetFulfillmentRequest(properties);
                        };
    
                        /**
                         * Encodes the specified GetFulfillmentRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.GetFulfillmentRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.GetFulfillmentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetFulfillmentRequest} message GetFulfillmentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetFulfillmentRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GetFulfillmentRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.GetFulfillmentRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GetFulfillmentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetFulfillmentRequest} message GetFulfillmentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetFulfillmentRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GetFulfillmentRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.GetFulfillmentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.GetFulfillmentRequest} GetFulfillmentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetFulfillmentRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.GetFulfillmentRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GetFulfillmentRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GetFulfillmentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.GetFulfillmentRequest} GetFulfillmentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetFulfillmentRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GetFulfillmentRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.GetFulfillmentRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GetFulfillmentRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a GetFulfillmentRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.GetFulfillmentRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.GetFulfillmentRequest} GetFulfillmentRequest
                         */
                        GetFulfillmentRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.GetFulfillmentRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.GetFulfillmentRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GetFulfillmentRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.GetFulfillmentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.GetFulfillmentRequest} message GetFulfillmentRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GetFulfillmentRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.name = "";
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            return object;
                        };
    
                        /**
                         * Converts this GetFulfillmentRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.GetFulfillmentRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GetFulfillmentRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GetFulfillmentRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.GetFulfillmentRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GetFulfillmentRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.GetFulfillmentRequest";
                        };
    
                        return GetFulfillmentRequest;
                    })();
    
                    v2.UpdateFulfillmentRequest = (function() {
    
                        /**
                         * Properties of an UpdateFulfillmentRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IUpdateFulfillmentRequest
                         * @property {google.cloud.dialogflow.v2.IFulfillment|null} [fulfillment] UpdateFulfillmentRequest fulfillment
                         * @property {google.protobuf.IFieldMask|null} [updateMask] UpdateFulfillmentRequest updateMask
                         */
    
                        /**
                         * Constructs a new UpdateFulfillmentRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an UpdateFulfillmentRequest.
                         * @implements IUpdateFulfillmentRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IUpdateFulfillmentRequest=} [properties] Properties to set
                         */
                        function UpdateFulfillmentRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * UpdateFulfillmentRequest fulfillment.
                         * @member {google.cloud.dialogflow.v2.IFulfillment|null|undefined} fulfillment
                         * @memberof google.cloud.dialogflow.v2.UpdateFulfillmentRequest
                         * @instance
                         */
                        UpdateFulfillmentRequest.prototype.fulfillment = null;
    
                        /**
                         * UpdateFulfillmentRequest updateMask.
                         * @member {google.protobuf.IFieldMask|null|undefined} updateMask
                         * @memberof google.cloud.dialogflow.v2.UpdateFulfillmentRequest
                         * @instance
                         */
                        UpdateFulfillmentRequest.prototype.updateMask = null;
    
                        /**
                         * Creates a new UpdateFulfillmentRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.UpdateFulfillmentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IUpdateFulfillmentRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.UpdateFulfillmentRequest} UpdateFulfillmentRequest instance
                         */
                        UpdateFulfillmentRequest.create = function create(properties) {
                            return new UpdateFulfillmentRequest(properties);
                        };
    
                        /**
                         * Encodes the specified UpdateFulfillmentRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.UpdateFulfillmentRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.UpdateFulfillmentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IUpdateFulfillmentRequest} message UpdateFulfillmentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UpdateFulfillmentRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.fulfillment != null && Object.hasOwnProperty.call(message, "fulfillment"))
                                $root.google.cloud.dialogflow.v2.Fulfillment.encode(message.fulfillment, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.updateMask != null && Object.hasOwnProperty.call(message, "updateMask"))
                                $root.google.protobuf.FieldMask.encode(message.updateMask, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified UpdateFulfillmentRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.UpdateFulfillmentRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.UpdateFulfillmentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IUpdateFulfillmentRequest} message UpdateFulfillmentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UpdateFulfillmentRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an UpdateFulfillmentRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.UpdateFulfillmentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.UpdateFulfillmentRequest} UpdateFulfillmentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UpdateFulfillmentRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.UpdateFulfillmentRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.fulfillment = $root.google.cloud.dialogflow.v2.Fulfillment.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.updateMask = $root.google.protobuf.FieldMask.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an UpdateFulfillmentRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.UpdateFulfillmentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.UpdateFulfillmentRequest} UpdateFulfillmentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UpdateFulfillmentRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an UpdateFulfillmentRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.UpdateFulfillmentRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        UpdateFulfillmentRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.fulfillment != null && message.hasOwnProperty("fulfillment")) {
                                var error = $root.google.cloud.dialogflow.v2.Fulfillment.verify(message.fulfillment);
                                if (error)
                                    return "fulfillment." + error;
                            }
                            if (message.updateMask != null && message.hasOwnProperty("updateMask")) {
                                var error = $root.google.protobuf.FieldMask.verify(message.updateMask);
                                if (error)
                                    return "updateMask." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates an UpdateFulfillmentRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.UpdateFulfillmentRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.UpdateFulfillmentRequest} UpdateFulfillmentRequest
                         */
                        UpdateFulfillmentRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.UpdateFulfillmentRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.UpdateFulfillmentRequest();
                            if (object.fulfillment != null) {
                                if (typeof object.fulfillment !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.UpdateFulfillmentRequest.fulfillment: object expected");
                                message.fulfillment = $root.google.cloud.dialogflow.v2.Fulfillment.fromObject(object.fulfillment);
                            }
                            if (object.updateMask != null) {
                                if (typeof object.updateMask !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.UpdateFulfillmentRequest.updateMask: object expected");
                                message.updateMask = $root.google.protobuf.FieldMask.fromObject(object.updateMask);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an UpdateFulfillmentRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.UpdateFulfillmentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.UpdateFulfillmentRequest} message UpdateFulfillmentRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        UpdateFulfillmentRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.fulfillment = null;
                                object.updateMask = null;
                            }
                            if (message.fulfillment != null && message.hasOwnProperty("fulfillment"))
                                object.fulfillment = $root.google.cloud.dialogflow.v2.Fulfillment.toObject(message.fulfillment, options);
                            if (message.updateMask != null && message.hasOwnProperty("updateMask"))
                                object.updateMask = $root.google.protobuf.FieldMask.toObject(message.updateMask, options);
                            return object;
                        };
    
                        /**
                         * Converts this UpdateFulfillmentRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.UpdateFulfillmentRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        UpdateFulfillmentRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for UpdateFulfillmentRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.UpdateFulfillmentRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        UpdateFulfillmentRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.UpdateFulfillmentRequest";
                        };
    
                        return UpdateFulfillmentRequest;
                    })();
    
                    v2.HumanAgentAssistantEvent = (function() {
    
                        /**
                         * Properties of a HumanAgentAssistantEvent.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IHumanAgentAssistantEvent
                         * @property {string|null} [conversation] HumanAgentAssistantEvent conversation
                         * @property {string|null} [participant] HumanAgentAssistantEvent participant
                         * @property {Array.<google.cloud.dialogflow.v2.ISuggestionResult>|null} [suggestionResults] HumanAgentAssistantEvent suggestionResults
                         */
    
                        /**
                         * Constructs a new HumanAgentAssistantEvent.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a HumanAgentAssistantEvent.
                         * @implements IHumanAgentAssistantEvent
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IHumanAgentAssistantEvent=} [properties] Properties to set
                         */
                        function HumanAgentAssistantEvent(properties) {
                            this.suggestionResults = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * HumanAgentAssistantEvent conversation.
                         * @member {string} conversation
                         * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantEvent
                         * @instance
                         */
                        HumanAgentAssistantEvent.prototype.conversation = "";
    
                        /**
                         * HumanAgentAssistantEvent participant.
                         * @member {string} participant
                         * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantEvent
                         * @instance
                         */
                        HumanAgentAssistantEvent.prototype.participant = "";
    
                        /**
                         * HumanAgentAssistantEvent suggestionResults.
                         * @member {Array.<google.cloud.dialogflow.v2.ISuggestionResult>} suggestionResults
                         * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantEvent
                         * @instance
                         */
                        HumanAgentAssistantEvent.prototype.suggestionResults = $util.emptyArray;
    
                        /**
                         * Creates a new HumanAgentAssistantEvent instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantEvent
                         * @static
                         * @param {google.cloud.dialogflow.v2.IHumanAgentAssistantEvent=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantEvent} HumanAgentAssistantEvent instance
                         */
                        HumanAgentAssistantEvent.create = function create(properties) {
                            return new HumanAgentAssistantEvent(properties);
                        };
    
                        /**
                         * Encodes the specified HumanAgentAssistantEvent message. Does not implicitly {@link google.cloud.dialogflow.v2.HumanAgentAssistantEvent.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantEvent
                         * @static
                         * @param {google.cloud.dialogflow.v2.IHumanAgentAssistantEvent} message HumanAgentAssistantEvent message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        HumanAgentAssistantEvent.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.conversation != null && Object.hasOwnProperty.call(message, "conversation"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.conversation);
                            if (message.participant != null && Object.hasOwnProperty.call(message, "participant"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.participant);
                            if (message.suggestionResults != null && message.suggestionResults.length)
                                for (var i = 0; i < message.suggestionResults.length; ++i)
                                    $root.google.cloud.dialogflow.v2.SuggestionResult.encode(message.suggestionResults[i], writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified HumanAgentAssistantEvent message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.HumanAgentAssistantEvent.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantEvent
                         * @static
                         * @param {google.cloud.dialogflow.v2.IHumanAgentAssistantEvent} message HumanAgentAssistantEvent message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        HumanAgentAssistantEvent.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a HumanAgentAssistantEvent message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantEvent
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantEvent} HumanAgentAssistantEvent
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        HumanAgentAssistantEvent.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.HumanAgentAssistantEvent();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.conversation = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.participant = reader.string();
                                        break;
                                    }
                                case 5: {
                                        if (!(message.suggestionResults && message.suggestionResults.length))
                                            message.suggestionResults = [];
                                        message.suggestionResults.push($root.google.cloud.dialogflow.v2.SuggestionResult.decode(reader, reader.uint32()));
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a HumanAgentAssistantEvent message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantEvent
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantEvent} HumanAgentAssistantEvent
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        HumanAgentAssistantEvent.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a HumanAgentAssistantEvent message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantEvent
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        HumanAgentAssistantEvent.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.conversation != null && message.hasOwnProperty("conversation"))
                                if (!$util.isString(message.conversation))
                                    return "conversation: string expected";
                            if (message.participant != null && message.hasOwnProperty("participant"))
                                if (!$util.isString(message.participant))
                                    return "participant: string expected";
                            if (message.suggestionResults != null && message.hasOwnProperty("suggestionResults")) {
                                if (!Array.isArray(message.suggestionResults))
                                    return "suggestionResults: array expected";
                                for (var i = 0; i < message.suggestionResults.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.SuggestionResult.verify(message.suggestionResults[i]);
                                    if (error)
                                        return "suggestionResults." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates a HumanAgentAssistantEvent message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantEvent
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.HumanAgentAssistantEvent} HumanAgentAssistantEvent
                         */
                        HumanAgentAssistantEvent.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.HumanAgentAssistantEvent)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.HumanAgentAssistantEvent();
                            if (object.conversation != null)
                                message.conversation = String(object.conversation);
                            if (object.participant != null)
                                message.participant = String(object.participant);
                            if (object.suggestionResults) {
                                if (!Array.isArray(object.suggestionResults))
                                    throw TypeError(".google.cloud.dialogflow.v2.HumanAgentAssistantEvent.suggestionResults: array expected");
                                message.suggestionResults = [];
                                for (var i = 0; i < object.suggestionResults.length; ++i) {
                                    if (typeof object.suggestionResults[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.HumanAgentAssistantEvent.suggestionResults: object expected");
                                    message.suggestionResults[i] = $root.google.cloud.dialogflow.v2.SuggestionResult.fromObject(object.suggestionResults[i]);
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a HumanAgentAssistantEvent message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantEvent
                         * @static
                         * @param {google.cloud.dialogflow.v2.HumanAgentAssistantEvent} message HumanAgentAssistantEvent
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        HumanAgentAssistantEvent.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.suggestionResults = [];
                            if (options.defaults) {
                                object.conversation = "";
                                object.participant = "";
                            }
                            if (message.conversation != null && message.hasOwnProperty("conversation"))
                                object.conversation = message.conversation;
                            if (message.participant != null && message.hasOwnProperty("participant"))
                                object.participant = message.participant;
                            if (message.suggestionResults && message.suggestionResults.length) {
                                object.suggestionResults = [];
                                for (var j = 0; j < message.suggestionResults.length; ++j)
                                    object.suggestionResults[j] = $root.google.cloud.dialogflow.v2.SuggestionResult.toObject(message.suggestionResults[j], options);
                            }
                            return object;
                        };
    
                        /**
                         * Converts this HumanAgentAssistantEvent to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantEvent
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        HumanAgentAssistantEvent.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for HumanAgentAssistantEvent
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.HumanAgentAssistantEvent
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        HumanAgentAssistantEvent.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.HumanAgentAssistantEvent";
                        };
    
                        return HumanAgentAssistantEvent;
                    })();
    
                    v2.KnowledgeBases = (function() {
    
                        /**
                         * Constructs a new KnowledgeBases service.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a KnowledgeBases
                         * @extends $protobuf.rpc.Service
                         * @constructor
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         */
                        function KnowledgeBases(rpcImpl, requestDelimited, responseDelimited) {
                            $protobuf.rpc.Service.call(this, rpcImpl, requestDelimited, responseDelimited);
                        }
    
                        (KnowledgeBases.prototype = Object.create($protobuf.rpc.Service.prototype)).constructor = KnowledgeBases;
    
                        /**
                         * Creates new KnowledgeBases service using the specified rpc implementation.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.KnowledgeBases
                         * @static
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         * @returns {KnowledgeBases} RPC service. Useful where requests and/or responses are streamed.
                         */
                        KnowledgeBases.create = function create(rpcImpl, requestDelimited, responseDelimited) {
                            return new this(rpcImpl, requestDelimited, responseDelimited);
                        };
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.KnowledgeBases|listKnowledgeBases}.
                         * @memberof google.cloud.dialogflow.v2.KnowledgeBases
                         * @typedef ListKnowledgeBasesCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.ListKnowledgeBasesResponse} [response] ListKnowledgeBasesResponse
                         */
    
                        /**
                         * Calls ListKnowledgeBases.
                         * @function listKnowledgeBases
                         * @memberof google.cloud.dialogflow.v2.KnowledgeBases
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IListKnowledgeBasesRequest} request ListKnowledgeBasesRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.KnowledgeBases.ListKnowledgeBasesCallback} callback Node-style callback called with the error, if any, and ListKnowledgeBasesResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(KnowledgeBases.prototype.listKnowledgeBases = function listKnowledgeBases(request, callback) {
                            return this.rpcCall(listKnowledgeBases, $root.google.cloud.dialogflow.v2.ListKnowledgeBasesRequest, $root.google.cloud.dialogflow.v2.ListKnowledgeBasesResponse, request, callback);
                        }, "name", { value: "ListKnowledgeBases" });
    
                        /**
                         * Calls ListKnowledgeBases.
                         * @function listKnowledgeBases
                         * @memberof google.cloud.dialogflow.v2.KnowledgeBases
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IListKnowledgeBasesRequest} request ListKnowledgeBasesRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.ListKnowledgeBasesResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.KnowledgeBases|getKnowledgeBase}.
                         * @memberof google.cloud.dialogflow.v2.KnowledgeBases
                         * @typedef GetKnowledgeBaseCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.KnowledgeBase} [response] KnowledgeBase
                         */
    
                        /**
                         * Calls GetKnowledgeBase.
                         * @function getKnowledgeBase
                         * @memberof google.cloud.dialogflow.v2.KnowledgeBases
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IGetKnowledgeBaseRequest} request GetKnowledgeBaseRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.KnowledgeBases.GetKnowledgeBaseCallback} callback Node-style callback called with the error, if any, and KnowledgeBase
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(KnowledgeBases.prototype.getKnowledgeBase = function getKnowledgeBase(request, callback) {
                            return this.rpcCall(getKnowledgeBase, $root.google.cloud.dialogflow.v2.GetKnowledgeBaseRequest, $root.google.cloud.dialogflow.v2.KnowledgeBase, request, callback);
                        }, "name", { value: "GetKnowledgeBase" });
    
                        /**
                         * Calls GetKnowledgeBase.
                         * @function getKnowledgeBase
                         * @memberof google.cloud.dialogflow.v2.KnowledgeBases
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IGetKnowledgeBaseRequest} request GetKnowledgeBaseRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.KnowledgeBase>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.KnowledgeBases|createKnowledgeBase}.
                         * @memberof google.cloud.dialogflow.v2.KnowledgeBases
                         * @typedef CreateKnowledgeBaseCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.KnowledgeBase} [response] KnowledgeBase
                         */
    
                        /**
                         * Calls CreateKnowledgeBase.
                         * @function createKnowledgeBase
                         * @memberof google.cloud.dialogflow.v2.KnowledgeBases
                         * @instance
                         * @param {google.cloud.dialogflow.v2.ICreateKnowledgeBaseRequest} request CreateKnowledgeBaseRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.KnowledgeBases.CreateKnowledgeBaseCallback} callback Node-style callback called with the error, if any, and KnowledgeBase
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(KnowledgeBases.prototype.createKnowledgeBase = function createKnowledgeBase(request, callback) {
                            return this.rpcCall(createKnowledgeBase, $root.google.cloud.dialogflow.v2.CreateKnowledgeBaseRequest, $root.google.cloud.dialogflow.v2.KnowledgeBase, request, callback);
                        }, "name", { value: "CreateKnowledgeBase" });
    
                        /**
                         * Calls CreateKnowledgeBase.
                         * @function createKnowledgeBase
                         * @memberof google.cloud.dialogflow.v2.KnowledgeBases
                         * @instance
                         * @param {google.cloud.dialogflow.v2.ICreateKnowledgeBaseRequest} request CreateKnowledgeBaseRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.KnowledgeBase>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.KnowledgeBases|deleteKnowledgeBase}.
                         * @memberof google.cloud.dialogflow.v2.KnowledgeBases
                         * @typedef DeleteKnowledgeBaseCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.protobuf.Empty} [response] Empty
                         */
    
                        /**
                         * Calls DeleteKnowledgeBase.
                         * @function deleteKnowledgeBase
                         * @memberof google.cloud.dialogflow.v2.KnowledgeBases
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IDeleteKnowledgeBaseRequest} request DeleteKnowledgeBaseRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.KnowledgeBases.DeleteKnowledgeBaseCallback} callback Node-style callback called with the error, if any, and Empty
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(KnowledgeBases.prototype.deleteKnowledgeBase = function deleteKnowledgeBase(request, callback) {
                            return this.rpcCall(deleteKnowledgeBase, $root.google.cloud.dialogflow.v2.DeleteKnowledgeBaseRequest, $root.google.protobuf.Empty, request, callback);
                        }, "name", { value: "DeleteKnowledgeBase" });
    
                        /**
                         * Calls DeleteKnowledgeBase.
                         * @function deleteKnowledgeBase
                         * @memberof google.cloud.dialogflow.v2.KnowledgeBases
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IDeleteKnowledgeBaseRequest} request DeleteKnowledgeBaseRequest message or plain object
                         * @returns {Promise<google.protobuf.Empty>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.KnowledgeBases|updateKnowledgeBase}.
                         * @memberof google.cloud.dialogflow.v2.KnowledgeBases
                         * @typedef UpdateKnowledgeBaseCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.KnowledgeBase} [response] KnowledgeBase
                         */
    
                        /**
                         * Calls UpdateKnowledgeBase.
                         * @function updateKnowledgeBase
                         * @memberof google.cloud.dialogflow.v2.KnowledgeBases
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IUpdateKnowledgeBaseRequest} request UpdateKnowledgeBaseRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.KnowledgeBases.UpdateKnowledgeBaseCallback} callback Node-style callback called with the error, if any, and KnowledgeBase
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(KnowledgeBases.prototype.updateKnowledgeBase = function updateKnowledgeBase(request, callback) {
                            return this.rpcCall(updateKnowledgeBase, $root.google.cloud.dialogflow.v2.UpdateKnowledgeBaseRequest, $root.google.cloud.dialogflow.v2.KnowledgeBase, request, callback);
                        }, "name", { value: "UpdateKnowledgeBase" });
    
                        /**
                         * Calls UpdateKnowledgeBase.
                         * @function updateKnowledgeBase
                         * @memberof google.cloud.dialogflow.v2.KnowledgeBases
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IUpdateKnowledgeBaseRequest} request UpdateKnowledgeBaseRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.KnowledgeBase>} Promise
                         * @variation 2
                         */
    
                        return KnowledgeBases;
                    })();
    
                    v2.KnowledgeBase = (function() {
    
                        /**
                         * Properties of a KnowledgeBase.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IKnowledgeBase
                         * @property {string|null} [name] KnowledgeBase name
                         * @property {string|null} [displayName] KnowledgeBase displayName
                         * @property {string|null} [languageCode] KnowledgeBase languageCode
                         */
    
                        /**
                         * Constructs a new KnowledgeBase.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a KnowledgeBase.
                         * @implements IKnowledgeBase
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IKnowledgeBase=} [properties] Properties to set
                         */
                        function KnowledgeBase(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * KnowledgeBase name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2.KnowledgeBase
                         * @instance
                         */
                        KnowledgeBase.prototype.name = "";
    
                        /**
                         * KnowledgeBase displayName.
                         * @member {string} displayName
                         * @memberof google.cloud.dialogflow.v2.KnowledgeBase
                         * @instance
                         */
                        KnowledgeBase.prototype.displayName = "";
    
                        /**
                         * KnowledgeBase languageCode.
                         * @member {string} languageCode
                         * @memberof google.cloud.dialogflow.v2.KnowledgeBase
                         * @instance
                         */
                        KnowledgeBase.prototype.languageCode = "";
    
                        /**
                         * Creates a new KnowledgeBase instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.KnowledgeBase
                         * @static
                         * @param {google.cloud.dialogflow.v2.IKnowledgeBase=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.KnowledgeBase} KnowledgeBase instance
                         */
                        KnowledgeBase.create = function create(properties) {
                            return new KnowledgeBase(properties);
                        };
    
                        /**
                         * Encodes the specified KnowledgeBase message. Does not implicitly {@link google.cloud.dialogflow.v2.KnowledgeBase.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.KnowledgeBase
                         * @static
                         * @param {google.cloud.dialogflow.v2.IKnowledgeBase} message KnowledgeBase message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        KnowledgeBase.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            if (message.displayName != null && Object.hasOwnProperty.call(message, "displayName"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.displayName);
                            if (message.languageCode != null && Object.hasOwnProperty.call(message, "languageCode"))
                                writer.uint32(/* id 4, wireType 2 =*/34).string(message.languageCode);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified KnowledgeBase message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.KnowledgeBase.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.KnowledgeBase
                         * @static
                         * @param {google.cloud.dialogflow.v2.IKnowledgeBase} message KnowledgeBase message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        KnowledgeBase.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a KnowledgeBase message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.KnowledgeBase
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.KnowledgeBase} KnowledgeBase
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        KnowledgeBase.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.KnowledgeBase();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.displayName = reader.string();
                                        break;
                                    }
                                case 4: {
                                        message.languageCode = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a KnowledgeBase message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.KnowledgeBase
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.KnowledgeBase} KnowledgeBase
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        KnowledgeBase.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a KnowledgeBase message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.KnowledgeBase
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        KnowledgeBase.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            if (message.displayName != null && message.hasOwnProperty("displayName"))
                                if (!$util.isString(message.displayName))
                                    return "displayName: string expected";
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                if (!$util.isString(message.languageCode))
                                    return "languageCode: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a KnowledgeBase message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.KnowledgeBase
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.KnowledgeBase} KnowledgeBase
                         */
                        KnowledgeBase.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.KnowledgeBase)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.KnowledgeBase();
                            if (object.name != null)
                                message.name = String(object.name);
                            if (object.displayName != null)
                                message.displayName = String(object.displayName);
                            if (object.languageCode != null)
                                message.languageCode = String(object.languageCode);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a KnowledgeBase message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.KnowledgeBase
                         * @static
                         * @param {google.cloud.dialogflow.v2.KnowledgeBase} message KnowledgeBase
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        KnowledgeBase.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.name = "";
                                object.displayName = "";
                                object.languageCode = "";
                            }
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            if (message.displayName != null && message.hasOwnProperty("displayName"))
                                object.displayName = message.displayName;
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                object.languageCode = message.languageCode;
                            return object;
                        };
    
                        /**
                         * Converts this KnowledgeBase to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.KnowledgeBase
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        KnowledgeBase.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for KnowledgeBase
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.KnowledgeBase
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        KnowledgeBase.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.KnowledgeBase";
                        };
    
                        return KnowledgeBase;
                    })();
    
                    v2.ListKnowledgeBasesRequest = (function() {
    
                        /**
                         * Properties of a ListKnowledgeBasesRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IListKnowledgeBasesRequest
                         * @property {string|null} [parent] ListKnowledgeBasesRequest parent
                         * @property {number|null} [pageSize] ListKnowledgeBasesRequest pageSize
                         * @property {string|null} [pageToken] ListKnowledgeBasesRequest pageToken
                         * @property {string|null} [filter] ListKnowledgeBasesRequest filter
                         */
    
                        /**
                         * Constructs a new ListKnowledgeBasesRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a ListKnowledgeBasesRequest.
                         * @implements IListKnowledgeBasesRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IListKnowledgeBasesRequest=} [properties] Properties to set
                         */
                        function ListKnowledgeBasesRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListKnowledgeBasesRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.ListKnowledgeBasesRequest
                         * @instance
                         */
                        ListKnowledgeBasesRequest.prototype.parent = "";
    
                        /**
                         * ListKnowledgeBasesRequest pageSize.
                         * @member {number} pageSize
                         * @memberof google.cloud.dialogflow.v2.ListKnowledgeBasesRequest
                         * @instance
                         */
                        ListKnowledgeBasesRequest.prototype.pageSize = 0;
    
                        /**
                         * ListKnowledgeBasesRequest pageToken.
                         * @member {string} pageToken
                         * @memberof google.cloud.dialogflow.v2.ListKnowledgeBasesRequest
                         * @instance
                         */
                        ListKnowledgeBasesRequest.prototype.pageToken = "";
    
                        /**
                         * ListKnowledgeBasesRequest filter.
                         * @member {string} filter
                         * @memberof google.cloud.dialogflow.v2.ListKnowledgeBasesRequest
                         * @instance
                         */
                        ListKnowledgeBasesRequest.prototype.filter = "";
    
                        /**
                         * Creates a new ListKnowledgeBasesRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ListKnowledgeBasesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListKnowledgeBasesRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ListKnowledgeBasesRequest} ListKnowledgeBasesRequest instance
                         */
                        ListKnowledgeBasesRequest.create = function create(properties) {
                            return new ListKnowledgeBasesRequest(properties);
                        };
    
                        /**
                         * Encodes the specified ListKnowledgeBasesRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.ListKnowledgeBasesRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ListKnowledgeBasesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListKnowledgeBasesRequest} message ListKnowledgeBasesRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListKnowledgeBasesRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.pageSize != null && Object.hasOwnProperty.call(message, "pageSize"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.pageSize);
                            if (message.pageToken != null && Object.hasOwnProperty.call(message, "pageToken"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.pageToken);
                            if (message.filter != null && Object.hasOwnProperty.call(message, "filter"))
                                writer.uint32(/* id 4, wireType 2 =*/34).string(message.filter);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListKnowledgeBasesRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ListKnowledgeBasesRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListKnowledgeBasesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListKnowledgeBasesRequest} message ListKnowledgeBasesRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListKnowledgeBasesRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListKnowledgeBasesRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ListKnowledgeBasesRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ListKnowledgeBasesRequest} ListKnowledgeBasesRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListKnowledgeBasesRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ListKnowledgeBasesRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.pageSize = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.pageToken = reader.string();
                                        break;
                                    }
                                case 4: {
                                        message.filter = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListKnowledgeBasesRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListKnowledgeBasesRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ListKnowledgeBasesRequest} ListKnowledgeBasesRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListKnowledgeBasesRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListKnowledgeBasesRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ListKnowledgeBasesRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListKnowledgeBasesRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                if (!$util.isInteger(message.pageSize))
                                    return "pageSize: integer expected";
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                if (!$util.isString(message.pageToken))
                                    return "pageToken: string expected";
                            if (message.filter != null && message.hasOwnProperty("filter"))
                                if (!$util.isString(message.filter))
                                    return "filter: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListKnowledgeBasesRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ListKnowledgeBasesRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ListKnowledgeBasesRequest} ListKnowledgeBasesRequest
                         */
                        ListKnowledgeBasesRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ListKnowledgeBasesRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ListKnowledgeBasesRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.pageSize != null)
                                message.pageSize = object.pageSize | 0;
                            if (object.pageToken != null)
                                message.pageToken = String(object.pageToken);
                            if (object.filter != null)
                                message.filter = String(object.filter);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListKnowledgeBasesRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ListKnowledgeBasesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ListKnowledgeBasesRequest} message ListKnowledgeBasesRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListKnowledgeBasesRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.pageSize = 0;
                                object.pageToken = "";
                                object.filter = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                object.pageSize = message.pageSize;
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                object.pageToken = message.pageToken;
                            if (message.filter != null && message.hasOwnProperty("filter"))
                                object.filter = message.filter;
                            return object;
                        };
    
                        /**
                         * Converts this ListKnowledgeBasesRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ListKnowledgeBasesRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListKnowledgeBasesRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListKnowledgeBasesRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ListKnowledgeBasesRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListKnowledgeBasesRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ListKnowledgeBasesRequest";
                        };
    
                        return ListKnowledgeBasesRequest;
                    })();
    
                    v2.ListKnowledgeBasesResponse = (function() {
    
                        /**
                         * Properties of a ListKnowledgeBasesResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IListKnowledgeBasesResponse
                         * @property {Array.<google.cloud.dialogflow.v2.IKnowledgeBase>|null} [knowledgeBases] ListKnowledgeBasesResponse knowledgeBases
                         * @property {string|null} [nextPageToken] ListKnowledgeBasesResponse nextPageToken
                         */
    
                        /**
                         * Constructs a new ListKnowledgeBasesResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a ListKnowledgeBasesResponse.
                         * @implements IListKnowledgeBasesResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IListKnowledgeBasesResponse=} [properties] Properties to set
                         */
                        function ListKnowledgeBasesResponse(properties) {
                            this.knowledgeBases = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListKnowledgeBasesResponse knowledgeBases.
                         * @member {Array.<google.cloud.dialogflow.v2.IKnowledgeBase>} knowledgeBases
                         * @memberof google.cloud.dialogflow.v2.ListKnowledgeBasesResponse
                         * @instance
                         */
                        ListKnowledgeBasesResponse.prototype.knowledgeBases = $util.emptyArray;
    
                        /**
                         * ListKnowledgeBasesResponse nextPageToken.
                         * @member {string} nextPageToken
                         * @memberof google.cloud.dialogflow.v2.ListKnowledgeBasesResponse
                         * @instance
                         */
                        ListKnowledgeBasesResponse.prototype.nextPageToken = "";
    
                        /**
                         * Creates a new ListKnowledgeBasesResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ListKnowledgeBasesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListKnowledgeBasesResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ListKnowledgeBasesResponse} ListKnowledgeBasesResponse instance
                         */
                        ListKnowledgeBasesResponse.create = function create(properties) {
                            return new ListKnowledgeBasesResponse(properties);
                        };
    
                        /**
                         * Encodes the specified ListKnowledgeBasesResponse message. Does not implicitly {@link google.cloud.dialogflow.v2.ListKnowledgeBasesResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ListKnowledgeBasesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListKnowledgeBasesResponse} message ListKnowledgeBasesResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListKnowledgeBasesResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.knowledgeBases != null && message.knowledgeBases.length)
                                for (var i = 0; i < message.knowledgeBases.length; ++i)
                                    $root.google.cloud.dialogflow.v2.KnowledgeBase.encode(message.knowledgeBases[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.nextPageToken != null && Object.hasOwnProperty.call(message, "nextPageToken"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.nextPageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListKnowledgeBasesResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ListKnowledgeBasesResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListKnowledgeBasesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListKnowledgeBasesResponse} message ListKnowledgeBasesResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListKnowledgeBasesResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListKnowledgeBasesResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ListKnowledgeBasesResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ListKnowledgeBasesResponse} ListKnowledgeBasesResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListKnowledgeBasesResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ListKnowledgeBasesResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.knowledgeBases && message.knowledgeBases.length))
                                            message.knowledgeBases = [];
                                        message.knowledgeBases.push($root.google.cloud.dialogflow.v2.KnowledgeBase.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 2: {
                                        message.nextPageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListKnowledgeBasesResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListKnowledgeBasesResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ListKnowledgeBasesResponse} ListKnowledgeBasesResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListKnowledgeBasesResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListKnowledgeBasesResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ListKnowledgeBasesResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListKnowledgeBasesResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.knowledgeBases != null && message.hasOwnProperty("knowledgeBases")) {
                                if (!Array.isArray(message.knowledgeBases))
                                    return "knowledgeBases: array expected";
                                for (var i = 0; i < message.knowledgeBases.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.KnowledgeBase.verify(message.knowledgeBases[i]);
                                    if (error)
                                        return "knowledgeBases." + error;
                                }
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                if (!$util.isString(message.nextPageToken))
                                    return "nextPageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListKnowledgeBasesResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ListKnowledgeBasesResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ListKnowledgeBasesResponse} ListKnowledgeBasesResponse
                         */
                        ListKnowledgeBasesResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ListKnowledgeBasesResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ListKnowledgeBasesResponse();
                            if (object.knowledgeBases) {
                                if (!Array.isArray(object.knowledgeBases))
                                    throw TypeError(".google.cloud.dialogflow.v2.ListKnowledgeBasesResponse.knowledgeBases: array expected");
                                message.knowledgeBases = [];
                                for (var i = 0; i < object.knowledgeBases.length; ++i) {
                                    if (typeof object.knowledgeBases[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.ListKnowledgeBasesResponse.knowledgeBases: object expected");
                                    message.knowledgeBases[i] = $root.google.cloud.dialogflow.v2.KnowledgeBase.fromObject(object.knowledgeBases[i]);
                                }
                            }
                            if (object.nextPageToken != null)
                                message.nextPageToken = String(object.nextPageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListKnowledgeBasesResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ListKnowledgeBasesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.ListKnowledgeBasesResponse} message ListKnowledgeBasesResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListKnowledgeBasesResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.knowledgeBases = [];
                            if (options.defaults)
                                object.nextPageToken = "";
                            if (message.knowledgeBases && message.knowledgeBases.length) {
                                object.knowledgeBases = [];
                                for (var j = 0; j < message.knowledgeBases.length; ++j)
                                    object.knowledgeBases[j] = $root.google.cloud.dialogflow.v2.KnowledgeBase.toObject(message.knowledgeBases[j], options);
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                object.nextPageToken = message.nextPageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListKnowledgeBasesResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ListKnowledgeBasesResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListKnowledgeBasesResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListKnowledgeBasesResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ListKnowledgeBasesResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListKnowledgeBasesResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ListKnowledgeBasesResponse";
                        };
    
                        return ListKnowledgeBasesResponse;
                    })();
    
                    v2.GetKnowledgeBaseRequest = (function() {
    
                        /**
                         * Properties of a GetKnowledgeBaseRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IGetKnowledgeBaseRequest
                         * @property {string|null} [name] GetKnowledgeBaseRequest name
                         */
    
                        /**
                         * Constructs a new GetKnowledgeBaseRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a GetKnowledgeBaseRequest.
                         * @implements IGetKnowledgeBaseRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IGetKnowledgeBaseRequest=} [properties] Properties to set
                         */
                        function GetKnowledgeBaseRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GetKnowledgeBaseRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2.GetKnowledgeBaseRequest
                         * @instance
                         */
                        GetKnowledgeBaseRequest.prototype.name = "";
    
                        /**
                         * Creates a new GetKnowledgeBaseRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.GetKnowledgeBaseRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetKnowledgeBaseRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.GetKnowledgeBaseRequest} GetKnowledgeBaseRequest instance
                         */
                        GetKnowledgeBaseRequest.create = function create(properties) {
                            return new GetKnowledgeBaseRequest(properties);
                        };
    
                        /**
                         * Encodes the specified GetKnowledgeBaseRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.GetKnowledgeBaseRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.GetKnowledgeBaseRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetKnowledgeBaseRequest} message GetKnowledgeBaseRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetKnowledgeBaseRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GetKnowledgeBaseRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.GetKnowledgeBaseRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GetKnowledgeBaseRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetKnowledgeBaseRequest} message GetKnowledgeBaseRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetKnowledgeBaseRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GetKnowledgeBaseRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.GetKnowledgeBaseRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.GetKnowledgeBaseRequest} GetKnowledgeBaseRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetKnowledgeBaseRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.GetKnowledgeBaseRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GetKnowledgeBaseRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GetKnowledgeBaseRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.GetKnowledgeBaseRequest} GetKnowledgeBaseRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetKnowledgeBaseRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GetKnowledgeBaseRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.GetKnowledgeBaseRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GetKnowledgeBaseRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a GetKnowledgeBaseRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.GetKnowledgeBaseRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.GetKnowledgeBaseRequest} GetKnowledgeBaseRequest
                         */
                        GetKnowledgeBaseRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.GetKnowledgeBaseRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.GetKnowledgeBaseRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GetKnowledgeBaseRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.GetKnowledgeBaseRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.GetKnowledgeBaseRequest} message GetKnowledgeBaseRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GetKnowledgeBaseRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.name = "";
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            return object;
                        };
    
                        /**
                         * Converts this GetKnowledgeBaseRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.GetKnowledgeBaseRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GetKnowledgeBaseRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GetKnowledgeBaseRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.GetKnowledgeBaseRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GetKnowledgeBaseRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.GetKnowledgeBaseRequest";
                        };
    
                        return GetKnowledgeBaseRequest;
                    })();
    
                    v2.CreateKnowledgeBaseRequest = (function() {
    
                        /**
                         * Properties of a CreateKnowledgeBaseRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ICreateKnowledgeBaseRequest
                         * @property {string|null} [parent] CreateKnowledgeBaseRequest parent
                         * @property {google.cloud.dialogflow.v2.IKnowledgeBase|null} [knowledgeBase] CreateKnowledgeBaseRequest knowledgeBase
                         */
    
                        /**
                         * Constructs a new CreateKnowledgeBaseRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a CreateKnowledgeBaseRequest.
                         * @implements ICreateKnowledgeBaseRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ICreateKnowledgeBaseRequest=} [properties] Properties to set
                         */
                        function CreateKnowledgeBaseRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * CreateKnowledgeBaseRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.CreateKnowledgeBaseRequest
                         * @instance
                         */
                        CreateKnowledgeBaseRequest.prototype.parent = "";
    
                        /**
                         * CreateKnowledgeBaseRequest knowledgeBase.
                         * @member {google.cloud.dialogflow.v2.IKnowledgeBase|null|undefined} knowledgeBase
                         * @memberof google.cloud.dialogflow.v2.CreateKnowledgeBaseRequest
                         * @instance
                         */
                        CreateKnowledgeBaseRequest.prototype.knowledgeBase = null;
    
                        /**
                         * Creates a new CreateKnowledgeBaseRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.CreateKnowledgeBaseRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICreateKnowledgeBaseRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.CreateKnowledgeBaseRequest} CreateKnowledgeBaseRequest instance
                         */
                        CreateKnowledgeBaseRequest.create = function create(properties) {
                            return new CreateKnowledgeBaseRequest(properties);
                        };
    
                        /**
                         * Encodes the specified CreateKnowledgeBaseRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.CreateKnowledgeBaseRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.CreateKnowledgeBaseRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICreateKnowledgeBaseRequest} message CreateKnowledgeBaseRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateKnowledgeBaseRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.knowledgeBase != null && Object.hasOwnProperty.call(message, "knowledgeBase"))
                                $root.google.cloud.dialogflow.v2.KnowledgeBase.encode(message.knowledgeBase, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified CreateKnowledgeBaseRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.CreateKnowledgeBaseRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.CreateKnowledgeBaseRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICreateKnowledgeBaseRequest} message CreateKnowledgeBaseRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateKnowledgeBaseRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a CreateKnowledgeBaseRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.CreateKnowledgeBaseRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.CreateKnowledgeBaseRequest} CreateKnowledgeBaseRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateKnowledgeBaseRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.CreateKnowledgeBaseRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.knowledgeBase = $root.google.cloud.dialogflow.v2.KnowledgeBase.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a CreateKnowledgeBaseRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.CreateKnowledgeBaseRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.CreateKnowledgeBaseRequest} CreateKnowledgeBaseRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateKnowledgeBaseRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a CreateKnowledgeBaseRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.CreateKnowledgeBaseRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        CreateKnowledgeBaseRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.knowledgeBase != null && message.hasOwnProperty("knowledgeBase")) {
                                var error = $root.google.cloud.dialogflow.v2.KnowledgeBase.verify(message.knowledgeBase);
                                if (error)
                                    return "knowledgeBase." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a CreateKnowledgeBaseRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.CreateKnowledgeBaseRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.CreateKnowledgeBaseRequest} CreateKnowledgeBaseRequest
                         */
                        CreateKnowledgeBaseRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.CreateKnowledgeBaseRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.CreateKnowledgeBaseRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.knowledgeBase != null) {
                                if (typeof object.knowledgeBase !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.CreateKnowledgeBaseRequest.knowledgeBase: object expected");
                                message.knowledgeBase = $root.google.cloud.dialogflow.v2.KnowledgeBase.fromObject(object.knowledgeBase);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a CreateKnowledgeBaseRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.CreateKnowledgeBaseRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.CreateKnowledgeBaseRequest} message CreateKnowledgeBaseRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        CreateKnowledgeBaseRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.knowledgeBase = null;
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.knowledgeBase != null && message.hasOwnProperty("knowledgeBase"))
                                object.knowledgeBase = $root.google.cloud.dialogflow.v2.KnowledgeBase.toObject(message.knowledgeBase, options);
                            return object;
                        };
    
                        /**
                         * Converts this CreateKnowledgeBaseRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.CreateKnowledgeBaseRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        CreateKnowledgeBaseRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for CreateKnowledgeBaseRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.CreateKnowledgeBaseRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        CreateKnowledgeBaseRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.CreateKnowledgeBaseRequest";
                        };
    
                        return CreateKnowledgeBaseRequest;
                    })();
    
                    v2.DeleteKnowledgeBaseRequest = (function() {
    
                        /**
                         * Properties of a DeleteKnowledgeBaseRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IDeleteKnowledgeBaseRequest
                         * @property {string|null} [name] DeleteKnowledgeBaseRequest name
                         * @property {boolean|null} [force] DeleteKnowledgeBaseRequest force
                         */
    
                        /**
                         * Constructs a new DeleteKnowledgeBaseRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a DeleteKnowledgeBaseRequest.
                         * @implements IDeleteKnowledgeBaseRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IDeleteKnowledgeBaseRequest=} [properties] Properties to set
                         */
                        function DeleteKnowledgeBaseRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * DeleteKnowledgeBaseRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2.DeleteKnowledgeBaseRequest
                         * @instance
                         */
                        DeleteKnowledgeBaseRequest.prototype.name = "";
    
                        /**
                         * DeleteKnowledgeBaseRequest force.
                         * @member {boolean} force
                         * @memberof google.cloud.dialogflow.v2.DeleteKnowledgeBaseRequest
                         * @instance
                         */
                        DeleteKnowledgeBaseRequest.prototype.force = false;
    
                        /**
                         * Creates a new DeleteKnowledgeBaseRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.DeleteKnowledgeBaseRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDeleteKnowledgeBaseRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.DeleteKnowledgeBaseRequest} DeleteKnowledgeBaseRequest instance
                         */
                        DeleteKnowledgeBaseRequest.create = function create(properties) {
                            return new DeleteKnowledgeBaseRequest(properties);
                        };
    
                        /**
                         * Encodes the specified DeleteKnowledgeBaseRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.DeleteKnowledgeBaseRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.DeleteKnowledgeBaseRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDeleteKnowledgeBaseRequest} message DeleteKnowledgeBaseRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteKnowledgeBaseRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            if (message.force != null && Object.hasOwnProperty.call(message, "force"))
                                writer.uint32(/* id 2, wireType 0 =*/16).bool(message.force);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified DeleteKnowledgeBaseRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.DeleteKnowledgeBaseRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.DeleteKnowledgeBaseRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDeleteKnowledgeBaseRequest} message DeleteKnowledgeBaseRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteKnowledgeBaseRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a DeleteKnowledgeBaseRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.DeleteKnowledgeBaseRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.DeleteKnowledgeBaseRequest} DeleteKnowledgeBaseRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteKnowledgeBaseRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.DeleteKnowledgeBaseRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.force = reader.bool();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a DeleteKnowledgeBaseRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.DeleteKnowledgeBaseRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.DeleteKnowledgeBaseRequest} DeleteKnowledgeBaseRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteKnowledgeBaseRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a DeleteKnowledgeBaseRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.DeleteKnowledgeBaseRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        DeleteKnowledgeBaseRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            if (message.force != null && message.hasOwnProperty("force"))
                                if (typeof message.force !== "boolean")
                                    return "force: boolean expected";
                            return null;
                        };
    
                        /**
                         * Creates a DeleteKnowledgeBaseRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.DeleteKnowledgeBaseRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.DeleteKnowledgeBaseRequest} DeleteKnowledgeBaseRequest
                         */
                        DeleteKnowledgeBaseRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.DeleteKnowledgeBaseRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.DeleteKnowledgeBaseRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            if (object.force != null)
                                message.force = Boolean(object.force);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a DeleteKnowledgeBaseRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.DeleteKnowledgeBaseRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.DeleteKnowledgeBaseRequest} message DeleteKnowledgeBaseRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        DeleteKnowledgeBaseRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.name = "";
                                object.force = false;
                            }
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            if (message.force != null && message.hasOwnProperty("force"))
                                object.force = message.force;
                            return object;
                        };
    
                        /**
                         * Converts this DeleteKnowledgeBaseRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.DeleteKnowledgeBaseRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        DeleteKnowledgeBaseRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for DeleteKnowledgeBaseRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.DeleteKnowledgeBaseRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        DeleteKnowledgeBaseRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.DeleteKnowledgeBaseRequest";
                        };
    
                        return DeleteKnowledgeBaseRequest;
                    })();
    
                    v2.UpdateKnowledgeBaseRequest = (function() {
    
                        /**
                         * Properties of an UpdateKnowledgeBaseRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IUpdateKnowledgeBaseRequest
                         * @property {google.cloud.dialogflow.v2.IKnowledgeBase|null} [knowledgeBase] UpdateKnowledgeBaseRequest knowledgeBase
                         * @property {google.protobuf.IFieldMask|null} [updateMask] UpdateKnowledgeBaseRequest updateMask
                         */
    
                        /**
                         * Constructs a new UpdateKnowledgeBaseRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an UpdateKnowledgeBaseRequest.
                         * @implements IUpdateKnowledgeBaseRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IUpdateKnowledgeBaseRequest=} [properties] Properties to set
                         */
                        function UpdateKnowledgeBaseRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * UpdateKnowledgeBaseRequest knowledgeBase.
                         * @member {google.cloud.dialogflow.v2.IKnowledgeBase|null|undefined} knowledgeBase
                         * @memberof google.cloud.dialogflow.v2.UpdateKnowledgeBaseRequest
                         * @instance
                         */
                        UpdateKnowledgeBaseRequest.prototype.knowledgeBase = null;
    
                        /**
                         * UpdateKnowledgeBaseRequest updateMask.
                         * @member {google.protobuf.IFieldMask|null|undefined} updateMask
                         * @memberof google.cloud.dialogflow.v2.UpdateKnowledgeBaseRequest
                         * @instance
                         */
                        UpdateKnowledgeBaseRequest.prototype.updateMask = null;
    
                        /**
                         * Creates a new UpdateKnowledgeBaseRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.UpdateKnowledgeBaseRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IUpdateKnowledgeBaseRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.UpdateKnowledgeBaseRequest} UpdateKnowledgeBaseRequest instance
                         */
                        UpdateKnowledgeBaseRequest.create = function create(properties) {
                            return new UpdateKnowledgeBaseRequest(properties);
                        };
    
                        /**
                         * Encodes the specified UpdateKnowledgeBaseRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.UpdateKnowledgeBaseRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.UpdateKnowledgeBaseRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IUpdateKnowledgeBaseRequest} message UpdateKnowledgeBaseRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UpdateKnowledgeBaseRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.knowledgeBase != null && Object.hasOwnProperty.call(message, "knowledgeBase"))
                                $root.google.cloud.dialogflow.v2.KnowledgeBase.encode(message.knowledgeBase, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.updateMask != null && Object.hasOwnProperty.call(message, "updateMask"))
                                $root.google.protobuf.FieldMask.encode(message.updateMask, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified UpdateKnowledgeBaseRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.UpdateKnowledgeBaseRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.UpdateKnowledgeBaseRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IUpdateKnowledgeBaseRequest} message UpdateKnowledgeBaseRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UpdateKnowledgeBaseRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an UpdateKnowledgeBaseRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.UpdateKnowledgeBaseRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.UpdateKnowledgeBaseRequest} UpdateKnowledgeBaseRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UpdateKnowledgeBaseRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.UpdateKnowledgeBaseRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.knowledgeBase = $root.google.cloud.dialogflow.v2.KnowledgeBase.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.updateMask = $root.google.protobuf.FieldMask.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an UpdateKnowledgeBaseRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.UpdateKnowledgeBaseRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.UpdateKnowledgeBaseRequest} UpdateKnowledgeBaseRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UpdateKnowledgeBaseRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an UpdateKnowledgeBaseRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.UpdateKnowledgeBaseRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        UpdateKnowledgeBaseRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.knowledgeBase != null && message.hasOwnProperty("knowledgeBase")) {
                                var error = $root.google.cloud.dialogflow.v2.KnowledgeBase.verify(message.knowledgeBase);
                                if (error)
                                    return "knowledgeBase." + error;
                            }
                            if (message.updateMask != null && message.hasOwnProperty("updateMask")) {
                                var error = $root.google.protobuf.FieldMask.verify(message.updateMask);
                                if (error)
                                    return "updateMask." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates an UpdateKnowledgeBaseRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.UpdateKnowledgeBaseRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.UpdateKnowledgeBaseRequest} UpdateKnowledgeBaseRequest
                         */
                        UpdateKnowledgeBaseRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.UpdateKnowledgeBaseRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.UpdateKnowledgeBaseRequest();
                            if (object.knowledgeBase != null) {
                                if (typeof object.knowledgeBase !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.UpdateKnowledgeBaseRequest.knowledgeBase: object expected");
                                message.knowledgeBase = $root.google.cloud.dialogflow.v2.KnowledgeBase.fromObject(object.knowledgeBase);
                            }
                            if (object.updateMask != null) {
                                if (typeof object.updateMask !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.UpdateKnowledgeBaseRequest.updateMask: object expected");
                                message.updateMask = $root.google.protobuf.FieldMask.fromObject(object.updateMask);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an UpdateKnowledgeBaseRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.UpdateKnowledgeBaseRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.UpdateKnowledgeBaseRequest} message UpdateKnowledgeBaseRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        UpdateKnowledgeBaseRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.knowledgeBase = null;
                                object.updateMask = null;
                            }
                            if (message.knowledgeBase != null && message.hasOwnProperty("knowledgeBase"))
                                object.knowledgeBase = $root.google.cloud.dialogflow.v2.KnowledgeBase.toObject(message.knowledgeBase, options);
                            if (message.updateMask != null && message.hasOwnProperty("updateMask"))
                                object.updateMask = $root.google.protobuf.FieldMask.toObject(message.updateMask, options);
                            return object;
                        };
    
                        /**
                         * Converts this UpdateKnowledgeBaseRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.UpdateKnowledgeBaseRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        UpdateKnowledgeBaseRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for UpdateKnowledgeBaseRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.UpdateKnowledgeBaseRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        UpdateKnowledgeBaseRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.UpdateKnowledgeBaseRequest";
                        };
    
                        return UpdateKnowledgeBaseRequest;
                    })();
    
                    v2.Versions = (function() {
    
                        /**
                         * Constructs a new Versions service.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a Versions
                         * @extends $protobuf.rpc.Service
                         * @constructor
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         */
                        function Versions(rpcImpl, requestDelimited, responseDelimited) {
                            $protobuf.rpc.Service.call(this, rpcImpl, requestDelimited, responseDelimited);
                        }
    
                        (Versions.prototype = Object.create($protobuf.rpc.Service.prototype)).constructor = Versions;
    
                        /**
                         * Creates new Versions service using the specified rpc implementation.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.Versions
                         * @static
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         * @returns {Versions} RPC service. Useful where requests and/or responses are streamed.
                         */
                        Versions.create = function create(rpcImpl, requestDelimited, responseDelimited) {
                            return new this(rpcImpl, requestDelimited, responseDelimited);
                        };
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Versions|listVersions}.
                         * @memberof google.cloud.dialogflow.v2.Versions
                         * @typedef ListVersionsCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.ListVersionsResponse} [response] ListVersionsResponse
                         */
    
                        /**
                         * Calls ListVersions.
                         * @function listVersions
                         * @memberof google.cloud.dialogflow.v2.Versions
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IListVersionsRequest} request ListVersionsRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Versions.ListVersionsCallback} callback Node-style callback called with the error, if any, and ListVersionsResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Versions.prototype.listVersions = function listVersions(request, callback) {
                            return this.rpcCall(listVersions, $root.google.cloud.dialogflow.v2.ListVersionsRequest, $root.google.cloud.dialogflow.v2.ListVersionsResponse, request, callback);
                        }, "name", { value: "ListVersions" });
    
                        /**
                         * Calls ListVersions.
                         * @function listVersions
                         * @memberof google.cloud.dialogflow.v2.Versions
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IListVersionsRequest} request ListVersionsRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.ListVersionsResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Versions|getVersion}.
                         * @memberof google.cloud.dialogflow.v2.Versions
                         * @typedef GetVersionCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.Version} [response] Version
                         */
    
                        /**
                         * Calls GetVersion.
                         * @function getVersion
                         * @memberof google.cloud.dialogflow.v2.Versions
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IGetVersionRequest} request GetVersionRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Versions.GetVersionCallback} callback Node-style callback called with the error, if any, and Version
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Versions.prototype.getVersion = function getVersion(request, callback) {
                            return this.rpcCall(getVersion, $root.google.cloud.dialogflow.v2.GetVersionRequest, $root.google.cloud.dialogflow.v2.Version, request, callback);
                        }, "name", { value: "GetVersion" });
    
                        /**
                         * Calls GetVersion.
                         * @function getVersion
                         * @memberof google.cloud.dialogflow.v2.Versions
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IGetVersionRequest} request GetVersionRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.Version>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Versions|createVersion}.
                         * @memberof google.cloud.dialogflow.v2.Versions
                         * @typedef CreateVersionCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.Version} [response] Version
                         */
    
                        /**
                         * Calls CreateVersion.
                         * @function createVersion
                         * @memberof google.cloud.dialogflow.v2.Versions
                         * @instance
                         * @param {google.cloud.dialogflow.v2.ICreateVersionRequest} request CreateVersionRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Versions.CreateVersionCallback} callback Node-style callback called with the error, if any, and Version
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Versions.prototype.createVersion = function createVersion(request, callback) {
                            return this.rpcCall(createVersion, $root.google.cloud.dialogflow.v2.CreateVersionRequest, $root.google.cloud.dialogflow.v2.Version, request, callback);
                        }, "name", { value: "CreateVersion" });
    
                        /**
                         * Calls CreateVersion.
                         * @function createVersion
                         * @memberof google.cloud.dialogflow.v2.Versions
                         * @instance
                         * @param {google.cloud.dialogflow.v2.ICreateVersionRequest} request CreateVersionRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.Version>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Versions|updateVersion}.
                         * @memberof google.cloud.dialogflow.v2.Versions
                         * @typedef UpdateVersionCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2.Version} [response] Version
                         */
    
                        /**
                         * Calls UpdateVersion.
                         * @function updateVersion
                         * @memberof google.cloud.dialogflow.v2.Versions
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IUpdateVersionRequest} request UpdateVersionRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Versions.UpdateVersionCallback} callback Node-style callback called with the error, if any, and Version
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Versions.prototype.updateVersion = function updateVersion(request, callback) {
                            return this.rpcCall(updateVersion, $root.google.cloud.dialogflow.v2.UpdateVersionRequest, $root.google.cloud.dialogflow.v2.Version, request, callback);
                        }, "name", { value: "UpdateVersion" });
    
                        /**
                         * Calls UpdateVersion.
                         * @function updateVersion
                         * @memberof google.cloud.dialogflow.v2.Versions
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IUpdateVersionRequest} request UpdateVersionRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2.Version>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2.Versions|deleteVersion}.
                         * @memberof google.cloud.dialogflow.v2.Versions
                         * @typedef DeleteVersionCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.protobuf.Empty} [response] Empty
                         */
    
                        /**
                         * Calls DeleteVersion.
                         * @function deleteVersion
                         * @memberof google.cloud.dialogflow.v2.Versions
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IDeleteVersionRequest} request DeleteVersionRequest message or plain object
                         * @param {google.cloud.dialogflow.v2.Versions.DeleteVersionCallback} callback Node-style callback called with the error, if any, and Empty
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Versions.prototype.deleteVersion = function deleteVersion(request, callback) {
                            return this.rpcCall(deleteVersion, $root.google.cloud.dialogflow.v2.DeleteVersionRequest, $root.google.protobuf.Empty, request, callback);
                        }, "name", { value: "DeleteVersion" });
    
                        /**
                         * Calls DeleteVersion.
                         * @function deleteVersion
                         * @memberof google.cloud.dialogflow.v2.Versions
                         * @instance
                         * @param {google.cloud.dialogflow.v2.IDeleteVersionRequest} request DeleteVersionRequest message or plain object
                         * @returns {Promise<google.protobuf.Empty>} Promise
                         * @variation 2
                         */
    
                        return Versions;
                    })();
    
                    v2.Version = (function() {
    
                        /**
                         * Properties of a Version.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IVersion
                         * @property {string|null} [name] Version name
                         * @property {string|null} [description] Version description
                         * @property {number|null} [versionNumber] Version versionNumber
                         * @property {google.protobuf.ITimestamp|null} [createTime] Version createTime
                         * @property {google.cloud.dialogflow.v2.Version.VersionStatus|null} [status] Version status
                         */
    
                        /**
                         * Constructs a new Version.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a Version.
                         * @implements IVersion
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IVersion=} [properties] Properties to set
                         */
                        function Version(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * Version name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2.Version
                         * @instance
                         */
                        Version.prototype.name = "";
    
                        /**
                         * Version description.
                         * @member {string} description
                         * @memberof google.cloud.dialogflow.v2.Version
                         * @instance
                         */
                        Version.prototype.description = "";
    
                        /**
                         * Version versionNumber.
                         * @member {number} versionNumber
                         * @memberof google.cloud.dialogflow.v2.Version
                         * @instance
                         */
                        Version.prototype.versionNumber = 0;
    
                        /**
                         * Version createTime.
                         * @member {google.protobuf.ITimestamp|null|undefined} createTime
                         * @memberof google.cloud.dialogflow.v2.Version
                         * @instance
                         */
                        Version.prototype.createTime = null;
    
                        /**
                         * Version status.
                         * @member {google.cloud.dialogflow.v2.Version.VersionStatus} status
                         * @memberof google.cloud.dialogflow.v2.Version
                         * @instance
                         */
                        Version.prototype.status = 0;
    
                        /**
                         * Creates a new Version instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.Version
                         * @static
                         * @param {google.cloud.dialogflow.v2.IVersion=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.Version} Version instance
                         */
                        Version.create = function create(properties) {
                            return new Version(properties);
                        };
    
                        /**
                         * Encodes the specified Version message. Does not implicitly {@link google.cloud.dialogflow.v2.Version.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.Version
                         * @static
                         * @param {google.cloud.dialogflow.v2.IVersion} message Version message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        Version.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            if (message.description != null && Object.hasOwnProperty.call(message, "description"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.description);
                            if (message.versionNumber != null && Object.hasOwnProperty.call(message, "versionNumber"))
                                writer.uint32(/* id 3, wireType 0 =*/24).int32(message.versionNumber);
                            if (message.createTime != null && Object.hasOwnProperty.call(message, "createTime"))
                                $root.google.protobuf.Timestamp.encode(message.createTime, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            if (message.status != null && Object.hasOwnProperty.call(message, "status"))
                                writer.uint32(/* id 6, wireType 0 =*/48).int32(message.status);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified Version message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.Version.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.Version
                         * @static
                         * @param {google.cloud.dialogflow.v2.IVersion} message Version message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        Version.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a Version message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.Version
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.Version} Version
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        Version.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.Version();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.description = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.versionNumber = reader.int32();
                                        break;
                                    }
                                case 4: {
                                        message.createTime = $root.google.protobuf.Timestamp.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 6: {
                                        message.status = reader.int32();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a Version message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.Version
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.Version} Version
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        Version.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a Version message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.Version
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        Version.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            if (message.description != null && message.hasOwnProperty("description"))
                                if (!$util.isString(message.description))
                                    return "description: string expected";
                            if (message.versionNumber != null && message.hasOwnProperty("versionNumber"))
                                if (!$util.isInteger(message.versionNumber))
                                    return "versionNumber: integer expected";
                            if (message.createTime != null && message.hasOwnProperty("createTime")) {
                                var error = $root.google.protobuf.Timestamp.verify(message.createTime);
                                if (error)
                                    return "createTime." + error;
                            }
                            if (message.status != null && message.hasOwnProperty("status"))
                                switch (message.status) {
                                default:
                                    return "status: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                    break;
                                }
                            return null;
                        };
    
                        /**
                         * Creates a Version message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.Version
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.Version} Version
                         */
                        Version.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.Version)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.Version();
                            if (object.name != null)
                                message.name = String(object.name);
                            if (object.description != null)
                                message.description = String(object.description);
                            if (object.versionNumber != null)
                                message.versionNumber = object.versionNumber | 0;
                            if (object.createTime != null) {
                                if (typeof object.createTime !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.Version.createTime: object expected");
                                message.createTime = $root.google.protobuf.Timestamp.fromObject(object.createTime);
                            }
                            switch (object.status) {
                            default:
                                if (typeof object.status === "number") {
                                    message.status = object.status;
                                    break;
                                }
                                break;
                            case "VERSION_STATUS_UNSPECIFIED":
                            case 0:
                                message.status = 0;
                                break;
                            case "IN_PROGRESS":
                            case 1:
                                message.status = 1;
                                break;
                            case "READY":
                            case 2:
                                message.status = 2;
                                break;
                            case "FAILED":
                            case 3:
                                message.status = 3;
                                break;
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a Version message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.Version
                         * @static
                         * @param {google.cloud.dialogflow.v2.Version} message Version
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        Version.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.name = "";
                                object.description = "";
                                object.versionNumber = 0;
                                object.createTime = null;
                                object.status = options.enums === String ? "VERSION_STATUS_UNSPECIFIED" : 0;
                            }
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            if (message.description != null && message.hasOwnProperty("description"))
                                object.description = message.description;
                            if (message.versionNumber != null && message.hasOwnProperty("versionNumber"))
                                object.versionNumber = message.versionNumber;
                            if (message.createTime != null && message.hasOwnProperty("createTime"))
                                object.createTime = $root.google.protobuf.Timestamp.toObject(message.createTime, options);
                            if (message.status != null && message.hasOwnProperty("status"))
                                object.status = options.enums === String ? $root.google.cloud.dialogflow.v2.Version.VersionStatus[message.status] === undefined ? message.status : $root.google.cloud.dialogflow.v2.Version.VersionStatus[message.status] : message.status;
                            return object;
                        };
    
                        /**
                         * Converts this Version to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.Version
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        Version.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for Version
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.Version
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        Version.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.Version";
                        };
    
                        /**
                         * VersionStatus enum.
                         * @name google.cloud.dialogflow.v2.Version.VersionStatus
                         * @enum {number}
                         * @property {number} VERSION_STATUS_UNSPECIFIED=0 VERSION_STATUS_UNSPECIFIED value
                         * @property {number} IN_PROGRESS=1 IN_PROGRESS value
                         * @property {number} READY=2 READY value
                         * @property {number} FAILED=3 FAILED value
                         */
                        Version.VersionStatus = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "VERSION_STATUS_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "IN_PROGRESS"] = 1;
                            values[valuesById[2] = "READY"] = 2;
                            values[valuesById[3] = "FAILED"] = 3;
                            return values;
                        })();
    
                        return Version;
                    })();
    
                    v2.ListVersionsRequest = (function() {
    
                        /**
                         * Properties of a ListVersionsRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IListVersionsRequest
                         * @property {string|null} [parent] ListVersionsRequest parent
                         * @property {number|null} [pageSize] ListVersionsRequest pageSize
                         * @property {string|null} [pageToken] ListVersionsRequest pageToken
                         */
    
                        /**
                         * Constructs a new ListVersionsRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a ListVersionsRequest.
                         * @implements IListVersionsRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IListVersionsRequest=} [properties] Properties to set
                         */
                        function ListVersionsRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListVersionsRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.ListVersionsRequest
                         * @instance
                         */
                        ListVersionsRequest.prototype.parent = "";
    
                        /**
                         * ListVersionsRequest pageSize.
                         * @member {number} pageSize
                         * @memberof google.cloud.dialogflow.v2.ListVersionsRequest
                         * @instance
                         */
                        ListVersionsRequest.prototype.pageSize = 0;
    
                        /**
                         * ListVersionsRequest pageToken.
                         * @member {string} pageToken
                         * @memberof google.cloud.dialogflow.v2.ListVersionsRequest
                         * @instance
                         */
                        ListVersionsRequest.prototype.pageToken = "";
    
                        /**
                         * Creates a new ListVersionsRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ListVersionsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListVersionsRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ListVersionsRequest} ListVersionsRequest instance
                         */
                        ListVersionsRequest.create = function create(properties) {
                            return new ListVersionsRequest(properties);
                        };
    
                        /**
                         * Encodes the specified ListVersionsRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.ListVersionsRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ListVersionsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListVersionsRequest} message ListVersionsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListVersionsRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.pageSize != null && Object.hasOwnProperty.call(message, "pageSize"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.pageSize);
                            if (message.pageToken != null && Object.hasOwnProperty.call(message, "pageToken"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.pageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListVersionsRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ListVersionsRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListVersionsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListVersionsRequest} message ListVersionsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListVersionsRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListVersionsRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ListVersionsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ListVersionsRequest} ListVersionsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListVersionsRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ListVersionsRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.pageSize = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.pageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListVersionsRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListVersionsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ListVersionsRequest} ListVersionsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListVersionsRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListVersionsRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ListVersionsRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListVersionsRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                if (!$util.isInteger(message.pageSize))
                                    return "pageSize: integer expected";
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                if (!$util.isString(message.pageToken))
                                    return "pageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListVersionsRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ListVersionsRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ListVersionsRequest} ListVersionsRequest
                         */
                        ListVersionsRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ListVersionsRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ListVersionsRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.pageSize != null)
                                message.pageSize = object.pageSize | 0;
                            if (object.pageToken != null)
                                message.pageToken = String(object.pageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListVersionsRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ListVersionsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ListVersionsRequest} message ListVersionsRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListVersionsRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.pageSize = 0;
                                object.pageToken = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                object.pageSize = message.pageSize;
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                object.pageToken = message.pageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListVersionsRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ListVersionsRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListVersionsRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListVersionsRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ListVersionsRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListVersionsRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ListVersionsRequest";
                        };
    
                        return ListVersionsRequest;
                    })();
    
                    v2.ListVersionsResponse = (function() {
    
                        /**
                         * Properties of a ListVersionsResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IListVersionsResponse
                         * @property {Array.<google.cloud.dialogflow.v2.IVersion>|null} [versions] ListVersionsResponse versions
                         * @property {string|null} [nextPageToken] ListVersionsResponse nextPageToken
                         */
    
                        /**
                         * Constructs a new ListVersionsResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a ListVersionsResponse.
                         * @implements IListVersionsResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IListVersionsResponse=} [properties] Properties to set
                         */
                        function ListVersionsResponse(properties) {
                            this.versions = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListVersionsResponse versions.
                         * @member {Array.<google.cloud.dialogflow.v2.IVersion>} versions
                         * @memberof google.cloud.dialogflow.v2.ListVersionsResponse
                         * @instance
                         */
                        ListVersionsResponse.prototype.versions = $util.emptyArray;
    
                        /**
                         * ListVersionsResponse nextPageToken.
                         * @member {string} nextPageToken
                         * @memberof google.cloud.dialogflow.v2.ListVersionsResponse
                         * @instance
                         */
                        ListVersionsResponse.prototype.nextPageToken = "";
    
                        /**
                         * Creates a new ListVersionsResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.ListVersionsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListVersionsResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.ListVersionsResponse} ListVersionsResponse instance
                         */
                        ListVersionsResponse.create = function create(properties) {
                            return new ListVersionsResponse(properties);
                        };
    
                        /**
                         * Encodes the specified ListVersionsResponse message. Does not implicitly {@link google.cloud.dialogflow.v2.ListVersionsResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.ListVersionsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListVersionsResponse} message ListVersionsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListVersionsResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.versions != null && message.versions.length)
                                for (var i = 0; i < message.versions.length; ++i)
                                    $root.google.cloud.dialogflow.v2.Version.encode(message.versions[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.nextPageToken != null && Object.hasOwnProperty.call(message, "nextPageToken"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.nextPageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListVersionsResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.ListVersionsResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListVersionsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IListVersionsResponse} message ListVersionsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListVersionsResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListVersionsResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.ListVersionsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.ListVersionsResponse} ListVersionsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListVersionsResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.ListVersionsResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.versions && message.versions.length))
                                            message.versions = [];
                                        message.versions.push($root.google.cloud.dialogflow.v2.Version.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 2: {
                                        message.nextPageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListVersionsResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.ListVersionsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.ListVersionsResponse} ListVersionsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListVersionsResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListVersionsResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.ListVersionsResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListVersionsResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.versions != null && message.hasOwnProperty("versions")) {
                                if (!Array.isArray(message.versions))
                                    return "versions: array expected";
                                for (var i = 0; i < message.versions.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.Version.verify(message.versions[i]);
                                    if (error)
                                        return "versions." + error;
                                }
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                if (!$util.isString(message.nextPageToken))
                                    return "nextPageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListVersionsResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.ListVersionsResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.ListVersionsResponse} ListVersionsResponse
                         */
                        ListVersionsResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.ListVersionsResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.ListVersionsResponse();
                            if (object.versions) {
                                if (!Array.isArray(object.versions))
                                    throw TypeError(".google.cloud.dialogflow.v2.ListVersionsResponse.versions: array expected");
                                message.versions = [];
                                for (var i = 0; i < object.versions.length; ++i) {
                                    if (typeof object.versions[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.ListVersionsResponse.versions: object expected");
                                    message.versions[i] = $root.google.cloud.dialogflow.v2.Version.fromObject(object.versions[i]);
                                }
                            }
                            if (object.nextPageToken != null)
                                message.nextPageToken = String(object.nextPageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListVersionsResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.ListVersionsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.ListVersionsResponse} message ListVersionsResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListVersionsResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.versions = [];
                            if (options.defaults)
                                object.nextPageToken = "";
                            if (message.versions && message.versions.length) {
                                object.versions = [];
                                for (var j = 0; j < message.versions.length; ++j)
                                    object.versions[j] = $root.google.cloud.dialogflow.v2.Version.toObject(message.versions[j], options);
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                object.nextPageToken = message.nextPageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListVersionsResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.ListVersionsResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListVersionsResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListVersionsResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.ListVersionsResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListVersionsResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.ListVersionsResponse";
                        };
    
                        return ListVersionsResponse;
                    })();
    
                    v2.GetVersionRequest = (function() {
    
                        /**
                         * Properties of a GetVersionRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IGetVersionRequest
                         * @property {string|null} [name] GetVersionRequest name
                         */
    
                        /**
                         * Constructs a new GetVersionRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a GetVersionRequest.
                         * @implements IGetVersionRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IGetVersionRequest=} [properties] Properties to set
                         */
                        function GetVersionRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GetVersionRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2.GetVersionRequest
                         * @instance
                         */
                        GetVersionRequest.prototype.name = "";
    
                        /**
                         * Creates a new GetVersionRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.GetVersionRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetVersionRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.GetVersionRequest} GetVersionRequest instance
                         */
                        GetVersionRequest.create = function create(properties) {
                            return new GetVersionRequest(properties);
                        };
    
                        /**
                         * Encodes the specified GetVersionRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.GetVersionRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.GetVersionRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetVersionRequest} message GetVersionRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetVersionRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GetVersionRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.GetVersionRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GetVersionRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IGetVersionRequest} message GetVersionRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetVersionRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GetVersionRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.GetVersionRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.GetVersionRequest} GetVersionRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetVersionRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.GetVersionRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GetVersionRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.GetVersionRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.GetVersionRequest} GetVersionRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetVersionRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GetVersionRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.GetVersionRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GetVersionRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a GetVersionRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.GetVersionRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.GetVersionRequest} GetVersionRequest
                         */
                        GetVersionRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.GetVersionRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.GetVersionRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GetVersionRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.GetVersionRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.GetVersionRequest} message GetVersionRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GetVersionRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.name = "";
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            return object;
                        };
    
                        /**
                         * Converts this GetVersionRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.GetVersionRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GetVersionRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GetVersionRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.GetVersionRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GetVersionRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.GetVersionRequest";
                        };
    
                        return GetVersionRequest;
                    })();
    
                    v2.CreateVersionRequest = (function() {
    
                        /**
                         * Properties of a CreateVersionRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface ICreateVersionRequest
                         * @property {string|null} [parent] CreateVersionRequest parent
                         * @property {google.cloud.dialogflow.v2.IVersion|null} [version] CreateVersionRequest version
                         */
    
                        /**
                         * Constructs a new CreateVersionRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a CreateVersionRequest.
                         * @implements ICreateVersionRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.ICreateVersionRequest=} [properties] Properties to set
                         */
                        function CreateVersionRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * CreateVersionRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2.CreateVersionRequest
                         * @instance
                         */
                        CreateVersionRequest.prototype.parent = "";
    
                        /**
                         * CreateVersionRequest version.
                         * @member {google.cloud.dialogflow.v2.IVersion|null|undefined} version
                         * @memberof google.cloud.dialogflow.v2.CreateVersionRequest
                         * @instance
                         */
                        CreateVersionRequest.prototype.version = null;
    
                        /**
                         * Creates a new CreateVersionRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.CreateVersionRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICreateVersionRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.CreateVersionRequest} CreateVersionRequest instance
                         */
                        CreateVersionRequest.create = function create(properties) {
                            return new CreateVersionRequest(properties);
                        };
    
                        /**
                         * Encodes the specified CreateVersionRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.CreateVersionRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.CreateVersionRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICreateVersionRequest} message CreateVersionRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateVersionRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.version != null && Object.hasOwnProperty.call(message, "version"))
                                $root.google.cloud.dialogflow.v2.Version.encode(message.version, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified CreateVersionRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.CreateVersionRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.CreateVersionRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.ICreateVersionRequest} message CreateVersionRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateVersionRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a CreateVersionRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.CreateVersionRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.CreateVersionRequest} CreateVersionRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateVersionRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.CreateVersionRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.version = $root.google.cloud.dialogflow.v2.Version.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a CreateVersionRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.CreateVersionRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.CreateVersionRequest} CreateVersionRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateVersionRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a CreateVersionRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.CreateVersionRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        CreateVersionRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.version != null && message.hasOwnProperty("version")) {
                                var error = $root.google.cloud.dialogflow.v2.Version.verify(message.version);
                                if (error)
                                    return "version." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a CreateVersionRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.CreateVersionRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.CreateVersionRequest} CreateVersionRequest
                         */
                        CreateVersionRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.CreateVersionRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.CreateVersionRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.version != null) {
                                if (typeof object.version !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.CreateVersionRequest.version: object expected");
                                message.version = $root.google.cloud.dialogflow.v2.Version.fromObject(object.version);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a CreateVersionRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.CreateVersionRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.CreateVersionRequest} message CreateVersionRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        CreateVersionRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.version = null;
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.version != null && message.hasOwnProperty("version"))
                                object.version = $root.google.cloud.dialogflow.v2.Version.toObject(message.version, options);
                            return object;
                        };
    
                        /**
                         * Converts this CreateVersionRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.CreateVersionRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        CreateVersionRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for CreateVersionRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.CreateVersionRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        CreateVersionRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.CreateVersionRequest";
                        };
    
                        return CreateVersionRequest;
                    })();
    
                    v2.UpdateVersionRequest = (function() {
    
                        /**
                         * Properties of an UpdateVersionRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IUpdateVersionRequest
                         * @property {google.cloud.dialogflow.v2.IVersion|null} [version] UpdateVersionRequest version
                         * @property {google.protobuf.IFieldMask|null} [updateMask] UpdateVersionRequest updateMask
                         */
    
                        /**
                         * Constructs a new UpdateVersionRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an UpdateVersionRequest.
                         * @implements IUpdateVersionRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IUpdateVersionRequest=} [properties] Properties to set
                         */
                        function UpdateVersionRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * UpdateVersionRequest version.
                         * @member {google.cloud.dialogflow.v2.IVersion|null|undefined} version
                         * @memberof google.cloud.dialogflow.v2.UpdateVersionRequest
                         * @instance
                         */
                        UpdateVersionRequest.prototype.version = null;
    
                        /**
                         * UpdateVersionRequest updateMask.
                         * @member {google.protobuf.IFieldMask|null|undefined} updateMask
                         * @memberof google.cloud.dialogflow.v2.UpdateVersionRequest
                         * @instance
                         */
                        UpdateVersionRequest.prototype.updateMask = null;
    
                        /**
                         * Creates a new UpdateVersionRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.UpdateVersionRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IUpdateVersionRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.UpdateVersionRequest} UpdateVersionRequest instance
                         */
                        UpdateVersionRequest.create = function create(properties) {
                            return new UpdateVersionRequest(properties);
                        };
    
                        /**
                         * Encodes the specified UpdateVersionRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.UpdateVersionRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.UpdateVersionRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IUpdateVersionRequest} message UpdateVersionRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UpdateVersionRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.version != null && Object.hasOwnProperty.call(message, "version"))
                                $root.google.cloud.dialogflow.v2.Version.encode(message.version, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.updateMask != null && Object.hasOwnProperty.call(message, "updateMask"))
                                $root.google.protobuf.FieldMask.encode(message.updateMask, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified UpdateVersionRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.UpdateVersionRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.UpdateVersionRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IUpdateVersionRequest} message UpdateVersionRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UpdateVersionRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an UpdateVersionRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.UpdateVersionRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.UpdateVersionRequest} UpdateVersionRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UpdateVersionRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.UpdateVersionRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.version = $root.google.cloud.dialogflow.v2.Version.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.updateMask = $root.google.protobuf.FieldMask.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an UpdateVersionRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.UpdateVersionRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.UpdateVersionRequest} UpdateVersionRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UpdateVersionRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an UpdateVersionRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.UpdateVersionRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        UpdateVersionRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.version != null && message.hasOwnProperty("version")) {
                                var error = $root.google.cloud.dialogflow.v2.Version.verify(message.version);
                                if (error)
                                    return "version." + error;
                            }
                            if (message.updateMask != null && message.hasOwnProperty("updateMask")) {
                                var error = $root.google.protobuf.FieldMask.verify(message.updateMask);
                                if (error)
                                    return "updateMask." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates an UpdateVersionRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.UpdateVersionRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.UpdateVersionRequest} UpdateVersionRequest
                         */
                        UpdateVersionRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.UpdateVersionRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.UpdateVersionRequest();
                            if (object.version != null) {
                                if (typeof object.version !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.UpdateVersionRequest.version: object expected");
                                message.version = $root.google.cloud.dialogflow.v2.Version.fromObject(object.version);
                            }
                            if (object.updateMask != null) {
                                if (typeof object.updateMask !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.UpdateVersionRequest.updateMask: object expected");
                                message.updateMask = $root.google.protobuf.FieldMask.fromObject(object.updateMask);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an UpdateVersionRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.UpdateVersionRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.UpdateVersionRequest} message UpdateVersionRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        UpdateVersionRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.version = null;
                                object.updateMask = null;
                            }
                            if (message.version != null && message.hasOwnProperty("version"))
                                object.version = $root.google.cloud.dialogflow.v2.Version.toObject(message.version, options);
                            if (message.updateMask != null && message.hasOwnProperty("updateMask"))
                                object.updateMask = $root.google.protobuf.FieldMask.toObject(message.updateMask, options);
                            return object;
                        };
    
                        /**
                         * Converts this UpdateVersionRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.UpdateVersionRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        UpdateVersionRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for UpdateVersionRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.UpdateVersionRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        UpdateVersionRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.UpdateVersionRequest";
                        };
    
                        return UpdateVersionRequest;
                    })();
    
                    v2.DeleteVersionRequest = (function() {
    
                        /**
                         * Properties of a DeleteVersionRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IDeleteVersionRequest
                         * @property {string|null} [name] DeleteVersionRequest name
                         */
    
                        /**
                         * Constructs a new DeleteVersionRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a DeleteVersionRequest.
                         * @implements IDeleteVersionRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IDeleteVersionRequest=} [properties] Properties to set
                         */
                        function DeleteVersionRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * DeleteVersionRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2.DeleteVersionRequest
                         * @instance
                         */
                        DeleteVersionRequest.prototype.name = "";
    
                        /**
                         * Creates a new DeleteVersionRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.DeleteVersionRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDeleteVersionRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.DeleteVersionRequest} DeleteVersionRequest instance
                         */
                        DeleteVersionRequest.create = function create(properties) {
                            return new DeleteVersionRequest(properties);
                        };
    
                        /**
                         * Encodes the specified DeleteVersionRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.DeleteVersionRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.DeleteVersionRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDeleteVersionRequest} message DeleteVersionRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteVersionRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified DeleteVersionRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.DeleteVersionRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.DeleteVersionRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IDeleteVersionRequest} message DeleteVersionRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteVersionRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a DeleteVersionRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.DeleteVersionRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.DeleteVersionRequest} DeleteVersionRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteVersionRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.DeleteVersionRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a DeleteVersionRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.DeleteVersionRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.DeleteVersionRequest} DeleteVersionRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteVersionRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a DeleteVersionRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.DeleteVersionRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        DeleteVersionRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a DeleteVersionRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.DeleteVersionRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.DeleteVersionRequest} DeleteVersionRequest
                         */
                        DeleteVersionRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.DeleteVersionRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.DeleteVersionRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a DeleteVersionRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.DeleteVersionRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.DeleteVersionRequest} message DeleteVersionRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        DeleteVersionRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.name = "";
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            return object;
                        };
    
                        /**
                         * Converts this DeleteVersionRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.DeleteVersionRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        DeleteVersionRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for DeleteVersionRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.DeleteVersionRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        DeleteVersionRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.DeleteVersionRequest";
                        };
    
                        return DeleteVersionRequest;
                    })();
    
                    v2.WebhookRequest = (function() {
    
                        /**
                         * Properties of a WebhookRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IWebhookRequest
                         * @property {string|null} [session] WebhookRequest session
                         * @property {string|null} [responseId] WebhookRequest responseId
                         * @property {google.cloud.dialogflow.v2.IQueryResult|null} [queryResult] WebhookRequest queryResult
                         * @property {google.cloud.dialogflow.v2.IOriginalDetectIntentRequest|null} [originalDetectIntentRequest] WebhookRequest originalDetectIntentRequest
                         */
    
                        /**
                         * Constructs a new WebhookRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a WebhookRequest.
                         * @implements IWebhookRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IWebhookRequest=} [properties] Properties to set
                         */
                        function WebhookRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * WebhookRequest session.
                         * @member {string} session
                         * @memberof google.cloud.dialogflow.v2.WebhookRequest
                         * @instance
                         */
                        WebhookRequest.prototype.session = "";
    
                        /**
                         * WebhookRequest responseId.
                         * @member {string} responseId
                         * @memberof google.cloud.dialogflow.v2.WebhookRequest
                         * @instance
                         */
                        WebhookRequest.prototype.responseId = "";
    
                        /**
                         * WebhookRequest queryResult.
                         * @member {google.cloud.dialogflow.v2.IQueryResult|null|undefined} queryResult
                         * @memberof google.cloud.dialogflow.v2.WebhookRequest
                         * @instance
                         */
                        WebhookRequest.prototype.queryResult = null;
    
                        /**
                         * WebhookRequest originalDetectIntentRequest.
                         * @member {google.cloud.dialogflow.v2.IOriginalDetectIntentRequest|null|undefined} originalDetectIntentRequest
                         * @memberof google.cloud.dialogflow.v2.WebhookRequest
                         * @instance
                         */
                        WebhookRequest.prototype.originalDetectIntentRequest = null;
    
                        /**
                         * Creates a new WebhookRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.WebhookRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IWebhookRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.WebhookRequest} WebhookRequest instance
                         */
                        WebhookRequest.create = function create(properties) {
                            return new WebhookRequest(properties);
                        };
    
                        /**
                         * Encodes the specified WebhookRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.WebhookRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.WebhookRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IWebhookRequest} message WebhookRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        WebhookRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.responseId != null && Object.hasOwnProperty.call(message, "responseId"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.responseId);
                            if (message.queryResult != null && Object.hasOwnProperty.call(message, "queryResult"))
                                $root.google.cloud.dialogflow.v2.QueryResult.encode(message.queryResult, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.originalDetectIntentRequest != null && Object.hasOwnProperty.call(message, "originalDetectIntentRequest"))
                                $root.google.cloud.dialogflow.v2.OriginalDetectIntentRequest.encode(message.originalDetectIntentRequest, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            if (message.session != null && Object.hasOwnProperty.call(message, "session"))
                                writer.uint32(/* id 4, wireType 2 =*/34).string(message.session);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified WebhookRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.WebhookRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.WebhookRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IWebhookRequest} message WebhookRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        WebhookRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a WebhookRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.WebhookRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.WebhookRequest} WebhookRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        WebhookRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.WebhookRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 4: {
                                        message.session = reader.string();
                                        break;
                                    }
                                case 1: {
                                        message.responseId = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.queryResult = $root.google.cloud.dialogflow.v2.QueryResult.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 3: {
                                        message.originalDetectIntentRequest = $root.google.cloud.dialogflow.v2.OriginalDetectIntentRequest.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a WebhookRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.WebhookRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.WebhookRequest} WebhookRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        WebhookRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a WebhookRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.WebhookRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        WebhookRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.session != null && message.hasOwnProperty("session"))
                                if (!$util.isString(message.session))
                                    return "session: string expected";
                            if (message.responseId != null && message.hasOwnProperty("responseId"))
                                if (!$util.isString(message.responseId))
                                    return "responseId: string expected";
                            if (message.queryResult != null && message.hasOwnProperty("queryResult")) {
                                var error = $root.google.cloud.dialogflow.v2.QueryResult.verify(message.queryResult);
                                if (error)
                                    return "queryResult." + error;
                            }
                            if (message.originalDetectIntentRequest != null && message.hasOwnProperty("originalDetectIntentRequest")) {
                                var error = $root.google.cloud.dialogflow.v2.OriginalDetectIntentRequest.verify(message.originalDetectIntentRequest);
                                if (error)
                                    return "originalDetectIntentRequest." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a WebhookRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.WebhookRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.WebhookRequest} WebhookRequest
                         */
                        WebhookRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.WebhookRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.WebhookRequest();
                            if (object.session != null)
                                message.session = String(object.session);
                            if (object.responseId != null)
                                message.responseId = String(object.responseId);
                            if (object.queryResult != null) {
                                if (typeof object.queryResult !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.WebhookRequest.queryResult: object expected");
                                message.queryResult = $root.google.cloud.dialogflow.v2.QueryResult.fromObject(object.queryResult);
                            }
                            if (object.originalDetectIntentRequest != null) {
                                if (typeof object.originalDetectIntentRequest !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.WebhookRequest.originalDetectIntentRequest: object expected");
                                message.originalDetectIntentRequest = $root.google.cloud.dialogflow.v2.OriginalDetectIntentRequest.fromObject(object.originalDetectIntentRequest);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a WebhookRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.WebhookRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.WebhookRequest} message WebhookRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        WebhookRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.responseId = "";
                                object.queryResult = null;
                                object.originalDetectIntentRequest = null;
                                object.session = "";
                            }
                            if (message.responseId != null && message.hasOwnProperty("responseId"))
                                object.responseId = message.responseId;
                            if (message.queryResult != null && message.hasOwnProperty("queryResult"))
                                object.queryResult = $root.google.cloud.dialogflow.v2.QueryResult.toObject(message.queryResult, options);
                            if (message.originalDetectIntentRequest != null && message.hasOwnProperty("originalDetectIntentRequest"))
                                object.originalDetectIntentRequest = $root.google.cloud.dialogflow.v2.OriginalDetectIntentRequest.toObject(message.originalDetectIntentRequest, options);
                            if (message.session != null && message.hasOwnProperty("session"))
                                object.session = message.session;
                            return object;
                        };
    
                        /**
                         * Converts this WebhookRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.WebhookRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        WebhookRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for WebhookRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.WebhookRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        WebhookRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.WebhookRequest";
                        };
    
                        return WebhookRequest;
                    })();
    
                    v2.WebhookResponse = (function() {
    
                        /**
                         * Properties of a WebhookResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IWebhookResponse
                         * @property {string|null} [fulfillmentText] WebhookResponse fulfillmentText
                         * @property {Array.<google.cloud.dialogflow.v2.Intent.IMessage>|null} [fulfillmentMessages] WebhookResponse fulfillmentMessages
                         * @property {string|null} [source] WebhookResponse source
                         * @property {google.protobuf.IStruct|null} [payload] WebhookResponse payload
                         * @property {Array.<google.cloud.dialogflow.v2.IContext>|null} [outputContexts] WebhookResponse outputContexts
                         * @property {google.cloud.dialogflow.v2.IEventInput|null} [followupEventInput] WebhookResponse followupEventInput
                         * @property {Array.<google.cloud.dialogflow.v2.ISessionEntityType>|null} [sessionEntityTypes] WebhookResponse sessionEntityTypes
                         */
    
                        /**
                         * Constructs a new WebhookResponse.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents a WebhookResponse.
                         * @implements IWebhookResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IWebhookResponse=} [properties] Properties to set
                         */
                        function WebhookResponse(properties) {
                            this.fulfillmentMessages = [];
                            this.outputContexts = [];
                            this.sessionEntityTypes = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * WebhookResponse fulfillmentText.
                         * @member {string} fulfillmentText
                         * @memberof google.cloud.dialogflow.v2.WebhookResponse
                         * @instance
                         */
                        WebhookResponse.prototype.fulfillmentText = "";
    
                        /**
                         * WebhookResponse fulfillmentMessages.
                         * @member {Array.<google.cloud.dialogflow.v2.Intent.IMessage>} fulfillmentMessages
                         * @memberof google.cloud.dialogflow.v2.WebhookResponse
                         * @instance
                         */
                        WebhookResponse.prototype.fulfillmentMessages = $util.emptyArray;
    
                        /**
                         * WebhookResponse source.
                         * @member {string} source
                         * @memberof google.cloud.dialogflow.v2.WebhookResponse
                         * @instance
                         */
                        WebhookResponse.prototype.source = "";
    
                        /**
                         * WebhookResponse payload.
                         * @member {google.protobuf.IStruct|null|undefined} payload
                         * @memberof google.cloud.dialogflow.v2.WebhookResponse
                         * @instance
                         */
                        WebhookResponse.prototype.payload = null;
    
                        /**
                         * WebhookResponse outputContexts.
                         * @member {Array.<google.cloud.dialogflow.v2.IContext>} outputContexts
                         * @memberof google.cloud.dialogflow.v2.WebhookResponse
                         * @instance
                         */
                        WebhookResponse.prototype.outputContexts = $util.emptyArray;
    
                        /**
                         * WebhookResponse followupEventInput.
                         * @member {google.cloud.dialogflow.v2.IEventInput|null|undefined} followupEventInput
                         * @memberof google.cloud.dialogflow.v2.WebhookResponse
                         * @instance
                         */
                        WebhookResponse.prototype.followupEventInput = null;
    
                        /**
                         * WebhookResponse sessionEntityTypes.
                         * @member {Array.<google.cloud.dialogflow.v2.ISessionEntityType>} sessionEntityTypes
                         * @memberof google.cloud.dialogflow.v2.WebhookResponse
                         * @instance
                         */
                        WebhookResponse.prototype.sessionEntityTypes = $util.emptyArray;
    
                        /**
                         * Creates a new WebhookResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.WebhookResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IWebhookResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.WebhookResponse} WebhookResponse instance
                         */
                        WebhookResponse.create = function create(properties) {
                            return new WebhookResponse(properties);
                        };
    
                        /**
                         * Encodes the specified WebhookResponse message. Does not implicitly {@link google.cloud.dialogflow.v2.WebhookResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.WebhookResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IWebhookResponse} message WebhookResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        WebhookResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.fulfillmentText != null && Object.hasOwnProperty.call(message, "fulfillmentText"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.fulfillmentText);
                            if (message.fulfillmentMessages != null && message.fulfillmentMessages.length)
                                for (var i = 0; i < message.fulfillmentMessages.length; ++i)
                                    $root.google.cloud.dialogflow.v2.Intent.Message.encode(message.fulfillmentMessages[i], writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.source != null && Object.hasOwnProperty.call(message, "source"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.source);
                            if (message.payload != null && Object.hasOwnProperty.call(message, "payload"))
                                $root.google.protobuf.Struct.encode(message.payload, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            if (message.outputContexts != null && message.outputContexts.length)
                                for (var i = 0; i < message.outputContexts.length; ++i)
                                    $root.google.cloud.dialogflow.v2.Context.encode(message.outputContexts[i], writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                            if (message.followupEventInput != null && Object.hasOwnProperty.call(message, "followupEventInput"))
                                $root.google.cloud.dialogflow.v2.EventInput.encode(message.followupEventInput, writer.uint32(/* id 6, wireType 2 =*/50).fork()).ldelim();
                            if (message.sessionEntityTypes != null && message.sessionEntityTypes.length)
                                for (var i = 0; i < message.sessionEntityTypes.length; ++i)
                                    $root.google.cloud.dialogflow.v2.SessionEntityType.encode(message.sessionEntityTypes[i], writer.uint32(/* id 10, wireType 2 =*/82).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified WebhookResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.WebhookResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.WebhookResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.IWebhookResponse} message WebhookResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        WebhookResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a WebhookResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.WebhookResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.WebhookResponse} WebhookResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        WebhookResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.WebhookResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.fulfillmentText = reader.string();
                                        break;
                                    }
                                case 2: {
                                        if (!(message.fulfillmentMessages && message.fulfillmentMessages.length))
                                            message.fulfillmentMessages = [];
                                        message.fulfillmentMessages.push($root.google.cloud.dialogflow.v2.Intent.Message.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 3: {
                                        message.source = reader.string();
                                        break;
                                    }
                                case 4: {
                                        message.payload = $root.google.protobuf.Struct.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 5: {
                                        if (!(message.outputContexts && message.outputContexts.length))
                                            message.outputContexts = [];
                                        message.outputContexts.push($root.google.cloud.dialogflow.v2.Context.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 6: {
                                        message.followupEventInput = $root.google.cloud.dialogflow.v2.EventInput.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 10: {
                                        if (!(message.sessionEntityTypes && message.sessionEntityTypes.length))
                                            message.sessionEntityTypes = [];
                                        message.sessionEntityTypes.push($root.google.cloud.dialogflow.v2.SessionEntityType.decode(reader, reader.uint32()));
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a WebhookResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.WebhookResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.WebhookResponse} WebhookResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        WebhookResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a WebhookResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.WebhookResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        WebhookResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.fulfillmentText != null && message.hasOwnProperty("fulfillmentText"))
                                if (!$util.isString(message.fulfillmentText))
                                    return "fulfillmentText: string expected";
                            if (message.fulfillmentMessages != null && message.hasOwnProperty("fulfillmentMessages")) {
                                if (!Array.isArray(message.fulfillmentMessages))
                                    return "fulfillmentMessages: array expected";
                                for (var i = 0; i < message.fulfillmentMessages.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.Intent.Message.verify(message.fulfillmentMessages[i]);
                                    if (error)
                                        return "fulfillmentMessages." + error;
                                }
                            }
                            if (message.source != null && message.hasOwnProperty("source"))
                                if (!$util.isString(message.source))
                                    return "source: string expected";
                            if (message.payload != null && message.hasOwnProperty("payload")) {
                                var error = $root.google.protobuf.Struct.verify(message.payload);
                                if (error)
                                    return "payload." + error;
                            }
                            if (message.outputContexts != null && message.hasOwnProperty("outputContexts")) {
                                if (!Array.isArray(message.outputContexts))
                                    return "outputContexts: array expected";
                                for (var i = 0; i < message.outputContexts.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.Context.verify(message.outputContexts[i]);
                                    if (error)
                                        return "outputContexts." + error;
                                }
                            }
                            if (message.followupEventInput != null && message.hasOwnProperty("followupEventInput")) {
                                var error = $root.google.cloud.dialogflow.v2.EventInput.verify(message.followupEventInput);
                                if (error)
                                    return "followupEventInput." + error;
                            }
                            if (message.sessionEntityTypes != null && message.hasOwnProperty("sessionEntityTypes")) {
                                if (!Array.isArray(message.sessionEntityTypes))
                                    return "sessionEntityTypes: array expected";
                                for (var i = 0; i < message.sessionEntityTypes.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2.SessionEntityType.verify(message.sessionEntityTypes[i]);
                                    if (error)
                                        return "sessionEntityTypes." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates a WebhookResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.WebhookResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.WebhookResponse} WebhookResponse
                         */
                        WebhookResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.WebhookResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.WebhookResponse();
                            if (object.fulfillmentText != null)
                                message.fulfillmentText = String(object.fulfillmentText);
                            if (object.fulfillmentMessages) {
                                if (!Array.isArray(object.fulfillmentMessages))
                                    throw TypeError(".google.cloud.dialogflow.v2.WebhookResponse.fulfillmentMessages: array expected");
                                message.fulfillmentMessages = [];
                                for (var i = 0; i < object.fulfillmentMessages.length; ++i) {
                                    if (typeof object.fulfillmentMessages[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.WebhookResponse.fulfillmentMessages: object expected");
                                    message.fulfillmentMessages[i] = $root.google.cloud.dialogflow.v2.Intent.Message.fromObject(object.fulfillmentMessages[i]);
                                }
                            }
                            if (object.source != null)
                                message.source = String(object.source);
                            if (object.payload != null) {
                                if (typeof object.payload !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.WebhookResponse.payload: object expected");
                                message.payload = $root.google.protobuf.Struct.fromObject(object.payload);
                            }
                            if (object.outputContexts) {
                                if (!Array.isArray(object.outputContexts))
                                    throw TypeError(".google.cloud.dialogflow.v2.WebhookResponse.outputContexts: array expected");
                                message.outputContexts = [];
                                for (var i = 0; i < object.outputContexts.length; ++i) {
                                    if (typeof object.outputContexts[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.WebhookResponse.outputContexts: object expected");
                                    message.outputContexts[i] = $root.google.cloud.dialogflow.v2.Context.fromObject(object.outputContexts[i]);
                                }
                            }
                            if (object.followupEventInput != null) {
                                if (typeof object.followupEventInput !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.WebhookResponse.followupEventInput: object expected");
                                message.followupEventInput = $root.google.cloud.dialogflow.v2.EventInput.fromObject(object.followupEventInput);
                            }
                            if (object.sessionEntityTypes) {
                                if (!Array.isArray(object.sessionEntityTypes))
                                    throw TypeError(".google.cloud.dialogflow.v2.WebhookResponse.sessionEntityTypes: array expected");
                                message.sessionEntityTypes = [];
                                for (var i = 0; i < object.sessionEntityTypes.length; ++i) {
                                    if (typeof object.sessionEntityTypes[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2.WebhookResponse.sessionEntityTypes: object expected");
                                    message.sessionEntityTypes[i] = $root.google.cloud.dialogflow.v2.SessionEntityType.fromObject(object.sessionEntityTypes[i]);
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a WebhookResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.WebhookResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2.WebhookResponse} message WebhookResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        WebhookResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults) {
                                object.fulfillmentMessages = [];
                                object.outputContexts = [];
                                object.sessionEntityTypes = [];
                            }
                            if (options.defaults) {
                                object.fulfillmentText = "";
                                object.source = "";
                                object.payload = null;
                                object.followupEventInput = null;
                            }
                            if (message.fulfillmentText != null && message.hasOwnProperty("fulfillmentText"))
                                object.fulfillmentText = message.fulfillmentText;
                            if (message.fulfillmentMessages && message.fulfillmentMessages.length) {
                                object.fulfillmentMessages = [];
                                for (var j = 0; j < message.fulfillmentMessages.length; ++j)
                                    object.fulfillmentMessages[j] = $root.google.cloud.dialogflow.v2.Intent.Message.toObject(message.fulfillmentMessages[j], options);
                            }
                            if (message.source != null && message.hasOwnProperty("source"))
                                object.source = message.source;
                            if (message.payload != null && message.hasOwnProperty("payload"))
                                object.payload = $root.google.protobuf.Struct.toObject(message.payload, options);
                            if (message.outputContexts && message.outputContexts.length) {
                                object.outputContexts = [];
                                for (var j = 0; j < message.outputContexts.length; ++j)
                                    object.outputContexts[j] = $root.google.cloud.dialogflow.v2.Context.toObject(message.outputContexts[j], options);
                            }
                            if (message.followupEventInput != null && message.hasOwnProperty("followupEventInput"))
                                object.followupEventInput = $root.google.cloud.dialogflow.v2.EventInput.toObject(message.followupEventInput, options);
                            if (message.sessionEntityTypes && message.sessionEntityTypes.length) {
                                object.sessionEntityTypes = [];
                                for (var j = 0; j < message.sessionEntityTypes.length; ++j)
                                    object.sessionEntityTypes[j] = $root.google.cloud.dialogflow.v2.SessionEntityType.toObject(message.sessionEntityTypes[j], options);
                            }
                            return object;
                        };
    
                        /**
                         * Converts this WebhookResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.WebhookResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        WebhookResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for WebhookResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.WebhookResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        WebhookResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.WebhookResponse";
                        };
    
                        return WebhookResponse;
                    })();
    
                    v2.OriginalDetectIntentRequest = (function() {
    
                        /**
                         * Properties of an OriginalDetectIntentRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @interface IOriginalDetectIntentRequest
                         * @property {string|null} [source] OriginalDetectIntentRequest source
                         * @property {string|null} [version] OriginalDetectIntentRequest version
                         * @property {google.protobuf.IStruct|null} [payload] OriginalDetectIntentRequest payload
                         */
    
                        /**
                         * Constructs a new OriginalDetectIntentRequest.
                         * @memberof google.cloud.dialogflow.v2
                         * @classdesc Represents an OriginalDetectIntentRequest.
                         * @implements IOriginalDetectIntentRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2.IOriginalDetectIntentRequest=} [properties] Properties to set
                         */
                        function OriginalDetectIntentRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * OriginalDetectIntentRequest source.
                         * @member {string} source
                         * @memberof google.cloud.dialogflow.v2.OriginalDetectIntentRequest
                         * @instance
                         */
                        OriginalDetectIntentRequest.prototype.source = "";
    
                        /**
                         * OriginalDetectIntentRequest version.
                         * @member {string} version
                         * @memberof google.cloud.dialogflow.v2.OriginalDetectIntentRequest
                         * @instance
                         */
                        OriginalDetectIntentRequest.prototype.version = "";
    
                        /**
                         * OriginalDetectIntentRequest payload.
                         * @member {google.protobuf.IStruct|null|undefined} payload
                         * @memberof google.cloud.dialogflow.v2.OriginalDetectIntentRequest
                         * @instance
                         */
                        OriginalDetectIntentRequest.prototype.payload = null;
    
                        /**
                         * Creates a new OriginalDetectIntentRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2.OriginalDetectIntentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IOriginalDetectIntentRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2.OriginalDetectIntentRequest} OriginalDetectIntentRequest instance
                         */
                        OriginalDetectIntentRequest.create = function create(properties) {
                            return new OriginalDetectIntentRequest(properties);
                        };
    
                        /**
                         * Encodes the specified OriginalDetectIntentRequest message. Does not implicitly {@link google.cloud.dialogflow.v2.OriginalDetectIntentRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2.OriginalDetectIntentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IOriginalDetectIntentRequest} message OriginalDetectIntentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        OriginalDetectIntentRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.source != null && Object.hasOwnProperty.call(message, "source"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.source);
                            if (message.version != null && Object.hasOwnProperty.call(message, "version"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.version);
                            if (message.payload != null && Object.hasOwnProperty.call(message, "payload"))
                                $root.google.protobuf.Struct.encode(message.payload, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified OriginalDetectIntentRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2.OriginalDetectIntentRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2.OriginalDetectIntentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.IOriginalDetectIntentRequest} message OriginalDetectIntentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        OriginalDetectIntentRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an OriginalDetectIntentRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2.OriginalDetectIntentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2.OriginalDetectIntentRequest} OriginalDetectIntentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        OriginalDetectIntentRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2.OriginalDetectIntentRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.source = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.version = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.payload = $root.google.protobuf.Struct.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an OriginalDetectIntentRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2.OriginalDetectIntentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2.OriginalDetectIntentRequest} OriginalDetectIntentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        OriginalDetectIntentRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an OriginalDetectIntentRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2.OriginalDetectIntentRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        OriginalDetectIntentRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.source != null && message.hasOwnProperty("source"))
                                if (!$util.isString(message.source))
                                    return "source: string expected";
                            if (message.version != null && message.hasOwnProperty("version"))
                                if (!$util.isString(message.version))
                                    return "version: string expected";
                            if (message.payload != null && message.hasOwnProperty("payload")) {
                                var error = $root.google.protobuf.Struct.verify(message.payload);
                                if (error)
                                    return "payload." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates an OriginalDetectIntentRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2.OriginalDetectIntentRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2.OriginalDetectIntentRequest} OriginalDetectIntentRequest
                         */
                        OriginalDetectIntentRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2.OriginalDetectIntentRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2.OriginalDetectIntentRequest();
                            if (object.source != null)
                                message.source = String(object.source);
                            if (object.version != null)
                                message.version = String(object.version);
                            if (object.payload != null) {
                                if (typeof object.payload !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2.OriginalDetectIntentRequest.payload: object expected");
                                message.payload = $root.google.protobuf.Struct.fromObject(object.payload);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an OriginalDetectIntentRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2.OriginalDetectIntentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2.OriginalDetectIntentRequest} message OriginalDetectIntentRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        OriginalDetectIntentRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.source = "";
                                object.version = "";
                                object.payload = null;
                            }
                            if (message.source != null && message.hasOwnProperty("source"))
                                object.source = message.source;
                            if (message.version != null && message.hasOwnProperty("version"))
                                object.version = message.version;
                            if (message.payload != null && message.hasOwnProperty("payload"))
                                object.payload = $root.google.protobuf.Struct.toObject(message.payload, options);
                            return object;
                        };
    
                        /**
                         * Converts this OriginalDetectIntentRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2.OriginalDetectIntentRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        OriginalDetectIntentRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for OriginalDetectIntentRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2.OriginalDetectIntentRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        OriginalDetectIntentRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2.OriginalDetectIntentRequest";
                        };
    
                        return OriginalDetectIntentRequest;
                    })();
    
                    return v2;
                })();
    
                dialogflow.v2beta1 = (function() {
    
                    /**
                     * Namespace v2beta1.
                     * @memberof google.cloud.dialogflow
                     * @namespace
                     */
                    var v2beta1 = {};
    
                    v2beta1.Agents = (function() {
    
                        /**
                         * Constructs a new Agents service.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an Agents
                         * @extends $protobuf.rpc.Service
                         * @constructor
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         */
                        function Agents(rpcImpl, requestDelimited, responseDelimited) {
                            $protobuf.rpc.Service.call(this, rpcImpl, requestDelimited, responseDelimited);
                        }
    
                        (Agents.prototype = Object.create($protobuf.rpc.Service.prototype)).constructor = Agents;
    
                        /**
                         * Creates new Agents service using the specified rpc implementation.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.Agents
                         * @static
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         * @returns {Agents} RPC service. Useful where requests and/or responses are streamed.
                         */
                        Agents.create = function create(rpcImpl, requestDelimited, responseDelimited) {
                            return new this(rpcImpl, requestDelimited, responseDelimited);
                        };
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Agents|getAgent}.
                         * @memberof google.cloud.dialogflow.v2beta1.Agents
                         * @typedef GetAgentCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.Agent} [response] Agent
                         */
    
                        /**
                         * Calls GetAgent.
                         * @function getAgent
                         * @memberof google.cloud.dialogflow.v2beta1.Agents
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IGetAgentRequest} request GetAgentRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Agents.GetAgentCallback} callback Node-style callback called with the error, if any, and Agent
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Agents.prototype.getAgent = function getAgent(request, callback) {
                            return this.rpcCall(getAgent, $root.google.cloud.dialogflow.v2beta1.GetAgentRequest, $root.google.cloud.dialogflow.v2beta1.Agent, request, callback);
                        }, "name", { value: "GetAgent" });
    
                        /**
                         * Calls GetAgent.
                         * @function getAgent
                         * @memberof google.cloud.dialogflow.v2beta1.Agents
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IGetAgentRequest} request GetAgentRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.Agent>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Agents|setAgent}.
                         * @memberof google.cloud.dialogflow.v2beta1.Agents
                         * @typedef SetAgentCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.Agent} [response] Agent
                         */
    
                        /**
                         * Calls SetAgent.
                         * @function setAgent
                         * @memberof google.cloud.dialogflow.v2beta1.Agents
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.ISetAgentRequest} request SetAgentRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Agents.SetAgentCallback} callback Node-style callback called with the error, if any, and Agent
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Agents.prototype.setAgent = function setAgent(request, callback) {
                            return this.rpcCall(setAgent, $root.google.cloud.dialogflow.v2beta1.SetAgentRequest, $root.google.cloud.dialogflow.v2beta1.Agent, request, callback);
                        }, "name", { value: "SetAgent" });
    
                        /**
                         * Calls SetAgent.
                         * @function setAgent
                         * @memberof google.cloud.dialogflow.v2beta1.Agents
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.ISetAgentRequest} request SetAgentRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.Agent>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Agents|deleteAgent}.
                         * @memberof google.cloud.dialogflow.v2beta1.Agents
                         * @typedef DeleteAgentCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.protobuf.Empty} [response] Empty
                         */
    
                        /**
                         * Calls DeleteAgent.
                         * @function deleteAgent
                         * @memberof google.cloud.dialogflow.v2beta1.Agents
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteAgentRequest} request DeleteAgentRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Agents.DeleteAgentCallback} callback Node-style callback called with the error, if any, and Empty
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Agents.prototype.deleteAgent = function deleteAgent(request, callback) {
                            return this.rpcCall(deleteAgent, $root.google.cloud.dialogflow.v2beta1.DeleteAgentRequest, $root.google.protobuf.Empty, request, callback);
                        }, "name", { value: "DeleteAgent" });
    
                        /**
                         * Calls DeleteAgent.
                         * @function deleteAgent
                         * @memberof google.cloud.dialogflow.v2beta1.Agents
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteAgentRequest} request DeleteAgentRequest message or plain object
                         * @returns {Promise<google.protobuf.Empty>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Agents|searchAgents}.
                         * @memberof google.cloud.dialogflow.v2beta1.Agents
                         * @typedef SearchAgentsCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.SearchAgentsResponse} [response] SearchAgentsResponse
                         */
    
                        /**
                         * Calls SearchAgents.
                         * @function searchAgents
                         * @memberof google.cloud.dialogflow.v2beta1.Agents
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.ISearchAgentsRequest} request SearchAgentsRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Agents.SearchAgentsCallback} callback Node-style callback called with the error, if any, and SearchAgentsResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Agents.prototype.searchAgents = function searchAgents(request, callback) {
                            return this.rpcCall(searchAgents, $root.google.cloud.dialogflow.v2beta1.SearchAgentsRequest, $root.google.cloud.dialogflow.v2beta1.SearchAgentsResponse, request, callback);
                        }, "name", { value: "SearchAgents" });
    
                        /**
                         * Calls SearchAgents.
                         * @function searchAgents
                         * @memberof google.cloud.dialogflow.v2beta1.Agents
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.ISearchAgentsRequest} request SearchAgentsRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.SearchAgentsResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Agents|trainAgent}.
                         * @memberof google.cloud.dialogflow.v2beta1.Agents
                         * @typedef TrainAgentCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.longrunning.Operation} [response] Operation
                         */
    
                        /**
                         * Calls TrainAgent.
                         * @function trainAgent
                         * @memberof google.cloud.dialogflow.v2beta1.Agents
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.ITrainAgentRequest} request TrainAgentRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Agents.TrainAgentCallback} callback Node-style callback called with the error, if any, and Operation
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Agents.prototype.trainAgent = function trainAgent(request, callback) {
                            return this.rpcCall(trainAgent, $root.google.cloud.dialogflow.v2beta1.TrainAgentRequest, $root.google.longrunning.Operation, request, callback);
                        }, "name", { value: "TrainAgent" });
    
                        /**
                         * Calls TrainAgent.
                         * @function trainAgent
                         * @memberof google.cloud.dialogflow.v2beta1.Agents
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.ITrainAgentRequest} request TrainAgentRequest message or plain object
                         * @returns {Promise<google.longrunning.Operation>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Agents|exportAgent}.
                         * @memberof google.cloud.dialogflow.v2beta1.Agents
                         * @typedef ExportAgentCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.longrunning.Operation} [response] Operation
                         */
    
                        /**
                         * Calls ExportAgent.
                         * @function exportAgent
                         * @memberof google.cloud.dialogflow.v2beta1.Agents
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IExportAgentRequest} request ExportAgentRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Agents.ExportAgentCallback} callback Node-style callback called with the error, if any, and Operation
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Agents.prototype.exportAgent = function exportAgent(request, callback) {
                            return this.rpcCall(exportAgent, $root.google.cloud.dialogflow.v2beta1.ExportAgentRequest, $root.google.longrunning.Operation, request, callback);
                        }, "name", { value: "ExportAgent" });
    
                        /**
                         * Calls ExportAgent.
                         * @function exportAgent
                         * @memberof google.cloud.dialogflow.v2beta1.Agents
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IExportAgentRequest} request ExportAgentRequest message or plain object
                         * @returns {Promise<google.longrunning.Operation>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Agents|importAgent}.
                         * @memberof google.cloud.dialogflow.v2beta1.Agents
                         * @typedef ImportAgentCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.longrunning.Operation} [response] Operation
                         */
    
                        /**
                         * Calls ImportAgent.
                         * @function importAgent
                         * @memberof google.cloud.dialogflow.v2beta1.Agents
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IImportAgentRequest} request ImportAgentRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Agents.ImportAgentCallback} callback Node-style callback called with the error, if any, and Operation
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Agents.prototype.importAgent = function importAgent(request, callback) {
                            return this.rpcCall(importAgent, $root.google.cloud.dialogflow.v2beta1.ImportAgentRequest, $root.google.longrunning.Operation, request, callback);
                        }, "name", { value: "ImportAgent" });
    
                        /**
                         * Calls ImportAgent.
                         * @function importAgent
                         * @memberof google.cloud.dialogflow.v2beta1.Agents
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IImportAgentRequest} request ImportAgentRequest message or plain object
                         * @returns {Promise<google.longrunning.Operation>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Agents|restoreAgent}.
                         * @memberof google.cloud.dialogflow.v2beta1.Agents
                         * @typedef RestoreAgentCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.longrunning.Operation} [response] Operation
                         */
    
                        /**
                         * Calls RestoreAgent.
                         * @function restoreAgent
                         * @memberof google.cloud.dialogflow.v2beta1.Agents
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IRestoreAgentRequest} request RestoreAgentRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Agents.RestoreAgentCallback} callback Node-style callback called with the error, if any, and Operation
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Agents.prototype.restoreAgent = function restoreAgent(request, callback) {
                            return this.rpcCall(restoreAgent, $root.google.cloud.dialogflow.v2beta1.RestoreAgentRequest, $root.google.longrunning.Operation, request, callback);
                        }, "name", { value: "RestoreAgent" });
    
                        /**
                         * Calls RestoreAgent.
                         * @function restoreAgent
                         * @memberof google.cloud.dialogflow.v2beta1.Agents
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IRestoreAgentRequest} request RestoreAgentRequest message or plain object
                         * @returns {Promise<google.longrunning.Operation>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Agents|getValidationResult}.
                         * @memberof google.cloud.dialogflow.v2beta1.Agents
                         * @typedef GetValidationResultCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.ValidationResult} [response] ValidationResult
                         */
    
                        /**
                         * Calls GetValidationResult.
                         * @function getValidationResult
                         * @memberof google.cloud.dialogflow.v2beta1.Agents
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IGetValidationResultRequest} request GetValidationResultRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Agents.GetValidationResultCallback} callback Node-style callback called with the error, if any, and ValidationResult
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Agents.prototype.getValidationResult = function getValidationResult(request, callback) {
                            return this.rpcCall(getValidationResult, $root.google.cloud.dialogflow.v2beta1.GetValidationResultRequest, $root.google.cloud.dialogflow.v2beta1.ValidationResult, request, callback);
                        }, "name", { value: "GetValidationResult" });
    
                        /**
                         * Calls GetValidationResult.
                         * @function getValidationResult
                         * @memberof google.cloud.dialogflow.v2beta1.Agents
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IGetValidationResultRequest} request GetValidationResultRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.ValidationResult>} Promise
                         * @variation 2
                         */
    
                        return Agents;
                    })();
    
                    v2beta1.Agent = (function() {
    
                        /**
                         * Properties of an Agent.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IAgent
                         * @property {string|null} [parent] Agent parent
                         * @property {string|null} [displayName] Agent displayName
                         * @property {string|null} [defaultLanguageCode] Agent defaultLanguageCode
                         * @property {Array.<string>|null} [supportedLanguageCodes] Agent supportedLanguageCodes
                         * @property {string|null} [timeZone] Agent timeZone
                         * @property {string|null} [description] Agent description
                         * @property {string|null} [avatarUri] Agent avatarUri
                         * @property {boolean|null} [enableLogging] Agent enableLogging
                         * @property {google.cloud.dialogflow.v2beta1.Agent.MatchMode|null} [matchMode] Agent matchMode
                         * @property {number|null} [classificationThreshold] Agent classificationThreshold
                         * @property {google.cloud.dialogflow.v2beta1.Agent.ApiVersion|null} [apiVersion] Agent apiVersion
                         * @property {google.cloud.dialogflow.v2beta1.Agent.Tier|null} [tier] Agent tier
                         */
    
                        /**
                         * Constructs a new Agent.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an Agent.
                         * @implements IAgent
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IAgent=} [properties] Properties to set
                         */
                        function Agent(properties) {
                            this.supportedLanguageCodes = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * Agent parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.Agent
                         * @instance
                         */
                        Agent.prototype.parent = "";
    
                        /**
                         * Agent displayName.
                         * @member {string} displayName
                         * @memberof google.cloud.dialogflow.v2beta1.Agent
                         * @instance
                         */
                        Agent.prototype.displayName = "";
    
                        /**
                         * Agent defaultLanguageCode.
                         * @member {string} defaultLanguageCode
                         * @memberof google.cloud.dialogflow.v2beta1.Agent
                         * @instance
                         */
                        Agent.prototype.defaultLanguageCode = "";
    
                        /**
                         * Agent supportedLanguageCodes.
                         * @member {Array.<string>} supportedLanguageCodes
                         * @memberof google.cloud.dialogflow.v2beta1.Agent
                         * @instance
                         */
                        Agent.prototype.supportedLanguageCodes = $util.emptyArray;
    
                        /**
                         * Agent timeZone.
                         * @member {string} timeZone
                         * @memberof google.cloud.dialogflow.v2beta1.Agent
                         * @instance
                         */
                        Agent.prototype.timeZone = "";
    
                        /**
                         * Agent description.
                         * @member {string} description
                         * @memberof google.cloud.dialogflow.v2beta1.Agent
                         * @instance
                         */
                        Agent.prototype.description = "";
    
                        /**
                         * Agent avatarUri.
                         * @member {string} avatarUri
                         * @memberof google.cloud.dialogflow.v2beta1.Agent
                         * @instance
                         */
                        Agent.prototype.avatarUri = "";
    
                        /**
                         * Agent enableLogging.
                         * @member {boolean} enableLogging
                         * @memberof google.cloud.dialogflow.v2beta1.Agent
                         * @instance
                         */
                        Agent.prototype.enableLogging = false;
    
                        /**
                         * Agent matchMode.
                         * @member {google.cloud.dialogflow.v2beta1.Agent.MatchMode} matchMode
                         * @memberof google.cloud.dialogflow.v2beta1.Agent
                         * @instance
                         */
                        Agent.prototype.matchMode = 0;
    
                        /**
                         * Agent classificationThreshold.
                         * @member {number} classificationThreshold
                         * @memberof google.cloud.dialogflow.v2beta1.Agent
                         * @instance
                         */
                        Agent.prototype.classificationThreshold = 0;
    
                        /**
                         * Agent apiVersion.
                         * @member {google.cloud.dialogflow.v2beta1.Agent.ApiVersion} apiVersion
                         * @memberof google.cloud.dialogflow.v2beta1.Agent
                         * @instance
                         */
                        Agent.prototype.apiVersion = 0;
    
                        /**
                         * Agent tier.
                         * @member {google.cloud.dialogflow.v2beta1.Agent.Tier} tier
                         * @memberof google.cloud.dialogflow.v2beta1.Agent
                         * @instance
                         */
                        Agent.prototype.tier = 0;
    
                        /**
                         * Creates a new Agent instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.Agent
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IAgent=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.Agent} Agent instance
                         */
                        Agent.create = function create(properties) {
                            return new Agent(properties);
                        };
    
                        /**
                         * Encodes the specified Agent message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Agent.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.Agent
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IAgent} message Agent message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        Agent.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.displayName != null && Object.hasOwnProperty.call(message, "displayName"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.displayName);
                            if (message.defaultLanguageCode != null && Object.hasOwnProperty.call(message, "defaultLanguageCode"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.defaultLanguageCode);
                            if (message.supportedLanguageCodes != null && message.supportedLanguageCodes.length)
                                for (var i = 0; i < message.supportedLanguageCodes.length; ++i)
                                    writer.uint32(/* id 4, wireType 2 =*/34).string(message.supportedLanguageCodes[i]);
                            if (message.timeZone != null && Object.hasOwnProperty.call(message, "timeZone"))
                                writer.uint32(/* id 5, wireType 2 =*/42).string(message.timeZone);
                            if (message.description != null && Object.hasOwnProperty.call(message, "description"))
                                writer.uint32(/* id 6, wireType 2 =*/50).string(message.description);
                            if (message.avatarUri != null && Object.hasOwnProperty.call(message, "avatarUri"))
                                writer.uint32(/* id 7, wireType 2 =*/58).string(message.avatarUri);
                            if (message.enableLogging != null && Object.hasOwnProperty.call(message, "enableLogging"))
                                writer.uint32(/* id 8, wireType 0 =*/64).bool(message.enableLogging);
                            if (message.matchMode != null && Object.hasOwnProperty.call(message, "matchMode"))
                                writer.uint32(/* id 9, wireType 0 =*/72).int32(message.matchMode);
                            if (message.classificationThreshold != null && Object.hasOwnProperty.call(message, "classificationThreshold"))
                                writer.uint32(/* id 10, wireType 5 =*/85).float(message.classificationThreshold);
                            if (message.apiVersion != null && Object.hasOwnProperty.call(message, "apiVersion"))
                                writer.uint32(/* id 14, wireType 0 =*/112).int32(message.apiVersion);
                            if (message.tier != null && Object.hasOwnProperty.call(message, "tier"))
                                writer.uint32(/* id 15, wireType 0 =*/120).int32(message.tier);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified Agent message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Agent.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.Agent
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IAgent} message Agent message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        Agent.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an Agent message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.Agent
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.Agent} Agent
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        Agent.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Agent();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.displayName = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.defaultLanguageCode = reader.string();
                                        break;
                                    }
                                case 4: {
                                        if (!(message.supportedLanguageCodes && message.supportedLanguageCodes.length))
                                            message.supportedLanguageCodes = [];
                                        message.supportedLanguageCodes.push(reader.string());
                                        break;
                                    }
                                case 5: {
                                        message.timeZone = reader.string();
                                        break;
                                    }
                                case 6: {
                                        message.description = reader.string();
                                        break;
                                    }
                                case 7: {
                                        message.avatarUri = reader.string();
                                        break;
                                    }
                                case 8: {
                                        message.enableLogging = reader.bool();
                                        break;
                                    }
                                case 9: {
                                        message.matchMode = reader.int32();
                                        break;
                                    }
                                case 10: {
                                        message.classificationThreshold = reader.float();
                                        break;
                                    }
                                case 14: {
                                        message.apiVersion = reader.int32();
                                        break;
                                    }
                                case 15: {
                                        message.tier = reader.int32();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an Agent message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.Agent
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.Agent} Agent
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        Agent.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an Agent message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.Agent
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        Agent.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.displayName != null && message.hasOwnProperty("displayName"))
                                if (!$util.isString(message.displayName))
                                    return "displayName: string expected";
                            if (message.defaultLanguageCode != null && message.hasOwnProperty("defaultLanguageCode"))
                                if (!$util.isString(message.defaultLanguageCode))
                                    return "defaultLanguageCode: string expected";
                            if (message.supportedLanguageCodes != null && message.hasOwnProperty("supportedLanguageCodes")) {
                                if (!Array.isArray(message.supportedLanguageCodes))
                                    return "supportedLanguageCodes: array expected";
                                for (var i = 0; i < message.supportedLanguageCodes.length; ++i)
                                    if (!$util.isString(message.supportedLanguageCodes[i]))
                                        return "supportedLanguageCodes: string[] expected";
                            }
                            if (message.timeZone != null && message.hasOwnProperty("timeZone"))
                                if (!$util.isString(message.timeZone))
                                    return "timeZone: string expected";
                            if (message.description != null && message.hasOwnProperty("description"))
                                if (!$util.isString(message.description))
                                    return "description: string expected";
                            if (message.avatarUri != null && message.hasOwnProperty("avatarUri"))
                                if (!$util.isString(message.avatarUri))
                                    return "avatarUri: string expected";
                            if (message.enableLogging != null && message.hasOwnProperty("enableLogging"))
                                if (typeof message.enableLogging !== "boolean")
                                    return "enableLogging: boolean expected";
                            if (message.matchMode != null && message.hasOwnProperty("matchMode"))
                                switch (message.matchMode) {
                                default:
                                    return "matchMode: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                    break;
                                }
                            if (message.classificationThreshold != null && message.hasOwnProperty("classificationThreshold"))
                                if (typeof message.classificationThreshold !== "number")
                                    return "classificationThreshold: number expected";
                            if (message.apiVersion != null && message.hasOwnProperty("apiVersion"))
                                switch (message.apiVersion) {
                                default:
                                    return "apiVersion: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                    break;
                                }
                            if (message.tier != null && message.hasOwnProperty("tier"))
                                switch (message.tier) {
                                default:
                                    return "tier: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                    break;
                                }
                            return null;
                        };
    
                        /**
                         * Creates an Agent message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.Agent
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.Agent} Agent
                         */
                        Agent.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.Agent)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.Agent();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.displayName != null)
                                message.displayName = String(object.displayName);
                            if (object.defaultLanguageCode != null)
                                message.defaultLanguageCode = String(object.defaultLanguageCode);
                            if (object.supportedLanguageCodes) {
                                if (!Array.isArray(object.supportedLanguageCodes))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.Agent.supportedLanguageCodes: array expected");
                                message.supportedLanguageCodes = [];
                                for (var i = 0; i < object.supportedLanguageCodes.length; ++i)
                                    message.supportedLanguageCodes[i] = String(object.supportedLanguageCodes[i]);
                            }
                            if (object.timeZone != null)
                                message.timeZone = String(object.timeZone);
                            if (object.description != null)
                                message.description = String(object.description);
                            if (object.avatarUri != null)
                                message.avatarUri = String(object.avatarUri);
                            if (object.enableLogging != null)
                                message.enableLogging = Boolean(object.enableLogging);
                            switch (object.matchMode) {
                            default:
                                if (typeof object.matchMode === "number") {
                                    message.matchMode = object.matchMode;
                                    break;
                                }
                                break;
                            case "MATCH_MODE_UNSPECIFIED":
                            case 0:
                                message.matchMode = 0;
                                break;
                            case "MATCH_MODE_HYBRID":
                            case 1:
                                message.matchMode = 1;
                                break;
                            case "MATCH_MODE_ML_ONLY":
                            case 2:
                                message.matchMode = 2;
                                break;
                            }
                            if (object.classificationThreshold != null)
                                message.classificationThreshold = Number(object.classificationThreshold);
                            switch (object.apiVersion) {
                            default:
                                if (typeof object.apiVersion === "number") {
                                    message.apiVersion = object.apiVersion;
                                    break;
                                }
                                break;
                            case "API_VERSION_UNSPECIFIED":
                            case 0:
                                message.apiVersion = 0;
                                break;
                            case "API_VERSION_V1":
                            case 1:
                                message.apiVersion = 1;
                                break;
                            case "API_VERSION_V2":
                            case 2:
                                message.apiVersion = 2;
                                break;
                            case "API_VERSION_V2_BETA_1":
                            case 3:
                                message.apiVersion = 3;
                                break;
                            }
                            switch (object.tier) {
                            default:
                                if (typeof object.tier === "number") {
                                    message.tier = object.tier;
                                    break;
                                }
                                break;
                            case "TIER_UNSPECIFIED":
                            case 0:
                                message.tier = 0;
                                break;
                            case "TIER_STANDARD":
                            case 1:
                                message.tier = 1;
                                break;
                            case "TIER_ENTERPRISE":
                            case 2:
                                message.tier = 2;
                                break;
                            case "TIER_ENTERPRISE_PLUS":
                            case 3:
                                message.tier = 3;
                                break;
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an Agent message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.Agent
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.Agent} message Agent
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        Agent.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.supportedLanguageCodes = [];
                            if (options.defaults) {
                                object.parent = "";
                                object.displayName = "";
                                object.defaultLanguageCode = "";
                                object.timeZone = "";
                                object.description = "";
                                object.avatarUri = "";
                                object.enableLogging = false;
                                object.matchMode = options.enums === String ? "MATCH_MODE_UNSPECIFIED" : 0;
                                object.classificationThreshold = 0;
                                object.apiVersion = options.enums === String ? "API_VERSION_UNSPECIFIED" : 0;
                                object.tier = options.enums === String ? "TIER_UNSPECIFIED" : 0;
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.displayName != null && message.hasOwnProperty("displayName"))
                                object.displayName = message.displayName;
                            if (message.defaultLanguageCode != null && message.hasOwnProperty("defaultLanguageCode"))
                                object.defaultLanguageCode = message.defaultLanguageCode;
                            if (message.supportedLanguageCodes && message.supportedLanguageCodes.length) {
                                object.supportedLanguageCodes = [];
                                for (var j = 0; j < message.supportedLanguageCodes.length; ++j)
                                    object.supportedLanguageCodes[j] = message.supportedLanguageCodes[j];
                            }
                            if (message.timeZone != null && message.hasOwnProperty("timeZone"))
                                object.timeZone = message.timeZone;
                            if (message.description != null && message.hasOwnProperty("description"))
                                object.description = message.description;
                            if (message.avatarUri != null && message.hasOwnProperty("avatarUri"))
                                object.avatarUri = message.avatarUri;
                            if (message.enableLogging != null && message.hasOwnProperty("enableLogging"))
                                object.enableLogging = message.enableLogging;
                            if (message.matchMode != null && message.hasOwnProperty("matchMode"))
                                object.matchMode = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.Agent.MatchMode[message.matchMode] === undefined ? message.matchMode : $root.google.cloud.dialogflow.v2beta1.Agent.MatchMode[message.matchMode] : message.matchMode;
                            if (message.classificationThreshold != null && message.hasOwnProperty("classificationThreshold"))
                                object.classificationThreshold = options.json && !isFinite(message.classificationThreshold) ? String(message.classificationThreshold) : message.classificationThreshold;
                            if (message.apiVersion != null && message.hasOwnProperty("apiVersion"))
                                object.apiVersion = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.Agent.ApiVersion[message.apiVersion] === undefined ? message.apiVersion : $root.google.cloud.dialogflow.v2beta1.Agent.ApiVersion[message.apiVersion] : message.apiVersion;
                            if (message.tier != null && message.hasOwnProperty("tier"))
                                object.tier = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.Agent.Tier[message.tier] === undefined ? message.tier : $root.google.cloud.dialogflow.v2beta1.Agent.Tier[message.tier] : message.tier;
                            return object;
                        };
    
                        /**
                         * Converts this Agent to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.Agent
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        Agent.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for Agent
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.Agent
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        Agent.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Agent";
                        };
    
                        /**
                         * MatchMode enum.
                         * @name google.cloud.dialogflow.v2beta1.Agent.MatchMode
                         * @enum {number}
                         * @property {number} MATCH_MODE_UNSPECIFIED=0 MATCH_MODE_UNSPECIFIED value
                         * @property {number} MATCH_MODE_HYBRID=1 MATCH_MODE_HYBRID value
                         * @property {number} MATCH_MODE_ML_ONLY=2 MATCH_MODE_ML_ONLY value
                         */
                        Agent.MatchMode = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "MATCH_MODE_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "MATCH_MODE_HYBRID"] = 1;
                            values[valuesById[2] = "MATCH_MODE_ML_ONLY"] = 2;
                            return values;
                        })();
    
                        /**
                         * ApiVersion enum.
                         * @name google.cloud.dialogflow.v2beta1.Agent.ApiVersion
                         * @enum {number}
                         * @property {number} API_VERSION_UNSPECIFIED=0 API_VERSION_UNSPECIFIED value
                         * @property {number} API_VERSION_V1=1 API_VERSION_V1 value
                         * @property {number} API_VERSION_V2=2 API_VERSION_V2 value
                         * @property {number} API_VERSION_V2_BETA_1=3 API_VERSION_V2_BETA_1 value
                         */
                        Agent.ApiVersion = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "API_VERSION_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "API_VERSION_V1"] = 1;
                            values[valuesById[2] = "API_VERSION_V2"] = 2;
                            values[valuesById[3] = "API_VERSION_V2_BETA_1"] = 3;
                            return values;
                        })();
    
                        /**
                         * Tier enum.
                         * @name google.cloud.dialogflow.v2beta1.Agent.Tier
                         * @enum {number}
                         * @property {number} TIER_UNSPECIFIED=0 TIER_UNSPECIFIED value
                         * @property {number} TIER_STANDARD=1 TIER_STANDARD value
                         * @property {number} TIER_ENTERPRISE=2 TIER_ENTERPRISE value
                         * @property {number} TIER_ENTERPRISE_PLUS=3 TIER_ENTERPRISE_PLUS value
                         */
                        Agent.Tier = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "TIER_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "TIER_STANDARD"] = 1;
                            values[valuesById[2] = "TIER_ENTERPRISE"] = 2;
                            values[valuesById[3] = "TIER_ENTERPRISE_PLUS"] = 3;
                            return values;
                        })();
    
                        return Agent;
                    })();
    
                    v2beta1.GetAgentRequest = (function() {
    
                        /**
                         * Properties of a GetAgentRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IGetAgentRequest
                         * @property {string|null} [parent] GetAgentRequest parent
                         */
    
                        /**
                         * Constructs a new GetAgentRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a GetAgentRequest.
                         * @implements IGetAgentRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IGetAgentRequest=} [properties] Properties to set
                         */
                        function GetAgentRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GetAgentRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.GetAgentRequest
                         * @instance
                         */
                        GetAgentRequest.prototype.parent = "";
    
                        /**
                         * Creates a new GetAgentRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.GetAgentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetAgentRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.GetAgentRequest} GetAgentRequest instance
                         */
                        GetAgentRequest.create = function create(properties) {
                            return new GetAgentRequest(properties);
                        };
    
                        /**
                         * Encodes the specified GetAgentRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GetAgentRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.GetAgentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetAgentRequest} message GetAgentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetAgentRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GetAgentRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GetAgentRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GetAgentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetAgentRequest} message GetAgentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetAgentRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GetAgentRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.GetAgentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.GetAgentRequest} GetAgentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetAgentRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.GetAgentRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GetAgentRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GetAgentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.GetAgentRequest} GetAgentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetAgentRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GetAgentRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.GetAgentRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GetAgentRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a GetAgentRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.GetAgentRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.GetAgentRequest} GetAgentRequest
                         */
                        GetAgentRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.GetAgentRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.GetAgentRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GetAgentRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.GetAgentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.GetAgentRequest} message GetAgentRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GetAgentRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.parent = "";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            return object;
                        };
    
                        /**
                         * Converts this GetAgentRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.GetAgentRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GetAgentRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GetAgentRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.GetAgentRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GetAgentRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.GetAgentRequest";
                        };
    
                        return GetAgentRequest;
                    })();
    
                    v2beta1.SetAgentRequest = (function() {
    
                        /**
                         * Properties of a SetAgentRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ISetAgentRequest
                         * @property {google.cloud.dialogflow.v2beta1.IAgent|null} [agent] SetAgentRequest agent
                         * @property {google.protobuf.IFieldMask|null} [updateMask] SetAgentRequest updateMask
                         */
    
                        /**
                         * Constructs a new SetAgentRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a SetAgentRequest.
                         * @implements ISetAgentRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ISetAgentRequest=} [properties] Properties to set
                         */
                        function SetAgentRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SetAgentRequest agent.
                         * @member {google.cloud.dialogflow.v2beta1.IAgent|null|undefined} agent
                         * @memberof google.cloud.dialogflow.v2beta1.SetAgentRequest
                         * @instance
                         */
                        SetAgentRequest.prototype.agent = null;
    
                        /**
                         * SetAgentRequest updateMask.
                         * @member {google.protobuf.IFieldMask|null|undefined} updateMask
                         * @memberof google.cloud.dialogflow.v2beta1.SetAgentRequest
                         * @instance
                         */
                        SetAgentRequest.prototype.updateMask = null;
    
                        /**
                         * Creates a new SetAgentRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.SetAgentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISetAgentRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.SetAgentRequest} SetAgentRequest instance
                         */
                        SetAgentRequest.create = function create(properties) {
                            return new SetAgentRequest(properties);
                        };
    
                        /**
                         * Encodes the specified SetAgentRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SetAgentRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.SetAgentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISetAgentRequest} message SetAgentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SetAgentRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.agent != null && Object.hasOwnProperty.call(message, "agent"))
                                $root.google.cloud.dialogflow.v2beta1.Agent.encode(message.agent, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.updateMask != null && Object.hasOwnProperty.call(message, "updateMask"))
                                $root.google.protobuf.FieldMask.encode(message.updateMask, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SetAgentRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SetAgentRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SetAgentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISetAgentRequest} message SetAgentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SetAgentRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SetAgentRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.SetAgentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.SetAgentRequest} SetAgentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SetAgentRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.SetAgentRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.agent = $root.google.cloud.dialogflow.v2beta1.Agent.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.updateMask = $root.google.protobuf.FieldMask.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SetAgentRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SetAgentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.SetAgentRequest} SetAgentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SetAgentRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SetAgentRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.SetAgentRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SetAgentRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.agent != null && message.hasOwnProperty("agent")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.Agent.verify(message.agent);
                                if (error)
                                    return "agent." + error;
                            }
                            if (message.updateMask != null && message.hasOwnProperty("updateMask")) {
                                var error = $root.google.protobuf.FieldMask.verify(message.updateMask);
                                if (error)
                                    return "updateMask." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a SetAgentRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.SetAgentRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.SetAgentRequest} SetAgentRequest
                         */
                        SetAgentRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.SetAgentRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.SetAgentRequest();
                            if (object.agent != null) {
                                if (typeof object.agent !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.SetAgentRequest.agent: object expected");
                                message.agent = $root.google.cloud.dialogflow.v2beta1.Agent.fromObject(object.agent);
                            }
                            if (object.updateMask != null) {
                                if (typeof object.updateMask !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.SetAgentRequest.updateMask: object expected");
                                message.updateMask = $root.google.protobuf.FieldMask.fromObject(object.updateMask);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SetAgentRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.SetAgentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.SetAgentRequest} message SetAgentRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SetAgentRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.agent = null;
                                object.updateMask = null;
                            }
                            if (message.agent != null && message.hasOwnProperty("agent"))
                                object.agent = $root.google.cloud.dialogflow.v2beta1.Agent.toObject(message.agent, options);
                            if (message.updateMask != null && message.hasOwnProperty("updateMask"))
                                object.updateMask = $root.google.protobuf.FieldMask.toObject(message.updateMask, options);
                            return object;
                        };
    
                        /**
                         * Converts this SetAgentRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.SetAgentRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SetAgentRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SetAgentRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.SetAgentRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SetAgentRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.SetAgentRequest";
                        };
    
                        return SetAgentRequest;
                    })();
    
                    v2beta1.DeleteAgentRequest = (function() {
    
                        /**
                         * Properties of a DeleteAgentRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IDeleteAgentRequest
                         * @property {string|null} [parent] DeleteAgentRequest parent
                         */
    
                        /**
                         * Constructs a new DeleteAgentRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a DeleteAgentRequest.
                         * @implements IDeleteAgentRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteAgentRequest=} [properties] Properties to set
                         */
                        function DeleteAgentRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * DeleteAgentRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteAgentRequest
                         * @instance
                         */
                        DeleteAgentRequest.prototype.parent = "";
    
                        /**
                         * Creates a new DeleteAgentRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteAgentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteAgentRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.DeleteAgentRequest} DeleteAgentRequest instance
                         */
                        DeleteAgentRequest.create = function create(properties) {
                            return new DeleteAgentRequest(properties);
                        };
    
                        /**
                         * Encodes the specified DeleteAgentRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.DeleteAgentRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteAgentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteAgentRequest} message DeleteAgentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteAgentRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified DeleteAgentRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.DeleteAgentRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteAgentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteAgentRequest} message DeleteAgentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteAgentRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a DeleteAgentRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteAgentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.DeleteAgentRequest} DeleteAgentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteAgentRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.DeleteAgentRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a DeleteAgentRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteAgentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.DeleteAgentRequest} DeleteAgentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteAgentRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a DeleteAgentRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteAgentRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        DeleteAgentRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a DeleteAgentRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteAgentRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.DeleteAgentRequest} DeleteAgentRequest
                         */
                        DeleteAgentRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.DeleteAgentRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.DeleteAgentRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a DeleteAgentRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteAgentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.DeleteAgentRequest} message DeleteAgentRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        DeleteAgentRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.parent = "";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            return object;
                        };
    
                        /**
                         * Converts this DeleteAgentRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteAgentRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        DeleteAgentRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for DeleteAgentRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteAgentRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        DeleteAgentRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.DeleteAgentRequest";
                        };
    
                        return DeleteAgentRequest;
                    })();
    
                    v2beta1.SubAgent = (function() {
    
                        /**
                         * Properties of a SubAgent.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ISubAgent
                         * @property {string|null} [project] SubAgent project
                         * @property {string|null} [environment] SubAgent environment
                         */
    
                        /**
                         * Constructs a new SubAgent.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a SubAgent.
                         * @implements ISubAgent
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ISubAgent=} [properties] Properties to set
                         */
                        function SubAgent(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SubAgent project.
                         * @member {string} project
                         * @memberof google.cloud.dialogflow.v2beta1.SubAgent
                         * @instance
                         */
                        SubAgent.prototype.project = "";
    
                        /**
                         * SubAgent environment.
                         * @member {string} environment
                         * @memberof google.cloud.dialogflow.v2beta1.SubAgent
                         * @instance
                         */
                        SubAgent.prototype.environment = "";
    
                        /**
                         * Creates a new SubAgent instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.SubAgent
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISubAgent=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.SubAgent} SubAgent instance
                         */
                        SubAgent.create = function create(properties) {
                            return new SubAgent(properties);
                        };
    
                        /**
                         * Encodes the specified SubAgent message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SubAgent.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.SubAgent
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISubAgent} message SubAgent message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SubAgent.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.project != null && Object.hasOwnProperty.call(message, "project"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.project);
                            if (message.environment != null && Object.hasOwnProperty.call(message, "environment"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.environment);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SubAgent message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SubAgent.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SubAgent
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISubAgent} message SubAgent message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SubAgent.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SubAgent message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.SubAgent
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.SubAgent} SubAgent
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SubAgent.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.SubAgent();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.project = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.environment = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SubAgent message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SubAgent
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.SubAgent} SubAgent
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SubAgent.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SubAgent message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.SubAgent
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SubAgent.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.project != null && message.hasOwnProperty("project"))
                                if (!$util.isString(message.project))
                                    return "project: string expected";
                            if (message.environment != null && message.hasOwnProperty("environment"))
                                if (!$util.isString(message.environment))
                                    return "environment: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a SubAgent message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.SubAgent
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.SubAgent} SubAgent
                         */
                        SubAgent.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.SubAgent)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.SubAgent();
                            if (object.project != null)
                                message.project = String(object.project);
                            if (object.environment != null)
                                message.environment = String(object.environment);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SubAgent message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.SubAgent
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.SubAgent} message SubAgent
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SubAgent.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.project = "";
                                object.environment = "";
                            }
                            if (message.project != null && message.hasOwnProperty("project"))
                                object.project = message.project;
                            if (message.environment != null && message.hasOwnProperty("environment"))
                                object.environment = message.environment;
                            return object;
                        };
    
                        /**
                         * Converts this SubAgent to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.SubAgent
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SubAgent.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SubAgent
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.SubAgent
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SubAgent.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.SubAgent";
                        };
    
                        return SubAgent;
                    })();
    
                    v2beta1.SearchAgentsRequest = (function() {
    
                        /**
                         * Properties of a SearchAgentsRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ISearchAgentsRequest
                         * @property {string|null} [parent] SearchAgentsRequest parent
                         * @property {number|null} [pageSize] SearchAgentsRequest pageSize
                         * @property {string|null} [pageToken] SearchAgentsRequest pageToken
                         */
    
                        /**
                         * Constructs a new SearchAgentsRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a SearchAgentsRequest.
                         * @implements ISearchAgentsRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ISearchAgentsRequest=} [properties] Properties to set
                         */
                        function SearchAgentsRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SearchAgentsRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.SearchAgentsRequest
                         * @instance
                         */
                        SearchAgentsRequest.prototype.parent = "";
    
                        /**
                         * SearchAgentsRequest pageSize.
                         * @member {number} pageSize
                         * @memberof google.cloud.dialogflow.v2beta1.SearchAgentsRequest
                         * @instance
                         */
                        SearchAgentsRequest.prototype.pageSize = 0;
    
                        /**
                         * SearchAgentsRequest pageToken.
                         * @member {string} pageToken
                         * @memberof google.cloud.dialogflow.v2beta1.SearchAgentsRequest
                         * @instance
                         */
                        SearchAgentsRequest.prototype.pageToken = "";
    
                        /**
                         * Creates a new SearchAgentsRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.SearchAgentsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISearchAgentsRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.SearchAgentsRequest} SearchAgentsRequest instance
                         */
                        SearchAgentsRequest.create = function create(properties) {
                            return new SearchAgentsRequest(properties);
                        };
    
                        /**
                         * Encodes the specified SearchAgentsRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SearchAgentsRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.SearchAgentsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISearchAgentsRequest} message SearchAgentsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SearchAgentsRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.pageSize != null && Object.hasOwnProperty.call(message, "pageSize"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.pageSize);
                            if (message.pageToken != null && Object.hasOwnProperty.call(message, "pageToken"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.pageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SearchAgentsRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SearchAgentsRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SearchAgentsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISearchAgentsRequest} message SearchAgentsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SearchAgentsRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SearchAgentsRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.SearchAgentsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.SearchAgentsRequest} SearchAgentsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SearchAgentsRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.SearchAgentsRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.pageSize = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.pageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SearchAgentsRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SearchAgentsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.SearchAgentsRequest} SearchAgentsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SearchAgentsRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SearchAgentsRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.SearchAgentsRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SearchAgentsRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                if (!$util.isInteger(message.pageSize))
                                    return "pageSize: integer expected";
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                if (!$util.isString(message.pageToken))
                                    return "pageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a SearchAgentsRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.SearchAgentsRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.SearchAgentsRequest} SearchAgentsRequest
                         */
                        SearchAgentsRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.SearchAgentsRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.SearchAgentsRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.pageSize != null)
                                message.pageSize = object.pageSize | 0;
                            if (object.pageToken != null)
                                message.pageToken = String(object.pageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SearchAgentsRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.SearchAgentsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.SearchAgentsRequest} message SearchAgentsRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SearchAgentsRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.pageSize = 0;
                                object.pageToken = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                object.pageSize = message.pageSize;
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                object.pageToken = message.pageToken;
                            return object;
                        };
    
                        /**
                         * Converts this SearchAgentsRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.SearchAgentsRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SearchAgentsRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SearchAgentsRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.SearchAgentsRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SearchAgentsRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.SearchAgentsRequest";
                        };
    
                        return SearchAgentsRequest;
                    })();
    
                    v2beta1.SearchAgentsResponse = (function() {
    
                        /**
                         * Properties of a SearchAgentsResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ISearchAgentsResponse
                         * @property {Array.<google.cloud.dialogflow.v2beta1.IAgent>|null} [agents] SearchAgentsResponse agents
                         * @property {string|null} [nextPageToken] SearchAgentsResponse nextPageToken
                         */
    
                        /**
                         * Constructs a new SearchAgentsResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a SearchAgentsResponse.
                         * @implements ISearchAgentsResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ISearchAgentsResponse=} [properties] Properties to set
                         */
                        function SearchAgentsResponse(properties) {
                            this.agents = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SearchAgentsResponse agents.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.IAgent>} agents
                         * @memberof google.cloud.dialogflow.v2beta1.SearchAgentsResponse
                         * @instance
                         */
                        SearchAgentsResponse.prototype.agents = $util.emptyArray;
    
                        /**
                         * SearchAgentsResponse nextPageToken.
                         * @member {string} nextPageToken
                         * @memberof google.cloud.dialogflow.v2beta1.SearchAgentsResponse
                         * @instance
                         */
                        SearchAgentsResponse.prototype.nextPageToken = "";
    
                        /**
                         * Creates a new SearchAgentsResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.SearchAgentsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISearchAgentsResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.SearchAgentsResponse} SearchAgentsResponse instance
                         */
                        SearchAgentsResponse.create = function create(properties) {
                            return new SearchAgentsResponse(properties);
                        };
    
                        /**
                         * Encodes the specified SearchAgentsResponse message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SearchAgentsResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.SearchAgentsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISearchAgentsResponse} message SearchAgentsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SearchAgentsResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.agents != null && message.agents.length)
                                for (var i = 0; i < message.agents.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.Agent.encode(message.agents[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.nextPageToken != null && Object.hasOwnProperty.call(message, "nextPageToken"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.nextPageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SearchAgentsResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SearchAgentsResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SearchAgentsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISearchAgentsResponse} message SearchAgentsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SearchAgentsResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SearchAgentsResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.SearchAgentsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.SearchAgentsResponse} SearchAgentsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SearchAgentsResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.SearchAgentsResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.agents && message.agents.length))
                                            message.agents = [];
                                        message.agents.push($root.google.cloud.dialogflow.v2beta1.Agent.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 2: {
                                        message.nextPageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SearchAgentsResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SearchAgentsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.SearchAgentsResponse} SearchAgentsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SearchAgentsResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SearchAgentsResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.SearchAgentsResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SearchAgentsResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.agents != null && message.hasOwnProperty("agents")) {
                                if (!Array.isArray(message.agents))
                                    return "agents: array expected";
                                for (var i = 0; i < message.agents.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.Agent.verify(message.agents[i]);
                                    if (error)
                                        return "agents." + error;
                                }
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                if (!$util.isString(message.nextPageToken))
                                    return "nextPageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a SearchAgentsResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.SearchAgentsResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.SearchAgentsResponse} SearchAgentsResponse
                         */
                        SearchAgentsResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.SearchAgentsResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.SearchAgentsResponse();
                            if (object.agents) {
                                if (!Array.isArray(object.agents))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.SearchAgentsResponse.agents: array expected");
                                message.agents = [];
                                for (var i = 0; i < object.agents.length; ++i) {
                                    if (typeof object.agents[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.SearchAgentsResponse.agents: object expected");
                                    message.agents[i] = $root.google.cloud.dialogflow.v2beta1.Agent.fromObject(object.agents[i]);
                                }
                            }
                            if (object.nextPageToken != null)
                                message.nextPageToken = String(object.nextPageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SearchAgentsResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.SearchAgentsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.SearchAgentsResponse} message SearchAgentsResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SearchAgentsResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.agents = [];
                            if (options.defaults)
                                object.nextPageToken = "";
                            if (message.agents && message.agents.length) {
                                object.agents = [];
                                for (var j = 0; j < message.agents.length; ++j)
                                    object.agents[j] = $root.google.cloud.dialogflow.v2beta1.Agent.toObject(message.agents[j], options);
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                object.nextPageToken = message.nextPageToken;
                            return object;
                        };
    
                        /**
                         * Converts this SearchAgentsResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.SearchAgentsResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SearchAgentsResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SearchAgentsResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.SearchAgentsResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SearchAgentsResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.SearchAgentsResponse";
                        };
    
                        return SearchAgentsResponse;
                    })();
    
                    v2beta1.TrainAgentRequest = (function() {
    
                        /**
                         * Properties of a TrainAgentRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ITrainAgentRequest
                         * @property {string|null} [parent] TrainAgentRequest parent
                         */
    
                        /**
                         * Constructs a new TrainAgentRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a TrainAgentRequest.
                         * @implements ITrainAgentRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ITrainAgentRequest=} [properties] Properties to set
                         */
                        function TrainAgentRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * TrainAgentRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.TrainAgentRequest
                         * @instance
                         */
                        TrainAgentRequest.prototype.parent = "";
    
                        /**
                         * Creates a new TrainAgentRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.TrainAgentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ITrainAgentRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.TrainAgentRequest} TrainAgentRequest instance
                         */
                        TrainAgentRequest.create = function create(properties) {
                            return new TrainAgentRequest(properties);
                        };
    
                        /**
                         * Encodes the specified TrainAgentRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.TrainAgentRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.TrainAgentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ITrainAgentRequest} message TrainAgentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        TrainAgentRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified TrainAgentRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.TrainAgentRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.TrainAgentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ITrainAgentRequest} message TrainAgentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        TrainAgentRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a TrainAgentRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.TrainAgentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.TrainAgentRequest} TrainAgentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        TrainAgentRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.TrainAgentRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a TrainAgentRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.TrainAgentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.TrainAgentRequest} TrainAgentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        TrainAgentRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a TrainAgentRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.TrainAgentRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        TrainAgentRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a TrainAgentRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.TrainAgentRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.TrainAgentRequest} TrainAgentRequest
                         */
                        TrainAgentRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.TrainAgentRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.TrainAgentRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a TrainAgentRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.TrainAgentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.TrainAgentRequest} message TrainAgentRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        TrainAgentRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.parent = "";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            return object;
                        };
    
                        /**
                         * Converts this TrainAgentRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.TrainAgentRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        TrainAgentRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for TrainAgentRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.TrainAgentRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        TrainAgentRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.TrainAgentRequest";
                        };
    
                        return TrainAgentRequest;
                    })();
    
                    v2beta1.ExportAgentRequest = (function() {
    
                        /**
                         * Properties of an ExportAgentRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IExportAgentRequest
                         * @property {string|null} [parent] ExportAgentRequest parent
                         * @property {string|null} [agentUri] ExportAgentRequest agentUri
                         */
    
                        /**
                         * Constructs a new ExportAgentRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an ExportAgentRequest.
                         * @implements IExportAgentRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IExportAgentRequest=} [properties] Properties to set
                         */
                        function ExportAgentRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ExportAgentRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.ExportAgentRequest
                         * @instance
                         */
                        ExportAgentRequest.prototype.parent = "";
    
                        /**
                         * ExportAgentRequest agentUri.
                         * @member {string} agentUri
                         * @memberof google.cloud.dialogflow.v2beta1.ExportAgentRequest
                         * @instance
                         */
                        ExportAgentRequest.prototype.agentUri = "";
    
                        /**
                         * Creates a new ExportAgentRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.ExportAgentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IExportAgentRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.ExportAgentRequest} ExportAgentRequest instance
                         */
                        ExportAgentRequest.create = function create(properties) {
                            return new ExportAgentRequest(properties);
                        };
    
                        /**
                         * Encodes the specified ExportAgentRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ExportAgentRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.ExportAgentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IExportAgentRequest} message ExportAgentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ExportAgentRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.agentUri != null && Object.hasOwnProperty.call(message, "agentUri"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.agentUri);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ExportAgentRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ExportAgentRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ExportAgentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IExportAgentRequest} message ExportAgentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ExportAgentRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an ExportAgentRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.ExportAgentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.ExportAgentRequest} ExportAgentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ExportAgentRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ExportAgentRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.agentUri = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an ExportAgentRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ExportAgentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.ExportAgentRequest} ExportAgentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ExportAgentRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an ExportAgentRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.ExportAgentRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ExportAgentRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.agentUri != null && message.hasOwnProperty("agentUri"))
                                if (!$util.isString(message.agentUri))
                                    return "agentUri: string expected";
                            return null;
                        };
    
                        /**
                         * Creates an ExportAgentRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.ExportAgentRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.ExportAgentRequest} ExportAgentRequest
                         */
                        ExportAgentRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.ExportAgentRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.ExportAgentRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.agentUri != null)
                                message.agentUri = String(object.agentUri);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an ExportAgentRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.ExportAgentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ExportAgentRequest} message ExportAgentRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ExportAgentRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.agentUri = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.agentUri != null && message.hasOwnProperty("agentUri"))
                                object.agentUri = message.agentUri;
                            return object;
                        };
    
                        /**
                         * Converts this ExportAgentRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.ExportAgentRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ExportAgentRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ExportAgentRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.ExportAgentRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ExportAgentRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ExportAgentRequest";
                        };
    
                        return ExportAgentRequest;
                    })();
    
                    v2beta1.ExportAgentResponse = (function() {
    
                        /**
                         * Properties of an ExportAgentResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IExportAgentResponse
                         * @property {string|null} [agentUri] ExportAgentResponse agentUri
                         * @property {Uint8Array|null} [agentContent] ExportAgentResponse agentContent
                         */
    
                        /**
                         * Constructs a new ExportAgentResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an ExportAgentResponse.
                         * @implements IExportAgentResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IExportAgentResponse=} [properties] Properties to set
                         */
                        function ExportAgentResponse(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ExportAgentResponse agentUri.
                         * @member {string|null|undefined} agentUri
                         * @memberof google.cloud.dialogflow.v2beta1.ExportAgentResponse
                         * @instance
                         */
                        ExportAgentResponse.prototype.agentUri = null;
    
                        /**
                         * ExportAgentResponse agentContent.
                         * @member {Uint8Array|null|undefined} agentContent
                         * @memberof google.cloud.dialogflow.v2beta1.ExportAgentResponse
                         * @instance
                         */
                        ExportAgentResponse.prototype.agentContent = null;
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * ExportAgentResponse agent.
                         * @member {"agentUri"|"agentContent"|undefined} agent
                         * @memberof google.cloud.dialogflow.v2beta1.ExportAgentResponse
                         * @instance
                         */
                        Object.defineProperty(ExportAgentResponse.prototype, "agent", {
                            get: $util.oneOfGetter($oneOfFields = ["agentUri", "agentContent"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new ExportAgentResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.ExportAgentResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IExportAgentResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.ExportAgentResponse} ExportAgentResponse instance
                         */
                        ExportAgentResponse.create = function create(properties) {
                            return new ExportAgentResponse(properties);
                        };
    
                        /**
                         * Encodes the specified ExportAgentResponse message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ExportAgentResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.ExportAgentResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IExportAgentResponse} message ExportAgentResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ExportAgentResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.agentUri != null && Object.hasOwnProperty.call(message, "agentUri"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.agentUri);
                            if (message.agentContent != null && Object.hasOwnProperty.call(message, "agentContent"))
                                writer.uint32(/* id 2, wireType 2 =*/18).bytes(message.agentContent);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ExportAgentResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ExportAgentResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ExportAgentResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IExportAgentResponse} message ExportAgentResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ExportAgentResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an ExportAgentResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.ExportAgentResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.ExportAgentResponse} ExportAgentResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ExportAgentResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ExportAgentResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.agentUri = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.agentContent = reader.bytes();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an ExportAgentResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ExportAgentResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.ExportAgentResponse} ExportAgentResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ExportAgentResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an ExportAgentResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.ExportAgentResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ExportAgentResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.agentUri != null && message.hasOwnProperty("agentUri")) {
                                properties.agent = 1;
                                if (!$util.isString(message.agentUri))
                                    return "agentUri: string expected";
                            }
                            if (message.agentContent != null && message.hasOwnProperty("agentContent")) {
                                if (properties.agent === 1)
                                    return "agent: multiple values";
                                properties.agent = 1;
                                if (!(message.agentContent && typeof message.agentContent.length === "number" || $util.isString(message.agentContent)))
                                    return "agentContent: buffer expected";
                            }
                            return null;
                        };
    
                        /**
                         * Creates an ExportAgentResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.ExportAgentResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.ExportAgentResponse} ExportAgentResponse
                         */
                        ExportAgentResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.ExportAgentResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.ExportAgentResponse();
                            if (object.agentUri != null)
                                message.agentUri = String(object.agentUri);
                            if (object.agentContent != null)
                                if (typeof object.agentContent === "string")
                                    $util.base64.decode(object.agentContent, message.agentContent = $util.newBuffer($util.base64.length(object.agentContent)), 0);
                                else if (object.agentContent.length >= 0)
                                    message.agentContent = object.agentContent;
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an ExportAgentResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.ExportAgentResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ExportAgentResponse} message ExportAgentResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ExportAgentResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (message.agentUri != null && message.hasOwnProperty("agentUri")) {
                                object.agentUri = message.agentUri;
                                if (options.oneofs)
                                    object.agent = "agentUri";
                            }
                            if (message.agentContent != null && message.hasOwnProperty("agentContent")) {
                                object.agentContent = options.bytes === String ? $util.base64.encode(message.agentContent, 0, message.agentContent.length) : options.bytes === Array ? Array.prototype.slice.call(message.agentContent) : message.agentContent;
                                if (options.oneofs)
                                    object.agent = "agentContent";
                            }
                            return object;
                        };
    
                        /**
                         * Converts this ExportAgentResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.ExportAgentResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ExportAgentResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ExportAgentResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.ExportAgentResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ExportAgentResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ExportAgentResponse";
                        };
    
                        return ExportAgentResponse;
                    })();
    
                    v2beta1.ImportAgentRequest = (function() {
    
                        /**
                         * Properties of an ImportAgentRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IImportAgentRequest
                         * @property {string|null} [parent] ImportAgentRequest parent
                         * @property {string|null} [agentUri] ImportAgentRequest agentUri
                         * @property {Uint8Array|null} [agentContent] ImportAgentRequest agentContent
                         */
    
                        /**
                         * Constructs a new ImportAgentRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an ImportAgentRequest.
                         * @implements IImportAgentRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IImportAgentRequest=} [properties] Properties to set
                         */
                        function ImportAgentRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ImportAgentRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.ImportAgentRequest
                         * @instance
                         */
                        ImportAgentRequest.prototype.parent = "";
    
                        /**
                         * ImportAgentRequest agentUri.
                         * @member {string|null|undefined} agentUri
                         * @memberof google.cloud.dialogflow.v2beta1.ImportAgentRequest
                         * @instance
                         */
                        ImportAgentRequest.prototype.agentUri = null;
    
                        /**
                         * ImportAgentRequest agentContent.
                         * @member {Uint8Array|null|undefined} agentContent
                         * @memberof google.cloud.dialogflow.v2beta1.ImportAgentRequest
                         * @instance
                         */
                        ImportAgentRequest.prototype.agentContent = null;
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * ImportAgentRequest agent.
                         * @member {"agentUri"|"agentContent"|undefined} agent
                         * @memberof google.cloud.dialogflow.v2beta1.ImportAgentRequest
                         * @instance
                         */
                        Object.defineProperty(ImportAgentRequest.prototype, "agent", {
                            get: $util.oneOfGetter($oneOfFields = ["agentUri", "agentContent"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new ImportAgentRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.ImportAgentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IImportAgentRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.ImportAgentRequest} ImportAgentRequest instance
                         */
                        ImportAgentRequest.create = function create(properties) {
                            return new ImportAgentRequest(properties);
                        };
    
                        /**
                         * Encodes the specified ImportAgentRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ImportAgentRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.ImportAgentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IImportAgentRequest} message ImportAgentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ImportAgentRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.agentUri != null && Object.hasOwnProperty.call(message, "agentUri"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.agentUri);
                            if (message.agentContent != null && Object.hasOwnProperty.call(message, "agentContent"))
                                writer.uint32(/* id 3, wireType 2 =*/26).bytes(message.agentContent);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ImportAgentRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ImportAgentRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ImportAgentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IImportAgentRequest} message ImportAgentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ImportAgentRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an ImportAgentRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.ImportAgentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.ImportAgentRequest} ImportAgentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ImportAgentRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ImportAgentRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.agentUri = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.agentContent = reader.bytes();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an ImportAgentRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ImportAgentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.ImportAgentRequest} ImportAgentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ImportAgentRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an ImportAgentRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.ImportAgentRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ImportAgentRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.agentUri != null && message.hasOwnProperty("agentUri")) {
                                properties.agent = 1;
                                if (!$util.isString(message.agentUri))
                                    return "agentUri: string expected";
                            }
                            if (message.agentContent != null && message.hasOwnProperty("agentContent")) {
                                if (properties.agent === 1)
                                    return "agent: multiple values";
                                properties.agent = 1;
                                if (!(message.agentContent && typeof message.agentContent.length === "number" || $util.isString(message.agentContent)))
                                    return "agentContent: buffer expected";
                            }
                            return null;
                        };
    
                        /**
                         * Creates an ImportAgentRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.ImportAgentRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.ImportAgentRequest} ImportAgentRequest
                         */
                        ImportAgentRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.ImportAgentRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.ImportAgentRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.agentUri != null)
                                message.agentUri = String(object.agentUri);
                            if (object.agentContent != null)
                                if (typeof object.agentContent === "string")
                                    $util.base64.decode(object.agentContent, message.agentContent = $util.newBuffer($util.base64.length(object.agentContent)), 0);
                                else if (object.agentContent.length >= 0)
                                    message.agentContent = object.agentContent;
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an ImportAgentRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.ImportAgentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ImportAgentRequest} message ImportAgentRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ImportAgentRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.parent = "";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.agentUri != null && message.hasOwnProperty("agentUri")) {
                                object.agentUri = message.agentUri;
                                if (options.oneofs)
                                    object.agent = "agentUri";
                            }
                            if (message.agentContent != null && message.hasOwnProperty("agentContent")) {
                                object.agentContent = options.bytes === String ? $util.base64.encode(message.agentContent, 0, message.agentContent.length) : options.bytes === Array ? Array.prototype.slice.call(message.agentContent) : message.agentContent;
                                if (options.oneofs)
                                    object.agent = "agentContent";
                            }
                            return object;
                        };
    
                        /**
                         * Converts this ImportAgentRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.ImportAgentRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ImportAgentRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ImportAgentRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.ImportAgentRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ImportAgentRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ImportAgentRequest";
                        };
    
                        return ImportAgentRequest;
                    })();
    
                    v2beta1.RestoreAgentRequest = (function() {
    
                        /**
                         * Properties of a RestoreAgentRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IRestoreAgentRequest
                         * @property {string|null} [parent] RestoreAgentRequest parent
                         * @property {string|null} [agentUri] RestoreAgentRequest agentUri
                         * @property {Uint8Array|null} [agentContent] RestoreAgentRequest agentContent
                         */
    
                        /**
                         * Constructs a new RestoreAgentRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a RestoreAgentRequest.
                         * @implements IRestoreAgentRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IRestoreAgentRequest=} [properties] Properties to set
                         */
                        function RestoreAgentRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * RestoreAgentRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.RestoreAgentRequest
                         * @instance
                         */
                        RestoreAgentRequest.prototype.parent = "";
    
                        /**
                         * RestoreAgentRequest agentUri.
                         * @member {string|null|undefined} agentUri
                         * @memberof google.cloud.dialogflow.v2beta1.RestoreAgentRequest
                         * @instance
                         */
                        RestoreAgentRequest.prototype.agentUri = null;
    
                        /**
                         * RestoreAgentRequest agentContent.
                         * @member {Uint8Array|null|undefined} agentContent
                         * @memberof google.cloud.dialogflow.v2beta1.RestoreAgentRequest
                         * @instance
                         */
                        RestoreAgentRequest.prototype.agentContent = null;
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * RestoreAgentRequest agent.
                         * @member {"agentUri"|"agentContent"|undefined} agent
                         * @memberof google.cloud.dialogflow.v2beta1.RestoreAgentRequest
                         * @instance
                         */
                        Object.defineProperty(RestoreAgentRequest.prototype, "agent", {
                            get: $util.oneOfGetter($oneOfFields = ["agentUri", "agentContent"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new RestoreAgentRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.RestoreAgentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IRestoreAgentRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.RestoreAgentRequest} RestoreAgentRequest instance
                         */
                        RestoreAgentRequest.create = function create(properties) {
                            return new RestoreAgentRequest(properties);
                        };
    
                        /**
                         * Encodes the specified RestoreAgentRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.RestoreAgentRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.RestoreAgentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IRestoreAgentRequest} message RestoreAgentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        RestoreAgentRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.agentUri != null && Object.hasOwnProperty.call(message, "agentUri"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.agentUri);
                            if (message.agentContent != null && Object.hasOwnProperty.call(message, "agentContent"))
                                writer.uint32(/* id 3, wireType 2 =*/26).bytes(message.agentContent);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified RestoreAgentRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.RestoreAgentRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.RestoreAgentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IRestoreAgentRequest} message RestoreAgentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        RestoreAgentRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a RestoreAgentRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.RestoreAgentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.RestoreAgentRequest} RestoreAgentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        RestoreAgentRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.RestoreAgentRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.agentUri = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.agentContent = reader.bytes();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a RestoreAgentRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.RestoreAgentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.RestoreAgentRequest} RestoreAgentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        RestoreAgentRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a RestoreAgentRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.RestoreAgentRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        RestoreAgentRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.agentUri != null && message.hasOwnProperty("agentUri")) {
                                properties.agent = 1;
                                if (!$util.isString(message.agentUri))
                                    return "agentUri: string expected";
                            }
                            if (message.agentContent != null && message.hasOwnProperty("agentContent")) {
                                if (properties.agent === 1)
                                    return "agent: multiple values";
                                properties.agent = 1;
                                if (!(message.agentContent && typeof message.agentContent.length === "number" || $util.isString(message.agentContent)))
                                    return "agentContent: buffer expected";
                            }
                            return null;
                        };
    
                        /**
                         * Creates a RestoreAgentRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.RestoreAgentRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.RestoreAgentRequest} RestoreAgentRequest
                         */
                        RestoreAgentRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.RestoreAgentRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.RestoreAgentRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.agentUri != null)
                                message.agentUri = String(object.agentUri);
                            if (object.agentContent != null)
                                if (typeof object.agentContent === "string")
                                    $util.base64.decode(object.agentContent, message.agentContent = $util.newBuffer($util.base64.length(object.agentContent)), 0);
                                else if (object.agentContent.length >= 0)
                                    message.agentContent = object.agentContent;
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a RestoreAgentRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.RestoreAgentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.RestoreAgentRequest} message RestoreAgentRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        RestoreAgentRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.parent = "";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.agentUri != null && message.hasOwnProperty("agentUri")) {
                                object.agentUri = message.agentUri;
                                if (options.oneofs)
                                    object.agent = "agentUri";
                            }
                            if (message.agentContent != null && message.hasOwnProperty("agentContent")) {
                                object.agentContent = options.bytes === String ? $util.base64.encode(message.agentContent, 0, message.agentContent.length) : options.bytes === Array ? Array.prototype.slice.call(message.agentContent) : message.agentContent;
                                if (options.oneofs)
                                    object.agent = "agentContent";
                            }
                            return object;
                        };
    
                        /**
                         * Converts this RestoreAgentRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.RestoreAgentRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        RestoreAgentRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for RestoreAgentRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.RestoreAgentRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        RestoreAgentRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.RestoreAgentRequest";
                        };
    
                        return RestoreAgentRequest;
                    })();
    
                    v2beta1.GetValidationResultRequest = (function() {
    
                        /**
                         * Properties of a GetValidationResultRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IGetValidationResultRequest
                         * @property {string|null} [parent] GetValidationResultRequest parent
                         * @property {string|null} [languageCode] GetValidationResultRequest languageCode
                         */
    
                        /**
                         * Constructs a new GetValidationResultRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a GetValidationResultRequest.
                         * @implements IGetValidationResultRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IGetValidationResultRequest=} [properties] Properties to set
                         */
                        function GetValidationResultRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GetValidationResultRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.GetValidationResultRequest
                         * @instance
                         */
                        GetValidationResultRequest.prototype.parent = "";
    
                        /**
                         * GetValidationResultRequest languageCode.
                         * @member {string} languageCode
                         * @memberof google.cloud.dialogflow.v2beta1.GetValidationResultRequest
                         * @instance
                         */
                        GetValidationResultRequest.prototype.languageCode = "";
    
                        /**
                         * Creates a new GetValidationResultRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.GetValidationResultRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetValidationResultRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.GetValidationResultRequest} GetValidationResultRequest instance
                         */
                        GetValidationResultRequest.create = function create(properties) {
                            return new GetValidationResultRequest(properties);
                        };
    
                        /**
                         * Encodes the specified GetValidationResultRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GetValidationResultRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.GetValidationResultRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetValidationResultRequest} message GetValidationResultRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetValidationResultRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.languageCode != null && Object.hasOwnProperty.call(message, "languageCode"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.languageCode);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GetValidationResultRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GetValidationResultRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GetValidationResultRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetValidationResultRequest} message GetValidationResultRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetValidationResultRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GetValidationResultRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.GetValidationResultRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.GetValidationResultRequest} GetValidationResultRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetValidationResultRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.GetValidationResultRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.languageCode = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GetValidationResultRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GetValidationResultRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.GetValidationResultRequest} GetValidationResultRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetValidationResultRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GetValidationResultRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.GetValidationResultRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GetValidationResultRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                if (!$util.isString(message.languageCode))
                                    return "languageCode: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a GetValidationResultRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.GetValidationResultRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.GetValidationResultRequest} GetValidationResultRequest
                         */
                        GetValidationResultRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.GetValidationResultRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.GetValidationResultRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.languageCode != null)
                                message.languageCode = String(object.languageCode);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GetValidationResultRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.GetValidationResultRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.GetValidationResultRequest} message GetValidationResultRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GetValidationResultRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.languageCode = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                object.languageCode = message.languageCode;
                            return object;
                        };
    
                        /**
                         * Converts this GetValidationResultRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.GetValidationResultRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GetValidationResultRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GetValidationResultRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.GetValidationResultRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GetValidationResultRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.GetValidationResultRequest";
                        };
    
                        return GetValidationResultRequest;
                    })();
    
                    v2beta1.ValidationError = (function() {
    
                        /**
                         * Properties of a ValidationError.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IValidationError
                         * @property {google.cloud.dialogflow.v2beta1.ValidationError.Severity|null} [severity] ValidationError severity
                         * @property {Array.<string>|null} [entries] ValidationError entries
                         * @property {string|null} [errorMessage] ValidationError errorMessage
                         */
    
                        /**
                         * Constructs a new ValidationError.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a ValidationError.
                         * @implements IValidationError
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IValidationError=} [properties] Properties to set
                         */
                        function ValidationError(properties) {
                            this.entries = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ValidationError severity.
                         * @member {google.cloud.dialogflow.v2beta1.ValidationError.Severity} severity
                         * @memberof google.cloud.dialogflow.v2beta1.ValidationError
                         * @instance
                         */
                        ValidationError.prototype.severity = 0;
    
                        /**
                         * ValidationError entries.
                         * @member {Array.<string>} entries
                         * @memberof google.cloud.dialogflow.v2beta1.ValidationError
                         * @instance
                         */
                        ValidationError.prototype.entries = $util.emptyArray;
    
                        /**
                         * ValidationError errorMessage.
                         * @member {string} errorMessage
                         * @memberof google.cloud.dialogflow.v2beta1.ValidationError
                         * @instance
                         */
                        ValidationError.prototype.errorMessage = "";
    
                        /**
                         * Creates a new ValidationError instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.ValidationError
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IValidationError=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.ValidationError} ValidationError instance
                         */
                        ValidationError.create = function create(properties) {
                            return new ValidationError(properties);
                        };
    
                        /**
                         * Encodes the specified ValidationError message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ValidationError.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.ValidationError
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IValidationError} message ValidationError message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ValidationError.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.severity != null && Object.hasOwnProperty.call(message, "severity"))
                                writer.uint32(/* id 1, wireType 0 =*/8).int32(message.severity);
                            if (message.entries != null && message.entries.length)
                                for (var i = 0; i < message.entries.length; ++i)
                                    writer.uint32(/* id 3, wireType 2 =*/26).string(message.entries[i]);
                            if (message.errorMessage != null && Object.hasOwnProperty.call(message, "errorMessage"))
                                writer.uint32(/* id 4, wireType 2 =*/34).string(message.errorMessage);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ValidationError message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ValidationError.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ValidationError
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IValidationError} message ValidationError message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ValidationError.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ValidationError message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.ValidationError
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.ValidationError} ValidationError
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ValidationError.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ValidationError();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.severity = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        if (!(message.entries && message.entries.length))
                                            message.entries = [];
                                        message.entries.push(reader.string());
                                        break;
                                    }
                                case 4: {
                                        message.errorMessage = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ValidationError message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ValidationError
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.ValidationError} ValidationError
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ValidationError.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ValidationError message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.ValidationError
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ValidationError.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.severity != null && message.hasOwnProperty("severity"))
                                switch (message.severity) {
                                default:
                                    return "severity: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                case 4:
                                    break;
                                }
                            if (message.entries != null && message.hasOwnProperty("entries")) {
                                if (!Array.isArray(message.entries))
                                    return "entries: array expected";
                                for (var i = 0; i < message.entries.length; ++i)
                                    if (!$util.isString(message.entries[i]))
                                        return "entries: string[] expected";
                            }
                            if (message.errorMessage != null && message.hasOwnProperty("errorMessage"))
                                if (!$util.isString(message.errorMessage))
                                    return "errorMessage: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ValidationError message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.ValidationError
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.ValidationError} ValidationError
                         */
                        ValidationError.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.ValidationError)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.ValidationError();
                            switch (object.severity) {
                            default:
                                if (typeof object.severity === "number") {
                                    message.severity = object.severity;
                                    break;
                                }
                                break;
                            case "SEVERITY_UNSPECIFIED":
                            case 0:
                                message.severity = 0;
                                break;
                            case "INFO":
                            case 1:
                                message.severity = 1;
                                break;
                            case "WARNING":
                            case 2:
                                message.severity = 2;
                                break;
                            case "ERROR":
                            case 3:
                                message.severity = 3;
                                break;
                            case "CRITICAL":
                            case 4:
                                message.severity = 4;
                                break;
                            }
                            if (object.entries) {
                                if (!Array.isArray(object.entries))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.ValidationError.entries: array expected");
                                message.entries = [];
                                for (var i = 0; i < object.entries.length; ++i)
                                    message.entries[i] = String(object.entries[i]);
                            }
                            if (object.errorMessage != null)
                                message.errorMessage = String(object.errorMessage);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ValidationError message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.ValidationError
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ValidationError} message ValidationError
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ValidationError.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.entries = [];
                            if (options.defaults) {
                                object.severity = options.enums === String ? "SEVERITY_UNSPECIFIED" : 0;
                                object.errorMessage = "";
                            }
                            if (message.severity != null && message.hasOwnProperty("severity"))
                                object.severity = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.ValidationError.Severity[message.severity] === undefined ? message.severity : $root.google.cloud.dialogflow.v2beta1.ValidationError.Severity[message.severity] : message.severity;
                            if (message.entries && message.entries.length) {
                                object.entries = [];
                                for (var j = 0; j < message.entries.length; ++j)
                                    object.entries[j] = message.entries[j];
                            }
                            if (message.errorMessage != null && message.hasOwnProperty("errorMessage"))
                                object.errorMessage = message.errorMessage;
                            return object;
                        };
    
                        /**
                         * Converts this ValidationError to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.ValidationError
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ValidationError.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ValidationError
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.ValidationError
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ValidationError.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ValidationError";
                        };
    
                        /**
                         * Severity enum.
                         * @name google.cloud.dialogflow.v2beta1.ValidationError.Severity
                         * @enum {number}
                         * @property {number} SEVERITY_UNSPECIFIED=0 SEVERITY_UNSPECIFIED value
                         * @property {number} INFO=1 INFO value
                         * @property {number} WARNING=2 WARNING value
                         * @property {number} ERROR=3 ERROR value
                         * @property {number} CRITICAL=4 CRITICAL value
                         */
                        ValidationError.Severity = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "SEVERITY_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "INFO"] = 1;
                            values[valuesById[2] = "WARNING"] = 2;
                            values[valuesById[3] = "ERROR"] = 3;
                            values[valuesById[4] = "CRITICAL"] = 4;
                            return values;
                        })();
    
                        return ValidationError;
                    })();
    
                    v2beta1.ValidationResult = (function() {
    
                        /**
                         * Properties of a ValidationResult.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IValidationResult
                         * @property {Array.<google.cloud.dialogflow.v2beta1.IValidationError>|null} [validationErrors] ValidationResult validationErrors
                         */
    
                        /**
                         * Constructs a new ValidationResult.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a ValidationResult.
                         * @implements IValidationResult
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IValidationResult=} [properties] Properties to set
                         */
                        function ValidationResult(properties) {
                            this.validationErrors = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ValidationResult validationErrors.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.IValidationError>} validationErrors
                         * @memberof google.cloud.dialogflow.v2beta1.ValidationResult
                         * @instance
                         */
                        ValidationResult.prototype.validationErrors = $util.emptyArray;
    
                        /**
                         * Creates a new ValidationResult instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.ValidationResult
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IValidationResult=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.ValidationResult} ValidationResult instance
                         */
                        ValidationResult.create = function create(properties) {
                            return new ValidationResult(properties);
                        };
    
                        /**
                         * Encodes the specified ValidationResult message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ValidationResult.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.ValidationResult
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IValidationResult} message ValidationResult message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ValidationResult.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.validationErrors != null && message.validationErrors.length)
                                for (var i = 0; i < message.validationErrors.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.ValidationError.encode(message.validationErrors[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ValidationResult message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ValidationResult.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ValidationResult
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IValidationResult} message ValidationResult message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ValidationResult.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ValidationResult message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.ValidationResult
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.ValidationResult} ValidationResult
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ValidationResult.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ValidationResult();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.validationErrors && message.validationErrors.length))
                                            message.validationErrors = [];
                                        message.validationErrors.push($root.google.cloud.dialogflow.v2beta1.ValidationError.decode(reader, reader.uint32()));
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ValidationResult message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ValidationResult
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.ValidationResult} ValidationResult
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ValidationResult.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ValidationResult message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.ValidationResult
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ValidationResult.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.validationErrors != null && message.hasOwnProperty("validationErrors")) {
                                if (!Array.isArray(message.validationErrors))
                                    return "validationErrors: array expected";
                                for (var i = 0; i < message.validationErrors.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.ValidationError.verify(message.validationErrors[i]);
                                    if (error)
                                        return "validationErrors." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates a ValidationResult message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.ValidationResult
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.ValidationResult} ValidationResult
                         */
                        ValidationResult.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.ValidationResult)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.ValidationResult();
                            if (object.validationErrors) {
                                if (!Array.isArray(object.validationErrors))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.ValidationResult.validationErrors: array expected");
                                message.validationErrors = [];
                                for (var i = 0; i < object.validationErrors.length; ++i) {
                                    if (typeof object.validationErrors[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.ValidationResult.validationErrors: object expected");
                                    message.validationErrors[i] = $root.google.cloud.dialogflow.v2beta1.ValidationError.fromObject(object.validationErrors[i]);
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ValidationResult message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.ValidationResult
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ValidationResult} message ValidationResult
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ValidationResult.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.validationErrors = [];
                            if (message.validationErrors && message.validationErrors.length) {
                                object.validationErrors = [];
                                for (var j = 0; j < message.validationErrors.length; ++j)
                                    object.validationErrors[j] = $root.google.cloud.dialogflow.v2beta1.ValidationError.toObject(message.validationErrors[j], options);
                            }
                            return object;
                        };
    
                        /**
                         * Converts this ValidationResult to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.ValidationResult
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ValidationResult.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ValidationResult
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.ValidationResult
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ValidationResult.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ValidationResult";
                        };
    
                        return ValidationResult;
                    })();
    
                    v2beta1.AnswerRecords = (function() {
    
                        /**
                         * Constructs a new AnswerRecords service.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an AnswerRecords
                         * @extends $protobuf.rpc.Service
                         * @constructor
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         */
                        function AnswerRecords(rpcImpl, requestDelimited, responseDelimited) {
                            $protobuf.rpc.Service.call(this, rpcImpl, requestDelimited, responseDelimited);
                        }
    
                        (AnswerRecords.prototype = Object.create($protobuf.rpc.Service.prototype)).constructor = AnswerRecords;
    
                        /**
                         * Creates new AnswerRecords service using the specified rpc implementation.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.AnswerRecords
                         * @static
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         * @returns {AnswerRecords} RPC service. Useful where requests and/or responses are streamed.
                         */
                        AnswerRecords.create = function create(rpcImpl, requestDelimited, responseDelimited) {
                            return new this(rpcImpl, requestDelimited, responseDelimited);
                        };
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.AnswerRecords|getAnswerRecord}.
                         * @memberof google.cloud.dialogflow.v2beta1.AnswerRecords
                         * @typedef GetAnswerRecordCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.AnswerRecord} [response] AnswerRecord
                         */
    
                        /**
                         * Calls GetAnswerRecord.
                         * @function getAnswerRecord
                         * @memberof google.cloud.dialogflow.v2beta1.AnswerRecords
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IGetAnswerRecordRequest} request GetAnswerRecordRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.AnswerRecords.GetAnswerRecordCallback} callback Node-style callback called with the error, if any, and AnswerRecord
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(AnswerRecords.prototype.getAnswerRecord = function getAnswerRecord(request, callback) {
                            return this.rpcCall(getAnswerRecord, $root.google.cloud.dialogflow.v2beta1.GetAnswerRecordRequest, $root.google.cloud.dialogflow.v2beta1.AnswerRecord, request, callback);
                        }, "name", { value: "GetAnswerRecord" });
    
                        /**
                         * Calls GetAnswerRecord.
                         * @function getAnswerRecord
                         * @memberof google.cloud.dialogflow.v2beta1.AnswerRecords
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IGetAnswerRecordRequest} request GetAnswerRecordRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.AnswerRecord>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.AnswerRecords|listAnswerRecords}.
                         * @memberof google.cloud.dialogflow.v2beta1.AnswerRecords
                         * @typedef ListAnswerRecordsCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.ListAnswerRecordsResponse} [response] ListAnswerRecordsResponse
                         */
    
                        /**
                         * Calls ListAnswerRecords.
                         * @function listAnswerRecords
                         * @memberof google.cloud.dialogflow.v2beta1.AnswerRecords
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IListAnswerRecordsRequest} request ListAnswerRecordsRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.AnswerRecords.ListAnswerRecordsCallback} callback Node-style callback called with the error, if any, and ListAnswerRecordsResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(AnswerRecords.prototype.listAnswerRecords = function listAnswerRecords(request, callback) {
                            return this.rpcCall(listAnswerRecords, $root.google.cloud.dialogflow.v2beta1.ListAnswerRecordsRequest, $root.google.cloud.dialogflow.v2beta1.ListAnswerRecordsResponse, request, callback);
                        }, "name", { value: "ListAnswerRecords" });
    
                        /**
                         * Calls ListAnswerRecords.
                         * @function listAnswerRecords
                         * @memberof google.cloud.dialogflow.v2beta1.AnswerRecords
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IListAnswerRecordsRequest} request ListAnswerRecordsRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.ListAnswerRecordsResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.AnswerRecords|updateAnswerRecord}.
                         * @memberof google.cloud.dialogflow.v2beta1.AnswerRecords
                         * @typedef UpdateAnswerRecordCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.AnswerRecord} [response] AnswerRecord
                         */
    
                        /**
                         * Calls UpdateAnswerRecord.
                         * @function updateAnswerRecord
                         * @memberof google.cloud.dialogflow.v2beta1.AnswerRecords
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateAnswerRecordRequest} request UpdateAnswerRecordRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.AnswerRecords.UpdateAnswerRecordCallback} callback Node-style callback called with the error, if any, and AnswerRecord
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(AnswerRecords.prototype.updateAnswerRecord = function updateAnswerRecord(request, callback) {
                            return this.rpcCall(updateAnswerRecord, $root.google.cloud.dialogflow.v2beta1.UpdateAnswerRecordRequest, $root.google.cloud.dialogflow.v2beta1.AnswerRecord, request, callback);
                        }, "name", { value: "UpdateAnswerRecord" });
    
                        /**
                         * Calls UpdateAnswerRecord.
                         * @function updateAnswerRecord
                         * @memberof google.cloud.dialogflow.v2beta1.AnswerRecords
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateAnswerRecordRequest} request UpdateAnswerRecordRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.AnswerRecord>} Promise
                         * @variation 2
                         */
    
                        return AnswerRecords;
                    })();
    
                    v2beta1.AnswerRecord = (function() {
    
                        /**
                         * Properties of an AnswerRecord.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IAnswerRecord
                         * @property {string|null} [name] AnswerRecord name
                         * @property {google.cloud.dialogflow.v2beta1.IAnswerFeedback|null} [answerFeedback] AnswerRecord answerFeedback
                         * @property {google.cloud.dialogflow.v2beta1.IAgentAssistantRecord|null} [agentAssistantRecord] AnswerRecord agentAssistantRecord
                         */
    
                        /**
                         * Constructs a new AnswerRecord.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an AnswerRecord.
                         * @implements IAnswerRecord
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IAnswerRecord=} [properties] Properties to set
                         */
                        function AnswerRecord(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * AnswerRecord name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2beta1.AnswerRecord
                         * @instance
                         */
                        AnswerRecord.prototype.name = "";
    
                        /**
                         * AnswerRecord answerFeedback.
                         * @member {google.cloud.dialogflow.v2beta1.IAnswerFeedback|null|undefined} answerFeedback
                         * @memberof google.cloud.dialogflow.v2beta1.AnswerRecord
                         * @instance
                         */
                        AnswerRecord.prototype.answerFeedback = null;
    
                        /**
                         * AnswerRecord agentAssistantRecord.
                         * @member {google.cloud.dialogflow.v2beta1.IAgentAssistantRecord|null|undefined} agentAssistantRecord
                         * @memberof google.cloud.dialogflow.v2beta1.AnswerRecord
                         * @instance
                         */
                        AnswerRecord.prototype.agentAssistantRecord = null;
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * AnswerRecord record.
                         * @member {"agentAssistantRecord"|undefined} record
                         * @memberof google.cloud.dialogflow.v2beta1.AnswerRecord
                         * @instance
                         */
                        Object.defineProperty(AnswerRecord.prototype, "record", {
                            get: $util.oneOfGetter($oneOfFields = ["agentAssistantRecord"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new AnswerRecord instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.AnswerRecord
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IAnswerRecord=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.AnswerRecord} AnswerRecord instance
                         */
                        AnswerRecord.create = function create(properties) {
                            return new AnswerRecord(properties);
                        };
    
                        /**
                         * Encodes the specified AnswerRecord message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.AnswerRecord.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.AnswerRecord
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IAnswerRecord} message AnswerRecord message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        AnswerRecord.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            if (message.answerFeedback != null && Object.hasOwnProperty.call(message, "answerFeedback"))
                                $root.google.cloud.dialogflow.v2beta1.AnswerFeedback.encode(message.answerFeedback, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            if (message.agentAssistantRecord != null && Object.hasOwnProperty.call(message, "agentAssistantRecord"))
                                $root.google.cloud.dialogflow.v2beta1.AgentAssistantRecord.encode(message.agentAssistantRecord, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified AnswerRecord message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.AnswerRecord.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.AnswerRecord
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IAnswerRecord} message AnswerRecord message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        AnswerRecord.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an AnswerRecord message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.AnswerRecord
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.AnswerRecord} AnswerRecord
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        AnswerRecord.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.AnswerRecord();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.answerFeedback = $root.google.cloud.dialogflow.v2beta1.AnswerFeedback.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 4: {
                                        message.agentAssistantRecord = $root.google.cloud.dialogflow.v2beta1.AgentAssistantRecord.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an AnswerRecord message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.AnswerRecord
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.AnswerRecord} AnswerRecord
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        AnswerRecord.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an AnswerRecord message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.AnswerRecord
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        AnswerRecord.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            if (message.answerFeedback != null && message.hasOwnProperty("answerFeedback")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.AnswerFeedback.verify(message.answerFeedback);
                                if (error)
                                    return "answerFeedback." + error;
                            }
                            if (message.agentAssistantRecord != null && message.hasOwnProperty("agentAssistantRecord")) {
                                properties.record = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2beta1.AgentAssistantRecord.verify(message.agentAssistantRecord);
                                    if (error)
                                        return "agentAssistantRecord." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates an AnswerRecord message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.AnswerRecord
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.AnswerRecord} AnswerRecord
                         */
                        AnswerRecord.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.AnswerRecord)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.AnswerRecord();
                            if (object.name != null)
                                message.name = String(object.name);
                            if (object.answerFeedback != null) {
                                if (typeof object.answerFeedback !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.AnswerRecord.answerFeedback: object expected");
                                message.answerFeedback = $root.google.cloud.dialogflow.v2beta1.AnswerFeedback.fromObject(object.answerFeedback);
                            }
                            if (object.agentAssistantRecord != null) {
                                if (typeof object.agentAssistantRecord !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.AnswerRecord.agentAssistantRecord: object expected");
                                message.agentAssistantRecord = $root.google.cloud.dialogflow.v2beta1.AgentAssistantRecord.fromObject(object.agentAssistantRecord);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an AnswerRecord message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.AnswerRecord
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.AnswerRecord} message AnswerRecord
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        AnswerRecord.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.name = "";
                                object.answerFeedback = null;
                            }
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            if (message.answerFeedback != null && message.hasOwnProperty("answerFeedback"))
                                object.answerFeedback = $root.google.cloud.dialogflow.v2beta1.AnswerFeedback.toObject(message.answerFeedback, options);
                            if (message.agentAssistantRecord != null && message.hasOwnProperty("agentAssistantRecord")) {
                                object.agentAssistantRecord = $root.google.cloud.dialogflow.v2beta1.AgentAssistantRecord.toObject(message.agentAssistantRecord, options);
                                if (options.oneofs)
                                    object.record = "agentAssistantRecord";
                            }
                            return object;
                        };
    
                        /**
                         * Converts this AnswerRecord to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.AnswerRecord
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        AnswerRecord.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for AnswerRecord
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.AnswerRecord
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        AnswerRecord.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.AnswerRecord";
                        };
    
                        return AnswerRecord;
                    })();
    
                    v2beta1.AgentAssistantRecord = (function() {
    
                        /**
                         * Properties of an AgentAssistantRecord.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IAgentAssistantRecord
                         * @property {google.cloud.dialogflow.v2beta1.IArticleAnswer|null} [articleSuggestionAnswer] AgentAssistantRecord articleSuggestionAnswer
                         * @property {google.cloud.dialogflow.v2beta1.IFaqAnswer|null} [faqAnswer] AgentAssistantRecord faqAnswer
                         * @property {google.cloud.dialogflow.v2beta1.IDialogflowAssistAnswer|null} [dialogflowAssistAnswer] AgentAssistantRecord dialogflowAssistAnswer
                         */
    
                        /**
                         * Constructs a new AgentAssistantRecord.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an AgentAssistantRecord.
                         * @implements IAgentAssistantRecord
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IAgentAssistantRecord=} [properties] Properties to set
                         */
                        function AgentAssistantRecord(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * AgentAssistantRecord articleSuggestionAnswer.
                         * @member {google.cloud.dialogflow.v2beta1.IArticleAnswer|null|undefined} articleSuggestionAnswer
                         * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantRecord
                         * @instance
                         */
                        AgentAssistantRecord.prototype.articleSuggestionAnswer = null;
    
                        /**
                         * AgentAssistantRecord faqAnswer.
                         * @member {google.cloud.dialogflow.v2beta1.IFaqAnswer|null|undefined} faqAnswer
                         * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantRecord
                         * @instance
                         */
                        AgentAssistantRecord.prototype.faqAnswer = null;
    
                        /**
                         * AgentAssistantRecord dialogflowAssistAnswer.
                         * @member {google.cloud.dialogflow.v2beta1.IDialogflowAssistAnswer|null|undefined} dialogflowAssistAnswer
                         * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantRecord
                         * @instance
                         */
                        AgentAssistantRecord.prototype.dialogflowAssistAnswer = null;
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * AgentAssistantRecord answer.
                         * @member {"articleSuggestionAnswer"|"faqAnswer"|"dialogflowAssistAnswer"|undefined} answer
                         * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantRecord
                         * @instance
                         */
                        Object.defineProperty(AgentAssistantRecord.prototype, "answer", {
                            get: $util.oneOfGetter($oneOfFields = ["articleSuggestionAnswer", "faqAnswer", "dialogflowAssistAnswer"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new AgentAssistantRecord instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantRecord
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IAgentAssistantRecord=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.AgentAssistantRecord} AgentAssistantRecord instance
                         */
                        AgentAssistantRecord.create = function create(properties) {
                            return new AgentAssistantRecord(properties);
                        };
    
                        /**
                         * Encodes the specified AgentAssistantRecord message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.AgentAssistantRecord.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantRecord
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IAgentAssistantRecord} message AgentAssistantRecord message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        AgentAssistantRecord.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.articleSuggestionAnswer != null && Object.hasOwnProperty.call(message, "articleSuggestionAnswer"))
                                $root.google.cloud.dialogflow.v2beta1.ArticleAnswer.encode(message.articleSuggestionAnswer, writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                            if (message.faqAnswer != null && Object.hasOwnProperty.call(message, "faqAnswer"))
                                $root.google.cloud.dialogflow.v2beta1.FaqAnswer.encode(message.faqAnswer, writer.uint32(/* id 6, wireType 2 =*/50).fork()).ldelim();
                            if (message.dialogflowAssistAnswer != null && Object.hasOwnProperty.call(message, "dialogflowAssistAnswer"))
                                $root.google.cloud.dialogflow.v2beta1.DialogflowAssistAnswer.encode(message.dialogflowAssistAnswer, writer.uint32(/* id 7, wireType 2 =*/58).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified AgentAssistantRecord message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.AgentAssistantRecord.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantRecord
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IAgentAssistantRecord} message AgentAssistantRecord message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        AgentAssistantRecord.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an AgentAssistantRecord message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantRecord
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.AgentAssistantRecord} AgentAssistantRecord
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        AgentAssistantRecord.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.AgentAssistantRecord();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 5: {
                                        message.articleSuggestionAnswer = $root.google.cloud.dialogflow.v2beta1.ArticleAnswer.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 6: {
                                        message.faqAnswer = $root.google.cloud.dialogflow.v2beta1.FaqAnswer.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 7: {
                                        message.dialogflowAssistAnswer = $root.google.cloud.dialogflow.v2beta1.DialogflowAssistAnswer.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an AgentAssistantRecord message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantRecord
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.AgentAssistantRecord} AgentAssistantRecord
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        AgentAssistantRecord.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an AgentAssistantRecord message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantRecord
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        AgentAssistantRecord.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.articleSuggestionAnswer != null && message.hasOwnProperty("articleSuggestionAnswer")) {
                                properties.answer = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2beta1.ArticleAnswer.verify(message.articleSuggestionAnswer);
                                    if (error)
                                        return "articleSuggestionAnswer." + error;
                                }
                            }
                            if (message.faqAnswer != null && message.hasOwnProperty("faqAnswer")) {
                                if (properties.answer === 1)
                                    return "answer: multiple values";
                                properties.answer = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2beta1.FaqAnswer.verify(message.faqAnswer);
                                    if (error)
                                        return "faqAnswer." + error;
                                }
                            }
                            if (message.dialogflowAssistAnswer != null && message.hasOwnProperty("dialogflowAssistAnswer")) {
                                if (properties.answer === 1)
                                    return "answer: multiple values";
                                properties.answer = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2beta1.DialogflowAssistAnswer.verify(message.dialogflowAssistAnswer);
                                    if (error)
                                        return "dialogflowAssistAnswer." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates an AgentAssistantRecord message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantRecord
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.AgentAssistantRecord} AgentAssistantRecord
                         */
                        AgentAssistantRecord.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.AgentAssistantRecord)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.AgentAssistantRecord();
                            if (object.articleSuggestionAnswer != null) {
                                if (typeof object.articleSuggestionAnswer !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.AgentAssistantRecord.articleSuggestionAnswer: object expected");
                                message.articleSuggestionAnswer = $root.google.cloud.dialogflow.v2beta1.ArticleAnswer.fromObject(object.articleSuggestionAnswer);
                            }
                            if (object.faqAnswer != null) {
                                if (typeof object.faqAnswer !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.AgentAssistantRecord.faqAnswer: object expected");
                                message.faqAnswer = $root.google.cloud.dialogflow.v2beta1.FaqAnswer.fromObject(object.faqAnswer);
                            }
                            if (object.dialogflowAssistAnswer != null) {
                                if (typeof object.dialogflowAssistAnswer !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.AgentAssistantRecord.dialogflowAssistAnswer: object expected");
                                message.dialogflowAssistAnswer = $root.google.cloud.dialogflow.v2beta1.DialogflowAssistAnswer.fromObject(object.dialogflowAssistAnswer);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an AgentAssistantRecord message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantRecord
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.AgentAssistantRecord} message AgentAssistantRecord
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        AgentAssistantRecord.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (message.articleSuggestionAnswer != null && message.hasOwnProperty("articleSuggestionAnswer")) {
                                object.articleSuggestionAnswer = $root.google.cloud.dialogflow.v2beta1.ArticleAnswer.toObject(message.articleSuggestionAnswer, options);
                                if (options.oneofs)
                                    object.answer = "articleSuggestionAnswer";
                            }
                            if (message.faqAnswer != null && message.hasOwnProperty("faqAnswer")) {
                                object.faqAnswer = $root.google.cloud.dialogflow.v2beta1.FaqAnswer.toObject(message.faqAnswer, options);
                                if (options.oneofs)
                                    object.answer = "faqAnswer";
                            }
                            if (message.dialogflowAssistAnswer != null && message.hasOwnProperty("dialogflowAssistAnswer")) {
                                object.dialogflowAssistAnswer = $root.google.cloud.dialogflow.v2beta1.DialogflowAssistAnswer.toObject(message.dialogflowAssistAnswer, options);
                                if (options.oneofs)
                                    object.answer = "dialogflowAssistAnswer";
                            }
                            return object;
                        };
    
                        /**
                         * Converts this AgentAssistantRecord to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantRecord
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        AgentAssistantRecord.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for AgentAssistantRecord
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantRecord
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        AgentAssistantRecord.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.AgentAssistantRecord";
                        };
    
                        return AgentAssistantRecord;
                    })();
    
                    v2beta1.AnswerFeedback = (function() {
    
                        /**
                         * Properties of an AnswerFeedback.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IAnswerFeedback
                         * @property {google.cloud.dialogflow.v2beta1.AnswerFeedback.CorrectnessLevel|null} [correctnessLevel] AnswerFeedback correctnessLevel
                         * @property {google.cloud.dialogflow.v2beta1.IAgentAssistantFeedback|null} [agentAssistantDetailFeedback] AnswerFeedback agentAssistantDetailFeedback
                         * @property {boolean|null} [clicked] AnswerFeedback clicked
                         * @property {google.protobuf.ITimestamp|null} [clickTime] AnswerFeedback clickTime
                         * @property {boolean|null} [displayed] AnswerFeedback displayed
                         * @property {google.protobuf.ITimestamp|null} [displayTime] AnswerFeedback displayTime
                         */
    
                        /**
                         * Constructs a new AnswerFeedback.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an AnswerFeedback.
                         * @implements IAnswerFeedback
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IAnswerFeedback=} [properties] Properties to set
                         */
                        function AnswerFeedback(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * AnswerFeedback correctnessLevel.
                         * @member {google.cloud.dialogflow.v2beta1.AnswerFeedback.CorrectnessLevel} correctnessLevel
                         * @memberof google.cloud.dialogflow.v2beta1.AnswerFeedback
                         * @instance
                         */
                        AnswerFeedback.prototype.correctnessLevel = 0;
    
                        /**
                         * AnswerFeedback agentAssistantDetailFeedback.
                         * @member {google.cloud.dialogflow.v2beta1.IAgentAssistantFeedback|null|undefined} agentAssistantDetailFeedback
                         * @memberof google.cloud.dialogflow.v2beta1.AnswerFeedback
                         * @instance
                         */
                        AnswerFeedback.prototype.agentAssistantDetailFeedback = null;
    
                        /**
                         * AnswerFeedback clicked.
                         * @member {boolean} clicked
                         * @memberof google.cloud.dialogflow.v2beta1.AnswerFeedback
                         * @instance
                         */
                        AnswerFeedback.prototype.clicked = false;
    
                        /**
                         * AnswerFeedback clickTime.
                         * @member {google.protobuf.ITimestamp|null|undefined} clickTime
                         * @memberof google.cloud.dialogflow.v2beta1.AnswerFeedback
                         * @instance
                         */
                        AnswerFeedback.prototype.clickTime = null;
    
                        /**
                         * AnswerFeedback displayed.
                         * @member {boolean} displayed
                         * @memberof google.cloud.dialogflow.v2beta1.AnswerFeedback
                         * @instance
                         */
                        AnswerFeedback.prototype.displayed = false;
    
                        /**
                         * AnswerFeedback displayTime.
                         * @member {google.protobuf.ITimestamp|null|undefined} displayTime
                         * @memberof google.cloud.dialogflow.v2beta1.AnswerFeedback
                         * @instance
                         */
                        AnswerFeedback.prototype.displayTime = null;
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * AnswerFeedback detailFeedback.
                         * @member {"agentAssistantDetailFeedback"|undefined} detailFeedback
                         * @memberof google.cloud.dialogflow.v2beta1.AnswerFeedback
                         * @instance
                         */
                        Object.defineProperty(AnswerFeedback.prototype, "detailFeedback", {
                            get: $util.oneOfGetter($oneOfFields = ["agentAssistantDetailFeedback"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new AnswerFeedback instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.AnswerFeedback
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IAnswerFeedback=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.AnswerFeedback} AnswerFeedback instance
                         */
                        AnswerFeedback.create = function create(properties) {
                            return new AnswerFeedback(properties);
                        };
    
                        /**
                         * Encodes the specified AnswerFeedback message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.AnswerFeedback.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.AnswerFeedback
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IAnswerFeedback} message AnswerFeedback message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        AnswerFeedback.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.correctnessLevel != null && Object.hasOwnProperty.call(message, "correctnessLevel"))
                                writer.uint32(/* id 1, wireType 0 =*/8).int32(message.correctnessLevel);
                            if (message.agentAssistantDetailFeedback != null && Object.hasOwnProperty.call(message, "agentAssistantDetailFeedback"))
                                $root.google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.encode(message.agentAssistantDetailFeedback, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.clicked != null && Object.hasOwnProperty.call(message, "clicked"))
                                writer.uint32(/* id 3, wireType 0 =*/24).bool(message.clicked);
                            if (message.displayed != null && Object.hasOwnProperty.call(message, "displayed"))
                                writer.uint32(/* id 4, wireType 0 =*/32).bool(message.displayed);
                            if (message.clickTime != null && Object.hasOwnProperty.call(message, "clickTime"))
                                $root.google.protobuf.Timestamp.encode(message.clickTime, writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                            if (message.displayTime != null && Object.hasOwnProperty.call(message, "displayTime"))
                                $root.google.protobuf.Timestamp.encode(message.displayTime, writer.uint32(/* id 6, wireType 2 =*/50).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified AnswerFeedback message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.AnswerFeedback.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.AnswerFeedback
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IAnswerFeedback} message AnswerFeedback message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        AnswerFeedback.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an AnswerFeedback message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.AnswerFeedback
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.AnswerFeedback} AnswerFeedback
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        AnswerFeedback.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.AnswerFeedback();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.correctnessLevel = reader.int32();
                                        break;
                                    }
                                case 2: {
                                        message.agentAssistantDetailFeedback = $root.google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 3: {
                                        message.clicked = reader.bool();
                                        break;
                                    }
                                case 5: {
                                        message.clickTime = $root.google.protobuf.Timestamp.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 4: {
                                        message.displayed = reader.bool();
                                        break;
                                    }
                                case 6: {
                                        message.displayTime = $root.google.protobuf.Timestamp.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an AnswerFeedback message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.AnswerFeedback
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.AnswerFeedback} AnswerFeedback
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        AnswerFeedback.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an AnswerFeedback message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.AnswerFeedback
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        AnswerFeedback.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.correctnessLevel != null && message.hasOwnProperty("correctnessLevel"))
                                switch (message.correctnessLevel) {
                                default:
                                    return "correctnessLevel: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                    break;
                                }
                            if (message.agentAssistantDetailFeedback != null && message.hasOwnProperty("agentAssistantDetailFeedback")) {
                                properties.detailFeedback = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.verify(message.agentAssistantDetailFeedback);
                                    if (error)
                                        return "agentAssistantDetailFeedback." + error;
                                }
                            }
                            if (message.clicked != null && message.hasOwnProperty("clicked"))
                                if (typeof message.clicked !== "boolean")
                                    return "clicked: boolean expected";
                            if (message.clickTime != null && message.hasOwnProperty("clickTime")) {
                                var error = $root.google.protobuf.Timestamp.verify(message.clickTime);
                                if (error)
                                    return "clickTime." + error;
                            }
                            if (message.displayed != null && message.hasOwnProperty("displayed"))
                                if (typeof message.displayed !== "boolean")
                                    return "displayed: boolean expected";
                            if (message.displayTime != null && message.hasOwnProperty("displayTime")) {
                                var error = $root.google.protobuf.Timestamp.verify(message.displayTime);
                                if (error)
                                    return "displayTime." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates an AnswerFeedback message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.AnswerFeedback
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.AnswerFeedback} AnswerFeedback
                         */
                        AnswerFeedback.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.AnswerFeedback)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.AnswerFeedback();
                            switch (object.correctnessLevel) {
                            default:
                                if (typeof object.correctnessLevel === "number") {
                                    message.correctnessLevel = object.correctnessLevel;
                                    break;
                                }
                                break;
                            case "CORRECTNESS_LEVEL_UNSPECIFIED":
                            case 0:
                                message.correctnessLevel = 0;
                                break;
                            case "NOT_CORRECT":
                            case 1:
                                message.correctnessLevel = 1;
                                break;
                            case "PARTIALLY_CORRECT":
                            case 2:
                                message.correctnessLevel = 2;
                                break;
                            case "FULLY_CORRECT":
                            case 3:
                                message.correctnessLevel = 3;
                                break;
                            }
                            if (object.agentAssistantDetailFeedback != null) {
                                if (typeof object.agentAssistantDetailFeedback !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.AnswerFeedback.agentAssistantDetailFeedback: object expected");
                                message.agentAssistantDetailFeedback = $root.google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.fromObject(object.agentAssistantDetailFeedback);
                            }
                            if (object.clicked != null)
                                message.clicked = Boolean(object.clicked);
                            if (object.clickTime != null) {
                                if (typeof object.clickTime !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.AnswerFeedback.clickTime: object expected");
                                message.clickTime = $root.google.protobuf.Timestamp.fromObject(object.clickTime);
                            }
                            if (object.displayed != null)
                                message.displayed = Boolean(object.displayed);
                            if (object.displayTime != null) {
                                if (typeof object.displayTime !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.AnswerFeedback.displayTime: object expected");
                                message.displayTime = $root.google.protobuf.Timestamp.fromObject(object.displayTime);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an AnswerFeedback message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.AnswerFeedback
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.AnswerFeedback} message AnswerFeedback
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        AnswerFeedback.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.correctnessLevel = options.enums === String ? "CORRECTNESS_LEVEL_UNSPECIFIED" : 0;
                                object.clicked = false;
                                object.displayed = false;
                                object.clickTime = null;
                                object.displayTime = null;
                            }
                            if (message.correctnessLevel != null && message.hasOwnProperty("correctnessLevel"))
                                object.correctnessLevel = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.AnswerFeedback.CorrectnessLevel[message.correctnessLevel] === undefined ? message.correctnessLevel : $root.google.cloud.dialogflow.v2beta1.AnswerFeedback.CorrectnessLevel[message.correctnessLevel] : message.correctnessLevel;
                            if (message.agentAssistantDetailFeedback != null && message.hasOwnProperty("agentAssistantDetailFeedback")) {
                                object.agentAssistantDetailFeedback = $root.google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.toObject(message.agentAssistantDetailFeedback, options);
                                if (options.oneofs)
                                    object.detailFeedback = "agentAssistantDetailFeedback";
                            }
                            if (message.clicked != null && message.hasOwnProperty("clicked"))
                                object.clicked = message.clicked;
                            if (message.displayed != null && message.hasOwnProperty("displayed"))
                                object.displayed = message.displayed;
                            if (message.clickTime != null && message.hasOwnProperty("clickTime"))
                                object.clickTime = $root.google.protobuf.Timestamp.toObject(message.clickTime, options);
                            if (message.displayTime != null && message.hasOwnProperty("displayTime"))
                                object.displayTime = $root.google.protobuf.Timestamp.toObject(message.displayTime, options);
                            return object;
                        };
    
                        /**
                         * Converts this AnswerFeedback to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.AnswerFeedback
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        AnswerFeedback.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for AnswerFeedback
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.AnswerFeedback
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        AnswerFeedback.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.AnswerFeedback";
                        };
    
                        /**
                         * CorrectnessLevel enum.
                         * @name google.cloud.dialogflow.v2beta1.AnswerFeedback.CorrectnessLevel
                         * @enum {number}
                         * @property {number} CORRECTNESS_LEVEL_UNSPECIFIED=0 CORRECTNESS_LEVEL_UNSPECIFIED value
                         * @property {number} NOT_CORRECT=1 NOT_CORRECT value
                         * @property {number} PARTIALLY_CORRECT=2 PARTIALLY_CORRECT value
                         * @property {number} FULLY_CORRECT=3 FULLY_CORRECT value
                         */
                        AnswerFeedback.CorrectnessLevel = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "CORRECTNESS_LEVEL_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "NOT_CORRECT"] = 1;
                            values[valuesById[2] = "PARTIALLY_CORRECT"] = 2;
                            values[valuesById[3] = "FULLY_CORRECT"] = 3;
                            return values;
                        })();
    
                        return AnswerFeedback;
                    })();
    
                    v2beta1.AgentAssistantFeedback = (function() {
    
                        /**
                         * Properties of an AgentAssistantFeedback.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IAgentAssistantFeedback
                         * @property {google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.AnswerRelevance|null} [answerRelevance] AgentAssistantFeedback answerRelevance
                         * @property {google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.DocumentCorrectness|null} [documentCorrectness] AgentAssistantFeedback documentCorrectness
                         * @property {google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.DocumentEfficiency|null} [documentEfficiency] AgentAssistantFeedback documentEfficiency
                         * @property {google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.ISummarizationFeedback|null} [summarizationFeedback] AgentAssistantFeedback summarizationFeedback
                         * @property {google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.IKnowledgeSearchFeedback|null} [knowledgeSearchFeedback] AgentAssistantFeedback knowledgeSearchFeedback
                         * @property {google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.IKnowledgeAssistFeedback|null} [knowledgeAssistFeedback] AgentAssistantFeedback knowledgeAssistFeedback
                         */
    
                        /**
                         * Constructs a new AgentAssistantFeedback.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an AgentAssistantFeedback.
                         * @implements IAgentAssistantFeedback
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IAgentAssistantFeedback=} [properties] Properties to set
                         */
                        function AgentAssistantFeedback(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * AgentAssistantFeedback answerRelevance.
                         * @member {google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.AnswerRelevance} answerRelevance
                         * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback
                         * @instance
                         */
                        AgentAssistantFeedback.prototype.answerRelevance = 0;
    
                        /**
                         * AgentAssistantFeedback documentCorrectness.
                         * @member {google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.DocumentCorrectness} documentCorrectness
                         * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback
                         * @instance
                         */
                        AgentAssistantFeedback.prototype.documentCorrectness = 0;
    
                        /**
                         * AgentAssistantFeedback documentEfficiency.
                         * @member {google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.DocumentEfficiency} documentEfficiency
                         * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback
                         * @instance
                         */
                        AgentAssistantFeedback.prototype.documentEfficiency = 0;
    
                        /**
                         * AgentAssistantFeedback summarizationFeedback.
                         * @member {google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.ISummarizationFeedback|null|undefined} summarizationFeedback
                         * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback
                         * @instance
                         */
                        AgentAssistantFeedback.prototype.summarizationFeedback = null;
    
                        /**
                         * AgentAssistantFeedback knowledgeSearchFeedback.
                         * @member {google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.IKnowledgeSearchFeedback|null|undefined} knowledgeSearchFeedback
                         * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback
                         * @instance
                         */
                        AgentAssistantFeedback.prototype.knowledgeSearchFeedback = null;
    
                        /**
                         * AgentAssistantFeedback knowledgeAssistFeedback.
                         * @member {google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.IKnowledgeAssistFeedback|null|undefined} knowledgeAssistFeedback
                         * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback
                         * @instance
                         */
                        AgentAssistantFeedback.prototype.knowledgeAssistFeedback = null;
    
                        /**
                         * Creates a new AgentAssistantFeedback instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IAgentAssistantFeedback=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.AgentAssistantFeedback} AgentAssistantFeedback instance
                         */
                        AgentAssistantFeedback.create = function create(properties) {
                            return new AgentAssistantFeedback(properties);
                        };
    
                        /**
                         * Encodes the specified AgentAssistantFeedback message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IAgentAssistantFeedback} message AgentAssistantFeedback message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        AgentAssistantFeedback.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.answerRelevance != null && Object.hasOwnProperty.call(message, "answerRelevance"))
                                writer.uint32(/* id 1, wireType 0 =*/8).int32(message.answerRelevance);
                            if (message.documentCorrectness != null && Object.hasOwnProperty.call(message, "documentCorrectness"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.documentCorrectness);
                            if (message.documentEfficiency != null && Object.hasOwnProperty.call(message, "documentEfficiency"))
                                writer.uint32(/* id 3, wireType 0 =*/24).int32(message.documentEfficiency);
                            if (message.summarizationFeedback != null && Object.hasOwnProperty.call(message, "summarizationFeedback"))
                                $root.google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.SummarizationFeedback.encode(message.summarizationFeedback, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            if (message.knowledgeSearchFeedback != null && Object.hasOwnProperty.call(message, "knowledgeSearchFeedback"))
                                $root.google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeSearchFeedback.encode(message.knowledgeSearchFeedback, writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                            if (message.knowledgeAssistFeedback != null && Object.hasOwnProperty.call(message, "knowledgeAssistFeedback"))
                                $root.google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeAssistFeedback.encode(message.knowledgeAssistFeedback, writer.uint32(/* id 6, wireType 2 =*/50).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified AgentAssistantFeedback message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IAgentAssistantFeedback} message AgentAssistantFeedback message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        AgentAssistantFeedback.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an AgentAssistantFeedback message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.AgentAssistantFeedback} AgentAssistantFeedback
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        AgentAssistantFeedback.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.AgentAssistantFeedback();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.answerRelevance = reader.int32();
                                        break;
                                    }
                                case 2: {
                                        message.documentCorrectness = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.documentEfficiency = reader.int32();
                                        break;
                                    }
                                case 4: {
                                        message.summarizationFeedback = $root.google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.SummarizationFeedback.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 5: {
                                        message.knowledgeSearchFeedback = $root.google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeSearchFeedback.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 6: {
                                        message.knowledgeAssistFeedback = $root.google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeAssistFeedback.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an AgentAssistantFeedback message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.AgentAssistantFeedback} AgentAssistantFeedback
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        AgentAssistantFeedback.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an AgentAssistantFeedback message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        AgentAssistantFeedback.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.answerRelevance != null && message.hasOwnProperty("answerRelevance"))
                                switch (message.answerRelevance) {
                                default:
                                    return "answerRelevance: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                    break;
                                }
                            if (message.documentCorrectness != null && message.hasOwnProperty("documentCorrectness"))
                                switch (message.documentCorrectness) {
                                default:
                                    return "documentCorrectness: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                    break;
                                }
                            if (message.documentEfficiency != null && message.hasOwnProperty("documentEfficiency"))
                                switch (message.documentEfficiency) {
                                default:
                                    return "documentEfficiency: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                    break;
                                }
                            if (message.summarizationFeedback != null && message.hasOwnProperty("summarizationFeedback")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.SummarizationFeedback.verify(message.summarizationFeedback);
                                if (error)
                                    return "summarizationFeedback." + error;
                            }
                            if (message.knowledgeSearchFeedback != null && message.hasOwnProperty("knowledgeSearchFeedback")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeSearchFeedback.verify(message.knowledgeSearchFeedback);
                                if (error)
                                    return "knowledgeSearchFeedback." + error;
                            }
                            if (message.knowledgeAssistFeedback != null && message.hasOwnProperty("knowledgeAssistFeedback")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeAssistFeedback.verify(message.knowledgeAssistFeedback);
                                if (error)
                                    return "knowledgeAssistFeedback." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates an AgentAssistantFeedback message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.AgentAssistantFeedback} AgentAssistantFeedback
                         */
                        AgentAssistantFeedback.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.AgentAssistantFeedback)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.AgentAssistantFeedback();
                            switch (object.answerRelevance) {
                            default:
                                if (typeof object.answerRelevance === "number") {
                                    message.answerRelevance = object.answerRelevance;
                                    break;
                                }
                                break;
                            case "ANSWER_RELEVANCE_UNSPECIFIED":
                            case 0:
                                message.answerRelevance = 0;
                                break;
                            case "IRRELEVANT":
                            case 1:
                                message.answerRelevance = 1;
                                break;
                            case "RELEVANT":
                            case 2:
                                message.answerRelevance = 2;
                                break;
                            }
                            switch (object.documentCorrectness) {
                            default:
                                if (typeof object.documentCorrectness === "number") {
                                    message.documentCorrectness = object.documentCorrectness;
                                    break;
                                }
                                break;
                            case "DOCUMENT_CORRECTNESS_UNSPECIFIED":
                            case 0:
                                message.documentCorrectness = 0;
                                break;
                            case "INCORRECT":
                            case 1:
                                message.documentCorrectness = 1;
                                break;
                            case "CORRECT":
                            case 2:
                                message.documentCorrectness = 2;
                                break;
                            }
                            switch (object.documentEfficiency) {
                            default:
                                if (typeof object.documentEfficiency === "number") {
                                    message.documentEfficiency = object.documentEfficiency;
                                    break;
                                }
                                break;
                            case "DOCUMENT_EFFICIENCY_UNSPECIFIED":
                            case 0:
                                message.documentEfficiency = 0;
                                break;
                            case "INEFFICIENT":
                            case 1:
                                message.documentEfficiency = 1;
                                break;
                            case "EFFICIENT":
                            case 2:
                                message.documentEfficiency = 2;
                                break;
                            }
                            if (object.summarizationFeedback != null) {
                                if (typeof object.summarizationFeedback !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.summarizationFeedback: object expected");
                                message.summarizationFeedback = $root.google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.SummarizationFeedback.fromObject(object.summarizationFeedback);
                            }
                            if (object.knowledgeSearchFeedback != null) {
                                if (typeof object.knowledgeSearchFeedback !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.knowledgeSearchFeedback: object expected");
                                message.knowledgeSearchFeedback = $root.google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeSearchFeedback.fromObject(object.knowledgeSearchFeedback);
                            }
                            if (object.knowledgeAssistFeedback != null) {
                                if (typeof object.knowledgeAssistFeedback !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.knowledgeAssistFeedback: object expected");
                                message.knowledgeAssistFeedback = $root.google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeAssistFeedback.fromObject(object.knowledgeAssistFeedback);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an AgentAssistantFeedback message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.AgentAssistantFeedback} message AgentAssistantFeedback
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        AgentAssistantFeedback.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.answerRelevance = options.enums === String ? "ANSWER_RELEVANCE_UNSPECIFIED" : 0;
                                object.documentCorrectness = options.enums === String ? "DOCUMENT_CORRECTNESS_UNSPECIFIED" : 0;
                                object.documentEfficiency = options.enums === String ? "DOCUMENT_EFFICIENCY_UNSPECIFIED" : 0;
                                object.summarizationFeedback = null;
                                object.knowledgeSearchFeedback = null;
                                object.knowledgeAssistFeedback = null;
                            }
                            if (message.answerRelevance != null && message.hasOwnProperty("answerRelevance"))
                                object.answerRelevance = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.AnswerRelevance[message.answerRelevance] === undefined ? message.answerRelevance : $root.google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.AnswerRelevance[message.answerRelevance] : message.answerRelevance;
                            if (message.documentCorrectness != null && message.hasOwnProperty("documentCorrectness"))
                                object.documentCorrectness = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.DocumentCorrectness[message.documentCorrectness] === undefined ? message.documentCorrectness : $root.google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.DocumentCorrectness[message.documentCorrectness] : message.documentCorrectness;
                            if (message.documentEfficiency != null && message.hasOwnProperty("documentEfficiency"))
                                object.documentEfficiency = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.DocumentEfficiency[message.documentEfficiency] === undefined ? message.documentEfficiency : $root.google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.DocumentEfficiency[message.documentEfficiency] : message.documentEfficiency;
                            if (message.summarizationFeedback != null && message.hasOwnProperty("summarizationFeedback"))
                                object.summarizationFeedback = $root.google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.SummarizationFeedback.toObject(message.summarizationFeedback, options);
                            if (message.knowledgeSearchFeedback != null && message.hasOwnProperty("knowledgeSearchFeedback"))
                                object.knowledgeSearchFeedback = $root.google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeSearchFeedback.toObject(message.knowledgeSearchFeedback, options);
                            if (message.knowledgeAssistFeedback != null && message.hasOwnProperty("knowledgeAssistFeedback"))
                                object.knowledgeAssistFeedback = $root.google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeAssistFeedback.toObject(message.knowledgeAssistFeedback, options);
                            return object;
                        };
    
                        /**
                         * Converts this AgentAssistantFeedback to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        AgentAssistantFeedback.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for AgentAssistantFeedback
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        AgentAssistantFeedback.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.AgentAssistantFeedback";
                        };
    
                        /**
                         * AnswerRelevance enum.
                         * @name google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.AnswerRelevance
                         * @enum {number}
                         * @property {number} ANSWER_RELEVANCE_UNSPECIFIED=0 ANSWER_RELEVANCE_UNSPECIFIED value
                         * @property {number} IRRELEVANT=1 IRRELEVANT value
                         * @property {number} RELEVANT=2 RELEVANT value
                         */
                        AgentAssistantFeedback.AnswerRelevance = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "ANSWER_RELEVANCE_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "IRRELEVANT"] = 1;
                            values[valuesById[2] = "RELEVANT"] = 2;
                            return values;
                        })();
    
                        /**
                         * DocumentCorrectness enum.
                         * @name google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.DocumentCorrectness
                         * @enum {number}
                         * @property {number} DOCUMENT_CORRECTNESS_UNSPECIFIED=0 DOCUMENT_CORRECTNESS_UNSPECIFIED value
                         * @property {number} INCORRECT=1 INCORRECT value
                         * @property {number} CORRECT=2 CORRECT value
                         */
                        AgentAssistantFeedback.DocumentCorrectness = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "DOCUMENT_CORRECTNESS_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "INCORRECT"] = 1;
                            values[valuesById[2] = "CORRECT"] = 2;
                            return values;
                        })();
    
                        /**
                         * DocumentEfficiency enum.
                         * @name google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.DocumentEfficiency
                         * @enum {number}
                         * @property {number} DOCUMENT_EFFICIENCY_UNSPECIFIED=0 DOCUMENT_EFFICIENCY_UNSPECIFIED value
                         * @property {number} INEFFICIENT=1 INEFFICIENT value
                         * @property {number} EFFICIENT=2 EFFICIENT value
                         */
                        AgentAssistantFeedback.DocumentEfficiency = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "DOCUMENT_EFFICIENCY_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "INEFFICIENT"] = 1;
                            values[valuesById[2] = "EFFICIENT"] = 2;
                            return values;
                        })();
    
                        AgentAssistantFeedback.SummarizationFeedback = (function() {
    
                            /**
                             * Properties of a SummarizationFeedback.
                             * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback
                             * @interface ISummarizationFeedback
                             * @property {google.protobuf.ITimestamp|null} [startTimestamp] SummarizationFeedback startTimestamp
                             * @property {google.protobuf.ITimestamp|null} [submitTimestamp] SummarizationFeedback submitTimestamp
                             * @property {string|null} [summaryText] SummarizationFeedback summaryText
                             * @property {Object.<string,string>|null} [textSections] SummarizationFeedback textSections
                             */
    
                            /**
                             * Constructs a new SummarizationFeedback.
                             * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback
                             * @classdesc Represents a SummarizationFeedback.
                             * @implements ISummarizationFeedback
                             * @constructor
                             * @param {google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.ISummarizationFeedback=} [properties] Properties to set
                             */
                            function SummarizationFeedback(properties) {
                                this.textSections = {};
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * SummarizationFeedback startTimestamp.
                             * @member {google.protobuf.ITimestamp|null|undefined} startTimestamp
                             * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.SummarizationFeedback
                             * @instance
                             */
                            SummarizationFeedback.prototype.startTimestamp = null;
    
                            /**
                             * SummarizationFeedback submitTimestamp.
                             * @member {google.protobuf.ITimestamp|null|undefined} submitTimestamp
                             * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.SummarizationFeedback
                             * @instance
                             */
                            SummarizationFeedback.prototype.submitTimestamp = null;
    
                            /**
                             * SummarizationFeedback summaryText.
                             * @member {string} summaryText
                             * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.SummarizationFeedback
                             * @instance
                             */
                            SummarizationFeedback.prototype.summaryText = "";
    
                            /**
                             * SummarizationFeedback textSections.
                             * @member {Object.<string,string>} textSections
                             * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.SummarizationFeedback
                             * @instance
                             */
                            SummarizationFeedback.prototype.textSections = $util.emptyObject;
    
                            /**
                             * Creates a new SummarizationFeedback instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.SummarizationFeedback
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.ISummarizationFeedback=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.SummarizationFeedback} SummarizationFeedback instance
                             */
                            SummarizationFeedback.create = function create(properties) {
                                return new SummarizationFeedback(properties);
                            };
    
                            /**
                             * Encodes the specified SummarizationFeedback message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.SummarizationFeedback.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.SummarizationFeedback
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.ISummarizationFeedback} message SummarizationFeedback message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            SummarizationFeedback.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.startTimestamp != null && Object.hasOwnProperty.call(message, "startTimestamp"))
                                    $root.google.protobuf.Timestamp.encode(message.startTimestamp, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                                if (message.submitTimestamp != null && Object.hasOwnProperty.call(message, "submitTimestamp"))
                                    $root.google.protobuf.Timestamp.encode(message.submitTimestamp, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                                if (message.summaryText != null && Object.hasOwnProperty.call(message, "summaryText"))
                                    writer.uint32(/* id 3, wireType 2 =*/26).string(message.summaryText);
                                if (message.textSections != null && Object.hasOwnProperty.call(message, "textSections"))
                                    for (var keys = Object.keys(message.textSections), i = 0; i < keys.length; ++i)
                                        writer.uint32(/* id 4, wireType 2 =*/34).fork().uint32(/* id 1, wireType 2 =*/10).string(keys[i]).uint32(/* id 2, wireType 2 =*/18).string(message.textSections[keys[i]]).ldelim();
                                return writer;
                            };
    
                            /**
                             * Encodes the specified SummarizationFeedback message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.SummarizationFeedback.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.SummarizationFeedback
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.ISummarizationFeedback} message SummarizationFeedback message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            SummarizationFeedback.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a SummarizationFeedback message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.SummarizationFeedback
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.SummarizationFeedback} SummarizationFeedback
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            SummarizationFeedback.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.SummarizationFeedback(), key, value;
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.startTimestamp = $root.google.protobuf.Timestamp.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 2: {
                                            message.submitTimestamp = $root.google.protobuf.Timestamp.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 3: {
                                            message.summaryText = reader.string();
                                            break;
                                        }
                                    case 4: {
                                            if (message.textSections === $util.emptyObject)
                                                message.textSections = {};
                                            var end2 = reader.uint32() + reader.pos;
                                            key = "";
                                            value = "";
                                            while (reader.pos < end2) {
                                                var tag2 = reader.uint32();
                                                switch (tag2 >>> 3) {
                                                case 1:
                                                    key = reader.string();
                                                    break;
                                                case 2:
                                                    value = reader.string();
                                                    break;
                                                default:
                                                    reader.skipType(tag2 & 7);
                                                    break;
                                                }
                                            }
                                            message.textSections[key] = value;
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a SummarizationFeedback message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.SummarizationFeedback
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.SummarizationFeedback} SummarizationFeedback
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            SummarizationFeedback.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a SummarizationFeedback message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.SummarizationFeedback
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            SummarizationFeedback.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.startTimestamp != null && message.hasOwnProperty("startTimestamp")) {
                                    var error = $root.google.protobuf.Timestamp.verify(message.startTimestamp);
                                    if (error)
                                        return "startTimestamp." + error;
                                }
                                if (message.submitTimestamp != null && message.hasOwnProperty("submitTimestamp")) {
                                    var error = $root.google.protobuf.Timestamp.verify(message.submitTimestamp);
                                    if (error)
                                        return "submitTimestamp." + error;
                                }
                                if (message.summaryText != null && message.hasOwnProperty("summaryText"))
                                    if (!$util.isString(message.summaryText))
                                        return "summaryText: string expected";
                                if (message.textSections != null && message.hasOwnProperty("textSections")) {
                                    if (!$util.isObject(message.textSections))
                                        return "textSections: object expected";
                                    var key = Object.keys(message.textSections);
                                    for (var i = 0; i < key.length; ++i)
                                        if (!$util.isString(message.textSections[key[i]]))
                                            return "textSections: string{k:string} expected";
                                }
                                return null;
                            };
    
                            /**
                             * Creates a SummarizationFeedback message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.SummarizationFeedback
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.SummarizationFeedback} SummarizationFeedback
                             */
                            SummarizationFeedback.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.SummarizationFeedback)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.SummarizationFeedback();
                                if (object.startTimestamp != null) {
                                    if (typeof object.startTimestamp !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.SummarizationFeedback.startTimestamp: object expected");
                                    message.startTimestamp = $root.google.protobuf.Timestamp.fromObject(object.startTimestamp);
                                }
                                if (object.submitTimestamp != null) {
                                    if (typeof object.submitTimestamp !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.SummarizationFeedback.submitTimestamp: object expected");
                                    message.submitTimestamp = $root.google.protobuf.Timestamp.fromObject(object.submitTimestamp);
                                }
                                if (object.summaryText != null)
                                    message.summaryText = String(object.summaryText);
                                if (object.textSections) {
                                    if (typeof object.textSections !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.SummarizationFeedback.textSections: object expected");
                                    message.textSections = {};
                                    for (var keys = Object.keys(object.textSections), i = 0; i < keys.length; ++i)
                                        message.textSections[keys[i]] = String(object.textSections[keys[i]]);
                                }
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a SummarizationFeedback message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.SummarizationFeedback
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.SummarizationFeedback} message SummarizationFeedback
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            SummarizationFeedback.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.objects || options.defaults)
                                    object.textSections = {};
                                if (options.defaults) {
                                    object.startTimestamp = null;
                                    object.submitTimestamp = null;
                                    object.summaryText = "";
                                }
                                if (message.startTimestamp != null && message.hasOwnProperty("startTimestamp"))
                                    object.startTimestamp = $root.google.protobuf.Timestamp.toObject(message.startTimestamp, options);
                                if (message.submitTimestamp != null && message.hasOwnProperty("submitTimestamp"))
                                    object.submitTimestamp = $root.google.protobuf.Timestamp.toObject(message.submitTimestamp, options);
                                if (message.summaryText != null && message.hasOwnProperty("summaryText"))
                                    object.summaryText = message.summaryText;
                                var keys2;
                                if (message.textSections && (keys2 = Object.keys(message.textSections)).length) {
                                    object.textSections = {};
                                    for (var j = 0; j < keys2.length; ++j)
                                        object.textSections[keys2[j]] = message.textSections[keys2[j]];
                                }
                                return object;
                            };
    
                            /**
                             * Converts this SummarizationFeedback to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.SummarizationFeedback
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            SummarizationFeedback.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for SummarizationFeedback
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.SummarizationFeedback
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            SummarizationFeedback.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.SummarizationFeedback";
                            };
    
                            return SummarizationFeedback;
                        })();
    
                        AgentAssistantFeedback.KnowledgeSearchFeedback = (function() {
    
                            /**
                             * Properties of a KnowledgeSearchFeedback.
                             * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback
                             * @interface IKnowledgeSearchFeedback
                             * @property {boolean|null} [answerCopied] KnowledgeSearchFeedback answerCopied
                             * @property {Array.<string>|null} [clickedUris] KnowledgeSearchFeedback clickedUris
                             */
    
                            /**
                             * Constructs a new KnowledgeSearchFeedback.
                             * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback
                             * @classdesc Represents a KnowledgeSearchFeedback.
                             * @implements IKnowledgeSearchFeedback
                             * @constructor
                             * @param {google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.IKnowledgeSearchFeedback=} [properties] Properties to set
                             */
                            function KnowledgeSearchFeedback(properties) {
                                this.clickedUris = [];
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * KnowledgeSearchFeedback answerCopied.
                             * @member {boolean} answerCopied
                             * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeSearchFeedback
                             * @instance
                             */
                            KnowledgeSearchFeedback.prototype.answerCopied = false;
    
                            /**
                             * KnowledgeSearchFeedback clickedUris.
                             * @member {Array.<string>} clickedUris
                             * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeSearchFeedback
                             * @instance
                             */
                            KnowledgeSearchFeedback.prototype.clickedUris = $util.emptyArray;
    
                            /**
                             * Creates a new KnowledgeSearchFeedback instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeSearchFeedback
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.IKnowledgeSearchFeedback=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeSearchFeedback} KnowledgeSearchFeedback instance
                             */
                            KnowledgeSearchFeedback.create = function create(properties) {
                                return new KnowledgeSearchFeedback(properties);
                            };
    
                            /**
                             * Encodes the specified KnowledgeSearchFeedback message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeSearchFeedback.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeSearchFeedback
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.IKnowledgeSearchFeedback} message KnowledgeSearchFeedback message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            KnowledgeSearchFeedback.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.answerCopied != null && Object.hasOwnProperty.call(message, "answerCopied"))
                                    writer.uint32(/* id 1, wireType 0 =*/8).bool(message.answerCopied);
                                if (message.clickedUris != null && message.clickedUris.length)
                                    for (var i = 0; i < message.clickedUris.length; ++i)
                                        writer.uint32(/* id 2, wireType 2 =*/18).string(message.clickedUris[i]);
                                return writer;
                            };
    
                            /**
                             * Encodes the specified KnowledgeSearchFeedback message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeSearchFeedback.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeSearchFeedback
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.IKnowledgeSearchFeedback} message KnowledgeSearchFeedback message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            KnowledgeSearchFeedback.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a KnowledgeSearchFeedback message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeSearchFeedback
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeSearchFeedback} KnowledgeSearchFeedback
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            KnowledgeSearchFeedback.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeSearchFeedback();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.answerCopied = reader.bool();
                                            break;
                                        }
                                    case 2: {
                                            if (!(message.clickedUris && message.clickedUris.length))
                                                message.clickedUris = [];
                                            message.clickedUris.push(reader.string());
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a KnowledgeSearchFeedback message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeSearchFeedback
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeSearchFeedback} KnowledgeSearchFeedback
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            KnowledgeSearchFeedback.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a KnowledgeSearchFeedback message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeSearchFeedback
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            KnowledgeSearchFeedback.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.answerCopied != null && message.hasOwnProperty("answerCopied"))
                                    if (typeof message.answerCopied !== "boolean")
                                        return "answerCopied: boolean expected";
                                if (message.clickedUris != null && message.hasOwnProperty("clickedUris")) {
                                    if (!Array.isArray(message.clickedUris))
                                        return "clickedUris: array expected";
                                    for (var i = 0; i < message.clickedUris.length; ++i)
                                        if (!$util.isString(message.clickedUris[i]))
                                            return "clickedUris: string[] expected";
                                }
                                return null;
                            };
    
                            /**
                             * Creates a KnowledgeSearchFeedback message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeSearchFeedback
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeSearchFeedback} KnowledgeSearchFeedback
                             */
                            KnowledgeSearchFeedback.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeSearchFeedback)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeSearchFeedback();
                                if (object.answerCopied != null)
                                    message.answerCopied = Boolean(object.answerCopied);
                                if (object.clickedUris) {
                                    if (!Array.isArray(object.clickedUris))
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeSearchFeedback.clickedUris: array expected");
                                    message.clickedUris = [];
                                    for (var i = 0; i < object.clickedUris.length; ++i)
                                        message.clickedUris[i] = String(object.clickedUris[i]);
                                }
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a KnowledgeSearchFeedback message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeSearchFeedback
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeSearchFeedback} message KnowledgeSearchFeedback
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            KnowledgeSearchFeedback.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.arrays || options.defaults)
                                    object.clickedUris = [];
                                if (options.defaults)
                                    object.answerCopied = false;
                                if (message.answerCopied != null && message.hasOwnProperty("answerCopied"))
                                    object.answerCopied = message.answerCopied;
                                if (message.clickedUris && message.clickedUris.length) {
                                    object.clickedUris = [];
                                    for (var j = 0; j < message.clickedUris.length; ++j)
                                        object.clickedUris[j] = message.clickedUris[j];
                                }
                                return object;
                            };
    
                            /**
                             * Converts this KnowledgeSearchFeedback to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeSearchFeedback
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            KnowledgeSearchFeedback.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for KnowledgeSearchFeedback
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeSearchFeedback
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            KnowledgeSearchFeedback.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeSearchFeedback";
                            };
    
                            return KnowledgeSearchFeedback;
                        })();
    
                        AgentAssistantFeedback.KnowledgeAssistFeedback = (function() {
    
                            /**
                             * Properties of a KnowledgeAssistFeedback.
                             * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback
                             * @interface IKnowledgeAssistFeedback
                             * @property {boolean|null} [answerCopied] KnowledgeAssistFeedback answerCopied
                             * @property {Array.<string>|null} [clickedUris] KnowledgeAssistFeedback clickedUris
                             */
    
                            /**
                             * Constructs a new KnowledgeAssistFeedback.
                             * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback
                             * @classdesc Represents a KnowledgeAssistFeedback.
                             * @implements IKnowledgeAssistFeedback
                             * @constructor
                             * @param {google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.IKnowledgeAssistFeedback=} [properties] Properties to set
                             */
                            function KnowledgeAssistFeedback(properties) {
                                this.clickedUris = [];
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * KnowledgeAssistFeedback answerCopied.
                             * @member {boolean} answerCopied
                             * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeAssistFeedback
                             * @instance
                             */
                            KnowledgeAssistFeedback.prototype.answerCopied = false;
    
                            /**
                             * KnowledgeAssistFeedback clickedUris.
                             * @member {Array.<string>} clickedUris
                             * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeAssistFeedback
                             * @instance
                             */
                            KnowledgeAssistFeedback.prototype.clickedUris = $util.emptyArray;
    
                            /**
                             * Creates a new KnowledgeAssistFeedback instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeAssistFeedback
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.IKnowledgeAssistFeedback=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeAssistFeedback} KnowledgeAssistFeedback instance
                             */
                            KnowledgeAssistFeedback.create = function create(properties) {
                                return new KnowledgeAssistFeedback(properties);
                            };
    
                            /**
                             * Encodes the specified KnowledgeAssistFeedback message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeAssistFeedback.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeAssistFeedback
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.IKnowledgeAssistFeedback} message KnowledgeAssistFeedback message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            KnowledgeAssistFeedback.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.answerCopied != null && Object.hasOwnProperty.call(message, "answerCopied"))
                                    writer.uint32(/* id 1, wireType 0 =*/8).bool(message.answerCopied);
                                if (message.clickedUris != null && message.clickedUris.length)
                                    for (var i = 0; i < message.clickedUris.length; ++i)
                                        writer.uint32(/* id 2, wireType 2 =*/18).string(message.clickedUris[i]);
                                return writer;
                            };
    
                            /**
                             * Encodes the specified KnowledgeAssistFeedback message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeAssistFeedback.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeAssistFeedback
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.IKnowledgeAssistFeedback} message KnowledgeAssistFeedback message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            KnowledgeAssistFeedback.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a KnowledgeAssistFeedback message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeAssistFeedback
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeAssistFeedback} KnowledgeAssistFeedback
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            KnowledgeAssistFeedback.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeAssistFeedback();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.answerCopied = reader.bool();
                                            break;
                                        }
                                    case 2: {
                                            if (!(message.clickedUris && message.clickedUris.length))
                                                message.clickedUris = [];
                                            message.clickedUris.push(reader.string());
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a KnowledgeAssistFeedback message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeAssistFeedback
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeAssistFeedback} KnowledgeAssistFeedback
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            KnowledgeAssistFeedback.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a KnowledgeAssistFeedback message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeAssistFeedback
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            KnowledgeAssistFeedback.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.answerCopied != null && message.hasOwnProperty("answerCopied"))
                                    if (typeof message.answerCopied !== "boolean")
                                        return "answerCopied: boolean expected";
                                if (message.clickedUris != null && message.hasOwnProperty("clickedUris")) {
                                    if (!Array.isArray(message.clickedUris))
                                        return "clickedUris: array expected";
                                    for (var i = 0; i < message.clickedUris.length; ++i)
                                        if (!$util.isString(message.clickedUris[i]))
                                            return "clickedUris: string[] expected";
                                }
                                return null;
                            };
    
                            /**
                             * Creates a KnowledgeAssistFeedback message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeAssistFeedback
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeAssistFeedback} KnowledgeAssistFeedback
                             */
                            KnowledgeAssistFeedback.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeAssistFeedback)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeAssistFeedback();
                                if (object.answerCopied != null)
                                    message.answerCopied = Boolean(object.answerCopied);
                                if (object.clickedUris) {
                                    if (!Array.isArray(object.clickedUris))
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeAssistFeedback.clickedUris: array expected");
                                    message.clickedUris = [];
                                    for (var i = 0; i < object.clickedUris.length; ++i)
                                        message.clickedUris[i] = String(object.clickedUris[i]);
                                }
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a KnowledgeAssistFeedback message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeAssistFeedback
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeAssistFeedback} message KnowledgeAssistFeedback
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            KnowledgeAssistFeedback.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.arrays || options.defaults)
                                    object.clickedUris = [];
                                if (options.defaults)
                                    object.answerCopied = false;
                                if (message.answerCopied != null && message.hasOwnProperty("answerCopied"))
                                    object.answerCopied = message.answerCopied;
                                if (message.clickedUris && message.clickedUris.length) {
                                    object.clickedUris = [];
                                    for (var j = 0; j < message.clickedUris.length; ++j)
                                        object.clickedUris[j] = message.clickedUris[j];
                                }
                                return object;
                            };
    
                            /**
                             * Converts this KnowledgeAssistFeedback to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeAssistFeedback
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            KnowledgeAssistFeedback.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for KnowledgeAssistFeedback
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeAssistFeedback
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            KnowledgeAssistFeedback.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.AgentAssistantFeedback.KnowledgeAssistFeedback";
                            };
    
                            return KnowledgeAssistFeedback;
                        })();
    
                        return AgentAssistantFeedback;
                    })();
    
                    v2beta1.GetAnswerRecordRequest = (function() {
    
                        /**
                         * Properties of a GetAnswerRecordRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IGetAnswerRecordRequest
                         * @property {string|null} [name] GetAnswerRecordRequest name
                         */
    
                        /**
                         * Constructs a new GetAnswerRecordRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a GetAnswerRecordRequest.
                         * @implements IGetAnswerRecordRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IGetAnswerRecordRequest=} [properties] Properties to set
                         */
                        function GetAnswerRecordRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GetAnswerRecordRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2beta1.GetAnswerRecordRequest
                         * @instance
                         */
                        GetAnswerRecordRequest.prototype.name = "";
    
                        /**
                         * Creates a new GetAnswerRecordRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.GetAnswerRecordRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetAnswerRecordRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.GetAnswerRecordRequest} GetAnswerRecordRequest instance
                         */
                        GetAnswerRecordRequest.create = function create(properties) {
                            return new GetAnswerRecordRequest(properties);
                        };
    
                        /**
                         * Encodes the specified GetAnswerRecordRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GetAnswerRecordRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.GetAnswerRecordRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetAnswerRecordRequest} message GetAnswerRecordRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetAnswerRecordRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GetAnswerRecordRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GetAnswerRecordRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GetAnswerRecordRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetAnswerRecordRequest} message GetAnswerRecordRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetAnswerRecordRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GetAnswerRecordRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.GetAnswerRecordRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.GetAnswerRecordRequest} GetAnswerRecordRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetAnswerRecordRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.GetAnswerRecordRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GetAnswerRecordRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GetAnswerRecordRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.GetAnswerRecordRequest} GetAnswerRecordRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetAnswerRecordRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GetAnswerRecordRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.GetAnswerRecordRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GetAnswerRecordRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a GetAnswerRecordRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.GetAnswerRecordRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.GetAnswerRecordRequest} GetAnswerRecordRequest
                         */
                        GetAnswerRecordRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.GetAnswerRecordRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.GetAnswerRecordRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GetAnswerRecordRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.GetAnswerRecordRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.GetAnswerRecordRequest} message GetAnswerRecordRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GetAnswerRecordRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.name = "";
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            return object;
                        };
    
                        /**
                         * Converts this GetAnswerRecordRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.GetAnswerRecordRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GetAnswerRecordRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GetAnswerRecordRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.GetAnswerRecordRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GetAnswerRecordRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.GetAnswerRecordRequest";
                        };
    
                        return GetAnswerRecordRequest;
                    })();
    
                    v2beta1.ListAnswerRecordsRequest = (function() {
    
                        /**
                         * Properties of a ListAnswerRecordsRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IListAnswerRecordsRequest
                         * @property {string|null} [parent] ListAnswerRecordsRequest parent
                         * @property {string|null} [filter] ListAnswerRecordsRequest filter
                         * @property {number|null} [pageSize] ListAnswerRecordsRequest pageSize
                         * @property {string|null} [pageToken] ListAnswerRecordsRequest pageToken
                         */
    
                        /**
                         * Constructs a new ListAnswerRecordsRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a ListAnswerRecordsRequest.
                         * @implements IListAnswerRecordsRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IListAnswerRecordsRequest=} [properties] Properties to set
                         */
                        function ListAnswerRecordsRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListAnswerRecordsRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.ListAnswerRecordsRequest
                         * @instance
                         */
                        ListAnswerRecordsRequest.prototype.parent = "";
    
                        /**
                         * ListAnswerRecordsRequest filter.
                         * @member {string} filter
                         * @memberof google.cloud.dialogflow.v2beta1.ListAnswerRecordsRequest
                         * @instance
                         */
                        ListAnswerRecordsRequest.prototype.filter = "";
    
                        /**
                         * ListAnswerRecordsRequest pageSize.
                         * @member {number} pageSize
                         * @memberof google.cloud.dialogflow.v2beta1.ListAnswerRecordsRequest
                         * @instance
                         */
                        ListAnswerRecordsRequest.prototype.pageSize = 0;
    
                        /**
                         * ListAnswerRecordsRequest pageToken.
                         * @member {string} pageToken
                         * @memberof google.cloud.dialogflow.v2beta1.ListAnswerRecordsRequest
                         * @instance
                         */
                        ListAnswerRecordsRequest.prototype.pageToken = "";
    
                        /**
                         * Creates a new ListAnswerRecordsRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.ListAnswerRecordsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListAnswerRecordsRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.ListAnswerRecordsRequest} ListAnswerRecordsRequest instance
                         */
                        ListAnswerRecordsRequest.create = function create(properties) {
                            return new ListAnswerRecordsRequest(properties);
                        };
    
                        /**
                         * Encodes the specified ListAnswerRecordsRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListAnswerRecordsRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.ListAnswerRecordsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListAnswerRecordsRequest} message ListAnswerRecordsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListAnswerRecordsRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.filter != null && Object.hasOwnProperty.call(message, "filter"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.filter);
                            if (message.pageSize != null && Object.hasOwnProperty.call(message, "pageSize"))
                                writer.uint32(/* id 3, wireType 0 =*/24).int32(message.pageSize);
                            if (message.pageToken != null && Object.hasOwnProperty.call(message, "pageToken"))
                                writer.uint32(/* id 4, wireType 2 =*/34).string(message.pageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListAnswerRecordsRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListAnswerRecordsRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListAnswerRecordsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListAnswerRecordsRequest} message ListAnswerRecordsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListAnswerRecordsRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListAnswerRecordsRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.ListAnswerRecordsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.ListAnswerRecordsRequest} ListAnswerRecordsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListAnswerRecordsRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ListAnswerRecordsRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.filter = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.pageSize = reader.int32();
                                        break;
                                    }
                                case 4: {
                                        message.pageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListAnswerRecordsRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListAnswerRecordsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.ListAnswerRecordsRequest} ListAnswerRecordsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListAnswerRecordsRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListAnswerRecordsRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.ListAnswerRecordsRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListAnswerRecordsRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.filter != null && message.hasOwnProperty("filter"))
                                if (!$util.isString(message.filter))
                                    return "filter: string expected";
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                if (!$util.isInteger(message.pageSize))
                                    return "pageSize: integer expected";
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                if (!$util.isString(message.pageToken))
                                    return "pageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListAnswerRecordsRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListAnswerRecordsRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.ListAnswerRecordsRequest} ListAnswerRecordsRequest
                         */
                        ListAnswerRecordsRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.ListAnswerRecordsRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.ListAnswerRecordsRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.filter != null)
                                message.filter = String(object.filter);
                            if (object.pageSize != null)
                                message.pageSize = object.pageSize | 0;
                            if (object.pageToken != null)
                                message.pageToken = String(object.pageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListAnswerRecordsRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListAnswerRecordsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ListAnswerRecordsRequest} message ListAnswerRecordsRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListAnswerRecordsRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.filter = "";
                                object.pageSize = 0;
                                object.pageToken = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.filter != null && message.hasOwnProperty("filter"))
                                object.filter = message.filter;
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                object.pageSize = message.pageSize;
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                object.pageToken = message.pageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListAnswerRecordsRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.ListAnswerRecordsRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListAnswerRecordsRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListAnswerRecordsRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.ListAnswerRecordsRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListAnswerRecordsRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ListAnswerRecordsRequest";
                        };
    
                        return ListAnswerRecordsRequest;
                    })();
    
                    v2beta1.ListAnswerRecordsResponse = (function() {
    
                        /**
                         * Properties of a ListAnswerRecordsResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IListAnswerRecordsResponse
                         * @property {Array.<google.cloud.dialogflow.v2beta1.IAnswerRecord>|null} [answerRecords] ListAnswerRecordsResponse answerRecords
                         * @property {string|null} [nextPageToken] ListAnswerRecordsResponse nextPageToken
                         */
    
                        /**
                         * Constructs a new ListAnswerRecordsResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a ListAnswerRecordsResponse.
                         * @implements IListAnswerRecordsResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IListAnswerRecordsResponse=} [properties] Properties to set
                         */
                        function ListAnswerRecordsResponse(properties) {
                            this.answerRecords = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListAnswerRecordsResponse answerRecords.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.IAnswerRecord>} answerRecords
                         * @memberof google.cloud.dialogflow.v2beta1.ListAnswerRecordsResponse
                         * @instance
                         */
                        ListAnswerRecordsResponse.prototype.answerRecords = $util.emptyArray;
    
                        /**
                         * ListAnswerRecordsResponse nextPageToken.
                         * @member {string} nextPageToken
                         * @memberof google.cloud.dialogflow.v2beta1.ListAnswerRecordsResponse
                         * @instance
                         */
                        ListAnswerRecordsResponse.prototype.nextPageToken = "";
    
                        /**
                         * Creates a new ListAnswerRecordsResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.ListAnswerRecordsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListAnswerRecordsResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.ListAnswerRecordsResponse} ListAnswerRecordsResponse instance
                         */
                        ListAnswerRecordsResponse.create = function create(properties) {
                            return new ListAnswerRecordsResponse(properties);
                        };
    
                        /**
                         * Encodes the specified ListAnswerRecordsResponse message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListAnswerRecordsResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.ListAnswerRecordsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListAnswerRecordsResponse} message ListAnswerRecordsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListAnswerRecordsResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.answerRecords != null && message.answerRecords.length)
                                for (var i = 0; i < message.answerRecords.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.AnswerRecord.encode(message.answerRecords[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.nextPageToken != null && Object.hasOwnProperty.call(message, "nextPageToken"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.nextPageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListAnswerRecordsResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListAnswerRecordsResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListAnswerRecordsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListAnswerRecordsResponse} message ListAnswerRecordsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListAnswerRecordsResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListAnswerRecordsResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.ListAnswerRecordsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.ListAnswerRecordsResponse} ListAnswerRecordsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListAnswerRecordsResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ListAnswerRecordsResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.answerRecords && message.answerRecords.length))
                                            message.answerRecords = [];
                                        message.answerRecords.push($root.google.cloud.dialogflow.v2beta1.AnswerRecord.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 2: {
                                        message.nextPageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListAnswerRecordsResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListAnswerRecordsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.ListAnswerRecordsResponse} ListAnswerRecordsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListAnswerRecordsResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListAnswerRecordsResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.ListAnswerRecordsResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListAnswerRecordsResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.answerRecords != null && message.hasOwnProperty("answerRecords")) {
                                if (!Array.isArray(message.answerRecords))
                                    return "answerRecords: array expected";
                                for (var i = 0; i < message.answerRecords.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.AnswerRecord.verify(message.answerRecords[i]);
                                    if (error)
                                        return "answerRecords." + error;
                                }
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                if (!$util.isString(message.nextPageToken))
                                    return "nextPageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListAnswerRecordsResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListAnswerRecordsResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.ListAnswerRecordsResponse} ListAnswerRecordsResponse
                         */
                        ListAnswerRecordsResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.ListAnswerRecordsResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.ListAnswerRecordsResponse();
                            if (object.answerRecords) {
                                if (!Array.isArray(object.answerRecords))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.ListAnswerRecordsResponse.answerRecords: array expected");
                                message.answerRecords = [];
                                for (var i = 0; i < object.answerRecords.length; ++i) {
                                    if (typeof object.answerRecords[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.ListAnswerRecordsResponse.answerRecords: object expected");
                                    message.answerRecords[i] = $root.google.cloud.dialogflow.v2beta1.AnswerRecord.fromObject(object.answerRecords[i]);
                                }
                            }
                            if (object.nextPageToken != null)
                                message.nextPageToken = String(object.nextPageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListAnswerRecordsResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListAnswerRecordsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ListAnswerRecordsResponse} message ListAnswerRecordsResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListAnswerRecordsResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.answerRecords = [];
                            if (options.defaults)
                                object.nextPageToken = "";
                            if (message.answerRecords && message.answerRecords.length) {
                                object.answerRecords = [];
                                for (var j = 0; j < message.answerRecords.length; ++j)
                                    object.answerRecords[j] = $root.google.cloud.dialogflow.v2beta1.AnswerRecord.toObject(message.answerRecords[j], options);
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                object.nextPageToken = message.nextPageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListAnswerRecordsResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.ListAnswerRecordsResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListAnswerRecordsResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListAnswerRecordsResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.ListAnswerRecordsResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListAnswerRecordsResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ListAnswerRecordsResponse";
                        };
    
                        return ListAnswerRecordsResponse;
                    })();
    
                    v2beta1.UpdateAnswerRecordRequest = (function() {
    
                        /**
                         * Properties of an UpdateAnswerRecordRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IUpdateAnswerRecordRequest
                         * @property {google.cloud.dialogflow.v2beta1.IAnswerRecord|null} [answerRecord] UpdateAnswerRecordRequest answerRecord
                         * @property {google.protobuf.IFieldMask|null} [updateMask] UpdateAnswerRecordRequest updateMask
                         */
    
                        /**
                         * Constructs a new UpdateAnswerRecordRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an UpdateAnswerRecordRequest.
                         * @implements IUpdateAnswerRecordRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateAnswerRecordRequest=} [properties] Properties to set
                         */
                        function UpdateAnswerRecordRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * UpdateAnswerRecordRequest answerRecord.
                         * @member {google.cloud.dialogflow.v2beta1.IAnswerRecord|null|undefined} answerRecord
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateAnswerRecordRequest
                         * @instance
                         */
                        UpdateAnswerRecordRequest.prototype.answerRecord = null;
    
                        /**
                         * UpdateAnswerRecordRequest updateMask.
                         * @member {google.protobuf.IFieldMask|null|undefined} updateMask
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateAnswerRecordRequest
                         * @instance
                         */
                        UpdateAnswerRecordRequest.prototype.updateMask = null;
    
                        /**
                         * Creates a new UpdateAnswerRecordRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateAnswerRecordRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateAnswerRecordRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.UpdateAnswerRecordRequest} UpdateAnswerRecordRequest instance
                         */
                        UpdateAnswerRecordRequest.create = function create(properties) {
                            return new UpdateAnswerRecordRequest(properties);
                        };
    
                        /**
                         * Encodes the specified UpdateAnswerRecordRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.UpdateAnswerRecordRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateAnswerRecordRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateAnswerRecordRequest} message UpdateAnswerRecordRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UpdateAnswerRecordRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.answerRecord != null && Object.hasOwnProperty.call(message, "answerRecord"))
                                $root.google.cloud.dialogflow.v2beta1.AnswerRecord.encode(message.answerRecord, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.updateMask != null && Object.hasOwnProperty.call(message, "updateMask"))
                                $root.google.protobuf.FieldMask.encode(message.updateMask, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified UpdateAnswerRecordRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.UpdateAnswerRecordRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateAnswerRecordRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateAnswerRecordRequest} message UpdateAnswerRecordRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UpdateAnswerRecordRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an UpdateAnswerRecordRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateAnswerRecordRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.UpdateAnswerRecordRequest} UpdateAnswerRecordRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UpdateAnswerRecordRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.UpdateAnswerRecordRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.answerRecord = $root.google.cloud.dialogflow.v2beta1.AnswerRecord.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.updateMask = $root.google.protobuf.FieldMask.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an UpdateAnswerRecordRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateAnswerRecordRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.UpdateAnswerRecordRequest} UpdateAnswerRecordRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UpdateAnswerRecordRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an UpdateAnswerRecordRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateAnswerRecordRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        UpdateAnswerRecordRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.answerRecord != null && message.hasOwnProperty("answerRecord")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.AnswerRecord.verify(message.answerRecord);
                                if (error)
                                    return "answerRecord." + error;
                            }
                            if (message.updateMask != null && message.hasOwnProperty("updateMask")) {
                                var error = $root.google.protobuf.FieldMask.verify(message.updateMask);
                                if (error)
                                    return "updateMask." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates an UpdateAnswerRecordRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateAnswerRecordRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.UpdateAnswerRecordRequest} UpdateAnswerRecordRequest
                         */
                        UpdateAnswerRecordRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.UpdateAnswerRecordRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.UpdateAnswerRecordRequest();
                            if (object.answerRecord != null) {
                                if (typeof object.answerRecord !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.UpdateAnswerRecordRequest.answerRecord: object expected");
                                message.answerRecord = $root.google.cloud.dialogflow.v2beta1.AnswerRecord.fromObject(object.answerRecord);
                            }
                            if (object.updateMask != null) {
                                if (typeof object.updateMask !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.UpdateAnswerRecordRequest.updateMask: object expected");
                                message.updateMask = $root.google.protobuf.FieldMask.fromObject(object.updateMask);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an UpdateAnswerRecordRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateAnswerRecordRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.UpdateAnswerRecordRequest} message UpdateAnswerRecordRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        UpdateAnswerRecordRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.answerRecord = null;
                                object.updateMask = null;
                            }
                            if (message.answerRecord != null && message.hasOwnProperty("answerRecord"))
                                object.answerRecord = $root.google.cloud.dialogflow.v2beta1.AnswerRecord.toObject(message.answerRecord, options);
                            if (message.updateMask != null && message.hasOwnProperty("updateMask"))
                                object.updateMask = $root.google.protobuf.FieldMask.toObject(message.updateMask, options);
                            return object;
                        };
    
                        /**
                         * Converts this UpdateAnswerRecordRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateAnswerRecordRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        UpdateAnswerRecordRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for UpdateAnswerRecordRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateAnswerRecordRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        UpdateAnswerRecordRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.UpdateAnswerRecordRequest";
                        };
    
                        return UpdateAnswerRecordRequest;
                    })();
    
                    v2beta1.Participants = (function() {
    
                        /**
                         * Constructs a new Participants service.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a Participants
                         * @extends $protobuf.rpc.Service
                         * @constructor
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         */
                        function Participants(rpcImpl, requestDelimited, responseDelimited) {
                            $protobuf.rpc.Service.call(this, rpcImpl, requestDelimited, responseDelimited);
                        }
    
                        (Participants.prototype = Object.create($protobuf.rpc.Service.prototype)).constructor = Participants;
    
                        /**
                         * Creates new Participants service using the specified rpc implementation.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.Participants
                         * @static
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         * @returns {Participants} RPC service. Useful where requests and/or responses are streamed.
                         */
                        Participants.create = function create(rpcImpl, requestDelimited, responseDelimited) {
                            return new this(rpcImpl, requestDelimited, responseDelimited);
                        };
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Participants|createParticipant}.
                         * @memberof google.cloud.dialogflow.v2beta1.Participants
                         * @typedef CreateParticipantCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.Participant} [response] Participant
                         */
    
                        /**
                         * Calls CreateParticipant.
                         * @function createParticipant
                         * @memberof google.cloud.dialogflow.v2beta1.Participants
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.ICreateParticipantRequest} request CreateParticipantRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Participants.CreateParticipantCallback} callback Node-style callback called with the error, if any, and Participant
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Participants.prototype.createParticipant = function createParticipant(request, callback) {
                            return this.rpcCall(createParticipant, $root.google.cloud.dialogflow.v2beta1.CreateParticipantRequest, $root.google.cloud.dialogflow.v2beta1.Participant, request, callback);
                        }, "name", { value: "CreateParticipant" });
    
                        /**
                         * Calls CreateParticipant.
                         * @function createParticipant
                         * @memberof google.cloud.dialogflow.v2beta1.Participants
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.ICreateParticipantRequest} request CreateParticipantRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.Participant>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Participants|getParticipant}.
                         * @memberof google.cloud.dialogflow.v2beta1.Participants
                         * @typedef GetParticipantCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.Participant} [response] Participant
                         */
    
                        /**
                         * Calls GetParticipant.
                         * @function getParticipant
                         * @memberof google.cloud.dialogflow.v2beta1.Participants
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IGetParticipantRequest} request GetParticipantRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Participants.GetParticipantCallback} callback Node-style callback called with the error, if any, and Participant
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Participants.prototype.getParticipant = function getParticipant(request, callback) {
                            return this.rpcCall(getParticipant, $root.google.cloud.dialogflow.v2beta1.GetParticipantRequest, $root.google.cloud.dialogflow.v2beta1.Participant, request, callback);
                        }, "name", { value: "GetParticipant" });
    
                        /**
                         * Calls GetParticipant.
                         * @function getParticipant
                         * @memberof google.cloud.dialogflow.v2beta1.Participants
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IGetParticipantRequest} request GetParticipantRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.Participant>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Participants|listParticipants}.
                         * @memberof google.cloud.dialogflow.v2beta1.Participants
                         * @typedef ListParticipantsCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.ListParticipantsResponse} [response] ListParticipantsResponse
                         */
    
                        /**
                         * Calls ListParticipants.
                         * @function listParticipants
                         * @memberof google.cloud.dialogflow.v2beta1.Participants
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IListParticipantsRequest} request ListParticipantsRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Participants.ListParticipantsCallback} callback Node-style callback called with the error, if any, and ListParticipantsResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Participants.prototype.listParticipants = function listParticipants(request, callback) {
                            return this.rpcCall(listParticipants, $root.google.cloud.dialogflow.v2beta1.ListParticipantsRequest, $root.google.cloud.dialogflow.v2beta1.ListParticipantsResponse, request, callback);
                        }, "name", { value: "ListParticipants" });
    
                        /**
                         * Calls ListParticipants.
                         * @function listParticipants
                         * @memberof google.cloud.dialogflow.v2beta1.Participants
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IListParticipantsRequest} request ListParticipantsRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.ListParticipantsResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Participants|updateParticipant}.
                         * @memberof google.cloud.dialogflow.v2beta1.Participants
                         * @typedef UpdateParticipantCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.Participant} [response] Participant
                         */
    
                        /**
                         * Calls UpdateParticipant.
                         * @function updateParticipant
                         * @memberof google.cloud.dialogflow.v2beta1.Participants
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateParticipantRequest} request UpdateParticipantRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Participants.UpdateParticipantCallback} callback Node-style callback called with the error, if any, and Participant
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Participants.prototype.updateParticipant = function updateParticipant(request, callback) {
                            return this.rpcCall(updateParticipant, $root.google.cloud.dialogflow.v2beta1.UpdateParticipantRequest, $root.google.cloud.dialogflow.v2beta1.Participant, request, callback);
                        }, "name", { value: "UpdateParticipant" });
    
                        /**
                         * Calls UpdateParticipant.
                         * @function updateParticipant
                         * @memberof google.cloud.dialogflow.v2beta1.Participants
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateParticipantRequest} request UpdateParticipantRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.Participant>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Participants|analyzeContent}.
                         * @memberof google.cloud.dialogflow.v2beta1.Participants
                         * @typedef AnalyzeContentCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.AnalyzeContentResponse} [response] AnalyzeContentResponse
                         */
    
                        /**
                         * Calls AnalyzeContent.
                         * @function analyzeContent
                         * @memberof google.cloud.dialogflow.v2beta1.Participants
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IAnalyzeContentRequest} request AnalyzeContentRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Participants.AnalyzeContentCallback} callback Node-style callback called with the error, if any, and AnalyzeContentResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Participants.prototype.analyzeContent = function analyzeContent(request, callback) {
                            return this.rpcCall(analyzeContent, $root.google.cloud.dialogflow.v2beta1.AnalyzeContentRequest, $root.google.cloud.dialogflow.v2beta1.AnalyzeContentResponse, request, callback);
                        }, "name", { value: "AnalyzeContent" });
    
                        /**
                         * Calls AnalyzeContent.
                         * @function analyzeContent
                         * @memberof google.cloud.dialogflow.v2beta1.Participants
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IAnalyzeContentRequest} request AnalyzeContentRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.AnalyzeContentResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Participants|streamingAnalyzeContent}.
                         * @memberof google.cloud.dialogflow.v2beta1.Participants
                         * @typedef StreamingAnalyzeContentCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentResponse} [response] StreamingAnalyzeContentResponse
                         */
    
                        /**
                         * Calls StreamingAnalyzeContent.
                         * @function streamingAnalyzeContent
                         * @memberof google.cloud.dialogflow.v2beta1.Participants
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IStreamingAnalyzeContentRequest} request StreamingAnalyzeContentRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Participants.StreamingAnalyzeContentCallback} callback Node-style callback called with the error, if any, and StreamingAnalyzeContentResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Participants.prototype.streamingAnalyzeContent = function streamingAnalyzeContent(request, callback) {
                            return this.rpcCall(streamingAnalyzeContent, $root.google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentRequest, $root.google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentResponse, request, callback);
                        }, "name", { value: "StreamingAnalyzeContent" });
    
                        /**
                         * Calls StreamingAnalyzeContent.
                         * @function streamingAnalyzeContent
                         * @memberof google.cloud.dialogflow.v2beta1.Participants
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IStreamingAnalyzeContentRequest} request StreamingAnalyzeContentRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Participants|suggestArticles}.
                         * @memberof google.cloud.dialogflow.v2beta1.Participants
                         * @typedef SuggestArticlesCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.SuggestArticlesResponse} [response] SuggestArticlesResponse
                         */
    
                        /**
                         * Calls SuggestArticles.
                         * @function suggestArticles
                         * @memberof google.cloud.dialogflow.v2beta1.Participants
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestArticlesRequest} request SuggestArticlesRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Participants.SuggestArticlesCallback} callback Node-style callback called with the error, if any, and SuggestArticlesResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Participants.prototype.suggestArticles = function suggestArticles(request, callback) {
                            return this.rpcCall(suggestArticles, $root.google.cloud.dialogflow.v2beta1.SuggestArticlesRequest, $root.google.cloud.dialogflow.v2beta1.SuggestArticlesResponse, request, callback);
                        }, "name", { value: "SuggestArticles" });
    
                        /**
                         * Calls SuggestArticles.
                         * @function suggestArticles
                         * @memberof google.cloud.dialogflow.v2beta1.Participants
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestArticlesRequest} request SuggestArticlesRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.SuggestArticlesResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Participants|suggestFaqAnswers}.
                         * @memberof google.cloud.dialogflow.v2beta1.Participants
                         * @typedef SuggestFaqAnswersCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.SuggestFaqAnswersResponse} [response] SuggestFaqAnswersResponse
                         */
    
                        /**
                         * Calls SuggestFaqAnswers.
                         * @function suggestFaqAnswers
                         * @memberof google.cloud.dialogflow.v2beta1.Participants
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestFaqAnswersRequest} request SuggestFaqAnswersRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Participants.SuggestFaqAnswersCallback} callback Node-style callback called with the error, if any, and SuggestFaqAnswersResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Participants.prototype.suggestFaqAnswers = function suggestFaqAnswers(request, callback) {
                            return this.rpcCall(suggestFaqAnswers, $root.google.cloud.dialogflow.v2beta1.SuggestFaqAnswersRequest, $root.google.cloud.dialogflow.v2beta1.SuggestFaqAnswersResponse, request, callback);
                        }, "name", { value: "SuggestFaqAnswers" });
    
                        /**
                         * Calls SuggestFaqAnswers.
                         * @function suggestFaqAnswers
                         * @memberof google.cloud.dialogflow.v2beta1.Participants
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestFaqAnswersRequest} request SuggestFaqAnswersRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.SuggestFaqAnswersResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Participants|suggestSmartReplies}.
                         * @memberof google.cloud.dialogflow.v2beta1.Participants
                         * @typedef SuggestSmartRepliesCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.SuggestSmartRepliesResponse} [response] SuggestSmartRepliesResponse
                         */
    
                        /**
                         * Calls SuggestSmartReplies.
                         * @function suggestSmartReplies
                         * @memberof google.cloud.dialogflow.v2beta1.Participants
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestSmartRepliesRequest} request SuggestSmartRepliesRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Participants.SuggestSmartRepliesCallback} callback Node-style callback called with the error, if any, and SuggestSmartRepliesResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Participants.prototype.suggestSmartReplies = function suggestSmartReplies(request, callback) {
                            return this.rpcCall(suggestSmartReplies, $root.google.cloud.dialogflow.v2beta1.SuggestSmartRepliesRequest, $root.google.cloud.dialogflow.v2beta1.SuggestSmartRepliesResponse, request, callback);
                        }, "name", { value: "SuggestSmartReplies" });
    
                        /**
                         * Calls SuggestSmartReplies.
                         * @function suggestSmartReplies
                         * @memberof google.cloud.dialogflow.v2beta1.Participants
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestSmartRepliesRequest} request SuggestSmartRepliesRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.SuggestSmartRepliesResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Participants|suggestKnowledgeAssist}.
                         * @memberof google.cloud.dialogflow.v2beta1.Participants
                         * @typedef SuggestKnowledgeAssistCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistResponse} [response] SuggestKnowledgeAssistResponse
                         */
    
                        /**
                         * Calls SuggestKnowledgeAssist.
                         * @function suggestKnowledgeAssist
                         * @memberof google.cloud.dialogflow.v2beta1.Participants
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestKnowledgeAssistRequest} request SuggestKnowledgeAssistRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Participants.SuggestKnowledgeAssistCallback} callback Node-style callback called with the error, if any, and SuggestKnowledgeAssistResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Participants.prototype.suggestKnowledgeAssist = function suggestKnowledgeAssist(request, callback) {
                            return this.rpcCall(suggestKnowledgeAssist, $root.google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistRequest, $root.google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistResponse, request, callback);
                        }, "name", { value: "SuggestKnowledgeAssist" });
    
                        /**
                         * Calls SuggestKnowledgeAssist.
                         * @function suggestKnowledgeAssist
                         * @memberof google.cloud.dialogflow.v2beta1.Participants
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestKnowledgeAssistRequest} request SuggestKnowledgeAssistRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Participants|listSuggestions}.
                         * @memberof google.cloud.dialogflow.v2beta1.Participants
                         * @typedef ListSuggestionsCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.ListSuggestionsResponse} [response] ListSuggestionsResponse
                         */
    
                        /**
                         * Calls ListSuggestions.
                         * @function listSuggestions
                         * @memberof google.cloud.dialogflow.v2beta1.Participants
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IListSuggestionsRequest} request ListSuggestionsRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Participants.ListSuggestionsCallback} callback Node-style callback called with the error, if any, and ListSuggestionsResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Participants.prototype.listSuggestions = function listSuggestions(request, callback) {
                            return this.rpcCall(listSuggestions, $root.google.cloud.dialogflow.v2beta1.ListSuggestionsRequest, $root.google.cloud.dialogflow.v2beta1.ListSuggestionsResponse, request, callback);
                        }, "name", { value: "ListSuggestions" });
    
                        /**
                         * Calls ListSuggestions.
                         * @function listSuggestions
                         * @memberof google.cloud.dialogflow.v2beta1.Participants
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IListSuggestionsRequest} request ListSuggestionsRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.ListSuggestionsResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Participants|compileSuggestion}.
                         * @memberof google.cloud.dialogflow.v2beta1.Participants
                         * @typedef CompileSuggestionCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.CompileSuggestionResponse} [response] CompileSuggestionResponse
                         */
    
                        /**
                         * Calls CompileSuggestion.
                         * @function compileSuggestion
                         * @memberof google.cloud.dialogflow.v2beta1.Participants
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.ICompileSuggestionRequest} request CompileSuggestionRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Participants.CompileSuggestionCallback} callback Node-style callback called with the error, if any, and CompileSuggestionResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Participants.prototype.compileSuggestion = function compileSuggestion(request, callback) {
                            return this.rpcCall(compileSuggestion, $root.google.cloud.dialogflow.v2beta1.CompileSuggestionRequest, $root.google.cloud.dialogflow.v2beta1.CompileSuggestionResponse, request, callback);
                        }, "name", { value: "CompileSuggestion" });
    
                        /**
                         * Calls CompileSuggestion.
                         * @function compileSuggestion
                         * @memberof google.cloud.dialogflow.v2beta1.Participants
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.ICompileSuggestionRequest} request CompileSuggestionRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.CompileSuggestionResponse>} Promise
                         * @variation 2
                         */
    
                        return Participants;
                    })();
    
                    v2beta1.Participant = (function() {
    
                        /**
                         * Properties of a Participant.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IParticipant
                         * @property {string|null} [name] Participant name
                         * @property {google.cloud.dialogflow.v2beta1.Participant.Role|null} [role] Participant role
                         * @property {string|null} [obfuscatedExternalUserId] Participant obfuscatedExternalUserId
                         * @property {Object.<string,string>|null} [documentsMetadataFilters] Participant documentsMetadataFilters
                         */
    
                        /**
                         * Constructs a new Participant.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a Participant.
                         * @implements IParticipant
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IParticipant=} [properties] Properties to set
                         */
                        function Participant(properties) {
                            this.documentsMetadataFilters = {};
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * Participant name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2beta1.Participant
                         * @instance
                         */
                        Participant.prototype.name = "";
    
                        /**
                         * Participant role.
                         * @member {google.cloud.dialogflow.v2beta1.Participant.Role} role
                         * @memberof google.cloud.dialogflow.v2beta1.Participant
                         * @instance
                         */
                        Participant.prototype.role = 0;
    
                        /**
                         * Participant obfuscatedExternalUserId.
                         * @member {string} obfuscatedExternalUserId
                         * @memberof google.cloud.dialogflow.v2beta1.Participant
                         * @instance
                         */
                        Participant.prototype.obfuscatedExternalUserId = "";
    
                        /**
                         * Participant documentsMetadataFilters.
                         * @member {Object.<string,string>} documentsMetadataFilters
                         * @memberof google.cloud.dialogflow.v2beta1.Participant
                         * @instance
                         */
                        Participant.prototype.documentsMetadataFilters = $util.emptyObject;
    
                        /**
                         * Creates a new Participant instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.Participant
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IParticipant=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.Participant} Participant instance
                         */
                        Participant.create = function create(properties) {
                            return new Participant(properties);
                        };
    
                        /**
                         * Encodes the specified Participant message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Participant.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.Participant
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IParticipant} message Participant message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        Participant.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            if (message.role != null && Object.hasOwnProperty.call(message, "role"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.role);
                            if (message.obfuscatedExternalUserId != null && Object.hasOwnProperty.call(message, "obfuscatedExternalUserId"))
                                writer.uint32(/* id 7, wireType 2 =*/58).string(message.obfuscatedExternalUserId);
                            if (message.documentsMetadataFilters != null && Object.hasOwnProperty.call(message, "documentsMetadataFilters"))
                                for (var keys = Object.keys(message.documentsMetadataFilters), i = 0; i < keys.length; ++i)
                                    writer.uint32(/* id 8, wireType 2 =*/66).fork().uint32(/* id 1, wireType 2 =*/10).string(keys[i]).uint32(/* id 2, wireType 2 =*/18).string(message.documentsMetadataFilters[keys[i]]).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified Participant message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Participant.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.Participant
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IParticipant} message Participant message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        Participant.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a Participant message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.Participant
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.Participant} Participant
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        Participant.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Participant(), key, value;
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.role = reader.int32();
                                        break;
                                    }
                                case 7: {
                                        message.obfuscatedExternalUserId = reader.string();
                                        break;
                                    }
                                case 8: {
                                        if (message.documentsMetadataFilters === $util.emptyObject)
                                            message.documentsMetadataFilters = {};
                                        var end2 = reader.uint32() + reader.pos;
                                        key = "";
                                        value = "";
                                        while (reader.pos < end2) {
                                            var tag2 = reader.uint32();
                                            switch (tag2 >>> 3) {
                                            case 1:
                                                key = reader.string();
                                                break;
                                            case 2:
                                                value = reader.string();
                                                break;
                                            default:
                                                reader.skipType(tag2 & 7);
                                                break;
                                            }
                                        }
                                        message.documentsMetadataFilters[key] = value;
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a Participant message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.Participant
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.Participant} Participant
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        Participant.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a Participant message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.Participant
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        Participant.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            if (message.role != null && message.hasOwnProperty("role"))
                                switch (message.role) {
                                default:
                                    return "role: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                    break;
                                }
                            if (message.obfuscatedExternalUserId != null && message.hasOwnProperty("obfuscatedExternalUserId"))
                                if (!$util.isString(message.obfuscatedExternalUserId))
                                    return "obfuscatedExternalUserId: string expected";
                            if (message.documentsMetadataFilters != null && message.hasOwnProperty("documentsMetadataFilters")) {
                                if (!$util.isObject(message.documentsMetadataFilters))
                                    return "documentsMetadataFilters: object expected";
                                var key = Object.keys(message.documentsMetadataFilters);
                                for (var i = 0; i < key.length; ++i)
                                    if (!$util.isString(message.documentsMetadataFilters[key[i]]))
                                        return "documentsMetadataFilters: string{k:string} expected";
                            }
                            return null;
                        };
    
                        /**
                         * Creates a Participant message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.Participant
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.Participant} Participant
                         */
                        Participant.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.Participant)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.Participant();
                            if (object.name != null)
                                message.name = String(object.name);
                            switch (object.role) {
                            default:
                                if (typeof object.role === "number") {
                                    message.role = object.role;
                                    break;
                                }
                                break;
                            case "ROLE_UNSPECIFIED":
                            case 0:
                                message.role = 0;
                                break;
                            case "HUMAN_AGENT":
                            case 1:
                                message.role = 1;
                                break;
                            case "AUTOMATED_AGENT":
                            case 2:
                                message.role = 2;
                                break;
                            case "END_USER":
                            case 3:
                                message.role = 3;
                                break;
                            }
                            if (object.obfuscatedExternalUserId != null)
                                message.obfuscatedExternalUserId = String(object.obfuscatedExternalUserId);
                            if (object.documentsMetadataFilters) {
                                if (typeof object.documentsMetadataFilters !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.Participant.documentsMetadataFilters: object expected");
                                message.documentsMetadataFilters = {};
                                for (var keys = Object.keys(object.documentsMetadataFilters), i = 0; i < keys.length; ++i)
                                    message.documentsMetadataFilters[keys[i]] = String(object.documentsMetadataFilters[keys[i]]);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a Participant message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.Participant
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.Participant} message Participant
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        Participant.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.objects || options.defaults)
                                object.documentsMetadataFilters = {};
                            if (options.defaults) {
                                object.name = "";
                                object.role = options.enums === String ? "ROLE_UNSPECIFIED" : 0;
                                object.obfuscatedExternalUserId = "";
                            }
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            if (message.role != null && message.hasOwnProperty("role"))
                                object.role = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.Participant.Role[message.role] === undefined ? message.role : $root.google.cloud.dialogflow.v2beta1.Participant.Role[message.role] : message.role;
                            if (message.obfuscatedExternalUserId != null && message.hasOwnProperty("obfuscatedExternalUserId"))
                                object.obfuscatedExternalUserId = message.obfuscatedExternalUserId;
                            var keys2;
                            if (message.documentsMetadataFilters && (keys2 = Object.keys(message.documentsMetadataFilters)).length) {
                                object.documentsMetadataFilters = {};
                                for (var j = 0; j < keys2.length; ++j)
                                    object.documentsMetadataFilters[keys2[j]] = message.documentsMetadataFilters[keys2[j]];
                            }
                            return object;
                        };
    
                        /**
                         * Converts this Participant to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.Participant
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        Participant.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for Participant
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.Participant
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        Participant.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Participant";
                        };
    
                        /**
                         * Role enum.
                         * @name google.cloud.dialogflow.v2beta1.Participant.Role
                         * @enum {number}
                         * @property {number} ROLE_UNSPECIFIED=0 ROLE_UNSPECIFIED value
                         * @property {number} HUMAN_AGENT=1 HUMAN_AGENT value
                         * @property {number} AUTOMATED_AGENT=2 AUTOMATED_AGENT value
                         * @property {number} END_USER=3 END_USER value
                         */
                        Participant.Role = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "ROLE_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "HUMAN_AGENT"] = 1;
                            values[valuesById[2] = "AUTOMATED_AGENT"] = 2;
                            values[valuesById[3] = "END_USER"] = 3;
                            return values;
                        })();
    
                        return Participant;
                    })();
    
                    v2beta1.Message = (function() {
    
                        /**
                         * Properties of a Message.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IMessage
                         * @property {string|null} [name] Message name
                         * @property {string|null} [content] Message content
                         * @property {Array.<google.cloud.dialogflow.v2beta1.IResponseMessage>|null} [responseMessages] Message responseMessages
                         * @property {string|null} [languageCode] Message languageCode
                         * @property {string|null} [participant] Message participant
                         * @property {google.cloud.dialogflow.v2beta1.Participant.Role|null} [participantRole] Message participantRole
                         * @property {google.protobuf.ITimestamp|null} [createTime] Message createTime
                         * @property {google.protobuf.ITimestamp|null} [sendTime] Message sendTime
                         * @property {google.cloud.dialogflow.v2beta1.IMessageAnnotation|null} [messageAnnotation] Message messageAnnotation
                         * @property {google.cloud.dialogflow.v2beta1.ISentimentAnalysisResult|null} [sentimentAnalysis] Message sentimentAnalysis
                         */
    
                        /**
                         * Constructs a new Message.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a Message.
                         * @implements IMessage
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IMessage=} [properties] Properties to set
                         */
                        function Message(properties) {
                            this.responseMessages = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * Message name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2beta1.Message
                         * @instance
                         */
                        Message.prototype.name = "";
    
                        /**
                         * Message content.
                         * @member {string} content
                         * @memberof google.cloud.dialogflow.v2beta1.Message
                         * @instance
                         */
                        Message.prototype.content = "";
    
                        /**
                         * Message responseMessages.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.IResponseMessage>} responseMessages
                         * @memberof google.cloud.dialogflow.v2beta1.Message
                         * @instance
                         */
                        Message.prototype.responseMessages = $util.emptyArray;
    
                        /**
                         * Message languageCode.
                         * @member {string} languageCode
                         * @memberof google.cloud.dialogflow.v2beta1.Message
                         * @instance
                         */
                        Message.prototype.languageCode = "";
    
                        /**
                         * Message participant.
                         * @member {string} participant
                         * @memberof google.cloud.dialogflow.v2beta1.Message
                         * @instance
                         */
                        Message.prototype.participant = "";
    
                        /**
                         * Message participantRole.
                         * @member {google.cloud.dialogflow.v2beta1.Participant.Role} participantRole
                         * @memberof google.cloud.dialogflow.v2beta1.Message
                         * @instance
                         */
                        Message.prototype.participantRole = 0;
    
                        /**
                         * Message createTime.
                         * @member {google.protobuf.ITimestamp|null|undefined} createTime
                         * @memberof google.cloud.dialogflow.v2beta1.Message
                         * @instance
                         */
                        Message.prototype.createTime = null;
    
                        /**
                         * Message sendTime.
                         * @member {google.protobuf.ITimestamp|null|undefined} sendTime
                         * @memberof google.cloud.dialogflow.v2beta1.Message
                         * @instance
                         */
                        Message.prototype.sendTime = null;
    
                        /**
                         * Message messageAnnotation.
                         * @member {google.cloud.dialogflow.v2beta1.IMessageAnnotation|null|undefined} messageAnnotation
                         * @memberof google.cloud.dialogflow.v2beta1.Message
                         * @instance
                         */
                        Message.prototype.messageAnnotation = null;
    
                        /**
                         * Message sentimentAnalysis.
                         * @member {google.cloud.dialogflow.v2beta1.ISentimentAnalysisResult|null|undefined} sentimentAnalysis
                         * @memberof google.cloud.dialogflow.v2beta1.Message
                         * @instance
                         */
                        Message.prototype.sentimentAnalysis = null;
    
                        /**
                         * Creates a new Message instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.Message
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IMessage=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.Message} Message instance
                         */
                        Message.create = function create(properties) {
                            return new Message(properties);
                        };
    
                        /**
                         * Encodes the specified Message message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Message.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.Message
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IMessage} message Message message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        Message.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            if (message.content != null && Object.hasOwnProperty.call(message, "content"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.content);
                            if (message.languageCode != null && Object.hasOwnProperty.call(message, "languageCode"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.languageCode);
                            if (message.participant != null && Object.hasOwnProperty.call(message, "participant"))
                                writer.uint32(/* id 4, wireType 2 =*/34).string(message.participant);
                            if (message.participantRole != null && Object.hasOwnProperty.call(message, "participantRole"))
                                writer.uint32(/* id 5, wireType 0 =*/40).int32(message.participantRole);
                            if (message.createTime != null && Object.hasOwnProperty.call(message, "createTime"))
                                $root.google.protobuf.Timestamp.encode(message.createTime, writer.uint32(/* id 6, wireType 2 =*/50).fork()).ldelim();
                            if (message.messageAnnotation != null && Object.hasOwnProperty.call(message, "messageAnnotation"))
                                $root.google.cloud.dialogflow.v2beta1.MessageAnnotation.encode(message.messageAnnotation, writer.uint32(/* id 7, wireType 2 =*/58).fork()).ldelim();
                            if (message.sentimentAnalysis != null && Object.hasOwnProperty.call(message, "sentimentAnalysis"))
                                $root.google.cloud.dialogflow.v2beta1.SentimentAnalysisResult.encode(message.sentimentAnalysis, writer.uint32(/* id 8, wireType 2 =*/66).fork()).ldelim();
                            if (message.sendTime != null && Object.hasOwnProperty.call(message, "sendTime"))
                                $root.google.protobuf.Timestamp.encode(message.sendTime, writer.uint32(/* id 9, wireType 2 =*/74).fork()).ldelim();
                            if (message.responseMessages != null && message.responseMessages.length)
                                for (var i = 0; i < message.responseMessages.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.ResponseMessage.encode(message.responseMessages[i], writer.uint32(/* id 11, wireType 2 =*/90).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified Message message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Message.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.Message
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IMessage} message Message message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        Message.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a Message message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.Message
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.Message} Message
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        Message.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Message();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.content = reader.string();
                                        break;
                                    }
                                case 11: {
                                        if (!(message.responseMessages && message.responseMessages.length))
                                            message.responseMessages = [];
                                        message.responseMessages.push($root.google.cloud.dialogflow.v2beta1.ResponseMessage.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 3: {
                                        message.languageCode = reader.string();
                                        break;
                                    }
                                case 4: {
                                        message.participant = reader.string();
                                        break;
                                    }
                                case 5: {
                                        message.participantRole = reader.int32();
                                        break;
                                    }
                                case 6: {
                                        message.createTime = $root.google.protobuf.Timestamp.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 9: {
                                        message.sendTime = $root.google.protobuf.Timestamp.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 7: {
                                        message.messageAnnotation = $root.google.cloud.dialogflow.v2beta1.MessageAnnotation.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 8: {
                                        message.sentimentAnalysis = $root.google.cloud.dialogflow.v2beta1.SentimentAnalysisResult.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a Message message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.Message
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.Message} Message
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        Message.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a Message message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.Message
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        Message.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            if (message.content != null && message.hasOwnProperty("content"))
                                if (!$util.isString(message.content))
                                    return "content: string expected";
                            if (message.responseMessages != null && message.hasOwnProperty("responseMessages")) {
                                if (!Array.isArray(message.responseMessages))
                                    return "responseMessages: array expected";
                                for (var i = 0; i < message.responseMessages.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.ResponseMessage.verify(message.responseMessages[i]);
                                    if (error)
                                        return "responseMessages." + error;
                                }
                            }
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                if (!$util.isString(message.languageCode))
                                    return "languageCode: string expected";
                            if (message.participant != null && message.hasOwnProperty("participant"))
                                if (!$util.isString(message.participant))
                                    return "participant: string expected";
                            if (message.participantRole != null && message.hasOwnProperty("participantRole"))
                                switch (message.participantRole) {
                                default:
                                    return "participantRole: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                    break;
                                }
                            if (message.createTime != null && message.hasOwnProperty("createTime")) {
                                var error = $root.google.protobuf.Timestamp.verify(message.createTime);
                                if (error)
                                    return "createTime." + error;
                            }
                            if (message.sendTime != null && message.hasOwnProperty("sendTime")) {
                                var error = $root.google.protobuf.Timestamp.verify(message.sendTime);
                                if (error)
                                    return "sendTime." + error;
                            }
                            if (message.messageAnnotation != null && message.hasOwnProperty("messageAnnotation")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.MessageAnnotation.verify(message.messageAnnotation);
                                if (error)
                                    return "messageAnnotation." + error;
                            }
                            if (message.sentimentAnalysis != null && message.hasOwnProperty("sentimentAnalysis")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.SentimentAnalysisResult.verify(message.sentimentAnalysis);
                                if (error)
                                    return "sentimentAnalysis." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a Message message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.Message
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.Message} Message
                         */
                        Message.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.Message)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.Message();
                            if (object.name != null)
                                message.name = String(object.name);
                            if (object.content != null)
                                message.content = String(object.content);
                            if (object.responseMessages) {
                                if (!Array.isArray(object.responseMessages))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.Message.responseMessages: array expected");
                                message.responseMessages = [];
                                for (var i = 0; i < object.responseMessages.length; ++i) {
                                    if (typeof object.responseMessages[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.Message.responseMessages: object expected");
                                    message.responseMessages[i] = $root.google.cloud.dialogflow.v2beta1.ResponseMessage.fromObject(object.responseMessages[i]);
                                }
                            }
                            if (object.languageCode != null)
                                message.languageCode = String(object.languageCode);
                            if (object.participant != null)
                                message.participant = String(object.participant);
                            switch (object.participantRole) {
                            default:
                                if (typeof object.participantRole === "number") {
                                    message.participantRole = object.participantRole;
                                    break;
                                }
                                break;
                            case "ROLE_UNSPECIFIED":
                            case 0:
                                message.participantRole = 0;
                                break;
                            case "HUMAN_AGENT":
                            case 1:
                                message.participantRole = 1;
                                break;
                            case "AUTOMATED_AGENT":
                            case 2:
                                message.participantRole = 2;
                                break;
                            case "END_USER":
                            case 3:
                                message.participantRole = 3;
                                break;
                            }
                            if (object.createTime != null) {
                                if (typeof object.createTime !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.Message.createTime: object expected");
                                message.createTime = $root.google.protobuf.Timestamp.fromObject(object.createTime);
                            }
                            if (object.sendTime != null) {
                                if (typeof object.sendTime !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.Message.sendTime: object expected");
                                message.sendTime = $root.google.protobuf.Timestamp.fromObject(object.sendTime);
                            }
                            if (object.messageAnnotation != null) {
                                if (typeof object.messageAnnotation !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.Message.messageAnnotation: object expected");
                                message.messageAnnotation = $root.google.cloud.dialogflow.v2beta1.MessageAnnotation.fromObject(object.messageAnnotation);
                            }
                            if (object.sentimentAnalysis != null) {
                                if (typeof object.sentimentAnalysis !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.Message.sentimentAnalysis: object expected");
                                message.sentimentAnalysis = $root.google.cloud.dialogflow.v2beta1.SentimentAnalysisResult.fromObject(object.sentimentAnalysis);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a Message message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.Message
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.Message} message Message
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        Message.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.responseMessages = [];
                            if (options.defaults) {
                                object.name = "";
                                object.content = "";
                                object.languageCode = "";
                                object.participant = "";
                                object.participantRole = options.enums === String ? "ROLE_UNSPECIFIED" : 0;
                                object.createTime = null;
                                object.messageAnnotation = null;
                                object.sentimentAnalysis = null;
                                object.sendTime = null;
                            }
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            if (message.content != null && message.hasOwnProperty("content"))
                                object.content = message.content;
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                object.languageCode = message.languageCode;
                            if (message.participant != null && message.hasOwnProperty("participant"))
                                object.participant = message.participant;
                            if (message.participantRole != null && message.hasOwnProperty("participantRole"))
                                object.participantRole = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.Participant.Role[message.participantRole] === undefined ? message.participantRole : $root.google.cloud.dialogflow.v2beta1.Participant.Role[message.participantRole] : message.participantRole;
                            if (message.createTime != null && message.hasOwnProperty("createTime"))
                                object.createTime = $root.google.protobuf.Timestamp.toObject(message.createTime, options);
                            if (message.messageAnnotation != null && message.hasOwnProperty("messageAnnotation"))
                                object.messageAnnotation = $root.google.cloud.dialogflow.v2beta1.MessageAnnotation.toObject(message.messageAnnotation, options);
                            if (message.sentimentAnalysis != null && message.hasOwnProperty("sentimentAnalysis"))
                                object.sentimentAnalysis = $root.google.cloud.dialogflow.v2beta1.SentimentAnalysisResult.toObject(message.sentimentAnalysis, options);
                            if (message.sendTime != null && message.hasOwnProperty("sendTime"))
                                object.sendTime = $root.google.protobuf.Timestamp.toObject(message.sendTime, options);
                            if (message.responseMessages && message.responseMessages.length) {
                                object.responseMessages = [];
                                for (var j = 0; j < message.responseMessages.length; ++j)
                                    object.responseMessages[j] = $root.google.cloud.dialogflow.v2beta1.ResponseMessage.toObject(message.responseMessages[j], options);
                            }
                            return object;
                        };
    
                        /**
                         * Converts this Message to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.Message
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        Message.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for Message
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.Message
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        Message.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Message";
                        };
    
                        return Message;
                    })();
    
                    v2beta1.CreateParticipantRequest = (function() {
    
                        /**
                         * Properties of a CreateParticipantRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ICreateParticipantRequest
                         * @property {string|null} [parent] CreateParticipantRequest parent
                         * @property {google.cloud.dialogflow.v2beta1.IParticipant|null} [participant] CreateParticipantRequest participant
                         */
    
                        /**
                         * Constructs a new CreateParticipantRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a CreateParticipantRequest.
                         * @implements ICreateParticipantRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ICreateParticipantRequest=} [properties] Properties to set
                         */
                        function CreateParticipantRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * CreateParticipantRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.CreateParticipantRequest
                         * @instance
                         */
                        CreateParticipantRequest.prototype.parent = "";
    
                        /**
                         * CreateParticipantRequest participant.
                         * @member {google.cloud.dialogflow.v2beta1.IParticipant|null|undefined} participant
                         * @memberof google.cloud.dialogflow.v2beta1.CreateParticipantRequest
                         * @instance
                         */
                        CreateParticipantRequest.prototype.participant = null;
    
                        /**
                         * Creates a new CreateParticipantRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.CreateParticipantRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ICreateParticipantRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.CreateParticipantRequest} CreateParticipantRequest instance
                         */
                        CreateParticipantRequest.create = function create(properties) {
                            return new CreateParticipantRequest(properties);
                        };
    
                        /**
                         * Encodes the specified CreateParticipantRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.CreateParticipantRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.CreateParticipantRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ICreateParticipantRequest} message CreateParticipantRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateParticipantRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.participant != null && Object.hasOwnProperty.call(message, "participant"))
                                $root.google.cloud.dialogflow.v2beta1.Participant.encode(message.participant, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified CreateParticipantRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.CreateParticipantRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.CreateParticipantRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ICreateParticipantRequest} message CreateParticipantRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateParticipantRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a CreateParticipantRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.CreateParticipantRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.CreateParticipantRequest} CreateParticipantRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateParticipantRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.CreateParticipantRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.participant = $root.google.cloud.dialogflow.v2beta1.Participant.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a CreateParticipantRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.CreateParticipantRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.CreateParticipantRequest} CreateParticipantRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateParticipantRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a CreateParticipantRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.CreateParticipantRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        CreateParticipantRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.participant != null && message.hasOwnProperty("participant")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.Participant.verify(message.participant);
                                if (error)
                                    return "participant." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a CreateParticipantRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.CreateParticipantRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.CreateParticipantRequest} CreateParticipantRequest
                         */
                        CreateParticipantRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.CreateParticipantRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.CreateParticipantRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.participant != null) {
                                if (typeof object.participant !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.CreateParticipantRequest.participant: object expected");
                                message.participant = $root.google.cloud.dialogflow.v2beta1.Participant.fromObject(object.participant);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a CreateParticipantRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.CreateParticipantRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.CreateParticipantRequest} message CreateParticipantRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        CreateParticipantRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.participant = null;
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.participant != null && message.hasOwnProperty("participant"))
                                object.participant = $root.google.cloud.dialogflow.v2beta1.Participant.toObject(message.participant, options);
                            return object;
                        };
    
                        /**
                         * Converts this CreateParticipantRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.CreateParticipantRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        CreateParticipantRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for CreateParticipantRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.CreateParticipantRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        CreateParticipantRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.CreateParticipantRequest";
                        };
    
                        return CreateParticipantRequest;
                    })();
    
                    v2beta1.GetParticipantRequest = (function() {
    
                        /**
                         * Properties of a GetParticipantRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IGetParticipantRequest
                         * @property {string|null} [name] GetParticipantRequest name
                         */
    
                        /**
                         * Constructs a new GetParticipantRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a GetParticipantRequest.
                         * @implements IGetParticipantRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IGetParticipantRequest=} [properties] Properties to set
                         */
                        function GetParticipantRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GetParticipantRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2beta1.GetParticipantRequest
                         * @instance
                         */
                        GetParticipantRequest.prototype.name = "";
    
                        /**
                         * Creates a new GetParticipantRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.GetParticipantRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetParticipantRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.GetParticipantRequest} GetParticipantRequest instance
                         */
                        GetParticipantRequest.create = function create(properties) {
                            return new GetParticipantRequest(properties);
                        };
    
                        /**
                         * Encodes the specified GetParticipantRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GetParticipantRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.GetParticipantRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetParticipantRequest} message GetParticipantRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetParticipantRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GetParticipantRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GetParticipantRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GetParticipantRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetParticipantRequest} message GetParticipantRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetParticipantRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GetParticipantRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.GetParticipantRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.GetParticipantRequest} GetParticipantRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetParticipantRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.GetParticipantRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GetParticipantRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GetParticipantRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.GetParticipantRequest} GetParticipantRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetParticipantRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GetParticipantRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.GetParticipantRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GetParticipantRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a GetParticipantRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.GetParticipantRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.GetParticipantRequest} GetParticipantRequest
                         */
                        GetParticipantRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.GetParticipantRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.GetParticipantRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GetParticipantRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.GetParticipantRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.GetParticipantRequest} message GetParticipantRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GetParticipantRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.name = "";
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            return object;
                        };
    
                        /**
                         * Converts this GetParticipantRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.GetParticipantRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GetParticipantRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GetParticipantRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.GetParticipantRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GetParticipantRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.GetParticipantRequest";
                        };
    
                        return GetParticipantRequest;
                    })();
    
                    v2beta1.ListParticipantsRequest = (function() {
    
                        /**
                         * Properties of a ListParticipantsRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IListParticipantsRequest
                         * @property {string|null} [parent] ListParticipantsRequest parent
                         * @property {number|null} [pageSize] ListParticipantsRequest pageSize
                         * @property {string|null} [pageToken] ListParticipantsRequest pageToken
                         */
    
                        /**
                         * Constructs a new ListParticipantsRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a ListParticipantsRequest.
                         * @implements IListParticipantsRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IListParticipantsRequest=} [properties] Properties to set
                         */
                        function ListParticipantsRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListParticipantsRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.ListParticipantsRequest
                         * @instance
                         */
                        ListParticipantsRequest.prototype.parent = "";
    
                        /**
                         * ListParticipantsRequest pageSize.
                         * @member {number} pageSize
                         * @memberof google.cloud.dialogflow.v2beta1.ListParticipantsRequest
                         * @instance
                         */
                        ListParticipantsRequest.prototype.pageSize = 0;
    
                        /**
                         * ListParticipantsRequest pageToken.
                         * @member {string} pageToken
                         * @memberof google.cloud.dialogflow.v2beta1.ListParticipantsRequest
                         * @instance
                         */
                        ListParticipantsRequest.prototype.pageToken = "";
    
                        /**
                         * Creates a new ListParticipantsRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.ListParticipantsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListParticipantsRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.ListParticipantsRequest} ListParticipantsRequest instance
                         */
                        ListParticipantsRequest.create = function create(properties) {
                            return new ListParticipantsRequest(properties);
                        };
    
                        /**
                         * Encodes the specified ListParticipantsRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListParticipantsRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.ListParticipantsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListParticipantsRequest} message ListParticipantsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListParticipantsRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.pageSize != null && Object.hasOwnProperty.call(message, "pageSize"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.pageSize);
                            if (message.pageToken != null && Object.hasOwnProperty.call(message, "pageToken"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.pageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListParticipantsRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListParticipantsRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListParticipantsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListParticipantsRequest} message ListParticipantsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListParticipantsRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListParticipantsRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.ListParticipantsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.ListParticipantsRequest} ListParticipantsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListParticipantsRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ListParticipantsRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.pageSize = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.pageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListParticipantsRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListParticipantsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.ListParticipantsRequest} ListParticipantsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListParticipantsRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListParticipantsRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.ListParticipantsRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListParticipantsRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                if (!$util.isInteger(message.pageSize))
                                    return "pageSize: integer expected";
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                if (!$util.isString(message.pageToken))
                                    return "pageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListParticipantsRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListParticipantsRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.ListParticipantsRequest} ListParticipantsRequest
                         */
                        ListParticipantsRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.ListParticipantsRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.ListParticipantsRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.pageSize != null)
                                message.pageSize = object.pageSize | 0;
                            if (object.pageToken != null)
                                message.pageToken = String(object.pageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListParticipantsRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListParticipantsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ListParticipantsRequest} message ListParticipantsRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListParticipantsRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.pageSize = 0;
                                object.pageToken = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                object.pageSize = message.pageSize;
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                object.pageToken = message.pageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListParticipantsRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.ListParticipantsRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListParticipantsRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListParticipantsRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.ListParticipantsRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListParticipantsRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ListParticipantsRequest";
                        };
    
                        return ListParticipantsRequest;
                    })();
    
                    v2beta1.ListParticipantsResponse = (function() {
    
                        /**
                         * Properties of a ListParticipantsResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IListParticipantsResponse
                         * @property {Array.<google.cloud.dialogflow.v2beta1.IParticipant>|null} [participants] ListParticipantsResponse participants
                         * @property {string|null} [nextPageToken] ListParticipantsResponse nextPageToken
                         */
    
                        /**
                         * Constructs a new ListParticipantsResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a ListParticipantsResponse.
                         * @implements IListParticipantsResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IListParticipantsResponse=} [properties] Properties to set
                         */
                        function ListParticipantsResponse(properties) {
                            this.participants = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListParticipantsResponse participants.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.IParticipant>} participants
                         * @memberof google.cloud.dialogflow.v2beta1.ListParticipantsResponse
                         * @instance
                         */
                        ListParticipantsResponse.prototype.participants = $util.emptyArray;
    
                        /**
                         * ListParticipantsResponse nextPageToken.
                         * @member {string} nextPageToken
                         * @memberof google.cloud.dialogflow.v2beta1.ListParticipantsResponse
                         * @instance
                         */
                        ListParticipantsResponse.prototype.nextPageToken = "";
    
                        /**
                         * Creates a new ListParticipantsResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.ListParticipantsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListParticipantsResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.ListParticipantsResponse} ListParticipantsResponse instance
                         */
                        ListParticipantsResponse.create = function create(properties) {
                            return new ListParticipantsResponse(properties);
                        };
    
                        /**
                         * Encodes the specified ListParticipantsResponse message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListParticipantsResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.ListParticipantsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListParticipantsResponse} message ListParticipantsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListParticipantsResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.participants != null && message.participants.length)
                                for (var i = 0; i < message.participants.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.Participant.encode(message.participants[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.nextPageToken != null && Object.hasOwnProperty.call(message, "nextPageToken"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.nextPageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListParticipantsResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListParticipantsResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListParticipantsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListParticipantsResponse} message ListParticipantsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListParticipantsResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListParticipantsResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.ListParticipantsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.ListParticipantsResponse} ListParticipantsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListParticipantsResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ListParticipantsResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.participants && message.participants.length))
                                            message.participants = [];
                                        message.participants.push($root.google.cloud.dialogflow.v2beta1.Participant.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 2: {
                                        message.nextPageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListParticipantsResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListParticipantsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.ListParticipantsResponse} ListParticipantsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListParticipantsResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListParticipantsResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.ListParticipantsResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListParticipantsResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.participants != null && message.hasOwnProperty("participants")) {
                                if (!Array.isArray(message.participants))
                                    return "participants: array expected";
                                for (var i = 0; i < message.participants.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.Participant.verify(message.participants[i]);
                                    if (error)
                                        return "participants." + error;
                                }
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                if (!$util.isString(message.nextPageToken))
                                    return "nextPageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListParticipantsResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListParticipantsResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.ListParticipantsResponse} ListParticipantsResponse
                         */
                        ListParticipantsResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.ListParticipantsResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.ListParticipantsResponse();
                            if (object.participants) {
                                if (!Array.isArray(object.participants))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.ListParticipantsResponse.participants: array expected");
                                message.participants = [];
                                for (var i = 0; i < object.participants.length; ++i) {
                                    if (typeof object.participants[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.ListParticipantsResponse.participants: object expected");
                                    message.participants[i] = $root.google.cloud.dialogflow.v2beta1.Participant.fromObject(object.participants[i]);
                                }
                            }
                            if (object.nextPageToken != null)
                                message.nextPageToken = String(object.nextPageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListParticipantsResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListParticipantsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ListParticipantsResponse} message ListParticipantsResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListParticipantsResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.participants = [];
                            if (options.defaults)
                                object.nextPageToken = "";
                            if (message.participants && message.participants.length) {
                                object.participants = [];
                                for (var j = 0; j < message.participants.length; ++j)
                                    object.participants[j] = $root.google.cloud.dialogflow.v2beta1.Participant.toObject(message.participants[j], options);
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                object.nextPageToken = message.nextPageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListParticipantsResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.ListParticipantsResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListParticipantsResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListParticipantsResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.ListParticipantsResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListParticipantsResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ListParticipantsResponse";
                        };
    
                        return ListParticipantsResponse;
                    })();
    
                    v2beta1.UpdateParticipantRequest = (function() {
    
                        /**
                         * Properties of an UpdateParticipantRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IUpdateParticipantRequest
                         * @property {google.cloud.dialogflow.v2beta1.IParticipant|null} [participant] UpdateParticipantRequest participant
                         * @property {google.protobuf.IFieldMask|null} [updateMask] UpdateParticipantRequest updateMask
                         */
    
                        /**
                         * Constructs a new UpdateParticipantRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an UpdateParticipantRequest.
                         * @implements IUpdateParticipantRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateParticipantRequest=} [properties] Properties to set
                         */
                        function UpdateParticipantRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * UpdateParticipantRequest participant.
                         * @member {google.cloud.dialogflow.v2beta1.IParticipant|null|undefined} participant
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateParticipantRequest
                         * @instance
                         */
                        UpdateParticipantRequest.prototype.participant = null;
    
                        /**
                         * UpdateParticipantRequest updateMask.
                         * @member {google.protobuf.IFieldMask|null|undefined} updateMask
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateParticipantRequest
                         * @instance
                         */
                        UpdateParticipantRequest.prototype.updateMask = null;
    
                        /**
                         * Creates a new UpdateParticipantRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateParticipantRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateParticipantRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.UpdateParticipantRequest} UpdateParticipantRequest instance
                         */
                        UpdateParticipantRequest.create = function create(properties) {
                            return new UpdateParticipantRequest(properties);
                        };
    
                        /**
                         * Encodes the specified UpdateParticipantRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.UpdateParticipantRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateParticipantRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateParticipantRequest} message UpdateParticipantRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UpdateParticipantRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.participant != null && Object.hasOwnProperty.call(message, "participant"))
                                $root.google.cloud.dialogflow.v2beta1.Participant.encode(message.participant, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.updateMask != null && Object.hasOwnProperty.call(message, "updateMask"))
                                $root.google.protobuf.FieldMask.encode(message.updateMask, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified UpdateParticipantRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.UpdateParticipantRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateParticipantRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateParticipantRequest} message UpdateParticipantRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UpdateParticipantRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an UpdateParticipantRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateParticipantRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.UpdateParticipantRequest} UpdateParticipantRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UpdateParticipantRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.UpdateParticipantRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.participant = $root.google.cloud.dialogflow.v2beta1.Participant.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.updateMask = $root.google.protobuf.FieldMask.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an UpdateParticipantRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateParticipantRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.UpdateParticipantRequest} UpdateParticipantRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UpdateParticipantRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an UpdateParticipantRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateParticipantRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        UpdateParticipantRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.participant != null && message.hasOwnProperty("participant")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.Participant.verify(message.participant);
                                if (error)
                                    return "participant." + error;
                            }
                            if (message.updateMask != null && message.hasOwnProperty("updateMask")) {
                                var error = $root.google.protobuf.FieldMask.verify(message.updateMask);
                                if (error)
                                    return "updateMask." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates an UpdateParticipantRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateParticipantRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.UpdateParticipantRequest} UpdateParticipantRequest
                         */
                        UpdateParticipantRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.UpdateParticipantRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.UpdateParticipantRequest();
                            if (object.participant != null) {
                                if (typeof object.participant !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.UpdateParticipantRequest.participant: object expected");
                                message.participant = $root.google.cloud.dialogflow.v2beta1.Participant.fromObject(object.participant);
                            }
                            if (object.updateMask != null) {
                                if (typeof object.updateMask !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.UpdateParticipantRequest.updateMask: object expected");
                                message.updateMask = $root.google.protobuf.FieldMask.fromObject(object.updateMask);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an UpdateParticipantRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateParticipantRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.UpdateParticipantRequest} message UpdateParticipantRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        UpdateParticipantRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.participant = null;
                                object.updateMask = null;
                            }
                            if (message.participant != null && message.hasOwnProperty("participant"))
                                object.participant = $root.google.cloud.dialogflow.v2beta1.Participant.toObject(message.participant, options);
                            if (message.updateMask != null && message.hasOwnProperty("updateMask"))
                                object.updateMask = $root.google.protobuf.FieldMask.toObject(message.updateMask, options);
                            return object;
                        };
    
                        /**
                         * Converts this UpdateParticipantRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateParticipantRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        UpdateParticipantRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for UpdateParticipantRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateParticipantRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        UpdateParticipantRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.UpdateParticipantRequest";
                        };
    
                        return UpdateParticipantRequest;
                    })();
    
                    v2beta1.AudioInput = (function() {
    
                        /**
                         * Properties of an AudioInput.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IAudioInput
                         * @property {google.cloud.dialogflow.v2beta1.IInputAudioConfig|null} [config] AudioInput config
                         * @property {Uint8Array|null} [audio] AudioInput audio
                         */
    
                        /**
                         * Constructs a new AudioInput.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an AudioInput.
                         * @implements IAudioInput
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IAudioInput=} [properties] Properties to set
                         */
                        function AudioInput(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * AudioInput config.
                         * @member {google.cloud.dialogflow.v2beta1.IInputAudioConfig|null|undefined} config
                         * @memberof google.cloud.dialogflow.v2beta1.AudioInput
                         * @instance
                         */
                        AudioInput.prototype.config = null;
    
                        /**
                         * AudioInput audio.
                         * @member {Uint8Array} audio
                         * @memberof google.cloud.dialogflow.v2beta1.AudioInput
                         * @instance
                         */
                        AudioInput.prototype.audio = $util.newBuffer([]);
    
                        /**
                         * Creates a new AudioInput instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.AudioInput
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IAudioInput=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.AudioInput} AudioInput instance
                         */
                        AudioInput.create = function create(properties) {
                            return new AudioInput(properties);
                        };
    
                        /**
                         * Encodes the specified AudioInput message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.AudioInput.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.AudioInput
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IAudioInput} message AudioInput message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        AudioInput.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.config != null && Object.hasOwnProperty.call(message, "config"))
                                $root.google.cloud.dialogflow.v2beta1.InputAudioConfig.encode(message.config, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.audio != null && Object.hasOwnProperty.call(message, "audio"))
                                writer.uint32(/* id 2, wireType 2 =*/18).bytes(message.audio);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified AudioInput message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.AudioInput.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.AudioInput
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IAudioInput} message AudioInput message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        AudioInput.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an AudioInput message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.AudioInput
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.AudioInput} AudioInput
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        AudioInput.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.AudioInput();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.config = $root.google.cloud.dialogflow.v2beta1.InputAudioConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.audio = reader.bytes();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an AudioInput message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.AudioInput
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.AudioInput} AudioInput
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        AudioInput.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an AudioInput message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.AudioInput
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        AudioInput.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.config != null && message.hasOwnProperty("config")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.InputAudioConfig.verify(message.config);
                                if (error)
                                    return "config." + error;
                            }
                            if (message.audio != null && message.hasOwnProperty("audio"))
                                if (!(message.audio && typeof message.audio.length === "number" || $util.isString(message.audio)))
                                    return "audio: buffer expected";
                            return null;
                        };
    
                        /**
                         * Creates an AudioInput message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.AudioInput
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.AudioInput} AudioInput
                         */
                        AudioInput.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.AudioInput)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.AudioInput();
                            if (object.config != null) {
                                if (typeof object.config !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.AudioInput.config: object expected");
                                message.config = $root.google.cloud.dialogflow.v2beta1.InputAudioConfig.fromObject(object.config);
                            }
                            if (object.audio != null)
                                if (typeof object.audio === "string")
                                    $util.base64.decode(object.audio, message.audio = $util.newBuffer($util.base64.length(object.audio)), 0);
                                else if (object.audio.length >= 0)
                                    message.audio = object.audio;
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an AudioInput message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.AudioInput
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.AudioInput} message AudioInput
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        AudioInput.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.config = null;
                                if (options.bytes === String)
                                    object.audio = "";
                                else {
                                    object.audio = [];
                                    if (options.bytes !== Array)
                                        object.audio = $util.newBuffer(object.audio);
                                }
                            }
                            if (message.config != null && message.hasOwnProperty("config"))
                                object.config = $root.google.cloud.dialogflow.v2beta1.InputAudioConfig.toObject(message.config, options);
                            if (message.audio != null && message.hasOwnProperty("audio"))
                                object.audio = options.bytes === String ? $util.base64.encode(message.audio, 0, message.audio.length) : options.bytes === Array ? Array.prototype.slice.call(message.audio) : message.audio;
                            return object;
                        };
    
                        /**
                         * Converts this AudioInput to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.AudioInput
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        AudioInput.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for AudioInput
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.AudioInput
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        AudioInput.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.AudioInput";
                        };
    
                        return AudioInput;
                    })();
    
                    v2beta1.OutputAudio = (function() {
    
                        /**
                         * Properties of an OutputAudio.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IOutputAudio
                         * @property {google.cloud.dialogflow.v2beta1.IOutputAudioConfig|null} [config] OutputAudio config
                         * @property {Uint8Array|null} [audio] OutputAudio audio
                         */
    
                        /**
                         * Constructs a new OutputAudio.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an OutputAudio.
                         * @implements IOutputAudio
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IOutputAudio=} [properties] Properties to set
                         */
                        function OutputAudio(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * OutputAudio config.
                         * @member {google.cloud.dialogflow.v2beta1.IOutputAudioConfig|null|undefined} config
                         * @memberof google.cloud.dialogflow.v2beta1.OutputAudio
                         * @instance
                         */
                        OutputAudio.prototype.config = null;
    
                        /**
                         * OutputAudio audio.
                         * @member {Uint8Array} audio
                         * @memberof google.cloud.dialogflow.v2beta1.OutputAudio
                         * @instance
                         */
                        OutputAudio.prototype.audio = $util.newBuffer([]);
    
                        /**
                         * Creates a new OutputAudio instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.OutputAudio
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IOutputAudio=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.OutputAudio} OutputAudio instance
                         */
                        OutputAudio.create = function create(properties) {
                            return new OutputAudio(properties);
                        };
    
                        /**
                         * Encodes the specified OutputAudio message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.OutputAudio.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.OutputAudio
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IOutputAudio} message OutputAudio message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        OutputAudio.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.config != null && Object.hasOwnProperty.call(message, "config"))
                                $root.google.cloud.dialogflow.v2beta1.OutputAudioConfig.encode(message.config, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.audio != null && Object.hasOwnProperty.call(message, "audio"))
                                writer.uint32(/* id 2, wireType 2 =*/18).bytes(message.audio);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified OutputAudio message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.OutputAudio.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.OutputAudio
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IOutputAudio} message OutputAudio message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        OutputAudio.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an OutputAudio message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.OutputAudio
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.OutputAudio} OutputAudio
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        OutputAudio.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.OutputAudio();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.config = $root.google.cloud.dialogflow.v2beta1.OutputAudioConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.audio = reader.bytes();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an OutputAudio message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.OutputAudio
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.OutputAudio} OutputAudio
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        OutputAudio.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an OutputAudio message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.OutputAudio
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        OutputAudio.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.config != null && message.hasOwnProperty("config")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.OutputAudioConfig.verify(message.config);
                                if (error)
                                    return "config." + error;
                            }
                            if (message.audio != null && message.hasOwnProperty("audio"))
                                if (!(message.audio && typeof message.audio.length === "number" || $util.isString(message.audio)))
                                    return "audio: buffer expected";
                            return null;
                        };
    
                        /**
                         * Creates an OutputAudio message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.OutputAudio
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.OutputAudio} OutputAudio
                         */
                        OutputAudio.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.OutputAudio)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.OutputAudio();
                            if (object.config != null) {
                                if (typeof object.config !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.OutputAudio.config: object expected");
                                message.config = $root.google.cloud.dialogflow.v2beta1.OutputAudioConfig.fromObject(object.config);
                            }
                            if (object.audio != null)
                                if (typeof object.audio === "string")
                                    $util.base64.decode(object.audio, message.audio = $util.newBuffer($util.base64.length(object.audio)), 0);
                                else if (object.audio.length >= 0)
                                    message.audio = object.audio;
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an OutputAudio message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.OutputAudio
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.OutputAudio} message OutputAudio
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        OutputAudio.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.config = null;
                                if (options.bytes === String)
                                    object.audio = "";
                                else {
                                    object.audio = [];
                                    if (options.bytes !== Array)
                                        object.audio = $util.newBuffer(object.audio);
                                }
                            }
                            if (message.config != null && message.hasOwnProperty("config"))
                                object.config = $root.google.cloud.dialogflow.v2beta1.OutputAudioConfig.toObject(message.config, options);
                            if (message.audio != null && message.hasOwnProperty("audio"))
                                object.audio = options.bytes === String ? $util.base64.encode(message.audio, 0, message.audio.length) : options.bytes === Array ? Array.prototype.slice.call(message.audio) : message.audio;
                            return object;
                        };
    
                        /**
                         * Converts this OutputAudio to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.OutputAudio
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        OutputAudio.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for OutputAudio
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.OutputAudio
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        OutputAudio.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.OutputAudio";
                        };
    
                        return OutputAudio;
                    })();
    
                    v2beta1.AutomatedAgentReply = (function() {
    
                        /**
                         * Properties of an AutomatedAgentReply.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IAutomatedAgentReply
                         * @property {google.cloud.dialogflow.v2beta1.IDetectIntentResponse|null} [detectIntentResponse] AutomatedAgentReply detectIntentResponse
                         * @property {Array.<google.cloud.dialogflow.v2beta1.IResponseMessage>|null} [responseMessages] AutomatedAgentReply responseMessages
                         * @property {string|null} [intent] AutomatedAgentReply intent
                         * @property {string|null} [event] AutomatedAgentReply event
                         * @property {number|null} [matchConfidence] AutomatedAgentReply matchConfidence
                         * @property {google.protobuf.IStruct|null} [parameters] AutomatedAgentReply parameters
                         * @property {google.protobuf.IStruct|null} [cxSessionParameters] AutomatedAgentReply cxSessionParameters
                         * @property {google.cloud.dialogflow.v2beta1.AutomatedAgentReply.AutomatedAgentReplyType|null} [automatedAgentReplyType] AutomatedAgentReply automatedAgentReplyType
                         * @property {boolean|null} [allowCancellation] AutomatedAgentReply allowCancellation
                         * @property {string|null} [cxCurrentPage] AutomatedAgentReply cxCurrentPage
                         * @property {Uint8Array|null} [callCompanionAuthCode] AutomatedAgentReply callCompanionAuthCode
                         */
    
                        /**
                         * Constructs a new AutomatedAgentReply.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an AutomatedAgentReply.
                         * @implements IAutomatedAgentReply
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IAutomatedAgentReply=} [properties] Properties to set
                         */
                        function AutomatedAgentReply(properties) {
                            this.responseMessages = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * AutomatedAgentReply detectIntentResponse.
                         * @member {google.cloud.dialogflow.v2beta1.IDetectIntentResponse|null|undefined} detectIntentResponse
                         * @memberof google.cloud.dialogflow.v2beta1.AutomatedAgentReply
                         * @instance
                         */
                        AutomatedAgentReply.prototype.detectIntentResponse = null;
    
                        /**
                         * AutomatedAgentReply responseMessages.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.IResponseMessage>} responseMessages
                         * @memberof google.cloud.dialogflow.v2beta1.AutomatedAgentReply
                         * @instance
                         */
                        AutomatedAgentReply.prototype.responseMessages = $util.emptyArray;
    
                        /**
                         * AutomatedAgentReply intent.
                         * @member {string|null|undefined} intent
                         * @memberof google.cloud.dialogflow.v2beta1.AutomatedAgentReply
                         * @instance
                         */
                        AutomatedAgentReply.prototype.intent = null;
    
                        /**
                         * AutomatedAgentReply event.
                         * @member {string|null|undefined} event
                         * @memberof google.cloud.dialogflow.v2beta1.AutomatedAgentReply
                         * @instance
                         */
                        AutomatedAgentReply.prototype.event = null;
    
                        /**
                         * AutomatedAgentReply matchConfidence.
                         * @member {number} matchConfidence
                         * @memberof google.cloud.dialogflow.v2beta1.AutomatedAgentReply
                         * @instance
                         */
                        AutomatedAgentReply.prototype.matchConfidence = 0;
    
                        /**
                         * AutomatedAgentReply parameters.
                         * @member {google.protobuf.IStruct|null|undefined} parameters
                         * @memberof google.cloud.dialogflow.v2beta1.AutomatedAgentReply
                         * @instance
                         */
                        AutomatedAgentReply.prototype.parameters = null;
    
                        /**
                         * AutomatedAgentReply cxSessionParameters.
                         * @member {google.protobuf.IStruct|null|undefined} cxSessionParameters
                         * @memberof google.cloud.dialogflow.v2beta1.AutomatedAgentReply
                         * @instance
                         */
                        AutomatedAgentReply.prototype.cxSessionParameters = null;
    
                        /**
                         * AutomatedAgentReply automatedAgentReplyType.
                         * @member {google.cloud.dialogflow.v2beta1.AutomatedAgentReply.AutomatedAgentReplyType} automatedAgentReplyType
                         * @memberof google.cloud.dialogflow.v2beta1.AutomatedAgentReply
                         * @instance
                         */
                        AutomatedAgentReply.prototype.automatedAgentReplyType = 0;
    
                        /**
                         * AutomatedAgentReply allowCancellation.
                         * @member {boolean} allowCancellation
                         * @memberof google.cloud.dialogflow.v2beta1.AutomatedAgentReply
                         * @instance
                         */
                        AutomatedAgentReply.prototype.allowCancellation = false;
    
                        /**
                         * AutomatedAgentReply cxCurrentPage.
                         * @member {string} cxCurrentPage
                         * @memberof google.cloud.dialogflow.v2beta1.AutomatedAgentReply
                         * @instance
                         */
                        AutomatedAgentReply.prototype.cxCurrentPage = "";
    
                        /**
                         * AutomatedAgentReply callCompanionAuthCode.
                         * @member {Uint8Array} callCompanionAuthCode
                         * @memberof google.cloud.dialogflow.v2beta1.AutomatedAgentReply
                         * @instance
                         */
                        AutomatedAgentReply.prototype.callCompanionAuthCode = $util.newBuffer([]);
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * AutomatedAgentReply response.
                         * @member {"detectIntentResponse"|undefined} response
                         * @memberof google.cloud.dialogflow.v2beta1.AutomatedAgentReply
                         * @instance
                         */
                        Object.defineProperty(AutomatedAgentReply.prototype, "response", {
                            get: $util.oneOfGetter($oneOfFields = ["detectIntentResponse"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * AutomatedAgentReply match.
                         * @member {"intent"|"event"|undefined} match
                         * @memberof google.cloud.dialogflow.v2beta1.AutomatedAgentReply
                         * @instance
                         */
                        Object.defineProperty(AutomatedAgentReply.prototype, "match", {
                            get: $util.oneOfGetter($oneOfFields = ["intent", "event"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new AutomatedAgentReply instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.AutomatedAgentReply
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IAutomatedAgentReply=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.AutomatedAgentReply} AutomatedAgentReply instance
                         */
                        AutomatedAgentReply.create = function create(properties) {
                            return new AutomatedAgentReply(properties);
                        };
    
                        /**
                         * Encodes the specified AutomatedAgentReply message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.AutomatedAgentReply.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.AutomatedAgentReply
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IAutomatedAgentReply} message AutomatedAgentReply message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        AutomatedAgentReply.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.detectIntentResponse != null && Object.hasOwnProperty.call(message, "detectIntentResponse"))
                                $root.google.cloud.dialogflow.v2beta1.DetectIntentResponse.encode(message.detectIntentResponse, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.responseMessages != null && message.responseMessages.length)
                                for (var i = 0; i < message.responseMessages.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.ResponseMessage.encode(message.responseMessages[i], writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            if (message.intent != null && Object.hasOwnProperty.call(message, "intent"))
                                writer.uint32(/* id 4, wireType 2 =*/34).string(message.intent);
                            if (message.event != null && Object.hasOwnProperty.call(message, "event"))
                                writer.uint32(/* id 5, wireType 2 =*/42).string(message.event);
                            if (message.cxSessionParameters != null && Object.hasOwnProperty.call(message, "cxSessionParameters"))
                                $root.google.protobuf.Struct.encode(message.cxSessionParameters, writer.uint32(/* id 6, wireType 2 =*/50).fork()).ldelim();
                            if (message.automatedAgentReplyType != null && Object.hasOwnProperty.call(message, "automatedAgentReplyType"))
                                writer.uint32(/* id 7, wireType 0 =*/56).int32(message.automatedAgentReplyType);
                            if (message.allowCancellation != null && Object.hasOwnProperty.call(message, "allowCancellation"))
                                writer.uint32(/* id 8, wireType 0 =*/64).bool(message.allowCancellation);
                            if (message.matchConfidence != null && Object.hasOwnProperty.call(message, "matchConfidence"))
                                writer.uint32(/* id 9, wireType 5 =*/77).float(message.matchConfidence);
                            if (message.parameters != null && Object.hasOwnProperty.call(message, "parameters"))
                                $root.google.protobuf.Struct.encode(message.parameters, writer.uint32(/* id 10, wireType 2 =*/82).fork()).ldelim();
                            if (message.cxCurrentPage != null && Object.hasOwnProperty.call(message, "cxCurrentPage"))
                                writer.uint32(/* id 11, wireType 2 =*/90).string(message.cxCurrentPage);
                            if (message.callCompanionAuthCode != null && Object.hasOwnProperty.call(message, "callCompanionAuthCode"))
                                writer.uint32(/* id 12, wireType 2 =*/98).bytes(message.callCompanionAuthCode);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified AutomatedAgentReply message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.AutomatedAgentReply.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.AutomatedAgentReply
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IAutomatedAgentReply} message AutomatedAgentReply message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        AutomatedAgentReply.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an AutomatedAgentReply message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.AutomatedAgentReply
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.AutomatedAgentReply} AutomatedAgentReply
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        AutomatedAgentReply.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.AutomatedAgentReply();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.detectIntentResponse = $root.google.cloud.dialogflow.v2beta1.DetectIntentResponse.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 3: {
                                        if (!(message.responseMessages && message.responseMessages.length))
                                            message.responseMessages = [];
                                        message.responseMessages.push($root.google.cloud.dialogflow.v2beta1.ResponseMessage.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 4: {
                                        message.intent = reader.string();
                                        break;
                                    }
                                case 5: {
                                        message.event = reader.string();
                                        break;
                                    }
                                case 9: {
                                        message.matchConfidence = reader.float();
                                        break;
                                    }
                                case 10: {
                                        message.parameters = $root.google.protobuf.Struct.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 6: {
                                        message.cxSessionParameters = $root.google.protobuf.Struct.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 7: {
                                        message.automatedAgentReplyType = reader.int32();
                                        break;
                                    }
                                case 8: {
                                        message.allowCancellation = reader.bool();
                                        break;
                                    }
                                case 11: {
                                        message.cxCurrentPage = reader.string();
                                        break;
                                    }
                                case 12: {
                                        message.callCompanionAuthCode = reader.bytes();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an AutomatedAgentReply message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.AutomatedAgentReply
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.AutomatedAgentReply} AutomatedAgentReply
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        AutomatedAgentReply.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an AutomatedAgentReply message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.AutomatedAgentReply
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        AutomatedAgentReply.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.detectIntentResponse != null && message.hasOwnProperty("detectIntentResponse")) {
                                properties.response = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2beta1.DetectIntentResponse.verify(message.detectIntentResponse);
                                    if (error)
                                        return "detectIntentResponse." + error;
                                }
                            }
                            if (message.responseMessages != null && message.hasOwnProperty("responseMessages")) {
                                if (!Array.isArray(message.responseMessages))
                                    return "responseMessages: array expected";
                                for (var i = 0; i < message.responseMessages.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.ResponseMessage.verify(message.responseMessages[i]);
                                    if (error)
                                        return "responseMessages." + error;
                                }
                            }
                            if (message.intent != null && message.hasOwnProperty("intent")) {
                                properties.match = 1;
                                if (!$util.isString(message.intent))
                                    return "intent: string expected";
                            }
                            if (message.event != null && message.hasOwnProperty("event")) {
                                if (properties.match === 1)
                                    return "match: multiple values";
                                properties.match = 1;
                                if (!$util.isString(message.event))
                                    return "event: string expected";
                            }
                            if (message.matchConfidence != null && message.hasOwnProperty("matchConfidence"))
                                if (typeof message.matchConfidence !== "number")
                                    return "matchConfidence: number expected";
                            if (message.parameters != null && message.hasOwnProperty("parameters")) {
                                var error = $root.google.protobuf.Struct.verify(message.parameters);
                                if (error)
                                    return "parameters." + error;
                            }
                            if (message.cxSessionParameters != null && message.hasOwnProperty("cxSessionParameters")) {
                                var error = $root.google.protobuf.Struct.verify(message.cxSessionParameters);
                                if (error)
                                    return "cxSessionParameters." + error;
                            }
                            if (message.automatedAgentReplyType != null && message.hasOwnProperty("automatedAgentReplyType"))
                                switch (message.automatedAgentReplyType) {
                                default:
                                    return "automatedAgentReplyType: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                    break;
                                }
                            if (message.allowCancellation != null && message.hasOwnProperty("allowCancellation"))
                                if (typeof message.allowCancellation !== "boolean")
                                    return "allowCancellation: boolean expected";
                            if (message.cxCurrentPage != null && message.hasOwnProperty("cxCurrentPage"))
                                if (!$util.isString(message.cxCurrentPage))
                                    return "cxCurrentPage: string expected";
                            if (message.callCompanionAuthCode != null && message.hasOwnProperty("callCompanionAuthCode"))
                                if (!(message.callCompanionAuthCode && typeof message.callCompanionAuthCode.length === "number" || $util.isString(message.callCompanionAuthCode)))
                                    return "callCompanionAuthCode: buffer expected";
                            return null;
                        };
    
                        /**
                         * Creates an AutomatedAgentReply message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.AutomatedAgentReply
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.AutomatedAgentReply} AutomatedAgentReply
                         */
                        AutomatedAgentReply.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.AutomatedAgentReply)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.AutomatedAgentReply();
                            if (object.detectIntentResponse != null) {
                                if (typeof object.detectIntentResponse !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.AutomatedAgentReply.detectIntentResponse: object expected");
                                message.detectIntentResponse = $root.google.cloud.dialogflow.v2beta1.DetectIntentResponse.fromObject(object.detectIntentResponse);
                            }
                            if (object.responseMessages) {
                                if (!Array.isArray(object.responseMessages))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.AutomatedAgentReply.responseMessages: array expected");
                                message.responseMessages = [];
                                for (var i = 0; i < object.responseMessages.length; ++i) {
                                    if (typeof object.responseMessages[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.AutomatedAgentReply.responseMessages: object expected");
                                    message.responseMessages[i] = $root.google.cloud.dialogflow.v2beta1.ResponseMessage.fromObject(object.responseMessages[i]);
                                }
                            }
                            if (object.intent != null)
                                message.intent = String(object.intent);
                            if (object.event != null)
                                message.event = String(object.event);
                            if (object.matchConfidence != null)
                                message.matchConfidence = Number(object.matchConfidence);
                            if (object.parameters != null) {
                                if (typeof object.parameters !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.AutomatedAgentReply.parameters: object expected");
                                message.parameters = $root.google.protobuf.Struct.fromObject(object.parameters);
                            }
                            if (object.cxSessionParameters != null) {
                                if (typeof object.cxSessionParameters !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.AutomatedAgentReply.cxSessionParameters: object expected");
                                message.cxSessionParameters = $root.google.protobuf.Struct.fromObject(object.cxSessionParameters);
                            }
                            switch (object.automatedAgentReplyType) {
                            default:
                                if (typeof object.automatedAgentReplyType === "number") {
                                    message.automatedAgentReplyType = object.automatedAgentReplyType;
                                    break;
                                }
                                break;
                            case "AUTOMATED_AGENT_REPLY_TYPE_UNSPECIFIED":
                            case 0:
                                message.automatedAgentReplyType = 0;
                                break;
                            case "PARTIAL":
                            case 1:
                                message.automatedAgentReplyType = 1;
                                break;
                            case "FINAL":
                            case 2:
                                message.automatedAgentReplyType = 2;
                                break;
                            }
                            if (object.allowCancellation != null)
                                message.allowCancellation = Boolean(object.allowCancellation);
                            if (object.cxCurrentPage != null)
                                message.cxCurrentPage = String(object.cxCurrentPage);
                            if (object.callCompanionAuthCode != null)
                                if (typeof object.callCompanionAuthCode === "string")
                                    $util.base64.decode(object.callCompanionAuthCode, message.callCompanionAuthCode = $util.newBuffer($util.base64.length(object.callCompanionAuthCode)), 0);
                                else if (object.callCompanionAuthCode.length >= 0)
                                    message.callCompanionAuthCode = object.callCompanionAuthCode;
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an AutomatedAgentReply message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.AutomatedAgentReply
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.AutomatedAgentReply} message AutomatedAgentReply
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        AutomatedAgentReply.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.responseMessages = [];
                            if (options.defaults) {
                                object.cxSessionParameters = null;
                                object.automatedAgentReplyType = options.enums === String ? "AUTOMATED_AGENT_REPLY_TYPE_UNSPECIFIED" : 0;
                                object.allowCancellation = false;
                                object.matchConfidence = 0;
                                object.parameters = null;
                                object.cxCurrentPage = "";
                                if (options.bytes === String)
                                    object.callCompanionAuthCode = "";
                                else {
                                    object.callCompanionAuthCode = [];
                                    if (options.bytes !== Array)
                                        object.callCompanionAuthCode = $util.newBuffer(object.callCompanionAuthCode);
                                }
                            }
                            if (message.detectIntentResponse != null && message.hasOwnProperty("detectIntentResponse")) {
                                object.detectIntentResponse = $root.google.cloud.dialogflow.v2beta1.DetectIntentResponse.toObject(message.detectIntentResponse, options);
                                if (options.oneofs)
                                    object.response = "detectIntentResponse";
                            }
                            if (message.responseMessages && message.responseMessages.length) {
                                object.responseMessages = [];
                                for (var j = 0; j < message.responseMessages.length; ++j)
                                    object.responseMessages[j] = $root.google.cloud.dialogflow.v2beta1.ResponseMessage.toObject(message.responseMessages[j], options);
                            }
                            if (message.intent != null && message.hasOwnProperty("intent")) {
                                object.intent = message.intent;
                                if (options.oneofs)
                                    object.match = "intent";
                            }
                            if (message.event != null && message.hasOwnProperty("event")) {
                                object.event = message.event;
                                if (options.oneofs)
                                    object.match = "event";
                            }
                            if (message.cxSessionParameters != null && message.hasOwnProperty("cxSessionParameters"))
                                object.cxSessionParameters = $root.google.protobuf.Struct.toObject(message.cxSessionParameters, options);
                            if (message.automatedAgentReplyType != null && message.hasOwnProperty("automatedAgentReplyType"))
                                object.automatedAgentReplyType = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.AutomatedAgentReply.AutomatedAgentReplyType[message.automatedAgentReplyType] === undefined ? message.automatedAgentReplyType : $root.google.cloud.dialogflow.v2beta1.AutomatedAgentReply.AutomatedAgentReplyType[message.automatedAgentReplyType] : message.automatedAgentReplyType;
                            if (message.allowCancellation != null && message.hasOwnProperty("allowCancellation"))
                                object.allowCancellation = message.allowCancellation;
                            if (message.matchConfidence != null && message.hasOwnProperty("matchConfidence"))
                                object.matchConfidence = options.json && !isFinite(message.matchConfidence) ? String(message.matchConfidence) : message.matchConfidence;
                            if (message.parameters != null && message.hasOwnProperty("parameters"))
                                object.parameters = $root.google.protobuf.Struct.toObject(message.parameters, options);
                            if (message.cxCurrentPage != null && message.hasOwnProperty("cxCurrentPage"))
                                object.cxCurrentPage = message.cxCurrentPage;
                            if (message.callCompanionAuthCode != null && message.hasOwnProperty("callCompanionAuthCode"))
                                object.callCompanionAuthCode = options.bytes === String ? $util.base64.encode(message.callCompanionAuthCode, 0, message.callCompanionAuthCode.length) : options.bytes === Array ? Array.prototype.slice.call(message.callCompanionAuthCode) : message.callCompanionAuthCode;
                            return object;
                        };
    
                        /**
                         * Converts this AutomatedAgentReply to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.AutomatedAgentReply
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        AutomatedAgentReply.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for AutomatedAgentReply
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.AutomatedAgentReply
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        AutomatedAgentReply.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.AutomatedAgentReply";
                        };
    
                        /**
                         * AutomatedAgentReplyType enum.
                         * @name google.cloud.dialogflow.v2beta1.AutomatedAgentReply.AutomatedAgentReplyType
                         * @enum {number}
                         * @property {number} AUTOMATED_AGENT_REPLY_TYPE_UNSPECIFIED=0 AUTOMATED_AGENT_REPLY_TYPE_UNSPECIFIED value
                         * @property {number} PARTIAL=1 PARTIAL value
                         * @property {number} FINAL=2 FINAL value
                         */
                        AutomatedAgentReply.AutomatedAgentReplyType = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "AUTOMATED_AGENT_REPLY_TYPE_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "PARTIAL"] = 1;
                            values[valuesById[2] = "FINAL"] = 2;
                            return values;
                        })();
    
                        return AutomatedAgentReply;
                    })();
    
                    v2beta1.SuggestionInput = (function() {
    
                        /**
                         * Properties of a SuggestionInput.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ISuggestionInput
                         * @property {string|null} [answerRecord] SuggestionInput answerRecord
                         * @property {google.cloud.dialogflow.v2beta1.ITextInput|null} [textOverride] SuggestionInput textOverride
                         * @property {google.protobuf.IStruct|null} [parameters] SuggestionInput parameters
                         * @property {google.cloud.dialogflow.v2beta1.IIntentInput|null} [intentInput] SuggestionInput intentInput
                         */
    
                        /**
                         * Constructs a new SuggestionInput.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a SuggestionInput.
                         * @implements ISuggestionInput
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestionInput=} [properties] Properties to set
                         */
                        function SuggestionInput(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SuggestionInput answerRecord.
                         * @member {string} answerRecord
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestionInput
                         * @instance
                         */
                        SuggestionInput.prototype.answerRecord = "";
    
                        /**
                         * SuggestionInput textOverride.
                         * @member {google.cloud.dialogflow.v2beta1.ITextInput|null|undefined} textOverride
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestionInput
                         * @instance
                         */
                        SuggestionInput.prototype.textOverride = null;
    
                        /**
                         * SuggestionInput parameters.
                         * @member {google.protobuf.IStruct|null|undefined} parameters
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestionInput
                         * @instance
                         */
                        SuggestionInput.prototype.parameters = null;
    
                        /**
                         * SuggestionInput intentInput.
                         * @member {google.cloud.dialogflow.v2beta1.IIntentInput|null|undefined} intentInput
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestionInput
                         * @instance
                         */
                        SuggestionInput.prototype.intentInput = null;
    
                        /**
                         * Creates a new SuggestionInput instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestionInput
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestionInput=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.SuggestionInput} SuggestionInput instance
                         */
                        SuggestionInput.create = function create(properties) {
                            return new SuggestionInput(properties);
                        };
    
                        /**
                         * Encodes the specified SuggestionInput message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SuggestionInput.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestionInput
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestionInput} message SuggestionInput message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SuggestionInput.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.answerRecord != null && Object.hasOwnProperty.call(message, "answerRecord"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.answerRecord);
                            if (message.textOverride != null && Object.hasOwnProperty.call(message, "textOverride"))
                                $root.google.cloud.dialogflow.v2beta1.TextInput.encode(message.textOverride, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.parameters != null && Object.hasOwnProperty.call(message, "parameters"))
                                $root.google.protobuf.Struct.encode(message.parameters, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            if (message.intentInput != null && Object.hasOwnProperty.call(message, "intentInput"))
                                $root.google.cloud.dialogflow.v2beta1.IntentInput.encode(message.intentInput, writer.uint32(/* id 6, wireType 2 =*/50).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SuggestionInput message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SuggestionInput.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestionInput
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestionInput} message SuggestionInput message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SuggestionInput.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SuggestionInput message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestionInput
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.SuggestionInput} SuggestionInput
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SuggestionInput.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.SuggestionInput();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.answerRecord = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.textOverride = $root.google.cloud.dialogflow.v2beta1.TextInput.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 4: {
                                        message.parameters = $root.google.protobuf.Struct.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 6: {
                                        message.intentInput = $root.google.cloud.dialogflow.v2beta1.IntentInput.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SuggestionInput message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestionInput
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.SuggestionInput} SuggestionInput
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SuggestionInput.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SuggestionInput message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestionInput
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SuggestionInput.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.answerRecord != null && message.hasOwnProperty("answerRecord"))
                                if (!$util.isString(message.answerRecord))
                                    return "answerRecord: string expected";
                            if (message.textOverride != null && message.hasOwnProperty("textOverride")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.TextInput.verify(message.textOverride);
                                if (error)
                                    return "textOverride." + error;
                            }
                            if (message.parameters != null && message.hasOwnProperty("parameters")) {
                                var error = $root.google.protobuf.Struct.verify(message.parameters);
                                if (error)
                                    return "parameters." + error;
                            }
                            if (message.intentInput != null && message.hasOwnProperty("intentInput")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.IntentInput.verify(message.intentInput);
                                if (error)
                                    return "intentInput." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a SuggestionInput message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestionInput
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.SuggestionInput} SuggestionInput
                         */
                        SuggestionInput.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.SuggestionInput)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.SuggestionInput();
                            if (object.answerRecord != null)
                                message.answerRecord = String(object.answerRecord);
                            if (object.textOverride != null) {
                                if (typeof object.textOverride !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.SuggestionInput.textOverride: object expected");
                                message.textOverride = $root.google.cloud.dialogflow.v2beta1.TextInput.fromObject(object.textOverride);
                            }
                            if (object.parameters != null) {
                                if (typeof object.parameters !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.SuggestionInput.parameters: object expected");
                                message.parameters = $root.google.protobuf.Struct.fromObject(object.parameters);
                            }
                            if (object.intentInput != null) {
                                if (typeof object.intentInput !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.SuggestionInput.intentInput: object expected");
                                message.intentInput = $root.google.cloud.dialogflow.v2beta1.IntentInput.fromObject(object.intentInput);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SuggestionInput message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestionInput
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.SuggestionInput} message SuggestionInput
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SuggestionInput.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.answerRecord = "";
                                object.textOverride = null;
                                object.parameters = null;
                                object.intentInput = null;
                            }
                            if (message.answerRecord != null && message.hasOwnProperty("answerRecord"))
                                object.answerRecord = message.answerRecord;
                            if (message.textOverride != null && message.hasOwnProperty("textOverride"))
                                object.textOverride = $root.google.cloud.dialogflow.v2beta1.TextInput.toObject(message.textOverride, options);
                            if (message.parameters != null && message.hasOwnProperty("parameters"))
                                object.parameters = $root.google.protobuf.Struct.toObject(message.parameters, options);
                            if (message.intentInput != null && message.hasOwnProperty("intentInput"))
                                object.intentInput = $root.google.cloud.dialogflow.v2beta1.IntentInput.toObject(message.intentInput, options);
                            return object;
                        };
    
                        /**
                         * Converts this SuggestionInput to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestionInput
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SuggestionInput.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SuggestionInput
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestionInput
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SuggestionInput.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.SuggestionInput";
                        };
    
                        return SuggestionInput;
                    })();
    
                    v2beta1.IntentInput = (function() {
    
                        /**
                         * Properties of an IntentInput.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IIntentInput
                         * @property {string|null} [intent] IntentInput intent
                         * @property {string|null} [languageCode] IntentInput languageCode
                         */
    
                        /**
                         * Constructs a new IntentInput.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an IntentInput.
                         * @implements IIntentInput
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IIntentInput=} [properties] Properties to set
                         */
                        function IntentInput(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * IntentInput intent.
                         * @member {string} intent
                         * @memberof google.cloud.dialogflow.v2beta1.IntentInput
                         * @instance
                         */
                        IntentInput.prototype.intent = "";
    
                        /**
                         * IntentInput languageCode.
                         * @member {string} languageCode
                         * @memberof google.cloud.dialogflow.v2beta1.IntentInput
                         * @instance
                         */
                        IntentInput.prototype.languageCode = "";
    
                        /**
                         * Creates a new IntentInput instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.IntentInput
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IIntentInput=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.IntentInput} IntentInput instance
                         */
                        IntentInput.create = function create(properties) {
                            return new IntentInput(properties);
                        };
    
                        /**
                         * Encodes the specified IntentInput message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.IntentInput.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.IntentInput
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IIntentInput} message IntentInput message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        IntentInput.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.intent != null && Object.hasOwnProperty.call(message, "intent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.intent);
                            if (message.languageCode != null && Object.hasOwnProperty.call(message, "languageCode"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.languageCode);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified IntentInput message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.IntentInput.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.IntentInput
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IIntentInput} message IntentInput message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        IntentInput.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an IntentInput message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.IntentInput
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.IntentInput} IntentInput
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        IntentInput.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.IntentInput();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.intent = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.languageCode = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an IntentInput message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.IntentInput
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.IntentInput} IntentInput
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        IntentInput.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an IntentInput message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.IntentInput
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        IntentInput.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.intent != null && message.hasOwnProperty("intent"))
                                if (!$util.isString(message.intent))
                                    return "intent: string expected";
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                if (!$util.isString(message.languageCode))
                                    return "languageCode: string expected";
                            return null;
                        };
    
                        /**
                         * Creates an IntentInput message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.IntentInput
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.IntentInput} IntentInput
                         */
                        IntentInput.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.IntentInput)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.IntentInput();
                            if (object.intent != null)
                                message.intent = String(object.intent);
                            if (object.languageCode != null)
                                message.languageCode = String(object.languageCode);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an IntentInput message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.IntentInput
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IntentInput} message IntentInput
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        IntentInput.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.intent = "";
                                object.languageCode = "";
                            }
                            if (message.intent != null && message.hasOwnProperty("intent"))
                                object.intent = message.intent;
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                object.languageCode = message.languageCode;
                            return object;
                        };
    
                        /**
                         * Converts this IntentInput to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.IntentInput
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        IntentInput.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for IntentInput
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.IntentInput
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        IntentInput.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.IntentInput";
                        };
    
                        return IntentInput;
                    })();
    
                    v2beta1.SuggestionFeature = (function() {
    
                        /**
                         * Properties of a SuggestionFeature.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ISuggestionFeature
                         * @property {google.cloud.dialogflow.v2beta1.SuggestionFeature.Type|null} [type] SuggestionFeature type
                         */
    
                        /**
                         * Constructs a new SuggestionFeature.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a SuggestionFeature.
                         * @implements ISuggestionFeature
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestionFeature=} [properties] Properties to set
                         */
                        function SuggestionFeature(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SuggestionFeature type.
                         * @member {google.cloud.dialogflow.v2beta1.SuggestionFeature.Type} type
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestionFeature
                         * @instance
                         */
                        SuggestionFeature.prototype.type = 0;
    
                        /**
                         * Creates a new SuggestionFeature instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestionFeature
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestionFeature=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.SuggestionFeature} SuggestionFeature instance
                         */
                        SuggestionFeature.create = function create(properties) {
                            return new SuggestionFeature(properties);
                        };
    
                        /**
                         * Encodes the specified SuggestionFeature message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SuggestionFeature.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestionFeature
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestionFeature} message SuggestionFeature message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SuggestionFeature.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.type != null && Object.hasOwnProperty.call(message, "type"))
                                writer.uint32(/* id 1, wireType 0 =*/8).int32(message.type);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SuggestionFeature message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SuggestionFeature.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestionFeature
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestionFeature} message SuggestionFeature message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SuggestionFeature.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SuggestionFeature message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestionFeature
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.SuggestionFeature} SuggestionFeature
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SuggestionFeature.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.SuggestionFeature();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.type = reader.int32();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SuggestionFeature message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestionFeature
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.SuggestionFeature} SuggestionFeature
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SuggestionFeature.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SuggestionFeature message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestionFeature
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SuggestionFeature.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.type != null && message.hasOwnProperty("type"))
                                switch (message.type) {
                                default:
                                    return "type: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                case 4:
                                case 8:
                                case 14:
                                case 15:
                                    break;
                                }
                            return null;
                        };
    
                        /**
                         * Creates a SuggestionFeature message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestionFeature
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.SuggestionFeature} SuggestionFeature
                         */
                        SuggestionFeature.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.SuggestionFeature)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.SuggestionFeature();
                            switch (object.type) {
                            default:
                                if (typeof object.type === "number") {
                                    message.type = object.type;
                                    break;
                                }
                                break;
                            case "TYPE_UNSPECIFIED":
                            case 0:
                                message.type = 0;
                                break;
                            case "ARTICLE_SUGGESTION":
                            case 1:
                                message.type = 1;
                                break;
                            case "FAQ":
                            case 2:
                                message.type = 2;
                                break;
                            case "SMART_REPLY":
                            case 3:
                                message.type = 3;
                                break;
                            case "DIALOGFLOW_ASSIST":
                            case 4:
                                message.type = 4;
                                break;
                            case "CONVERSATION_SUMMARIZATION":
                            case 8:
                                message.type = 8;
                                break;
                            case "KNOWLEDGE_SEARCH":
                            case 14:
                                message.type = 14;
                                break;
                            case "KNOWLEDGE_ASSIST":
                            case 15:
                                message.type = 15;
                                break;
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SuggestionFeature message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestionFeature
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.SuggestionFeature} message SuggestionFeature
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SuggestionFeature.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.type = options.enums === String ? "TYPE_UNSPECIFIED" : 0;
                            if (message.type != null && message.hasOwnProperty("type"))
                                object.type = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.SuggestionFeature.Type[message.type] === undefined ? message.type : $root.google.cloud.dialogflow.v2beta1.SuggestionFeature.Type[message.type] : message.type;
                            return object;
                        };
    
                        /**
                         * Converts this SuggestionFeature to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestionFeature
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SuggestionFeature.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SuggestionFeature
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestionFeature
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SuggestionFeature.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.SuggestionFeature";
                        };
    
                        /**
                         * Type enum.
                         * @name google.cloud.dialogflow.v2beta1.SuggestionFeature.Type
                         * @enum {number}
                         * @property {number} TYPE_UNSPECIFIED=0 TYPE_UNSPECIFIED value
                         * @property {number} ARTICLE_SUGGESTION=1 ARTICLE_SUGGESTION value
                         * @property {number} FAQ=2 FAQ value
                         * @property {number} SMART_REPLY=3 SMART_REPLY value
                         * @property {number} DIALOGFLOW_ASSIST=4 DIALOGFLOW_ASSIST value
                         * @property {number} CONVERSATION_SUMMARIZATION=8 CONVERSATION_SUMMARIZATION value
                         * @property {number} KNOWLEDGE_SEARCH=14 KNOWLEDGE_SEARCH value
                         * @property {number} KNOWLEDGE_ASSIST=15 KNOWLEDGE_ASSIST value
                         */
                        SuggestionFeature.Type = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "TYPE_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "ARTICLE_SUGGESTION"] = 1;
                            values[valuesById[2] = "FAQ"] = 2;
                            values[valuesById[3] = "SMART_REPLY"] = 3;
                            values[valuesById[4] = "DIALOGFLOW_ASSIST"] = 4;
                            values[valuesById[8] = "CONVERSATION_SUMMARIZATION"] = 8;
                            values[valuesById[14] = "KNOWLEDGE_SEARCH"] = 14;
                            values[valuesById[15] = "KNOWLEDGE_ASSIST"] = 15;
                            return values;
                        })();
    
                        return SuggestionFeature;
                    })();
    
                    v2beta1.AssistQueryParameters = (function() {
    
                        /**
                         * Properties of an AssistQueryParameters.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IAssistQueryParameters
                         * @property {Object.<string,string>|null} [documentsMetadataFilters] AssistQueryParameters documentsMetadataFilters
                         */
    
                        /**
                         * Constructs a new AssistQueryParameters.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an AssistQueryParameters.
                         * @implements IAssistQueryParameters
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IAssistQueryParameters=} [properties] Properties to set
                         */
                        function AssistQueryParameters(properties) {
                            this.documentsMetadataFilters = {};
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * AssistQueryParameters documentsMetadataFilters.
                         * @member {Object.<string,string>} documentsMetadataFilters
                         * @memberof google.cloud.dialogflow.v2beta1.AssistQueryParameters
                         * @instance
                         */
                        AssistQueryParameters.prototype.documentsMetadataFilters = $util.emptyObject;
    
                        /**
                         * Creates a new AssistQueryParameters instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.AssistQueryParameters
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IAssistQueryParameters=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.AssistQueryParameters} AssistQueryParameters instance
                         */
                        AssistQueryParameters.create = function create(properties) {
                            return new AssistQueryParameters(properties);
                        };
    
                        /**
                         * Encodes the specified AssistQueryParameters message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.AssistQueryParameters.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.AssistQueryParameters
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IAssistQueryParameters} message AssistQueryParameters message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        AssistQueryParameters.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.documentsMetadataFilters != null && Object.hasOwnProperty.call(message, "documentsMetadataFilters"))
                                for (var keys = Object.keys(message.documentsMetadataFilters), i = 0; i < keys.length; ++i)
                                    writer.uint32(/* id 1, wireType 2 =*/10).fork().uint32(/* id 1, wireType 2 =*/10).string(keys[i]).uint32(/* id 2, wireType 2 =*/18).string(message.documentsMetadataFilters[keys[i]]).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified AssistQueryParameters message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.AssistQueryParameters.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.AssistQueryParameters
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IAssistQueryParameters} message AssistQueryParameters message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        AssistQueryParameters.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an AssistQueryParameters message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.AssistQueryParameters
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.AssistQueryParameters} AssistQueryParameters
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        AssistQueryParameters.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.AssistQueryParameters(), key, value;
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (message.documentsMetadataFilters === $util.emptyObject)
                                            message.documentsMetadataFilters = {};
                                        var end2 = reader.uint32() + reader.pos;
                                        key = "";
                                        value = "";
                                        while (reader.pos < end2) {
                                            var tag2 = reader.uint32();
                                            switch (tag2 >>> 3) {
                                            case 1:
                                                key = reader.string();
                                                break;
                                            case 2:
                                                value = reader.string();
                                                break;
                                            default:
                                                reader.skipType(tag2 & 7);
                                                break;
                                            }
                                        }
                                        message.documentsMetadataFilters[key] = value;
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an AssistQueryParameters message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.AssistQueryParameters
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.AssistQueryParameters} AssistQueryParameters
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        AssistQueryParameters.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an AssistQueryParameters message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.AssistQueryParameters
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        AssistQueryParameters.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.documentsMetadataFilters != null && message.hasOwnProperty("documentsMetadataFilters")) {
                                if (!$util.isObject(message.documentsMetadataFilters))
                                    return "documentsMetadataFilters: object expected";
                                var key = Object.keys(message.documentsMetadataFilters);
                                for (var i = 0; i < key.length; ++i)
                                    if (!$util.isString(message.documentsMetadataFilters[key[i]]))
                                        return "documentsMetadataFilters: string{k:string} expected";
                            }
                            return null;
                        };
    
                        /**
                         * Creates an AssistQueryParameters message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.AssistQueryParameters
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.AssistQueryParameters} AssistQueryParameters
                         */
                        AssistQueryParameters.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.AssistQueryParameters)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.AssistQueryParameters();
                            if (object.documentsMetadataFilters) {
                                if (typeof object.documentsMetadataFilters !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.AssistQueryParameters.documentsMetadataFilters: object expected");
                                message.documentsMetadataFilters = {};
                                for (var keys = Object.keys(object.documentsMetadataFilters), i = 0; i < keys.length; ++i)
                                    message.documentsMetadataFilters[keys[i]] = String(object.documentsMetadataFilters[keys[i]]);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an AssistQueryParameters message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.AssistQueryParameters
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.AssistQueryParameters} message AssistQueryParameters
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        AssistQueryParameters.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.objects || options.defaults)
                                object.documentsMetadataFilters = {};
                            var keys2;
                            if (message.documentsMetadataFilters && (keys2 = Object.keys(message.documentsMetadataFilters)).length) {
                                object.documentsMetadataFilters = {};
                                for (var j = 0; j < keys2.length; ++j)
                                    object.documentsMetadataFilters[keys2[j]] = message.documentsMetadataFilters[keys2[j]];
                            }
                            return object;
                        };
    
                        /**
                         * Converts this AssistQueryParameters to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.AssistQueryParameters
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        AssistQueryParameters.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for AssistQueryParameters
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.AssistQueryParameters
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        AssistQueryParameters.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.AssistQueryParameters";
                        };
    
                        return AssistQueryParameters;
                    })();
    
                    v2beta1.AnalyzeContentRequest = (function() {
    
                        /**
                         * Properties of an AnalyzeContentRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IAnalyzeContentRequest
                         * @property {string|null} [participant] AnalyzeContentRequest participant
                         * @property {google.cloud.dialogflow.v2beta1.ITextInput|null} [textInput] AnalyzeContentRequest textInput
                         * @property {google.cloud.dialogflow.v2beta1.IAudioInput|null} [audioInput] AnalyzeContentRequest audioInput
                         * @property {google.cloud.dialogflow.v2beta1.IEventInput|null} [eventInput] AnalyzeContentRequest eventInput
                         * @property {google.cloud.dialogflow.v2beta1.ISuggestionInput|null} [suggestionInput] AnalyzeContentRequest suggestionInput
                         * @property {google.cloud.dialogflow.v2beta1.IIntentInput|null} [intentInput] AnalyzeContentRequest intentInput
                         * @property {google.cloud.dialogflow.v2beta1.IOutputAudioConfig|null} [replyAudioConfig] AnalyzeContentRequest replyAudioConfig
                         * @property {google.cloud.dialogflow.v2beta1.IQueryParameters|null} [queryParams] AnalyzeContentRequest queryParams
                         * @property {google.cloud.dialogflow.v2beta1.IAssistQueryParameters|null} [assistQueryParams] AnalyzeContentRequest assistQueryParams
                         * @property {google.protobuf.IStruct|null} [cxParameters] AnalyzeContentRequest cxParameters
                         * @property {string|null} [cxCurrentPage] AnalyzeContentRequest cxCurrentPage
                         * @property {google.protobuf.ITimestamp|null} [messageSendTime] AnalyzeContentRequest messageSendTime
                         * @property {string|null} [requestId] AnalyzeContentRequest requestId
                         */
    
                        /**
                         * Constructs a new AnalyzeContentRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an AnalyzeContentRequest.
                         * @implements IAnalyzeContentRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IAnalyzeContentRequest=} [properties] Properties to set
                         */
                        function AnalyzeContentRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * AnalyzeContentRequest participant.
                         * @member {string} participant
                         * @memberof google.cloud.dialogflow.v2beta1.AnalyzeContentRequest
                         * @instance
                         */
                        AnalyzeContentRequest.prototype.participant = "";
    
                        /**
                         * AnalyzeContentRequest textInput.
                         * @member {google.cloud.dialogflow.v2beta1.ITextInput|null|undefined} textInput
                         * @memberof google.cloud.dialogflow.v2beta1.AnalyzeContentRequest
                         * @instance
                         */
                        AnalyzeContentRequest.prototype.textInput = null;
    
                        /**
                         * AnalyzeContentRequest audioInput.
                         * @member {google.cloud.dialogflow.v2beta1.IAudioInput|null|undefined} audioInput
                         * @memberof google.cloud.dialogflow.v2beta1.AnalyzeContentRequest
                         * @instance
                         */
                        AnalyzeContentRequest.prototype.audioInput = null;
    
                        /**
                         * AnalyzeContentRequest eventInput.
                         * @member {google.cloud.dialogflow.v2beta1.IEventInput|null|undefined} eventInput
                         * @memberof google.cloud.dialogflow.v2beta1.AnalyzeContentRequest
                         * @instance
                         */
                        AnalyzeContentRequest.prototype.eventInput = null;
    
                        /**
                         * AnalyzeContentRequest suggestionInput.
                         * @member {google.cloud.dialogflow.v2beta1.ISuggestionInput|null|undefined} suggestionInput
                         * @memberof google.cloud.dialogflow.v2beta1.AnalyzeContentRequest
                         * @instance
                         */
                        AnalyzeContentRequest.prototype.suggestionInput = null;
    
                        /**
                         * AnalyzeContentRequest intentInput.
                         * @member {google.cloud.dialogflow.v2beta1.IIntentInput|null|undefined} intentInput
                         * @memberof google.cloud.dialogflow.v2beta1.AnalyzeContentRequest
                         * @instance
                         */
                        AnalyzeContentRequest.prototype.intentInput = null;
    
                        /**
                         * AnalyzeContentRequest replyAudioConfig.
                         * @member {google.cloud.dialogflow.v2beta1.IOutputAudioConfig|null|undefined} replyAudioConfig
                         * @memberof google.cloud.dialogflow.v2beta1.AnalyzeContentRequest
                         * @instance
                         */
                        AnalyzeContentRequest.prototype.replyAudioConfig = null;
    
                        /**
                         * AnalyzeContentRequest queryParams.
                         * @member {google.cloud.dialogflow.v2beta1.IQueryParameters|null|undefined} queryParams
                         * @memberof google.cloud.dialogflow.v2beta1.AnalyzeContentRequest
                         * @instance
                         */
                        AnalyzeContentRequest.prototype.queryParams = null;
    
                        /**
                         * AnalyzeContentRequest assistQueryParams.
                         * @member {google.cloud.dialogflow.v2beta1.IAssistQueryParameters|null|undefined} assistQueryParams
                         * @memberof google.cloud.dialogflow.v2beta1.AnalyzeContentRequest
                         * @instance
                         */
                        AnalyzeContentRequest.prototype.assistQueryParams = null;
    
                        /**
                         * AnalyzeContentRequest cxParameters.
                         * @member {google.protobuf.IStruct|null|undefined} cxParameters
                         * @memberof google.cloud.dialogflow.v2beta1.AnalyzeContentRequest
                         * @instance
                         */
                        AnalyzeContentRequest.prototype.cxParameters = null;
    
                        /**
                         * AnalyzeContentRequest cxCurrentPage.
                         * @member {string} cxCurrentPage
                         * @memberof google.cloud.dialogflow.v2beta1.AnalyzeContentRequest
                         * @instance
                         */
                        AnalyzeContentRequest.prototype.cxCurrentPage = "";
    
                        /**
                         * AnalyzeContentRequest messageSendTime.
                         * @member {google.protobuf.ITimestamp|null|undefined} messageSendTime
                         * @memberof google.cloud.dialogflow.v2beta1.AnalyzeContentRequest
                         * @instance
                         */
                        AnalyzeContentRequest.prototype.messageSendTime = null;
    
                        /**
                         * AnalyzeContentRequest requestId.
                         * @member {string} requestId
                         * @memberof google.cloud.dialogflow.v2beta1.AnalyzeContentRequest
                         * @instance
                         */
                        AnalyzeContentRequest.prototype.requestId = "";
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * AnalyzeContentRequest input.
                         * @member {"textInput"|"audioInput"|"eventInput"|"suggestionInput"|"intentInput"|undefined} input
                         * @memberof google.cloud.dialogflow.v2beta1.AnalyzeContentRequest
                         * @instance
                         */
                        Object.defineProperty(AnalyzeContentRequest.prototype, "input", {
                            get: $util.oneOfGetter($oneOfFields = ["textInput", "audioInput", "eventInput", "suggestionInput", "intentInput"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new AnalyzeContentRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.AnalyzeContentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IAnalyzeContentRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.AnalyzeContentRequest} AnalyzeContentRequest instance
                         */
                        AnalyzeContentRequest.create = function create(properties) {
                            return new AnalyzeContentRequest(properties);
                        };
    
                        /**
                         * Encodes the specified AnalyzeContentRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.AnalyzeContentRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.AnalyzeContentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IAnalyzeContentRequest} message AnalyzeContentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        AnalyzeContentRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.participant != null && Object.hasOwnProperty.call(message, "participant"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.participant);
                            if (message.replyAudioConfig != null && Object.hasOwnProperty.call(message, "replyAudioConfig"))
                                $root.google.cloud.dialogflow.v2beta1.OutputAudioConfig.encode(message.replyAudioConfig, writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                            if (message.textInput != null && Object.hasOwnProperty.call(message, "textInput"))
                                $root.google.cloud.dialogflow.v2beta1.TextInput.encode(message.textInput, writer.uint32(/* id 6, wireType 2 =*/50).fork()).ldelim();
                            if (message.audioInput != null && Object.hasOwnProperty.call(message, "audioInput"))
                                $root.google.cloud.dialogflow.v2beta1.AudioInput.encode(message.audioInput, writer.uint32(/* id 7, wireType 2 =*/58).fork()).ldelim();
                            if (message.eventInput != null && Object.hasOwnProperty.call(message, "eventInput"))
                                $root.google.cloud.dialogflow.v2beta1.EventInput.encode(message.eventInput, writer.uint32(/* id 8, wireType 2 =*/66).fork()).ldelim();
                            if (message.queryParams != null && Object.hasOwnProperty.call(message, "queryParams"))
                                $root.google.cloud.dialogflow.v2beta1.QueryParameters.encode(message.queryParams, writer.uint32(/* id 9, wireType 2 =*/74).fork()).ldelim();
                            if (message.messageSendTime != null && Object.hasOwnProperty.call(message, "messageSendTime"))
                                $root.google.protobuf.Timestamp.encode(message.messageSendTime, writer.uint32(/* id 10, wireType 2 =*/82).fork()).ldelim();
                            if (message.requestId != null && Object.hasOwnProperty.call(message, "requestId"))
                                writer.uint32(/* id 11, wireType 2 =*/90).string(message.requestId);
                            if (message.suggestionInput != null && Object.hasOwnProperty.call(message, "suggestionInput"))
                                $root.google.cloud.dialogflow.v2beta1.SuggestionInput.encode(message.suggestionInput, writer.uint32(/* id 12, wireType 2 =*/98).fork()).ldelim();
                            if (message.intentInput != null && Object.hasOwnProperty.call(message, "intentInput"))
                                $root.google.cloud.dialogflow.v2beta1.IntentInput.encode(message.intentInput, writer.uint32(/* id 13, wireType 2 =*/106).fork()).ldelim();
                            if (message.assistQueryParams != null && Object.hasOwnProperty.call(message, "assistQueryParams"))
                                $root.google.cloud.dialogflow.v2beta1.AssistQueryParameters.encode(message.assistQueryParams, writer.uint32(/* id 14, wireType 2 =*/114).fork()).ldelim();
                            if (message.cxParameters != null && Object.hasOwnProperty.call(message, "cxParameters"))
                                $root.google.protobuf.Struct.encode(message.cxParameters, writer.uint32(/* id 18, wireType 2 =*/146).fork()).ldelim();
                            if (message.cxCurrentPage != null && Object.hasOwnProperty.call(message, "cxCurrentPage"))
                                writer.uint32(/* id 20, wireType 2 =*/162).string(message.cxCurrentPage);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified AnalyzeContentRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.AnalyzeContentRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.AnalyzeContentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IAnalyzeContentRequest} message AnalyzeContentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        AnalyzeContentRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an AnalyzeContentRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.AnalyzeContentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.AnalyzeContentRequest} AnalyzeContentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        AnalyzeContentRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.AnalyzeContentRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.participant = reader.string();
                                        break;
                                    }
                                case 6: {
                                        message.textInput = $root.google.cloud.dialogflow.v2beta1.TextInput.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 7: {
                                        message.audioInput = $root.google.cloud.dialogflow.v2beta1.AudioInput.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 8: {
                                        message.eventInput = $root.google.cloud.dialogflow.v2beta1.EventInput.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 12: {
                                        message.suggestionInput = $root.google.cloud.dialogflow.v2beta1.SuggestionInput.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 13: {
                                        message.intentInput = $root.google.cloud.dialogflow.v2beta1.IntentInput.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 5: {
                                        message.replyAudioConfig = $root.google.cloud.dialogflow.v2beta1.OutputAudioConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 9: {
                                        message.queryParams = $root.google.cloud.dialogflow.v2beta1.QueryParameters.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 14: {
                                        message.assistQueryParams = $root.google.cloud.dialogflow.v2beta1.AssistQueryParameters.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 18: {
                                        message.cxParameters = $root.google.protobuf.Struct.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 20: {
                                        message.cxCurrentPage = reader.string();
                                        break;
                                    }
                                case 10: {
                                        message.messageSendTime = $root.google.protobuf.Timestamp.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 11: {
                                        message.requestId = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an AnalyzeContentRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.AnalyzeContentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.AnalyzeContentRequest} AnalyzeContentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        AnalyzeContentRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an AnalyzeContentRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.AnalyzeContentRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        AnalyzeContentRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.participant != null && message.hasOwnProperty("participant"))
                                if (!$util.isString(message.participant))
                                    return "participant: string expected";
                            if (message.textInput != null && message.hasOwnProperty("textInput")) {
                                properties.input = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2beta1.TextInput.verify(message.textInput);
                                    if (error)
                                        return "textInput." + error;
                                }
                            }
                            if (message.audioInput != null && message.hasOwnProperty("audioInput")) {
                                if (properties.input === 1)
                                    return "input: multiple values";
                                properties.input = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2beta1.AudioInput.verify(message.audioInput);
                                    if (error)
                                        return "audioInput." + error;
                                }
                            }
                            if (message.eventInput != null && message.hasOwnProperty("eventInput")) {
                                if (properties.input === 1)
                                    return "input: multiple values";
                                properties.input = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2beta1.EventInput.verify(message.eventInput);
                                    if (error)
                                        return "eventInput." + error;
                                }
                            }
                            if (message.suggestionInput != null && message.hasOwnProperty("suggestionInput")) {
                                if (properties.input === 1)
                                    return "input: multiple values";
                                properties.input = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2beta1.SuggestionInput.verify(message.suggestionInput);
                                    if (error)
                                        return "suggestionInput." + error;
                                }
                            }
                            if (message.intentInput != null && message.hasOwnProperty("intentInput")) {
                                if (properties.input === 1)
                                    return "input: multiple values";
                                properties.input = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2beta1.IntentInput.verify(message.intentInput);
                                    if (error)
                                        return "intentInput." + error;
                                }
                            }
                            if (message.replyAudioConfig != null && message.hasOwnProperty("replyAudioConfig")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.OutputAudioConfig.verify(message.replyAudioConfig);
                                if (error)
                                    return "replyAudioConfig." + error;
                            }
                            if (message.queryParams != null && message.hasOwnProperty("queryParams")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.QueryParameters.verify(message.queryParams);
                                if (error)
                                    return "queryParams." + error;
                            }
                            if (message.assistQueryParams != null && message.hasOwnProperty("assistQueryParams")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.AssistQueryParameters.verify(message.assistQueryParams);
                                if (error)
                                    return "assistQueryParams." + error;
                            }
                            if (message.cxParameters != null && message.hasOwnProperty("cxParameters")) {
                                var error = $root.google.protobuf.Struct.verify(message.cxParameters);
                                if (error)
                                    return "cxParameters." + error;
                            }
                            if (message.cxCurrentPage != null && message.hasOwnProperty("cxCurrentPage"))
                                if (!$util.isString(message.cxCurrentPage))
                                    return "cxCurrentPage: string expected";
                            if (message.messageSendTime != null && message.hasOwnProperty("messageSendTime")) {
                                var error = $root.google.protobuf.Timestamp.verify(message.messageSendTime);
                                if (error)
                                    return "messageSendTime." + error;
                            }
                            if (message.requestId != null && message.hasOwnProperty("requestId"))
                                if (!$util.isString(message.requestId))
                                    return "requestId: string expected";
                            return null;
                        };
    
                        /**
                         * Creates an AnalyzeContentRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.AnalyzeContentRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.AnalyzeContentRequest} AnalyzeContentRequest
                         */
                        AnalyzeContentRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.AnalyzeContentRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.AnalyzeContentRequest();
                            if (object.participant != null)
                                message.participant = String(object.participant);
                            if (object.textInput != null) {
                                if (typeof object.textInput !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.AnalyzeContentRequest.textInput: object expected");
                                message.textInput = $root.google.cloud.dialogflow.v2beta1.TextInput.fromObject(object.textInput);
                            }
                            if (object.audioInput != null) {
                                if (typeof object.audioInput !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.AnalyzeContentRequest.audioInput: object expected");
                                message.audioInput = $root.google.cloud.dialogflow.v2beta1.AudioInput.fromObject(object.audioInput);
                            }
                            if (object.eventInput != null) {
                                if (typeof object.eventInput !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.AnalyzeContentRequest.eventInput: object expected");
                                message.eventInput = $root.google.cloud.dialogflow.v2beta1.EventInput.fromObject(object.eventInput);
                            }
                            if (object.suggestionInput != null) {
                                if (typeof object.suggestionInput !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.AnalyzeContentRequest.suggestionInput: object expected");
                                message.suggestionInput = $root.google.cloud.dialogflow.v2beta1.SuggestionInput.fromObject(object.suggestionInput);
                            }
                            if (object.intentInput != null) {
                                if (typeof object.intentInput !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.AnalyzeContentRequest.intentInput: object expected");
                                message.intentInput = $root.google.cloud.dialogflow.v2beta1.IntentInput.fromObject(object.intentInput);
                            }
                            if (object.replyAudioConfig != null) {
                                if (typeof object.replyAudioConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.AnalyzeContentRequest.replyAudioConfig: object expected");
                                message.replyAudioConfig = $root.google.cloud.dialogflow.v2beta1.OutputAudioConfig.fromObject(object.replyAudioConfig);
                            }
                            if (object.queryParams != null) {
                                if (typeof object.queryParams !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.AnalyzeContentRequest.queryParams: object expected");
                                message.queryParams = $root.google.cloud.dialogflow.v2beta1.QueryParameters.fromObject(object.queryParams);
                            }
                            if (object.assistQueryParams != null) {
                                if (typeof object.assistQueryParams !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.AnalyzeContentRequest.assistQueryParams: object expected");
                                message.assistQueryParams = $root.google.cloud.dialogflow.v2beta1.AssistQueryParameters.fromObject(object.assistQueryParams);
                            }
                            if (object.cxParameters != null) {
                                if (typeof object.cxParameters !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.AnalyzeContentRequest.cxParameters: object expected");
                                message.cxParameters = $root.google.protobuf.Struct.fromObject(object.cxParameters);
                            }
                            if (object.cxCurrentPage != null)
                                message.cxCurrentPage = String(object.cxCurrentPage);
                            if (object.messageSendTime != null) {
                                if (typeof object.messageSendTime !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.AnalyzeContentRequest.messageSendTime: object expected");
                                message.messageSendTime = $root.google.protobuf.Timestamp.fromObject(object.messageSendTime);
                            }
                            if (object.requestId != null)
                                message.requestId = String(object.requestId);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an AnalyzeContentRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.AnalyzeContentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.AnalyzeContentRequest} message AnalyzeContentRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        AnalyzeContentRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.participant = "";
                                object.replyAudioConfig = null;
                                object.queryParams = null;
                                object.messageSendTime = null;
                                object.requestId = "";
                                object.assistQueryParams = null;
                                object.cxParameters = null;
                                object.cxCurrentPage = "";
                            }
                            if (message.participant != null && message.hasOwnProperty("participant"))
                                object.participant = message.participant;
                            if (message.replyAudioConfig != null && message.hasOwnProperty("replyAudioConfig"))
                                object.replyAudioConfig = $root.google.cloud.dialogflow.v2beta1.OutputAudioConfig.toObject(message.replyAudioConfig, options);
                            if (message.textInput != null && message.hasOwnProperty("textInput")) {
                                object.textInput = $root.google.cloud.dialogflow.v2beta1.TextInput.toObject(message.textInput, options);
                                if (options.oneofs)
                                    object.input = "textInput";
                            }
                            if (message.audioInput != null && message.hasOwnProperty("audioInput")) {
                                object.audioInput = $root.google.cloud.dialogflow.v2beta1.AudioInput.toObject(message.audioInput, options);
                                if (options.oneofs)
                                    object.input = "audioInput";
                            }
                            if (message.eventInput != null && message.hasOwnProperty("eventInput")) {
                                object.eventInput = $root.google.cloud.dialogflow.v2beta1.EventInput.toObject(message.eventInput, options);
                                if (options.oneofs)
                                    object.input = "eventInput";
                            }
                            if (message.queryParams != null && message.hasOwnProperty("queryParams"))
                                object.queryParams = $root.google.cloud.dialogflow.v2beta1.QueryParameters.toObject(message.queryParams, options);
                            if (message.messageSendTime != null && message.hasOwnProperty("messageSendTime"))
                                object.messageSendTime = $root.google.protobuf.Timestamp.toObject(message.messageSendTime, options);
                            if (message.requestId != null && message.hasOwnProperty("requestId"))
                                object.requestId = message.requestId;
                            if (message.suggestionInput != null && message.hasOwnProperty("suggestionInput")) {
                                object.suggestionInput = $root.google.cloud.dialogflow.v2beta1.SuggestionInput.toObject(message.suggestionInput, options);
                                if (options.oneofs)
                                    object.input = "suggestionInput";
                            }
                            if (message.intentInput != null && message.hasOwnProperty("intentInput")) {
                                object.intentInput = $root.google.cloud.dialogflow.v2beta1.IntentInput.toObject(message.intentInput, options);
                                if (options.oneofs)
                                    object.input = "intentInput";
                            }
                            if (message.assistQueryParams != null && message.hasOwnProperty("assistQueryParams"))
                                object.assistQueryParams = $root.google.cloud.dialogflow.v2beta1.AssistQueryParameters.toObject(message.assistQueryParams, options);
                            if (message.cxParameters != null && message.hasOwnProperty("cxParameters"))
                                object.cxParameters = $root.google.protobuf.Struct.toObject(message.cxParameters, options);
                            if (message.cxCurrentPage != null && message.hasOwnProperty("cxCurrentPage"))
                                object.cxCurrentPage = message.cxCurrentPage;
                            return object;
                        };
    
                        /**
                         * Converts this AnalyzeContentRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.AnalyzeContentRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        AnalyzeContentRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for AnalyzeContentRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.AnalyzeContentRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        AnalyzeContentRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.AnalyzeContentRequest";
                        };
    
                        return AnalyzeContentRequest;
                    })();
    
                    v2beta1.DtmfParameters = (function() {
    
                        /**
                         * Properties of a DtmfParameters.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IDtmfParameters
                         * @property {boolean|null} [acceptsDtmfInput] DtmfParameters acceptsDtmfInput
                         */
    
                        /**
                         * Constructs a new DtmfParameters.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a DtmfParameters.
                         * @implements IDtmfParameters
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IDtmfParameters=} [properties] Properties to set
                         */
                        function DtmfParameters(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * DtmfParameters acceptsDtmfInput.
                         * @member {boolean} acceptsDtmfInput
                         * @memberof google.cloud.dialogflow.v2beta1.DtmfParameters
                         * @instance
                         */
                        DtmfParameters.prototype.acceptsDtmfInput = false;
    
                        /**
                         * Creates a new DtmfParameters instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.DtmfParameters
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDtmfParameters=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.DtmfParameters} DtmfParameters instance
                         */
                        DtmfParameters.create = function create(properties) {
                            return new DtmfParameters(properties);
                        };
    
                        /**
                         * Encodes the specified DtmfParameters message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.DtmfParameters.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.DtmfParameters
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDtmfParameters} message DtmfParameters message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DtmfParameters.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.acceptsDtmfInput != null && Object.hasOwnProperty.call(message, "acceptsDtmfInput"))
                                writer.uint32(/* id 1, wireType 0 =*/8).bool(message.acceptsDtmfInput);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified DtmfParameters message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.DtmfParameters.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.DtmfParameters
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDtmfParameters} message DtmfParameters message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DtmfParameters.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a DtmfParameters message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.DtmfParameters
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.DtmfParameters} DtmfParameters
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DtmfParameters.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.DtmfParameters();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.acceptsDtmfInput = reader.bool();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a DtmfParameters message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.DtmfParameters
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.DtmfParameters} DtmfParameters
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DtmfParameters.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a DtmfParameters message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.DtmfParameters
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        DtmfParameters.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.acceptsDtmfInput != null && message.hasOwnProperty("acceptsDtmfInput"))
                                if (typeof message.acceptsDtmfInput !== "boolean")
                                    return "acceptsDtmfInput: boolean expected";
                            return null;
                        };
    
                        /**
                         * Creates a DtmfParameters message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.DtmfParameters
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.DtmfParameters} DtmfParameters
                         */
                        DtmfParameters.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.DtmfParameters)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.DtmfParameters();
                            if (object.acceptsDtmfInput != null)
                                message.acceptsDtmfInput = Boolean(object.acceptsDtmfInput);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a DtmfParameters message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.DtmfParameters
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.DtmfParameters} message DtmfParameters
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        DtmfParameters.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.acceptsDtmfInput = false;
                            if (message.acceptsDtmfInput != null && message.hasOwnProperty("acceptsDtmfInput"))
                                object.acceptsDtmfInput = message.acceptsDtmfInput;
                            return object;
                        };
    
                        /**
                         * Converts this DtmfParameters to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.DtmfParameters
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        DtmfParameters.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for DtmfParameters
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.DtmfParameters
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        DtmfParameters.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.DtmfParameters";
                        };
    
                        return DtmfParameters;
                    })();
    
                    v2beta1.AnalyzeContentResponse = (function() {
    
                        /**
                         * Properties of an AnalyzeContentResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IAnalyzeContentResponse
                         * @property {string|null} [replyText] AnalyzeContentResponse replyText
                         * @property {google.cloud.dialogflow.v2beta1.IOutputAudio|null} [replyAudio] AnalyzeContentResponse replyAudio
                         * @property {google.cloud.dialogflow.v2beta1.IAutomatedAgentReply|null} [automatedAgentReply] AnalyzeContentResponse automatedAgentReply
                         * @property {google.cloud.dialogflow.v2beta1.IMessage|null} [message] AnalyzeContentResponse message
                         * @property {Array.<google.cloud.dialogflow.v2beta1.ISuggestionResult>|null} [humanAgentSuggestionResults] AnalyzeContentResponse humanAgentSuggestionResults
                         * @property {Array.<google.cloud.dialogflow.v2beta1.ISuggestionResult>|null} [endUserSuggestionResults] AnalyzeContentResponse endUserSuggestionResults
                         * @property {google.cloud.dialogflow.v2beta1.IDtmfParameters|null} [dtmfParameters] AnalyzeContentResponse dtmfParameters
                         */
    
                        /**
                         * Constructs a new AnalyzeContentResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an AnalyzeContentResponse.
                         * @implements IAnalyzeContentResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IAnalyzeContentResponse=} [properties] Properties to set
                         */
                        function AnalyzeContentResponse(properties) {
                            this.humanAgentSuggestionResults = [];
                            this.endUserSuggestionResults = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * AnalyzeContentResponse replyText.
                         * @member {string} replyText
                         * @memberof google.cloud.dialogflow.v2beta1.AnalyzeContentResponse
                         * @instance
                         */
                        AnalyzeContentResponse.prototype.replyText = "";
    
                        /**
                         * AnalyzeContentResponse replyAudio.
                         * @member {google.cloud.dialogflow.v2beta1.IOutputAudio|null|undefined} replyAudio
                         * @memberof google.cloud.dialogflow.v2beta1.AnalyzeContentResponse
                         * @instance
                         */
                        AnalyzeContentResponse.prototype.replyAudio = null;
    
                        /**
                         * AnalyzeContentResponse automatedAgentReply.
                         * @member {google.cloud.dialogflow.v2beta1.IAutomatedAgentReply|null|undefined} automatedAgentReply
                         * @memberof google.cloud.dialogflow.v2beta1.AnalyzeContentResponse
                         * @instance
                         */
                        AnalyzeContentResponse.prototype.automatedAgentReply = null;
    
                        /**
                         * AnalyzeContentResponse message.
                         * @member {google.cloud.dialogflow.v2beta1.IMessage|null|undefined} message
                         * @memberof google.cloud.dialogflow.v2beta1.AnalyzeContentResponse
                         * @instance
                         */
                        AnalyzeContentResponse.prototype.message = null;
    
                        /**
                         * AnalyzeContentResponse humanAgentSuggestionResults.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.ISuggestionResult>} humanAgentSuggestionResults
                         * @memberof google.cloud.dialogflow.v2beta1.AnalyzeContentResponse
                         * @instance
                         */
                        AnalyzeContentResponse.prototype.humanAgentSuggestionResults = $util.emptyArray;
    
                        /**
                         * AnalyzeContentResponse endUserSuggestionResults.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.ISuggestionResult>} endUserSuggestionResults
                         * @memberof google.cloud.dialogflow.v2beta1.AnalyzeContentResponse
                         * @instance
                         */
                        AnalyzeContentResponse.prototype.endUserSuggestionResults = $util.emptyArray;
    
                        /**
                         * AnalyzeContentResponse dtmfParameters.
                         * @member {google.cloud.dialogflow.v2beta1.IDtmfParameters|null|undefined} dtmfParameters
                         * @memberof google.cloud.dialogflow.v2beta1.AnalyzeContentResponse
                         * @instance
                         */
                        AnalyzeContentResponse.prototype.dtmfParameters = null;
    
                        /**
                         * Creates a new AnalyzeContentResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.AnalyzeContentResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IAnalyzeContentResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.AnalyzeContentResponse} AnalyzeContentResponse instance
                         */
                        AnalyzeContentResponse.create = function create(properties) {
                            return new AnalyzeContentResponse(properties);
                        };
    
                        /**
                         * Encodes the specified AnalyzeContentResponse message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.AnalyzeContentResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.AnalyzeContentResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IAnalyzeContentResponse} message AnalyzeContentResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        AnalyzeContentResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.replyText != null && Object.hasOwnProperty.call(message, "replyText"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.replyText);
                            if (message.replyAudio != null && Object.hasOwnProperty.call(message, "replyAudio"))
                                $root.google.cloud.dialogflow.v2beta1.OutputAudio.encode(message.replyAudio, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.automatedAgentReply != null && Object.hasOwnProperty.call(message, "automatedAgentReply"))
                                $root.google.cloud.dialogflow.v2beta1.AutomatedAgentReply.encode(message.automatedAgentReply, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            if (message.message != null && Object.hasOwnProperty.call(message, "message"))
                                $root.google.cloud.dialogflow.v2beta1.Message.encode(message.message, writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                            if (message.humanAgentSuggestionResults != null && message.humanAgentSuggestionResults.length)
                                for (var i = 0; i < message.humanAgentSuggestionResults.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.SuggestionResult.encode(message.humanAgentSuggestionResults[i], writer.uint32(/* id 6, wireType 2 =*/50).fork()).ldelim();
                            if (message.endUserSuggestionResults != null && message.endUserSuggestionResults.length)
                                for (var i = 0; i < message.endUserSuggestionResults.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.SuggestionResult.encode(message.endUserSuggestionResults[i], writer.uint32(/* id 7, wireType 2 =*/58).fork()).ldelim();
                            if (message.dtmfParameters != null && Object.hasOwnProperty.call(message, "dtmfParameters"))
                                $root.google.cloud.dialogflow.v2beta1.DtmfParameters.encode(message.dtmfParameters, writer.uint32(/* id 9, wireType 2 =*/74).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified AnalyzeContentResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.AnalyzeContentResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.AnalyzeContentResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IAnalyzeContentResponse} message AnalyzeContentResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        AnalyzeContentResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an AnalyzeContentResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.AnalyzeContentResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.AnalyzeContentResponse} AnalyzeContentResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        AnalyzeContentResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.AnalyzeContentResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.replyText = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.replyAudio = $root.google.cloud.dialogflow.v2beta1.OutputAudio.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 3: {
                                        message.automatedAgentReply = $root.google.cloud.dialogflow.v2beta1.AutomatedAgentReply.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 5: {
                                        message.message = $root.google.cloud.dialogflow.v2beta1.Message.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 6: {
                                        if (!(message.humanAgentSuggestionResults && message.humanAgentSuggestionResults.length))
                                            message.humanAgentSuggestionResults = [];
                                        message.humanAgentSuggestionResults.push($root.google.cloud.dialogflow.v2beta1.SuggestionResult.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 7: {
                                        if (!(message.endUserSuggestionResults && message.endUserSuggestionResults.length))
                                            message.endUserSuggestionResults = [];
                                        message.endUserSuggestionResults.push($root.google.cloud.dialogflow.v2beta1.SuggestionResult.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 9: {
                                        message.dtmfParameters = $root.google.cloud.dialogflow.v2beta1.DtmfParameters.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an AnalyzeContentResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.AnalyzeContentResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.AnalyzeContentResponse} AnalyzeContentResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        AnalyzeContentResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an AnalyzeContentResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.AnalyzeContentResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        AnalyzeContentResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.replyText != null && message.hasOwnProperty("replyText"))
                                if (!$util.isString(message.replyText))
                                    return "replyText: string expected";
                            if (message.replyAudio != null && message.hasOwnProperty("replyAudio")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.OutputAudio.verify(message.replyAudio);
                                if (error)
                                    return "replyAudio." + error;
                            }
                            if (message.automatedAgentReply != null && message.hasOwnProperty("automatedAgentReply")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.AutomatedAgentReply.verify(message.automatedAgentReply);
                                if (error)
                                    return "automatedAgentReply." + error;
                            }
                            if (message.message != null && message.hasOwnProperty("message")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.Message.verify(message.message);
                                if (error)
                                    return "message." + error;
                            }
                            if (message.humanAgentSuggestionResults != null && message.hasOwnProperty("humanAgentSuggestionResults")) {
                                if (!Array.isArray(message.humanAgentSuggestionResults))
                                    return "humanAgentSuggestionResults: array expected";
                                for (var i = 0; i < message.humanAgentSuggestionResults.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.SuggestionResult.verify(message.humanAgentSuggestionResults[i]);
                                    if (error)
                                        return "humanAgentSuggestionResults." + error;
                                }
                            }
                            if (message.endUserSuggestionResults != null && message.hasOwnProperty("endUserSuggestionResults")) {
                                if (!Array.isArray(message.endUserSuggestionResults))
                                    return "endUserSuggestionResults: array expected";
                                for (var i = 0; i < message.endUserSuggestionResults.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.SuggestionResult.verify(message.endUserSuggestionResults[i]);
                                    if (error)
                                        return "endUserSuggestionResults." + error;
                                }
                            }
                            if (message.dtmfParameters != null && message.hasOwnProperty("dtmfParameters")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.DtmfParameters.verify(message.dtmfParameters);
                                if (error)
                                    return "dtmfParameters." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates an AnalyzeContentResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.AnalyzeContentResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.AnalyzeContentResponse} AnalyzeContentResponse
                         */
                        AnalyzeContentResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.AnalyzeContentResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.AnalyzeContentResponse();
                            if (object.replyText != null)
                                message.replyText = String(object.replyText);
                            if (object.replyAudio != null) {
                                if (typeof object.replyAudio !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.AnalyzeContentResponse.replyAudio: object expected");
                                message.replyAudio = $root.google.cloud.dialogflow.v2beta1.OutputAudio.fromObject(object.replyAudio);
                            }
                            if (object.automatedAgentReply != null) {
                                if (typeof object.automatedAgentReply !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.AnalyzeContentResponse.automatedAgentReply: object expected");
                                message.automatedAgentReply = $root.google.cloud.dialogflow.v2beta1.AutomatedAgentReply.fromObject(object.automatedAgentReply);
                            }
                            if (object.message != null) {
                                if (typeof object.message !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.AnalyzeContentResponse.message: object expected");
                                message.message = $root.google.cloud.dialogflow.v2beta1.Message.fromObject(object.message);
                            }
                            if (object.humanAgentSuggestionResults) {
                                if (!Array.isArray(object.humanAgentSuggestionResults))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.AnalyzeContentResponse.humanAgentSuggestionResults: array expected");
                                message.humanAgentSuggestionResults = [];
                                for (var i = 0; i < object.humanAgentSuggestionResults.length; ++i) {
                                    if (typeof object.humanAgentSuggestionResults[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.AnalyzeContentResponse.humanAgentSuggestionResults: object expected");
                                    message.humanAgentSuggestionResults[i] = $root.google.cloud.dialogflow.v2beta1.SuggestionResult.fromObject(object.humanAgentSuggestionResults[i]);
                                }
                            }
                            if (object.endUserSuggestionResults) {
                                if (!Array.isArray(object.endUserSuggestionResults))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.AnalyzeContentResponse.endUserSuggestionResults: array expected");
                                message.endUserSuggestionResults = [];
                                for (var i = 0; i < object.endUserSuggestionResults.length; ++i) {
                                    if (typeof object.endUserSuggestionResults[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.AnalyzeContentResponse.endUserSuggestionResults: object expected");
                                    message.endUserSuggestionResults[i] = $root.google.cloud.dialogflow.v2beta1.SuggestionResult.fromObject(object.endUserSuggestionResults[i]);
                                }
                            }
                            if (object.dtmfParameters != null) {
                                if (typeof object.dtmfParameters !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.AnalyzeContentResponse.dtmfParameters: object expected");
                                message.dtmfParameters = $root.google.cloud.dialogflow.v2beta1.DtmfParameters.fromObject(object.dtmfParameters);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an AnalyzeContentResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.AnalyzeContentResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.AnalyzeContentResponse} message AnalyzeContentResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        AnalyzeContentResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults) {
                                object.humanAgentSuggestionResults = [];
                                object.endUserSuggestionResults = [];
                            }
                            if (options.defaults) {
                                object.replyText = "";
                                object.replyAudio = null;
                                object.automatedAgentReply = null;
                                object.message = null;
                                object.dtmfParameters = null;
                            }
                            if (message.replyText != null && message.hasOwnProperty("replyText"))
                                object.replyText = message.replyText;
                            if (message.replyAudio != null && message.hasOwnProperty("replyAudio"))
                                object.replyAudio = $root.google.cloud.dialogflow.v2beta1.OutputAudio.toObject(message.replyAudio, options);
                            if (message.automatedAgentReply != null && message.hasOwnProperty("automatedAgentReply"))
                                object.automatedAgentReply = $root.google.cloud.dialogflow.v2beta1.AutomatedAgentReply.toObject(message.automatedAgentReply, options);
                            if (message.message != null && message.hasOwnProperty("message"))
                                object.message = $root.google.cloud.dialogflow.v2beta1.Message.toObject(message.message, options);
                            if (message.humanAgentSuggestionResults && message.humanAgentSuggestionResults.length) {
                                object.humanAgentSuggestionResults = [];
                                for (var j = 0; j < message.humanAgentSuggestionResults.length; ++j)
                                    object.humanAgentSuggestionResults[j] = $root.google.cloud.dialogflow.v2beta1.SuggestionResult.toObject(message.humanAgentSuggestionResults[j], options);
                            }
                            if (message.endUserSuggestionResults && message.endUserSuggestionResults.length) {
                                object.endUserSuggestionResults = [];
                                for (var j = 0; j < message.endUserSuggestionResults.length; ++j)
                                    object.endUserSuggestionResults[j] = $root.google.cloud.dialogflow.v2beta1.SuggestionResult.toObject(message.endUserSuggestionResults[j], options);
                            }
                            if (message.dtmfParameters != null && message.hasOwnProperty("dtmfParameters"))
                                object.dtmfParameters = $root.google.cloud.dialogflow.v2beta1.DtmfParameters.toObject(message.dtmfParameters, options);
                            return object;
                        };
    
                        /**
                         * Converts this AnalyzeContentResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.AnalyzeContentResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        AnalyzeContentResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for AnalyzeContentResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.AnalyzeContentResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        AnalyzeContentResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.AnalyzeContentResponse";
                        };
    
                        return AnalyzeContentResponse;
                    })();
    
                    v2beta1.InputTextConfig = (function() {
    
                        /**
                         * Properties of an InputTextConfig.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IInputTextConfig
                         * @property {string|null} [languageCode] InputTextConfig languageCode
                         */
    
                        /**
                         * Constructs a new InputTextConfig.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an InputTextConfig.
                         * @implements IInputTextConfig
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IInputTextConfig=} [properties] Properties to set
                         */
                        function InputTextConfig(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * InputTextConfig languageCode.
                         * @member {string} languageCode
                         * @memberof google.cloud.dialogflow.v2beta1.InputTextConfig
                         * @instance
                         */
                        InputTextConfig.prototype.languageCode = "";
    
                        /**
                         * Creates a new InputTextConfig instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.InputTextConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IInputTextConfig=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.InputTextConfig} InputTextConfig instance
                         */
                        InputTextConfig.create = function create(properties) {
                            return new InputTextConfig(properties);
                        };
    
                        /**
                         * Encodes the specified InputTextConfig message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.InputTextConfig.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.InputTextConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IInputTextConfig} message InputTextConfig message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        InputTextConfig.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.languageCode != null && Object.hasOwnProperty.call(message, "languageCode"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.languageCode);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified InputTextConfig message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.InputTextConfig.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.InputTextConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IInputTextConfig} message InputTextConfig message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        InputTextConfig.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an InputTextConfig message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.InputTextConfig
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.InputTextConfig} InputTextConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        InputTextConfig.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.InputTextConfig();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.languageCode = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an InputTextConfig message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.InputTextConfig
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.InputTextConfig} InputTextConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        InputTextConfig.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an InputTextConfig message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.InputTextConfig
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        InputTextConfig.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                if (!$util.isString(message.languageCode))
                                    return "languageCode: string expected";
                            return null;
                        };
    
                        /**
                         * Creates an InputTextConfig message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.InputTextConfig
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.InputTextConfig} InputTextConfig
                         */
                        InputTextConfig.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.InputTextConfig)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.InputTextConfig();
                            if (object.languageCode != null)
                                message.languageCode = String(object.languageCode);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an InputTextConfig message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.InputTextConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.InputTextConfig} message InputTextConfig
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        InputTextConfig.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.languageCode = "";
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                object.languageCode = message.languageCode;
                            return object;
                        };
    
                        /**
                         * Converts this InputTextConfig to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.InputTextConfig
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        InputTextConfig.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for InputTextConfig
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.InputTextConfig
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        InputTextConfig.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.InputTextConfig";
                        };
    
                        return InputTextConfig;
                    })();
    
                    v2beta1.StreamingAnalyzeContentRequest = (function() {
    
                        /**
                         * Properties of a StreamingAnalyzeContentRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IStreamingAnalyzeContentRequest
                         * @property {string|null} [participant] StreamingAnalyzeContentRequest participant
                         * @property {google.cloud.dialogflow.v2beta1.IInputAudioConfig|null} [audioConfig] StreamingAnalyzeContentRequest audioConfig
                         * @property {google.cloud.dialogflow.v2beta1.IInputTextConfig|null} [textConfig] StreamingAnalyzeContentRequest textConfig
                         * @property {google.cloud.dialogflow.v2beta1.IOutputAudioConfig|null} [replyAudioConfig] StreamingAnalyzeContentRequest replyAudioConfig
                         * @property {Uint8Array|null} [inputAudio] StreamingAnalyzeContentRequest inputAudio
                         * @property {string|null} [inputText] StreamingAnalyzeContentRequest inputText
                         * @property {google.cloud.dialogflow.v2beta1.ITelephonyDtmfEvents|null} [inputDtmf] StreamingAnalyzeContentRequest inputDtmf
                         * @property {string|null} [inputIntent] StreamingAnalyzeContentRequest inputIntent
                         * @property {string|null} [inputEvent] StreamingAnalyzeContentRequest inputEvent
                         * @property {google.cloud.dialogflow.v2beta1.IQueryParameters|null} [queryParams] StreamingAnalyzeContentRequest queryParams
                         * @property {google.cloud.dialogflow.v2beta1.IAssistQueryParameters|null} [assistQueryParams] StreamingAnalyzeContentRequest assistQueryParams
                         * @property {google.protobuf.IStruct|null} [cxParameters] StreamingAnalyzeContentRequest cxParameters
                         * @property {string|null} [cxCurrentPage] StreamingAnalyzeContentRequest cxCurrentPage
                         * @property {boolean|null} [enableExtendedStreaming] StreamingAnalyzeContentRequest enableExtendedStreaming
                         * @property {boolean|null} [enablePartialAutomatedAgentReply] StreamingAnalyzeContentRequest enablePartialAutomatedAgentReply
                         * @property {boolean|null} [enableDebuggingInfo] StreamingAnalyzeContentRequest enableDebuggingInfo
                         */
    
                        /**
                         * Constructs a new StreamingAnalyzeContentRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a StreamingAnalyzeContentRequest.
                         * @implements IStreamingAnalyzeContentRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IStreamingAnalyzeContentRequest=} [properties] Properties to set
                         */
                        function StreamingAnalyzeContentRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * StreamingAnalyzeContentRequest participant.
                         * @member {string} participant
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentRequest
                         * @instance
                         */
                        StreamingAnalyzeContentRequest.prototype.participant = "";
    
                        /**
                         * StreamingAnalyzeContentRequest audioConfig.
                         * @member {google.cloud.dialogflow.v2beta1.IInputAudioConfig|null|undefined} audioConfig
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentRequest
                         * @instance
                         */
                        StreamingAnalyzeContentRequest.prototype.audioConfig = null;
    
                        /**
                         * StreamingAnalyzeContentRequest textConfig.
                         * @member {google.cloud.dialogflow.v2beta1.IInputTextConfig|null|undefined} textConfig
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentRequest
                         * @instance
                         */
                        StreamingAnalyzeContentRequest.prototype.textConfig = null;
    
                        /**
                         * StreamingAnalyzeContentRequest replyAudioConfig.
                         * @member {google.cloud.dialogflow.v2beta1.IOutputAudioConfig|null|undefined} replyAudioConfig
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentRequest
                         * @instance
                         */
                        StreamingAnalyzeContentRequest.prototype.replyAudioConfig = null;
    
                        /**
                         * StreamingAnalyzeContentRequest inputAudio.
                         * @member {Uint8Array|null|undefined} inputAudio
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentRequest
                         * @instance
                         */
                        StreamingAnalyzeContentRequest.prototype.inputAudio = null;
    
                        /**
                         * StreamingAnalyzeContentRequest inputText.
                         * @member {string|null|undefined} inputText
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentRequest
                         * @instance
                         */
                        StreamingAnalyzeContentRequest.prototype.inputText = null;
    
                        /**
                         * StreamingAnalyzeContentRequest inputDtmf.
                         * @member {google.cloud.dialogflow.v2beta1.ITelephonyDtmfEvents|null|undefined} inputDtmf
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentRequest
                         * @instance
                         */
                        StreamingAnalyzeContentRequest.prototype.inputDtmf = null;
    
                        /**
                         * StreamingAnalyzeContentRequest inputIntent.
                         * @member {string|null|undefined} inputIntent
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentRequest
                         * @instance
                         */
                        StreamingAnalyzeContentRequest.prototype.inputIntent = null;
    
                        /**
                         * StreamingAnalyzeContentRequest inputEvent.
                         * @member {string|null|undefined} inputEvent
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentRequest
                         * @instance
                         */
                        StreamingAnalyzeContentRequest.prototype.inputEvent = null;
    
                        /**
                         * StreamingAnalyzeContentRequest queryParams.
                         * @member {google.cloud.dialogflow.v2beta1.IQueryParameters|null|undefined} queryParams
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentRequest
                         * @instance
                         */
                        StreamingAnalyzeContentRequest.prototype.queryParams = null;
    
                        /**
                         * StreamingAnalyzeContentRequest assistQueryParams.
                         * @member {google.cloud.dialogflow.v2beta1.IAssistQueryParameters|null|undefined} assistQueryParams
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentRequest
                         * @instance
                         */
                        StreamingAnalyzeContentRequest.prototype.assistQueryParams = null;
    
                        /**
                         * StreamingAnalyzeContentRequest cxParameters.
                         * @member {google.protobuf.IStruct|null|undefined} cxParameters
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentRequest
                         * @instance
                         */
                        StreamingAnalyzeContentRequest.prototype.cxParameters = null;
    
                        /**
                         * StreamingAnalyzeContentRequest cxCurrentPage.
                         * @member {string} cxCurrentPage
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentRequest
                         * @instance
                         */
                        StreamingAnalyzeContentRequest.prototype.cxCurrentPage = "";
    
                        /**
                         * StreamingAnalyzeContentRequest enableExtendedStreaming.
                         * @member {boolean} enableExtendedStreaming
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentRequest
                         * @instance
                         */
                        StreamingAnalyzeContentRequest.prototype.enableExtendedStreaming = false;
    
                        /**
                         * StreamingAnalyzeContentRequest enablePartialAutomatedAgentReply.
                         * @member {boolean} enablePartialAutomatedAgentReply
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentRequest
                         * @instance
                         */
                        StreamingAnalyzeContentRequest.prototype.enablePartialAutomatedAgentReply = false;
    
                        /**
                         * StreamingAnalyzeContentRequest enableDebuggingInfo.
                         * @member {boolean} enableDebuggingInfo
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentRequest
                         * @instance
                         */
                        StreamingAnalyzeContentRequest.prototype.enableDebuggingInfo = false;
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * StreamingAnalyzeContentRequest config.
                         * @member {"audioConfig"|"textConfig"|undefined} config
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentRequest
                         * @instance
                         */
                        Object.defineProperty(StreamingAnalyzeContentRequest.prototype, "config", {
                            get: $util.oneOfGetter($oneOfFields = ["audioConfig", "textConfig"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * StreamingAnalyzeContentRequest input.
                         * @member {"inputAudio"|"inputText"|"inputDtmf"|"inputIntent"|"inputEvent"|undefined} input
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentRequest
                         * @instance
                         */
                        Object.defineProperty(StreamingAnalyzeContentRequest.prototype, "input", {
                            get: $util.oneOfGetter($oneOfFields = ["inputAudio", "inputText", "inputDtmf", "inputIntent", "inputEvent"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new StreamingAnalyzeContentRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IStreamingAnalyzeContentRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentRequest} StreamingAnalyzeContentRequest instance
                         */
                        StreamingAnalyzeContentRequest.create = function create(properties) {
                            return new StreamingAnalyzeContentRequest(properties);
                        };
    
                        /**
                         * Encodes the specified StreamingAnalyzeContentRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IStreamingAnalyzeContentRequest} message StreamingAnalyzeContentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        StreamingAnalyzeContentRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.participant != null && Object.hasOwnProperty.call(message, "participant"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.participant);
                            if (message.audioConfig != null && Object.hasOwnProperty.call(message, "audioConfig"))
                                $root.google.cloud.dialogflow.v2beta1.InputAudioConfig.encode(message.audioConfig, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.textConfig != null && Object.hasOwnProperty.call(message, "textConfig"))
                                $root.google.cloud.dialogflow.v2beta1.InputTextConfig.encode(message.textConfig, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            if (message.replyAudioConfig != null && Object.hasOwnProperty.call(message, "replyAudioConfig"))
                                $root.google.cloud.dialogflow.v2beta1.OutputAudioConfig.encode(message.replyAudioConfig, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            if (message.inputAudio != null && Object.hasOwnProperty.call(message, "inputAudio"))
                                writer.uint32(/* id 5, wireType 2 =*/42).bytes(message.inputAudio);
                            if (message.inputText != null && Object.hasOwnProperty.call(message, "inputText"))
                                writer.uint32(/* id 6, wireType 2 =*/50).string(message.inputText);
                            if (message.queryParams != null && Object.hasOwnProperty.call(message, "queryParams"))
                                $root.google.cloud.dialogflow.v2beta1.QueryParameters.encode(message.queryParams, writer.uint32(/* id 7, wireType 2 =*/58).fork()).ldelim();
                            if (message.assistQueryParams != null && Object.hasOwnProperty.call(message, "assistQueryParams"))
                                $root.google.cloud.dialogflow.v2beta1.AssistQueryParameters.encode(message.assistQueryParams, writer.uint32(/* id 8, wireType 2 =*/66).fork()).ldelim();
                            if (message.inputDtmf != null && Object.hasOwnProperty.call(message, "inputDtmf"))
                                $root.google.cloud.dialogflow.v2beta1.TelephonyDtmfEvents.encode(message.inputDtmf, writer.uint32(/* id 9, wireType 2 =*/74).fork()).ldelim();
                            if (message.enableExtendedStreaming != null && Object.hasOwnProperty.call(message, "enableExtendedStreaming"))
                                writer.uint32(/* id 11, wireType 0 =*/88).bool(message.enableExtendedStreaming);
                            if (message.enablePartialAutomatedAgentReply != null && Object.hasOwnProperty.call(message, "enablePartialAutomatedAgentReply"))
                                writer.uint32(/* id 12, wireType 0 =*/96).bool(message.enablePartialAutomatedAgentReply);
                            if (message.cxParameters != null && Object.hasOwnProperty.call(message, "cxParameters"))
                                $root.google.protobuf.Struct.encode(message.cxParameters, writer.uint32(/* id 13, wireType 2 =*/106).fork()).ldelim();
                            if (message.cxCurrentPage != null && Object.hasOwnProperty.call(message, "cxCurrentPage"))
                                writer.uint32(/* id 15, wireType 2 =*/122).string(message.cxCurrentPage);
                            if (message.inputIntent != null && Object.hasOwnProperty.call(message, "inputIntent"))
                                writer.uint32(/* id 17, wireType 2 =*/138).string(message.inputIntent);
                            if (message.enableDebuggingInfo != null && Object.hasOwnProperty.call(message, "enableDebuggingInfo"))
                                writer.uint32(/* id 19, wireType 0 =*/152).bool(message.enableDebuggingInfo);
                            if (message.inputEvent != null && Object.hasOwnProperty.call(message, "inputEvent"))
                                writer.uint32(/* id 20, wireType 2 =*/162).string(message.inputEvent);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified StreamingAnalyzeContentRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IStreamingAnalyzeContentRequest} message StreamingAnalyzeContentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        StreamingAnalyzeContentRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a StreamingAnalyzeContentRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentRequest} StreamingAnalyzeContentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        StreamingAnalyzeContentRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.participant = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.audioConfig = $root.google.cloud.dialogflow.v2beta1.InputAudioConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 3: {
                                        message.textConfig = $root.google.cloud.dialogflow.v2beta1.InputTextConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 4: {
                                        message.replyAudioConfig = $root.google.cloud.dialogflow.v2beta1.OutputAudioConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 5: {
                                        message.inputAudio = reader.bytes();
                                        break;
                                    }
                                case 6: {
                                        message.inputText = reader.string();
                                        break;
                                    }
                                case 9: {
                                        message.inputDtmf = $root.google.cloud.dialogflow.v2beta1.TelephonyDtmfEvents.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 17: {
                                        message.inputIntent = reader.string();
                                        break;
                                    }
                                case 20: {
                                        message.inputEvent = reader.string();
                                        break;
                                    }
                                case 7: {
                                        message.queryParams = $root.google.cloud.dialogflow.v2beta1.QueryParameters.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 8: {
                                        message.assistQueryParams = $root.google.cloud.dialogflow.v2beta1.AssistQueryParameters.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 13: {
                                        message.cxParameters = $root.google.protobuf.Struct.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 15: {
                                        message.cxCurrentPage = reader.string();
                                        break;
                                    }
                                case 11: {
                                        message.enableExtendedStreaming = reader.bool();
                                        break;
                                    }
                                case 12: {
                                        message.enablePartialAutomatedAgentReply = reader.bool();
                                        break;
                                    }
                                case 19: {
                                        message.enableDebuggingInfo = reader.bool();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a StreamingAnalyzeContentRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentRequest} StreamingAnalyzeContentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        StreamingAnalyzeContentRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a StreamingAnalyzeContentRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        StreamingAnalyzeContentRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.participant != null && message.hasOwnProperty("participant"))
                                if (!$util.isString(message.participant))
                                    return "participant: string expected";
                            if (message.audioConfig != null && message.hasOwnProperty("audioConfig")) {
                                properties.config = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2beta1.InputAudioConfig.verify(message.audioConfig);
                                    if (error)
                                        return "audioConfig." + error;
                                }
                            }
                            if (message.textConfig != null && message.hasOwnProperty("textConfig")) {
                                if (properties.config === 1)
                                    return "config: multiple values";
                                properties.config = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2beta1.InputTextConfig.verify(message.textConfig);
                                    if (error)
                                        return "textConfig." + error;
                                }
                            }
                            if (message.replyAudioConfig != null && message.hasOwnProperty("replyAudioConfig")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.OutputAudioConfig.verify(message.replyAudioConfig);
                                if (error)
                                    return "replyAudioConfig." + error;
                            }
                            if (message.inputAudio != null && message.hasOwnProperty("inputAudio")) {
                                properties.input = 1;
                                if (!(message.inputAudio && typeof message.inputAudio.length === "number" || $util.isString(message.inputAudio)))
                                    return "inputAudio: buffer expected";
                            }
                            if (message.inputText != null && message.hasOwnProperty("inputText")) {
                                if (properties.input === 1)
                                    return "input: multiple values";
                                properties.input = 1;
                                if (!$util.isString(message.inputText))
                                    return "inputText: string expected";
                            }
                            if (message.inputDtmf != null && message.hasOwnProperty("inputDtmf")) {
                                if (properties.input === 1)
                                    return "input: multiple values";
                                properties.input = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2beta1.TelephonyDtmfEvents.verify(message.inputDtmf);
                                    if (error)
                                        return "inputDtmf." + error;
                                }
                            }
                            if (message.inputIntent != null && message.hasOwnProperty("inputIntent")) {
                                if (properties.input === 1)
                                    return "input: multiple values";
                                properties.input = 1;
                                if (!$util.isString(message.inputIntent))
                                    return "inputIntent: string expected";
                            }
                            if (message.inputEvent != null && message.hasOwnProperty("inputEvent")) {
                                if (properties.input === 1)
                                    return "input: multiple values";
                                properties.input = 1;
                                if (!$util.isString(message.inputEvent))
                                    return "inputEvent: string expected";
                            }
                            if (message.queryParams != null && message.hasOwnProperty("queryParams")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.QueryParameters.verify(message.queryParams);
                                if (error)
                                    return "queryParams." + error;
                            }
                            if (message.assistQueryParams != null && message.hasOwnProperty("assistQueryParams")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.AssistQueryParameters.verify(message.assistQueryParams);
                                if (error)
                                    return "assistQueryParams." + error;
                            }
                            if (message.cxParameters != null && message.hasOwnProperty("cxParameters")) {
                                var error = $root.google.protobuf.Struct.verify(message.cxParameters);
                                if (error)
                                    return "cxParameters." + error;
                            }
                            if (message.cxCurrentPage != null && message.hasOwnProperty("cxCurrentPage"))
                                if (!$util.isString(message.cxCurrentPage))
                                    return "cxCurrentPage: string expected";
                            if (message.enableExtendedStreaming != null && message.hasOwnProperty("enableExtendedStreaming"))
                                if (typeof message.enableExtendedStreaming !== "boolean")
                                    return "enableExtendedStreaming: boolean expected";
                            if (message.enablePartialAutomatedAgentReply != null && message.hasOwnProperty("enablePartialAutomatedAgentReply"))
                                if (typeof message.enablePartialAutomatedAgentReply !== "boolean")
                                    return "enablePartialAutomatedAgentReply: boolean expected";
                            if (message.enableDebuggingInfo != null && message.hasOwnProperty("enableDebuggingInfo"))
                                if (typeof message.enableDebuggingInfo !== "boolean")
                                    return "enableDebuggingInfo: boolean expected";
                            return null;
                        };
    
                        /**
                         * Creates a StreamingAnalyzeContentRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentRequest} StreamingAnalyzeContentRequest
                         */
                        StreamingAnalyzeContentRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentRequest();
                            if (object.participant != null)
                                message.participant = String(object.participant);
                            if (object.audioConfig != null) {
                                if (typeof object.audioConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentRequest.audioConfig: object expected");
                                message.audioConfig = $root.google.cloud.dialogflow.v2beta1.InputAudioConfig.fromObject(object.audioConfig);
                            }
                            if (object.textConfig != null) {
                                if (typeof object.textConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentRequest.textConfig: object expected");
                                message.textConfig = $root.google.cloud.dialogflow.v2beta1.InputTextConfig.fromObject(object.textConfig);
                            }
                            if (object.replyAudioConfig != null) {
                                if (typeof object.replyAudioConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentRequest.replyAudioConfig: object expected");
                                message.replyAudioConfig = $root.google.cloud.dialogflow.v2beta1.OutputAudioConfig.fromObject(object.replyAudioConfig);
                            }
                            if (object.inputAudio != null)
                                if (typeof object.inputAudio === "string")
                                    $util.base64.decode(object.inputAudio, message.inputAudio = $util.newBuffer($util.base64.length(object.inputAudio)), 0);
                                else if (object.inputAudio.length >= 0)
                                    message.inputAudio = object.inputAudio;
                            if (object.inputText != null)
                                message.inputText = String(object.inputText);
                            if (object.inputDtmf != null) {
                                if (typeof object.inputDtmf !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentRequest.inputDtmf: object expected");
                                message.inputDtmf = $root.google.cloud.dialogflow.v2beta1.TelephonyDtmfEvents.fromObject(object.inputDtmf);
                            }
                            if (object.inputIntent != null)
                                message.inputIntent = String(object.inputIntent);
                            if (object.inputEvent != null)
                                message.inputEvent = String(object.inputEvent);
                            if (object.queryParams != null) {
                                if (typeof object.queryParams !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentRequest.queryParams: object expected");
                                message.queryParams = $root.google.cloud.dialogflow.v2beta1.QueryParameters.fromObject(object.queryParams);
                            }
                            if (object.assistQueryParams != null) {
                                if (typeof object.assistQueryParams !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentRequest.assistQueryParams: object expected");
                                message.assistQueryParams = $root.google.cloud.dialogflow.v2beta1.AssistQueryParameters.fromObject(object.assistQueryParams);
                            }
                            if (object.cxParameters != null) {
                                if (typeof object.cxParameters !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentRequest.cxParameters: object expected");
                                message.cxParameters = $root.google.protobuf.Struct.fromObject(object.cxParameters);
                            }
                            if (object.cxCurrentPage != null)
                                message.cxCurrentPage = String(object.cxCurrentPage);
                            if (object.enableExtendedStreaming != null)
                                message.enableExtendedStreaming = Boolean(object.enableExtendedStreaming);
                            if (object.enablePartialAutomatedAgentReply != null)
                                message.enablePartialAutomatedAgentReply = Boolean(object.enablePartialAutomatedAgentReply);
                            if (object.enableDebuggingInfo != null)
                                message.enableDebuggingInfo = Boolean(object.enableDebuggingInfo);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a StreamingAnalyzeContentRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentRequest} message StreamingAnalyzeContentRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        StreamingAnalyzeContentRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.participant = "";
                                object.replyAudioConfig = null;
                                object.queryParams = null;
                                object.assistQueryParams = null;
                                object.enableExtendedStreaming = false;
                                object.enablePartialAutomatedAgentReply = false;
                                object.cxParameters = null;
                                object.cxCurrentPage = "";
                                object.enableDebuggingInfo = false;
                            }
                            if (message.participant != null && message.hasOwnProperty("participant"))
                                object.participant = message.participant;
                            if (message.audioConfig != null && message.hasOwnProperty("audioConfig")) {
                                object.audioConfig = $root.google.cloud.dialogflow.v2beta1.InputAudioConfig.toObject(message.audioConfig, options);
                                if (options.oneofs)
                                    object.config = "audioConfig";
                            }
                            if (message.textConfig != null && message.hasOwnProperty("textConfig")) {
                                object.textConfig = $root.google.cloud.dialogflow.v2beta1.InputTextConfig.toObject(message.textConfig, options);
                                if (options.oneofs)
                                    object.config = "textConfig";
                            }
                            if (message.replyAudioConfig != null && message.hasOwnProperty("replyAudioConfig"))
                                object.replyAudioConfig = $root.google.cloud.dialogflow.v2beta1.OutputAudioConfig.toObject(message.replyAudioConfig, options);
                            if (message.inputAudio != null && message.hasOwnProperty("inputAudio")) {
                                object.inputAudio = options.bytes === String ? $util.base64.encode(message.inputAudio, 0, message.inputAudio.length) : options.bytes === Array ? Array.prototype.slice.call(message.inputAudio) : message.inputAudio;
                                if (options.oneofs)
                                    object.input = "inputAudio";
                            }
                            if (message.inputText != null && message.hasOwnProperty("inputText")) {
                                object.inputText = message.inputText;
                                if (options.oneofs)
                                    object.input = "inputText";
                            }
                            if (message.queryParams != null && message.hasOwnProperty("queryParams"))
                                object.queryParams = $root.google.cloud.dialogflow.v2beta1.QueryParameters.toObject(message.queryParams, options);
                            if (message.assistQueryParams != null && message.hasOwnProperty("assistQueryParams"))
                                object.assistQueryParams = $root.google.cloud.dialogflow.v2beta1.AssistQueryParameters.toObject(message.assistQueryParams, options);
                            if (message.inputDtmf != null && message.hasOwnProperty("inputDtmf")) {
                                object.inputDtmf = $root.google.cloud.dialogflow.v2beta1.TelephonyDtmfEvents.toObject(message.inputDtmf, options);
                                if (options.oneofs)
                                    object.input = "inputDtmf";
                            }
                            if (message.enableExtendedStreaming != null && message.hasOwnProperty("enableExtendedStreaming"))
                                object.enableExtendedStreaming = message.enableExtendedStreaming;
                            if (message.enablePartialAutomatedAgentReply != null && message.hasOwnProperty("enablePartialAutomatedAgentReply"))
                                object.enablePartialAutomatedAgentReply = message.enablePartialAutomatedAgentReply;
                            if (message.cxParameters != null && message.hasOwnProperty("cxParameters"))
                                object.cxParameters = $root.google.protobuf.Struct.toObject(message.cxParameters, options);
                            if (message.cxCurrentPage != null && message.hasOwnProperty("cxCurrentPage"))
                                object.cxCurrentPage = message.cxCurrentPage;
                            if (message.inputIntent != null && message.hasOwnProperty("inputIntent")) {
                                object.inputIntent = message.inputIntent;
                                if (options.oneofs)
                                    object.input = "inputIntent";
                            }
                            if (message.enableDebuggingInfo != null && message.hasOwnProperty("enableDebuggingInfo"))
                                object.enableDebuggingInfo = message.enableDebuggingInfo;
                            if (message.inputEvent != null && message.hasOwnProperty("inputEvent")) {
                                object.inputEvent = message.inputEvent;
                                if (options.oneofs)
                                    object.input = "inputEvent";
                            }
                            return object;
                        };
    
                        /**
                         * Converts this StreamingAnalyzeContentRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        StreamingAnalyzeContentRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for StreamingAnalyzeContentRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        StreamingAnalyzeContentRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentRequest";
                        };
    
                        return StreamingAnalyzeContentRequest;
                    })();
    
                    v2beta1.StreamingAnalyzeContentResponse = (function() {
    
                        /**
                         * Properties of a StreamingAnalyzeContentResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IStreamingAnalyzeContentResponse
                         * @property {google.cloud.dialogflow.v2beta1.IStreamingRecognitionResult|null} [recognitionResult] StreamingAnalyzeContentResponse recognitionResult
                         * @property {string|null} [replyText] StreamingAnalyzeContentResponse replyText
                         * @property {google.cloud.dialogflow.v2beta1.IOutputAudio|null} [replyAudio] StreamingAnalyzeContentResponse replyAudio
                         * @property {google.cloud.dialogflow.v2beta1.IAutomatedAgentReply|null} [automatedAgentReply] StreamingAnalyzeContentResponse automatedAgentReply
                         * @property {google.cloud.dialogflow.v2beta1.IMessage|null} [message] StreamingAnalyzeContentResponse message
                         * @property {Array.<google.cloud.dialogflow.v2beta1.ISuggestionResult>|null} [humanAgentSuggestionResults] StreamingAnalyzeContentResponse humanAgentSuggestionResults
                         * @property {Array.<google.cloud.dialogflow.v2beta1.ISuggestionResult>|null} [endUserSuggestionResults] StreamingAnalyzeContentResponse endUserSuggestionResults
                         * @property {google.cloud.dialogflow.v2beta1.IDtmfParameters|null} [dtmfParameters] StreamingAnalyzeContentResponse dtmfParameters
                         * @property {google.cloud.dialogflow.v2beta1.ICloudConversationDebuggingInfo|null} [debuggingInfo] StreamingAnalyzeContentResponse debuggingInfo
                         * @property {string|null} [speechModel] StreamingAnalyzeContentResponse speechModel
                         */
    
                        /**
                         * Constructs a new StreamingAnalyzeContentResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a StreamingAnalyzeContentResponse.
                         * @implements IStreamingAnalyzeContentResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IStreamingAnalyzeContentResponse=} [properties] Properties to set
                         */
                        function StreamingAnalyzeContentResponse(properties) {
                            this.humanAgentSuggestionResults = [];
                            this.endUserSuggestionResults = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * StreamingAnalyzeContentResponse recognitionResult.
                         * @member {google.cloud.dialogflow.v2beta1.IStreamingRecognitionResult|null|undefined} recognitionResult
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentResponse
                         * @instance
                         */
                        StreamingAnalyzeContentResponse.prototype.recognitionResult = null;
    
                        /**
                         * StreamingAnalyzeContentResponse replyText.
                         * @member {string} replyText
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentResponse
                         * @instance
                         */
                        StreamingAnalyzeContentResponse.prototype.replyText = "";
    
                        /**
                         * StreamingAnalyzeContentResponse replyAudio.
                         * @member {google.cloud.dialogflow.v2beta1.IOutputAudio|null|undefined} replyAudio
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentResponse
                         * @instance
                         */
                        StreamingAnalyzeContentResponse.prototype.replyAudio = null;
    
                        /**
                         * StreamingAnalyzeContentResponse automatedAgentReply.
                         * @member {google.cloud.dialogflow.v2beta1.IAutomatedAgentReply|null|undefined} automatedAgentReply
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentResponse
                         * @instance
                         */
                        StreamingAnalyzeContentResponse.prototype.automatedAgentReply = null;
    
                        /**
                         * StreamingAnalyzeContentResponse message.
                         * @member {google.cloud.dialogflow.v2beta1.IMessage|null|undefined} message
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentResponse
                         * @instance
                         */
                        StreamingAnalyzeContentResponse.prototype.message = null;
    
                        /**
                         * StreamingAnalyzeContentResponse humanAgentSuggestionResults.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.ISuggestionResult>} humanAgentSuggestionResults
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentResponse
                         * @instance
                         */
                        StreamingAnalyzeContentResponse.prototype.humanAgentSuggestionResults = $util.emptyArray;
    
                        /**
                         * StreamingAnalyzeContentResponse endUserSuggestionResults.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.ISuggestionResult>} endUserSuggestionResults
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentResponse
                         * @instance
                         */
                        StreamingAnalyzeContentResponse.prototype.endUserSuggestionResults = $util.emptyArray;
    
                        /**
                         * StreamingAnalyzeContentResponse dtmfParameters.
                         * @member {google.cloud.dialogflow.v2beta1.IDtmfParameters|null|undefined} dtmfParameters
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentResponse
                         * @instance
                         */
                        StreamingAnalyzeContentResponse.prototype.dtmfParameters = null;
    
                        /**
                         * StreamingAnalyzeContentResponse debuggingInfo.
                         * @member {google.cloud.dialogflow.v2beta1.ICloudConversationDebuggingInfo|null|undefined} debuggingInfo
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentResponse
                         * @instance
                         */
                        StreamingAnalyzeContentResponse.prototype.debuggingInfo = null;
    
                        /**
                         * StreamingAnalyzeContentResponse speechModel.
                         * @member {string} speechModel
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentResponse
                         * @instance
                         */
                        StreamingAnalyzeContentResponse.prototype.speechModel = "";
    
                        /**
                         * Creates a new StreamingAnalyzeContentResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IStreamingAnalyzeContentResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentResponse} StreamingAnalyzeContentResponse instance
                         */
                        StreamingAnalyzeContentResponse.create = function create(properties) {
                            return new StreamingAnalyzeContentResponse(properties);
                        };
    
                        /**
                         * Encodes the specified StreamingAnalyzeContentResponse message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IStreamingAnalyzeContentResponse} message StreamingAnalyzeContentResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        StreamingAnalyzeContentResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.recognitionResult != null && Object.hasOwnProperty.call(message, "recognitionResult"))
                                $root.google.cloud.dialogflow.v2beta1.StreamingRecognitionResult.encode(message.recognitionResult, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.replyText != null && Object.hasOwnProperty.call(message, "replyText"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.replyText);
                            if (message.replyAudio != null && Object.hasOwnProperty.call(message, "replyAudio"))
                                $root.google.cloud.dialogflow.v2beta1.OutputAudio.encode(message.replyAudio, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            if (message.automatedAgentReply != null && Object.hasOwnProperty.call(message, "automatedAgentReply"))
                                $root.google.cloud.dialogflow.v2beta1.AutomatedAgentReply.encode(message.automatedAgentReply, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            if (message.message != null && Object.hasOwnProperty.call(message, "message"))
                                $root.google.cloud.dialogflow.v2beta1.Message.encode(message.message, writer.uint32(/* id 6, wireType 2 =*/50).fork()).ldelim();
                            if (message.humanAgentSuggestionResults != null && message.humanAgentSuggestionResults.length)
                                for (var i = 0; i < message.humanAgentSuggestionResults.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.SuggestionResult.encode(message.humanAgentSuggestionResults[i], writer.uint32(/* id 7, wireType 2 =*/58).fork()).ldelim();
                            if (message.endUserSuggestionResults != null && message.endUserSuggestionResults.length)
                                for (var i = 0; i < message.endUserSuggestionResults.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.SuggestionResult.encode(message.endUserSuggestionResults[i], writer.uint32(/* id 8, wireType 2 =*/66).fork()).ldelim();
                            if (message.dtmfParameters != null && Object.hasOwnProperty.call(message, "dtmfParameters"))
                                $root.google.cloud.dialogflow.v2beta1.DtmfParameters.encode(message.dtmfParameters, writer.uint32(/* id 10, wireType 2 =*/82).fork()).ldelim();
                            if (message.debuggingInfo != null && Object.hasOwnProperty.call(message, "debuggingInfo"))
                                $root.google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo.encode(message.debuggingInfo, writer.uint32(/* id 11, wireType 2 =*/90).fork()).ldelim();
                            if (message.speechModel != null && Object.hasOwnProperty.call(message, "speechModel"))
                                writer.uint32(/* id 13, wireType 2 =*/106).string(message.speechModel);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified StreamingAnalyzeContentResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IStreamingAnalyzeContentResponse} message StreamingAnalyzeContentResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        StreamingAnalyzeContentResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a StreamingAnalyzeContentResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentResponse} StreamingAnalyzeContentResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        StreamingAnalyzeContentResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.recognitionResult = $root.google.cloud.dialogflow.v2beta1.StreamingRecognitionResult.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.replyText = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.replyAudio = $root.google.cloud.dialogflow.v2beta1.OutputAudio.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 4: {
                                        message.automatedAgentReply = $root.google.cloud.dialogflow.v2beta1.AutomatedAgentReply.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 6: {
                                        message.message = $root.google.cloud.dialogflow.v2beta1.Message.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 7: {
                                        if (!(message.humanAgentSuggestionResults && message.humanAgentSuggestionResults.length))
                                            message.humanAgentSuggestionResults = [];
                                        message.humanAgentSuggestionResults.push($root.google.cloud.dialogflow.v2beta1.SuggestionResult.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 8: {
                                        if (!(message.endUserSuggestionResults && message.endUserSuggestionResults.length))
                                            message.endUserSuggestionResults = [];
                                        message.endUserSuggestionResults.push($root.google.cloud.dialogflow.v2beta1.SuggestionResult.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 10: {
                                        message.dtmfParameters = $root.google.cloud.dialogflow.v2beta1.DtmfParameters.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 11: {
                                        message.debuggingInfo = $root.google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 13: {
                                        message.speechModel = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a StreamingAnalyzeContentResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentResponse} StreamingAnalyzeContentResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        StreamingAnalyzeContentResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a StreamingAnalyzeContentResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        StreamingAnalyzeContentResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.recognitionResult != null && message.hasOwnProperty("recognitionResult")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.StreamingRecognitionResult.verify(message.recognitionResult);
                                if (error)
                                    return "recognitionResult." + error;
                            }
                            if (message.replyText != null && message.hasOwnProperty("replyText"))
                                if (!$util.isString(message.replyText))
                                    return "replyText: string expected";
                            if (message.replyAudio != null && message.hasOwnProperty("replyAudio")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.OutputAudio.verify(message.replyAudio);
                                if (error)
                                    return "replyAudio." + error;
                            }
                            if (message.automatedAgentReply != null && message.hasOwnProperty("automatedAgentReply")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.AutomatedAgentReply.verify(message.automatedAgentReply);
                                if (error)
                                    return "automatedAgentReply." + error;
                            }
                            if (message.message != null && message.hasOwnProperty("message")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.Message.verify(message.message);
                                if (error)
                                    return "message." + error;
                            }
                            if (message.humanAgentSuggestionResults != null && message.hasOwnProperty("humanAgentSuggestionResults")) {
                                if (!Array.isArray(message.humanAgentSuggestionResults))
                                    return "humanAgentSuggestionResults: array expected";
                                for (var i = 0; i < message.humanAgentSuggestionResults.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.SuggestionResult.verify(message.humanAgentSuggestionResults[i]);
                                    if (error)
                                        return "humanAgentSuggestionResults." + error;
                                }
                            }
                            if (message.endUserSuggestionResults != null && message.hasOwnProperty("endUserSuggestionResults")) {
                                if (!Array.isArray(message.endUserSuggestionResults))
                                    return "endUserSuggestionResults: array expected";
                                for (var i = 0; i < message.endUserSuggestionResults.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.SuggestionResult.verify(message.endUserSuggestionResults[i]);
                                    if (error)
                                        return "endUserSuggestionResults." + error;
                                }
                            }
                            if (message.dtmfParameters != null && message.hasOwnProperty("dtmfParameters")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.DtmfParameters.verify(message.dtmfParameters);
                                if (error)
                                    return "dtmfParameters." + error;
                            }
                            if (message.debuggingInfo != null && message.hasOwnProperty("debuggingInfo")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo.verify(message.debuggingInfo);
                                if (error)
                                    return "debuggingInfo." + error;
                            }
                            if (message.speechModel != null && message.hasOwnProperty("speechModel"))
                                if (!$util.isString(message.speechModel))
                                    return "speechModel: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a StreamingAnalyzeContentResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentResponse} StreamingAnalyzeContentResponse
                         */
                        StreamingAnalyzeContentResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentResponse();
                            if (object.recognitionResult != null) {
                                if (typeof object.recognitionResult !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentResponse.recognitionResult: object expected");
                                message.recognitionResult = $root.google.cloud.dialogflow.v2beta1.StreamingRecognitionResult.fromObject(object.recognitionResult);
                            }
                            if (object.replyText != null)
                                message.replyText = String(object.replyText);
                            if (object.replyAudio != null) {
                                if (typeof object.replyAudio !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentResponse.replyAudio: object expected");
                                message.replyAudio = $root.google.cloud.dialogflow.v2beta1.OutputAudio.fromObject(object.replyAudio);
                            }
                            if (object.automatedAgentReply != null) {
                                if (typeof object.automatedAgentReply !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentResponse.automatedAgentReply: object expected");
                                message.automatedAgentReply = $root.google.cloud.dialogflow.v2beta1.AutomatedAgentReply.fromObject(object.automatedAgentReply);
                            }
                            if (object.message != null) {
                                if (typeof object.message !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentResponse.message: object expected");
                                message.message = $root.google.cloud.dialogflow.v2beta1.Message.fromObject(object.message);
                            }
                            if (object.humanAgentSuggestionResults) {
                                if (!Array.isArray(object.humanAgentSuggestionResults))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentResponse.humanAgentSuggestionResults: array expected");
                                message.humanAgentSuggestionResults = [];
                                for (var i = 0; i < object.humanAgentSuggestionResults.length; ++i) {
                                    if (typeof object.humanAgentSuggestionResults[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentResponse.humanAgentSuggestionResults: object expected");
                                    message.humanAgentSuggestionResults[i] = $root.google.cloud.dialogflow.v2beta1.SuggestionResult.fromObject(object.humanAgentSuggestionResults[i]);
                                }
                            }
                            if (object.endUserSuggestionResults) {
                                if (!Array.isArray(object.endUserSuggestionResults))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentResponse.endUserSuggestionResults: array expected");
                                message.endUserSuggestionResults = [];
                                for (var i = 0; i < object.endUserSuggestionResults.length; ++i) {
                                    if (typeof object.endUserSuggestionResults[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentResponse.endUserSuggestionResults: object expected");
                                    message.endUserSuggestionResults[i] = $root.google.cloud.dialogflow.v2beta1.SuggestionResult.fromObject(object.endUserSuggestionResults[i]);
                                }
                            }
                            if (object.dtmfParameters != null) {
                                if (typeof object.dtmfParameters !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentResponse.dtmfParameters: object expected");
                                message.dtmfParameters = $root.google.cloud.dialogflow.v2beta1.DtmfParameters.fromObject(object.dtmfParameters);
                            }
                            if (object.debuggingInfo != null) {
                                if (typeof object.debuggingInfo !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentResponse.debuggingInfo: object expected");
                                message.debuggingInfo = $root.google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo.fromObject(object.debuggingInfo);
                            }
                            if (object.speechModel != null)
                                message.speechModel = String(object.speechModel);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a StreamingAnalyzeContentResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentResponse} message StreamingAnalyzeContentResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        StreamingAnalyzeContentResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults) {
                                object.humanAgentSuggestionResults = [];
                                object.endUserSuggestionResults = [];
                            }
                            if (options.defaults) {
                                object.recognitionResult = null;
                                object.replyText = "";
                                object.replyAudio = null;
                                object.automatedAgentReply = null;
                                object.message = null;
                                object.dtmfParameters = null;
                                object.debuggingInfo = null;
                                object.speechModel = "";
                            }
                            if (message.recognitionResult != null && message.hasOwnProperty("recognitionResult"))
                                object.recognitionResult = $root.google.cloud.dialogflow.v2beta1.StreamingRecognitionResult.toObject(message.recognitionResult, options);
                            if (message.replyText != null && message.hasOwnProperty("replyText"))
                                object.replyText = message.replyText;
                            if (message.replyAudio != null && message.hasOwnProperty("replyAudio"))
                                object.replyAudio = $root.google.cloud.dialogflow.v2beta1.OutputAudio.toObject(message.replyAudio, options);
                            if (message.automatedAgentReply != null && message.hasOwnProperty("automatedAgentReply"))
                                object.automatedAgentReply = $root.google.cloud.dialogflow.v2beta1.AutomatedAgentReply.toObject(message.automatedAgentReply, options);
                            if (message.message != null && message.hasOwnProperty("message"))
                                object.message = $root.google.cloud.dialogflow.v2beta1.Message.toObject(message.message, options);
                            if (message.humanAgentSuggestionResults && message.humanAgentSuggestionResults.length) {
                                object.humanAgentSuggestionResults = [];
                                for (var j = 0; j < message.humanAgentSuggestionResults.length; ++j)
                                    object.humanAgentSuggestionResults[j] = $root.google.cloud.dialogflow.v2beta1.SuggestionResult.toObject(message.humanAgentSuggestionResults[j], options);
                            }
                            if (message.endUserSuggestionResults && message.endUserSuggestionResults.length) {
                                object.endUserSuggestionResults = [];
                                for (var j = 0; j < message.endUserSuggestionResults.length; ++j)
                                    object.endUserSuggestionResults[j] = $root.google.cloud.dialogflow.v2beta1.SuggestionResult.toObject(message.endUserSuggestionResults[j], options);
                            }
                            if (message.dtmfParameters != null && message.hasOwnProperty("dtmfParameters"))
                                object.dtmfParameters = $root.google.cloud.dialogflow.v2beta1.DtmfParameters.toObject(message.dtmfParameters, options);
                            if (message.debuggingInfo != null && message.hasOwnProperty("debuggingInfo"))
                                object.debuggingInfo = $root.google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo.toObject(message.debuggingInfo, options);
                            if (message.speechModel != null && message.hasOwnProperty("speechModel"))
                                object.speechModel = message.speechModel;
                            return object;
                        };
    
                        /**
                         * Converts this StreamingAnalyzeContentResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        StreamingAnalyzeContentResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for StreamingAnalyzeContentResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        StreamingAnalyzeContentResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.StreamingAnalyzeContentResponse";
                        };
    
                        return StreamingAnalyzeContentResponse;
                    })();
    
                    v2beta1.AnnotatedMessagePart = (function() {
    
                        /**
                         * Properties of an AnnotatedMessagePart.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IAnnotatedMessagePart
                         * @property {string|null} [text] AnnotatedMessagePart text
                         * @property {string|null} [entityType] AnnotatedMessagePart entityType
                         * @property {google.protobuf.IValue|null} [formattedValue] AnnotatedMessagePart formattedValue
                         */
    
                        /**
                         * Constructs a new AnnotatedMessagePart.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an AnnotatedMessagePart.
                         * @implements IAnnotatedMessagePart
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IAnnotatedMessagePart=} [properties] Properties to set
                         */
                        function AnnotatedMessagePart(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * AnnotatedMessagePart text.
                         * @member {string} text
                         * @memberof google.cloud.dialogflow.v2beta1.AnnotatedMessagePart
                         * @instance
                         */
                        AnnotatedMessagePart.prototype.text = "";
    
                        /**
                         * AnnotatedMessagePart entityType.
                         * @member {string} entityType
                         * @memberof google.cloud.dialogflow.v2beta1.AnnotatedMessagePart
                         * @instance
                         */
                        AnnotatedMessagePart.prototype.entityType = "";
    
                        /**
                         * AnnotatedMessagePart formattedValue.
                         * @member {google.protobuf.IValue|null|undefined} formattedValue
                         * @memberof google.cloud.dialogflow.v2beta1.AnnotatedMessagePart
                         * @instance
                         */
                        AnnotatedMessagePart.prototype.formattedValue = null;
    
                        /**
                         * Creates a new AnnotatedMessagePart instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.AnnotatedMessagePart
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IAnnotatedMessagePart=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.AnnotatedMessagePart} AnnotatedMessagePart instance
                         */
                        AnnotatedMessagePart.create = function create(properties) {
                            return new AnnotatedMessagePart(properties);
                        };
    
                        /**
                         * Encodes the specified AnnotatedMessagePart message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.AnnotatedMessagePart.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.AnnotatedMessagePart
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IAnnotatedMessagePart} message AnnotatedMessagePart message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        AnnotatedMessagePart.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.text != null && Object.hasOwnProperty.call(message, "text"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.text);
                            if (message.entityType != null && Object.hasOwnProperty.call(message, "entityType"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.entityType);
                            if (message.formattedValue != null && Object.hasOwnProperty.call(message, "formattedValue"))
                                $root.google.protobuf.Value.encode(message.formattedValue, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified AnnotatedMessagePart message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.AnnotatedMessagePart.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.AnnotatedMessagePart
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IAnnotatedMessagePart} message AnnotatedMessagePart message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        AnnotatedMessagePart.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an AnnotatedMessagePart message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.AnnotatedMessagePart
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.AnnotatedMessagePart} AnnotatedMessagePart
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        AnnotatedMessagePart.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.AnnotatedMessagePart();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.text = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.entityType = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.formattedValue = $root.google.protobuf.Value.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an AnnotatedMessagePart message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.AnnotatedMessagePart
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.AnnotatedMessagePart} AnnotatedMessagePart
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        AnnotatedMessagePart.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an AnnotatedMessagePart message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.AnnotatedMessagePart
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        AnnotatedMessagePart.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.text != null && message.hasOwnProperty("text"))
                                if (!$util.isString(message.text))
                                    return "text: string expected";
                            if (message.entityType != null && message.hasOwnProperty("entityType"))
                                if (!$util.isString(message.entityType))
                                    return "entityType: string expected";
                            if (message.formattedValue != null && message.hasOwnProperty("formattedValue")) {
                                var error = $root.google.protobuf.Value.verify(message.formattedValue);
                                if (error)
                                    return "formattedValue." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates an AnnotatedMessagePart message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.AnnotatedMessagePart
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.AnnotatedMessagePart} AnnotatedMessagePart
                         */
                        AnnotatedMessagePart.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.AnnotatedMessagePart)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.AnnotatedMessagePart();
                            if (object.text != null)
                                message.text = String(object.text);
                            if (object.entityType != null)
                                message.entityType = String(object.entityType);
                            if (object.formattedValue != null) {
                                if (typeof object.formattedValue !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.AnnotatedMessagePart.formattedValue: object expected");
                                message.formattedValue = $root.google.protobuf.Value.fromObject(object.formattedValue);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an AnnotatedMessagePart message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.AnnotatedMessagePart
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.AnnotatedMessagePart} message AnnotatedMessagePart
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        AnnotatedMessagePart.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.text = "";
                                object.entityType = "";
                                object.formattedValue = null;
                            }
                            if (message.text != null && message.hasOwnProperty("text"))
                                object.text = message.text;
                            if (message.entityType != null && message.hasOwnProperty("entityType"))
                                object.entityType = message.entityType;
                            if (message.formattedValue != null && message.hasOwnProperty("formattedValue"))
                                object.formattedValue = $root.google.protobuf.Value.toObject(message.formattedValue, options);
                            return object;
                        };
    
                        /**
                         * Converts this AnnotatedMessagePart to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.AnnotatedMessagePart
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        AnnotatedMessagePart.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for AnnotatedMessagePart
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.AnnotatedMessagePart
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        AnnotatedMessagePart.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.AnnotatedMessagePart";
                        };
    
                        return AnnotatedMessagePart;
                    })();
    
                    v2beta1.MessageAnnotation = (function() {
    
                        /**
                         * Properties of a MessageAnnotation.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IMessageAnnotation
                         * @property {Array.<google.cloud.dialogflow.v2beta1.IAnnotatedMessagePart>|null} [parts] MessageAnnotation parts
                         * @property {boolean|null} [containEntities] MessageAnnotation containEntities
                         */
    
                        /**
                         * Constructs a new MessageAnnotation.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a MessageAnnotation.
                         * @implements IMessageAnnotation
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IMessageAnnotation=} [properties] Properties to set
                         */
                        function MessageAnnotation(properties) {
                            this.parts = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * MessageAnnotation parts.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.IAnnotatedMessagePart>} parts
                         * @memberof google.cloud.dialogflow.v2beta1.MessageAnnotation
                         * @instance
                         */
                        MessageAnnotation.prototype.parts = $util.emptyArray;
    
                        /**
                         * MessageAnnotation containEntities.
                         * @member {boolean} containEntities
                         * @memberof google.cloud.dialogflow.v2beta1.MessageAnnotation
                         * @instance
                         */
                        MessageAnnotation.prototype.containEntities = false;
    
                        /**
                         * Creates a new MessageAnnotation instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.MessageAnnotation
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IMessageAnnotation=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.MessageAnnotation} MessageAnnotation instance
                         */
                        MessageAnnotation.create = function create(properties) {
                            return new MessageAnnotation(properties);
                        };
    
                        /**
                         * Encodes the specified MessageAnnotation message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.MessageAnnotation.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.MessageAnnotation
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IMessageAnnotation} message MessageAnnotation message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        MessageAnnotation.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parts != null && message.parts.length)
                                for (var i = 0; i < message.parts.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.AnnotatedMessagePart.encode(message.parts[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.containEntities != null && Object.hasOwnProperty.call(message, "containEntities"))
                                writer.uint32(/* id 2, wireType 0 =*/16).bool(message.containEntities);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified MessageAnnotation message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.MessageAnnotation.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.MessageAnnotation
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IMessageAnnotation} message MessageAnnotation message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        MessageAnnotation.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a MessageAnnotation message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.MessageAnnotation
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.MessageAnnotation} MessageAnnotation
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        MessageAnnotation.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.MessageAnnotation();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.parts && message.parts.length))
                                            message.parts = [];
                                        message.parts.push($root.google.cloud.dialogflow.v2beta1.AnnotatedMessagePart.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 2: {
                                        message.containEntities = reader.bool();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a MessageAnnotation message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.MessageAnnotation
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.MessageAnnotation} MessageAnnotation
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        MessageAnnotation.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a MessageAnnotation message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.MessageAnnotation
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        MessageAnnotation.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parts != null && message.hasOwnProperty("parts")) {
                                if (!Array.isArray(message.parts))
                                    return "parts: array expected";
                                for (var i = 0; i < message.parts.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.AnnotatedMessagePart.verify(message.parts[i]);
                                    if (error)
                                        return "parts." + error;
                                }
                            }
                            if (message.containEntities != null && message.hasOwnProperty("containEntities"))
                                if (typeof message.containEntities !== "boolean")
                                    return "containEntities: boolean expected";
                            return null;
                        };
    
                        /**
                         * Creates a MessageAnnotation message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.MessageAnnotation
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.MessageAnnotation} MessageAnnotation
                         */
                        MessageAnnotation.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.MessageAnnotation)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.MessageAnnotation();
                            if (object.parts) {
                                if (!Array.isArray(object.parts))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.MessageAnnotation.parts: array expected");
                                message.parts = [];
                                for (var i = 0; i < object.parts.length; ++i) {
                                    if (typeof object.parts[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.MessageAnnotation.parts: object expected");
                                    message.parts[i] = $root.google.cloud.dialogflow.v2beta1.AnnotatedMessagePart.fromObject(object.parts[i]);
                                }
                            }
                            if (object.containEntities != null)
                                message.containEntities = Boolean(object.containEntities);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a MessageAnnotation message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.MessageAnnotation
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.MessageAnnotation} message MessageAnnotation
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        MessageAnnotation.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.parts = [];
                            if (options.defaults)
                                object.containEntities = false;
                            if (message.parts && message.parts.length) {
                                object.parts = [];
                                for (var j = 0; j < message.parts.length; ++j)
                                    object.parts[j] = $root.google.cloud.dialogflow.v2beta1.AnnotatedMessagePart.toObject(message.parts[j], options);
                            }
                            if (message.containEntities != null && message.hasOwnProperty("containEntities"))
                                object.containEntities = message.containEntities;
                            return object;
                        };
    
                        /**
                         * Converts this MessageAnnotation to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.MessageAnnotation
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        MessageAnnotation.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for MessageAnnotation
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.MessageAnnotation
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        MessageAnnotation.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.MessageAnnotation";
                        };
    
                        return MessageAnnotation;
                    })();
    
                    v2beta1.ArticleAnswer = (function() {
    
                        /**
                         * Properties of an ArticleAnswer.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IArticleAnswer
                         * @property {string|null} [title] ArticleAnswer title
                         * @property {string|null} [uri] ArticleAnswer uri
                         * @property {Array.<string>|null} [snippets] ArticleAnswer snippets
                         * @property {Object.<string,string>|null} [metadata] ArticleAnswer metadata
                         * @property {string|null} [answerRecord] ArticleAnswer answerRecord
                         */
    
                        /**
                         * Constructs a new ArticleAnswer.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an ArticleAnswer.
                         * @implements IArticleAnswer
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IArticleAnswer=} [properties] Properties to set
                         */
                        function ArticleAnswer(properties) {
                            this.snippets = [];
                            this.metadata = {};
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ArticleAnswer title.
                         * @member {string} title
                         * @memberof google.cloud.dialogflow.v2beta1.ArticleAnswer
                         * @instance
                         */
                        ArticleAnswer.prototype.title = "";
    
                        /**
                         * ArticleAnswer uri.
                         * @member {string} uri
                         * @memberof google.cloud.dialogflow.v2beta1.ArticleAnswer
                         * @instance
                         */
                        ArticleAnswer.prototype.uri = "";
    
                        /**
                         * ArticleAnswer snippets.
                         * @member {Array.<string>} snippets
                         * @memberof google.cloud.dialogflow.v2beta1.ArticleAnswer
                         * @instance
                         */
                        ArticleAnswer.prototype.snippets = $util.emptyArray;
    
                        /**
                         * ArticleAnswer metadata.
                         * @member {Object.<string,string>} metadata
                         * @memberof google.cloud.dialogflow.v2beta1.ArticleAnswer
                         * @instance
                         */
                        ArticleAnswer.prototype.metadata = $util.emptyObject;
    
                        /**
                         * ArticleAnswer answerRecord.
                         * @member {string} answerRecord
                         * @memberof google.cloud.dialogflow.v2beta1.ArticleAnswer
                         * @instance
                         */
                        ArticleAnswer.prototype.answerRecord = "";
    
                        /**
                         * Creates a new ArticleAnswer instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.ArticleAnswer
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IArticleAnswer=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.ArticleAnswer} ArticleAnswer instance
                         */
                        ArticleAnswer.create = function create(properties) {
                            return new ArticleAnswer(properties);
                        };
    
                        /**
                         * Encodes the specified ArticleAnswer message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ArticleAnswer.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.ArticleAnswer
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IArticleAnswer} message ArticleAnswer message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ArticleAnswer.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.title != null && Object.hasOwnProperty.call(message, "title"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.title);
                            if (message.uri != null && Object.hasOwnProperty.call(message, "uri"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.uri);
                            if (message.snippets != null && message.snippets.length)
                                for (var i = 0; i < message.snippets.length; ++i)
                                    writer.uint32(/* id 3, wireType 2 =*/26).string(message.snippets[i]);
                            if (message.metadata != null && Object.hasOwnProperty.call(message, "metadata"))
                                for (var keys = Object.keys(message.metadata), i = 0; i < keys.length; ++i)
                                    writer.uint32(/* id 5, wireType 2 =*/42).fork().uint32(/* id 1, wireType 2 =*/10).string(keys[i]).uint32(/* id 2, wireType 2 =*/18).string(message.metadata[keys[i]]).ldelim();
                            if (message.answerRecord != null && Object.hasOwnProperty.call(message, "answerRecord"))
                                writer.uint32(/* id 6, wireType 2 =*/50).string(message.answerRecord);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ArticleAnswer message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ArticleAnswer.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ArticleAnswer
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IArticleAnswer} message ArticleAnswer message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ArticleAnswer.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an ArticleAnswer message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.ArticleAnswer
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.ArticleAnswer} ArticleAnswer
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ArticleAnswer.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ArticleAnswer(), key, value;
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.title = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.uri = reader.string();
                                        break;
                                    }
                                case 3: {
                                        if (!(message.snippets && message.snippets.length))
                                            message.snippets = [];
                                        message.snippets.push(reader.string());
                                        break;
                                    }
                                case 5: {
                                        if (message.metadata === $util.emptyObject)
                                            message.metadata = {};
                                        var end2 = reader.uint32() + reader.pos;
                                        key = "";
                                        value = "";
                                        while (reader.pos < end2) {
                                            var tag2 = reader.uint32();
                                            switch (tag2 >>> 3) {
                                            case 1:
                                                key = reader.string();
                                                break;
                                            case 2:
                                                value = reader.string();
                                                break;
                                            default:
                                                reader.skipType(tag2 & 7);
                                                break;
                                            }
                                        }
                                        message.metadata[key] = value;
                                        break;
                                    }
                                case 6: {
                                        message.answerRecord = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an ArticleAnswer message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ArticleAnswer
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.ArticleAnswer} ArticleAnswer
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ArticleAnswer.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an ArticleAnswer message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.ArticleAnswer
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ArticleAnswer.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.title != null && message.hasOwnProperty("title"))
                                if (!$util.isString(message.title))
                                    return "title: string expected";
                            if (message.uri != null && message.hasOwnProperty("uri"))
                                if (!$util.isString(message.uri))
                                    return "uri: string expected";
                            if (message.snippets != null && message.hasOwnProperty("snippets")) {
                                if (!Array.isArray(message.snippets))
                                    return "snippets: array expected";
                                for (var i = 0; i < message.snippets.length; ++i)
                                    if (!$util.isString(message.snippets[i]))
                                        return "snippets: string[] expected";
                            }
                            if (message.metadata != null && message.hasOwnProperty("metadata")) {
                                if (!$util.isObject(message.metadata))
                                    return "metadata: object expected";
                                var key = Object.keys(message.metadata);
                                for (var i = 0; i < key.length; ++i)
                                    if (!$util.isString(message.metadata[key[i]]))
                                        return "metadata: string{k:string} expected";
                            }
                            if (message.answerRecord != null && message.hasOwnProperty("answerRecord"))
                                if (!$util.isString(message.answerRecord))
                                    return "answerRecord: string expected";
                            return null;
                        };
    
                        /**
                         * Creates an ArticleAnswer message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.ArticleAnswer
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.ArticleAnswer} ArticleAnswer
                         */
                        ArticleAnswer.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.ArticleAnswer)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.ArticleAnswer();
                            if (object.title != null)
                                message.title = String(object.title);
                            if (object.uri != null)
                                message.uri = String(object.uri);
                            if (object.snippets) {
                                if (!Array.isArray(object.snippets))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.ArticleAnswer.snippets: array expected");
                                message.snippets = [];
                                for (var i = 0; i < object.snippets.length; ++i)
                                    message.snippets[i] = String(object.snippets[i]);
                            }
                            if (object.metadata) {
                                if (typeof object.metadata !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.ArticleAnswer.metadata: object expected");
                                message.metadata = {};
                                for (var keys = Object.keys(object.metadata), i = 0; i < keys.length; ++i)
                                    message.metadata[keys[i]] = String(object.metadata[keys[i]]);
                            }
                            if (object.answerRecord != null)
                                message.answerRecord = String(object.answerRecord);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an ArticleAnswer message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.ArticleAnswer
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ArticleAnswer} message ArticleAnswer
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ArticleAnswer.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.snippets = [];
                            if (options.objects || options.defaults)
                                object.metadata = {};
                            if (options.defaults) {
                                object.title = "";
                                object.uri = "";
                                object.answerRecord = "";
                            }
                            if (message.title != null && message.hasOwnProperty("title"))
                                object.title = message.title;
                            if (message.uri != null && message.hasOwnProperty("uri"))
                                object.uri = message.uri;
                            if (message.snippets && message.snippets.length) {
                                object.snippets = [];
                                for (var j = 0; j < message.snippets.length; ++j)
                                    object.snippets[j] = message.snippets[j];
                            }
                            var keys2;
                            if (message.metadata && (keys2 = Object.keys(message.metadata)).length) {
                                object.metadata = {};
                                for (var j = 0; j < keys2.length; ++j)
                                    object.metadata[keys2[j]] = message.metadata[keys2[j]];
                            }
                            if (message.answerRecord != null && message.hasOwnProperty("answerRecord"))
                                object.answerRecord = message.answerRecord;
                            return object;
                        };
    
                        /**
                         * Converts this ArticleAnswer to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.ArticleAnswer
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ArticleAnswer.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ArticleAnswer
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.ArticleAnswer
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ArticleAnswer.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ArticleAnswer";
                        };
    
                        return ArticleAnswer;
                    })();
    
                    v2beta1.FaqAnswer = (function() {
    
                        /**
                         * Properties of a FaqAnswer.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IFaqAnswer
                         * @property {string|null} [answer] FaqAnswer answer
                         * @property {number|null} [confidence] FaqAnswer confidence
                         * @property {string|null} [question] FaqAnswer question
                         * @property {string|null} [source] FaqAnswer source
                         * @property {Object.<string,string>|null} [metadata] FaqAnswer metadata
                         * @property {string|null} [answerRecord] FaqAnswer answerRecord
                         */
    
                        /**
                         * Constructs a new FaqAnswer.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a FaqAnswer.
                         * @implements IFaqAnswer
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IFaqAnswer=} [properties] Properties to set
                         */
                        function FaqAnswer(properties) {
                            this.metadata = {};
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * FaqAnswer answer.
                         * @member {string} answer
                         * @memberof google.cloud.dialogflow.v2beta1.FaqAnswer
                         * @instance
                         */
                        FaqAnswer.prototype.answer = "";
    
                        /**
                         * FaqAnswer confidence.
                         * @member {number} confidence
                         * @memberof google.cloud.dialogflow.v2beta1.FaqAnswer
                         * @instance
                         */
                        FaqAnswer.prototype.confidence = 0;
    
                        /**
                         * FaqAnswer question.
                         * @member {string} question
                         * @memberof google.cloud.dialogflow.v2beta1.FaqAnswer
                         * @instance
                         */
                        FaqAnswer.prototype.question = "";
    
                        /**
                         * FaqAnswer source.
                         * @member {string} source
                         * @memberof google.cloud.dialogflow.v2beta1.FaqAnswer
                         * @instance
                         */
                        FaqAnswer.prototype.source = "";
    
                        /**
                         * FaqAnswer metadata.
                         * @member {Object.<string,string>} metadata
                         * @memberof google.cloud.dialogflow.v2beta1.FaqAnswer
                         * @instance
                         */
                        FaqAnswer.prototype.metadata = $util.emptyObject;
    
                        /**
                         * FaqAnswer answerRecord.
                         * @member {string} answerRecord
                         * @memberof google.cloud.dialogflow.v2beta1.FaqAnswer
                         * @instance
                         */
                        FaqAnswer.prototype.answerRecord = "";
    
                        /**
                         * Creates a new FaqAnswer instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.FaqAnswer
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IFaqAnswer=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.FaqAnswer} FaqAnswer instance
                         */
                        FaqAnswer.create = function create(properties) {
                            return new FaqAnswer(properties);
                        };
    
                        /**
                         * Encodes the specified FaqAnswer message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.FaqAnswer.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.FaqAnswer
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IFaqAnswer} message FaqAnswer message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        FaqAnswer.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.answer != null && Object.hasOwnProperty.call(message, "answer"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.answer);
                            if (message.confidence != null && Object.hasOwnProperty.call(message, "confidence"))
                                writer.uint32(/* id 2, wireType 5 =*/21).float(message.confidence);
                            if (message.question != null && Object.hasOwnProperty.call(message, "question"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.question);
                            if (message.source != null && Object.hasOwnProperty.call(message, "source"))
                                writer.uint32(/* id 4, wireType 2 =*/34).string(message.source);
                            if (message.metadata != null && Object.hasOwnProperty.call(message, "metadata"))
                                for (var keys = Object.keys(message.metadata), i = 0; i < keys.length; ++i)
                                    writer.uint32(/* id 5, wireType 2 =*/42).fork().uint32(/* id 1, wireType 2 =*/10).string(keys[i]).uint32(/* id 2, wireType 2 =*/18).string(message.metadata[keys[i]]).ldelim();
                            if (message.answerRecord != null && Object.hasOwnProperty.call(message, "answerRecord"))
                                writer.uint32(/* id 6, wireType 2 =*/50).string(message.answerRecord);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified FaqAnswer message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.FaqAnswer.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.FaqAnswer
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IFaqAnswer} message FaqAnswer message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        FaqAnswer.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a FaqAnswer message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.FaqAnswer
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.FaqAnswer} FaqAnswer
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        FaqAnswer.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.FaqAnswer(), key, value;
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.answer = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.confidence = reader.float();
                                        break;
                                    }
                                case 3: {
                                        message.question = reader.string();
                                        break;
                                    }
                                case 4: {
                                        message.source = reader.string();
                                        break;
                                    }
                                case 5: {
                                        if (message.metadata === $util.emptyObject)
                                            message.metadata = {};
                                        var end2 = reader.uint32() + reader.pos;
                                        key = "";
                                        value = "";
                                        while (reader.pos < end2) {
                                            var tag2 = reader.uint32();
                                            switch (tag2 >>> 3) {
                                            case 1:
                                                key = reader.string();
                                                break;
                                            case 2:
                                                value = reader.string();
                                                break;
                                            default:
                                                reader.skipType(tag2 & 7);
                                                break;
                                            }
                                        }
                                        message.metadata[key] = value;
                                        break;
                                    }
                                case 6: {
                                        message.answerRecord = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a FaqAnswer message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.FaqAnswer
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.FaqAnswer} FaqAnswer
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        FaqAnswer.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a FaqAnswer message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.FaqAnswer
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        FaqAnswer.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.answer != null && message.hasOwnProperty("answer"))
                                if (!$util.isString(message.answer))
                                    return "answer: string expected";
                            if (message.confidence != null && message.hasOwnProperty("confidence"))
                                if (typeof message.confidence !== "number")
                                    return "confidence: number expected";
                            if (message.question != null && message.hasOwnProperty("question"))
                                if (!$util.isString(message.question))
                                    return "question: string expected";
                            if (message.source != null && message.hasOwnProperty("source"))
                                if (!$util.isString(message.source))
                                    return "source: string expected";
                            if (message.metadata != null && message.hasOwnProperty("metadata")) {
                                if (!$util.isObject(message.metadata))
                                    return "metadata: object expected";
                                var key = Object.keys(message.metadata);
                                for (var i = 0; i < key.length; ++i)
                                    if (!$util.isString(message.metadata[key[i]]))
                                        return "metadata: string{k:string} expected";
                            }
                            if (message.answerRecord != null && message.hasOwnProperty("answerRecord"))
                                if (!$util.isString(message.answerRecord))
                                    return "answerRecord: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a FaqAnswer message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.FaqAnswer
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.FaqAnswer} FaqAnswer
                         */
                        FaqAnswer.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.FaqAnswer)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.FaqAnswer();
                            if (object.answer != null)
                                message.answer = String(object.answer);
                            if (object.confidence != null)
                                message.confidence = Number(object.confidence);
                            if (object.question != null)
                                message.question = String(object.question);
                            if (object.source != null)
                                message.source = String(object.source);
                            if (object.metadata) {
                                if (typeof object.metadata !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.FaqAnswer.metadata: object expected");
                                message.metadata = {};
                                for (var keys = Object.keys(object.metadata), i = 0; i < keys.length; ++i)
                                    message.metadata[keys[i]] = String(object.metadata[keys[i]]);
                            }
                            if (object.answerRecord != null)
                                message.answerRecord = String(object.answerRecord);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a FaqAnswer message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.FaqAnswer
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.FaqAnswer} message FaqAnswer
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        FaqAnswer.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.objects || options.defaults)
                                object.metadata = {};
                            if (options.defaults) {
                                object.answer = "";
                                object.confidence = 0;
                                object.question = "";
                                object.source = "";
                                object.answerRecord = "";
                            }
                            if (message.answer != null && message.hasOwnProperty("answer"))
                                object.answer = message.answer;
                            if (message.confidence != null && message.hasOwnProperty("confidence"))
                                object.confidence = options.json && !isFinite(message.confidence) ? String(message.confidence) : message.confidence;
                            if (message.question != null && message.hasOwnProperty("question"))
                                object.question = message.question;
                            if (message.source != null && message.hasOwnProperty("source"))
                                object.source = message.source;
                            var keys2;
                            if (message.metadata && (keys2 = Object.keys(message.metadata)).length) {
                                object.metadata = {};
                                for (var j = 0; j < keys2.length; ++j)
                                    object.metadata[keys2[j]] = message.metadata[keys2[j]];
                            }
                            if (message.answerRecord != null && message.hasOwnProperty("answerRecord"))
                                object.answerRecord = message.answerRecord;
                            return object;
                        };
    
                        /**
                         * Converts this FaqAnswer to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.FaqAnswer
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        FaqAnswer.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for FaqAnswer
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.FaqAnswer
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        FaqAnswer.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.FaqAnswer";
                        };
    
                        return FaqAnswer;
                    })();
    
                    v2beta1.SmartReplyAnswer = (function() {
    
                        /**
                         * Properties of a SmartReplyAnswer.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ISmartReplyAnswer
                         * @property {string|null} [reply] SmartReplyAnswer reply
                         * @property {number|null} [confidence] SmartReplyAnswer confidence
                         * @property {string|null} [answerRecord] SmartReplyAnswer answerRecord
                         */
    
                        /**
                         * Constructs a new SmartReplyAnswer.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a SmartReplyAnswer.
                         * @implements ISmartReplyAnswer
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ISmartReplyAnswer=} [properties] Properties to set
                         */
                        function SmartReplyAnswer(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SmartReplyAnswer reply.
                         * @member {string} reply
                         * @memberof google.cloud.dialogflow.v2beta1.SmartReplyAnswer
                         * @instance
                         */
                        SmartReplyAnswer.prototype.reply = "";
    
                        /**
                         * SmartReplyAnswer confidence.
                         * @member {number} confidence
                         * @memberof google.cloud.dialogflow.v2beta1.SmartReplyAnswer
                         * @instance
                         */
                        SmartReplyAnswer.prototype.confidence = 0;
    
                        /**
                         * SmartReplyAnswer answerRecord.
                         * @member {string} answerRecord
                         * @memberof google.cloud.dialogflow.v2beta1.SmartReplyAnswer
                         * @instance
                         */
                        SmartReplyAnswer.prototype.answerRecord = "";
    
                        /**
                         * Creates a new SmartReplyAnswer instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.SmartReplyAnswer
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISmartReplyAnswer=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.SmartReplyAnswer} SmartReplyAnswer instance
                         */
                        SmartReplyAnswer.create = function create(properties) {
                            return new SmartReplyAnswer(properties);
                        };
    
                        /**
                         * Encodes the specified SmartReplyAnswer message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SmartReplyAnswer.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.SmartReplyAnswer
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISmartReplyAnswer} message SmartReplyAnswer message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SmartReplyAnswer.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.reply != null && Object.hasOwnProperty.call(message, "reply"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.reply);
                            if (message.confidence != null && Object.hasOwnProperty.call(message, "confidence"))
                                writer.uint32(/* id 2, wireType 5 =*/21).float(message.confidence);
                            if (message.answerRecord != null && Object.hasOwnProperty.call(message, "answerRecord"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.answerRecord);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SmartReplyAnswer message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SmartReplyAnswer.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SmartReplyAnswer
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISmartReplyAnswer} message SmartReplyAnswer message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SmartReplyAnswer.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SmartReplyAnswer message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.SmartReplyAnswer
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.SmartReplyAnswer} SmartReplyAnswer
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SmartReplyAnswer.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.SmartReplyAnswer();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.reply = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.confidence = reader.float();
                                        break;
                                    }
                                case 3: {
                                        message.answerRecord = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SmartReplyAnswer message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SmartReplyAnswer
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.SmartReplyAnswer} SmartReplyAnswer
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SmartReplyAnswer.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SmartReplyAnswer message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.SmartReplyAnswer
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SmartReplyAnswer.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.reply != null && message.hasOwnProperty("reply"))
                                if (!$util.isString(message.reply))
                                    return "reply: string expected";
                            if (message.confidence != null && message.hasOwnProperty("confidence"))
                                if (typeof message.confidence !== "number")
                                    return "confidence: number expected";
                            if (message.answerRecord != null && message.hasOwnProperty("answerRecord"))
                                if (!$util.isString(message.answerRecord))
                                    return "answerRecord: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a SmartReplyAnswer message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.SmartReplyAnswer
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.SmartReplyAnswer} SmartReplyAnswer
                         */
                        SmartReplyAnswer.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.SmartReplyAnswer)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.SmartReplyAnswer();
                            if (object.reply != null)
                                message.reply = String(object.reply);
                            if (object.confidence != null)
                                message.confidence = Number(object.confidence);
                            if (object.answerRecord != null)
                                message.answerRecord = String(object.answerRecord);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SmartReplyAnswer message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.SmartReplyAnswer
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.SmartReplyAnswer} message SmartReplyAnswer
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SmartReplyAnswer.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.reply = "";
                                object.confidence = 0;
                                object.answerRecord = "";
                            }
                            if (message.reply != null && message.hasOwnProperty("reply"))
                                object.reply = message.reply;
                            if (message.confidence != null && message.hasOwnProperty("confidence"))
                                object.confidence = options.json && !isFinite(message.confidence) ? String(message.confidence) : message.confidence;
                            if (message.answerRecord != null && message.hasOwnProperty("answerRecord"))
                                object.answerRecord = message.answerRecord;
                            return object;
                        };
    
                        /**
                         * Converts this SmartReplyAnswer to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.SmartReplyAnswer
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SmartReplyAnswer.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SmartReplyAnswer
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.SmartReplyAnswer
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SmartReplyAnswer.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.SmartReplyAnswer";
                        };
    
                        return SmartReplyAnswer;
                    })();
    
                    v2beta1.IntentSuggestion = (function() {
    
                        /**
                         * Properties of an IntentSuggestion.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IIntentSuggestion
                         * @property {string|null} [displayName] IntentSuggestion displayName
                         * @property {string|null} [intentV2] IntentSuggestion intentV2
                         * @property {string|null} [description] IntentSuggestion description
                         */
    
                        /**
                         * Constructs a new IntentSuggestion.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an IntentSuggestion.
                         * @implements IIntentSuggestion
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IIntentSuggestion=} [properties] Properties to set
                         */
                        function IntentSuggestion(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * IntentSuggestion displayName.
                         * @member {string} displayName
                         * @memberof google.cloud.dialogflow.v2beta1.IntentSuggestion
                         * @instance
                         */
                        IntentSuggestion.prototype.displayName = "";
    
                        /**
                         * IntentSuggestion intentV2.
                         * @member {string|null|undefined} intentV2
                         * @memberof google.cloud.dialogflow.v2beta1.IntentSuggestion
                         * @instance
                         */
                        IntentSuggestion.prototype.intentV2 = null;
    
                        /**
                         * IntentSuggestion description.
                         * @member {string} description
                         * @memberof google.cloud.dialogflow.v2beta1.IntentSuggestion
                         * @instance
                         */
                        IntentSuggestion.prototype.description = "";
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * IntentSuggestion intent.
                         * @member {"intentV2"|undefined} intent
                         * @memberof google.cloud.dialogflow.v2beta1.IntentSuggestion
                         * @instance
                         */
                        Object.defineProperty(IntentSuggestion.prototype, "intent", {
                            get: $util.oneOfGetter($oneOfFields = ["intentV2"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new IntentSuggestion instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.IntentSuggestion
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IIntentSuggestion=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.IntentSuggestion} IntentSuggestion instance
                         */
                        IntentSuggestion.create = function create(properties) {
                            return new IntentSuggestion(properties);
                        };
    
                        /**
                         * Encodes the specified IntentSuggestion message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.IntentSuggestion.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.IntentSuggestion
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IIntentSuggestion} message IntentSuggestion message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        IntentSuggestion.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.displayName != null && Object.hasOwnProperty.call(message, "displayName"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.displayName);
                            if (message.intentV2 != null && Object.hasOwnProperty.call(message, "intentV2"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.intentV2);
                            if (message.description != null && Object.hasOwnProperty.call(message, "description"))
                                writer.uint32(/* id 5, wireType 2 =*/42).string(message.description);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified IntentSuggestion message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.IntentSuggestion.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.IntentSuggestion
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IIntentSuggestion} message IntentSuggestion message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        IntentSuggestion.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an IntentSuggestion message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.IntentSuggestion
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.IntentSuggestion} IntentSuggestion
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        IntentSuggestion.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.IntentSuggestion();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.displayName = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.intentV2 = reader.string();
                                        break;
                                    }
                                case 5: {
                                        message.description = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an IntentSuggestion message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.IntentSuggestion
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.IntentSuggestion} IntentSuggestion
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        IntentSuggestion.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an IntentSuggestion message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.IntentSuggestion
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        IntentSuggestion.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.displayName != null && message.hasOwnProperty("displayName"))
                                if (!$util.isString(message.displayName))
                                    return "displayName: string expected";
                            if (message.intentV2 != null && message.hasOwnProperty("intentV2")) {
                                properties.intent = 1;
                                if (!$util.isString(message.intentV2))
                                    return "intentV2: string expected";
                            }
                            if (message.description != null && message.hasOwnProperty("description"))
                                if (!$util.isString(message.description))
                                    return "description: string expected";
                            return null;
                        };
    
                        /**
                         * Creates an IntentSuggestion message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.IntentSuggestion
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.IntentSuggestion} IntentSuggestion
                         */
                        IntentSuggestion.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.IntentSuggestion)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.IntentSuggestion();
                            if (object.displayName != null)
                                message.displayName = String(object.displayName);
                            if (object.intentV2 != null)
                                message.intentV2 = String(object.intentV2);
                            if (object.description != null)
                                message.description = String(object.description);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an IntentSuggestion message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.IntentSuggestion
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IntentSuggestion} message IntentSuggestion
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        IntentSuggestion.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.displayName = "";
                                object.description = "";
                            }
                            if (message.displayName != null && message.hasOwnProperty("displayName"))
                                object.displayName = message.displayName;
                            if (message.intentV2 != null && message.hasOwnProperty("intentV2")) {
                                object.intentV2 = message.intentV2;
                                if (options.oneofs)
                                    object.intent = "intentV2";
                            }
                            if (message.description != null && message.hasOwnProperty("description"))
                                object.description = message.description;
                            return object;
                        };
    
                        /**
                         * Converts this IntentSuggestion to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.IntentSuggestion
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        IntentSuggestion.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for IntentSuggestion
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.IntentSuggestion
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        IntentSuggestion.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.IntentSuggestion";
                        };
    
                        return IntentSuggestion;
                    })();
    
                    v2beta1.DialogflowAssistAnswer = (function() {
    
                        /**
                         * Properties of a DialogflowAssistAnswer.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IDialogflowAssistAnswer
                         * @property {google.cloud.dialogflow.v2beta1.IQueryResult|null} [queryResult] DialogflowAssistAnswer queryResult
                         * @property {google.cloud.dialogflow.v2beta1.IIntentSuggestion|null} [intentSuggestion] DialogflowAssistAnswer intentSuggestion
                         * @property {string|null} [answerRecord] DialogflowAssistAnswer answerRecord
                         */
    
                        /**
                         * Constructs a new DialogflowAssistAnswer.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a DialogflowAssistAnswer.
                         * @implements IDialogflowAssistAnswer
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IDialogflowAssistAnswer=} [properties] Properties to set
                         */
                        function DialogflowAssistAnswer(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * DialogflowAssistAnswer queryResult.
                         * @member {google.cloud.dialogflow.v2beta1.IQueryResult|null|undefined} queryResult
                         * @memberof google.cloud.dialogflow.v2beta1.DialogflowAssistAnswer
                         * @instance
                         */
                        DialogflowAssistAnswer.prototype.queryResult = null;
    
                        /**
                         * DialogflowAssistAnswer intentSuggestion.
                         * @member {google.cloud.dialogflow.v2beta1.IIntentSuggestion|null|undefined} intentSuggestion
                         * @memberof google.cloud.dialogflow.v2beta1.DialogflowAssistAnswer
                         * @instance
                         */
                        DialogflowAssistAnswer.prototype.intentSuggestion = null;
    
                        /**
                         * DialogflowAssistAnswer answerRecord.
                         * @member {string} answerRecord
                         * @memberof google.cloud.dialogflow.v2beta1.DialogflowAssistAnswer
                         * @instance
                         */
                        DialogflowAssistAnswer.prototype.answerRecord = "";
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * DialogflowAssistAnswer result.
                         * @member {"queryResult"|"intentSuggestion"|undefined} result
                         * @memberof google.cloud.dialogflow.v2beta1.DialogflowAssistAnswer
                         * @instance
                         */
                        Object.defineProperty(DialogflowAssistAnswer.prototype, "result", {
                            get: $util.oneOfGetter($oneOfFields = ["queryResult", "intentSuggestion"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new DialogflowAssistAnswer instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.DialogflowAssistAnswer
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDialogflowAssistAnswer=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.DialogflowAssistAnswer} DialogflowAssistAnswer instance
                         */
                        DialogflowAssistAnswer.create = function create(properties) {
                            return new DialogflowAssistAnswer(properties);
                        };
    
                        /**
                         * Encodes the specified DialogflowAssistAnswer message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.DialogflowAssistAnswer.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.DialogflowAssistAnswer
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDialogflowAssistAnswer} message DialogflowAssistAnswer message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DialogflowAssistAnswer.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.queryResult != null && Object.hasOwnProperty.call(message, "queryResult"))
                                $root.google.cloud.dialogflow.v2beta1.QueryResult.encode(message.queryResult, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.answerRecord != null && Object.hasOwnProperty.call(message, "answerRecord"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.answerRecord);
                            if (message.intentSuggestion != null && Object.hasOwnProperty.call(message, "intentSuggestion"))
                                $root.google.cloud.dialogflow.v2beta1.IntentSuggestion.encode(message.intentSuggestion, writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified DialogflowAssistAnswer message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.DialogflowAssistAnswer.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.DialogflowAssistAnswer
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDialogflowAssistAnswer} message DialogflowAssistAnswer message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DialogflowAssistAnswer.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a DialogflowAssistAnswer message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.DialogflowAssistAnswer
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.DialogflowAssistAnswer} DialogflowAssistAnswer
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DialogflowAssistAnswer.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.DialogflowAssistAnswer();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.queryResult = $root.google.cloud.dialogflow.v2beta1.QueryResult.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 5: {
                                        message.intentSuggestion = $root.google.cloud.dialogflow.v2beta1.IntentSuggestion.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.answerRecord = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a DialogflowAssistAnswer message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.DialogflowAssistAnswer
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.DialogflowAssistAnswer} DialogflowAssistAnswer
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DialogflowAssistAnswer.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a DialogflowAssistAnswer message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.DialogflowAssistAnswer
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        DialogflowAssistAnswer.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.queryResult != null && message.hasOwnProperty("queryResult")) {
                                properties.result = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2beta1.QueryResult.verify(message.queryResult);
                                    if (error)
                                        return "queryResult." + error;
                                }
                            }
                            if (message.intentSuggestion != null && message.hasOwnProperty("intentSuggestion")) {
                                if (properties.result === 1)
                                    return "result: multiple values";
                                properties.result = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2beta1.IntentSuggestion.verify(message.intentSuggestion);
                                    if (error)
                                        return "intentSuggestion." + error;
                                }
                            }
                            if (message.answerRecord != null && message.hasOwnProperty("answerRecord"))
                                if (!$util.isString(message.answerRecord))
                                    return "answerRecord: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a DialogflowAssistAnswer message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.DialogflowAssistAnswer
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.DialogflowAssistAnswer} DialogflowAssistAnswer
                         */
                        DialogflowAssistAnswer.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.DialogflowAssistAnswer)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.DialogflowAssistAnswer();
                            if (object.queryResult != null) {
                                if (typeof object.queryResult !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.DialogflowAssistAnswer.queryResult: object expected");
                                message.queryResult = $root.google.cloud.dialogflow.v2beta1.QueryResult.fromObject(object.queryResult);
                            }
                            if (object.intentSuggestion != null) {
                                if (typeof object.intentSuggestion !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.DialogflowAssistAnswer.intentSuggestion: object expected");
                                message.intentSuggestion = $root.google.cloud.dialogflow.v2beta1.IntentSuggestion.fromObject(object.intentSuggestion);
                            }
                            if (object.answerRecord != null)
                                message.answerRecord = String(object.answerRecord);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a DialogflowAssistAnswer message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.DialogflowAssistAnswer
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.DialogflowAssistAnswer} message DialogflowAssistAnswer
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        DialogflowAssistAnswer.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.answerRecord = "";
                            if (message.queryResult != null && message.hasOwnProperty("queryResult")) {
                                object.queryResult = $root.google.cloud.dialogflow.v2beta1.QueryResult.toObject(message.queryResult, options);
                                if (options.oneofs)
                                    object.result = "queryResult";
                            }
                            if (message.answerRecord != null && message.hasOwnProperty("answerRecord"))
                                object.answerRecord = message.answerRecord;
                            if (message.intentSuggestion != null && message.hasOwnProperty("intentSuggestion")) {
                                object.intentSuggestion = $root.google.cloud.dialogflow.v2beta1.IntentSuggestion.toObject(message.intentSuggestion, options);
                                if (options.oneofs)
                                    object.result = "intentSuggestion";
                            }
                            return object;
                        };
    
                        /**
                         * Converts this DialogflowAssistAnswer to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.DialogflowAssistAnswer
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        DialogflowAssistAnswer.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for DialogflowAssistAnswer
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.DialogflowAssistAnswer
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        DialogflowAssistAnswer.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.DialogflowAssistAnswer";
                        };
    
                        return DialogflowAssistAnswer;
                    })();
    
                    v2beta1.SuggestionResult = (function() {
    
                        /**
                         * Properties of a SuggestionResult.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ISuggestionResult
                         * @property {google.rpc.IStatus|null} [error] SuggestionResult error
                         * @property {google.cloud.dialogflow.v2beta1.ISuggestArticlesResponse|null} [suggestArticlesResponse] SuggestionResult suggestArticlesResponse
                         * @property {google.cloud.dialogflow.v2beta1.ISuggestKnowledgeAssistResponse|null} [suggestKnowledgeAssistResponse] SuggestionResult suggestKnowledgeAssistResponse
                         * @property {google.cloud.dialogflow.v2beta1.ISuggestFaqAnswersResponse|null} [suggestFaqAnswersResponse] SuggestionResult suggestFaqAnswersResponse
                         * @property {google.cloud.dialogflow.v2beta1.ISuggestSmartRepliesResponse|null} [suggestSmartRepliesResponse] SuggestionResult suggestSmartRepliesResponse
                         * @property {google.cloud.dialogflow.v2beta1.ISuggestDialogflowAssistsResponse|null} [suggestDialogflowAssistsResponse] SuggestionResult suggestDialogflowAssistsResponse
                         * @property {google.cloud.dialogflow.v2beta1.ISuggestDialogflowAssistsResponse|null} [suggestEntityExtractionResponse] SuggestionResult suggestEntityExtractionResponse
                         * @property {google.cloud.dialogflow.v2beta1.IGenerateSuggestionsResponse|null} [generateSuggestionsResponse] SuggestionResult generateSuggestionsResponse
                         */
    
                        /**
                         * Constructs a new SuggestionResult.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a SuggestionResult.
                         * @implements ISuggestionResult
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestionResult=} [properties] Properties to set
                         */
                        function SuggestionResult(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SuggestionResult error.
                         * @member {google.rpc.IStatus|null|undefined} error
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestionResult
                         * @instance
                         */
                        SuggestionResult.prototype.error = null;
    
                        /**
                         * SuggestionResult suggestArticlesResponse.
                         * @member {google.cloud.dialogflow.v2beta1.ISuggestArticlesResponse|null|undefined} suggestArticlesResponse
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestionResult
                         * @instance
                         */
                        SuggestionResult.prototype.suggestArticlesResponse = null;
    
                        /**
                         * SuggestionResult suggestKnowledgeAssistResponse.
                         * @member {google.cloud.dialogflow.v2beta1.ISuggestKnowledgeAssistResponse|null|undefined} suggestKnowledgeAssistResponse
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestionResult
                         * @instance
                         */
                        SuggestionResult.prototype.suggestKnowledgeAssistResponse = null;
    
                        /**
                         * SuggestionResult suggestFaqAnswersResponse.
                         * @member {google.cloud.dialogflow.v2beta1.ISuggestFaqAnswersResponse|null|undefined} suggestFaqAnswersResponse
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestionResult
                         * @instance
                         */
                        SuggestionResult.prototype.suggestFaqAnswersResponse = null;
    
                        /**
                         * SuggestionResult suggestSmartRepliesResponse.
                         * @member {google.cloud.dialogflow.v2beta1.ISuggestSmartRepliesResponse|null|undefined} suggestSmartRepliesResponse
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestionResult
                         * @instance
                         */
                        SuggestionResult.prototype.suggestSmartRepliesResponse = null;
    
                        /**
                         * SuggestionResult suggestDialogflowAssistsResponse.
                         * @member {google.cloud.dialogflow.v2beta1.ISuggestDialogflowAssistsResponse|null|undefined} suggestDialogflowAssistsResponse
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestionResult
                         * @instance
                         */
                        SuggestionResult.prototype.suggestDialogflowAssistsResponse = null;
    
                        /**
                         * SuggestionResult suggestEntityExtractionResponse.
                         * @member {google.cloud.dialogflow.v2beta1.ISuggestDialogflowAssistsResponse|null|undefined} suggestEntityExtractionResponse
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestionResult
                         * @instance
                         */
                        SuggestionResult.prototype.suggestEntityExtractionResponse = null;
    
                        /**
                         * SuggestionResult generateSuggestionsResponse.
                         * @member {google.cloud.dialogflow.v2beta1.IGenerateSuggestionsResponse|null|undefined} generateSuggestionsResponse
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestionResult
                         * @instance
                         */
                        SuggestionResult.prototype.generateSuggestionsResponse = null;
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * SuggestionResult suggestionResponse.
                         * @member {"error"|"suggestArticlesResponse"|"suggestKnowledgeAssistResponse"|"suggestFaqAnswersResponse"|"suggestSmartRepliesResponse"|"suggestDialogflowAssistsResponse"|"suggestEntityExtractionResponse"|"generateSuggestionsResponse"|undefined} suggestionResponse
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestionResult
                         * @instance
                         */
                        Object.defineProperty(SuggestionResult.prototype, "suggestionResponse", {
                            get: $util.oneOfGetter($oneOfFields = ["error", "suggestArticlesResponse", "suggestKnowledgeAssistResponse", "suggestFaqAnswersResponse", "suggestSmartRepliesResponse", "suggestDialogflowAssistsResponse", "suggestEntityExtractionResponse", "generateSuggestionsResponse"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new SuggestionResult instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestionResult
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestionResult=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.SuggestionResult} SuggestionResult instance
                         */
                        SuggestionResult.create = function create(properties) {
                            return new SuggestionResult(properties);
                        };
    
                        /**
                         * Encodes the specified SuggestionResult message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SuggestionResult.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestionResult
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestionResult} message SuggestionResult message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SuggestionResult.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.error != null && Object.hasOwnProperty.call(message, "error"))
                                $root.google.rpc.Status.encode(message.error, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.suggestArticlesResponse != null && Object.hasOwnProperty.call(message, "suggestArticlesResponse"))
                                $root.google.cloud.dialogflow.v2beta1.SuggestArticlesResponse.encode(message.suggestArticlesResponse, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.suggestFaqAnswersResponse != null && Object.hasOwnProperty.call(message, "suggestFaqAnswersResponse"))
                                $root.google.cloud.dialogflow.v2beta1.SuggestFaqAnswersResponse.encode(message.suggestFaqAnswersResponse, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            if (message.suggestSmartRepliesResponse != null && Object.hasOwnProperty.call(message, "suggestSmartRepliesResponse"))
                                $root.google.cloud.dialogflow.v2beta1.SuggestSmartRepliesResponse.encode(message.suggestSmartRepliesResponse, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            if (message.suggestDialogflowAssistsResponse != null && Object.hasOwnProperty.call(message, "suggestDialogflowAssistsResponse"))
                                $root.google.cloud.dialogflow.v2beta1.SuggestDialogflowAssistsResponse.encode(message.suggestDialogflowAssistsResponse, writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                            if (message.suggestEntityExtractionResponse != null && Object.hasOwnProperty.call(message, "suggestEntityExtractionResponse"))
                                $root.google.cloud.dialogflow.v2beta1.SuggestDialogflowAssistsResponse.encode(message.suggestEntityExtractionResponse, writer.uint32(/* id 7, wireType 2 =*/58).fork()).ldelim();
                            if (message.suggestKnowledgeAssistResponse != null && Object.hasOwnProperty.call(message, "suggestKnowledgeAssistResponse"))
                                $root.google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistResponse.encode(message.suggestKnowledgeAssistResponse, writer.uint32(/* id 8, wireType 2 =*/66).fork()).ldelim();
                            if (message.generateSuggestionsResponse != null && Object.hasOwnProperty.call(message, "generateSuggestionsResponse"))
                                $root.google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse.encode(message.generateSuggestionsResponse, writer.uint32(/* id 9, wireType 2 =*/74).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SuggestionResult message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SuggestionResult.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestionResult
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestionResult} message SuggestionResult message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SuggestionResult.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SuggestionResult message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestionResult
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.SuggestionResult} SuggestionResult
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SuggestionResult.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.SuggestionResult();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.error = $root.google.rpc.Status.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.suggestArticlesResponse = $root.google.cloud.dialogflow.v2beta1.SuggestArticlesResponse.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 8: {
                                        message.suggestKnowledgeAssistResponse = $root.google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistResponse.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 3: {
                                        message.suggestFaqAnswersResponse = $root.google.cloud.dialogflow.v2beta1.SuggestFaqAnswersResponse.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 4: {
                                        message.suggestSmartRepliesResponse = $root.google.cloud.dialogflow.v2beta1.SuggestSmartRepliesResponse.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 5: {
                                        message.suggestDialogflowAssistsResponse = $root.google.cloud.dialogflow.v2beta1.SuggestDialogflowAssistsResponse.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 7: {
                                        message.suggestEntityExtractionResponse = $root.google.cloud.dialogflow.v2beta1.SuggestDialogflowAssistsResponse.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 9: {
                                        message.generateSuggestionsResponse = $root.google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SuggestionResult message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestionResult
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.SuggestionResult} SuggestionResult
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SuggestionResult.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SuggestionResult message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestionResult
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SuggestionResult.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.error != null && message.hasOwnProperty("error")) {
                                properties.suggestionResponse = 1;
                                {
                                    var error = $root.google.rpc.Status.verify(message.error);
                                    if (error)
                                        return "error." + error;
                                }
                            }
                            if (message.suggestArticlesResponse != null && message.hasOwnProperty("suggestArticlesResponse")) {
                                if (properties.suggestionResponse === 1)
                                    return "suggestionResponse: multiple values";
                                properties.suggestionResponse = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2beta1.SuggestArticlesResponse.verify(message.suggestArticlesResponse);
                                    if (error)
                                        return "suggestArticlesResponse." + error;
                                }
                            }
                            if (message.suggestKnowledgeAssistResponse != null && message.hasOwnProperty("suggestKnowledgeAssistResponse")) {
                                if (properties.suggestionResponse === 1)
                                    return "suggestionResponse: multiple values";
                                properties.suggestionResponse = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistResponse.verify(message.suggestKnowledgeAssistResponse);
                                    if (error)
                                        return "suggestKnowledgeAssistResponse." + error;
                                }
                            }
                            if (message.suggestFaqAnswersResponse != null && message.hasOwnProperty("suggestFaqAnswersResponse")) {
                                if (properties.suggestionResponse === 1)
                                    return "suggestionResponse: multiple values";
                                properties.suggestionResponse = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2beta1.SuggestFaqAnswersResponse.verify(message.suggestFaqAnswersResponse);
                                    if (error)
                                        return "suggestFaqAnswersResponse." + error;
                                }
                            }
                            if (message.suggestSmartRepliesResponse != null && message.hasOwnProperty("suggestSmartRepliesResponse")) {
                                if (properties.suggestionResponse === 1)
                                    return "suggestionResponse: multiple values";
                                properties.suggestionResponse = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2beta1.SuggestSmartRepliesResponse.verify(message.suggestSmartRepliesResponse);
                                    if (error)
                                        return "suggestSmartRepliesResponse." + error;
                                }
                            }
                            if (message.suggestDialogflowAssistsResponse != null && message.hasOwnProperty("suggestDialogflowAssistsResponse")) {
                                if (properties.suggestionResponse === 1)
                                    return "suggestionResponse: multiple values";
                                properties.suggestionResponse = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2beta1.SuggestDialogflowAssistsResponse.verify(message.suggestDialogflowAssistsResponse);
                                    if (error)
                                        return "suggestDialogflowAssistsResponse." + error;
                                }
                            }
                            if (message.suggestEntityExtractionResponse != null && message.hasOwnProperty("suggestEntityExtractionResponse")) {
                                if (properties.suggestionResponse === 1)
                                    return "suggestionResponse: multiple values";
                                properties.suggestionResponse = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2beta1.SuggestDialogflowAssistsResponse.verify(message.suggestEntityExtractionResponse);
                                    if (error)
                                        return "suggestEntityExtractionResponse." + error;
                                }
                            }
                            if (message.generateSuggestionsResponse != null && message.hasOwnProperty("generateSuggestionsResponse")) {
                                if (properties.suggestionResponse === 1)
                                    return "suggestionResponse: multiple values";
                                properties.suggestionResponse = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse.verify(message.generateSuggestionsResponse);
                                    if (error)
                                        return "generateSuggestionsResponse." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates a SuggestionResult message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestionResult
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.SuggestionResult} SuggestionResult
                         */
                        SuggestionResult.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.SuggestionResult)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.SuggestionResult();
                            if (object.error != null) {
                                if (typeof object.error !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.SuggestionResult.error: object expected");
                                message.error = $root.google.rpc.Status.fromObject(object.error);
                            }
                            if (object.suggestArticlesResponse != null) {
                                if (typeof object.suggestArticlesResponse !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.SuggestionResult.suggestArticlesResponse: object expected");
                                message.suggestArticlesResponse = $root.google.cloud.dialogflow.v2beta1.SuggestArticlesResponse.fromObject(object.suggestArticlesResponse);
                            }
                            if (object.suggestKnowledgeAssistResponse != null) {
                                if (typeof object.suggestKnowledgeAssistResponse !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.SuggestionResult.suggestKnowledgeAssistResponse: object expected");
                                message.suggestKnowledgeAssistResponse = $root.google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistResponse.fromObject(object.suggestKnowledgeAssistResponse);
                            }
                            if (object.suggestFaqAnswersResponse != null) {
                                if (typeof object.suggestFaqAnswersResponse !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.SuggestionResult.suggestFaqAnswersResponse: object expected");
                                message.suggestFaqAnswersResponse = $root.google.cloud.dialogflow.v2beta1.SuggestFaqAnswersResponse.fromObject(object.suggestFaqAnswersResponse);
                            }
                            if (object.suggestSmartRepliesResponse != null) {
                                if (typeof object.suggestSmartRepliesResponse !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.SuggestionResult.suggestSmartRepliesResponse: object expected");
                                message.suggestSmartRepliesResponse = $root.google.cloud.dialogflow.v2beta1.SuggestSmartRepliesResponse.fromObject(object.suggestSmartRepliesResponse);
                            }
                            if (object.suggestDialogflowAssistsResponse != null) {
                                if (typeof object.suggestDialogflowAssistsResponse !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.SuggestionResult.suggestDialogflowAssistsResponse: object expected");
                                message.suggestDialogflowAssistsResponse = $root.google.cloud.dialogflow.v2beta1.SuggestDialogflowAssistsResponse.fromObject(object.suggestDialogflowAssistsResponse);
                            }
                            if (object.suggestEntityExtractionResponse != null) {
                                if (typeof object.suggestEntityExtractionResponse !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.SuggestionResult.suggestEntityExtractionResponse: object expected");
                                message.suggestEntityExtractionResponse = $root.google.cloud.dialogflow.v2beta1.SuggestDialogflowAssistsResponse.fromObject(object.suggestEntityExtractionResponse);
                            }
                            if (object.generateSuggestionsResponse != null) {
                                if (typeof object.generateSuggestionsResponse !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.SuggestionResult.generateSuggestionsResponse: object expected");
                                message.generateSuggestionsResponse = $root.google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse.fromObject(object.generateSuggestionsResponse);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SuggestionResult message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestionResult
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.SuggestionResult} message SuggestionResult
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SuggestionResult.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (message.error != null && message.hasOwnProperty("error")) {
                                object.error = $root.google.rpc.Status.toObject(message.error, options);
                                if (options.oneofs)
                                    object.suggestionResponse = "error";
                            }
                            if (message.suggestArticlesResponse != null && message.hasOwnProperty("suggestArticlesResponse")) {
                                object.suggestArticlesResponse = $root.google.cloud.dialogflow.v2beta1.SuggestArticlesResponse.toObject(message.suggestArticlesResponse, options);
                                if (options.oneofs)
                                    object.suggestionResponse = "suggestArticlesResponse";
                            }
                            if (message.suggestFaqAnswersResponse != null && message.hasOwnProperty("suggestFaqAnswersResponse")) {
                                object.suggestFaqAnswersResponse = $root.google.cloud.dialogflow.v2beta1.SuggestFaqAnswersResponse.toObject(message.suggestFaqAnswersResponse, options);
                                if (options.oneofs)
                                    object.suggestionResponse = "suggestFaqAnswersResponse";
                            }
                            if (message.suggestSmartRepliesResponse != null && message.hasOwnProperty("suggestSmartRepliesResponse")) {
                                object.suggestSmartRepliesResponse = $root.google.cloud.dialogflow.v2beta1.SuggestSmartRepliesResponse.toObject(message.suggestSmartRepliesResponse, options);
                                if (options.oneofs)
                                    object.suggestionResponse = "suggestSmartRepliesResponse";
                            }
                            if (message.suggestDialogflowAssistsResponse != null && message.hasOwnProperty("suggestDialogflowAssistsResponse")) {
                                object.suggestDialogflowAssistsResponse = $root.google.cloud.dialogflow.v2beta1.SuggestDialogflowAssistsResponse.toObject(message.suggestDialogflowAssistsResponse, options);
                                if (options.oneofs)
                                    object.suggestionResponse = "suggestDialogflowAssistsResponse";
                            }
                            if (message.suggestEntityExtractionResponse != null && message.hasOwnProperty("suggestEntityExtractionResponse")) {
                                object.suggestEntityExtractionResponse = $root.google.cloud.dialogflow.v2beta1.SuggestDialogflowAssistsResponse.toObject(message.suggestEntityExtractionResponse, options);
                                if (options.oneofs)
                                    object.suggestionResponse = "suggestEntityExtractionResponse";
                            }
                            if (message.suggestKnowledgeAssistResponse != null && message.hasOwnProperty("suggestKnowledgeAssistResponse")) {
                                object.suggestKnowledgeAssistResponse = $root.google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistResponse.toObject(message.suggestKnowledgeAssistResponse, options);
                                if (options.oneofs)
                                    object.suggestionResponse = "suggestKnowledgeAssistResponse";
                            }
                            if (message.generateSuggestionsResponse != null && message.hasOwnProperty("generateSuggestionsResponse")) {
                                object.generateSuggestionsResponse = $root.google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse.toObject(message.generateSuggestionsResponse, options);
                                if (options.oneofs)
                                    object.suggestionResponse = "generateSuggestionsResponse";
                            }
                            return object;
                        };
    
                        /**
                         * Converts this SuggestionResult to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestionResult
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SuggestionResult.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SuggestionResult
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestionResult
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SuggestionResult.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.SuggestionResult";
                        };
    
                        return SuggestionResult;
                    })();
    
                    v2beta1.SuggestArticlesRequest = (function() {
    
                        /**
                         * Properties of a SuggestArticlesRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ISuggestArticlesRequest
                         * @property {string|null} [parent] SuggestArticlesRequest parent
                         * @property {string|null} [latestMessage] SuggestArticlesRequest latestMessage
                         * @property {number|null} [contextSize] SuggestArticlesRequest contextSize
                         * @property {google.cloud.dialogflow.v2beta1.IAssistQueryParameters|null} [assistQueryParams] SuggestArticlesRequest assistQueryParams
                         */
    
                        /**
                         * Constructs a new SuggestArticlesRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a SuggestArticlesRequest.
                         * @implements ISuggestArticlesRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestArticlesRequest=} [properties] Properties to set
                         */
                        function SuggestArticlesRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SuggestArticlesRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestArticlesRequest
                         * @instance
                         */
                        SuggestArticlesRequest.prototype.parent = "";
    
                        /**
                         * SuggestArticlesRequest latestMessage.
                         * @member {string} latestMessage
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestArticlesRequest
                         * @instance
                         */
                        SuggestArticlesRequest.prototype.latestMessage = "";
    
                        /**
                         * SuggestArticlesRequest contextSize.
                         * @member {number} contextSize
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestArticlesRequest
                         * @instance
                         */
                        SuggestArticlesRequest.prototype.contextSize = 0;
    
                        /**
                         * SuggestArticlesRequest assistQueryParams.
                         * @member {google.cloud.dialogflow.v2beta1.IAssistQueryParameters|null|undefined} assistQueryParams
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestArticlesRequest
                         * @instance
                         */
                        SuggestArticlesRequest.prototype.assistQueryParams = null;
    
                        /**
                         * Creates a new SuggestArticlesRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestArticlesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestArticlesRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.SuggestArticlesRequest} SuggestArticlesRequest instance
                         */
                        SuggestArticlesRequest.create = function create(properties) {
                            return new SuggestArticlesRequest(properties);
                        };
    
                        /**
                         * Encodes the specified SuggestArticlesRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SuggestArticlesRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestArticlesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestArticlesRequest} message SuggestArticlesRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SuggestArticlesRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.latestMessage != null && Object.hasOwnProperty.call(message, "latestMessage"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.latestMessage);
                            if (message.contextSize != null && Object.hasOwnProperty.call(message, "contextSize"))
                                writer.uint32(/* id 3, wireType 0 =*/24).int32(message.contextSize);
                            if (message.assistQueryParams != null && Object.hasOwnProperty.call(message, "assistQueryParams"))
                                $root.google.cloud.dialogflow.v2beta1.AssistQueryParameters.encode(message.assistQueryParams, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SuggestArticlesRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SuggestArticlesRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestArticlesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestArticlesRequest} message SuggestArticlesRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SuggestArticlesRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SuggestArticlesRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestArticlesRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.SuggestArticlesRequest} SuggestArticlesRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SuggestArticlesRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.SuggestArticlesRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.latestMessage = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.contextSize = reader.int32();
                                        break;
                                    }
                                case 4: {
                                        message.assistQueryParams = $root.google.cloud.dialogflow.v2beta1.AssistQueryParameters.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SuggestArticlesRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestArticlesRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.SuggestArticlesRequest} SuggestArticlesRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SuggestArticlesRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SuggestArticlesRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestArticlesRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SuggestArticlesRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                if (!$util.isString(message.latestMessage))
                                    return "latestMessage: string expected";
                            if (message.contextSize != null && message.hasOwnProperty("contextSize"))
                                if (!$util.isInteger(message.contextSize))
                                    return "contextSize: integer expected";
                            if (message.assistQueryParams != null && message.hasOwnProperty("assistQueryParams")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.AssistQueryParameters.verify(message.assistQueryParams);
                                if (error)
                                    return "assistQueryParams." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a SuggestArticlesRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestArticlesRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.SuggestArticlesRequest} SuggestArticlesRequest
                         */
                        SuggestArticlesRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.SuggestArticlesRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.SuggestArticlesRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.latestMessage != null)
                                message.latestMessage = String(object.latestMessage);
                            if (object.contextSize != null)
                                message.contextSize = object.contextSize | 0;
                            if (object.assistQueryParams != null) {
                                if (typeof object.assistQueryParams !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.SuggestArticlesRequest.assistQueryParams: object expected");
                                message.assistQueryParams = $root.google.cloud.dialogflow.v2beta1.AssistQueryParameters.fromObject(object.assistQueryParams);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SuggestArticlesRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestArticlesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.SuggestArticlesRequest} message SuggestArticlesRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SuggestArticlesRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.latestMessage = "";
                                object.contextSize = 0;
                                object.assistQueryParams = null;
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                object.latestMessage = message.latestMessage;
                            if (message.contextSize != null && message.hasOwnProperty("contextSize"))
                                object.contextSize = message.contextSize;
                            if (message.assistQueryParams != null && message.hasOwnProperty("assistQueryParams"))
                                object.assistQueryParams = $root.google.cloud.dialogflow.v2beta1.AssistQueryParameters.toObject(message.assistQueryParams, options);
                            return object;
                        };
    
                        /**
                         * Converts this SuggestArticlesRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestArticlesRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SuggestArticlesRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SuggestArticlesRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestArticlesRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SuggestArticlesRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.SuggestArticlesRequest";
                        };
    
                        return SuggestArticlesRequest;
                    })();
    
                    v2beta1.SuggestArticlesResponse = (function() {
    
                        /**
                         * Properties of a SuggestArticlesResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ISuggestArticlesResponse
                         * @property {Array.<google.cloud.dialogflow.v2beta1.IArticleAnswer>|null} [articleAnswers] SuggestArticlesResponse articleAnswers
                         * @property {string|null} [latestMessage] SuggestArticlesResponse latestMessage
                         * @property {number|null} [contextSize] SuggestArticlesResponse contextSize
                         */
    
                        /**
                         * Constructs a new SuggestArticlesResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a SuggestArticlesResponse.
                         * @implements ISuggestArticlesResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestArticlesResponse=} [properties] Properties to set
                         */
                        function SuggestArticlesResponse(properties) {
                            this.articleAnswers = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SuggestArticlesResponse articleAnswers.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.IArticleAnswer>} articleAnswers
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestArticlesResponse
                         * @instance
                         */
                        SuggestArticlesResponse.prototype.articleAnswers = $util.emptyArray;
    
                        /**
                         * SuggestArticlesResponse latestMessage.
                         * @member {string} latestMessage
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestArticlesResponse
                         * @instance
                         */
                        SuggestArticlesResponse.prototype.latestMessage = "";
    
                        /**
                         * SuggestArticlesResponse contextSize.
                         * @member {number} contextSize
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestArticlesResponse
                         * @instance
                         */
                        SuggestArticlesResponse.prototype.contextSize = 0;
    
                        /**
                         * Creates a new SuggestArticlesResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestArticlesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestArticlesResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.SuggestArticlesResponse} SuggestArticlesResponse instance
                         */
                        SuggestArticlesResponse.create = function create(properties) {
                            return new SuggestArticlesResponse(properties);
                        };
    
                        /**
                         * Encodes the specified SuggestArticlesResponse message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SuggestArticlesResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestArticlesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestArticlesResponse} message SuggestArticlesResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SuggestArticlesResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.articleAnswers != null && message.articleAnswers.length)
                                for (var i = 0; i < message.articleAnswers.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.ArticleAnswer.encode(message.articleAnswers[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.latestMessage != null && Object.hasOwnProperty.call(message, "latestMessage"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.latestMessage);
                            if (message.contextSize != null && Object.hasOwnProperty.call(message, "contextSize"))
                                writer.uint32(/* id 3, wireType 0 =*/24).int32(message.contextSize);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SuggestArticlesResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SuggestArticlesResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestArticlesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestArticlesResponse} message SuggestArticlesResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SuggestArticlesResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SuggestArticlesResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestArticlesResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.SuggestArticlesResponse} SuggestArticlesResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SuggestArticlesResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.SuggestArticlesResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.articleAnswers && message.articleAnswers.length))
                                            message.articleAnswers = [];
                                        message.articleAnswers.push($root.google.cloud.dialogflow.v2beta1.ArticleAnswer.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 2: {
                                        message.latestMessage = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.contextSize = reader.int32();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SuggestArticlesResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestArticlesResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.SuggestArticlesResponse} SuggestArticlesResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SuggestArticlesResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SuggestArticlesResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestArticlesResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SuggestArticlesResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.articleAnswers != null && message.hasOwnProperty("articleAnswers")) {
                                if (!Array.isArray(message.articleAnswers))
                                    return "articleAnswers: array expected";
                                for (var i = 0; i < message.articleAnswers.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.ArticleAnswer.verify(message.articleAnswers[i]);
                                    if (error)
                                        return "articleAnswers." + error;
                                }
                            }
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                if (!$util.isString(message.latestMessage))
                                    return "latestMessage: string expected";
                            if (message.contextSize != null && message.hasOwnProperty("contextSize"))
                                if (!$util.isInteger(message.contextSize))
                                    return "contextSize: integer expected";
                            return null;
                        };
    
                        /**
                         * Creates a SuggestArticlesResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestArticlesResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.SuggestArticlesResponse} SuggestArticlesResponse
                         */
                        SuggestArticlesResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.SuggestArticlesResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.SuggestArticlesResponse();
                            if (object.articleAnswers) {
                                if (!Array.isArray(object.articleAnswers))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.SuggestArticlesResponse.articleAnswers: array expected");
                                message.articleAnswers = [];
                                for (var i = 0; i < object.articleAnswers.length; ++i) {
                                    if (typeof object.articleAnswers[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.SuggestArticlesResponse.articleAnswers: object expected");
                                    message.articleAnswers[i] = $root.google.cloud.dialogflow.v2beta1.ArticleAnswer.fromObject(object.articleAnswers[i]);
                                }
                            }
                            if (object.latestMessage != null)
                                message.latestMessage = String(object.latestMessage);
                            if (object.contextSize != null)
                                message.contextSize = object.contextSize | 0;
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SuggestArticlesResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestArticlesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.SuggestArticlesResponse} message SuggestArticlesResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SuggestArticlesResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.articleAnswers = [];
                            if (options.defaults) {
                                object.latestMessage = "";
                                object.contextSize = 0;
                            }
                            if (message.articleAnswers && message.articleAnswers.length) {
                                object.articleAnswers = [];
                                for (var j = 0; j < message.articleAnswers.length; ++j)
                                    object.articleAnswers[j] = $root.google.cloud.dialogflow.v2beta1.ArticleAnswer.toObject(message.articleAnswers[j], options);
                            }
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                object.latestMessage = message.latestMessage;
                            if (message.contextSize != null && message.hasOwnProperty("contextSize"))
                                object.contextSize = message.contextSize;
                            return object;
                        };
    
                        /**
                         * Converts this SuggestArticlesResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestArticlesResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SuggestArticlesResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SuggestArticlesResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestArticlesResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SuggestArticlesResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.SuggestArticlesResponse";
                        };
    
                        return SuggestArticlesResponse;
                    })();
    
                    v2beta1.SuggestFaqAnswersRequest = (function() {
    
                        /**
                         * Properties of a SuggestFaqAnswersRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ISuggestFaqAnswersRequest
                         * @property {string|null} [parent] SuggestFaqAnswersRequest parent
                         * @property {string|null} [latestMessage] SuggestFaqAnswersRequest latestMessage
                         * @property {number|null} [contextSize] SuggestFaqAnswersRequest contextSize
                         * @property {google.cloud.dialogflow.v2beta1.IAssistQueryParameters|null} [assistQueryParams] SuggestFaqAnswersRequest assistQueryParams
                         */
    
                        /**
                         * Constructs a new SuggestFaqAnswersRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a SuggestFaqAnswersRequest.
                         * @implements ISuggestFaqAnswersRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestFaqAnswersRequest=} [properties] Properties to set
                         */
                        function SuggestFaqAnswersRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SuggestFaqAnswersRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestFaqAnswersRequest
                         * @instance
                         */
                        SuggestFaqAnswersRequest.prototype.parent = "";
    
                        /**
                         * SuggestFaqAnswersRequest latestMessage.
                         * @member {string} latestMessage
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestFaqAnswersRequest
                         * @instance
                         */
                        SuggestFaqAnswersRequest.prototype.latestMessage = "";
    
                        /**
                         * SuggestFaqAnswersRequest contextSize.
                         * @member {number} contextSize
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestFaqAnswersRequest
                         * @instance
                         */
                        SuggestFaqAnswersRequest.prototype.contextSize = 0;
    
                        /**
                         * SuggestFaqAnswersRequest assistQueryParams.
                         * @member {google.cloud.dialogflow.v2beta1.IAssistQueryParameters|null|undefined} assistQueryParams
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestFaqAnswersRequest
                         * @instance
                         */
                        SuggestFaqAnswersRequest.prototype.assistQueryParams = null;
    
                        /**
                         * Creates a new SuggestFaqAnswersRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestFaqAnswersRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestFaqAnswersRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.SuggestFaqAnswersRequest} SuggestFaqAnswersRequest instance
                         */
                        SuggestFaqAnswersRequest.create = function create(properties) {
                            return new SuggestFaqAnswersRequest(properties);
                        };
    
                        /**
                         * Encodes the specified SuggestFaqAnswersRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SuggestFaqAnswersRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestFaqAnswersRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestFaqAnswersRequest} message SuggestFaqAnswersRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SuggestFaqAnswersRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.latestMessage != null && Object.hasOwnProperty.call(message, "latestMessage"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.latestMessage);
                            if (message.contextSize != null && Object.hasOwnProperty.call(message, "contextSize"))
                                writer.uint32(/* id 3, wireType 0 =*/24).int32(message.contextSize);
                            if (message.assistQueryParams != null && Object.hasOwnProperty.call(message, "assistQueryParams"))
                                $root.google.cloud.dialogflow.v2beta1.AssistQueryParameters.encode(message.assistQueryParams, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SuggestFaqAnswersRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SuggestFaqAnswersRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestFaqAnswersRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestFaqAnswersRequest} message SuggestFaqAnswersRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SuggestFaqAnswersRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SuggestFaqAnswersRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestFaqAnswersRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.SuggestFaqAnswersRequest} SuggestFaqAnswersRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SuggestFaqAnswersRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.SuggestFaqAnswersRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.latestMessage = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.contextSize = reader.int32();
                                        break;
                                    }
                                case 4: {
                                        message.assistQueryParams = $root.google.cloud.dialogflow.v2beta1.AssistQueryParameters.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SuggestFaqAnswersRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestFaqAnswersRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.SuggestFaqAnswersRequest} SuggestFaqAnswersRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SuggestFaqAnswersRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SuggestFaqAnswersRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestFaqAnswersRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SuggestFaqAnswersRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                if (!$util.isString(message.latestMessage))
                                    return "latestMessage: string expected";
                            if (message.contextSize != null && message.hasOwnProperty("contextSize"))
                                if (!$util.isInteger(message.contextSize))
                                    return "contextSize: integer expected";
                            if (message.assistQueryParams != null && message.hasOwnProperty("assistQueryParams")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.AssistQueryParameters.verify(message.assistQueryParams);
                                if (error)
                                    return "assistQueryParams." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a SuggestFaqAnswersRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestFaqAnswersRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.SuggestFaqAnswersRequest} SuggestFaqAnswersRequest
                         */
                        SuggestFaqAnswersRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.SuggestFaqAnswersRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.SuggestFaqAnswersRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.latestMessage != null)
                                message.latestMessage = String(object.latestMessage);
                            if (object.contextSize != null)
                                message.contextSize = object.contextSize | 0;
                            if (object.assistQueryParams != null) {
                                if (typeof object.assistQueryParams !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.SuggestFaqAnswersRequest.assistQueryParams: object expected");
                                message.assistQueryParams = $root.google.cloud.dialogflow.v2beta1.AssistQueryParameters.fromObject(object.assistQueryParams);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SuggestFaqAnswersRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestFaqAnswersRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.SuggestFaqAnswersRequest} message SuggestFaqAnswersRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SuggestFaqAnswersRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.latestMessage = "";
                                object.contextSize = 0;
                                object.assistQueryParams = null;
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                object.latestMessage = message.latestMessage;
                            if (message.contextSize != null && message.hasOwnProperty("contextSize"))
                                object.contextSize = message.contextSize;
                            if (message.assistQueryParams != null && message.hasOwnProperty("assistQueryParams"))
                                object.assistQueryParams = $root.google.cloud.dialogflow.v2beta1.AssistQueryParameters.toObject(message.assistQueryParams, options);
                            return object;
                        };
    
                        /**
                         * Converts this SuggestFaqAnswersRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestFaqAnswersRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SuggestFaqAnswersRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SuggestFaqAnswersRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestFaqAnswersRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SuggestFaqAnswersRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.SuggestFaqAnswersRequest";
                        };
    
                        return SuggestFaqAnswersRequest;
                    })();
    
                    v2beta1.SuggestFaqAnswersResponse = (function() {
    
                        /**
                         * Properties of a SuggestFaqAnswersResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ISuggestFaqAnswersResponse
                         * @property {Array.<google.cloud.dialogflow.v2beta1.IFaqAnswer>|null} [faqAnswers] SuggestFaqAnswersResponse faqAnswers
                         * @property {string|null} [latestMessage] SuggestFaqAnswersResponse latestMessage
                         * @property {number|null} [contextSize] SuggestFaqAnswersResponse contextSize
                         */
    
                        /**
                         * Constructs a new SuggestFaqAnswersResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a SuggestFaqAnswersResponse.
                         * @implements ISuggestFaqAnswersResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestFaqAnswersResponse=} [properties] Properties to set
                         */
                        function SuggestFaqAnswersResponse(properties) {
                            this.faqAnswers = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SuggestFaqAnswersResponse faqAnswers.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.IFaqAnswer>} faqAnswers
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestFaqAnswersResponse
                         * @instance
                         */
                        SuggestFaqAnswersResponse.prototype.faqAnswers = $util.emptyArray;
    
                        /**
                         * SuggestFaqAnswersResponse latestMessage.
                         * @member {string} latestMessage
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestFaqAnswersResponse
                         * @instance
                         */
                        SuggestFaqAnswersResponse.prototype.latestMessage = "";
    
                        /**
                         * SuggestFaqAnswersResponse contextSize.
                         * @member {number} contextSize
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestFaqAnswersResponse
                         * @instance
                         */
                        SuggestFaqAnswersResponse.prototype.contextSize = 0;
    
                        /**
                         * Creates a new SuggestFaqAnswersResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestFaqAnswersResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestFaqAnswersResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.SuggestFaqAnswersResponse} SuggestFaqAnswersResponse instance
                         */
                        SuggestFaqAnswersResponse.create = function create(properties) {
                            return new SuggestFaqAnswersResponse(properties);
                        };
    
                        /**
                         * Encodes the specified SuggestFaqAnswersResponse message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SuggestFaqAnswersResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestFaqAnswersResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestFaqAnswersResponse} message SuggestFaqAnswersResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SuggestFaqAnswersResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.faqAnswers != null && message.faqAnswers.length)
                                for (var i = 0; i < message.faqAnswers.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.FaqAnswer.encode(message.faqAnswers[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.latestMessage != null && Object.hasOwnProperty.call(message, "latestMessage"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.latestMessage);
                            if (message.contextSize != null && Object.hasOwnProperty.call(message, "contextSize"))
                                writer.uint32(/* id 3, wireType 0 =*/24).int32(message.contextSize);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SuggestFaqAnswersResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SuggestFaqAnswersResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestFaqAnswersResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestFaqAnswersResponse} message SuggestFaqAnswersResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SuggestFaqAnswersResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SuggestFaqAnswersResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestFaqAnswersResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.SuggestFaqAnswersResponse} SuggestFaqAnswersResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SuggestFaqAnswersResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.SuggestFaqAnswersResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.faqAnswers && message.faqAnswers.length))
                                            message.faqAnswers = [];
                                        message.faqAnswers.push($root.google.cloud.dialogflow.v2beta1.FaqAnswer.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 2: {
                                        message.latestMessage = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.contextSize = reader.int32();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SuggestFaqAnswersResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestFaqAnswersResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.SuggestFaqAnswersResponse} SuggestFaqAnswersResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SuggestFaqAnswersResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SuggestFaqAnswersResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestFaqAnswersResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SuggestFaqAnswersResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.faqAnswers != null && message.hasOwnProperty("faqAnswers")) {
                                if (!Array.isArray(message.faqAnswers))
                                    return "faqAnswers: array expected";
                                for (var i = 0; i < message.faqAnswers.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.FaqAnswer.verify(message.faqAnswers[i]);
                                    if (error)
                                        return "faqAnswers." + error;
                                }
                            }
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                if (!$util.isString(message.latestMessage))
                                    return "latestMessage: string expected";
                            if (message.contextSize != null && message.hasOwnProperty("contextSize"))
                                if (!$util.isInteger(message.contextSize))
                                    return "contextSize: integer expected";
                            return null;
                        };
    
                        /**
                         * Creates a SuggestFaqAnswersResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestFaqAnswersResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.SuggestFaqAnswersResponse} SuggestFaqAnswersResponse
                         */
                        SuggestFaqAnswersResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.SuggestFaqAnswersResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.SuggestFaqAnswersResponse();
                            if (object.faqAnswers) {
                                if (!Array.isArray(object.faqAnswers))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.SuggestFaqAnswersResponse.faqAnswers: array expected");
                                message.faqAnswers = [];
                                for (var i = 0; i < object.faqAnswers.length; ++i) {
                                    if (typeof object.faqAnswers[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.SuggestFaqAnswersResponse.faqAnswers: object expected");
                                    message.faqAnswers[i] = $root.google.cloud.dialogflow.v2beta1.FaqAnswer.fromObject(object.faqAnswers[i]);
                                }
                            }
                            if (object.latestMessage != null)
                                message.latestMessage = String(object.latestMessage);
                            if (object.contextSize != null)
                                message.contextSize = object.contextSize | 0;
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SuggestFaqAnswersResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestFaqAnswersResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.SuggestFaqAnswersResponse} message SuggestFaqAnswersResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SuggestFaqAnswersResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.faqAnswers = [];
                            if (options.defaults) {
                                object.latestMessage = "";
                                object.contextSize = 0;
                            }
                            if (message.faqAnswers && message.faqAnswers.length) {
                                object.faqAnswers = [];
                                for (var j = 0; j < message.faqAnswers.length; ++j)
                                    object.faqAnswers[j] = $root.google.cloud.dialogflow.v2beta1.FaqAnswer.toObject(message.faqAnswers[j], options);
                            }
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                object.latestMessage = message.latestMessage;
                            if (message.contextSize != null && message.hasOwnProperty("contextSize"))
                                object.contextSize = message.contextSize;
                            return object;
                        };
    
                        /**
                         * Converts this SuggestFaqAnswersResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestFaqAnswersResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SuggestFaqAnswersResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SuggestFaqAnswersResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestFaqAnswersResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SuggestFaqAnswersResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.SuggestFaqAnswersResponse";
                        };
    
                        return SuggestFaqAnswersResponse;
                    })();
    
                    v2beta1.SuggestSmartRepliesRequest = (function() {
    
                        /**
                         * Properties of a SuggestSmartRepliesRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ISuggestSmartRepliesRequest
                         * @property {string|null} [parent] SuggestSmartRepliesRequest parent
                         * @property {google.cloud.dialogflow.v2beta1.ITextInput|null} [currentTextInput] SuggestSmartRepliesRequest currentTextInput
                         * @property {string|null} [latestMessage] SuggestSmartRepliesRequest latestMessage
                         * @property {number|null} [contextSize] SuggestSmartRepliesRequest contextSize
                         */
    
                        /**
                         * Constructs a new SuggestSmartRepliesRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a SuggestSmartRepliesRequest.
                         * @implements ISuggestSmartRepliesRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestSmartRepliesRequest=} [properties] Properties to set
                         */
                        function SuggestSmartRepliesRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SuggestSmartRepliesRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestSmartRepliesRequest
                         * @instance
                         */
                        SuggestSmartRepliesRequest.prototype.parent = "";
    
                        /**
                         * SuggestSmartRepliesRequest currentTextInput.
                         * @member {google.cloud.dialogflow.v2beta1.ITextInput|null|undefined} currentTextInput
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestSmartRepliesRequest
                         * @instance
                         */
                        SuggestSmartRepliesRequest.prototype.currentTextInput = null;
    
                        /**
                         * SuggestSmartRepliesRequest latestMessage.
                         * @member {string} latestMessage
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestSmartRepliesRequest
                         * @instance
                         */
                        SuggestSmartRepliesRequest.prototype.latestMessage = "";
    
                        /**
                         * SuggestSmartRepliesRequest contextSize.
                         * @member {number} contextSize
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestSmartRepliesRequest
                         * @instance
                         */
                        SuggestSmartRepliesRequest.prototype.contextSize = 0;
    
                        /**
                         * Creates a new SuggestSmartRepliesRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestSmartRepliesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestSmartRepliesRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.SuggestSmartRepliesRequest} SuggestSmartRepliesRequest instance
                         */
                        SuggestSmartRepliesRequest.create = function create(properties) {
                            return new SuggestSmartRepliesRequest(properties);
                        };
    
                        /**
                         * Encodes the specified SuggestSmartRepliesRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SuggestSmartRepliesRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestSmartRepliesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestSmartRepliesRequest} message SuggestSmartRepliesRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SuggestSmartRepliesRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.latestMessage != null && Object.hasOwnProperty.call(message, "latestMessage"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.latestMessage);
                            if (message.contextSize != null && Object.hasOwnProperty.call(message, "contextSize"))
                                writer.uint32(/* id 3, wireType 0 =*/24).int32(message.contextSize);
                            if (message.currentTextInput != null && Object.hasOwnProperty.call(message, "currentTextInput"))
                                $root.google.cloud.dialogflow.v2beta1.TextInput.encode(message.currentTextInput, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SuggestSmartRepliesRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SuggestSmartRepliesRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestSmartRepliesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestSmartRepliesRequest} message SuggestSmartRepliesRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SuggestSmartRepliesRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SuggestSmartRepliesRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestSmartRepliesRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.SuggestSmartRepliesRequest} SuggestSmartRepliesRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SuggestSmartRepliesRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.SuggestSmartRepliesRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 4: {
                                        message.currentTextInput = $root.google.cloud.dialogflow.v2beta1.TextInput.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.latestMessage = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.contextSize = reader.int32();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SuggestSmartRepliesRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestSmartRepliesRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.SuggestSmartRepliesRequest} SuggestSmartRepliesRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SuggestSmartRepliesRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SuggestSmartRepliesRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestSmartRepliesRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SuggestSmartRepliesRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.currentTextInput != null && message.hasOwnProperty("currentTextInput")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.TextInput.verify(message.currentTextInput);
                                if (error)
                                    return "currentTextInput." + error;
                            }
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                if (!$util.isString(message.latestMessage))
                                    return "latestMessage: string expected";
                            if (message.contextSize != null && message.hasOwnProperty("contextSize"))
                                if (!$util.isInteger(message.contextSize))
                                    return "contextSize: integer expected";
                            return null;
                        };
    
                        /**
                         * Creates a SuggestSmartRepliesRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestSmartRepliesRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.SuggestSmartRepliesRequest} SuggestSmartRepliesRequest
                         */
                        SuggestSmartRepliesRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.SuggestSmartRepliesRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.SuggestSmartRepliesRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.currentTextInput != null) {
                                if (typeof object.currentTextInput !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.SuggestSmartRepliesRequest.currentTextInput: object expected");
                                message.currentTextInput = $root.google.cloud.dialogflow.v2beta1.TextInput.fromObject(object.currentTextInput);
                            }
                            if (object.latestMessage != null)
                                message.latestMessage = String(object.latestMessage);
                            if (object.contextSize != null)
                                message.contextSize = object.contextSize | 0;
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SuggestSmartRepliesRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestSmartRepliesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.SuggestSmartRepliesRequest} message SuggestSmartRepliesRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SuggestSmartRepliesRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.latestMessage = "";
                                object.contextSize = 0;
                                object.currentTextInput = null;
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                object.latestMessage = message.latestMessage;
                            if (message.contextSize != null && message.hasOwnProperty("contextSize"))
                                object.contextSize = message.contextSize;
                            if (message.currentTextInput != null && message.hasOwnProperty("currentTextInput"))
                                object.currentTextInput = $root.google.cloud.dialogflow.v2beta1.TextInput.toObject(message.currentTextInput, options);
                            return object;
                        };
    
                        /**
                         * Converts this SuggestSmartRepliesRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestSmartRepliesRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SuggestSmartRepliesRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SuggestSmartRepliesRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestSmartRepliesRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SuggestSmartRepliesRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.SuggestSmartRepliesRequest";
                        };
    
                        return SuggestSmartRepliesRequest;
                    })();
    
                    v2beta1.SuggestSmartRepliesResponse = (function() {
    
                        /**
                         * Properties of a SuggestSmartRepliesResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ISuggestSmartRepliesResponse
                         * @property {Array.<google.cloud.dialogflow.v2beta1.ISmartReplyAnswer>|null} [smartReplyAnswers] SuggestSmartRepliesResponse smartReplyAnswers
                         * @property {string|null} [latestMessage] SuggestSmartRepliesResponse latestMessage
                         * @property {number|null} [contextSize] SuggestSmartRepliesResponse contextSize
                         */
    
                        /**
                         * Constructs a new SuggestSmartRepliesResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a SuggestSmartRepliesResponse.
                         * @implements ISuggestSmartRepliesResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestSmartRepliesResponse=} [properties] Properties to set
                         */
                        function SuggestSmartRepliesResponse(properties) {
                            this.smartReplyAnswers = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SuggestSmartRepliesResponse smartReplyAnswers.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.ISmartReplyAnswer>} smartReplyAnswers
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestSmartRepliesResponse
                         * @instance
                         */
                        SuggestSmartRepliesResponse.prototype.smartReplyAnswers = $util.emptyArray;
    
                        /**
                         * SuggestSmartRepliesResponse latestMessage.
                         * @member {string} latestMessage
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestSmartRepliesResponse
                         * @instance
                         */
                        SuggestSmartRepliesResponse.prototype.latestMessage = "";
    
                        /**
                         * SuggestSmartRepliesResponse contextSize.
                         * @member {number} contextSize
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestSmartRepliesResponse
                         * @instance
                         */
                        SuggestSmartRepliesResponse.prototype.contextSize = 0;
    
                        /**
                         * Creates a new SuggestSmartRepliesResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestSmartRepliesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestSmartRepliesResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.SuggestSmartRepliesResponse} SuggestSmartRepliesResponse instance
                         */
                        SuggestSmartRepliesResponse.create = function create(properties) {
                            return new SuggestSmartRepliesResponse(properties);
                        };
    
                        /**
                         * Encodes the specified SuggestSmartRepliesResponse message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SuggestSmartRepliesResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestSmartRepliesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestSmartRepliesResponse} message SuggestSmartRepliesResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SuggestSmartRepliesResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.smartReplyAnswers != null && message.smartReplyAnswers.length)
                                for (var i = 0; i < message.smartReplyAnswers.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.SmartReplyAnswer.encode(message.smartReplyAnswers[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.latestMessage != null && Object.hasOwnProperty.call(message, "latestMessage"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.latestMessage);
                            if (message.contextSize != null && Object.hasOwnProperty.call(message, "contextSize"))
                                writer.uint32(/* id 3, wireType 0 =*/24).int32(message.contextSize);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SuggestSmartRepliesResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SuggestSmartRepliesResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestSmartRepliesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestSmartRepliesResponse} message SuggestSmartRepliesResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SuggestSmartRepliesResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SuggestSmartRepliesResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestSmartRepliesResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.SuggestSmartRepliesResponse} SuggestSmartRepliesResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SuggestSmartRepliesResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.SuggestSmartRepliesResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.smartReplyAnswers && message.smartReplyAnswers.length))
                                            message.smartReplyAnswers = [];
                                        message.smartReplyAnswers.push($root.google.cloud.dialogflow.v2beta1.SmartReplyAnswer.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 2: {
                                        message.latestMessage = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.contextSize = reader.int32();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SuggestSmartRepliesResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestSmartRepliesResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.SuggestSmartRepliesResponse} SuggestSmartRepliesResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SuggestSmartRepliesResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SuggestSmartRepliesResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestSmartRepliesResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SuggestSmartRepliesResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.smartReplyAnswers != null && message.hasOwnProperty("smartReplyAnswers")) {
                                if (!Array.isArray(message.smartReplyAnswers))
                                    return "smartReplyAnswers: array expected";
                                for (var i = 0; i < message.smartReplyAnswers.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.SmartReplyAnswer.verify(message.smartReplyAnswers[i]);
                                    if (error)
                                        return "smartReplyAnswers." + error;
                                }
                            }
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                if (!$util.isString(message.latestMessage))
                                    return "latestMessage: string expected";
                            if (message.contextSize != null && message.hasOwnProperty("contextSize"))
                                if (!$util.isInteger(message.contextSize))
                                    return "contextSize: integer expected";
                            return null;
                        };
    
                        /**
                         * Creates a SuggestSmartRepliesResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestSmartRepliesResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.SuggestSmartRepliesResponse} SuggestSmartRepliesResponse
                         */
                        SuggestSmartRepliesResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.SuggestSmartRepliesResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.SuggestSmartRepliesResponse();
                            if (object.smartReplyAnswers) {
                                if (!Array.isArray(object.smartReplyAnswers))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.SuggestSmartRepliesResponse.smartReplyAnswers: array expected");
                                message.smartReplyAnswers = [];
                                for (var i = 0; i < object.smartReplyAnswers.length; ++i) {
                                    if (typeof object.smartReplyAnswers[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.SuggestSmartRepliesResponse.smartReplyAnswers: object expected");
                                    message.smartReplyAnswers[i] = $root.google.cloud.dialogflow.v2beta1.SmartReplyAnswer.fromObject(object.smartReplyAnswers[i]);
                                }
                            }
                            if (object.latestMessage != null)
                                message.latestMessage = String(object.latestMessage);
                            if (object.contextSize != null)
                                message.contextSize = object.contextSize | 0;
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SuggestSmartRepliesResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestSmartRepliesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.SuggestSmartRepliesResponse} message SuggestSmartRepliesResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SuggestSmartRepliesResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.smartReplyAnswers = [];
                            if (options.defaults) {
                                object.latestMessage = "";
                                object.contextSize = 0;
                            }
                            if (message.smartReplyAnswers && message.smartReplyAnswers.length) {
                                object.smartReplyAnswers = [];
                                for (var j = 0; j < message.smartReplyAnswers.length; ++j)
                                    object.smartReplyAnswers[j] = $root.google.cloud.dialogflow.v2beta1.SmartReplyAnswer.toObject(message.smartReplyAnswers[j], options);
                            }
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                object.latestMessage = message.latestMessage;
                            if (message.contextSize != null && message.hasOwnProperty("contextSize"))
                                object.contextSize = message.contextSize;
                            return object;
                        };
    
                        /**
                         * Converts this SuggestSmartRepliesResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestSmartRepliesResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SuggestSmartRepliesResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SuggestSmartRepliesResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestSmartRepliesResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SuggestSmartRepliesResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.SuggestSmartRepliesResponse";
                        };
    
                        return SuggestSmartRepliesResponse;
                    })();
    
                    v2beta1.GenerateSuggestionsResponse = (function() {
    
                        /**
                         * Properties of a GenerateSuggestionsResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IGenerateSuggestionsResponse
                         * @property {Array.<google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse.IGeneratorSuggestionAnswer>|null} [generatorSuggestionAnswers] GenerateSuggestionsResponse generatorSuggestionAnswers
                         * @property {string|null} [latestMessage] GenerateSuggestionsResponse latestMessage
                         */
    
                        /**
                         * Constructs a new GenerateSuggestionsResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a GenerateSuggestionsResponse.
                         * @implements IGenerateSuggestionsResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IGenerateSuggestionsResponse=} [properties] Properties to set
                         */
                        function GenerateSuggestionsResponse(properties) {
                            this.generatorSuggestionAnswers = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GenerateSuggestionsResponse generatorSuggestionAnswers.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse.IGeneratorSuggestionAnswer>} generatorSuggestionAnswers
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse
                         * @instance
                         */
                        GenerateSuggestionsResponse.prototype.generatorSuggestionAnswers = $util.emptyArray;
    
                        /**
                         * GenerateSuggestionsResponse latestMessage.
                         * @member {string} latestMessage
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse
                         * @instance
                         */
                        GenerateSuggestionsResponse.prototype.latestMessage = "";
    
                        /**
                         * Creates a new GenerateSuggestionsResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGenerateSuggestionsResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse} GenerateSuggestionsResponse instance
                         */
                        GenerateSuggestionsResponse.create = function create(properties) {
                            return new GenerateSuggestionsResponse(properties);
                        };
    
                        /**
                         * Encodes the specified GenerateSuggestionsResponse message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGenerateSuggestionsResponse} message GenerateSuggestionsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GenerateSuggestionsResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.generatorSuggestionAnswers != null && message.generatorSuggestionAnswers.length)
                                for (var i = 0; i < message.generatorSuggestionAnswers.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse.GeneratorSuggestionAnswer.encode(message.generatorSuggestionAnswers[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.latestMessage != null && Object.hasOwnProperty.call(message, "latestMessage"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.latestMessage);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GenerateSuggestionsResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGenerateSuggestionsResponse} message GenerateSuggestionsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GenerateSuggestionsResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GenerateSuggestionsResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse} GenerateSuggestionsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GenerateSuggestionsResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.generatorSuggestionAnswers && message.generatorSuggestionAnswers.length))
                                            message.generatorSuggestionAnswers = [];
                                        message.generatorSuggestionAnswers.push($root.google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse.GeneratorSuggestionAnswer.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 2: {
                                        message.latestMessage = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GenerateSuggestionsResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse} GenerateSuggestionsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GenerateSuggestionsResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GenerateSuggestionsResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GenerateSuggestionsResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.generatorSuggestionAnswers != null && message.hasOwnProperty("generatorSuggestionAnswers")) {
                                if (!Array.isArray(message.generatorSuggestionAnswers))
                                    return "generatorSuggestionAnswers: array expected";
                                for (var i = 0; i < message.generatorSuggestionAnswers.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse.GeneratorSuggestionAnswer.verify(message.generatorSuggestionAnswers[i]);
                                    if (error)
                                        return "generatorSuggestionAnswers." + error;
                                }
                            }
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                if (!$util.isString(message.latestMessage))
                                    return "latestMessage: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a GenerateSuggestionsResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse} GenerateSuggestionsResponse
                         */
                        GenerateSuggestionsResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse();
                            if (object.generatorSuggestionAnswers) {
                                if (!Array.isArray(object.generatorSuggestionAnswers))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse.generatorSuggestionAnswers: array expected");
                                message.generatorSuggestionAnswers = [];
                                for (var i = 0; i < object.generatorSuggestionAnswers.length; ++i) {
                                    if (typeof object.generatorSuggestionAnswers[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse.generatorSuggestionAnswers: object expected");
                                    message.generatorSuggestionAnswers[i] = $root.google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse.GeneratorSuggestionAnswer.fromObject(object.generatorSuggestionAnswers[i]);
                                }
                            }
                            if (object.latestMessage != null)
                                message.latestMessage = String(object.latestMessage);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GenerateSuggestionsResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse} message GenerateSuggestionsResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GenerateSuggestionsResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.generatorSuggestionAnswers = [];
                            if (options.defaults)
                                object.latestMessage = "";
                            if (message.generatorSuggestionAnswers && message.generatorSuggestionAnswers.length) {
                                object.generatorSuggestionAnswers = [];
                                for (var j = 0; j < message.generatorSuggestionAnswers.length; ++j)
                                    object.generatorSuggestionAnswers[j] = $root.google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse.GeneratorSuggestionAnswer.toObject(message.generatorSuggestionAnswers[j], options);
                            }
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                object.latestMessage = message.latestMessage;
                            return object;
                        };
    
                        /**
                         * Converts this GenerateSuggestionsResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GenerateSuggestionsResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GenerateSuggestionsResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GenerateSuggestionsResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse";
                        };
    
                        GenerateSuggestionsResponse.GeneratorSuggestionAnswer = (function() {
    
                            /**
                             * Properties of a GeneratorSuggestionAnswer.
                             * @memberof google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse
                             * @interface IGeneratorSuggestionAnswer
                             * @property {google.cloud.dialogflow.v2beta1.IGeneratorSuggestion|null} [generatorSuggestion] GeneratorSuggestionAnswer generatorSuggestion
                             * @property {string|null} [sourceGenerator] GeneratorSuggestionAnswer sourceGenerator
                             * @property {string|null} [answerRecord] GeneratorSuggestionAnswer answerRecord
                             */
    
                            /**
                             * Constructs a new GeneratorSuggestionAnswer.
                             * @memberof google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse
                             * @classdesc Represents a GeneratorSuggestionAnswer.
                             * @implements IGeneratorSuggestionAnswer
                             * @constructor
                             * @param {google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse.IGeneratorSuggestionAnswer=} [properties] Properties to set
                             */
                            function GeneratorSuggestionAnswer(properties) {
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * GeneratorSuggestionAnswer generatorSuggestion.
                             * @member {google.cloud.dialogflow.v2beta1.IGeneratorSuggestion|null|undefined} generatorSuggestion
                             * @memberof google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse.GeneratorSuggestionAnswer
                             * @instance
                             */
                            GeneratorSuggestionAnswer.prototype.generatorSuggestion = null;
    
                            /**
                             * GeneratorSuggestionAnswer sourceGenerator.
                             * @member {string} sourceGenerator
                             * @memberof google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse.GeneratorSuggestionAnswer
                             * @instance
                             */
                            GeneratorSuggestionAnswer.prototype.sourceGenerator = "";
    
                            /**
                             * GeneratorSuggestionAnswer answerRecord.
                             * @member {string} answerRecord
                             * @memberof google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse.GeneratorSuggestionAnswer
                             * @instance
                             */
                            GeneratorSuggestionAnswer.prototype.answerRecord = "";
    
                            /**
                             * Creates a new GeneratorSuggestionAnswer instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse.GeneratorSuggestionAnswer
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse.IGeneratorSuggestionAnswer=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse.GeneratorSuggestionAnswer} GeneratorSuggestionAnswer instance
                             */
                            GeneratorSuggestionAnswer.create = function create(properties) {
                                return new GeneratorSuggestionAnswer(properties);
                            };
    
                            /**
                             * Encodes the specified GeneratorSuggestionAnswer message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse.GeneratorSuggestionAnswer.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse.GeneratorSuggestionAnswer
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse.IGeneratorSuggestionAnswer} message GeneratorSuggestionAnswer message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            GeneratorSuggestionAnswer.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.generatorSuggestion != null && Object.hasOwnProperty.call(message, "generatorSuggestion"))
                                    $root.google.cloud.dialogflow.v2beta1.GeneratorSuggestion.encode(message.generatorSuggestion, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                                if (message.sourceGenerator != null && Object.hasOwnProperty.call(message, "sourceGenerator"))
                                    writer.uint32(/* id 2, wireType 2 =*/18).string(message.sourceGenerator);
                                if (message.answerRecord != null && Object.hasOwnProperty.call(message, "answerRecord"))
                                    writer.uint32(/* id 3, wireType 2 =*/26).string(message.answerRecord);
                                return writer;
                            };
    
                            /**
                             * Encodes the specified GeneratorSuggestionAnswer message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse.GeneratorSuggestionAnswer.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse.GeneratorSuggestionAnswer
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse.IGeneratorSuggestionAnswer} message GeneratorSuggestionAnswer message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            GeneratorSuggestionAnswer.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a GeneratorSuggestionAnswer message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse.GeneratorSuggestionAnswer
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse.GeneratorSuggestionAnswer} GeneratorSuggestionAnswer
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            GeneratorSuggestionAnswer.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse.GeneratorSuggestionAnswer();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.generatorSuggestion = $root.google.cloud.dialogflow.v2beta1.GeneratorSuggestion.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 2: {
                                            message.sourceGenerator = reader.string();
                                            break;
                                        }
                                    case 3: {
                                            message.answerRecord = reader.string();
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a GeneratorSuggestionAnswer message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse.GeneratorSuggestionAnswer
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse.GeneratorSuggestionAnswer} GeneratorSuggestionAnswer
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            GeneratorSuggestionAnswer.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a GeneratorSuggestionAnswer message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse.GeneratorSuggestionAnswer
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            GeneratorSuggestionAnswer.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.generatorSuggestion != null && message.hasOwnProperty("generatorSuggestion")) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.GeneratorSuggestion.verify(message.generatorSuggestion);
                                    if (error)
                                        return "generatorSuggestion." + error;
                                }
                                if (message.sourceGenerator != null && message.hasOwnProperty("sourceGenerator"))
                                    if (!$util.isString(message.sourceGenerator))
                                        return "sourceGenerator: string expected";
                                if (message.answerRecord != null && message.hasOwnProperty("answerRecord"))
                                    if (!$util.isString(message.answerRecord))
                                        return "answerRecord: string expected";
                                return null;
                            };
    
                            /**
                             * Creates a GeneratorSuggestionAnswer message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse.GeneratorSuggestionAnswer
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse.GeneratorSuggestionAnswer} GeneratorSuggestionAnswer
                             */
                            GeneratorSuggestionAnswer.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse.GeneratorSuggestionAnswer)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse.GeneratorSuggestionAnswer();
                                if (object.generatorSuggestion != null) {
                                    if (typeof object.generatorSuggestion !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse.GeneratorSuggestionAnswer.generatorSuggestion: object expected");
                                    message.generatorSuggestion = $root.google.cloud.dialogflow.v2beta1.GeneratorSuggestion.fromObject(object.generatorSuggestion);
                                }
                                if (object.sourceGenerator != null)
                                    message.sourceGenerator = String(object.sourceGenerator);
                                if (object.answerRecord != null)
                                    message.answerRecord = String(object.answerRecord);
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a GeneratorSuggestionAnswer message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse.GeneratorSuggestionAnswer
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse.GeneratorSuggestionAnswer} message GeneratorSuggestionAnswer
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            GeneratorSuggestionAnswer.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.defaults) {
                                    object.generatorSuggestion = null;
                                    object.sourceGenerator = "";
                                    object.answerRecord = "";
                                }
                                if (message.generatorSuggestion != null && message.hasOwnProperty("generatorSuggestion"))
                                    object.generatorSuggestion = $root.google.cloud.dialogflow.v2beta1.GeneratorSuggestion.toObject(message.generatorSuggestion, options);
                                if (message.sourceGenerator != null && message.hasOwnProperty("sourceGenerator"))
                                    object.sourceGenerator = message.sourceGenerator;
                                if (message.answerRecord != null && message.hasOwnProperty("answerRecord"))
                                    object.answerRecord = message.answerRecord;
                                return object;
                            };
    
                            /**
                             * Converts this GeneratorSuggestionAnswer to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse.GeneratorSuggestionAnswer
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            GeneratorSuggestionAnswer.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for GeneratorSuggestionAnswer
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse.GeneratorSuggestionAnswer
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            GeneratorSuggestionAnswer.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse.GeneratorSuggestionAnswer";
                            };
    
                            return GeneratorSuggestionAnswer;
                        })();
    
                        return GenerateSuggestionsResponse;
                    })();
    
                    v2beta1.SuggestDialogflowAssistsResponse = (function() {
    
                        /**
                         * Properties of a SuggestDialogflowAssistsResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ISuggestDialogflowAssistsResponse
                         * @property {Array.<google.cloud.dialogflow.v2beta1.IDialogflowAssistAnswer>|null} [dialogflowAssistAnswers] SuggestDialogflowAssistsResponse dialogflowAssistAnswers
                         * @property {string|null} [latestMessage] SuggestDialogflowAssistsResponse latestMessage
                         * @property {number|null} [contextSize] SuggestDialogflowAssistsResponse contextSize
                         */
    
                        /**
                         * Constructs a new SuggestDialogflowAssistsResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a SuggestDialogflowAssistsResponse.
                         * @implements ISuggestDialogflowAssistsResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestDialogflowAssistsResponse=} [properties] Properties to set
                         */
                        function SuggestDialogflowAssistsResponse(properties) {
                            this.dialogflowAssistAnswers = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SuggestDialogflowAssistsResponse dialogflowAssistAnswers.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.IDialogflowAssistAnswer>} dialogflowAssistAnswers
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestDialogflowAssistsResponse
                         * @instance
                         */
                        SuggestDialogflowAssistsResponse.prototype.dialogflowAssistAnswers = $util.emptyArray;
    
                        /**
                         * SuggestDialogflowAssistsResponse latestMessage.
                         * @member {string} latestMessage
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestDialogflowAssistsResponse
                         * @instance
                         */
                        SuggestDialogflowAssistsResponse.prototype.latestMessage = "";
    
                        /**
                         * SuggestDialogflowAssistsResponse contextSize.
                         * @member {number} contextSize
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestDialogflowAssistsResponse
                         * @instance
                         */
                        SuggestDialogflowAssistsResponse.prototype.contextSize = 0;
    
                        /**
                         * Creates a new SuggestDialogflowAssistsResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestDialogflowAssistsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestDialogflowAssistsResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.SuggestDialogflowAssistsResponse} SuggestDialogflowAssistsResponse instance
                         */
                        SuggestDialogflowAssistsResponse.create = function create(properties) {
                            return new SuggestDialogflowAssistsResponse(properties);
                        };
    
                        /**
                         * Encodes the specified SuggestDialogflowAssistsResponse message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SuggestDialogflowAssistsResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestDialogflowAssistsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestDialogflowAssistsResponse} message SuggestDialogflowAssistsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SuggestDialogflowAssistsResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.dialogflowAssistAnswers != null && message.dialogflowAssistAnswers.length)
                                for (var i = 0; i < message.dialogflowAssistAnswers.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.DialogflowAssistAnswer.encode(message.dialogflowAssistAnswers[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.latestMessage != null && Object.hasOwnProperty.call(message, "latestMessage"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.latestMessage);
                            if (message.contextSize != null && Object.hasOwnProperty.call(message, "contextSize"))
                                writer.uint32(/* id 3, wireType 0 =*/24).int32(message.contextSize);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SuggestDialogflowAssistsResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SuggestDialogflowAssistsResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestDialogflowAssistsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestDialogflowAssistsResponse} message SuggestDialogflowAssistsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SuggestDialogflowAssistsResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SuggestDialogflowAssistsResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestDialogflowAssistsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.SuggestDialogflowAssistsResponse} SuggestDialogflowAssistsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SuggestDialogflowAssistsResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.SuggestDialogflowAssistsResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.dialogflowAssistAnswers && message.dialogflowAssistAnswers.length))
                                            message.dialogflowAssistAnswers = [];
                                        message.dialogflowAssistAnswers.push($root.google.cloud.dialogflow.v2beta1.DialogflowAssistAnswer.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 2: {
                                        message.latestMessage = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.contextSize = reader.int32();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SuggestDialogflowAssistsResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestDialogflowAssistsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.SuggestDialogflowAssistsResponse} SuggestDialogflowAssistsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SuggestDialogflowAssistsResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SuggestDialogflowAssistsResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestDialogflowAssistsResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SuggestDialogflowAssistsResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.dialogflowAssistAnswers != null && message.hasOwnProperty("dialogflowAssistAnswers")) {
                                if (!Array.isArray(message.dialogflowAssistAnswers))
                                    return "dialogflowAssistAnswers: array expected";
                                for (var i = 0; i < message.dialogflowAssistAnswers.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.DialogflowAssistAnswer.verify(message.dialogflowAssistAnswers[i]);
                                    if (error)
                                        return "dialogflowAssistAnswers." + error;
                                }
                            }
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                if (!$util.isString(message.latestMessage))
                                    return "latestMessage: string expected";
                            if (message.contextSize != null && message.hasOwnProperty("contextSize"))
                                if (!$util.isInteger(message.contextSize))
                                    return "contextSize: integer expected";
                            return null;
                        };
    
                        /**
                         * Creates a SuggestDialogflowAssistsResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestDialogflowAssistsResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.SuggestDialogflowAssistsResponse} SuggestDialogflowAssistsResponse
                         */
                        SuggestDialogflowAssistsResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.SuggestDialogflowAssistsResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.SuggestDialogflowAssistsResponse();
                            if (object.dialogflowAssistAnswers) {
                                if (!Array.isArray(object.dialogflowAssistAnswers))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.SuggestDialogflowAssistsResponse.dialogflowAssistAnswers: array expected");
                                message.dialogflowAssistAnswers = [];
                                for (var i = 0; i < object.dialogflowAssistAnswers.length; ++i) {
                                    if (typeof object.dialogflowAssistAnswers[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.SuggestDialogflowAssistsResponse.dialogflowAssistAnswers: object expected");
                                    message.dialogflowAssistAnswers[i] = $root.google.cloud.dialogflow.v2beta1.DialogflowAssistAnswer.fromObject(object.dialogflowAssistAnswers[i]);
                                }
                            }
                            if (object.latestMessage != null)
                                message.latestMessage = String(object.latestMessage);
                            if (object.contextSize != null)
                                message.contextSize = object.contextSize | 0;
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SuggestDialogflowAssistsResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestDialogflowAssistsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.SuggestDialogflowAssistsResponse} message SuggestDialogflowAssistsResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SuggestDialogflowAssistsResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.dialogflowAssistAnswers = [];
                            if (options.defaults) {
                                object.latestMessage = "";
                                object.contextSize = 0;
                            }
                            if (message.dialogflowAssistAnswers && message.dialogflowAssistAnswers.length) {
                                object.dialogflowAssistAnswers = [];
                                for (var j = 0; j < message.dialogflowAssistAnswers.length; ++j)
                                    object.dialogflowAssistAnswers[j] = $root.google.cloud.dialogflow.v2beta1.DialogflowAssistAnswer.toObject(message.dialogflowAssistAnswers[j], options);
                            }
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                object.latestMessage = message.latestMessage;
                            if (message.contextSize != null && message.hasOwnProperty("contextSize"))
                                object.contextSize = message.contextSize;
                            return object;
                        };
    
                        /**
                         * Converts this SuggestDialogflowAssistsResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestDialogflowAssistsResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SuggestDialogflowAssistsResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SuggestDialogflowAssistsResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestDialogflowAssistsResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SuggestDialogflowAssistsResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.SuggestDialogflowAssistsResponse";
                        };
    
                        return SuggestDialogflowAssistsResponse;
                    })();
    
                    v2beta1.Suggestion = (function() {
    
                        /**
                         * Properties of a Suggestion.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ISuggestion
                         * @property {string|null} [name] Suggestion name
                         * @property {Array.<google.cloud.dialogflow.v2beta1.Suggestion.IArticle>|null} [articles] Suggestion articles
                         * @property {Array.<google.cloud.dialogflow.v2beta1.Suggestion.IFaqAnswer>|null} [faqAnswers] Suggestion faqAnswers
                         * @property {google.protobuf.ITimestamp|null} [createTime] Suggestion createTime
                         * @property {string|null} [latestMessage] Suggestion latestMessage
                         */
    
                        /**
                         * Constructs a new Suggestion.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a Suggestion.
                         * @implements ISuggestion
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestion=} [properties] Properties to set
                         */
                        function Suggestion(properties) {
                            this.articles = [];
                            this.faqAnswers = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * Suggestion name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2beta1.Suggestion
                         * @instance
                         */
                        Suggestion.prototype.name = "";
    
                        /**
                         * Suggestion articles.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.Suggestion.IArticle>} articles
                         * @memberof google.cloud.dialogflow.v2beta1.Suggestion
                         * @instance
                         */
                        Suggestion.prototype.articles = $util.emptyArray;
    
                        /**
                         * Suggestion faqAnswers.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.Suggestion.IFaqAnswer>} faqAnswers
                         * @memberof google.cloud.dialogflow.v2beta1.Suggestion
                         * @instance
                         */
                        Suggestion.prototype.faqAnswers = $util.emptyArray;
    
                        /**
                         * Suggestion createTime.
                         * @member {google.protobuf.ITimestamp|null|undefined} createTime
                         * @memberof google.cloud.dialogflow.v2beta1.Suggestion
                         * @instance
                         */
                        Suggestion.prototype.createTime = null;
    
                        /**
                         * Suggestion latestMessage.
                         * @member {string} latestMessage
                         * @memberof google.cloud.dialogflow.v2beta1.Suggestion
                         * @instance
                         */
                        Suggestion.prototype.latestMessage = "";
    
                        /**
                         * Creates a new Suggestion instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.Suggestion
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestion=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.Suggestion} Suggestion instance
                         */
                        Suggestion.create = function create(properties) {
                            return new Suggestion(properties);
                        };
    
                        /**
                         * Encodes the specified Suggestion message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Suggestion.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.Suggestion
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestion} message Suggestion message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        Suggestion.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            if (message.articles != null && message.articles.length)
                                for (var i = 0; i < message.articles.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.Suggestion.Article.encode(message.articles[i], writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.faqAnswers != null && message.faqAnswers.length)
                                for (var i = 0; i < message.faqAnswers.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.Suggestion.FaqAnswer.encode(message.faqAnswers[i], writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            if (message.createTime != null && Object.hasOwnProperty.call(message, "createTime"))
                                $root.google.protobuf.Timestamp.encode(message.createTime, writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                            if (message.latestMessage != null && Object.hasOwnProperty.call(message, "latestMessage"))
                                writer.uint32(/* id 7, wireType 2 =*/58).string(message.latestMessage);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified Suggestion message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Suggestion.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.Suggestion
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestion} message Suggestion message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        Suggestion.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a Suggestion message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.Suggestion
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.Suggestion} Suggestion
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        Suggestion.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Suggestion();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                case 2: {
                                        if (!(message.articles && message.articles.length))
                                            message.articles = [];
                                        message.articles.push($root.google.cloud.dialogflow.v2beta1.Suggestion.Article.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 4: {
                                        if (!(message.faqAnswers && message.faqAnswers.length))
                                            message.faqAnswers = [];
                                        message.faqAnswers.push($root.google.cloud.dialogflow.v2beta1.Suggestion.FaqAnswer.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 5: {
                                        message.createTime = $root.google.protobuf.Timestamp.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 7: {
                                        message.latestMessage = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a Suggestion message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.Suggestion
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.Suggestion} Suggestion
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        Suggestion.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a Suggestion message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.Suggestion
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        Suggestion.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            if (message.articles != null && message.hasOwnProperty("articles")) {
                                if (!Array.isArray(message.articles))
                                    return "articles: array expected";
                                for (var i = 0; i < message.articles.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.Suggestion.Article.verify(message.articles[i]);
                                    if (error)
                                        return "articles." + error;
                                }
                            }
                            if (message.faqAnswers != null && message.hasOwnProperty("faqAnswers")) {
                                if (!Array.isArray(message.faqAnswers))
                                    return "faqAnswers: array expected";
                                for (var i = 0; i < message.faqAnswers.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.Suggestion.FaqAnswer.verify(message.faqAnswers[i]);
                                    if (error)
                                        return "faqAnswers." + error;
                                }
                            }
                            if (message.createTime != null && message.hasOwnProperty("createTime")) {
                                var error = $root.google.protobuf.Timestamp.verify(message.createTime);
                                if (error)
                                    return "createTime." + error;
                            }
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                if (!$util.isString(message.latestMessage))
                                    return "latestMessage: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a Suggestion message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.Suggestion
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.Suggestion} Suggestion
                         */
                        Suggestion.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.Suggestion)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.Suggestion();
                            if (object.name != null)
                                message.name = String(object.name);
                            if (object.articles) {
                                if (!Array.isArray(object.articles))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.Suggestion.articles: array expected");
                                message.articles = [];
                                for (var i = 0; i < object.articles.length; ++i) {
                                    if (typeof object.articles[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.Suggestion.articles: object expected");
                                    message.articles[i] = $root.google.cloud.dialogflow.v2beta1.Suggestion.Article.fromObject(object.articles[i]);
                                }
                            }
                            if (object.faqAnswers) {
                                if (!Array.isArray(object.faqAnswers))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.Suggestion.faqAnswers: array expected");
                                message.faqAnswers = [];
                                for (var i = 0; i < object.faqAnswers.length; ++i) {
                                    if (typeof object.faqAnswers[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.Suggestion.faqAnswers: object expected");
                                    message.faqAnswers[i] = $root.google.cloud.dialogflow.v2beta1.Suggestion.FaqAnswer.fromObject(object.faqAnswers[i]);
                                }
                            }
                            if (object.createTime != null) {
                                if (typeof object.createTime !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.Suggestion.createTime: object expected");
                                message.createTime = $root.google.protobuf.Timestamp.fromObject(object.createTime);
                            }
                            if (object.latestMessage != null)
                                message.latestMessage = String(object.latestMessage);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a Suggestion message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.Suggestion
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.Suggestion} message Suggestion
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        Suggestion.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults) {
                                object.articles = [];
                                object.faqAnswers = [];
                            }
                            if (options.defaults) {
                                object.name = "";
                                object.createTime = null;
                                object.latestMessage = "";
                            }
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            if (message.articles && message.articles.length) {
                                object.articles = [];
                                for (var j = 0; j < message.articles.length; ++j)
                                    object.articles[j] = $root.google.cloud.dialogflow.v2beta1.Suggestion.Article.toObject(message.articles[j], options);
                            }
                            if (message.faqAnswers && message.faqAnswers.length) {
                                object.faqAnswers = [];
                                for (var j = 0; j < message.faqAnswers.length; ++j)
                                    object.faqAnswers[j] = $root.google.cloud.dialogflow.v2beta1.Suggestion.FaqAnswer.toObject(message.faqAnswers[j], options);
                            }
                            if (message.createTime != null && message.hasOwnProperty("createTime"))
                                object.createTime = $root.google.protobuf.Timestamp.toObject(message.createTime, options);
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                object.latestMessage = message.latestMessage;
                            return object;
                        };
    
                        /**
                         * Converts this Suggestion to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.Suggestion
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        Suggestion.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for Suggestion
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.Suggestion
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        Suggestion.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Suggestion";
                        };
    
                        Suggestion.Article = (function() {
    
                            /**
                             * Properties of an Article.
                             * @memberof google.cloud.dialogflow.v2beta1.Suggestion
                             * @interface IArticle
                             * @property {string|null} [title] Article title
                             * @property {string|null} [uri] Article uri
                             * @property {Array.<string>|null} [snippets] Article snippets
                             * @property {Object.<string,string>|null} [metadata] Article metadata
                             * @property {string|null} [answerRecord] Article answerRecord
                             */
    
                            /**
                             * Constructs a new Article.
                             * @memberof google.cloud.dialogflow.v2beta1.Suggestion
                             * @classdesc Represents an Article.
                             * @implements IArticle
                             * @constructor
                             * @param {google.cloud.dialogflow.v2beta1.Suggestion.IArticle=} [properties] Properties to set
                             */
                            function Article(properties) {
                                this.snippets = [];
                                this.metadata = {};
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * Article title.
                             * @member {string} title
                             * @memberof google.cloud.dialogflow.v2beta1.Suggestion.Article
                             * @instance
                             */
                            Article.prototype.title = "";
    
                            /**
                             * Article uri.
                             * @member {string} uri
                             * @memberof google.cloud.dialogflow.v2beta1.Suggestion.Article
                             * @instance
                             */
                            Article.prototype.uri = "";
    
                            /**
                             * Article snippets.
                             * @member {Array.<string>} snippets
                             * @memberof google.cloud.dialogflow.v2beta1.Suggestion.Article
                             * @instance
                             */
                            Article.prototype.snippets = $util.emptyArray;
    
                            /**
                             * Article metadata.
                             * @member {Object.<string,string>} metadata
                             * @memberof google.cloud.dialogflow.v2beta1.Suggestion.Article
                             * @instance
                             */
                            Article.prototype.metadata = $util.emptyObject;
    
                            /**
                             * Article answerRecord.
                             * @member {string} answerRecord
                             * @memberof google.cloud.dialogflow.v2beta1.Suggestion.Article
                             * @instance
                             */
                            Article.prototype.answerRecord = "";
    
                            /**
                             * Creates a new Article instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2beta1.Suggestion.Article
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.Suggestion.IArticle=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2beta1.Suggestion.Article} Article instance
                             */
                            Article.create = function create(properties) {
                                return new Article(properties);
                            };
    
                            /**
                             * Encodes the specified Article message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Suggestion.Article.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2beta1.Suggestion.Article
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.Suggestion.IArticle} message Article message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            Article.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.title != null && Object.hasOwnProperty.call(message, "title"))
                                    writer.uint32(/* id 1, wireType 2 =*/10).string(message.title);
                                if (message.uri != null && Object.hasOwnProperty.call(message, "uri"))
                                    writer.uint32(/* id 2, wireType 2 =*/18).string(message.uri);
                                if (message.snippets != null && message.snippets.length)
                                    for (var i = 0; i < message.snippets.length; ++i)
                                        writer.uint32(/* id 3, wireType 2 =*/26).string(message.snippets[i]);
                                if (message.metadata != null && Object.hasOwnProperty.call(message, "metadata"))
                                    for (var keys = Object.keys(message.metadata), i = 0; i < keys.length; ++i)
                                        writer.uint32(/* id 5, wireType 2 =*/42).fork().uint32(/* id 1, wireType 2 =*/10).string(keys[i]).uint32(/* id 2, wireType 2 =*/18).string(message.metadata[keys[i]]).ldelim();
                                if (message.answerRecord != null && Object.hasOwnProperty.call(message, "answerRecord"))
                                    writer.uint32(/* id 6, wireType 2 =*/50).string(message.answerRecord);
                                return writer;
                            };
    
                            /**
                             * Encodes the specified Article message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Suggestion.Article.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.Suggestion.Article
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.Suggestion.IArticle} message Article message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            Article.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes an Article message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2beta1.Suggestion.Article
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2beta1.Suggestion.Article} Article
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            Article.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Suggestion.Article(), key, value;
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.title = reader.string();
                                            break;
                                        }
                                    case 2: {
                                            message.uri = reader.string();
                                            break;
                                        }
                                    case 3: {
                                            if (!(message.snippets && message.snippets.length))
                                                message.snippets = [];
                                            message.snippets.push(reader.string());
                                            break;
                                        }
                                    case 5: {
                                            if (message.metadata === $util.emptyObject)
                                                message.metadata = {};
                                            var end2 = reader.uint32() + reader.pos;
                                            key = "";
                                            value = "";
                                            while (reader.pos < end2) {
                                                var tag2 = reader.uint32();
                                                switch (tag2 >>> 3) {
                                                case 1:
                                                    key = reader.string();
                                                    break;
                                                case 2:
                                                    value = reader.string();
                                                    break;
                                                default:
                                                    reader.skipType(tag2 & 7);
                                                    break;
                                                }
                                            }
                                            message.metadata[key] = value;
                                            break;
                                        }
                                    case 6: {
                                            message.answerRecord = reader.string();
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes an Article message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.Suggestion.Article
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2beta1.Suggestion.Article} Article
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            Article.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies an Article message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2beta1.Suggestion.Article
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            Article.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.title != null && message.hasOwnProperty("title"))
                                    if (!$util.isString(message.title))
                                        return "title: string expected";
                                if (message.uri != null && message.hasOwnProperty("uri"))
                                    if (!$util.isString(message.uri))
                                        return "uri: string expected";
                                if (message.snippets != null && message.hasOwnProperty("snippets")) {
                                    if (!Array.isArray(message.snippets))
                                        return "snippets: array expected";
                                    for (var i = 0; i < message.snippets.length; ++i)
                                        if (!$util.isString(message.snippets[i]))
                                            return "snippets: string[] expected";
                                }
                                if (message.metadata != null && message.hasOwnProperty("metadata")) {
                                    if (!$util.isObject(message.metadata))
                                        return "metadata: object expected";
                                    var key = Object.keys(message.metadata);
                                    for (var i = 0; i < key.length; ++i)
                                        if (!$util.isString(message.metadata[key[i]]))
                                            return "metadata: string{k:string} expected";
                                }
                                if (message.answerRecord != null && message.hasOwnProperty("answerRecord"))
                                    if (!$util.isString(message.answerRecord))
                                        return "answerRecord: string expected";
                                return null;
                            };
    
                            /**
                             * Creates an Article message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2beta1.Suggestion.Article
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2beta1.Suggestion.Article} Article
                             */
                            Article.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2beta1.Suggestion.Article)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2beta1.Suggestion.Article();
                                if (object.title != null)
                                    message.title = String(object.title);
                                if (object.uri != null)
                                    message.uri = String(object.uri);
                                if (object.snippets) {
                                    if (!Array.isArray(object.snippets))
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.Suggestion.Article.snippets: array expected");
                                    message.snippets = [];
                                    for (var i = 0; i < object.snippets.length; ++i)
                                        message.snippets[i] = String(object.snippets[i]);
                                }
                                if (object.metadata) {
                                    if (typeof object.metadata !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.Suggestion.Article.metadata: object expected");
                                    message.metadata = {};
                                    for (var keys = Object.keys(object.metadata), i = 0; i < keys.length; ++i)
                                        message.metadata[keys[i]] = String(object.metadata[keys[i]]);
                                }
                                if (object.answerRecord != null)
                                    message.answerRecord = String(object.answerRecord);
                                return message;
                            };
    
                            /**
                             * Creates a plain object from an Article message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2beta1.Suggestion.Article
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.Suggestion.Article} message Article
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            Article.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.arrays || options.defaults)
                                    object.snippets = [];
                                if (options.objects || options.defaults)
                                    object.metadata = {};
                                if (options.defaults) {
                                    object.title = "";
                                    object.uri = "";
                                    object.answerRecord = "";
                                }
                                if (message.title != null && message.hasOwnProperty("title"))
                                    object.title = message.title;
                                if (message.uri != null && message.hasOwnProperty("uri"))
                                    object.uri = message.uri;
                                if (message.snippets && message.snippets.length) {
                                    object.snippets = [];
                                    for (var j = 0; j < message.snippets.length; ++j)
                                        object.snippets[j] = message.snippets[j];
                                }
                                var keys2;
                                if (message.metadata && (keys2 = Object.keys(message.metadata)).length) {
                                    object.metadata = {};
                                    for (var j = 0; j < keys2.length; ++j)
                                        object.metadata[keys2[j]] = message.metadata[keys2[j]];
                                }
                                if (message.answerRecord != null && message.hasOwnProperty("answerRecord"))
                                    object.answerRecord = message.answerRecord;
                                return object;
                            };
    
                            /**
                             * Converts this Article to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2beta1.Suggestion.Article
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            Article.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for Article
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2beta1.Suggestion.Article
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            Article.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Suggestion.Article";
                            };
    
                            return Article;
                        })();
    
                        Suggestion.FaqAnswer = (function() {
    
                            /**
                             * Properties of a FaqAnswer.
                             * @memberof google.cloud.dialogflow.v2beta1.Suggestion
                             * @interface IFaqAnswer
                             * @property {string|null} [answer] FaqAnswer answer
                             * @property {number|null} [confidence] FaqAnswer confidence
                             * @property {string|null} [question] FaqAnswer question
                             * @property {string|null} [source] FaqAnswer source
                             * @property {Object.<string,string>|null} [metadata] FaqAnswer metadata
                             * @property {string|null} [answerRecord] FaqAnswer answerRecord
                             */
    
                            /**
                             * Constructs a new FaqAnswer.
                             * @memberof google.cloud.dialogflow.v2beta1.Suggestion
                             * @classdesc Represents a FaqAnswer.
                             * @implements IFaqAnswer
                             * @constructor
                             * @param {google.cloud.dialogflow.v2beta1.Suggestion.IFaqAnswer=} [properties] Properties to set
                             */
                            function FaqAnswer(properties) {
                                this.metadata = {};
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * FaqAnswer answer.
                             * @member {string} answer
                             * @memberof google.cloud.dialogflow.v2beta1.Suggestion.FaqAnswer
                             * @instance
                             */
                            FaqAnswer.prototype.answer = "";
    
                            /**
                             * FaqAnswer confidence.
                             * @member {number} confidence
                             * @memberof google.cloud.dialogflow.v2beta1.Suggestion.FaqAnswer
                             * @instance
                             */
                            FaqAnswer.prototype.confidence = 0;
    
                            /**
                             * FaqAnswer question.
                             * @member {string} question
                             * @memberof google.cloud.dialogflow.v2beta1.Suggestion.FaqAnswer
                             * @instance
                             */
                            FaqAnswer.prototype.question = "";
    
                            /**
                             * FaqAnswer source.
                             * @member {string} source
                             * @memberof google.cloud.dialogflow.v2beta1.Suggestion.FaqAnswer
                             * @instance
                             */
                            FaqAnswer.prototype.source = "";
    
                            /**
                             * FaqAnswer metadata.
                             * @member {Object.<string,string>} metadata
                             * @memberof google.cloud.dialogflow.v2beta1.Suggestion.FaqAnswer
                             * @instance
                             */
                            FaqAnswer.prototype.metadata = $util.emptyObject;
    
                            /**
                             * FaqAnswer answerRecord.
                             * @member {string} answerRecord
                             * @memberof google.cloud.dialogflow.v2beta1.Suggestion.FaqAnswer
                             * @instance
                             */
                            FaqAnswer.prototype.answerRecord = "";
    
                            /**
                             * Creates a new FaqAnswer instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2beta1.Suggestion.FaqAnswer
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.Suggestion.IFaqAnswer=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2beta1.Suggestion.FaqAnswer} FaqAnswer instance
                             */
                            FaqAnswer.create = function create(properties) {
                                return new FaqAnswer(properties);
                            };
    
                            /**
                             * Encodes the specified FaqAnswer message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Suggestion.FaqAnswer.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2beta1.Suggestion.FaqAnswer
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.Suggestion.IFaqAnswer} message FaqAnswer message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            FaqAnswer.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.answer != null && Object.hasOwnProperty.call(message, "answer"))
                                    writer.uint32(/* id 1, wireType 2 =*/10).string(message.answer);
                                if (message.confidence != null && Object.hasOwnProperty.call(message, "confidence"))
                                    writer.uint32(/* id 2, wireType 5 =*/21).float(message.confidence);
                                if (message.question != null && Object.hasOwnProperty.call(message, "question"))
                                    writer.uint32(/* id 3, wireType 2 =*/26).string(message.question);
                                if (message.source != null && Object.hasOwnProperty.call(message, "source"))
                                    writer.uint32(/* id 4, wireType 2 =*/34).string(message.source);
                                if (message.metadata != null && Object.hasOwnProperty.call(message, "metadata"))
                                    for (var keys = Object.keys(message.metadata), i = 0; i < keys.length; ++i)
                                        writer.uint32(/* id 5, wireType 2 =*/42).fork().uint32(/* id 1, wireType 2 =*/10).string(keys[i]).uint32(/* id 2, wireType 2 =*/18).string(message.metadata[keys[i]]).ldelim();
                                if (message.answerRecord != null && Object.hasOwnProperty.call(message, "answerRecord"))
                                    writer.uint32(/* id 6, wireType 2 =*/50).string(message.answerRecord);
                                return writer;
                            };
    
                            /**
                             * Encodes the specified FaqAnswer message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Suggestion.FaqAnswer.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.Suggestion.FaqAnswer
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.Suggestion.IFaqAnswer} message FaqAnswer message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            FaqAnswer.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a FaqAnswer message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2beta1.Suggestion.FaqAnswer
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2beta1.Suggestion.FaqAnswer} FaqAnswer
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            FaqAnswer.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Suggestion.FaqAnswer(), key, value;
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.answer = reader.string();
                                            break;
                                        }
                                    case 2: {
                                            message.confidence = reader.float();
                                            break;
                                        }
                                    case 3: {
                                            message.question = reader.string();
                                            break;
                                        }
                                    case 4: {
                                            message.source = reader.string();
                                            break;
                                        }
                                    case 5: {
                                            if (message.metadata === $util.emptyObject)
                                                message.metadata = {};
                                            var end2 = reader.uint32() + reader.pos;
                                            key = "";
                                            value = "";
                                            while (reader.pos < end2) {
                                                var tag2 = reader.uint32();
                                                switch (tag2 >>> 3) {
                                                case 1:
                                                    key = reader.string();
                                                    break;
                                                case 2:
                                                    value = reader.string();
                                                    break;
                                                default:
                                                    reader.skipType(tag2 & 7);
                                                    break;
                                                }
                                            }
                                            message.metadata[key] = value;
                                            break;
                                        }
                                    case 6: {
                                            message.answerRecord = reader.string();
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a FaqAnswer message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.Suggestion.FaqAnswer
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2beta1.Suggestion.FaqAnswer} FaqAnswer
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            FaqAnswer.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a FaqAnswer message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2beta1.Suggestion.FaqAnswer
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            FaqAnswer.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.answer != null && message.hasOwnProperty("answer"))
                                    if (!$util.isString(message.answer))
                                        return "answer: string expected";
                                if (message.confidence != null && message.hasOwnProperty("confidence"))
                                    if (typeof message.confidence !== "number")
                                        return "confidence: number expected";
                                if (message.question != null && message.hasOwnProperty("question"))
                                    if (!$util.isString(message.question))
                                        return "question: string expected";
                                if (message.source != null && message.hasOwnProperty("source"))
                                    if (!$util.isString(message.source))
                                        return "source: string expected";
                                if (message.metadata != null && message.hasOwnProperty("metadata")) {
                                    if (!$util.isObject(message.metadata))
                                        return "metadata: object expected";
                                    var key = Object.keys(message.metadata);
                                    for (var i = 0; i < key.length; ++i)
                                        if (!$util.isString(message.metadata[key[i]]))
                                            return "metadata: string{k:string} expected";
                                }
                                if (message.answerRecord != null && message.hasOwnProperty("answerRecord"))
                                    if (!$util.isString(message.answerRecord))
                                        return "answerRecord: string expected";
                                return null;
                            };
    
                            /**
                             * Creates a FaqAnswer message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2beta1.Suggestion.FaqAnswer
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2beta1.Suggestion.FaqAnswer} FaqAnswer
                             */
                            FaqAnswer.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2beta1.Suggestion.FaqAnswer)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2beta1.Suggestion.FaqAnswer();
                                if (object.answer != null)
                                    message.answer = String(object.answer);
                                if (object.confidence != null)
                                    message.confidence = Number(object.confidence);
                                if (object.question != null)
                                    message.question = String(object.question);
                                if (object.source != null)
                                    message.source = String(object.source);
                                if (object.metadata) {
                                    if (typeof object.metadata !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.Suggestion.FaqAnswer.metadata: object expected");
                                    message.metadata = {};
                                    for (var keys = Object.keys(object.metadata), i = 0; i < keys.length; ++i)
                                        message.metadata[keys[i]] = String(object.metadata[keys[i]]);
                                }
                                if (object.answerRecord != null)
                                    message.answerRecord = String(object.answerRecord);
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a FaqAnswer message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2beta1.Suggestion.FaqAnswer
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.Suggestion.FaqAnswer} message FaqAnswer
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            FaqAnswer.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.objects || options.defaults)
                                    object.metadata = {};
                                if (options.defaults) {
                                    object.answer = "";
                                    object.confidence = 0;
                                    object.question = "";
                                    object.source = "";
                                    object.answerRecord = "";
                                }
                                if (message.answer != null && message.hasOwnProperty("answer"))
                                    object.answer = message.answer;
                                if (message.confidence != null && message.hasOwnProperty("confidence"))
                                    object.confidence = options.json && !isFinite(message.confidence) ? String(message.confidence) : message.confidence;
                                if (message.question != null && message.hasOwnProperty("question"))
                                    object.question = message.question;
                                if (message.source != null && message.hasOwnProperty("source"))
                                    object.source = message.source;
                                var keys2;
                                if (message.metadata && (keys2 = Object.keys(message.metadata)).length) {
                                    object.metadata = {};
                                    for (var j = 0; j < keys2.length; ++j)
                                        object.metadata[keys2[j]] = message.metadata[keys2[j]];
                                }
                                if (message.answerRecord != null && message.hasOwnProperty("answerRecord"))
                                    object.answerRecord = message.answerRecord;
                                return object;
                            };
    
                            /**
                             * Converts this FaqAnswer to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2beta1.Suggestion.FaqAnswer
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            FaqAnswer.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for FaqAnswer
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2beta1.Suggestion.FaqAnswer
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            FaqAnswer.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Suggestion.FaqAnswer";
                            };
    
                            return FaqAnswer;
                        })();
    
                        return Suggestion;
                    })();
    
                    v2beta1.ListSuggestionsRequest = (function() {
    
                        /**
                         * Properties of a ListSuggestionsRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IListSuggestionsRequest
                         * @property {string|null} [parent] ListSuggestionsRequest parent
                         * @property {number|null} [pageSize] ListSuggestionsRequest pageSize
                         * @property {string|null} [pageToken] ListSuggestionsRequest pageToken
                         * @property {string|null} [filter] ListSuggestionsRequest filter
                         */
    
                        /**
                         * Constructs a new ListSuggestionsRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a ListSuggestionsRequest.
                         * @implements IListSuggestionsRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IListSuggestionsRequest=} [properties] Properties to set
                         */
                        function ListSuggestionsRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListSuggestionsRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.ListSuggestionsRequest
                         * @instance
                         */
                        ListSuggestionsRequest.prototype.parent = "";
    
                        /**
                         * ListSuggestionsRequest pageSize.
                         * @member {number} pageSize
                         * @memberof google.cloud.dialogflow.v2beta1.ListSuggestionsRequest
                         * @instance
                         */
                        ListSuggestionsRequest.prototype.pageSize = 0;
    
                        /**
                         * ListSuggestionsRequest pageToken.
                         * @member {string} pageToken
                         * @memberof google.cloud.dialogflow.v2beta1.ListSuggestionsRequest
                         * @instance
                         */
                        ListSuggestionsRequest.prototype.pageToken = "";
    
                        /**
                         * ListSuggestionsRequest filter.
                         * @member {string} filter
                         * @memberof google.cloud.dialogflow.v2beta1.ListSuggestionsRequest
                         * @instance
                         */
                        ListSuggestionsRequest.prototype.filter = "";
    
                        /**
                         * Creates a new ListSuggestionsRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.ListSuggestionsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListSuggestionsRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.ListSuggestionsRequest} ListSuggestionsRequest instance
                         */
                        ListSuggestionsRequest.create = function create(properties) {
                            return new ListSuggestionsRequest(properties);
                        };
    
                        /**
                         * Encodes the specified ListSuggestionsRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListSuggestionsRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.ListSuggestionsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListSuggestionsRequest} message ListSuggestionsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListSuggestionsRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.pageSize != null && Object.hasOwnProperty.call(message, "pageSize"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.pageSize);
                            if (message.pageToken != null && Object.hasOwnProperty.call(message, "pageToken"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.pageToken);
                            if (message.filter != null && Object.hasOwnProperty.call(message, "filter"))
                                writer.uint32(/* id 4, wireType 2 =*/34).string(message.filter);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListSuggestionsRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListSuggestionsRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListSuggestionsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListSuggestionsRequest} message ListSuggestionsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListSuggestionsRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListSuggestionsRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.ListSuggestionsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.ListSuggestionsRequest} ListSuggestionsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListSuggestionsRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ListSuggestionsRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.pageSize = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.pageToken = reader.string();
                                        break;
                                    }
                                case 4: {
                                        message.filter = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListSuggestionsRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListSuggestionsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.ListSuggestionsRequest} ListSuggestionsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListSuggestionsRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListSuggestionsRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.ListSuggestionsRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListSuggestionsRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                if (!$util.isInteger(message.pageSize))
                                    return "pageSize: integer expected";
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                if (!$util.isString(message.pageToken))
                                    return "pageToken: string expected";
                            if (message.filter != null && message.hasOwnProperty("filter"))
                                if (!$util.isString(message.filter))
                                    return "filter: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListSuggestionsRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListSuggestionsRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.ListSuggestionsRequest} ListSuggestionsRequest
                         */
                        ListSuggestionsRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.ListSuggestionsRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.ListSuggestionsRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.pageSize != null)
                                message.pageSize = object.pageSize | 0;
                            if (object.pageToken != null)
                                message.pageToken = String(object.pageToken);
                            if (object.filter != null)
                                message.filter = String(object.filter);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListSuggestionsRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListSuggestionsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ListSuggestionsRequest} message ListSuggestionsRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListSuggestionsRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.pageSize = 0;
                                object.pageToken = "";
                                object.filter = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                object.pageSize = message.pageSize;
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                object.pageToken = message.pageToken;
                            if (message.filter != null && message.hasOwnProperty("filter"))
                                object.filter = message.filter;
                            return object;
                        };
    
                        /**
                         * Converts this ListSuggestionsRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.ListSuggestionsRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListSuggestionsRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListSuggestionsRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.ListSuggestionsRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListSuggestionsRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ListSuggestionsRequest";
                        };
    
                        return ListSuggestionsRequest;
                    })();
    
                    v2beta1.ListSuggestionsResponse = (function() {
    
                        /**
                         * Properties of a ListSuggestionsResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IListSuggestionsResponse
                         * @property {Array.<google.cloud.dialogflow.v2beta1.ISuggestion>|null} [suggestions] ListSuggestionsResponse suggestions
                         * @property {string|null} [nextPageToken] ListSuggestionsResponse nextPageToken
                         */
    
                        /**
                         * Constructs a new ListSuggestionsResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a ListSuggestionsResponse.
                         * @implements IListSuggestionsResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IListSuggestionsResponse=} [properties] Properties to set
                         */
                        function ListSuggestionsResponse(properties) {
                            this.suggestions = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListSuggestionsResponse suggestions.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.ISuggestion>} suggestions
                         * @memberof google.cloud.dialogflow.v2beta1.ListSuggestionsResponse
                         * @instance
                         */
                        ListSuggestionsResponse.prototype.suggestions = $util.emptyArray;
    
                        /**
                         * ListSuggestionsResponse nextPageToken.
                         * @member {string} nextPageToken
                         * @memberof google.cloud.dialogflow.v2beta1.ListSuggestionsResponse
                         * @instance
                         */
                        ListSuggestionsResponse.prototype.nextPageToken = "";
    
                        /**
                         * Creates a new ListSuggestionsResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.ListSuggestionsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListSuggestionsResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.ListSuggestionsResponse} ListSuggestionsResponse instance
                         */
                        ListSuggestionsResponse.create = function create(properties) {
                            return new ListSuggestionsResponse(properties);
                        };
    
                        /**
                         * Encodes the specified ListSuggestionsResponse message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListSuggestionsResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.ListSuggestionsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListSuggestionsResponse} message ListSuggestionsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListSuggestionsResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.suggestions != null && message.suggestions.length)
                                for (var i = 0; i < message.suggestions.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.Suggestion.encode(message.suggestions[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.nextPageToken != null && Object.hasOwnProperty.call(message, "nextPageToken"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.nextPageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListSuggestionsResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListSuggestionsResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListSuggestionsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListSuggestionsResponse} message ListSuggestionsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListSuggestionsResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListSuggestionsResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.ListSuggestionsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.ListSuggestionsResponse} ListSuggestionsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListSuggestionsResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ListSuggestionsResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.suggestions && message.suggestions.length))
                                            message.suggestions = [];
                                        message.suggestions.push($root.google.cloud.dialogflow.v2beta1.Suggestion.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 2: {
                                        message.nextPageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListSuggestionsResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListSuggestionsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.ListSuggestionsResponse} ListSuggestionsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListSuggestionsResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListSuggestionsResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.ListSuggestionsResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListSuggestionsResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.suggestions != null && message.hasOwnProperty("suggestions")) {
                                if (!Array.isArray(message.suggestions))
                                    return "suggestions: array expected";
                                for (var i = 0; i < message.suggestions.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.Suggestion.verify(message.suggestions[i]);
                                    if (error)
                                        return "suggestions." + error;
                                }
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                if (!$util.isString(message.nextPageToken))
                                    return "nextPageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListSuggestionsResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListSuggestionsResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.ListSuggestionsResponse} ListSuggestionsResponse
                         */
                        ListSuggestionsResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.ListSuggestionsResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.ListSuggestionsResponse();
                            if (object.suggestions) {
                                if (!Array.isArray(object.suggestions))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.ListSuggestionsResponse.suggestions: array expected");
                                message.suggestions = [];
                                for (var i = 0; i < object.suggestions.length; ++i) {
                                    if (typeof object.suggestions[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.ListSuggestionsResponse.suggestions: object expected");
                                    message.suggestions[i] = $root.google.cloud.dialogflow.v2beta1.Suggestion.fromObject(object.suggestions[i]);
                                }
                            }
                            if (object.nextPageToken != null)
                                message.nextPageToken = String(object.nextPageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListSuggestionsResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListSuggestionsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ListSuggestionsResponse} message ListSuggestionsResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListSuggestionsResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.suggestions = [];
                            if (options.defaults)
                                object.nextPageToken = "";
                            if (message.suggestions && message.suggestions.length) {
                                object.suggestions = [];
                                for (var j = 0; j < message.suggestions.length; ++j)
                                    object.suggestions[j] = $root.google.cloud.dialogflow.v2beta1.Suggestion.toObject(message.suggestions[j], options);
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                object.nextPageToken = message.nextPageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListSuggestionsResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.ListSuggestionsResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListSuggestionsResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListSuggestionsResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.ListSuggestionsResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListSuggestionsResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ListSuggestionsResponse";
                        };
    
                        return ListSuggestionsResponse;
                    })();
    
                    v2beta1.CompileSuggestionRequest = (function() {
    
                        /**
                         * Properties of a CompileSuggestionRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ICompileSuggestionRequest
                         * @property {string|null} [parent] CompileSuggestionRequest parent
                         * @property {string|null} [latestMessage] CompileSuggestionRequest latestMessage
                         * @property {number|null} [contextSize] CompileSuggestionRequest contextSize
                         */
    
                        /**
                         * Constructs a new CompileSuggestionRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a CompileSuggestionRequest.
                         * @implements ICompileSuggestionRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ICompileSuggestionRequest=} [properties] Properties to set
                         */
                        function CompileSuggestionRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * CompileSuggestionRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.CompileSuggestionRequest
                         * @instance
                         */
                        CompileSuggestionRequest.prototype.parent = "";
    
                        /**
                         * CompileSuggestionRequest latestMessage.
                         * @member {string} latestMessage
                         * @memberof google.cloud.dialogflow.v2beta1.CompileSuggestionRequest
                         * @instance
                         */
                        CompileSuggestionRequest.prototype.latestMessage = "";
    
                        /**
                         * CompileSuggestionRequest contextSize.
                         * @member {number} contextSize
                         * @memberof google.cloud.dialogflow.v2beta1.CompileSuggestionRequest
                         * @instance
                         */
                        CompileSuggestionRequest.prototype.contextSize = 0;
    
                        /**
                         * Creates a new CompileSuggestionRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.CompileSuggestionRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ICompileSuggestionRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.CompileSuggestionRequest} CompileSuggestionRequest instance
                         */
                        CompileSuggestionRequest.create = function create(properties) {
                            return new CompileSuggestionRequest(properties);
                        };
    
                        /**
                         * Encodes the specified CompileSuggestionRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.CompileSuggestionRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.CompileSuggestionRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ICompileSuggestionRequest} message CompileSuggestionRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CompileSuggestionRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.latestMessage != null && Object.hasOwnProperty.call(message, "latestMessage"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.latestMessage);
                            if (message.contextSize != null && Object.hasOwnProperty.call(message, "contextSize"))
                                writer.uint32(/* id 3, wireType 0 =*/24).int32(message.contextSize);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified CompileSuggestionRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.CompileSuggestionRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.CompileSuggestionRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ICompileSuggestionRequest} message CompileSuggestionRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CompileSuggestionRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a CompileSuggestionRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.CompileSuggestionRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.CompileSuggestionRequest} CompileSuggestionRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CompileSuggestionRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.CompileSuggestionRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.latestMessage = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.contextSize = reader.int32();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a CompileSuggestionRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.CompileSuggestionRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.CompileSuggestionRequest} CompileSuggestionRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CompileSuggestionRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a CompileSuggestionRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.CompileSuggestionRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        CompileSuggestionRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                if (!$util.isString(message.latestMessage))
                                    return "latestMessage: string expected";
                            if (message.contextSize != null && message.hasOwnProperty("contextSize"))
                                if (!$util.isInteger(message.contextSize))
                                    return "contextSize: integer expected";
                            return null;
                        };
    
                        /**
                         * Creates a CompileSuggestionRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.CompileSuggestionRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.CompileSuggestionRequest} CompileSuggestionRequest
                         */
                        CompileSuggestionRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.CompileSuggestionRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.CompileSuggestionRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.latestMessage != null)
                                message.latestMessage = String(object.latestMessage);
                            if (object.contextSize != null)
                                message.contextSize = object.contextSize | 0;
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a CompileSuggestionRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.CompileSuggestionRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.CompileSuggestionRequest} message CompileSuggestionRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        CompileSuggestionRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.latestMessage = "";
                                object.contextSize = 0;
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                object.latestMessage = message.latestMessage;
                            if (message.contextSize != null && message.hasOwnProperty("contextSize"))
                                object.contextSize = message.contextSize;
                            return object;
                        };
    
                        /**
                         * Converts this CompileSuggestionRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.CompileSuggestionRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        CompileSuggestionRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for CompileSuggestionRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.CompileSuggestionRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        CompileSuggestionRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.CompileSuggestionRequest";
                        };
    
                        return CompileSuggestionRequest;
                    })();
    
                    v2beta1.CompileSuggestionResponse = (function() {
    
                        /**
                         * Properties of a CompileSuggestionResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ICompileSuggestionResponse
                         * @property {google.cloud.dialogflow.v2beta1.ISuggestion|null} [suggestion] CompileSuggestionResponse suggestion
                         * @property {string|null} [latestMessage] CompileSuggestionResponse latestMessage
                         * @property {number|null} [contextSize] CompileSuggestionResponse contextSize
                         */
    
                        /**
                         * Constructs a new CompileSuggestionResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a CompileSuggestionResponse.
                         * @implements ICompileSuggestionResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ICompileSuggestionResponse=} [properties] Properties to set
                         */
                        function CompileSuggestionResponse(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * CompileSuggestionResponse suggestion.
                         * @member {google.cloud.dialogflow.v2beta1.ISuggestion|null|undefined} suggestion
                         * @memberof google.cloud.dialogflow.v2beta1.CompileSuggestionResponse
                         * @instance
                         */
                        CompileSuggestionResponse.prototype.suggestion = null;
    
                        /**
                         * CompileSuggestionResponse latestMessage.
                         * @member {string} latestMessage
                         * @memberof google.cloud.dialogflow.v2beta1.CompileSuggestionResponse
                         * @instance
                         */
                        CompileSuggestionResponse.prototype.latestMessage = "";
    
                        /**
                         * CompileSuggestionResponse contextSize.
                         * @member {number} contextSize
                         * @memberof google.cloud.dialogflow.v2beta1.CompileSuggestionResponse
                         * @instance
                         */
                        CompileSuggestionResponse.prototype.contextSize = 0;
    
                        /**
                         * Creates a new CompileSuggestionResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.CompileSuggestionResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ICompileSuggestionResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.CompileSuggestionResponse} CompileSuggestionResponse instance
                         */
                        CompileSuggestionResponse.create = function create(properties) {
                            return new CompileSuggestionResponse(properties);
                        };
    
                        /**
                         * Encodes the specified CompileSuggestionResponse message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.CompileSuggestionResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.CompileSuggestionResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ICompileSuggestionResponse} message CompileSuggestionResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CompileSuggestionResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.suggestion != null && Object.hasOwnProperty.call(message, "suggestion"))
                                $root.google.cloud.dialogflow.v2beta1.Suggestion.encode(message.suggestion, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.latestMessage != null && Object.hasOwnProperty.call(message, "latestMessage"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.latestMessage);
                            if (message.contextSize != null && Object.hasOwnProperty.call(message, "contextSize"))
                                writer.uint32(/* id 3, wireType 0 =*/24).int32(message.contextSize);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified CompileSuggestionResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.CompileSuggestionResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.CompileSuggestionResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ICompileSuggestionResponse} message CompileSuggestionResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CompileSuggestionResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a CompileSuggestionResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.CompileSuggestionResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.CompileSuggestionResponse} CompileSuggestionResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CompileSuggestionResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.CompileSuggestionResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.suggestion = $root.google.cloud.dialogflow.v2beta1.Suggestion.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.latestMessage = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.contextSize = reader.int32();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a CompileSuggestionResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.CompileSuggestionResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.CompileSuggestionResponse} CompileSuggestionResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CompileSuggestionResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a CompileSuggestionResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.CompileSuggestionResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        CompileSuggestionResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.suggestion != null && message.hasOwnProperty("suggestion")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.Suggestion.verify(message.suggestion);
                                if (error)
                                    return "suggestion." + error;
                            }
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                if (!$util.isString(message.latestMessage))
                                    return "latestMessage: string expected";
                            if (message.contextSize != null && message.hasOwnProperty("contextSize"))
                                if (!$util.isInteger(message.contextSize))
                                    return "contextSize: integer expected";
                            return null;
                        };
    
                        /**
                         * Creates a CompileSuggestionResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.CompileSuggestionResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.CompileSuggestionResponse} CompileSuggestionResponse
                         */
                        CompileSuggestionResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.CompileSuggestionResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.CompileSuggestionResponse();
                            if (object.suggestion != null) {
                                if (typeof object.suggestion !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.CompileSuggestionResponse.suggestion: object expected");
                                message.suggestion = $root.google.cloud.dialogflow.v2beta1.Suggestion.fromObject(object.suggestion);
                            }
                            if (object.latestMessage != null)
                                message.latestMessage = String(object.latestMessage);
                            if (object.contextSize != null)
                                message.contextSize = object.contextSize | 0;
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a CompileSuggestionResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.CompileSuggestionResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.CompileSuggestionResponse} message CompileSuggestionResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        CompileSuggestionResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.suggestion = null;
                                object.latestMessage = "";
                                object.contextSize = 0;
                            }
                            if (message.suggestion != null && message.hasOwnProperty("suggestion"))
                                object.suggestion = $root.google.cloud.dialogflow.v2beta1.Suggestion.toObject(message.suggestion, options);
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                object.latestMessage = message.latestMessage;
                            if (message.contextSize != null && message.hasOwnProperty("contextSize"))
                                object.contextSize = message.contextSize;
                            return object;
                        };
    
                        /**
                         * Converts this CompileSuggestionResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.CompileSuggestionResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        CompileSuggestionResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for CompileSuggestionResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.CompileSuggestionResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        CompileSuggestionResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.CompileSuggestionResponse";
                        };
    
                        return CompileSuggestionResponse;
                    })();
    
                    v2beta1.ResponseMessage = (function() {
    
                        /**
                         * Properties of a ResponseMessage.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IResponseMessage
                         * @property {google.cloud.dialogflow.v2beta1.ResponseMessage.IText|null} [text] ResponseMessage text
                         * @property {google.protobuf.IStruct|null} [payload] ResponseMessage payload
                         * @property {google.cloud.dialogflow.v2beta1.ResponseMessage.ILiveAgentHandoff|null} [liveAgentHandoff] ResponseMessage liveAgentHandoff
                         * @property {google.cloud.dialogflow.v2beta1.ResponseMessage.IEndInteraction|null} [endInteraction] ResponseMessage endInteraction
                         * @property {google.cloud.dialogflow.v2beta1.ResponseMessage.IMixedAudio|null} [mixedAudio] ResponseMessage mixedAudio
                         * @property {google.cloud.dialogflow.v2beta1.ResponseMessage.ITelephonyTransferCall|null} [telephonyTransferCall] ResponseMessage telephonyTransferCall
                         */
    
                        /**
                         * Constructs a new ResponseMessage.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a ResponseMessage.
                         * @implements IResponseMessage
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IResponseMessage=} [properties] Properties to set
                         */
                        function ResponseMessage(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ResponseMessage text.
                         * @member {google.cloud.dialogflow.v2beta1.ResponseMessage.IText|null|undefined} text
                         * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage
                         * @instance
                         */
                        ResponseMessage.prototype.text = null;
    
                        /**
                         * ResponseMessage payload.
                         * @member {google.protobuf.IStruct|null|undefined} payload
                         * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage
                         * @instance
                         */
                        ResponseMessage.prototype.payload = null;
    
                        /**
                         * ResponseMessage liveAgentHandoff.
                         * @member {google.cloud.dialogflow.v2beta1.ResponseMessage.ILiveAgentHandoff|null|undefined} liveAgentHandoff
                         * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage
                         * @instance
                         */
                        ResponseMessage.prototype.liveAgentHandoff = null;
    
                        /**
                         * ResponseMessage endInteraction.
                         * @member {google.cloud.dialogflow.v2beta1.ResponseMessage.IEndInteraction|null|undefined} endInteraction
                         * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage
                         * @instance
                         */
                        ResponseMessage.prototype.endInteraction = null;
    
                        /**
                         * ResponseMessage mixedAudio.
                         * @member {google.cloud.dialogflow.v2beta1.ResponseMessage.IMixedAudio|null|undefined} mixedAudio
                         * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage
                         * @instance
                         */
                        ResponseMessage.prototype.mixedAudio = null;
    
                        /**
                         * ResponseMessage telephonyTransferCall.
                         * @member {google.cloud.dialogflow.v2beta1.ResponseMessage.ITelephonyTransferCall|null|undefined} telephonyTransferCall
                         * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage
                         * @instance
                         */
                        ResponseMessage.prototype.telephonyTransferCall = null;
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * ResponseMessage message.
                         * @member {"text"|"payload"|"liveAgentHandoff"|"endInteraction"|"mixedAudio"|"telephonyTransferCall"|undefined} message
                         * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage
                         * @instance
                         */
                        Object.defineProperty(ResponseMessage.prototype, "message", {
                            get: $util.oneOfGetter($oneOfFields = ["text", "payload", "liveAgentHandoff", "endInteraction", "mixedAudio", "telephonyTransferCall"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new ResponseMessage instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IResponseMessage=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.ResponseMessage} ResponseMessage instance
                         */
                        ResponseMessage.create = function create(properties) {
                            return new ResponseMessage(properties);
                        };
    
                        /**
                         * Encodes the specified ResponseMessage message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ResponseMessage.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IResponseMessage} message ResponseMessage message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ResponseMessage.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.text != null && Object.hasOwnProperty.call(message, "text"))
                                $root.google.cloud.dialogflow.v2beta1.ResponseMessage.Text.encode(message.text, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.payload != null && Object.hasOwnProperty.call(message, "payload"))
                                $root.google.protobuf.Struct.encode(message.payload, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.liveAgentHandoff != null && Object.hasOwnProperty.call(message, "liveAgentHandoff"))
                                $root.google.cloud.dialogflow.v2beta1.ResponseMessage.LiveAgentHandoff.encode(message.liveAgentHandoff, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            if (message.endInteraction != null && Object.hasOwnProperty.call(message, "endInteraction"))
                                $root.google.cloud.dialogflow.v2beta1.ResponseMessage.EndInteraction.encode(message.endInteraction, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            if (message.mixedAudio != null && Object.hasOwnProperty.call(message, "mixedAudio"))
                                $root.google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio.encode(message.mixedAudio, writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                            if (message.telephonyTransferCall != null && Object.hasOwnProperty.call(message, "telephonyTransferCall"))
                                $root.google.cloud.dialogflow.v2beta1.ResponseMessage.TelephonyTransferCall.encode(message.telephonyTransferCall, writer.uint32(/* id 6, wireType 2 =*/50).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ResponseMessage message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ResponseMessage.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IResponseMessage} message ResponseMessage message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ResponseMessage.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ResponseMessage message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.ResponseMessage} ResponseMessage
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ResponseMessage.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ResponseMessage();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.text = $root.google.cloud.dialogflow.v2beta1.ResponseMessage.Text.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.payload = $root.google.protobuf.Struct.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 3: {
                                        message.liveAgentHandoff = $root.google.cloud.dialogflow.v2beta1.ResponseMessage.LiveAgentHandoff.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 4: {
                                        message.endInteraction = $root.google.cloud.dialogflow.v2beta1.ResponseMessage.EndInteraction.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 5: {
                                        message.mixedAudio = $root.google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 6: {
                                        message.telephonyTransferCall = $root.google.cloud.dialogflow.v2beta1.ResponseMessage.TelephonyTransferCall.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ResponseMessage message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.ResponseMessage} ResponseMessage
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ResponseMessage.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ResponseMessage message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ResponseMessage.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.text != null && message.hasOwnProperty("text")) {
                                properties.message = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2beta1.ResponseMessage.Text.verify(message.text);
                                    if (error)
                                        return "text." + error;
                                }
                            }
                            if (message.payload != null && message.hasOwnProperty("payload")) {
                                if (properties.message === 1)
                                    return "message: multiple values";
                                properties.message = 1;
                                {
                                    var error = $root.google.protobuf.Struct.verify(message.payload);
                                    if (error)
                                        return "payload." + error;
                                }
                            }
                            if (message.liveAgentHandoff != null && message.hasOwnProperty("liveAgentHandoff")) {
                                if (properties.message === 1)
                                    return "message: multiple values";
                                properties.message = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2beta1.ResponseMessage.LiveAgentHandoff.verify(message.liveAgentHandoff);
                                    if (error)
                                        return "liveAgentHandoff." + error;
                                }
                            }
                            if (message.endInteraction != null && message.hasOwnProperty("endInteraction")) {
                                if (properties.message === 1)
                                    return "message: multiple values";
                                properties.message = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2beta1.ResponseMessage.EndInteraction.verify(message.endInteraction);
                                    if (error)
                                        return "endInteraction." + error;
                                }
                            }
                            if (message.mixedAudio != null && message.hasOwnProperty("mixedAudio")) {
                                if (properties.message === 1)
                                    return "message: multiple values";
                                properties.message = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio.verify(message.mixedAudio);
                                    if (error)
                                        return "mixedAudio." + error;
                                }
                            }
                            if (message.telephonyTransferCall != null && message.hasOwnProperty("telephonyTransferCall")) {
                                if (properties.message === 1)
                                    return "message: multiple values";
                                properties.message = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2beta1.ResponseMessage.TelephonyTransferCall.verify(message.telephonyTransferCall);
                                    if (error)
                                        return "telephonyTransferCall." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates a ResponseMessage message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.ResponseMessage} ResponseMessage
                         */
                        ResponseMessage.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.ResponseMessage)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.ResponseMessage();
                            if (object.text != null) {
                                if (typeof object.text !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.ResponseMessage.text: object expected");
                                message.text = $root.google.cloud.dialogflow.v2beta1.ResponseMessage.Text.fromObject(object.text);
                            }
                            if (object.payload != null) {
                                if (typeof object.payload !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.ResponseMessage.payload: object expected");
                                message.payload = $root.google.protobuf.Struct.fromObject(object.payload);
                            }
                            if (object.liveAgentHandoff != null) {
                                if (typeof object.liveAgentHandoff !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.ResponseMessage.liveAgentHandoff: object expected");
                                message.liveAgentHandoff = $root.google.cloud.dialogflow.v2beta1.ResponseMessage.LiveAgentHandoff.fromObject(object.liveAgentHandoff);
                            }
                            if (object.endInteraction != null) {
                                if (typeof object.endInteraction !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.ResponseMessage.endInteraction: object expected");
                                message.endInteraction = $root.google.cloud.dialogflow.v2beta1.ResponseMessage.EndInteraction.fromObject(object.endInteraction);
                            }
                            if (object.mixedAudio != null) {
                                if (typeof object.mixedAudio !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.ResponseMessage.mixedAudio: object expected");
                                message.mixedAudio = $root.google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio.fromObject(object.mixedAudio);
                            }
                            if (object.telephonyTransferCall != null) {
                                if (typeof object.telephonyTransferCall !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.ResponseMessage.telephonyTransferCall: object expected");
                                message.telephonyTransferCall = $root.google.cloud.dialogflow.v2beta1.ResponseMessage.TelephonyTransferCall.fromObject(object.telephonyTransferCall);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ResponseMessage message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ResponseMessage} message ResponseMessage
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ResponseMessage.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (message.text != null && message.hasOwnProperty("text")) {
                                object.text = $root.google.cloud.dialogflow.v2beta1.ResponseMessage.Text.toObject(message.text, options);
                                if (options.oneofs)
                                    object.message = "text";
                            }
                            if (message.payload != null && message.hasOwnProperty("payload")) {
                                object.payload = $root.google.protobuf.Struct.toObject(message.payload, options);
                                if (options.oneofs)
                                    object.message = "payload";
                            }
                            if (message.liveAgentHandoff != null && message.hasOwnProperty("liveAgentHandoff")) {
                                object.liveAgentHandoff = $root.google.cloud.dialogflow.v2beta1.ResponseMessage.LiveAgentHandoff.toObject(message.liveAgentHandoff, options);
                                if (options.oneofs)
                                    object.message = "liveAgentHandoff";
                            }
                            if (message.endInteraction != null && message.hasOwnProperty("endInteraction")) {
                                object.endInteraction = $root.google.cloud.dialogflow.v2beta1.ResponseMessage.EndInteraction.toObject(message.endInteraction, options);
                                if (options.oneofs)
                                    object.message = "endInteraction";
                            }
                            if (message.mixedAudio != null && message.hasOwnProperty("mixedAudio")) {
                                object.mixedAudio = $root.google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio.toObject(message.mixedAudio, options);
                                if (options.oneofs)
                                    object.message = "mixedAudio";
                            }
                            if (message.telephonyTransferCall != null && message.hasOwnProperty("telephonyTransferCall")) {
                                object.telephonyTransferCall = $root.google.cloud.dialogflow.v2beta1.ResponseMessage.TelephonyTransferCall.toObject(message.telephonyTransferCall, options);
                                if (options.oneofs)
                                    object.message = "telephonyTransferCall";
                            }
                            return object;
                        };
    
                        /**
                         * Converts this ResponseMessage to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ResponseMessage.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ResponseMessage
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ResponseMessage.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ResponseMessage";
                        };
    
                        ResponseMessage.Text = (function() {
    
                            /**
                             * Properties of a Text.
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage
                             * @interface IText
                             * @property {Array.<string>|null} [text] Text text
                             */
    
                            /**
                             * Constructs a new Text.
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage
                             * @classdesc Represents a Text.
                             * @implements IText
                             * @constructor
                             * @param {google.cloud.dialogflow.v2beta1.ResponseMessage.IText=} [properties] Properties to set
                             */
                            function Text(properties) {
                                this.text = [];
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * Text text.
                             * @member {Array.<string>} text
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.Text
                             * @instance
                             */
                            Text.prototype.text = $util.emptyArray;
    
                            /**
                             * Creates a new Text instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.Text
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.ResponseMessage.IText=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2beta1.ResponseMessage.Text} Text instance
                             */
                            Text.create = function create(properties) {
                                return new Text(properties);
                            };
    
                            /**
                             * Encodes the specified Text message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ResponseMessage.Text.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.Text
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.ResponseMessage.IText} message Text message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            Text.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.text != null && message.text.length)
                                    for (var i = 0; i < message.text.length; ++i)
                                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.text[i]);
                                return writer;
                            };
    
                            /**
                             * Encodes the specified Text message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ResponseMessage.Text.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.Text
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.ResponseMessage.IText} message Text message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            Text.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a Text message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.Text
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2beta1.ResponseMessage.Text} Text
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            Text.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ResponseMessage.Text();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            if (!(message.text && message.text.length))
                                                message.text = [];
                                            message.text.push(reader.string());
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a Text message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.Text
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2beta1.ResponseMessage.Text} Text
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            Text.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a Text message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.Text
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            Text.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.text != null && message.hasOwnProperty("text")) {
                                    if (!Array.isArray(message.text))
                                        return "text: array expected";
                                    for (var i = 0; i < message.text.length; ++i)
                                        if (!$util.isString(message.text[i]))
                                            return "text: string[] expected";
                                }
                                return null;
                            };
    
                            /**
                             * Creates a Text message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.Text
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2beta1.ResponseMessage.Text} Text
                             */
                            Text.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2beta1.ResponseMessage.Text)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2beta1.ResponseMessage.Text();
                                if (object.text) {
                                    if (!Array.isArray(object.text))
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.ResponseMessage.Text.text: array expected");
                                    message.text = [];
                                    for (var i = 0; i < object.text.length; ++i)
                                        message.text[i] = String(object.text[i]);
                                }
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a Text message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.Text
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.ResponseMessage.Text} message Text
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            Text.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.arrays || options.defaults)
                                    object.text = [];
                                if (message.text && message.text.length) {
                                    object.text = [];
                                    for (var j = 0; j < message.text.length; ++j)
                                        object.text[j] = message.text[j];
                                }
                                return object;
                            };
    
                            /**
                             * Converts this Text to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.Text
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            Text.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for Text
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.Text
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            Text.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ResponseMessage.Text";
                            };
    
                            return Text;
                        })();
    
                        ResponseMessage.LiveAgentHandoff = (function() {
    
                            /**
                             * Properties of a LiveAgentHandoff.
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage
                             * @interface ILiveAgentHandoff
                             * @property {google.protobuf.IStruct|null} [metadata] LiveAgentHandoff metadata
                             */
    
                            /**
                             * Constructs a new LiveAgentHandoff.
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage
                             * @classdesc Represents a LiveAgentHandoff.
                             * @implements ILiveAgentHandoff
                             * @constructor
                             * @param {google.cloud.dialogflow.v2beta1.ResponseMessage.ILiveAgentHandoff=} [properties] Properties to set
                             */
                            function LiveAgentHandoff(properties) {
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * LiveAgentHandoff metadata.
                             * @member {google.protobuf.IStruct|null|undefined} metadata
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.LiveAgentHandoff
                             * @instance
                             */
                            LiveAgentHandoff.prototype.metadata = null;
    
                            /**
                             * Creates a new LiveAgentHandoff instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.LiveAgentHandoff
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.ResponseMessage.ILiveAgentHandoff=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2beta1.ResponseMessage.LiveAgentHandoff} LiveAgentHandoff instance
                             */
                            LiveAgentHandoff.create = function create(properties) {
                                return new LiveAgentHandoff(properties);
                            };
    
                            /**
                             * Encodes the specified LiveAgentHandoff message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ResponseMessage.LiveAgentHandoff.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.LiveAgentHandoff
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.ResponseMessage.ILiveAgentHandoff} message LiveAgentHandoff message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            LiveAgentHandoff.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.metadata != null && Object.hasOwnProperty.call(message, "metadata"))
                                    $root.google.protobuf.Struct.encode(message.metadata, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                                return writer;
                            };
    
                            /**
                             * Encodes the specified LiveAgentHandoff message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ResponseMessage.LiveAgentHandoff.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.LiveAgentHandoff
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.ResponseMessage.ILiveAgentHandoff} message LiveAgentHandoff message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            LiveAgentHandoff.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a LiveAgentHandoff message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.LiveAgentHandoff
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2beta1.ResponseMessage.LiveAgentHandoff} LiveAgentHandoff
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            LiveAgentHandoff.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ResponseMessage.LiveAgentHandoff();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.metadata = $root.google.protobuf.Struct.decode(reader, reader.uint32());
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a LiveAgentHandoff message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.LiveAgentHandoff
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2beta1.ResponseMessage.LiveAgentHandoff} LiveAgentHandoff
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            LiveAgentHandoff.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a LiveAgentHandoff message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.LiveAgentHandoff
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            LiveAgentHandoff.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.metadata != null && message.hasOwnProperty("metadata")) {
                                    var error = $root.google.protobuf.Struct.verify(message.metadata);
                                    if (error)
                                        return "metadata." + error;
                                }
                                return null;
                            };
    
                            /**
                             * Creates a LiveAgentHandoff message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.LiveAgentHandoff
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2beta1.ResponseMessage.LiveAgentHandoff} LiveAgentHandoff
                             */
                            LiveAgentHandoff.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2beta1.ResponseMessage.LiveAgentHandoff)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2beta1.ResponseMessage.LiveAgentHandoff();
                                if (object.metadata != null) {
                                    if (typeof object.metadata !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.ResponseMessage.LiveAgentHandoff.metadata: object expected");
                                    message.metadata = $root.google.protobuf.Struct.fromObject(object.metadata);
                                }
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a LiveAgentHandoff message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.LiveAgentHandoff
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.ResponseMessage.LiveAgentHandoff} message LiveAgentHandoff
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            LiveAgentHandoff.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.defaults)
                                    object.metadata = null;
                                if (message.metadata != null && message.hasOwnProperty("metadata"))
                                    object.metadata = $root.google.protobuf.Struct.toObject(message.metadata, options);
                                return object;
                            };
    
                            /**
                             * Converts this LiveAgentHandoff to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.LiveAgentHandoff
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            LiveAgentHandoff.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for LiveAgentHandoff
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.LiveAgentHandoff
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            LiveAgentHandoff.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ResponseMessage.LiveAgentHandoff";
                            };
    
                            return LiveAgentHandoff;
                        })();
    
                        ResponseMessage.EndInteraction = (function() {
    
                            /**
                             * Properties of an EndInteraction.
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage
                             * @interface IEndInteraction
                             */
    
                            /**
                             * Constructs a new EndInteraction.
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage
                             * @classdesc Represents an EndInteraction.
                             * @implements IEndInteraction
                             * @constructor
                             * @param {google.cloud.dialogflow.v2beta1.ResponseMessage.IEndInteraction=} [properties] Properties to set
                             */
                            function EndInteraction(properties) {
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * Creates a new EndInteraction instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.EndInteraction
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.ResponseMessage.IEndInteraction=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2beta1.ResponseMessage.EndInteraction} EndInteraction instance
                             */
                            EndInteraction.create = function create(properties) {
                                return new EndInteraction(properties);
                            };
    
                            /**
                             * Encodes the specified EndInteraction message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ResponseMessage.EndInteraction.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.EndInteraction
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.ResponseMessage.IEndInteraction} message EndInteraction message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            EndInteraction.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                return writer;
                            };
    
                            /**
                             * Encodes the specified EndInteraction message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ResponseMessage.EndInteraction.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.EndInteraction
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.ResponseMessage.IEndInteraction} message EndInteraction message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            EndInteraction.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes an EndInteraction message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.EndInteraction
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2beta1.ResponseMessage.EndInteraction} EndInteraction
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            EndInteraction.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ResponseMessage.EndInteraction();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes an EndInteraction message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.EndInteraction
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2beta1.ResponseMessage.EndInteraction} EndInteraction
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            EndInteraction.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies an EndInteraction message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.EndInteraction
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            EndInteraction.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                return null;
                            };
    
                            /**
                             * Creates an EndInteraction message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.EndInteraction
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2beta1.ResponseMessage.EndInteraction} EndInteraction
                             */
                            EndInteraction.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2beta1.ResponseMessage.EndInteraction)
                                    return object;
                                return new $root.google.cloud.dialogflow.v2beta1.ResponseMessage.EndInteraction();
                            };
    
                            /**
                             * Creates a plain object from an EndInteraction message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.EndInteraction
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.ResponseMessage.EndInteraction} message EndInteraction
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            EndInteraction.toObject = function toObject() {
                                return {};
                            };
    
                            /**
                             * Converts this EndInteraction to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.EndInteraction
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            EndInteraction.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for EndInteraction
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.EndInteraction
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            EndInteraction.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ResponseMessage.EndInteraction";
                            };
    
                            return EndInteraction;
                        })();
    
                        ResponseMessage.MixedAudio = (function() {
    
                            /**
                             * Properties of a MixedAudio.
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage
                             * @interface IMixedAudio
                             * @property {Array.<google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio.ISegment>|null} [segments] MixedAudio segments
                             */
    
                            /**
                             * Constructs a new MixedAudio.
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage
                             * @classdesc Represents a MixedAudio.
                             * @implements IMixedAudio
                             * @constructor
                             * @param {google.cloud.dialogflow.v2beta1.ResponseMessage.IMixedAudio=} [properties] Properties to set
                             */
                            function MixedAudio(properties) {
                                this.segments = [];
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * MixedAudio segments.
                             * @member {Array.<google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio.ISegment>} segments
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio
                             * @instance
                             */
                            MixedAudio.prototype.segments = $util.emptyArray;
    
                            /**
                             * Creates a new MixedAudio instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.ResponseMessage.IMixedAudio=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio} MixedAudio instance
                             */
                            MixedAudio.create = function create(properties) {
                                return new MixedAudio(properties);
                            };
    
                            /**
                             * Encodes the specified MixedAudio message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.ResponseMessage.IMixedAudio} message MixedAudio message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            MixedAudio.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.segments != null && message.segments.length)
                                    for (var i = 0; i < message.segments.length; ++i)
                                        $root.google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio.Segment.encode(message.segments[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                                return writer;
                            };
    
                            /**
                             * Encodes the specified MixedAudio message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.ResponseMessage.IMixedAudio} message MixedAudio message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            MixedAudio.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a MixedAudio message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio} MixedAudio
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            MixedAudio.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            if (!(message.segments && message.segments.length))
                                                message.segments = [];
                                            message.segments.push($root.google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio.Segment.decode(reader, reader.uint32()));
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a MixedAudio message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio} MixedAudio
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            MixedAudio.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a MixedAudio message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            MixedAudio.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.segments != null && message.hasOwnProperty("segments")) {
                                    if (!Array.isArray(message.segments))
                                        return "segments: array expected";
                                    for (var i = 0; i < message.segments.length; ++i) {
                                        var error = $root.google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio.Segment.verify(message.segments[i]);
                                        if (error)
                                            return "segments." + error;
                                    }
                                }
                                return null;
                            };
    
                            /**
                             * Creates a MixedAudio message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio} MixedAudio
                             */
                            MixedAudio.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio();
                                if (object.segments) {
                                    if (!Array.isArray(object.segments))
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio.segments: array expected");
                                    message.segments = [];
                                    for (var i = 0; i < object.segments.length; ++i) {
                                        if (typeof object.segments[i] !== "object")
                                            throw TypeError(".google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio.segments: object expected");
                                        message.segments[i] = $root.google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio.Segment.fromObject(object.segments[i]);
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a MixedAudio message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio} message MixedAudio
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            MixedAudio.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.arrays || options.defaults)
                                    object.segments = [];
                                if (message.segments && message.segments.length) {
                                    object.segments = [];
                                    for (var j = 0; j < message.segments.length; ++j)
                                        object.segments[j] = $root.google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio.Segment.toObject(message.segments[j], options);
                                }
                                return object;
                            };
    
                            /**
                             * Converts this MixedAudio to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            MixedAudio.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for MixedAudio
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            MixedAudio.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio";
                            };
    
                            MixedAudio.Segment = (function() {
    
                                /**
                                 * Properties of a Segment.
                                 * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio
                                 * @interface ISegment
                                 * @property {Uint8Array|null} [audio] Segment audio
                                 * @property {string|null} [uri] Segment uri
                                 * @property {boolean|null} [allowPlaybackInterruption] Segment allowPlaybackInterruption
                                 */
    
                                /**
                                 * Constructs a new Segment.
                                 * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio
                                 * @classdesc Represents a Segment.
                                 * @implements ISegment
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio.ISegment=} [properties] Properties to set
                                 */
                                function Segment(properties) {
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * Segment audio.
                                 * @member {Uint8Array|null|undefined} audio
                                 * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio.Segment
                                 * @instance
                                 */
                                Segment.prototype.audio = null;
    
                                /**
                                 * Segment uri.
                                 * @member {string|null|undefined} uri
                                 * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio.Segment
                                 * @instance
                                 */
                                Segment.prototype.uri = null;
    
                                /**
                                 * Segment allowPlaybackInterruption.
                                 * @member {boolean} allowPlaybackInterruption
                                 * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio.Segment
                                 * @instance
                                 */
                                Segment.prototype.allowPlaybackInterruption = false;
    
                                // OneOf field names bound to virtual getters and setters
                                var $oneOfFields;
    
                                /**
                                 * Segment content.
                                 * @member {"audio"|"uri"|undefined} content
                                 * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio.Segment
                                 * @instance
                                 */
                                Object.defineProperty(Segment.prototype, "content", {
                                    get: $util.oneOfGetter($oneOfFields = ["audio", "uri"]),
                                    set: $util.oneOfSetter($oneOfFields)
                                });
    
                                /**
                                 * Creates a new Segment instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio.Segment
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio.ISegment=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio.Segment} Segment instance
                                 */
                                Segment.create = function create(properties) {
                                    return new Segment(properties);
                                };
    
                                /**
                                 * Encodes the specified Segment message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio.Segment.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio.Segment
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio.ISegment} message Segment message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                Segment.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.audio != null && Object.hasOwnProperty.call(message, "audio"))
                                        writer.uint32(/* id 1, wireType 2 =*/10).bytes(message.audio);
                                    if (message.uri != null && Object.hasOwnProperty.call(message, "uri"))
                                        writer.uint32(/* id 2, wireType 2 =*/18).string(message.uri);
                                    if (message.allowPlaybackInterruption != null && Object.hasOwnProperty.call(message, "allowPlaybackInterruption"))
                                        writer.uint32(/* id 3, wireType 0 =*/24).bool(message.allowPlaybackInterruption);
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified Segment message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio.Segment.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio.Segment
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio.ISegment} message Segment message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                Segment.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a Segment message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio.Segment
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio.Segment} Segment
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                Segment.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio.Segment();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                message.audio = reader.bytes();
                                                break;
                                            }
                                        case 2: {
                                                message.uri = reader.string();
                                                break;
                                            }
                                        case 3: {
                                                message.allowPlaybackInterruption = reader.bool();
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a Segment message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio.Segment
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio.Segment} Segment
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                Segment.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a Segment message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio.Segment
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                Segment.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    var properties = {};
                                    if (message.audio != null && message.hasOwnProperty("audio")) {
                                        properties.content = 1;
                                        if (!(message.audio && typeof message.audio.length === "number" || $util.isString(message.audio)))
                                            return "audio: buffer expected";
                                    }
                                    if (message.uri != null && message.hasOwnProperty("uri")) {
                                        if (properties.content === 1)
                                            return "content: multiple values";
                                        properties.content = 1;
                                        if (!$util.isString(message.uri))
                                            return "uri: string expected";
                                    }
                                    if (message.allowPlaybackInterruption != null && message.hasOwnProperty("allowPlaybackInterruption"))
                                        if (typeof message.allowPlaybackInterruption !== "boolean")
                                            return "allowPlaybackInterruption: boolean expected";
                                    return null;
                                };
    
                                /**
                                 * Creates a Segment message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio.Segment
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio.Segment} Segment
                                 */
                                Segment.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio.Segment)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio.Segment();
                                    if (object.audio != null)
                                        if (typeof object.audio === "string")
                                            $util.base64.decode(object.audio, message.audio = $util.newBuffer($util.base64.length(object.audio)), 0);
                                        else if (object.audio.length >= 0)
                                            message.audio = object.audio;
                                    if (object.uri != null)
                                        message.uri = String(object.uri);
                                    if (object.allowPlaybackInterruption != null)
                                        message.allowPlaybackInterruption = Boolean(object.allowPlaybackInterruption);
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a Segment message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio.Segment
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio.Segment} message Segment
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                Segment.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.defaults)
                                        object.allowPlaybackInterruption = false;
                                    if (message.audio != null && message.hasOwnProperty("audio")) {
                                        object.audio = options.bytes === String ? $util.base64.encode(message.audio, 0, message.audio.length) : options.bytes === Array ? Array.prototype.slice.call(message.audio) : message.audio;
                                        if (options.oneofs)
                                            object.content = "audio";
                                    }
                                    if (message.uri != null && message.hasOwnProperty("uri")) {
                                        object.uri = message.uri;
                                        if (options.oneofs)
                                            object.content = "uri";
                                    }
                                    if (message.allowPlaybackInterruption != null && message.hasOwnProperty("allowPlaybackInterruption"))
                                        object.allowPlaybackInterruption = message.allowPlaybackInterruption;
                                    return object;
                                };
    
                                /**
                                 * Converts this Segment to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio.Segment
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                Segment.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for Segment
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio.Segment
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                Segment.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ResponseMessage.MixedAudio.Segment";
                                };
    
                                return Segment;
                            })();
    
                            return MixedAudio;
                        })();
    
                        ResponseMessage.TelephonyTransferCall = (function() {
    
                            /**
                             * Properties of a TelephonyTransferCall.
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage
                             * @interface ITelephonyTransferCall
                             * @property {string|null} [phoneNumber] TelephonyTransferCall phoneNumber
                             * @property {string|null} [sipUri] TelephonyTransferCall sipUri
                             */
    
                            /**
                             * Constructs a new TelephonyTransferCall.
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage
                             * @classdesc Represents a TelephonyTransferCall.
                             * @implements ITelephonyTransferCall
                             * @constructor
                             * @param {google.cloud.dialogflow.v2beta1.ResponseMessage.ITelephonyTransferCall=} [properties] Properties to set
                             */
                            function TelephonyTransferCall(properties) {
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * TelephonyTransferCall phoneNumber.
                             * @member {string|null|undefined} phoneNumber
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.TelephonyTransferCall
                             * @instance
                             */
                            TelephonyTransferCall.prototype.phoneNumber = null;
    
                            /**
                             * TelephonyTransferCall sipUri.
                             * @member {string|null|undefined} sipUri
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.TelephonyTransferCall
                             * @instance
                             */
                            TelephonyTransferCall.prototype.sipUri = null;
    
                            // OneOf field names bound to virtual getters and setters
                            var $oneOfFields;
    
                            /**
                             * TelephonyTransferCall endpoint.
                             * @member {"phoneNumber"|"sipUri"|undefined} endpoint
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.TelephonyTransferCall
                             * @instance
                             */
                            Object.defineProperty(TelephonyTransferCall.prototype, "endpoint", {
                                get: $util.oneOfGetter($oneOfFields = ["phoneNumber", "sipUri"]),
                                set: $util.oneOfSetter($oneOfFields)
                            });
    
                            /**
                             * Creates a new TelephonyTransferCall instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.TelephonyTransferCall
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.ResponseMessage.ITelephonyTransferCall=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2beta1.ResponseMessage.TelephonyTransferCall} TelephonyTransferCall instance
                             */
                            TelephonyTransferCall.create = function create(properties) {
                                return new TelephonyTransferCall(properties);
                            };
    
                            /**
                             * Encodes the specified TelephonyTransferCall message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ResponseMessage.TelephonyTransferCall.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.TelephonyTransferCall
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.ResponseMessage.ITelephonyTransferCall} message TelephonyTransferCall message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            TelephonyTransferCall.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.phoneNumber != null && Object.hasOwnProperty.call(message, "phoneNumber"))
                                    writer.uint32(/* id 1, wireType 2 =*/10).string(message.phoneNumber);
                                if (message.sipUri != null && Object.hasOwnProperty.call(message, "sipUri"))
                                    writer.uint32(/* id 2, wireType 2 =*/18).string(message.sipUri);
                                return writer;
                            };
    
                            /**
                             * Encodes the specified TelephonyTransferCall message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ResponseMessage.TelephonyTransferCall.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.TelephonyTransferCall
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.ResponseMessage.ITelephonyTransferCall} message TelephonyTransferCall message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            TelephonyTransferCall.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a TelephonyTransferCall message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.TelephonyTransferCall
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2beta1.ResponseMessage.TelephonyTransferCall} TelephonyTransferCall
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            TelephonyTransferCall.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ResponseMessage.TelephonyTransferCall();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.phoneNumber = reader.string();
                                            break;
                                        }
                                    case 2: {
                                            message.sipUri = reader.string();
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a TelephonyTransferCall message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.TelephonyTransferCall
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2beta1.ResponseMessage.TelephonyTransferCall} TelephonyTransferCall
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            TelephonyTransferCall.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a TelephonyTransferCall message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.TelephonyTransferCall
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            TelephonyTransferCall.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                var properties = {};
                                if (message.phoneNumber != null && message.hasOwnProperty("phoneNumber")) {
                                    properties.endpoint = 1;
                                    if (!$util.isString(message.phoneNumber))
                                        return "phoneNumber: string expected";
                                }
                                if (message.sipUri != null && message.hasOwnProperty("sipUri")) {
                                    if (properties.endpoint === 1)
                                        return "endpoint: multiple values";
                                    properties.endpoint = 1;
                                    if (!$util.isString(message.sipUri))
                                        return "sipUri: string expected";
                                }
                                return null;
                            };
    
                            /**
                             * Creates a TelephonyTransferCall message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.TelephonyTransferCall
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2beta1.ResponseMessage.TelephonyTransferCall} TelephonyTransferCall
                             */
                            TelephonyTransferCall.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2beta1.ResponseMessage.TelephonyTransferCall)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2beta1.ResponseMessage.TelephonyTransferCall();
                                if (object.phoneNumber != null)
                                    message.phoneNumber = String(object.phoneNumber);
                                if (object.sipUri != null)
                                    message.sipUri = String(object.sipUri);
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a TelephonyTransferCall message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.TelephonyTransferCall
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.ResponseMessage.TelephonyTransferCall} message TelephonyTransferCall
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            TelephonyTransferCall.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (message.phoneNumber != null && message.hasOwnProperty("phoneNumber")) {
                                    object.phoneNumber = message.phoneNumber;
                                    if (options.oneofs)
                                        object.endpoint = "phoneNumber";
                                }
                                if (message.sipUri != null && message.hasOwnProperty("sipUri")) {
                                    object.sipUri = message.sipUri;
                                    if (options.oneofs)
                                        object.endpoint = "sipUri";
                                }
                                return object;
                            };
    
                            /**
                             * Converts this TelephonyTransferCall to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.TelephonyTransferCall
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            TelephonyTransferCall.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for TelephonyTransferCall
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2beta1.ResponseMessage.TelephonyTransferCall
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            TelephonyTransferCall.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ResponseMessage.TelephonyTransferCall";
                            };
    
                            return TelephonyTransferCall;
                        })();
    
                        return ResponseMessage;
                    })();
    
                    v2beta1.SuggestKnowledgeAssistRequest = (function() {
    
                        /**
                         * Properties of a SuggestKnowledgeAssistRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ISuggestKnowledgeAssistRequest
                         * @property {string|null} [parent] SuggestKnowledgeAssistRequest parent
                         * @property {string|null} [latestMessage] SuggestKnowledgeAssistRequest latestMessage
                         * @property {number|null} [contextSize] SuggestKnowledgeAssistRequest contextSize
                         * @property {string|null} [previousSuggestedQuery] SuggestKnowledgeAssistRequest previousSuggestedQuery
                         */
    
                        /**
                         * Constructs a new SuggestKnowledgeAssistRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a SuggestKnowledgeAssistRequest.
                         * @implements ISuggestKnowledgeAssistRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestKnowledgeAssistRequest=} [properties] Properties to set
                         */
                        function SuggestKnowledgeAssistRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SuggestKnowledgeAssistRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistRequest
                         * @instance
                         */
                        SuggestKnowledgeAssistRequest.prototype.parent = "";
    
                        /**
                         * SuggestKnowledgeAssistRequest latestMessage.
                         * @member {string} latestMessage
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistRequest
                         * @instance
                         */
                        SuggestKnowledgeAssistRequest.prototype.latestMessage = "";
    
                        /**
                         * SuggestKnowledgeAssistRequest contextSize.
                         * @member {number} contextSize
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistRequest
                         * @instance
                         */
                        SuggestKnowledgeAssistRequest.prototype.contextSize = 0;
    
                        /**
                         * SuggestKnowledgeAssistRequest previousSuggestedQuery.
                         * @member {string} previousSuggestedQuery
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistRequest
                         * @instance
                         */
                        SuggestKnowledgeAssistRequest.prototype.previousSuggestedQuery = "";
    
                        /**
                         * Creates a new SuggestKnowledgeAssistRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestKnowledgeAssistRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistRequest} SuggestKnowledgeAssistRequest instance
                         */
                        SuggestKnowledgeAssistRequest.create = function create(properties) {
                            return new SuggestKnowledgeAssistRequest(properties);
                        };
    
                        /**
                         * Encodes the specified SuggestKnowledgeAssistRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestKnowledgeAssistRequest} message SuggestKnowledgeAssistRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SuggestKnowledgeAssistRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.latestMessage != null && Object.hasOwnProperty.call(message, "latestMessage"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.latestMessage);
                            if (message.contextSize != null && Object.hasOwnProperty.call(message, "contextSize"))
                                writer.uint32(/* id 3, wireType 0 =*/24).int32(message.contextSize);
                            if (message.previousSuggestedQuery != null && Object.hasOwnProperty.call(message, "previousSuggestedQuery"))
                                writer.uint32(/* id 4, wireType 2 =*/34).string(message.previousSuggestedQuery);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SuggestKnowledgeAssistRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestKnowledgeAssistRequest} message SuggestKnowledgeAssistRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SuggestKnowledgeAssistRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SuggestKnowledgeAssistRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistRequest} SuggestKnowledgeAssistRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SuggestKnowledgeAssistRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.latestMessage = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.contextSize = reader.int32();
                                        break;
                                    }
                                case 4: {
                                        message.previousSuggestedQuery = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SuggestKnowledgeAssistRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistRequest} SuggestKnowledgeAssistRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SuggestKnowledgeAssistRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SuggestKnowledgeAssistRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SuggestKnowledgeAssistRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                if (!$util.isString(message.latestMessage))
                                    return "latestMessage: string expected";
                            if (message.contextSize != null && message.hasOwnProperty("contextSize"))
                                if (!$util.isInteger(message.contextSize))
                                    return "contextSize: integer expected";
                            if (message.previousSuggestedQuery != null && message.hasOwnProperty("previousSuggestedQuery"))
                                if (!$util.isString(message.previousSuggestedQuery))
                                    return "previousSuggestedQuery: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a SuggestKnowledgeAssistRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistRequest} SuggestKnowledgeAssistRequest
                         */
                        SuggestKnowledgeAssistRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.latestMessage != null)
                                message.latestMessage = String(object.latestMessage);
                            if (object.contextSize != null)
                                message.contextSize = object.contextSize | 0;
                            if (object.previousSuggestedQuery != null)
                                message.previousSuggestedQuery = String(object.previousSuggestedQuery);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SuggestKnowledgeAssistRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistRequest} message SuggestKnowledgeAssistRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SuggestKnowledgeAssistRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.latestMessage = "";
                                object.contextSize = 0;
                                object.previousSuggestedQuery = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                object.latestMessage = message.latestMessage;
                            if (message.contextSize != null && message.hasOwnProperty("contextSize"))
                                object.contextSize = message.contextSize;
                            if (message.previousSuggestedQuery != null && message.hasOwnProperty("previousSuggestedQuery"))
                                object.previousSuggestedQuery = message.previousSuggestedQuery;
                            return object;
                        };
    
                        /**
                         * Converts this SuggestKnowledgeAssistRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SuggestKnowledgeAssistRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SuggestKnowledgeAssistRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SuggestKnowledgeAssistRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistRequest";
                        };
    
                        return SuggestKnowledgeAssistRequest;
                    })();
    
                    v2beta1.SuggestKnowledgeAssistResponse = (function() {
    
                        /**
                         * Properties of a SuggestKnowledgeAssistResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ISuggestKnowledgeAssistResponse
                         * @property {google.cloud.dialogflow.v2beta1.IKnowledgeAssistAnswer|null} [knowledgeAssistAnswer] SuggestKnowledgeAssistResponse knowledgeAssistAnswer
                         * @property {string|null} [latestMessage] SuggestKnowledgeAssistResponse latestMessage
                         * @property {number|null} [contextSize] SuggestKnowledgeAssistResponse contextSize
                         */
    
                        /**
                         * Constructs a new SuggestKnowledgeAssistResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a SuggestKnowledgeAssistResponse.
                         * @implements ISuggestKnowledgeAssistResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestKnowledgeAssistResponse=} [properties] Properties to set
                         */
                        function SuggestKnowledgeAssistResponse(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SuggestKnowledgeAssistResponse knowledgeAssistAnswer.
                         * @member {google.cloud.dialogflow.v2beta1.IKnowledgeAssistAnswer|null|undefined} knowledgeAssistAnswer
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistResponse
                         * @instance
                         */
                        SuggestKnowledgeAssistResponse.prototype.knowledgeAssistAnswer = null;
    
                        /**
                         * SuggestKnowledgeAssistResponse latestMessage.
                         * @member {string} latestMessage
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistResponse
                         * @instance
                         */
                        SuggestKnowledgeAssistResponse.prototype.latestMessage = "";
    
                        /**
                         * SuggestKnowledgeAssistResponse contextSize.
                         * @member {number} contextSize
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistResponse
                         * @instance
                         */
                        SuggestKnowledgeAssistResponse.prototype.contextSize = 0;
    
                        /**
                         * Creates a new SuggestKnowledgeAssistResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestKnowledgeAssistResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistResponse} SuggestKnowledgeAssistResponse instance
                         */
                        SuggestKnowledgeAssistResponse.create = function create(properties) {
                            return new SuggestKnowledgeAssistResponse(properties);
                        };
    
                        /**
                         * Encodes the specified SuggestKnowledgeAssistResponse message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestKnowledgeAssistResponse} message SuggestKnowledgeAssistResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SuggestKnowledgeAssistResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.knowledgeAssistAnswer != null && Object.hasOwnProperty.call(message, "knowledgeAssistAnswer"))
                                $root.google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.encode(message.knowledgeAssistAnswer, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.latestMessage != null && Object.hasOwnProperty.call(message, "latestMessage"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.latestMessage);
                            if (message.contextSize != null && Object.hasOwnProperty.call(message, "contextSize"))
                                writer.uint32(/* id 3, wireType 0 =*/24).int32(message.contextSize);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SuggestKnowledgeAssistResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestKnowledgeAssistResponse} message SuggestKnowledgeAssistResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SuggestKnowledgeAssistResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SuggestKnowledgeAssistResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistResponse} SuggestKnowledgeAssistResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SuggestKnowledgeAssistResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.knowledgeAssistAnswer = $root.google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.latestMessage = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.contextSize = reader.int32();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SuggestKnowledgeAssistResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistResponse} SuggestKnowledgeAssistResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SuggestKnowledgeAssistResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SuggestKnowledgeAssistResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SuggestKnowledgeAssistResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.knowledgeAssistAnswer != null && message.hasOwnProperty("knowledgeAssistAnswer")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.verify(message.knowledgeAssistAnswer);
                                if (error)
                                    return "knowledgeAssistAnswer." + error;
                            }
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                if (!$util.isString(message.latestMessage))
                                    return "latestMessage: string expected";
                            if (message.contextSize != null && message.hasOwnProperty("contextSize"))
                                if (!$util.isInteger(message.contextSize))
                                    return "contextSize: integer expected";
                            return null;
                        };
    
                        /**
                         * Creates a SuggestKnowledgeAssistResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistResponse} SuggestKnowledgeAssistResponse
                         */
                        SuggestKnowledgeAssistResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistResponse();
                            if (object.knowledgeAssistAnswer != null) {
                                if (typeof object.knowledgeAssistAnswer !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistResponse.knowledgeAssistAnswer: object expected");
                                message.knowledgeAssistAnswer = $root.google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.fromObject(object.knowledgeAssistAnswer);
                            }
                            if (object.latestMessage != null)
                                message.latestMessage = String(object.latestMessage);
                            if (object.contextSize != null)
                                message.contextSize = object.contextSize | 0;
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SuggestKnowledgeAssistResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistResponse} message SuggestKnowledgeAssistResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SuggestKnowledgeAssistResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.knowledgeAssistAnswer = null;
                                object.latestMessage = "";
                                object.contextSize = 0;
                            }
                            if (message.knowledgeAssistAnswer != null && message.hasOwnProperty("knowledgeAssistAnswer"))
                                object.knowledgeAssistAnswer = $root.google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.toObject(message.knowledgeAssistAnswer, options);
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                object.latestMessage = message.latestMessage;
                            if (message.contextSize != null && message.hasOwnProperty("contextSize"))
                                object.contextSize = message.contextSize;
                            return object;
                        };
    
                        /**
                         * Converts this SuggestKnowledgeAssistResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SuggestKnowledgeAssistResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SuggestKnowledgeAssistResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SuggestKnowledgeAssistResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.SuggestKnowledgeAssistResponse";
                        };
    
                        return SuggestKnowledgeAssistResponse;
                    })();
    
                    v2beta1.KnowledgeAssistAnswer = (function() {
    
                        /**
                         * Properties of a KnowledgeAssistAnswer.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IKnowledgeAssistAnswer
                         * @property {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.ISuggestedQuery|null} [suggestedQuery] KnowledgeAssistAnswer suggestedQuery
                         * @property {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.IKnowledgeAnswer|null} [suggestedQueryAnswer] KnowledgeAssistAnswer suggestedQueryAnswer
                         * @property {string|null} [answerRecord] KnowledgeAssistAnswer answerRecord
                         */
    
                        /**
                         * Constructs a new KnowledgeAssistAnswer.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a KnowledgeAssistAnswer.
                         * @implements IKnowledgeAssistAnswer
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IKnowledgeAssistAnswer=} [properties] Properties to set
                         */
                        function KnowledgeAssistAnswer(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * KnowledgeAssistAnswer suggestedQuery.
                         * @member {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.ISuggestedQuery|null|undefined} suggestedQuery
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer
                         * @instance
                         */
                        KnowledgeAssistAnswer.prototype.suggestedQuery = null;
    
                        /**
                         * KnowledgeAssistAnswer suggestedQueryAnswer.
                         * @member {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.IKnowledgeAnswer|null|undefined} suggestedQueryAnswer
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer
                         * @instance
                         */
                        KnowledgeAssistAnswer.prototype.suggestedQueryAnswer = null;
    
                        /**
                         * KnowledgeAssistAnswer answerRecord.
                         * @member {string} answerRecord
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer
                         * @instance
                         */
                        KnowledgeAssistAnswer.prototype.answerRecord = "";
    
                        /**
                         * Creates a new KnowledgeAssistAnswer instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IKnowledgeAssistAnswer=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer} KnowledgeAssistAnswer instance
                         */
                        KnowledgeAssistAnswer.create = function create(properties) {
                            return new KnowledgeAssistAnswer(properties);
                        };
    
                        /**
                         * Encodes the specified KnowledgeAssistAnswer message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IKnowledgeAssistAnswer} message KnowledgeAssistAnswer message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        KnowledgeAssistAnswer.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.suggestedQuery != null && Object.hasOwnProperty.call(message, "suggestedQuery"))
                                $root.google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.SuggestedQuery.encode(message.suggestedQuery, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.suggestedQueryAnswer != null && Object.hasOwnProperty.call(message, "suggestedQueryAnswer"))
                                $root.google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.encode(message.suggestedQueryAnswer, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.answerRecord != null && Object.hasOwnProperty.call(message, "answerRecord"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.answerRecord);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified KnowledgeAssistAnswer message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IKnowledgeAssistAnswer} message KnowledgeAssistAnswer message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        KnowledgeAssistAnswer.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a KnowledgeAssistAnswer message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer} KnowledgeAssistAnswer
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        KnowledgeAssistAnswer.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.suggestedQuery = $root.google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.SuggestedQuery.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.suggestedQueryAnswer = $root.google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 3: {
                                        message.answerRecord = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a KnowledgeAssistAnswer message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer} KnowledgeAssistAnswer
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        KnowledgeAssistAnswer.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a KnowledgeAssistAnswer message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        KnowledgeAssistAnswer.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.suggestedQuery != null && message.hasOwnProperty("suggestedQuery")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.SuggestedQuery.verify(message.suggestedQuery);
                                if (error)
                                    return "suggestedQuery." + error;
                            }
                            if (message.suggestedQueryAnswer != null && message.hasOwnProperty("suggestedQueryAnswer")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.verify(message.suggestedQueryAnswer);
                                if (error)
                                    return "suggestedQueryAnswer." + error;
                            }
                            if (message.answerRecord != null && message.hasOwnProperty("answerRecord"))
                                if (!$util.isString(message.answerRecord))
                                    return "answerRecord: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a KnowledgeAssistAnswer message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer} KnowledgeAssistAnswer
                         */
                        KnowledgeAssistAnswer.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer();
                            if (object.suggestedQuery != null) {
                                if (typeof object.suggestedQuery !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.suggestedQuery: object expected");
                                message.suggestedQuery = $root.google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.SuggestedQuery.fromObject(object.suggestedQuery);
                            }
                            if (object.suggestedQueryAnswer != null) {
                                if (typeof object.suggestedQueryAnswer !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.suggestedQueryAnswer: object expected");
                                message.suggestedQueryAnswer = $root.google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.fromObject(object.suggestedQueryAnswer);
                            }
                            if (object.answerRecord != null)
                                message.answerRecord = String(object.answerRecord);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a KnowledgeAssistAnswer message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer} message KnowledgeAssistAnswer
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        KnowledgeAssistAnswer.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.suggestedQuery = null;
                                object.suggestedQueryAnswer = null;
                                object.answerRecord = "";
                            }
                            if (message.suggestedQuery != null && message.hasOwnProperty("suggestedQuery"))
                                object.suggestedQuery = $root.google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.SuggestedQuery.toObject(message.suggestedQuery, options);
                            if (message.suggestedQueryAnswer != null && message.hasOwnProperty("suggestedQueryAnswer"))
                                object.suggestedQueryAnswer = $root.google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.toObject(message.suggestedQueryAnswer, options);
                            if (message.answerRecord != null && message.hasOwnProperty("answerRecord"))
                                object.answerRecord = message.answerRecord;
                            return object;
                        };
    
                        /**
                         * Converts this KnowledgeAssistAnswer to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        KnowledgeAssistAnswer.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for KnowledgeAssistAnswer
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        KnowledgeAssistAnswer.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer";
                        };
    
                        KnowledgeAssistAnswer.SuggestedQuery = (function() {
    
                            /**
                             * Properties of a SuggestedQuery.
                             * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer
                             * @interface ISuggestedQuery
                             * @property {string|null} [queryText] SuggestedQuery queryText
                             */
    
                            /**
                             * Constructs a new SuggestedQuery.
                             * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer
                             * @classdesc Represents a SuggestedQuery.
                             * @implements ISuggestedQuery
                             * @constructor
                             * @param {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.ISuggestedQuery=} [properties] Properties to set
                             */
                            function SuggestedQuery(properties) {
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * SuggestedQuery queryText.
                             * @member {string} queryText
                             * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.SuggestedQuery
                             * @instance
                             */
                            SuggestedQuery.prototype.queryText = "";
    
                            /**
                             * Creates a new SuggestedQuery instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.SuggestedQuery
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.ISuggestedQuery=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.SuggestedQuery} SuggestedQuery instance
                             */
                            SuggestedQuery.create = function create(properties) {
                                return new SuggestedQuery(properties);
                            };
    
                            /**
                             * Encodes the specified SuggestedQuery message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.SuggestedQuery.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.SuggestedQuery
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.ISuggestedQuery} message SuggestedQuery message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            SuggestedQuery.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.queryText != null && Object.hasOwnProperty.call(message, "queryText"))
                                    writer.uint32(/* id 1, wireType 2 =*/10).string(message.queryText);
                                return writer;
                            };
    
                            /**
                             * Encodes the specified SuggestedQuery message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.SuggestedQuery.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.SuggestedQuery
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.ISuggestedQuery} message SuggestedQuery message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            SuggestedQuery.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a SuggestedQuery message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.SuggestedQuery
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.SuggestedQuery} SuggestedQuery
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            SuggestedQuery.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.SuggestedQuery();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.queryText = reader.string();
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a SuggestedQuery message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.SuggestedQuery
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.SuggestedQuery} SuggestedQuery
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            SuggestedQuery.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a SuggestedQuery message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.SuggestedQuery
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            SuggestedQuery.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.queryText != null && message.hasOwnProperty("queryText"))
                                    if (!$util.isString(message.queryText))
                                        return "queryText: string expected";
                                return null;
                            };
    
                            /**
                             * Creates a SuggestedQuery message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.SuggestedQuery
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.SuggestedQuery} SuggestedQuery
                             */
                            SuggestedQuery.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.SuggestedQuery)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.SuggestedQuery();
                                if (object.queryText != null)
                                    message.queryText = String(object.queryText);
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a SuggestedQuery message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.SuggestedQuery
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.SuggestedQuery} message SuggestedQuery
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            SuggestedQuery.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.defaults)
                                    object.queryText = "";
                                if (message.queryText != null && message.hasOwnProperty("queryText"))
                                    object.queryText = message.queryText;
                                return object;
                            };
    
                            /**
                             * Converts this SuggestedQuery to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.SuggestedQuery
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            SuggestedQuery.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for SuggestedQuery
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.SuggestedQuery
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            SuggestedQuery.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.SuggestedQuery";
                            };
    
                            return SuggestedQuery;
                        })();
    
                        KnowledgeAssistAnswer.KnowledgeAnswer = (function() {
    
                            /**
                             * Properties of a KnowledgeAnswer.
                             * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer
                             * @interface IKnowledgeAnswer
                             * @property {string|null} [answerText] KnowledgeAnswer answerText
                             * @property {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.IFaqSource|null} [faqSource] KnowledgeAnswer faqSource
                             * @property {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.IGenerativeSource|null} [generativeSource] KnowledgeAnswer generativeSource
                             */
    
                            /**
                             * Constructs a new KnowledgeAnswer.
                             * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer
                             * @classdesc Represents a KnowledgeAnswer.
                             * @implements IKnowledgeAnswer
                             * @constructor
                             * @param {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.IKnowledgeAnswer=} [properties] Properties to set
                             */
                            function KnowledgeAnswer(properties) {
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * KnowledgeAnswer answerText.
                             * @member {string} answerText
                             * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer
                             * @instance
                             */
                            KnowledgeAnswer.prototype.answerText = "";
    
                            /**
                             * KnowledgeAnswer faqSource.
                             * @member {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.IFaqSource|null|undefined} faqSource
                             * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer
                             * @instance
                             */
                            KnowledgeAnswer.prototype.faqSource = null;
    
                            /**
                             * KnowledgeAnswer generativeSource.
                             * @member {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.IGenerativeSource|null|undefined} generativeSource
                             * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer
                             * @instance
                             */
                            KnowledgeAnswer.prototype.generativeSource = null;
    
                            // OneOf field names bound to virtual getters and setters
                            var $oneOfFields;
    
                            /**
                             * KnowledgeAnswer source.
                             * @member {"faqSource"|"generativeSource"|undefined} source
                             * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer
                             * @instance
                             */
                            Object.defineProperty(KnowledgeAnswer.prototype, "source", {
                                get: $util.oneOfGetter($oneOfFields = ["faqSource", "generativeSource"]),
                                set: $util.oneOfSetter($oneOfFields)
                            });
    
                            /**
                             * Creates a new KnowledgeAnswer instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.IKnowledgeAnswer=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer} KnowledgeAnswer instance
                             */
                            KnowledgeAnswer.create = function create(properties) {
                                return new KnowledgeAnswer(properties);
                            };
    
                            /**
                             * Encodes the specified KnowledgeAnswer message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.IKnowledgeAnswer} message KnowledgeAnswer message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            KnowledgeAnswer.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.answerText != null && Object.hasOwnProperty.call(message, "answerText"))
                                    writer.uint32(/* id 1, wireType 2 =*/10).string(message.answerText);
                                if (message.faqSource != null && Object.hasOwnProperty.call(message, "faqSource"))
                                    $root.google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.FaqSource.encode(message.faqSource, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                                if (message.generativeSource != null && Object.hasOwnProperty.call(message, "generativeSource"))
                                    $root.google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.encode(message.generativeSource, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                                return writer;
                            };
    
                            /**
                             * Encodes the specified KnowledgeAnswer message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.IKnowledgeAnswer} message KnowledgeAnswer message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            KnowledgeAnswer.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a KnowledgeAnswer message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer} KnowledgeAnswer
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            KnowledgeAnswer.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.answerText = reader.string();
                                            break;
                                        }
                                    case 3: {
                                            message.faqSource = $root.google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.FaqSource.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 4: {
                                            message.generativeSource = $root.google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.decode(reader, reader.uint32());
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a KnowledgeAnswer message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer} KnowledgeAnswer
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            KnowledgeAnswer.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a KnowledgeAnswer message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            KnowledgeAnswer.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                var properties = {};
                                if (message.answerText != null && message.hasOwnProperty("answerText"))
                                    if (!$util.isString(message.answerText))
                                        return "answerText: string expected";
                                if (message.faqSource != null && message.hasOwnProperty("faqSource")) {
                                    properties.source = 1;
                                    {
                                        var error = $root.google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.FaqSource.verify(message.faqSource);
                                        if (error)
                                            return "faqSource." + error;
                                    }
                                }
                                if (message.generativeSource != null && message.hasOwnProperty("generativeSource")) {
                                    if (properties.source === 1)
                                        return "source: multiple values";
                                    properties.source = 1;
                                    {
                                        var error = $root.google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.verify(message.generativeSource);
                                        if (error)
                                            return "generativeSource." + error;
                                    }
                                }
                                return null;
                            };
    
                            /**
                             * Creates a KnowledgeAnswer message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer} KnowledgeAnswer
                             */
                            KnowledgeAnswer.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer();
                                if (object.answerText != null)
                                    message.answerText = String(object.answerText);
                                if (object.faqSource != null) {
                                    if (typeof object.faqSource !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.faqSource: object expected");
                                    message.faqSource = $root.google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.FaqSource.fromObject(object.faqSource);
                                }
                                if (object.generativeSource != null) {
                                    if (typeof object.generativeSource !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.generativeSource: object expected");
                                    message.generativeSource = $root.google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.fromObject(object.generativeSource);
                                }
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a KnowledgeAnswer message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer} message KnowledgeAnswer
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            KnowledgeAnswer.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.defaults)
                                    object.answerText = "";
                                if (message.answerText != null && message.hasOwnProperty("answerText"))
                                    object.answerText = message.answerText;
                                if (message.faqSource != null && message.hasOwnProperty("faqSource")) {
                                    object.faqSource = $root.google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.FaqSource.toObject(message.faqSource, options);
                                    if (options.oneofs)
                                        object.source = "faqSource";
                                }
                                if (message.generativeSource != null && message.hasOwnProperty("generativeSource")) {
                                    object.generativeSource = $root.google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.toObject(message.generativeSource, options);
                                    if (options.oneofs)
                                        object.source = "generativeSource";
                                }
                                return object;
                            };
    
                            /**
                             * Converts this KnowledgeAnswer to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            KnowledgeAnswer.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for KnowledgeAnswer
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            KnowledgeAnswer.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer";
                            };
    
                            KnowledgeAnswer.FaqSource = (function() {
    
                                /**
                                 * Properties of a FaqSource.
                                 * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer
                                 * @interface IFaqSource
                                 * @property {string|null} [question] FaqSource question
                                 */
    
                                /**
                                 * Constructs a new FaqSource.
                                 * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer
                                 * @classdesc Represents a FaqSource.
                                 * @implements IFaqSource
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.IFaqSource=} [properties] Properties to set
                                 */
                                function FaqSource(properties) {
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * FaqSource question.
                                 * @member {string} question
                                 * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.FaqSource
                                 * @instance
                                 */
                                FaqSource.prototype.question = "";
    
                                /**
                                 * Creates a new FaqSource instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.FaqSource
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.IFaqSource=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.FaqSource} FaqSource instance
                                 */
                                FaqSource.create = function create(properties) {
                                    return new FaqSource(properties);
                                };
    
                                /**
                                 * Encodes the specified FaqSource message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.FaqSource.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.FaqSource
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.IFaqSource} message FaqSource message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                FaqSource.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.question != null && Object.hasOwnProperty.call(message, "question"))
                                        writer.uint32(/* id 2, wireType 2 =*/18).string(message.question);
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified FaqSource message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.FaqSource.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.FaqSource
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.IFaqSource} message FaqSource message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                FaqSource.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a FaqSource message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.FaqSource
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.FaqSource} FaqSource
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                FaqSource.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.FaqSource();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 2: {
                                                message.question = reader.string();
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a FaqSource message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.FaqSource
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.FaqSource} FaqSource
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                FaqSource.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a FaqSource message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.FaqSource
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                FaqSource.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.question != null && message.hasOwnProperty("question"))
                                        if (!$util.isString(message.question))
                                            return "question: string expected";
                                    return null;
                                };
    
                                /**
                                 * Creates a FaqSource message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.FaqSource
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.FaqSource} FaqSource
                                 */
                                FaqSource.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.FaqSource)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.FaqSource();
                                    if (object.question != null)
                                        message.question = String(object.question);
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a FaqSource message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.FaqSource
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.FaqSource} message FaqSource
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                FaqSource.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.defaults)
                                        object.question = "";
                                    if (message.question != null && message.hasOwnProperty("question"))
                                        object.question = message.question;
                                    return object;
                                };
    
                                /**
                                 * Converts this FaqSource to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.FaqSource
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                FaqSource.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for FaqSource
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.FaqSource
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                FaqSource.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.FaqSource";
                                };
    
                                return FaqSource;
                            })();
    
                            KnowledgeAnswer.GenerativeSource = (function() {
    
                                /**
                                 * Properties of a GenerativeSource.
                                 * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer
                                 * @interface IGenerativeSource
                                 * @property {Array.<google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.ISnippet>|null} [snippets] GenerativeSource snippets
                                 */
    
                                /**
                                 * Constructs a new GenerativeSource.
                                 * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer
                                 * @classdesc Represents a GenerativeSource.
                                 * @implements IGenerativeSource
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.IGenerativeSource=} [properties] Properties to set
                                 */
                                function GenerativeSource(properties) {
                                    this.snippets = [];
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * GenerativeSource snippets.
                                 * @member {Array.<google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.ISnippet>} snippets
                                 * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource
                                 * @instance
                                 */
                                GenerativeSource.prototype.snippets = $util.emptyArray;
    
                                /**
                                 * Creates a new GenerativeSource instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.IGenerativeSource=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource} GenerativeSource instance
                                 */
                                GenerativeSource.create = function create(properties) {
                                    return new GenerativeSource(properties);
                                };
    
                                /**
                                 * Encodes the specified GenerativeSource message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.IGenerativeSource} message GenerativeSource message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                GenerativeSource.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.snippets != null && message.snippets.length)
                                        for (var i = 0; i < message.snippets.length; ++i)
                                            $root.google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet.encode(message.snippets[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified GenerativeSource message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.IGenerativeSource} message GenerativeSource message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                GenerativeSource.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a GenerativeSource message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource} GenerativeSource
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                GenerativeSource.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                if (!(message.snippets && message.snippets.length))
                                                    message.snippets = [];
                                                message.snippets.push($root.google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet.decode(reader, reader.uint32()));
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a GenerativeSource message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource} GenerativeSource
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                GenerativeSource.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a GenerativeSource message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                GenerativeSource.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.snippets != null && message.hasOwnProperty("snippets")) {
                                        if (!Array.isArray(message.snippets))
                                            return "snippets: array expected";
                                        for (var i = 0; i < message.snippets.length; ++i) {
                                            var error = $root.google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet.verify(message.snippets[i]);
                                            if (error)
                                                return "snippets." + error;
                                        }
                                    }
                                    return null;
                                };
    
                                /**
                                 * Creates a GenerativeSource message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource} GenerativeSource
                                 */
                                GenerativeSource.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource();
                                    if (object.snippets) {
                                        if (!Array.isArray(object.snippets))
                                            throw TypeError(".google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.snippets: array expected");
                                        message.snippets = [];
                                        for (var i = 0; i < object.snippets.length; ++i) {
                                            if (typeof object.snippets[i] !== "object")
                                                throw TypeError(".google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.snippets: object expected");
                                            message.snippets[i] = $root.google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet.fromObject(object.snippets[i]);
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a GenerativeSource message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource} message GenerativeSource
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                GenerativeSource.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.arrays || options.defaults)
                                        object.snippets = [];
                                    if (message.snippets && message.snippets.length) {
                                        object.snippets = [];
                                        for (var j = 0; j < message.snippets.length; ++j)
                                            object.snippets[j] = $root.google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet.toObject(message.snippets[j], options);
                                    }
                                    return object;
                                };
    
                                /**
                                 * Converts this GenerativeSource to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                GenerativeSource.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for GenerativeSource
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                GenerativeSource.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource";
                                };
    
                                GenerativeSource.Snippet = (function() {
    
                                    /**
                                     * Properties of a Snippet.
                                     * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource
                                     * @interface ISnippet
                                     * @property {string|null} [uri] Snippet uri
                                     * @property {string|null} [text] Snippet text
                                     * @property {string|null} [title] Snippet title
                                     * @property {google.protobuf.IStruct|null} [metadata] Snippet metadata
                                     */
    
                                    /**
                                     * Constructs a new Snippet.
                                     * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource
                                     * @classdesc Represents a Snippet.
                                     * @implements ISnippet
                                     * @constructor
                                     * @param {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.ISnippet=} [properties] Properties to set
                                     */
                                    function Snippet(properties) {
                                        if (properties)
                                            for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                                if (properties[keys[i]] != null)
                                                    this[keys[i]] = properties[keys[i]];
                                    }
    
                                    /**
                                     * Snippet uri.
                                     * @member {string} uri
                                     * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet
                                     * @instance
                                     */
                                    Snippet.prototype.uri = "";
    
                                    /**
                                     * Snippet text.
                                     * @member {string} text
                                     * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet
                                     * @instance
                                     */
                                    Snippet.prototype.text = "";
    
                                    /**
                                     * Snippet title.
                                     * @member {string} title
                                     * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet
                                     * @instance
                                     */
                                    Snippet.prototype.title = "";
    
                                    /**
                                     * Snippet metadata.
                                     * @member {google.protobuf.IStruct|null|undefined} metadata
                                     * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet
                                     * @instance
                                     */
                                    Snippet.prototype.metadata = null;
    
                                    /**
                                     * Creates a new Snippet instance using the specified properties.
                                     * @function create
                                     * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet
                                     * @static
                                     * @param {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.ISnippet=} [properties] Properties to set
                                     * @returns {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet} Snippet instance
                                     */
                                    Snippet.create = function create(properties) {
                                        return new Snippet(properties);
                                    };
    
                                    /**
                                     * Encodes the specified Snippet message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet.verify|verify} messages.
                                     * @function encode
                                     * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet
                                     * @static
                                     * @param {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.ISnippet} message Snippet message or plain object to encode
                                     * @param {$protobuf.Writer} [writer] Writer to encode to
                                     * @returns {$protobuf.Writer} Writer
                                     */
                                    Snippet.encode = function encode(message, writer) {
                                        if (!writer)
                                            writer = $Writer.create();
                                        if (message.uri != null && Object.hasOwnProperty.call(message, "uri"))
                                            writer.uint32(/* id 2, wireType 2 =*/18).string(message.uri);
                                        if (message.text != null && Object.hasOwnProperty.call(message, "text"))
                                            writer.uint32(/* id 3, wireType 2 =*/26).string(message.text);
                                        if (message.title != null && Object.hasOwnProperty.call(message, "title"))
                                            writer.uint32(/* id 4, wireType 2 =*/34).string(message.title);
                                        if (message.metadata != null && Object.hasOwnProperty.call(message, "metadata"))
                                            $root.google.protobuf.Struct.encode(message.metadata, writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                                        return writer;
                                    };
    
                                    /**
                                     * Encodes the specified Snippet message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet.verify|verify} messages.
                                     * @function encodeDelimited
                                     * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet
                                     * @static
                                     * @param {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.ISnippet} message Snippet message or plain object to encode
                                     * @param {$protobuf.Writer} [writer] Writer to encode to
                                     * @returns {$protobuf.Writer} Writer
                                     */
                                    Snippet.encodeDelimited = function encodeDelimited(message, writer) {
                                        return this.encode(message, writer).ldelim();
                                    };
    
                                    /**
                                     * Decodes a Snippet message from the specified reader or buffer.
                                     * @function decode
                                     * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet
                                     * @static
                                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                     * @param {number} [length] Message length if known beforehand
                                     * @returns {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet} Snippet
                                     * @throws {Error} If the payload is not a reader or valid buffer
                                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                     */
                                    Snippet.decode = function decode(reader, length) {
                                        if (!(reader instanceof $Reader))
                                            reader = $Reader.create(reader);
                                        var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet();
                                        while (reader.pos < end) {
                                            var tag = reader.uint32();
                                            switch (tag >>> 3) {
                                            case 2: {
                                                    message.uri = reader.string();
                                                    break;
                                                }
                                            case 3: {
                                                    message.text = reader.string();
                                                    break;
                                                }
                                            case 4: {
                                                    message.title = reader.string();
                                                    break;
                                                }
                                            case 5: {
                                                    message.metadata = $root.google.protobuf.Struct.decode(reader, reader.uint32());
                                                    break;
                                                }
                                            default:
                                                reader.skipType(tag & 7);
                                                break;
                                            }
                                        }
                                        return message;
                                    };
    
                                    /**
                                     * Decodes a Snippet message from the specified reader or buffer, length delimited.
                                     * @function decodeDelimited
                                     * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet
                                     * @static
                                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                     * @returns {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet} Snippet
                                     * @throws {Error} If the payload is not a reader or valid buffer
                                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                     */
                                    Snippet.decodeDelimited = function decodeDelimited(reader) {
                                        if (!(reader instanceof $Reader))
                                            reader = new $Reader(reader);
                                        return this.decode(reader, reader.uint32());
                                    };
    
                                    /**
                                     * Verifies a Snippet message.
                                     * @function verify
                                     * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet
                                     * @static
                                     * @param {Object.<string,*>} message Plain object to verify
                                     * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                     */
                                    Snippet.verify = function verify(message) {
                                        if (typeof message !== "object" || message === null)
                                            return "object expected";
                                        if (message.uri != null && message.hasOwnProperty("uri"))
                                            if (!$util.isString(message.uri))
                                                return "uri: string expected";
                                        if (message.text != null && message.hasOwnProperty("text"))
                                            if (!$util.isString(message.text))
                                                return "text: string expected";
                                        if (message.title != null && message.hasOwnProperty("title"))
                                            if (!$util.isString(message.title))
                                                return "title: string expected";
                                        if (message.metadata != null && message.hasOwnProperty("metadata")) {
                                            var error = $root.google.protobuf.Struct.verify(message.metadata);
                                            if (error)
                                                return "metadata." + error;
                                        }
                                        return null;
                                    };
    
                                    /**
                                     * Creates a Snippet message from a plain object. Also converts values to their respective internal types.
                                     * @function fromObject
                                     * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet
                                     * @static
                                     * @param {Object.<string,*>} object Plain object
                                     * @returns {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet} Snippet
                                     */
                                    Snippet.fromObject = function fromObject(object) {
                                        if (object instanceof $root.google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet)
                                            return object;
                                        var message = new $root.google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet();
                                        if (object.uri != null)
                                            message.uri = String(object.uri);
                                        if (object.text != null)
                                            message.text = String(object.text);
                                        if (object.title != null)
                                            message.title = String(object.title);
                                        if (object.metadata != null) {
                                            if (typeof object.metadata !== "object")
                                                throw TypeError(".google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet.metadata: object expected");
                                            message.metadata = $root.google.protobuf.Struct.fromObject(object.metadata);
                                        }
                                        return message;
                                    };
    
                                    /**
                                     * Creates a plain object from a Snippet message. Also converts values to other types if specified.
                                     * @function toObject
                                     * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet
                                     * @static
                                     * @param {google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet} message Snippet
                                     * @param {$protobuf.IConversionOptions} [options] Conversion options
                                     * @returns {Object.<string,*>} Plain object
                                     */
                                    Snippet.toObject = function toObject(message, options) {
                                        if (!options)
                                            options = {};
                                        var object = {};
                                        if (options.defaults) {
                                            object.uri = "";
                                            object.text = "";
                                            object.title = "";
                                            object.metadata = null;
                                        }
                                        if (message.uri != null && message.hasOwnProperty("uri"))
                                            object.uri = message.uri;
                                        if (message.text != null && message.hasOwnProperty("text"))
                                            object.text = message.text;
                                        if (message.title != null && message.hasOwnProperty("title"))
                                            object.title = message.title;
                                        if (message.metadata != null && message.hasOwnProperty("metadata"))
                                            object.metadata = $root.google.protobuf.Struct.toObject(message.metadata, options);
                                        return object;
                                    };
    
                                    /**
                                     * Converts this Snippet to JSON.
                                     * @function toJSON
                                     * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet
                                     * @instance
                                     * @returns {Object.<string,*>} JSON object
                                     */
                                    Snippet.prototype.toJSON = function toJSON() {
                                        return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                    };
    
                                    /**
                                     * Gets the default type url for Snippet
                                     * @function getTypeUrl
                                     * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet
                                     * @static
                                     * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                     * @returns {string} The default type url
                                     */
                                    Snippet.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                        if (typeUrlPrefix === undefined) {
                                            typeUrlPrefix = "type.googleapis.com";
                                        }
                                        return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.KnowledgeAssistAnswer.KnowledgeAnswer.GenerativeSource.Snippet";
                                    };
    
                                    return Snippet;
                                })();
    
                                return GenerativeSource;
                            })();
    
                            return KnowledgeAnswer;
                        })();
    
                        return KnowledgeAssistAnswer;
                    })();
    
                    v2beta1.SpeechContext = (function() {
    
                        /**
                         * Properties of a SpeechContext.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ISpeechContext
                         * @property {Array.<string>|null} [phrases] SpeechContext phrases
                         * @property {number|null} [boost] SpeechContext boost
                         */
    
                        /**
                         * Constructs a new SpeechContext.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a SpeechContext.
                         * @implements ISpeechContext
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ISpeechContext=} [properties] Properties to set
                         */
                        function SpeechContext(properties) {
                            this.phrases = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SpeechContext phrases.
                         * @member {Array.<string>} phrases
                         * @memberof google.cloud.dialogflow.v2beta1.SpeechContext
                         * @instance
                         */
                        SpeechContext.prototype.phrases = $util.emptyArray;
    
                        /**
                         * SpeechContext boost.
                         * @member {number} boost
                         * @memberof google.cloud.dialogflow.v2beta1.SpeechContext
                         * @instance
                         */
                        SpeechContext.prototype.boost = 0;
    
                        /**
                         * Creates a new SpeechContext instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.SpeechContext
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISpeechContext=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.SpeechContext} SpeechContext instance
                         */
                        SpeechContext.create = function create(properties) {
                            return new SpeechContext(properties);
                        };
    
                        /**
                         * Encodes the specified SpeechContext message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SpeechContext.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.SpeechContext
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISpeechContext} message SpeechContext message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SpeechContext.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.phrases != null && message.phrases.length)
                                for (var i = 0; i < message.phrases.length; ++i)
                                    writer.uint32(/* id 1, wireType 2 =*/10).string(message.phrases[i]);
                            if (message.boost != null && Object.hasOwnProperty.call(message, "boost"))
                                writer.uint32(/* id 2, wireType 5 =*/21).float(message.boost);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SpeechContext message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SpeechContext.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SpeechContext
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISpeechContext} message SpeechContext message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SpeechContext.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SpeechContext message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.SpeechContext
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.SpeechContext} SpeechContext
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SpeechContext.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.SpeechContext();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.phrases && message.phrases.length))
                                            message.phrases = [];
                                        message.phrases.push(reader.string());
                                        break;
                                    }
                                case 2: {
                                        message.boost = reader.float();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SpeechContext message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SpeechContext
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.SpeechContext} SpeechContext
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SpeechContext.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SpeechContext message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.SpeechContext
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SpeechContext.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.phrases != null && message.hasOwnProperty("phrases")) {
                                if (!Array.isArray(message.phrases))
                                    return "phrases: array expected";
                                for (var i = 0; i < message.phrases.length; ++i)
                                    if (!$util.isString(message.phrases[i]))
                                        return "phrases: string[] expected";
                            }
                            if (message.boost != null && message.hasOwnProperty("boost"))
                                if (typeof message.boost !== "number")
                                    return "boost: number expected";
                            return null;
                        };
    
                        /**
                         * Creates a SpeechContext message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.SpeechContext
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.SpeechContext} SpeechContext
                         */
                        SpeechContext.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.SpeechContext)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.SpeechContext();
                            if (object.phrases) {
                                if (!Array.isArray(object.phrases))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.SpeechContext.phrases: array expected");
                                message.phrases = [];
                                for (var i = 0; i < object.phrases.length; ++i)
                                    message.phrases[i] = String(object.phrases[i]);
                            }
                            if (object.boost != null)
                                message.boost = Number(object.boost);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SpeechContext message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.SpeechContext
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.SpeechContext} message SpeechContext
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SpeechContext.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.phrases = [];
                            if (options.defaults)
                                object.boost = 0;
                            if (message.phrases && message.phrases.length) {
                                object.phrases = [];
                                for (var j = 0; j < message.phrases.length; ++j)
                                    object.phrases[j] = message.phrases[j];
                            }
                            if (message.boost != null && message.hasOwnProperty("boost"))
                                object.boost = options.json && !isFinite(message.boost) ? String(message.boost) : message.boost;
                            return object;
                        };
    
                        /**
                         * Converts this SpeechContext to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.SpeechContext
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SpeechContext.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SpeechContext
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.SpeechContext
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SpeechContext.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.SpeechContext";
                        };
    
                        return SpeechContext;
                    })();
    
                    v2beta1.SpeechWordInfo = (function() {
    
                        /**
                         * Properties of a SpeechWordInfo.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ISpeechWordInfo
                         * @property {string|null} [word] SpeechWordInfo word
                         * @property {google.protobuf.IDuration|null} [startOffset] SpeechWordInfo startOffset
                         * @property {google.protobuf.IDuration|null} [endOffset] SpeechWordInfo endOffset
                         * @property {number|null} [confidence] SpeechWordInfo confidence
                         */
    
                        /**
                         * Constructs a new SpeechWordInfo.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a SpeechWordInfo.
                         * @implements ISpeechWordInfo
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ISpeechWordInfo=} [properties] Properties to set
                         */
                        function SpeechWordInfo(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SpeechWordInfo word.
                         * @member {string} word
                         * @memberof google.cloud.dialogflow.v2beta1.SpeechWordInfo
                         * @instance
                         */
                        SpeechWordInfo.prototype.word = "";
    
                        /**
                         * SpeechWordInfo startOffset.
                         * @member {google.protobuf.IDuration|null|undefined} startOffset
                         * @memberof google.cloud.dialogflow.v2beta1.SpeechWordInfo
                         * @instance
                         */
                        SpeechWordInfo.prototype.startOffset = null;
    
                        /**
                         * SpeechWordInfo endOffset.
                         * @member {google.protobuf.IDuration|null|undefined} endOffset
                         * @memberof google.cloud.dialogflow.v2beta1.SpeechWordInfo
                         * @instance
                         */
                        SpeechWordInfo.prototype.endOffset = null;
    
                        /**
                         * SpeechWordInfo confidence.
                         * @member {number} confidence
                         * @memberof google.cloud.dialogflow.v2beta1.SpeechWordInfo
                         * @instance
                         */
                        SpeechWordInfo.prototype.confidence = 0;
    
                        /**
                         * Creates a new SpeechWordInfo instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.SpeechWordInfo
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISpeechWordInfo=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.SpeechWordInfo} SpeechWordInfo instance
                         */
                        SpeechWordInfo.create = function create(properties) {
                            return new SpeechWordInfo(properties);
                        };
    
                        /**
                         * Encodes the specified SpeechWordInfo message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SpeechWordInfo.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.SpeechWordInfo
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISpeechWordInfo} message SpeechWordInfo message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SpeechWordInfo.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.startOffset != null && Object.hasOwnProperty.call(message, "startOffset"))
                                $root.google.protobuf.Duration.encode(message.startOffset, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.endOffset != null && Object.hasOwnProperty.call(message, "endOffset"))
                                $root.google.protobuf.Duration.encode(message.endOffset, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.word != null && Object.hasOwnProperty.call(message, "word"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.word);
                            if (message.confidence != null && Object.hasOwnProperty.call(message, "confidence"))
                                writer.uint32(/* id 4, wireType 5 =*/37).float(message.confidence);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SpeechWordInfo message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SpeechWordInfo.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SpeechWordInfo
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISpeechWordInfo} message SpeechWordInfo message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SpeechWordInfo.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SpeechWordInfo message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.SpeechWordInfo
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.SpeechWordInfo} SpeechWordInfo
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SpeechWordInfo.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.SpeechWordInfo();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 3: {
                                        message.word = reader.string();
                                        break;
                                    }
                                case 1: {
                                        message.startOffset = $root.google.protobuf.Duration.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.endOffset = $root.google.protobuf.Duration.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 4: {
                                        message.confidence = reader.float();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SpeechWordInfo message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SpeechWordInfo
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.SpeechWordInfo} SpeechWordInfo
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SpeechWordInfo.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SpeechWordInfo message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.SpeechWordInfo
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SpeechWordInfo.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.word != null && message.hasOwnProperty("word"))
                                if (!$util.isString(message.word))
                                    return "word: string expected";
                            if (message.startOffset != null && message.hasOwnProperty("startOffset")) {
                                var error = $root.google.protobuf.Duration.verify(message.startOffset);
                                if (error)
                                    return "startOffset." + error;
                            }
                            if (message.endOffset != null && message.hasOwnProperty("endOffset")) {
                                var error = $root.google.protobuf.Duration.verify(message.endOffset);
                                if (error)
                                    return "endOffset." + error;
                            }
                            if (message.confidence != null && message.hasOwnProperty("confidence"))
                                if (typeof message.confidence !== "number")
                                    return "confidence: number expected";
                            return null;
                        };
    
                        /**
                         * Creates a SpeechWordInfo message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.SpeechWordInfo
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.SpeechWordInfo} SpeechWordInfo
                         */
                        SpeechWordInfo.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.SpeechWordInfo)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.SpeechWordInfo();
                            if (object.word != null)
                                message.word = String(object.word);
                            if (object.startOffset != null) {
                                if (typeof object.startOffset !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.SpeechWordInfo.startOffset: object expected");
                                message.startOffset = $root.google.protobuf.Duration.fromObject(object.startOffset);
                            }
                            if (object.endOffset != null) {
                                if (typeof object.endOffset !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.SpeechWordInfo.endOffset: object expected");
                                message.endOffset = $root.google.protobuf.Duration.fromObject(object.endOffset);
                            }
                            if (object.confidence != null)
                                message.confidence = Number(object.confidence);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SpeechWordInfo message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.SpeechWordInfo
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.SpeechWordInfo} message SpeechWordInfo
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SpeechWordInfo.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.startOffset = null;
                                object.endOffset = null;
                                object.word = "";
                                object.confidence = 0;
                            }
                            if (message.startOffset != null && message.hasOwnProperty("startOffset"))
                                object.startOffset = $root.google.protobuf.Duration.toObject(message.startOffset, options);
                            if (message.endOffset != null && message.hasOwnProperty("endOffset"))
                                object.endOffset = $root.google.protobuf.Duration.toObject(message.endOffset, options);
                            if (message.word != null && message.hasOwnProperty("word"))
                                object.word = message.word;
                            if (message.confidence != null && message.hasOwnProperty("confidence"))
                                object.confidence = options.json && !isFinite(message.confidence) ? String(message.confidence) : message.confidence;
                            return object;
                        };
    
                        /**
                         * Converts this SpeechWordInfo to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.SpeechWordInfo
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SpeechWordInfo.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SpeechWordInfo
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.SpeechWordInfo
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SpeechWordInfo.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.SpeechWordInfo";
                        };
    
                        return SpeechWordInfo;
                    })();
    
                    v2beta1.BargeInConfig = (function() {
    
                        /**
                         * Properties of a BargeInConfig.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IBargeInConfig
                         * @property {google.protobuf.IDuration|null} [noBargeInDuration] BargeInConfig noBargeInDuration
                         * @property {google.protobuf.IDuration|null} [totalDuration] BargeInConfig totalDuration
                         */
    
                        /**
                         * Constructs a new BargeInConfig.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a BargeInConfig.
                         * @implements IBargeInConfig
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IBargeInConfig=} [properties] Properties to set
                         */
                        function BargeInConfig(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * BargeInConfig noBargeInDuration.
                         * @member {google.protobuf.IDuration|null|undefined} noBargeInDuration
                         * @memberof google.cloud.dialogflow.v2beta1.BargeInConfig
                         * @instance
                         */
                        BargeInConfig.prototype.noBargeInDuration = null;
    
                        /**
                         * BargeInConfig totalDuration.
                         * @member {google.protobuf.IDuration|null|undefined} totalDuration
                         * @memberof google.cloud.dialogflow.v2beta1.BargeInConfig
                         * @instance
                         */
                        BargeInConfig.prototype.totalDuration = null;
    
                        /**
                         * Creates a new BargeInConfig instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.BargeInConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IBargeInConfig=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.BargeInConfig} BargeInConfig instance
                         */
                        BargeInConfig.create = function create(properties) {
                            return new BargeInConfig(properties);
                        };
    
                        /**
                         * Encodes the specified BargeInConfig message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.BargeInConfig.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.BargeInConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IBargeInConfig} message BargeInConfig message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        BargeInConfig.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.noBargeInDuration != null && Object.hasOwnProperty.call(message, "noBargeInDuration"))
                                $root.google.protobuf.Duration.encode(message.noBargeInDuration, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.totalDuration != null && Object.hasOwnProperty.call(message, "totalDuration"))
                                $root.google.protobuf.Duration.encode(message.totalDuration, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified BargeInConfig message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.BargeInConfig.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.BargeInConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IBargeInConfig} message BargeInConfig message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        BargeInConfig.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a BargeInConfig message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.BargeInConfig
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.BargeInConfig} BargeInConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        BargeInConfig.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.BargeInConfig();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.noBargeInDuration = $root.google.protobuf.Duration.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.totalDuration = $root.google.protobuf.Duration.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a BargeInConfig message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.BargeInConfig
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.BargeInConfig} BargeInConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        BargeInConfig.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a BargeInConfig message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.BargeInConfig
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        BargeInConfig.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.noBargeInDuration != null && message.hasOwnProperty("noBargeInDuration")) {
                                var error = $root.google.protobuf.Duration.verify(message.noBargeInDuration);
                                if (error)
                                    return "noBargeInDuration." + error;
                            }
                            if (message.totalDuration != null && message.hasOwnProperty("totalDuration")) {
                                var error = $root.google.protobuf.Duration.verify(message.totalDuration);
                                if (error)
                                    return "totalDuration." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a BargeInConfig message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.BargeInConfig
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.BargeInConfig} BargeInConfig
                         */
                        BargeInConfig.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.BargeInConfig)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.BargeInConfig();
                            if (object.noBargeInDuration != null) {
                                if (typeof object.noBargeInDuration !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.BargeInConfig.noBargeInDuration: object expected");
                                message.noBargeInDuration = $root.google.protobuf.Duration.fromObject(object.noBargeInDuration);
                            }
                            if (object.totalDuration != null) {
                                if (typeof object.totalDuration !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.BargeInConfig.totalDuration: object expected");
                                message.totalDuration = $root.google.protobuf.Duration.fromObject(object.totalDuration);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a BargeInConfig message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.BargeInConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.BargeInConfig} message BargeInConfig
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        BargeInConfig.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.noBargeInDuration = null;
                                object.totalDuration = null;
                            }
                            if (message.noBargeInDuration != null && message.hasOwnProperty("noBargeInDuration"))
                                object.noBargeInDuration = $root.google.protobuf.Duration.toObject(message.noBargeInDuration, options);
                            if (message.totalDuration != null && message.hasOwnProperty("totalDuration"))
                                object.totalDuration = $root.google.protobuf.Duration.toObject(message.totalDuration, options);
                            return object;
                        };
    
                        /**
                         * Converts this BargeInConfig to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.BargeInConfig
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        BargeInConfig.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for BargeInConfig
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.BargeInConfig
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        BargeInConfig.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.BargeInConfig";
                        };
    
                        return BargeInConfig;
                    })();
    
                    v2beta1.InputAudioConfig = (function() {
    
                        /**
                         * Properties of an InputAudioConfig.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IInputAudioConfig
                         * @property {google.cloud.dialogflow.v2beta1.AudioEncoding|null} [audioEncoding] InputAudioConfig audioEncoding
                         * @property {number|null} [sampleRateHertz] InputAudioConfig sampleRateHertz
                         * @property {string|null} [languageCode] InputAudioConfig languageCode
                         * @property {boolean|null} [enableWordInfo] InputAudioConfig enableWordInfo
                         * @property {Array.<string>|null} [phraseHints] InputAudioConfig phraseHints
                         * @property {Array.<google.cloud.dialogflow.v2beta1.ISpeechContext>|null} [speechContexts] InputAudioConfig speechContexts
                         * @property {string|null} [model] InputAudioConfig model
                         * @property {google.cloud.dialogflow.v2beta1.SpeechModelVariant|null} [modelVariant] InputAudioConfig modelVariant
                         * @property {boolean|null} [singleUtterance] InputAudioConfig singleUtterance
                         * @property {boolean|null} [disableNoSpeechRecognizedEvent] InputAudioConfig disableNoSpeechRecognizedEvent
                         * @property {google.cloud.dialogflow.v2beta1.IBargeInConfig|null} [bargeInConfig] InputAudioConfig bargeInConfig
                         * @property {boolean|null} [enableAutomaticPunctuation] InputAudioConfig enableAutomaticPunctuation
                         * @property {google.protobuf.IDuration|null} [defaultNoSpeechTimeout] InputAudioConfig defaultNoSpeechTimeout
                         * @property {Array.<string>|null} [phraseSets] InputAudioConfig phraseSets
                         * @property {boolean|null} [optOutConformerModelMigration] InputAudioConfig optOutConformerModelMigration
                         */
    
                        /**
                         * Constructs a new InputAudioConfig.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an InputAudioConfig.
                         * @implements IInputAudioConfig
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IInputAudioConfig=} [properties] Properties to set
                         */
                        function InputAudioConfig(properties) {
                            this.phraseHints = [];
                            this.speechContexts = [];
                            this.phraseSets = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * InputAudioConfig audioEncoding.
                         * @member {google.cloud.dialogflow.v2beta1.AudioEncoding} audioEncoding
                         * @memberof google.cloud.dialogflow.v2beta1.InputAudioConfig
                         * @instance
                         */
                        InputAudioConfig.prototype.audioEncoding = 0;
    
                        /**
                         * InputAudioConfig sampleRateHertz.
                         * @member {number} sampleRateHertz
                         * @memberof google.cloud.dialogflow.v2beta1.InputAudioConfig
                         * @instance
                         */
                        InputAudioConfig.prototype.sampleRateHertz = 0;
    
                        /**
                         * InputAudioConfig languageCode.
                         * @member {string} languageCode
                         * @memberof google.cloud.dialogflow.v2beta1.InputAudioConfig
                         * @instance
                         */
                        InputAudioConfig.prototype.languageCode = "";
    
                        /**
                         * InputAudioConfig enableWordInfo.
                         * @member {boolean} enableWordInfo
                         * @memberof google.cloud.dialogflow.v2beta1.InputAudioConfig
                         * @instance
                         */
                        InputAudioConfig.prototype.enableWordInfo = false;
    
                        /**
                         * InputAudioConfig phraseHints.
                         * @member {Array.<string>} phraseHints
                         * @memberof google.cloud.dialogflow.v2beta1.InputAudioConfig
                         * @instance
                         */
                        InputAudioConfig.prototype.phraseHints = $util.emptyArray;
    
                        /**
                         * InputAudioConfig speechContexts.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.ISpeechContext>} speechContexts
                         * @memberof google.cloud.dialogflow.v2beta1.InputAudioConfig
                         * @instance
                         */
                        InputAudioConfig.prototype.speechContexts = $util.emptyArray;
    
                        /**
                         * InputAudioConfig model.
                         * @member {string} model
                         * @memberof google.cloud.dialogflow.v2beta1.InputAudioConfig
                         * @instance
                         */
                        InputAudioConfig.prototype.model = "";
    
                        /**
                         * InputAudioConfig modelVariant.
                         * @member {google.cloud.dialogflow.v2beta1.SpeechModelVariant} modelVariant
                         * @memberof google.cloud.dialogflow.v2beta1.InputAudioConfig
                         * @instance
                         */
                        InputAudioConfig.prototype.modelVariant = 0;
    
                        /**
                         * InputAudioConfig singleUtterance.
                         * @member {boolean} singleUtterance
                         * @memberof google.cloud.dialogflow.v2beta1.InputAudioConfig
                         * @instance
                         */
                        InputAudioConfig.prototype.singleUtterance = false;
    
                        /**
                         * InputAudioConfig disableNoSpeechRecognizedEvent.
                         * @member {boolean} disableNoSpeechRecognizedEvent
                         * @memberof google.cloud.dialogflow.v2beta1.InputAudioConfig
                         * @instance
                         */
                        InputAudioConfig.prototype.disableNoSpeechRecognizedEvent = false;
    
                        /**
                         * InputAudioConfig bargeInConfig.
                         * @member {google.cloud.dialogflow.v2beta1.IBargeInConfig|null|undefined} bargeInConfig
                         * @memberof google.cloud.dialogflow.v2beta1.InputAudioConfig
                         * @instance
                         */
                        InputAudioConfig.prototype.bargeInConfig = null;
    
                        /**
                         * InputAudioConfig enableAutomaticPunctuation.
                         * @member {boolean} enableAutomaticPunctuation
                         * @memberof google.cloud.dialogflow.v2beta1.InputAudioConfig
                         * @instance
                         */
                        InputAudioConfig.prototype.enableAutomaticPunctuation = false;
    
                        /**
                         * InputAudioConfig defaultNoSpeechTimeout.
                         * @member {google.protobuf.IDuration|null|undefined} defaultNoSpeechTimeout
                         * @memberof google.cloud.dialogflow.v2beta1.InputAudioConfig
                         * @instance
                         */
                        InputAudioConfig.prototype.defaultNoSpeechTimeout = null;
    
                        /**
                         * InputAudioConfig phraseSets.
                         * @member {Array.<string>} phraseSets
                         * @memberof google.cloud.dialogflow.v2beta1.InputAudioConfig
                         * @instance
                         */
                        InputAudioConfig.prototype.phraseSets = $util.emptyArray;
    
                        /**
                         * InputAudioConfig optOutConformerModelMigration.
                         * @member {boolean} optOutConformerModelMigration
                         * @memberof google.cloud.dialogflow.v2beta1.InputAudioConfig
                         * @instance
                         */
                        InputAudioConfig.prototype.optOutConformerModelMigration = false;
    
                        /**
                         * Creates a new InputAudioConfig instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.InputAudioConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IInputAudioConfig=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.InputAudioConfig} InputAudioConfig instance
                         */
                        InputAudioConfig.create = function create(properties) {
                            return new InputAudioConfig(properties);
                        };
    
                        /**
                         * Encodes the specified InputAudioConfig message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.InputAudioConfig.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.InputAudioConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IInputAudioConfig} message InputAudioConfig message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        InputAudioConfig.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.audioEncoding != null && Object.hasOwnProperty.call(message, "audioEncoding"))
                                writer.uint32(/* id 1, wireType 0 =*/8).int32(message.audioEncoding);
                            if (message.sampleRateHertz != null && Object.hasOwnProperty.call(message, "sampleRateHertz"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.sampleRateHertz);
                            if (message.languageCode != null && Object.hasOwnProperty.call(message, "languageCode"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.languageCode);
                            if (message.phraseHints != null && message.phraseHints.length)
                                for (var i = 0; i < message.phraseHints.length; ++i)
                                    writer.uint32(/* id 4, wireType 2 =*/34).string(message.phraseHints[i]);
                            if (message.model != null && Object.hasOwnProperty.call(message, "model"))
                                writer.uint32(/* id 7, wireType 2 =*/58).string(message.model);
                            if (message.singleUtterance != null && Object.hasOwnProperty.call(message, "singleUtterance"))
                                writer.uint32(/* id 8, wireType 0 =*/64).bool(message.singleUtterance);
                            if (message.modelVariant != null && Object.hasOwnProperty.call(message, "modelVariant"))
                                writer.uint32(/* id 10, wireType 0 =*/80).int32(message.modelVariant);
                            if (message.speechContexts != null && message.speechContexts.length)
                                for (var i = 0; i < message.speechContexts.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.SpeechContext.encode(message.speechContexts[i], writer.uint32(/* id 11, wireType 2 =*/90).fork()).ldelim();
                            if (message.enableWordInfo != null && Object.hasOwnProperty.call(message, "enableWordInfo"))
                                writer.uint32(/* id 13, wireType 0 =*/104).bool(message.enableWordInfo);
                            if (message.disableNoSpeechRecognizedEvent != null && Object.hasOwnProperty.call(message, "disableNoSpeechRecognizedEvent"))
                                writer.uint32(/* id 14, wireType 0 =*/112).bool(message.disableNoSpeechRecognizedEvent);
                            if (message.bargeInConfig != null && Object.hasOwnProperty.call(message, "bargeInConfig"))
                                $root.google.cloud.dialogflow.v2beta1.BargeInConfig.encode(message.bargeInConfig, writer.uint32(/* id 15, wireType 2 =*/122).fork()).ldelim();
                            if (message.enableAutomaticPunctuation != null && Object.hasOwnProperty.call(message, "enableAutomaticPunctuation"))
                                writer.uint32(/* id 17, wireType 0 =*/136).bool(message.enableAutomaticPunctuation);
                            if (message.defaultNoSpeechTimeout != null && Object.hasOwnProperty.call(message, "defaultNoSpeechTimeout"))
                                $root.google.protobuf.Duration.encode(message.defaultNoSpeechTimeout, writer.uint32(/* id 18, wireType 2 =*/146).fork()).ldelim();
                            if (message.phraseSets != null && message.phraseSets.length)
                                for (var i = 0; i < message.phraseSets.length; ++i)
                                    writer.uint32(/* id 20, wireType 2 =*/162).string(message.phraseSets[i]);
                            if (message.optOutConformerModelMigration != null && Object.hasOwnProperty.call(message, "optOutConformerModelMigration"))
                                writer.uint32(/* id 26, wireType 0 =*/208).bool(message.optOutConformerModelMigration);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified InputAudioConfig message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.InputAudioConfig.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.InputAudioConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IInputAudioConfig} message InputAudioConfig message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        InputAudioConfig.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an InputAudioConfig message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.InputAudioConfig
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.InputAudioConfig} InputAudioConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        InputAudioConfig.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.InputAudioConfig();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.audioEncoding = reader.int32();
                                        break;
                                    }
                                case 2: {
                                        message.sampleRateHertz = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.languageCode = reader.string();
                                        break;
                                    }
                                case 13: {
                                        message.enableWordInfo = reader.bool();
                                        break;
                                    }
                                case 4: {
                                        if (!(message.phraseHints && message.phraseHints.length))
                                            message.phraseHints = [];
                                        message.phraseHints.push(reader.string());
                                        break;
                                    }
                                case 11: {
                                        if (!(message.speechContexts && message.speechContexts.length))
                                            message.speechContexts = [];
                                        message.speechContexts.push($root.google.cloud.dialogflow.v2beta1.SpeechContext.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 7: {
                                        message.model = reader.string();
                                        break;
                                    }
                                case 10: {
                                        message.modelVariant = reader.int32();
                                        break;
                                    }
                                case 8: {
                                        message.singleUtterance = reader.bool();
                                        break;
                                    }
                                case 14: {
                                        message.disableNoSpeechRecognizedEvent = reader.bool();
                                        break;
                                    }
                                case 15: {
                                        message.bargeInConfig = $root.google.cloud.dialogflow.v2beta1.BargeInConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 17: {
                                        message.enableAutomaticPunctuation = reader.bool();
                                        break;
                                    }
                                case 18: {
                                        message.defaultNoSpeechTimeout = $root.google.protobuf.Duration.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 20: {
                                        if (!(message.phraseSets && message.phraseSets.length))
                                            message.phraseSets = [];
                                        message.phraseSets.push(reader.string());
                                        break;
                                    }
                                case 26: {
                                        message.optOutConformerModelMigration = reader.bool();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an InputAudioConfig message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.InputAudioConfig
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.InputAudioConfig} InputAudioConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        InputAudioConfig.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an InputAudioConfig message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.InputAudioConfig
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        InputAudioConfig.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.audioEncoding != null && message.hasOwnProperty("audioEncoding"))
                                switch (message.audioEncoding) {
                                default:
                                    return "audioEncoding: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                case 4:
                                case 5:
                                case 6:
                                case 7:
                                case 8:
                                    break;
                                }
                            if (message.sampleRateHertz != null && message.hasOwnProperty("sampleRateHertz"))
                                if (!$util.isInteger(message.sampleRateHertz))
                                    return "sampleRateHertz: integer expected";
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                if (!$util.isString(message.languageCode))
                                    return "languageCode: string expected";
                            if (message.enableWordInfo != null && message.hasOwnProperty("enableWordInfo"))
                                if (typeof message.enableWordInfo !== "boolean")
                                    return "enableWordInfo: boolean expected";
                            if (message.phraseHints != null && message.hasOwnProperty("phraseHints")) {
                                if (!Array.isArray(message.phraseHints))
                                    return "phraseHints: array expected";
                                for (var i = 0; i < message.phraseHints.length; ++i)
                                    if (!$util.isString(message.phraseHints[i]))
                                        return "phraseHints: string[] expected";
                            }
                            if (message.speechContexts != null && message.hasOwnProperty("speechContexts")) {
                                if (!Array.isArray(message.speechContexts))
                                    return "speechContexts: array expected";
                                for (var i = 0; i < message.speechContexts.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.SpeechContext.verify(message.speechContexts[i]);
                                    if (error)
                                        return "speechContexts." + error;
                                }
                            }
                            if (message.model != null && message.hasOwnProperty("model"))
                                if (!$util.isString(message.model))
                                    return "model: string expected";
                            if (message.modelVariant != null && message.hasOwnProperty("modelVariant"))
                                switch (message.modelVariant) {
                                default:
                                    return "modelVariant: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                    break;
                                }
                            if (message.singleUtterance != null && message.hasOwnProperty("singleUtterance"))
                                if (typeof message.singleUtterance !== "boolean")
                                    return "singleUtterance: boolean expected";
                            if (message.disableNoSpeechRecognizedEvent != null && message.hasOwnProperty("disableNoSpeechRecognizedEvent"))
                                if (typeof message.disableNoSpeechRecognizedEvent !== "boolean")
                                    return "disableNoSpeechRecognizedEvent: boolean expected";
                            if (message.bargeInConfig != null && message.hasOwnProperty("bargeInConfig")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.BargeInConfig.verify(message.bargeInConfig);
                                if (error)
                                    return "bargeInConfig." + error;
                            }
                            if (message.enableAutomaticPunctuation != null && message.hasOwnProperty("enableAutomaticPunctuation"))
                                if (typeof message.enableAutomaticPunctuation !== "boolean")
                                    return "enableAutomaticPunctuation: boolean expected";
                            if (message.defaultNoSpeechTimeout != null && message.hasOwnProperty("defaultNoSpeechTimeout")) {
                                var error = $root.google.protobuf.Duration.verify(message.defaultNoSpeechTimeout);
                                if (error)
                                    return "defaultNoSpeechTimeout." + error;
                            }
                            if (message.phraseSets != null && message.hasOwnProperty("phraseSets")) {
                                if (!Array.isArray(message.phraseSets))
                                    return "phraseSets: array expected";
                                for (var i = 0; i < message.phraseSets.length; ++i)
                                    if (!$util.isString(message.phraseSets[i]))
                                        return "phraseSets: string[] expected";
                            }
                            if (message.optOutConformerModelMigration != null && message.hasOwnProperty("optOutConformerModelMigration"))
                                if (typeof message.optOutConformerModelMigration !== "boolean")
                                    return "optOutConformerModelMigration: boolean expected";
                            return null;
                        };
    
                        /**
                         * Creates an InputAudioConfig message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.InputAudioConfig
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.InputAudioConfig} InputAudioConfig
                         */
                        InputAudioConfig.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.InputAudioConfig)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.InputAudioConfig();
                            switch (object.audioEncoding) {
                            default:
                                if (typeof object.audioEncoding === "number") {
                                    message.audioEncoding = object.audioEncoding;
                                    break;
                                }
                                break;
                            case "AUDIO_ENCODING_UNSPECIFIED":
                            case 0:
                                message.audioEncoding = 0;
                                break;
                            case "AUDIO_ENCODING_LINEAR_16":
                            case 1:
                                message.audioEncoding = 1;
                                break;
                            case "AUDIO_ENCODING_FLAC":
                            case 2:
                                message.audioEncoding = 2;
                                break;
                            case "AUDIO_ENCODING_MULAW":
                            case 3:
                                message.audioEncoding = 3;
                                break;
                            case "AUDIO_ENCODING_AMR":
                            case 4:
                                message.audioEncoding = 4;
                                break;
                            case "AUDIO_ENCODING_AMR_WB":
                            case 5:
                                message.audioEncoding = 5;
                                break;
                            case "AUDIO_ENCODING_OGG_OPUS":
                            case 6:
                                message.audioEncoding = 6;
                                break;
                            case "AUDIO_ENCODING_SPEEX_WITH_HEADER_BYTE":
                            case 7:
                                message.audioEncoding = 7;
                                break;
                            case "AUDIO_ENCODING_ALAW":
                            case 8:
                                message.audioEncoding = 8;
                                break;
                            }
                            if (object.sampleRateHertz != null)
                                message.sampleRateHertz = object.sampleRateHertz | 0;
                            if (object.languageCode != null)
                                message.languageCode = String(object.languageCode);
                            if (object.enableWordInfo != null)
                                message.enableWordInfo = Boolean(object.enableWordInfo);
                            if (object.phraseHints) {
                                if (!Array.isArray(object.phraseHints))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.InputAudioConfig.phraseHints: array expected");
                                message.phraseHints = [];
                                for (var i = 0; i < object.phraseHints.length; ++i)
                                    message.phraseHints[i] = String(object.phraseHints[i]);
                            }
                            if (object.speechContexts) {
                                if (!Array.isArray(object.speechContexts))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.InputAudioConfig.speechContexts: array expected");
                                message.speechContexts = [];
                                for (var i = 0; i < object.speechContexts.length; ++i) {
                                    if (typeof object.speechContexts[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.InputAudioConfig.speechContexts: object expected");
                                    message.speechContexts[i] = $root.google.cloud.dialogflow.v2beta1.SpeechContext.fromObject(object.speechContexts[i]);
                                }
                            }
                            if (object.model != null)
                                message.model = String(object.model);
                            switch (object.modelVariant) {
                            default:
                                if (typeof object.modelVariant === "number") {
                                    message.modelVariant = object.modelVariant;
                                    break;
                                }
                                break;
                            case "SPEECH_MODEL_VARIANT_UNSPECIFIED":
                            case 0:
                                message.modelVariant = 0;
                                break;
                            case "USE_BEST_AVAILABLE":
                            case 1:
                                message.modelVariant = 1;
                                break;
                            case "USE_STANDARD":
                            case 2:
                                message.modelVariant = 2;
                                break;
                            case "USE_ENHANCED":
                            case 3:
                                message.modelVariant = 3;
                                break;
                            }
                            if (object.singleUtterance != null)
                                message.singleUtterance = Boolean(object.singleUtterance);
                            if (object.disableNoSpeechRecognizedEvent != null)
                                message.disableNoSpeechRecognizedEvent = Boolean(object.disableNoSpeechRecognizedEvent);
                            if (object.bargeInConfig != null) {
                                if (typeof object.bargeInConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.InputAudioConfig.bargeInConfig: object expected");
                                message.bargeInConfig = $root.google.cloud.dialogflow.v2beta1.BargeInConfig.fromObject(object.bargeInConfig);
                            }
                            if (object.enableAutomaticPunctuation != null)
                                message.enableAutomaticPunctuation = Boolean(object.enableAutomaticPunctuation);
                            if (object.defaultNoSpeechTimeout != null) {
                                if (typeof object.defaultNoSpeechTimeout !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.InputAudioConfig.defaultNoSpeechTimeout: object expected");
                                message.defaultNoSpeechTimeout = $root.google.protobuf.Duration.fromObject(object.defaultNoSpeechTimeout);
                            }
                            if (object.phraseSets) {
                                if (!Array.isArray(object.phraseSets))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.InputAudioConfig.phraseSets: array expected");
                                message.phraseSets = [];
                                for (var i = 0; i < object.phraseSets.length; ++i)
                                    message.phraseSets[i] = String(object.phraseSets[i]);
                            }
                            if (object.optOutConformerModelMigration != null)
                                message.optOutConformerModelMigration = Boolean(object.optOutConformerModelMigration);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an InputAudioConfig message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.InputAudioConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.InputAudioConfig} message InputAudioConfig
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        InputAudioConfig.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults) {
                                object.phraseHints = [];
                                object.speechContexts = [];
                                object.phraseSets = [];
                            }
                            if (options.defaults) {
                                object.audioEncoding = options.enums === String ? "AUDIO_ENCODING_UNSPECIFIED" : 0;
                                object.sampleRateHertz = 0;
                                object.languageCode = "";
                                object.model = "";
                                object.singleUtterance = false;
                                object.modelVariant = options.enums === String ? "SPEECH_MODEL_VARIANT_UNSPECIFIED" : 0;
                                object.enableWordInfo = false;
                                object.disableNoSpeechRecognizedEvent = false;
                                object.bargeInConfig = null;
                                object.enableAutomaticPunctuation = false;
                                object.defaultNoSpeechTimeout = null;
                                object.optOutConformerModelMigration = false;
                            }
                            if (message.audioEncoding != null && message.hasOwnProperty("audioEncoding"))
                                object.audioEncoding = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.AudioEncoding[message.audioEncoding] === undefined ? message.audioEncoding : $root.google.cloud.dialogflow.v2beta1.AudioEncoding[message.audioEncoding] : message.audioEncoding;
                            if (message.sampleRateHertz != null && message.hasOwnProperty("sampleRateHertz"))
                                object.sampleRateHertz = message.sampleRateHertz;
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                object.languageCode = message.languageCode;
                            if (message.phraseHints && message.phraseHints.length) {
                                object.phraseHints = [];
                                for (var j = 0; j < message.phraseHints.length; ++j)
                                    object.phraseHints[j] = message.phraseHints[j];
                            }
                            if (message.model != null && message.hasOwnProperty("model"))
                                object.model = message.model;
                            if (message.singleUtterance != null && message.hasOwnProperty("singleUtterance"))
                                object.singleUtterance = message.singleUtterance;
                            if (message.modelVariant != null && message.hasOwnProperty("modelVariant"))
                                object.modelVariant = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.SpeechModelVariant[message.modelVariant] === undefined ? message.modelVariant : $root.google.cloud.dialogflow.v2beta1.SpeechModelVariant[message.modelVariant] : message.modelVariant;
                            if (message.speechContexts && message.speechContexts.length) {
                                object.speechContexts = [];
                                for (var j = 0; j < message.speechContexts.length; ++j)
                                    object.speechContexts[j] = $root.google.cloud.dialogflow.v2beta1.SpeechContext.toObject(message.speechContexts[j], options);
                            }
                            if (message.enableWordInfo != null && message.hasOwnProperty("enableWordInfo"))
                                object.enableWordInfo = message.enableWordInfo;
                            if (message.disableNoSpeechRecognizedEvent != null && message.hasOwnProperty("disableNoSpeechRecognizedEvent"))
                                object.disableNoSpeechRecognizedEvent = message.disableNoSpeechRecognizedEvent;
                            if (message.bargeInConfig != null && message.hasOwnProperty("bargeInConfig"))
                                object.bargeInConfig = $root.google.cloud.dialogflow.v2beta1.BargeInConfig.toObject(message.bargeInConfig, options);
                            if (message.enableAutomaticPunctuation != null && message.hasOwnProperty("enableAutomaticPunctuation"))
                                object.enableAutomaticPunctuation = message.enableAutomaticPunctuation;
                            if (message.defaultNoSpeechTimeout != null && message.hasOwnProperty("defaultNoSpeechTimeout"))
                                object.defaultNoSpeechTimeout = $root.google.protobuf.Duration.toObject(message.defaultNoSpeechTimeout, options);
                            if (message.phraseSets && message.phraseSets.length) {
                                object.phraseSets = [];
                                for (var j = 0; j < message.phraseSets.length; ++j)
                                    object.phraseSets[j] = message.phraseSets[j];
                            }
                            if (message.optOutConformerModelMigration != null && message.hasOwnProperty("optOutConformerModelMigration"))
                                object.optOutConformerModelMigration = message.optOutConformerModelMigration;
                            return object;
                        };
    
                        /**
                         * Converts this InputAudioConfig to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.InputAudioConfig
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        InputAudioConfig.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for InputAudioConfig
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.InputAudioConfig
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        InputAudioConfig.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.InputAudioConfig";
                        };
    
                        return InputAudioConfig;
                    })();
    
                    v2beta1.VoiceSelectionParams = (function() {
    
                        /**
                         * Properties of a VoiceSelectionParams.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IVoiceSelectionParams
                         * @property {string|null} [name] VoiceSelectionParams name
                         * @property {google.cloud.dialogflow.v2beta1.SsmlVoiceGender|null} [ssmlGender] VoiceSelectionParams ssmlGender
                         */
    
                        /**
                         * Constructs a new VoiceSelectionParams.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a VoiceSelectionParams.
                         * @implements IVoiceSelectionParams
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IVoiceSelectionParams=} [properties] Properties to set
                         */
                        function VoiceSelectionParams(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * VoiceSelectionParams name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2beta1.VoiceSelectionParams
                         * @instance
                         */
                        VoiceSelectionParams.prototype.name = "";
    
                        /**
                         * VoiceSelectionParams ssmlGender.
                         * @member {google.cloud.dialogflow.v2beta1.SsmlVoiceGender} ssmlGender
                         * @memberof google.cloud.dialogflow.v2beta1.VoiceSelectionParams
                         * @instance
                         */
                        VoiceSelectionParams.prototype.ssmlGender = 0;
    
                        /**
                         * Creates a new VoiceSelectionParams instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.VoiceSelectionParams
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IVoiceSelectionParams=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.VoiceSelectionParams} VoiceSelectionParams instance
                         */
                        VoiceSelectionParams.create = function create(properties) {
                            return new VoiceSelectionParams(properties);
                        };
    
                        /**
                         * Encodes the specified VoiceSelectionParams message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.VoiceSelectionParams.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.VoiceSelectionParams
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IVoiceSelectionParams} message VoiceSelectionParams message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        VoiceSelectionParams.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            if (message.ssmlGender != null && Object.hasOwnProperty.call(message, "ssmlGender"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.ssmlGender);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified VoiceSelectionParams message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.VoiceSelectionParams.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.VoiceSelectionParams
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IVoiceSelectionParams} message VoiceSelectionParams message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        VoiceSelectionParams.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a VoiceSelectionParams message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.VoiceSelectionParams
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.VoiceSelectionParams} VoiceSelectionParams
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        VoiceSelectionParams.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.VoiceSelectionParams();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.ssmlGender = reader.int32();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a VoiceSelectionParams message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.VoiceSelectionParams
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.VoiceSelectionParams} VoiceSelectionParams
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        VoiceSelectionParams.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a VoiceSelectionParams message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.VoiceSelectionParams
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        VoiceSelectionParams.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            if (message.ssmlGender != null && message.hasOwnProperty("ssmlGender"))
                                switch (message.ssmlGender) {
                                default:
                                    return "ssmlGender: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                    break;
                                }
                            return null;
                        };
    
                        /**
                         * Creates a VoiceSelectionParams message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.VoiceSelectionParams
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.VoiceSelectionParams} VoiceSelectionParams
                         */
                        VoiceSelectionParams.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.VoiceSelectionParams)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.VoiceSelectionParams();
                            if (object.name != null)
                                message.name = String(object.name);
                            switch (object.ssmlGender) {
                            default:
                                if (typeof object.ssmlGender === "number") {
                                    message.ssmlGender = object.ssmlGender;
                                    break;
                                }
                                break;
                            case "SSML_VOICE_GENDER_UNSPECIFIED":
                            case 0:
                                message.ssmlGender = 0;
                                break;
                            case "SSML_VOICE_GENDER_MALE":
                            case 1:
                                message.ssmlGender = 1;
                                break;
                            case "SSML_VOICE_GENDER_FEMALE":
                            case 2:
                                message.ssmlGender = 2;
                                break;
                            case "SSML_VOICE_GENDER_NEUTRAL":
                            case 3:
                                message.ssmlGender = 3;
                                break;
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a VoiceSelectionParams message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.VoiceSelectionParams
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.VoiceSelectionParams} message VoiceSelectionParams
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        VoiceSelectionParams.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.name = "";
                                object.ssmlGender = options.enums === String ? "SSML_VOICE_GENDER_UNSPECIFIED" : 0;
                            }
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            if (message.ssmlGender != null && message.hasOwnProperty("ssmlGender"))
                                object.ssmlGender = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.SsmlVoiceGender[message.ssmlGender] === undefined ? message.ssmlGender : $root.google.cloud.dialogflow.v2beta1.SsmlVoiceGender[message.ssmlGender] : message.ssmlGender;
                            return object;
                        };
    
                        /**
                         * Converts this VoiceSelectionParams to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.VoiceSelectionParams
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        VoiceSelectionParams.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for VoiceSelectionParams
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.VoiceSelectionParams
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        VoiceSelectionParams.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.VoiceSelectionParams";
                        };
    
                        return VoiceSelectionParams;
                    })();
    
                    v2beta1.SynthesizeSpeechConfig = (function() {
    
                        /**
                         * Properties of a SynthesizeSpeechConfig.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ISynthesizeSpeechConfig
                         * @property {number|null} [speakingRate] SynthesizeSpeechConfig speakingRate
                         * @property {number|null} [pitch] SynthesizeSpeechConfig pitch
                         * @property {number|null} [volumeGainDb] SynthesizeSpeechConfig volumeGainDb
                         * @property {Array.<string>|null} [effectsProfileId] SynthesizeSpeechConfig effectsProfileId
                         * @property {google.cloud.dialogflow.v2beta1.IVoiceSelectionParams|null} [voice] SynthesizeSpeechConfig voice
                         */
    
                        /**
                         * Constructs a new SynthesizeSpeechConfig.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a SynthesizeSpeechConfig.
                         * @implements ISynthesizeSpeechConfig
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ISynthesizeSpeechConfig=} [properties] Properties to set
                         */
                        function SynthesizeSpeechConfig(properties) {
                            this.effectsProfileId = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SynthesizeSpeechConfig speakingRate.
                         * @member {number} speakingRate
                         * @memberof google.cloud.dialogflow.v2beta1.SynthesizeSpeechConfig
                         * @instance
                         */
                        SynthesizeSpeechConfig.prototype.speakingRate = 0;
    
                        /**
                         * SynthesizeSpeechConfig pitch.
                         * @member {number} pitch
                         * @memberof google.cloud.dialogflow.v2beta1.SynthesizeSpeechConfig
                         * @instance
                         */
                        SynthesizeSpeechConfig.prototype.pitch = 0;
    
                        /**
                         * SynthesizeSpeechConfig volumeGainDb.
                         * @member {number} volumeGainDb
                         * @memberof google.cloud.dialogflow.v2beta1.SynthesizeSpeechConfig
                         * @instance
                         */
                        SynthesizeSpeechConfig.prototype.volumeGainDb = 0;
    
                        /**
                         * SynthesizeSpeechConfig effectsProfileId.
                         * @member {Array.<string>} effectsProfileId
                         * @memberof google.cloud.dialogflow.v2beta1.SynthesizeSpeechConfig
                         * @instance
                         */
                        SynthesizeSpeechConfig.prototype.effectsProfileId = $util.emptyArray;
    
                        /**
                         * SynthesizeSpeechConfig voice.
                         * @member {google.cloud.dialogflow.v2beta1.IVoiceSelectionParams|null|undefined} voice
                         * @memberof google.cloud.dialogflow.v2beta1.SynthesizeSpeechConfig
                         * @instance
                         */
                        SynthesizeSpeechConfig.prototype.voice = null;
    
                        /**
                         * Creates a new SynthesizeSpeechConfig instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.SynthesizeSpeechConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISynthesizeSpeechConfig=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.SynthesizeSpeechConfig} SynthesizeSpeechConfig instance
                         */
                        SynthesizeSpeechConfig.create = function create(properties) {
                            return new SynthesizeSpeechConfig(properties);
                        };
    
                        /**
                         * Encodes the specified SynthesizeSpeechConfig message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SynthesizeSpeechConfig.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.SynthesizeSpeechConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISynthesizeSpeechConfig} message SynthesizeSpeechConfig message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SynthesizeSpeechConfig.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.speakingRate != null && Object.hasOwnProperty.call(message, "speakingRate"))
                                writer.uint32(/* id 1, wireType 1 =*/9).double(message.speakingRate);
                            if (message.pitch != null && Object.hasOwnProperty.call(message, "pitch"))
                                writer.uint32(/* id 2, wireType 1 =*/17).double(message.pitch);
                            if (message.volumeGainDb != null && Object.hasOwnProperty.call(message, "volumeGainDb"))
                                writer.uint32(/* id 3, wireType 1 =*/25).double(message.volumeGainDb);
                            if (message.voice != null && Object.hasOwnProperty.call(message, "voice"))
                                $root.google.cloud.dialogflow.v2beta1.VoiceSelectionParams.encode(message.voice, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            if (message.effectsProfileId != null && message.effectsProfileId.length)
                                for (var i = 0; i < message.effectsProfileId.length; ++i)
                                    writer.uint32(/* id 5, wireType 2 =*/42).string(message.effectsProfileId[i]);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SynthesizeSpeechConfig message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SynthesizeSpeechConfig.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SynthesizeSpeechConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISynthesizeSpeechConfig} message SynthesizeSpeechConfig message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SynthesizeSpeechConfig.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SynthesizeSpeechConfig message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.SynthesizeSpeechConfig
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.SynthesizeSpeechConfig} SynthesizeSpeechConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SynthesizeSpeechConfig.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.SynthesizeSpeechConfig();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.speakingRate = reader.double();
                                        break;
                                    }
                                case 2: {
                                        message.pitch = reader.double();
                                        break;
                                    }
                                case 3: {
                                        message.volumeGainDb = reader.double();
                                        break;
                                    }
                                case 5: {
                                        if (!(message.effectsProfileId && message.effectsProfileId.length))
                                            message.effectsProfileId = [];
                                        message.effectsProfileId.push(reader.string());
                                        break;
                                    }
                                case 4: {
                                        message.voice = $root.google.cloud.dialogflow.v2beta1.VoiceSelectionParams.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SynthesizeSpeechConfig message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SynthesizeSpeechConfig
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.SynthesizeSpeechConfig} SynthesizeSpeechConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SynthesizeSpeechConfig.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SynthesizeSpeechConfig message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.SynthesizeSpeechConfig
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SynthesizeSpeechConfig.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.speakingRate != null && message.hasOwnProperty("speakingRate"))
                                if (typeof message.speakingRate !== "number")
                                    return "speakingRate: number expected";
                            if (message.pitch != null && message.hasOwnProperty("pitch"))
                                if (typeof message.pitch !== "number")
                                    return "pitch: number expected";
                            if (message.volumeGainDb != null && message.hasOwnProperty("volumeGainDb"))
                                if (typeof message.volumeGainDb !== "number")
                                    return "volumeGainDb: number expected";
                            if (message.effectsProfileId != null && message.hasOwnProperty("effectsProfileId")) {
                                if (!Array.isArray(message.effectsProfileId))
                                    return "effectsProfileId: array expected";
                                for (var i = 0; i < message.effectsProfileId.length; ++i)
                                    if (!$util.isString(message.effectsProfileId[i]))
                                        return "effectsProfileId: string[] expected";
                            }
                            if (message.voice != null && message.hasOwnProperty("voice")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.VoiceSelectionParams.verify(message.voice);
                                if (error)
                                    return "voice." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a SynthesizeSpeechConfig message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.SynthesizeSpeechConfig
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.SynthesizeSpeechConfig} SynthesizeSpeechConfig
                         */
                        SynthesizeSpeechConfig.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.SynthesizeSpeechConfig)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.SynthesizeSpeechConfig();
                            if (object.speakingRate != null)
                                message.speakingRate = Number(object.speakingRate);
                            if (object.pitch != null)
                                message.pitch = Number(object.pitch);
                            if (object.volumeGainDb != null)
                                message.volumeGainDb = Number(object.volumeGainDb);
                            if (object.effectsProfileId) {
                                if (!Array.isArray(object.effectsProfileId))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.SynthesizeSpeechConfig.effectsProfileId: array expected");
                                message.effectsProfileId = [];
                                for (var i = 0; i < object.effectsProfileId.length; ++i)
                                    message.effectsProfileId[i] = String(object.effectsProfileId[i]);
                            }
                            if (object.voice != null) {
                                if (typeof object.voice !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.SynthesizeSpeechConfig.voice: object expected");
                                message.voice = $root.google.cloud.dialogflow.v2beta1.VoiceSelectionParams.fromObject(object.voice);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SynthesizeSpeechConfig message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.SynthesizeSpeechConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.SynthesizeSpeechConfig} message SynthesizeSpeechConfig
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SynthesizeSpeechConfig.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.effectsProfileId = [];
                            if (options.defaults) {
                                object.speakingRate = 0;
                                object.pitch = 0;
                                object.volumeGainDb = 0;
                                object.voice = null;
                            }
                            if (message.speakingRate != null && message.hasOwnProperty("speakingRate"))
                                object.speakingRate = options.json && !isFinite(message.speakingRate) ? String(message.speakingRate) : message.speakingRate;
                            if (message.pitch != null && message.hasOwnProperty("pitch"))
                                object.pitch = options.json && !isFinite(message.pitch) ? String(message.pitch) : message.pitch;
                            if (message.volumeGainDb != null && message.hasOwnProperty("volumeGainDb"))
                                object.volumeGainDb = options.json && !isFinite(message.volumeGainDb) ? String(message.volumeGainDb) : message.volumeGainDb;
                            if (message.voice != null && message.hasOwnProperty("voice"))
                                object.voice = $root.google.cloud.dialogflow.v2beta1.VoiceSelectionParams.toObject(message.voice, options);
                            if (message.effectsProfileId && message.effectsProfileId.length) {
                                object.effectsProfileId = [];
                                for (var j = 0; j < message.effectsProfileId.length; ++j)
                                    object.effectsProfileId[j] = message.effectsProfileId[j];
                            }
                            return object;
                        };
    
                        /**
                         * Converts this SynthesizeSpeechConfig to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.SynthesizeSpeechConfig
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SynthesizeSpeechConfig.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SynthesizeSpeechConfig
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.SynthesizeSpeechConfig
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SynthesizeSpeechConfig.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.SynthesizeSpeechConfig";
                        };
    
                        return SynthesizeSpeechConfig;
                    })();
    
                    v2beta1.OutputAudioConfig = (function() {
    
                        /**
                         * Properties of an OutputAudioConfig.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IOutputAudioConfig
                         * @property {google.cloud.dialogflow.v2beta1.OutputAudioEncoding|null} [audioEncoding] OutputAudioConfig audioEncoding
                         * @property {number|null} [sampleRateHertz] OutputAudioConfig sampleRateHertz
                         * @property {google.cloud.dialogflow.v2beta1.ISynthesizeSpeechConfig|null} [synthesizeSpeechConfig] OutputAudioConfig synthesizeSpeechConfig
                         */
    
                        /**
                         * Constructs a new OutputAudioConfig.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an OutputAudioConfig.
                         * @implements IOutputAudioConfig
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IOutputAudioConfig=} [properties] Properties to set
                         */
                        function OutputAudioConfig(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * OutputAudioConfig audioEncoding.
                         * @member {google.cloud.dialogflow.v2beta1.OutputAudioEncoding} audioEncoding
                         * @memberof google.cloud.dialogflow.v2beta1.OutputAudioConfig
                         * @instance
                         */
                        OutputAudioConfig.prototype.audioEncoding = 0;
    
                        /**
                         * OutputAudioConfig sampleRateHertz.
                         * @member {number} sampleRateHertz
                         * @memberof google.cloud.dialogflow.v2beta1.OutputAudioConfig
                         * @instance
                         */
                        OutputAudioConfig.prototype.sampleRateHertz = 0;
    
                        /**
                         * OutputAudioConfig synthesizeSpeechConfig.
                         * @member {google.cloud.dialogflow.v2beta1.ISynthesizeSpeechConfig|null|undefined} synthesizeSpeechConfig
                         * @memberof google.cloud.dialogflow.v2beta1.OutputAudioConfig
                         * @instance
                         */
                        OutputAudioConfig.prototype.synthesizeSpeechConfig = null;
    
                        /**
                         * Creates a new OutputAudioConfig instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.OutputAudioConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IOutputAudioConfig=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.OutputAudioConfig} OutputAudioConfig instance
                         */
                        OutputAudioConfig.create = function create(properties) {
                            return new OutputAudioConfig(properties);
                        };
    
                        /**
                         * Encodes the specified OutputAudioConfig message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.OutputAudioConfig.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.OutputAudioConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IOutputAudioConfig} message OutputAudioConfig message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        OutputAudioConfig.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.audioEncoding != null && Object.hasOwnProperty.call(message, "audioEncoding"))
                                writer.uint32(/* id 1, wireType 0 =*/8).int32(message.audioEncoding);
                            if (message.sampleRateHertz != null && Object.hasOwnProperty.call(message, "sampleRateHertz"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.sampleRateHertz);
                            if (message.synthesizeSpeechConfig != null && Object.hasOwnProperty.call(message, "synthesizeSpeechConfig"))
                                $root.google.cloud.dialogflow.v2beta1.SynthesizeSpeechConfig.encode(message.synthesizeSpeechConfig, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified OutputAudioConfig message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.OutputAudioConfig.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.OutputAudioConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IOutputAudioConfig} message OutputAudioConfig message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        OutputAudioConfig.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an OutputAudioConfig message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.OutputAudioConfig
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.OutputAudioConfig} OutputAudioConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        OutputAudioConfig.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.OutputAudioConfig();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.audioEncoding = reader.int32();
                                        break;
                                    }
                                case 2: {
                                        message.sampleRateHertz = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.synthesizeSpeechConfig = $root.google.cloud.dialogflow.v2beta1.SynthesizeSpeechConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an OutputAudioConfig message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.OutputAudioConfig
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.OutputAudioConfig} OutputAudioConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        OutputAudioConfig.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an OutputAudioConfig message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.OutputAudioConfig
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        OutputAudioConfig.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.audioEncoding != null && message.hasOwnProperty("audioEncoding"))
                                switch (message.audioEncoding) {
                                default:
                                    return "audioEncoding: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 4:
                                case 3:
                                case 5:
                                case 6:
                                    break;
                                }
                            if (message.sampleRateHertz != null && message.hasOwnProperty("sampleRateHertz"))
                                if (!$util.isInteger(message.sampleRateHertz))
                                    return "sampleRateHertz: integer expected";
                            if (message.synthesizeSpeechConfig != null && message.hasOwnProperty("synthesizeSpeechConfig")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.SynthesizeSpeechConfig.verify(message.synthesizeSpeechConfig);
                                if (error)
                                    return "synthesizeSpeechConfig." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates an OutputAudioConfig message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.OutputAudioConfig
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.OutputAudioConfig} OutputAudioConfig
                         */
                        OutputAudioConfig.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.OutputAudioConfig)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.OutputAudioConfig();
                            switch (object.audioEncoding) {
                            default:
                                if (typeof object.audioEncoding === "number") {
                                    message.audioEncoding = object.audioEncoding;
                                    break;
                                }
                                break;
                            case "OUTPUT_AUDIO_ENCODING_UNSPECIFIED":
                            case 0:
                                message.audioEncoding = 0;
                                break;
                            case "OUTPUT_AUDIO_ENCODING_LINEAR_16":
                            case 1:
                                message.audioEncoding = 1;
                                break;
                            case "OUTPUT_AUDIO_ENCODING_MP3":
                            case 2:
                                message.audioEncoding = 2;
                                break;
                            case "OUTPUT_AUDIO_ENCODING_MP3_64_KBPS":
                            case 4:
                                message.audioEncoding = 4;
                                break;
                            case "OUTPUT_AUDIO_ENCODING_OGG_OPUS":
                            case 3:
                                message.audioEncoding = 3;
                                break;
                            case "OUTPUT_AUDIO_ENCODING_MULAW":
                            case 5:
                                message.audioEncoding = 5;
                                break;
                            case "OUTPUT_AUDIO_ENCODING_ALAW":
                            case 6:
                                message.audioEncoding = 6;
                                break;
                            }
                            if (object.sampleRateHertz != null)
                                message.sampleRateHertz = object.sampleRateHertz | 0;
                            if (object.synthesizeSpeechConfig != null) {
                                if (typeof object.synthesizeSpeechConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.OutputAudioConfig.synthesizeSpeechConfig: object expected");
                                message.synthesizeSpeechConfig = $root.google.cloud.dialogflow.v2beta1.SynthesizeSpeechConfig.fromObject(object.synthesizeSpeechConfig);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an OutputAudioConfig message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.OutputAudioConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.OutputAudioConfig} message OutputAudioConfig
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        OutputAudioConfig.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.audioEncoding = options.enums === String ? "OUTPUT_AUDIO_ENCODING_UNSPECIFIED" : 0;
                                object.sampleRateHertz = 0;
                                object.synthesizeSpeechConfig = null;
                            }
                            if (message.audioEncoding != null && message.hasOwnProperty("audioEncoding"))
                                object.audioEncoding = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.OutputAudioEncoding[message.audioEncoding] === undefined ? message.audioEncoding : $root.google.cloud.dialogflow.v2beta1.OutputAudioEncoding[message.audioEncoding] : message.audioEncoding;
                            if (message.sampleRateHertz != null && message.hasOwnProperty("sampleRateHertz"))
                                object.sampleRateHertz = message.sampleRateHertz;
                            if (message.synthesizeSpeechConfig != null && message.hasOwnProperty("synthesizeSpeechConfig"))
                                object.synthesizeSpeechConfig = $root.google.cloud.dialogflow.v2beta1.SynthesizeSpeechConfig.toObject(message.synthesizeSpeechConfig, options);
                            return object;
                        };
    
                        /**
                         * Converts this OutputAudioConfig to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.OutputAudioConfig
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        OutputAudioConfig.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for OutputAudioConfig
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.OutputAudioConfig
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        OutputAudioConfig.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.OutputAudioConfig";
                        };
    
                        return OutputAudioConfig;
                    })();
    
                    v2beta1.TelephonyDtmfEvents = (function() {
    
                        /**
                         * Properties of a TelephonyDtmfEvents.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ITelephonyDtmfEvents
                         * @property {Array.<google.cloud.dialogflow.v2beta1.TelephonyDtmf>|null} [dtmfEvents] TelephonyDtmfEvents dtmfEvents
                         */
    
                        /**
                         * Constructs a new TelephonyDtmfEvents.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a TelephonyDtmfEvents.
                         * @implements ITelephonyDtmfEvents
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ITelephonyDtmfEvents=} [properties] Properties to set
                         */
                        function TelephonyDtmfEvents(properties) {
                            this.dtmfEvents = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * TelephonyDtmfEvents dtmfEvents.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.TelephonyDtmf>} dtmfEvents
                         * @memberof google.cloud.dialogflow.v2beta1.TelephonyDtmfEvents
                         * @instance
                         */
                        TelephonyDtmfEvents.prototype.dtmfEvents = $util.emptyArray;
    
                        /**
                         * Creates a new TelephonyDtmfEvents instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.TelephonyDtmfEvents
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ITelephonyDtmfEvents=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.TelephonyDtmfEvents} TelephonyDtmfEvents instance
                         */
                        TelephonyDtmfEvents.create = function create(properties) {
                            return new TelephonyDtmfEvents(properties);
                        };
    
                        /**
                         * Encodes the specified TelephonyDtmfEvents message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.TelephonyDtmfEvents.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.TelephonyDtmfEvents
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ITelephonyDtmfEvents} message TelephonyDtmfEvents message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        TelephonyDtmfEvents.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.dtmfEvents != null && message.dtmfEvents.length) {
                                writer.uint32(/* id 1, wireType 2 =*/10).fork();
                                for (var i = 0; i < message.dtmfEvents.length; ++i)
                                    writer.int32(message.dtmfEvents[i]);
                                writer.ldelim();
                            }
                            return writer;
                        };
    
                        /**
                         * Encodes the specified TelephonyDtmfEvents message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.TelephonyDtmfEvents.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.TelephonyDtmfEvents
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ITelephonyDtmfEvents} message TelephonyDtmfEvents message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        TelephonyDtmfEvents.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a TelephonyDtmfEvents message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.TelephonyDtmfEvents
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.TelephonyDtmfEvents} TelephonyDtmfEvents
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        TelephonyDtmfEvents.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.TelephonyDtmfEvents();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.dtmfEvents && message.dtmfEvents.length))
                                            message.dtmfEvents = [];
                                        if ((tag & 7) === 2) {
                                            var end2 = reader.uint32() + reader.pos;
                                            while (reader.pos < end2)
                                                message.dtmfEvents.push(reader.int32());
                                        } else
                                            message.dtmfEvents.push(reader.int32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a TelephonyDtmfEvents message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.TelephonyDtmfEvents
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.TelephonyDtmfEvents} TelephonyDtmfEvents
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        TelephonyDtmfEvents.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a TelephonyDtmfEvents message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.TelephonyDtmfEvents
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        TelephonyDtmfEvents.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.dtmfEvents != null && message.hasOwnProperty("dtmfEvents")) {
                                if (!Array.isArray(message.dtmfEvents))
                                    return "dtmfEvents: array expected";
                                for (var i = 0; i < message.dtmfEvents.length; ++i)
                                    switch (message.dtmfEvents[i]) {
                                    default:
                                        return "dtmfEvents: enum value[] expected";
                                    case 0:
                                    case 1:
                                    case 2:
                                    case 3:
                                    case 4:
                                    case 5:
                                    case 6:
                                    case 7:
                                    case 8:
                                    case 9:
                                    case 10:
                                    case 11:
                                    case 12:
                                    case 13:
                                    case 14:
                                    case 15:
                                    case 16:
                                        break;
                                    }
                            }
                            return null;
                        };
    
                        /**
                         * Creates a TelephonyDtmfEvents message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.TelephonyDtmfEvents
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.TelephonyDtmfEvents} TelephonyDtmfEvents
                         */
                        TelephonyDtmfEvents.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.TelephonyDtmfEvents)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.TelephonyDtmfEvents();
                            if (object.dtmfEvents) {
                                if (!Array.isArray(object.dtmfEvents))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.TelephonyDtmfEvents.dtmfEvents: array expected");
                                message.dtmfEvents = [];
                                for (var i = 0; i < object.dtmfEvents.length; ++i)
                                    switch (object.dtmfEvents[i]) {
                                    default:
                                        if (typeof object.dtmfEvents[i] === "number") {
                                            message.dtmfEvents[i] = object.dtmfEvents[i];
                                            break;
                                        }
                                    case "TELEPHONY_DTMF_UNSPECIFIED":
                                    case 0:
                                        message.dtmfEvents[i] = 0;
                                        break;
                                    case "DTMF_ONE":
                                    case 1:
                                        message.dtmfEvents[i] = 1;
                                        break;
                                    case "DTMF_TWO":
                                    case 2:
                                        message.dtmfEvents[i] = 2;
                                        break;
                                    case "DTMF_THREE":
                                    case 3:
                                        message.dtmfEvents[i] = 3;
                                        break;
                                    case "DTMF_FOUR":
                                    case 4:
                                        message.dtmfEvents[i] = 4;
                                        break;
                                    case "DTMF_FIVE":
                                    case 5:
                                        message.dtmfEvents[i] = 5;
                                        break;
                                    case "DTMF_SIX":
                                    case 6:
                                        message.dtmfEvents[i] = 6;
                                        break;
                                    case "DTMF_SEVEN":
                                    case 7:
                                        message.dtmfEvents[i] = 7;
                                        break;
                                    case "DTMF_EIGHT":
                                    case 8:
                                        message.dtmfEvents[i] = 8;
                                        break;
                                    case "DTMF_NINE":
                                    case 9:
                                        message.dtmfEvents[i] = 9;
                                        break;
                                    case "DTMF_ZERO":
                                    case 10:
                                        message.dtmfEvents[i] = 10;
                                        break;
                                    case "DTMF_A":
                                    case 11:
                                        message.dtmfEvents[i] = 11;
                                        break;
                                    case "DTMF_B":
                                    case 12:
                                        message.dtmfEvents[i] = 12;
                                        break;
                                    case "DTMF_C":
                                    case 13:
                                        message.dtmfEvents[i] = 13;
                                        break;
                                    case "DTMF_D":
                                    case 14:
                                        message.dtmfEvents[i] = 14;
                                        break;
                                    case "DTMF_STAR":
                                    case 15:
                                        message.dtmfEvents[i] = 15;
                                        break;
                                    case "DTMF_POUND":
                                    case 16:
                                        message.dtmfEvents[i] = 16;
                                        break;
                                    }
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a TelephonyDtmfEvents message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.TelephonyDtmfEvents
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.TelephonyDtmfEvents} message TelephonyDtmfEvents
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        TelephonyDtmfEvents.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.dtmfEvents = [];
                            if (message.dtmfEvents && message.dtmfEvents.length) {
                                object.dtmfEvents = [];
                                for (var j = 0; j < message.dtmfEvents.length; ++j)
                                    object.dtmfEvents[j] = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.TelephonyDtmf[message.dtmfEvents[j]] === undefined ? message.dtmfEvents[j] : $root.google.cloud.dialogflow.v2beta1.TelephonyDtmf[message.dtmfEvents[j]] : message.dtmfEvents[j];
                            }
                            return object;
                        };
    
                        /**
                         * Converts this TelephonyDtmfEvents to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.TelephonyDtmfEvents
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        TelephonyDtmfEvents.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for TelephonyDtmfEvents
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.TelephonyDtmfEvents
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        TelephonyDtmfEvents.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.TelephonyDtmfEvents";
                        };
    
                        return TelephonyDtmfEvents;
                    })();
    
                    v2beta1.SpeechToTextConfig = (function() {
    
                        /**
                         * Properties of a SpeechToTextConfig.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ISpeechToTextConfig
                         * @property {google.cloud.dialogflow.v2beta1.SpeechModelVariant|null} [speechModelVariant] SpeechToTextConfig speechModelVariant
                         * @property {string|null} [model] SpeechToTextConfig model
                         * @property {Array.<string>|null} [phraseSets] SpeechToTextConfig phraseSets
                         * @property {google.cloud.dialogflow.v2beta1.AudioEncoding|null} [audioEncoding] SpeechToTextConfig audioEncoding
                         * @property {number|null} [sampleRateHertz] SpeechToTextConfig sampleRateHertz
                         * @property {string|null} [languageCode] SpeechToTextConfig languageCode
                         * @property {boolean|null} [enableWordInfo] SpeechToTextConfig enableWordInfo
                         * @property {boolean|null} [useTimeoutBasedEndpointing] SpeechToTextConfig useTimeoutBasedEndpointing
                         */
    
                        /**
                         * Constructs a new SpeechToTextConfig.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a SpeechToTextConfig.
                         * @implements ISpeechToTextConfig
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ISpeechToTextConfig=} [properties] Properties to set
                         */
                        function SpeechToTextConfig(properties) {
                            this.phraseSets = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SpeechToTextConfig speechModelVariant.
                         * @member {google.cloud.dialogflow.v2beta1.SpeechModelVariant} speechModelVariant
                         * @memberof google.cloud.dialogflow.v2beta1.SpeechToTextConfig
                         * @instance
                         */
                        SpeechToTextConfig.prototype.speechModelVariant = 0;
    
                        /**
                         * SpeechToTextConfig model.
                         * @member {string} model
                         * @memberof google.cloud.dialogflow.v2beta1.SpeechToTextConfig
                         * @instance
                         */
                        SpeechToTextConfig.prototype.model = "";
    
                        /**
                         * SpeechToTextConfig phraseSets.
                         * @member {Array.<string>} phraseSets
                         * @memberof google.cloud.dialogflow.v2beta1.SpeechToTextConfig
                         * @instance
                         */
                        SpeechToTextConfig.prototype.phraseSets = $util.emptyArray;
    
                        /**
                         * SpeechToTextConfig audioEncoding.
                         * @member {google.cloud.dialogflow.v2beta1.AudioEncoding} audioEncoding
                         * @memberof google.cloud.dialogflow.v2beta1.SpeechToTextConfig
                         * @instance
                         */
                        SpeechToTextConfig.prototype.audioEncoding = 0;
    
                        /**
                         * SpeechToTextConfig sampleRateHertz.
                         * @member {number} sampleRateHertz
                         * @memberof google.cloud.dialogflow.v2beta1.SpeechToTextConfig
                         * @instance
                         */
                        SpeechToTextConfig.prototype.sampleRateHertz = 0;
    
                        /**
                         * SpeechToTextConfig languageCode.
                         * @member {string} languageCode
                         * @memberof google.cloud.dialogflow.v2beta1.SpeechToTextConfig
                         * @instance
                         */
                        SpeechToTextConfig.prototype.languageCode = "";
    
                        /**
                         * SpeechToTextConfig enableWordInfo.
                         * @member {boolean} enableWordInfo
                         * @memberof google.cloud.dialogflow.v2beta1.SpeechToTextConfig
                         * @instance
                         */
                        SpeechToTextConfig.prototype.enableWordInfo = false;
    
                        /**
                         * SpeechToTextConfig useTimeoutBasedEndpointing.
                         * @member {boolean} useTimeoutBasedEndpointing
                         * @memberof google.cloud.dialogflow.v2beta1.SpeechToTextConfig
                         * @instance
                         */
                        SpeechToTextConfig.prototype.useTimeoutBasedEndpointing = false;
    
                        /**
                         * Creates a new SpeechToTextConfig instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.SpeechToTextConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISpeechToTextConfig=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.SpeechToTextConfig} SpeechToTextConfig instance
                         */
                        SpeechToTextConfig.create = function create(properties) {
                            return new SpeechToTextConfig(properties);
                        };
    
                        /**
                         * Encodes the specified SpeechToTextConfig message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SpeechToTextConfig.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.SpeechToTextConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISpeechToTextConfig} message SpeechToTextConfig message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SpeechToTextConfig.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.speechModelVariant != null && Object.hasOwnProperty.call(message, "speechModelVariant"))
                                writer.uint32(/* id 1, wireType 0 =*/8).int32(message.speechModelVariant);
                            if (message.model != null && Object.hasOwnProperty.call(message, "model"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.model);
                            if (message.phraseSets != null && message.phraseSets.length)
                                for (var i = 0; i < message.phraseSets.length; ++i)
                                    writer.uint32(/* id 4, wireType 2 =*/34).string(message.phraseSets[i]);
                            if (message.audioEncoding != null && Object.hasOwnProperty.call(message, "audioEncoding"))
                                writer.uint32(/* id 6, wireType 0 =*/48).int32(message.audioEncoding);
                            if (message.sampleRateHertz != null && Object.hasOwnProperty.call(message, "sampleRateHertz"))
                                writer.uint32(/* id 7, wireType 0 =*/56).int32(message.sampleRateHertz);
                            if (message.languageCode != null && Object.hasOwnProperty.call(message, "languageCode"))
                                writer.uint32(/* id 8, wireType 2 =*/66).string(message.languageCode);
                            if (message.enableWordInfo != null && Object.hasOwnProperty.call(message, "enableWordInfo"))
                                writer.uint32(/* id 9, wireType 0 =*/72).bool(message.enableWordInfo);
                            if (message.useTimeoutBasedEndpointing != null && Object.hasOwnProperty.call(message, "useTimeoutBasedEndpointing"))
                                writer.uint32(/* id 11, wireType 0 =*/88).bool(message.useTimeoutBasedEndpointing);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SpeechToTextConfig message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SpeechToTextConfig.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SpeechToTextConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISpeechToTextConfig} message SpeechToTextConfig message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SpeechToTextConfig.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SpeechToTextConfig message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.SpeechToTextConfig
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.SpeechToTextConfig} SpeechToTextConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SpeechToTextConfig.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.SpeechToTextConfig();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.speechModelVariant = reader.int32();
                                        break;
                                    }
                                case 2: {
                                        message.model = reader.string();
                                        break;
                                    }
                                case 4: {
                                        if (!(message.phraseSets && message.phraseSets.length))
                                            message.phraseSets = [];
                                        message.phraseSets.push(reader.string());
                                        break;
                                    }
                                case 6: {
                                        message.audioEncoding = reader.int32();
                                        break;
                                    }
                                case 7: {
                                        message.sampleRateHertz = reader.int32();
                                        break;
                                    }
                                case 8: {
                                        message.languageCode = reader.string();
                                        break;
                                    }
                                case 9: {
                                        message.enableWordInfo = reader.bool();
                                        break;
                                    }
                                case 11: {
                                        message.useTimeoutBasedEndpointing = reader.bool();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SpeechToTextConfig message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SpeechToTextConfig
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.SpeechToTextConfig} SpeechToTextConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SpeechToTextConfig.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SpeechToTextConfig message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.SpeechToTextConfig
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SpeechToTextConfig.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.speechModelVariant != null && message.hasOwnProperty("speechModelVariant"))
                                switch (message.speechModelVariant) {
                                default:
                                    return "speechModelVariant: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                    break;
                                }
                            if (message.model != null && message.hasOwnProperty("model"))
                                if (!$util.isString(message.model))
                                    return "model: string expected";
                            if (message.phraseSets != null && message.hasOwnProperty("phraseSets")) {
                                if (!Array.isArray(message.phraseSets))
                                    return "phraseSets: array expected";
                                for (var i = 0; i < message.phraseSets.length; ++i)
                                    if (!$util.isString(message.phraseSets[i]))
                                        return "phraseSets: string[] expected";
                            }
                            if (message.audioEncoding != null && message.hasOwnProperty("audioEncoding"))
                                switch (message.audioEncoding) {
                                default:
                                    return "audioEncoding: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                case 4:
                                case 5:
                                case 6:
                                case 7:
                                case 8:
                                    break;
                                }
                            if (message.sampleRateHertz != null && message.hasOwnProperty("sampleRateHertz"))
                                if (!$util.isInteger(message.sampleRateHertz))
                                    return "sampleRateHertz: integer expected";
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                if (!$util.isString(message.languageCode))
                                    return "languageCode: string expected";
                            if (message.enableWordInfo != null && message.hasOwnProperty("enableWordInfo"))
                                if (typeof message.enableWordInfo !== "boolean")
                                    return "enableWordInfo: boolean expected";
                            if (message.useTimeoutBasedEndpointing != null && message.hasOwnProperty("useTimeoutBasedEndpointing"))
                                if (typeof message.useTimeoutBasedEndpointing !== "boolean")
                                    return "useTimeoutBasedEndpointing: boolean expected";
                            return null;
                        };
    
                        /**
                         * Creates a SpeechToTextConfig message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.SpeechToTextConfig
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.SpeechToTextConfig} SpeechToTextConfig
                         */
                        SpeechToTextConfig.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.SpeechToTextConfig)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.SpeechToTextConfig();
                            switch (object.speechModelVariant) {
                            default:
                                if (typeof object.speechModelVariant === "number") {
                                    message.speechModelVariant = object.speechModelVariant;
                                    break;
                                }
                                break;
                            case "SPEECH_MODEL_VARIANT_UNSPECIFIED":
                            case 0:
                                message.speechModelVariant = 0;
                                break;
                            case "USE_BEST_AVAILABLE":
                            case 1:
                                message.speechModelVariant = 1;
                                break;
                            case "USE_STANDARD":
                            case 2:
                                message.speechModelVariant = 2;
                                break;
                            case "USE_ENHANCED":
                            case 3:
                                message.speechModelVariant = 3;
                                break;
                            }
                            if (object.model != null)
                                message.model = String(object.model);
                            if (object.phraseSets) {
                                if (!Array.isArray(object.phraseSets))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.SpeechToTextConfig.phraseSets: array expected");
                                message.phraseSets = [];
                                for (var i = 0; i < object.phraseSets.length; ++i)
                                    message.phraseSets[i] = String(object.phraseSets[i]);
                            }
                            switch (object.audioEncoding) {
                            default:
                                if (typeof object.audioEncoding === "number") {
                                    message.audioEncoding = object.audioEncoding;
                                    break;
                                }
                                break;
                            case "AUDIO_ENCODING_UNSPECIFIED":
                            case 0:
                                message.audioEncoding = 0;
                                break;
                            case "AUDIO_ENCODING_LINEAR_16":
                            case 1:
                                message.audioEncoding = 1;
                                break;
                            case "AUDIO_ENCODING_FLAC":
                            case 2:
                                message.audioEncoding = 2;
                                break;
                            case "AUDIO_ENCODING_MULAW":
                            case 3:
                                message.audioEncoding = 3;
                                break;
                            case "AUDIO_ENCODING_AMR":
                            case 4:
                                message.audioEncoding = 4;
                                break;
                            case "AUDIO_ENCODING_AMR_WB":
                            case 5:
                                message.audioEncoding = 5;
                                break;
                            case "AUDIO_ENCODING_OGG_OPUS":
                            case 6:
                                message.audioEncoding = 6;
                                break;
                            case "AUDIO_ENCODING_SPEEX_WITH_HEADER_BYTE":
                            case 7:
                                message.audioEncoding = 7;
                                break;
                            case "AUDIO_ENCODING_ALAW":
                            case 8:
                                message.audioEncoding = 8;
                                break;
                            }
                            if (object.sampleRateHertz != null)
                                message.sampleRateHertz = object.sampleRateHertz | 0;
                            if (object.languageCode != null)
                                message.languageCode = String(object.languageCode);
                            if (object.enableWordInfo != null)
                                message.enableWordInfo = Boolean(object.enableWordInfo);
                            if (object.useTimeoutBasedEndpointing != null)
                                message.useTimeoutBasedEndpointing = Boolean(object.useTimeoutBasedEndpointing);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SpeechToTextConfig message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.SpeechToTextConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.SpeechToTextConfig} message SpeechToTextConfig
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SpeechToTextConfig.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.phraseSets = [];
                            if (options.defaults) {
                                object.speechModelVariant = options.enums === String ? "SPEECH_MODEL_VARIANT_UNSPECIFIED" : 0;
                                object.model = "";
                                object.audioEncoding = options.enums === String ? "AUDIO_ENCODING_UNSPECIFIED" : 0;
                                object.sampleRateHertz = 0;
                                object.languageCode = "";
                                object.enableWordInfo = false;
                                object.useTimeoutBasedEndpointing = false;
                            }
                            if (message.speechModelVariant != null && message.hasOwnProperty("speechModelVariant"))
                                object.speechModelVariant = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.SpeechModelVariant[message.speechModelVariant] === undefined ? message.speechModelVariant : $root.google.cloud.dialogflow.v2beta1.SpeechModelVariant[message.speechModelVariant] : message.speechModelVariant;
                            if (message.model != null && message.hasOwnProperty("model"))
                                object.model = message.model;
                            if (message.phraseSets && message.phraseSets.length) {
                                object.phraseSets = [];
                                for (var j = 0; j < message.phraseSets.length; ++j)
                                    object.phraseSets[j] = message.phraseSets[j];
                            }
                            if (message.audioEncoding != null && message.hasOwnProperty("audioEncoding"))
                                object.audioEncoding = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.AudioEncoding[message.audioEncoding] === undefined ? message.audioEncoding : $root.google.cloud.dialogflow.v2beta1.AudioEncoding[message.audioEncoding] : message.audioEncoding;
                            if (message.sampleRateHertz != null && message.hasOwnProperty("sampleRateHertz"))
                                object.sampleRateHertz = message.sampleRateHertz;
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                object.languageCode = message.languageCode;
                            if (message.enableWordInfo != null && message.hasOwnProperty("enableWordInfo"))
                                object.enableWordInfo = message.enableWordInfo;
                            if (message.useTimeoutBasedEndpointing != null && message.hasOwnProperty("useTimeoutBasedEndpointing"))
                                object.useTimeoutBasedEndpointing = message.useTimeoutBasedEndpointing;
                            return object;
                        };
    
                        /**
                         * Converts this SpeechToTextConfig to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.SpeechToTextConfig
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SpeechToTextConfig.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SpeechToTextConfig
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.SpeechToTextConfig
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SpeechToTextConfig.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.SpeechToTextConfig";
                        };
    
                        return SpeechToTextConfig;
                    })();
    
                    /**
                     * TelephonyDtmf enum.
                     * @name google.cloud.dialogflow.v2beta1.TelephonyDtmf
                     * @enum {number}
                     * @property {number} TELEPHONY_DTMF_UNSPECIFIED=0 TELEPHONY_DTMF_UNSPECIFIED value
                     * @property {number} DTMF_ONE=1 DTMF_ONE value
                     * @property {number} DTMF_TWO=2 DTMF_TWO value
                     * @property {number} DTMF_THREE=3 DTMF_THREE value
                     * @property {number} DTMF_FOUR=4 DTMF_FOUR value
                     * @property {number} DTMF_FIVE=5 DTMF_FIVE value
                     * @property {number} DTMF_SIX=6 DTMF_SIX value
                     * @property {number} DTMF_SEVEN=7 DTMF_SEVEN value
                     * @property {number} DTMF_EIGHT=8 DTMF_EIGHT value
                     * @property {number} DTMF_NINE=9 DTMF_NINE value
                     * @property {number} DTMF_ZERO=10 DTMF_ZERO value
                     * @property {number} DTMF_A=11 DTMF_A value
                     * @property {number} DTMF_B=12 DTMF_B value
                     * @property {number} DTMF_C=13 DTMF_C value
                     * @property {number} DTMF_D=14 DTMF_D value
                     * @property {number} DTMF_STAR=15 DTMF_STAR value
                     * @property {number} DTMF_POUND=16 DTMF_POUND value
                     */
                    v2beta1.TelephonyDtmf = (function() {
                        var valuesById = {}, values = Object.create(valuesById);
                        values[valuesById[0] = "TELEPHONY_DTMF_UNSPECIFIED"] = 0;
                        values[valuesById[1] = "DTMF_ONE"] = 1;
                        values[valuesById[2] = "DTMF_TWO"] = 2;
                        values[valuesById[3] = "DTMF_THREE"] = 3;
                        values[valuesById[4] = "DTMF_FOUR"] = 4;
                        values[valuesById[5] = "DTMF_FIVE"] = 5;
                        values[valuesById[6] = "DTMF_SIX"] = 6;
                        values[valuesById[7] = "DTMF_SEVEN"] = 7;
                        values[valuesById[8] = "DTMF_EIGHT"] = 8;
                        values[valuesById[9] = "DTMF_NINE"] = 9;
                        values[valuesById[10] = "DTMF_ZERO"] = 10;
                        values[valuesById[11] = "DTMF_A"] = 11;
                        values[valuesById[12] = "DTMF_B"] = 12;
                        values[valuesById[13] = "DTMF_C"] = 13;
                        values[valuesById[14] = "DTMF_D"] = 14;
                        values[valuesById[15] = "DTMF_STAR"] = 15;
                        values[valuesById[16] = "DTMF_POUND"] = 16;
                        return values;
                    })();
    
                    /**
                     * AudioEncoding enum.
                     * @name google.cloud.dialogflow.v2beta1.AudioEncoding
                     * @enum {number}
                     * @property {number} AUDIO_ENCODING_UNSPECIFIED=0 AUDIO_ENCODING_UNSPECIFIED value
                     * @property {number} AUDIO_ENCODING_LINEAR_16=1 AUDIO_ENCODING_LINEAR_16 value
                     * @property {number} AUDIO_ENCODING_FLAC=2 AUDIO_ENCODING_FLAC value
                     * @property {number} AUDIO_ENCODING_MULAW=3 AUDIO_ENCODING_MULAW value
                     * @property {number} AUDIO_ENCODING_AMR=4 AUDIO_ENCODING_AMR value
                     * @property {number} AUDIO_ENCODING_AMR_WB=5 AUDIO_ENCODING_AMR_WB value
                     * @property {number} AUDIO_ENCODING_OGG_OPUS=6 AUDIO_ENCODING_OGG_OPUS value
                     * @property {number} AUDIO_ENCODING_SPEEX_WITH_HEADER_BYTE=7 AUDIO_ENCODING_SPEEX_WITH_HEADER_BYTE value
                     * @property {number} AUDIO_ENCODING_ALAW=8 AUDIO_ENCODING_ALAW value
                     */
                    v2beta1.AudioEncoding = (function() {
                        var valuesById = {}, values = Object.create(valuesById);
                        values[valuesById[0] = "AUDIO_ENCODING_UNSPECIFIED"] = 0;
                        values[valuesById[1] = "AUDIO_ENCODING_LINEAR_16"] = 1;
                        values[valuesById[2] = "AUDIO_ENCODING_FLAC"] = 2;
                        values[valuesById[3] = "AUDIO_ENCODING_MULAW"] = 3;
                        values[valuesById[4] = "AUDIO_ENCODING_AMR"] = 4;
                        values[valuesById[5] = "AUDIO_ENCODING_AMR_WB"] = 5;
                        values[valuesById[6] = "AUDIO_ENCODING_OGG_OPUS"] = 6;
                        values[valuesById[7] = "AUDIO_ENCODING_SPEEX_WITH_HEADER_BYTE"] = 7;
                        values[valuesById[8] = "AUDIO_ENCODING_ALAW"] = 8;
                        return values;
                    })();
    
                    /**
                     * SpeechModelVariant enum.
                     * @name google.cloud.dialogflow.v2beta1.SpeechModelVariant
                     * @enum {number}
                     * @property {number} SPEECH_MODEL_VARIANT_UNSPECIFIED=0 SPEECH_MODEL_VARIANT_UNSPECIFIED value
                     * @property {number} USE_BEST_AVAILABLE=1 USE_BEST_AVAILABLE value
                     * @property {number} USE_STANDARD=2 USE_STANDARD value
                     * @property {number} USE_ENHANCED=3 USE_ENHANCED value
                     */
                    v2beta1.SpeechModelVariant = (function() {
                        var valuesById = {}, values = Object.create(valuesById);
                        values[valuesById[0] = "SPEECH_MODEL_VARIANT_UNSPECIFIED"] = 0;
                        values[valuesById[1] = "USE_BEST_AVAILABLE"] = 1;
                        values[valuesById[2] = "USE_STANDARD"] = 2;
                        values[valuesById[3] = "USE_ENHANCED"] = 3;
                        return values;
                    })();
    
                    /**
                     * SsmlVoiceGender enum.
                     * @name google.cloud.dialogflow.v2beta1.SsmlVoiceGender
                     * @enum {number}
                     * @property {number} SSML_VOICE_GENDER_UNSPECIFIED=0 SSML_VOICE_GENDER_UNSPECIFIED value
                     * @property {number} SSML_VOICE_GENDER_MALE=1 SSML_VOICE_GENDER_MALE value
                     * @property {number} SSML_VOICE_GENDER_FEMALE=2 SSML_VOICE_GENDER_FEMALE value
                     * @property {number} SSML_VOICE_GENDER_NEUTRAL=3 SSML_VOICE_GENDER_NEUTRAL value
                     */
                    v2beta1.SsmlVoiceGender = (function() {
                        var valuesById = {}, values = Object.create(valuesById);
                        values[valuesById[0] = "SSML_VOICE_GENDER_UNSPECIFIED"] = 0;
                        values[valuesById[1] = "SSML_VOICE_GENDER_MALE"] = 1;
                        values[valuesById[2] = "SSML_VOICE_GENDER_FEMALE"] = 2;
                        values[valuesById[3] = "SSML_VOICE_GENDER_NEUTRAL"] = 3;
                        return values;
                    })();
    
                    /**
                     * OutputAudioEncoding enum.
                     * @name google.cloud.dialogflow.v2beta1.OutputAudioEncoding
                     * @enum {number}
                     * @property {number} OUTPUT_AUDIO_ENCODING_UNSPECIFIED=0 OUTPUT_AUDIO_ENCODING_UNSPECIFIED value
                     * @property {number} OUTPUT_AUDIO_ENCODING_LINEAR_16=1 OUTPUT_AUDIO_ENCODING_LINEAR_16 value
                     * @property {number} OUTPUT_AUDIO_ENCODING_MP3=2 OUTPUT_AUDIO_ENCODING_MP3 value
                     * @property {number} OUTPUT_AUDIO_ENCODING_MP3_64_KBPS=4 OUTPUT_AUDIO_ENCODING_MP3_64_KBPS value
                     * @property {number} OUTPUT_AUDIO_ENCODING_OGG_OPUS=3 OUTPUT_AUDIO_ENCODING_OGG_OPUS value
                     * @property {number} OUTPUT_AUDIO_ENCODING_MULAW=5 OUTPUT_AUDIO_ENCODING_MULAW value
                     * @property {number} OUTPUT_AUDIO_ENCODING_ALAW=6 OUTPUT_AUDIO_ENCODING_ALAW value
                     */
                    v2beta1.OutputAudioEncoding = (function() {
                        var valuesById = {}, values = Object.create(valuesById);
                        values[valuesById[0] = "OUTPUT_AUDIO_ENCODING_UNSPECIFIED"] = 0;
                        values[valuesById[1] = "OUTPUT_AUDIO_ENCODING_LINEAR_16"] = 1;
                        values[valuesById[2] = "OUTPUT_AUDIO_ENCODING_MP3"] = 2;
                        values[valuesById[4] = "OUTPUT_AUDIO_ENCODING_MP3_64_KBPS"] = 4;
                        values[valuesById[3] = "OUTPUT_AUDIO_ENCODING_OGG_OPUS"] = 3;
                        values[valuesById[5] = "OUTPUT_AUDIO_ENCODING_MULAW"] = 5;
                        values[valuesById[6] = "OUTPUT_AUDIO_ENCODING_ALAW"] = 6;
                        return values;
                    })();
    
                    v2beta1.Generators = (function() {
    
                        /**
                         * Constructs a new Generators service.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a Generators
                         * @extends $protobuf.rpc.Service
                         * @constructor
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         */
                        function Generators(rpcImpl, requestDelimited, responseDelimited) {
                            $protobuf.rpc.Service.call(this, rpcImpl, requestDelimited, responseDelimited);
                        }
    
                        (Generators.prototype = Object.create($protobuf.rpc.Service.prototype)).constructor = Generators;
    
                        /**
                         * Creates new Generators service using the specified rpc implementation.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.Generators
                         * @static
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         * @returns {Generators} RPC service. Useful where requests and/or responses are streamed.
                         */
                        Generators.create = function create(rpcImpl, requestDelimited, responseDelimited) {
                            return new this(rpcImpl, requestDelimited, responseDelimited);
                        };
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Generators|createGenerator}.
                         * @memberof google.cloud.dialogflow.v2beta1.Generators
                         * @typedef CreateGeneratorCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.Generator} [response] Generator
                         */
    
                        /**
                         * Calls CreateGenerator.
                         * @function createGenerator
                         * @memberof google.cloud.dialogflow.v2beta1.Generators
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.ICreateGeneratorRequest} request CreateGeneratorRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Generators.CreateGeneratorCallback} callback Node-style callback called with the error, if any, and Generator
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Generators.prototype.createGenerator = function createGenerator(request, callback) {
                            return this.rpcCall(createGenerator, $root.google.cloud.dialogflow.v2beta1.CreateGeneratorRequest, $root.google.cloud.dialogflow.v2beta1.Generator, request, callback);
                        }, "name", { value: "CreateGenerator" });
    
                        /**
                         * Calls CreateGenerator.
                         * @function createGenerator
                         * @memberof google.cloud.dialogflow.v2beta1.Generators
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.ICreateGeneratorRequest} request CreateGeneratorRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.Generator>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Generators|getGenerator}.
                         * @memberof google.cloud.dialogflow.v2beta1.Generators
                         * @typedef GetGeneratorCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.Generator} [response] Generator
                         */
    
                        /**
                         * Calls GetGenerator.
                         * @function getGenerator
                         * @memberof google.cloud.dialogflow.v2beta1.Generators
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IGetGeneratorRequest} request GetGeneratorRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Generators.GetGeneratorCallback} callback Node-style callback called with the error, if any, and Generator
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Generators.prototype.getGenerator = function getGenerator(request, callback) {
                            return this.rpcCall(getGenerator, $root.google.cloud.dialogflow.v2beta1.GetGeneratorRequest, $root.google.cloud.dialogflow.v2beta1.Generator, request, callback);
                        }, "name", { value: "GetGenerator" });
    
                        /**
                         * Calls GetGenerator.
                         * @function getGenerator
                         * @memberof google.cloud.dialogflow.v2beta1.Generators
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IGetGeneratorRequest} request GetGeneratorRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.Generator>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Generators|listGenerators}.
                         * @memberof google.cloud.dialogflow.v2beta1.Generators
                         * @typedef ListGeneratorsCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.ListGeneratorsResponse} [response] ListGeneratorsResponse
                         */
    
                        /**
                         * Calls ListGenerators.
                         * @function listGenerators
                         * @memberof google.cloud.dialogflow.v2beta1.Generators
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IListGeneratorsRequest} request ListGeneratorsRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Generators.ListGeneratorsCallback} callback Node-style callback called with the error, if any, and ListGeneratorsResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Generators.prototype.listGenerators = function listGenerators(request, callback) {
                            return this.rpcCall(listGenerators, $root.google.cloud.dialogflow.v2beta1.ListGeneratorsRequest, $root.google.cloud.dialogflow.v2beta1.ListGeneratorsResponse, request, callback);
                        }, "name", { value: "ListGenerators" });
    
                        /**
                         * Calls ListGenerators.
                         * @function listGenerators
                         * @memberof google.cloud.dialogflow.v2beta1.Generators
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IListGeneratorsRequest} request ListGeneratorsRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.ListGeneratorsResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Generators|deleteGenerator}.
                         * @memberof google.cloud.dialogflow.v2beta1.Generators
                         * @typedef DeleteGeneratorCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.protobuf.Empty} [response] Empty
                         */
    
                        /**
                         * Calls DeleteGenerator.
                         * @function deleteGenerator
                         * @memberof google.cloud.dialogflow.v2beta1.Generators
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteGeneratorRequest} request DeleteGeneratorRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Generators.DeleteGeneratorCallback} callback Node-style callback called with the error, if any, and Empty
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Generators.prototype.deleteGenerator = function deleteGenerator(request, callback) {
                            return this.rpcCall(deleteGenerator, $root.google.cloud.dialogflow.v2beta1.DeleteGeneratorRequest, $root.google.protobuf.Empty, request, callback);
                        }, "name", { value: "DeleteGenerator" });
    
                        /**
                         * Calls DeleteGenerator.
                         * @function deleteGenerator
                         * @memberof google.cloud.dialogflow.v2beta1.Generators
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteGeneratorRequest} request DeleteGeneratorRequest message or plain object
                         * @returns {Promise<google.protobuf.Empty>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Generators|updateGenerator}.
                         * @memberof google.cloud.dialogflow.v2beta1.Generators
                         * @typedef UpdateGeneratorCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.Generator} [response] Generator
                         */
    
                        /**
                         * Calls UpdateGenerator.
                         * @function updateGenerator
                         * @memberof google.cloud.dialogflow.v2beta1.Generators
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateGeneratorRequest} request UpdateGeneratorRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Generators.UpdateGeneratorCallback} callback Node-style callback called with the error, if any, and Generator
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Generators.prototype.updateGenerator = function updateGenerator(request, callback) {
                            return this.rpcCall(updateGenerator, $root.google.cloud.dialogflow.v2beta1.UpdateGeneratorRequest, $root.google.cloud.dialogflow.v2beta1.Generator, request, callback);
                        }, "name", { value: "UpdateGenerator" });
    
                        /**
                         * Calls UpdateGenerator.
                         * @function updateGenerator
                         * @memberof google.cloud.dialogflow.v2beta1.Generators
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateGeneratorRequest} request UpdateGeneratorRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.Generator>} Promise
                         * @variation 2
                         */
    
                        return Generators;
                    })();
    
                    v2beta1.CreateGeneratorRequest = (function() {
    
                        /**
                         * Properties of a CreateGeneratorRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ICreateGeneratorRequest
                         * @property {string|null} [parent] CreateGeneratorRequest parent
                         * @property {google.cloud.dialogflow.v2beta1.IGenerator|null} [generator] CreateGeneratorRequest generator
                         * @property {string|null} [generatorId] CreateGeneratorRequest generatorId
                         */
    
                        /**
                         * Constructs a new CreateGeneratorRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a CreateGeneratorRequest.
                         * @implements ICreateGeneratorRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ICreateGeneratorRequest=} [properties] Properties to set
                         */
                        function CreateGeneratorRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * CreateGeneratorRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.CreateGeneratorRequest
                         * @instance
                         */
                        CreateGeneratorRequest.prototype.parent = "";
    
                        /**
                         * CreateGeneratorRequest generator.
                         * @member {google.cloud.dialogflow.v2beta1.IGenerator|null|undefined} generator
                         * @memberof google.cloud.dialogflow.v2beta1.CreateGeneratorRequest
                         * @instance
                         */
                        CreateGeneratorRequest.prototype.generator = null;
    
                        /**
                         * CreateGeneratorRequest generatorId.
                         * @member {string} generatorId
                         * @memberof google.cloud.dialogflow.v2beta1.CreateGeneratorRequest
                         * @instance
                         */
                        CreateGeneratorRequest.prototype.generatorId = "";
    
                        /**
                         * Creates a new CreateGeneratorRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.CreateGeneratorRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ICreateGeneratorRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.CreateGeneratorRequest} CreateGeneratorRequest instance
                         */
                        CreateGeneratorRequest.create = function create(properties) {
                            return new CreateGeneratorRequest(properties);
                        };
    
                        /**
                         * Encodes the specified CreateGeneratorRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.CreateGeneratorRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.CreateGeneratorRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ICreateGeneratorRequest} message CreateGeneratorRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateGeneratorRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.generator != null && Object.hasOwnProperty.call(message, "generator"))
                                $root.google.cloud.dialogflow.v2beta1.Generator.encode(message.generator, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.generatorId != null && Object.hasOwnProperty.call(message, "generatorId"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.generatorId);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified CreateGeneratorRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.CreateGeneratorRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.CreateGeneratorRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ICreateGeneratorRequest} message CreateGeneratorRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateGeneratorRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a CreateGeneratorRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.CreateGeneratorRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.CreateGeneratorRequest} CreateGeneratorRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateGeneratorRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.CreateGeneratorRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.generator = $root.google.cloud.dialogflow.v2beta1.Generator.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 3: {
                                        message.generatorId = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a CreateGeneratorRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.CreateGeneratorRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.CreateGeneratorRequest} CreateGeneratorRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateGeneratorRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a CreateGeneratorRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.CreateGeneratorRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        CreateGeneratorRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.generator != null && message.hasOwnProperty("generator")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.Generator.verify(message.generator);
                                if (error)
                                    return "generator." + error;
                            }
                            if (message.generatorId != null && message.hasOwnProperty("generatorId"))
                                if (!$util.isString(message.generatorId))
                                    return "generatorId: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a CreateGeneratorRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.CreateGeneratorRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.CreateGeneratorRequest} CreateGeneratorRequest
                         */
                        CreateGeneratorRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.CreateGeneratorRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.CreateGeneratorRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.generator != null) {
                                if (typeof object.generator !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.CreateGeneratorRequest.generator: object expected");
                                message.generator = $root.google.cloud.dialogflow.v2beta1.Generator.fromObject(object.generator);
                            }
                            if (object.generatorId != null)
                                message.generatorId = String(object.generatorId);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a CreateGeneratorRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.CreateGeneratorRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.CreateGeneratorRequest} message CreateGeneratorRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        CreateGeneratorRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.generator = null;
                                object.generatorId = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.generator != null && message.hasOwnProperty("generator"))
                                object.generator = $root.google.cloud.dialogflow.v2beta1.Generator.toObject(message.generator, options);
                            if (message.generatorId != null && message.hasOwnProperty("generatorId"))
                                object.generatorId = message.generatorId;
                            return object;
                        };
    
                        /**
                         * Converts this CreateGeneratorRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.CreateGeneratorRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        CreateGeneratorRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for CreateGeneratorRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.CreateGeneratorRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        CreateGeneratorRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.CreateGeneratorRequest";
                        };
    
                        return CreateGeneratorRequest;
                    })();
    
                    v2beta1.GetGeneratorRequest = (function() {
    
                        /**
                         * Properties of a GetGeneratorRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IGetGeneratorRequest
                         * @property {string|null} [name] GetGeneratorRequest name
                         */
    
                        /**
                         * Constructs a new GetGeneratorRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a GetGeneratorRequest.
                         * @implements IGetGeneratorRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IGetGeneratorRequest=} [properties] Properties to set
                         */
                        function GetGeneratorRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GetGeneratorRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2beta1.GetGeneratorRequest
                         * @instance
                         */
                        GetGeneratorRequest.prototype.name = "";
    
                        /**
                         * Creates a new GetGeneratorRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.GetGeneratorRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetGeneratorRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.GetGeneratorRequest} GetGeneratorRequest instance
                         */
                        GetGeneratorRequest.create = function create(properties) {
                            return new GetGeneratorRequest(properties);
                        };
    
                        /**
                         * Encodes the specified GetGeneratorRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GetGeneratorRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.GetGeneratorRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetGeneratorRequest} message GetGeneratorRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetGeneratorRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GetGeneratorRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GetGeneratorRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GetGeneratorRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetGeneratorRequest} message GetGeneratorRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetGeneratorRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GetGeneratorRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.GetGeneratorRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.GetGeneratorRequest} GetGeneratorRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetGeneratorRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.GetGeneratorRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GetGeneratorRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GetGeneratorRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.GetGeneratorRequest} GetGeneratorRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetGeneratorRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GetGeneratorRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.GetGeneratorRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GetGeneratorRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a GetGeneratorRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.GetGeneratorRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.GetGeneratorRequest} GetGeneratorRequest
                         */
                        GetGeneratorRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.GetGeneratorRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.GetGeneratorRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GetGeneratorRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.GetGeneratorRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.GetGeneratorRequest} message GetGeneratorRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GetGeneratorRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.name = "";
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            return object;
                        };
    
                        /**
                         * Converts this GetGeneratorRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.GetGeneratorRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GetGeneratorRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GetGeneratorRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.GetGeneratorRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GetGeneratorRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.GetGeneratorRequest";
                        };
    
                        return GetGeneratorRequest;
                    })();
    
                    v2beta1.ListGeneratorsRequest = (function() {
    
                        /**
                         * Properties of a ListGeneratorsRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IListGeneratorsRequest
                         * @property {string|null} [parent] ListGeneratorsRequest parent
                         * @property {number|null} [pageSize] ListGeneratorsRequest pageSize
                         * @property {string|null} [pageToken] ListGeneratorsRequest pageToken
                         */
    
                        /**
                         * Constructs a new ListGeneratorsRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a ListGeneratorsRequest.
                         * @implements IListGeneratorsRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IListGeneratorsRequest=} [properties] Properties to set
                         */
                        function ListGeneratorsRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListGeneratorsRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.ListGeneratorsRequest
                         * @instance
                         */
                        ListGeneratorsRequest.prototype.parent = "";
    
                        /**
                         * ListGeneratorsRequest pageSize.
                         * @member {number} pageSize
                         * @memberof google.cloud.dialogflow.v2beta1.ListGeneratorsRequest
                         * @instance
                         */
                        ListGeneratorsRequest.prototype.pageSize = 0;
    
                        /**
                         * ListGeneratorsRequest pageToken.
                         * @member {string} pageToken
                         * @memberof google.cloud.dialogflow.v2beta1.ListGeneratorsRequest
                         * @instance
                         */
                        ListGeneratorsRequest.prototype.pageToken = "";
    
                        /**
                         * Creates a new ListGeneratorsRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.ListGeneratorsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListGeneratorsRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.ListGeneratorsRequest} ListGeneratorsRequest instance
                         */
                        ListGeneratorsRequest.create = function create(properties) {
                            return new ListGeneratorsRequest(properties);
                        };
    
                        /**
                         * Encodes the specified ListGeneratorsRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListGeneratorsRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.ListGeneratorsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListGeneratorsRequest} message ListGeneratorsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListGeneratorsRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.pageSize != null && Object.hasOwnProperty.call(message, "pageSize"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.pageSize);
                            if (message.pageToken != null && Object.hasOwnProperty.call(message, "pageToken"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.pageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListGeneratorsRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListGeneratorsRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListGeneratorsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListGeneratorsRequest} message ListGeneratorsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListGeneratorsRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListGeneratorsRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.ListGeneratorsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.ListGeneratorsRequest} ListGeneratorsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListGeneratorsRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ListGeneratorsRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.pageSize = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.pageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListGeneratorsRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListGeneratorsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.ListGeneratorsRequest} ListGeneratorsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListGeneratorsRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListGeneratorsRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.ListGeneratorsRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListGeneratorsRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                if (!$util.isInteger(message.pageSize))
                                    return "pageSize: integer expected";
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                if (!$util.isString(message.pageToken))
                                    return "pageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListGeneratorsRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListGeneratorsRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.ListGeneratorsRequest} ListGeneratorsRequest
                         */
                        ListGeneratorsRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.ListGeneratorsRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.ListGeneratorsRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.pageSize != null)
                                message.pageSize = object.pageSize | 0;
                            if (object.pageToken != null)
                                message.pageToken = String(object.pageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListGeneratorsRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListGeneratorsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ListGeneratorsRequest} message ListGeneratorsRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListGeneratorsRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.pageSize = 0;
                                object.pageToken = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                object.pageSize = message.pageSize;
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                object.pageToken = message.pageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListGeneratorsRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.ListGeneratorsRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListGeneratorsRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListGeneratorsRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.ListGeneratorsRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListGeneratorsRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ListGeneratorsRequest";
                        };
    
                        return ListGeneratorsRequest;
                    })();
    
                    v2beta1.ListGeneratorsResponse = (function() {
    
                        /**
                         * Properties of a ListGeneratorsResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IListGeneratorsResponse
                         * @property {Array.<google.cloud.dialogflow.v2beta1.IGenerator>|null} [generators] ListGeneratorsResponse generators
                         * @property {string|null} [nextPageToken] ListGeneratorsResponse nextPageToken
                         */
    
                        /**
                         * Constructs a new ListGeneratorsResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a ListGeneratorsResponse.
                         * @implements IListGeneratorsResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IListGeneratorsResponse=} [properties] Properties to set
                         */
                        function ListGeneratorsResponse(properties) {
                            this.generators = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListGeneratorsResponse generators.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.IGenerator>} generators
                         * @memberof google.cloud.dialogflow.v2beta1.ListGeneratorsResponse
                         * @instance
                         */
                        ListGeneratorsResponse.prototype.generators = $util.emptyArray;
    
                        /**
                         * ListGeneratorsResponse nextPageToken.
                         * @member {string} nextPageToken
                         * @memberof google.cloud.dialogflow.v2beta1.ListGeneratorsResponse
                         * @instance
                         */
                        ListGeneratorsResponse.prototype.nextPageToken = "";
    
                        /**
                         * Creates a new ListGeneratorsResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.ListGeneratorsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListGeneratorsResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.ListGeneratorsResponse} ListGeneratorsResponse instance
                         */
                        ListGeneratorsResponse.create = function create(properties) {
                            return new ListGeneratorsResponse(properties);
                        };
    
                        /**
                         * Encodes the specified ListGeneratorsResponse message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListGeneratorsResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.ListGeneratorsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListGeneratorsResponse} message ListGeneratorsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListGeneratorsResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.generators != null && message.generators.length)
                                for (var i = 0; i < message.generators.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.Generator.encode(message.generators[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.nextPageToken != null && Object.hasOwnProperty.call(message, "nextPageToken"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.nextPageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListGeneratorsResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListGeneratorsResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListGeneratorsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListGeneratorsResponse} message ListGeneratorsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListGeneratorsResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListGeneratorsResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.ListGeneratorsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.ListGeneratorsResponse} ListGeneratorsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListGeneratorsResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ListGeneratorsResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.generators && message.generators.length))
                                            message.generators = [];
                                        message.generators.push($root.google.cloud.dialogflow.v2beta1.Generator.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 2: {
                                        message.nextPageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListGeneratorsResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListGeneratorsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.ListGeneratorsResponse} ListGeneratorsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListGeneratorsResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListGeneratorsResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.ListGeneratorsResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListGeneratorsResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.generators != null && message.hasOwnProperty("generators")) {
                                if (!Array.isArray(message.generators))
                                    return "generators: array expected";
                                for (var i = 0; i < message.generators.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.Generator.verify(message.generators[i]);
                                    if (error)
                                        return "generators." + error;
                                }
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                if (!$util.isString(message.nextPageToken))
                                    return "nextPageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListGeneratorsResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListGeneratorsResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.ListGeneratorsResponse} ListGeneratorsResponse
                         */
                        ListGeneratorsResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.ListGeneratorsResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.ListGeneratorsResponse();
                            if (object.generators) {
                                if (!Array.isArray(object.generators))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.ListGeneratorsResponse.generators: array expected");
                                message.generators = [];
                                for (var i = 0; i < object.generators.length; ++i) {
                                    if (typeof object.generators[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.ListGeneratorsResponse.generators: object expected");
                                    message.generators[i] = $root.google.cloud.dialogflow.v2beta1.Generator.fromObject(object.generators[i]);
                                }
                            }
                            if (object.nextPageToken != null)
                                message.nextPageToken = String(object.nextPageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListGeneratorsResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListGeneratorsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ListGeneratorsResponse} message ListGeneratorsResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListGeneratorsResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.generators = [];
                            if (options.defaults)
                                object.nextPageToken = "";
                            if (message.generators && message.generators.length) {
                                object.generators = [];
                                for (var j = 0; j < message.generators.length; ++j)
                                    object.generators[j] = $root.google.cloud.dialogflow.v2beta1.Generator.toObject(message.generators[j], options);
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                object.nextPageToken = message.nextPageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListGeneratorsResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.ListGeneratorsResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListGeneratorsResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListGeneratorsResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.ListGeneratorsResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListGeneratorsResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ListGeneratorsResponse";
                        };
    
                        return ListGeneratorsResponse;
                    })();
    
                    v2beta1.DeleteGeneratorRequest = (function() {
    
                        /**
                         * Properties of a DeleteGeneratorRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IDeleteGeneratorRequest
                         * @property {string|null} [name] DeleteGeneratorRequest name
                         */
    
                        /**
                         * Constructs a new DeleteGeneratorRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a DeleteGeneratorRequest.
                         * @implements IDeleteGeneratorRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteGeneratorRequest=} [properties] Properties to set
                         */
                        function DeleteGeneratorRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * DeleteGeneratorRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteGeneratorRequest
                         * @instance
                         */
                        DeleteGeneratorRequest.prototype.name = "";
    
                        /**
                         * Creates a new DeleteGeneratorRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteGeneratorRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteGeneratorRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.DeleteGeneratorRequest} DeleteGeneratorRequest instance
                         */
                        DeleteGeneratorRequest.create = function create(properties) {
                            return new DeleteGeneratorRequest(properties);
                        };
    
                        /**
                         * Encodes the specified DeleteGeneratorRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.DeleteGeneratorRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteGeneratorRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteGeneratorRequest} message DeleteGeneratorRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteGeneratorRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified DeleteGeneratorRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.DeleteGeneratorRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteGeneratorRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteGeneratorRequest} message DeleteGeneratorRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteGeneratorRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a DeleteGeneratorRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteGeneratorRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.DeleteGeneratorRequest} DeleteGeneratorRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteGeneratorRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.DeleteGeneratorRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a DeleteGeneratorRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteGeneratorRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.DeleteGeneratorRequest} DeleteGeneratorRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteGeneratorRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a DeleteGeneratorRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteGeneratorRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        DeleteGeneratorRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a DeleteGeneratorRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteGeneratorRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.DeleteGeneratorRequest} DeleteGeneratorRequest
                         */
                        DeleteGeneratorRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.DeleteGeneratorRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.DeleteGeneratorRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a DeleteGeneratorRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteGeneratorRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.DeleteGeneratorRequest} message DeleteGeneratorRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        DeleteGeneratorRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.name = "";
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            return object;
                        };
    
                        /**
                         * Converts this DeleteGeneratorRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteGeneratorRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        DeleteGeneratorRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for DeleteGeneratorRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteGeneratorRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        DeleteGeneratorRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.DeleteGeneratorRequest";
                        };
    
                        return DeleteGeneratorRequest;
                    })();
    
                    v2beta1.UpdateGeneratorRequest = (function() {
    
                        /**
                         * Properties of an UpdateGeneratorRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IUpdateGeneratorRequest
                         * @property {google.cloud.dialogflow.v2beta1.IGenerator|null} [generator] UpdateGeneratorRequest generator
                         * @property {google.protobuf.IFieldMask|null} [updateMask] UpdateGeneratorRequest updateMask
                         */
    
                        /**
                         * Constructs a new UpdateGeneratorRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an UpdateGeneratorRequest.
                         * @implements IUpdateGeneratorRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateGeneratorRequest=} [properties] Properties to set
                         */
                        function UpdateGeneratorRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * UpdateGeneratorRequest generator.
                         * @member {google.cloud.dialogflow.v2beta1.IGenerator|null|undefined} generator
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateGeneratorRequest
                         * @instance
                         */
                        UpdateGeneratorRequest.prototype.generator = null;
    
                        /**
                         * UpdateGeneratorRequest updateMask.
                         * @member {google.protobuf.IFieldMask|null|undefined} updateMask
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateGeneratorRequest
                         * @instance
                         */
                        UpdateGeneratorRequest.prototype.updateMask = null;
    
                        /**
                         * Creates a new UpdateGeneratorRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateGeneratorRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateGeneratorRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.UpdateGeneratorRequest} UpdateGeneratorRequest instance
                         */
                        UpdateGeneratorRequest.create = function create(properties) {
                            return new UpdateGeneratorRequest(properties);
                        };
    
                        /**
                         * Encodes the specified UpdateGeneratorRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.UpdateGeneratorRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateGeneratorRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateGeneratorRequest} message UpdateGeneratorRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UpdateGeneratorRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.generator != null && Object.hasOwnProperty.call(message, "generator"))
                                $root.google.cloud.dialogflow.v2beta1.Generator.encode(message.generator, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.updateMask != null && Object.hasOwnProperty.call(message, "updateMask"))
                                $root.google.protobuf.FieldMask.encode(message.updateMask, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified UpdateGeneratorRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.UpdateGeneratorRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateGeneratorRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateGeneratorRequest} message UpdateGeneratorRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UpdateGeneratorRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an UpdateGeneratorRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateGeneratorRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.UpdateGeneratorRequest} UpdateGeneratorRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UpdateGeneratorRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.UpdateGeneratorRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.generator = $root.google.cloud.dialogflow.v2beta1.Generator.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.updateMask = $root.google.protobuf.FieldMask.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an UpdateGeneratorRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateGeneratorRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.UpdateGeneratorRequest} UpdateGeneratorRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UpdateGeneratorRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an UpdateGeneratorRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateGeneratorRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        UpdateGeneratorRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.generator != null && message.hasOwnProperty("generator")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.Generator.verify(message.generator);
                                if (error)
                                    return "generator." + error;
                            }
                            if (message.updateMask != null && message.hasOwnProperty("updateMask")) {
                                var error = $root.google.protobuf.FieldMask.verify(message.updateMask);
                                if (error)
                                    return "updateMask." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates an UpdateGeneratorRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateGeneratorRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.UpdateGeneratorRequest} UpdateGeneratorRequest
                         */
                        UpdateGeneratorRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.UpdateGeneratorRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.UpdateGeneratorRequest();
                            if (object.generator != null) {
                                if (typeof object.generator !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.UpdateGeneratorRequest.generator: object expected");
                                message.generator = $root.google.cloud.dialogflow.v2beta1.Generator.fromObject(object.generator);
                            }
                            if (object.updateMask != null) {
                                if (typeof object.updateMask !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.UpdateGeneratorRequest.updateMask: object expected");
                                message.updateMask = $root.google.protobuf.FieldMask.fromObject(object.updateMask);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an UpdateGeneratorRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateGeneratorRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.UpdateGeneratorRequest} message UpdateGeneratorRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        UpdateGeneratorRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.generator = null;
                                object.updateMask = null;
                            }
                            if (message.generator != null && message.hasOwnProperty("generator"))
                                object.generator = $root.google.cloud.dialogflow.v2beta1.Generator.toObject(message.generator, options);
                            if (message.updateMask != null && message.hasOwnProperty("updateMask"))
                                object.updateMask = $root.google.protobuf.FieldMask.toObject(message.updateMask, options);
                            return object;
                        };
    
                        /**
                         * Converts this UpdateGeneratorRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateGeneratorRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        UpdateGeneratorRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for UpdateGeneratorRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateGeneratorRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        UpdateGeneratorRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.UpdateGeneratorRequest";
                        };
    
                        return UpdateGeneratorRequest;
                    })();
    
                    v2beta1.MessageEntry = (function() {
    
                        /**
                         * Properties of a MessageEntry.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IMessageEntry
                         * @property {google.cloud.dialogflow.v2beta1.MessageEntry.Role|null} [role] MessageEntry role
                         * @property {string|null} [text] MessageEntry text
                         * @property {string|null} [languageCode] MessageEntry languageCode
                         * @property {google.protobuf.ITimestamp|null} [createTime] MessageEntry createTime
                         */
    
                        /**
                         * Constructs a new MessageEntry.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a MessageEntry.
                         * @implements IMessageEntry
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IMessageEntry=} [properties] Properties to set
                         */
                        function MessageEntry(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * MessageEntry role.
                         * @member {google.cloud.dialogflow.v2beta1.MessageEntry.Role} role
                         * @memberof google.cloud.dialogflow.v2beta1.MessageEntry
                         * @instance
                         */
                        MessageEntry.prototype.role = 0;
    
                        /**
                         * MessageEntry text.
                         * @member {string} text
                         * @memberof google.cloud.dialogflow.v2beta1.MessageEntry
                         * @instance
                         */
                        MessageEntry.prototype.text = "";
    
                        /**
                         * MessageEntry languageCode.
                         * @member {string} languageCode
                         * @memberof google.cloud.dialogflow.v2beta1.MessageEntry
                         * @instance
                         */
                        MessageEntry.prototype.languageCode = "";
    
                        /**
                         * MessageEntry createTime.
                         * @member {google.protobuf.ITimestamp|null|undefined} createTime
                         * @memberof google.cloud.dialogflow.v2beta1.MessageEntry
                         * @instance
                         */
                        MessageEntry.prototype.createTime = null;
    
                        /**
                         * Creates a new MessageEntry instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.MessageEntry
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IMessageEntry=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.MessageEntry} MessageEntry instance
                         */
                        MessageEntry.create = function create(properties) {
                            return new MessageEntry(properties);
                        };
    
                        /**
                         * Encodes the specified MessageEntry message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.MessageEntry.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.MessageEntry
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IMessageEntry} message MessageEntry message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        MessageEntry.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.role != null && Object.hasOwnProperty.call(message, "role"))
                                writer.uint32(/* id 1, wireType 0 =*/8).int32(message.role);
                            if (message.text != null && Object.hasOwnProperty.call(message, "text"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.text);
                            if (message.languageCode != null && Object.hasOwnProperty.call(message, "languageCode"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.languageCode);
                            if (message.createTime != null && Object.hasOwnProperty.call(message, "createTime"))
                                $root.google.protobuf.Timestamp.encode(message.createTime, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified MessageEntry message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.MessageEntry.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.MessageEntry
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IMessageEntry} message MessageEntry message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        MessageEntry.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a MessageEntry message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.MessageEntry
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.MessageEntry} MessageEntry
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        MessageEntry.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.MessageEntry();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.role = reader.int32();
                                        break;
                                    }
                                case 2: {
                                        message.text = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.languageCode = reader.string();
                                        break;
                                    }
                                case 4: {
                                        message.createTime = $root.google.protobuf.Timestamp.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a MessageEntry message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.MessageEntry
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.MessageEntry} MessageEntry
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        MessageEntry.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a MessageEntry message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.MessageEntry
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        MessageEntry.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.role != null && message.hasOwnProperty("role"))
                                switch (message.role) {
                                default:
                                    return "role: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                    break;
                                }
                            if (message.text != null && message.hasOwnProperty("text"))
                                if (!$util.isString(message.text))
                                    return "text: string expected";
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                if (!$util.isString(message.languageCode))
                                    return "languageCode: string expected";
                            if (message.createTime != null && message.hasOwnProperty("createTime")) {
                                var error = $root.google.protobuf.Timestamp.verify(message.createTime);
                                if (error)
                                    return "createTime." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a MessageEntry message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.MessageEntry
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.MessageEntry} MessageEntry
                         */
                        MessageEntry.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.MessageEntry)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.MessageEntry();
                            switch (object.role) {
                            default:
                                if (typeof object.role === "number") {
                                    message.role = object.role;
                                    break;
                                }
                                break;
                            case "ROLE_UNSPECIFIED":
                            case 0:
                                message.role = 0;
                                break;
                            case "HUMAN_AGENT":
                            case 1:
                                message.role = 1;
                                break;
                            case "AUTOMATED_AGENT":
                            case 2:
                                message.role = 2;
                                break;
                            case "END_USER":
                            case 3:
                                message.role = 3;
                                break;
                            }
                            if (object.text != null)
                                message.text = String(object.text);
                            if (object.languageCode != null)
                                message.languageCode = String(object.languageCode);
                            if (object.createTime != null) {
                                if (typeof object.createTime !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.MessageEntry.createTime: object expected");
                                message.createTime = $root.google.protobuf.Timestamp.fromObject(object.createTime);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a MessageEntry message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.MessageEntry
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.MessageEntry} message MessageEntry
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        MessageEntry.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.role = options.enums === String ? "ROLE_UNSPECIFIED" : 0;
                                object.text = "";
                                object.languageCode = "";
                                object.createTime = null;
                            }
                            if (message.role != null && message.hasOwnProperty("role"))
                                object.role = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.MessageEntry.Role[message.role] === undefined ? message.role : $root.google.cloud.dialogflow.v2beta1.MessageEntry.Role[message.role] : message.role;
                            if (message.text != null && message.hasOwnProperty("text"))
                                object.text = message.text;
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                object.languageCode = message.languageCode;
                            if (message.createTime != null && message.hasOwnProperty("createTime"))
                                object.createTime = $root.google.protobuf.Timestamp.toObject(message.createTime, options);
                            return object;
                        };
    
                        /**
                         * Converts this MessageEntry to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.MessageEntry
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        MessageEntry.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for MessageEntry
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.MessageEntry
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        MessageEntry.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.MessageEntry";
                        };
    
                        /**
                         * Role enum.
                         * @name google.cloud.dialogflow.v2beta1.MessageEntry.Role
                         * @enum {number}
                         * @property {number} ROLE_UNSPECIFIED=0 ROLE_UNSPECIFIED value
                         * @property {number} HUMAN_AGENT=1 HUMAN_AGENT value
                         * @property {number} AUTOMATED_AGENT=2 AUTOMATED_AGENT value
                         * @property {number} END_USER=3 END_USER value
                         */
                        MessageEntry.Role = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "ROLE_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "HUMAN_AGENT"] = 1;
                            values[valuesById[2] = "AUTOMATED_AGENT"] = 2;
                            values[valuesById[3] = "END_USER"] = 3;
                            return values;
                        })();
    
                        return MessageEntry;
                    })();
    
                    v2beta1.ConversationContext = (function() {
    
                        /**
                         * Properties of a ConversationContext.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IConversationContext
                         * @property {Array.<google.cloud.dialogflow.v2beta1.IMessageEntry>|null} [messageEntries] ConversationContext messageEntries
                         */
    
                        /**
                         * Constructs a new ConversationContext.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a ConversationContext.
                         * @implements IConversationContext
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IConversationContext=} [properties] Properties to set
                         */
                        function ConversationContext(properties) {
                            this.messageEntries = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ConversationContext messageEntries.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.IMessageEntry>} messageEntries
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationContext
                         * @instance
                         */
                        ConversationContext.prototype.messageEntries = $util.emptyArray;
    
                        /**
                         * Creates a new ConversationContext instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationContext
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IConversationContext=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.ConversationContext} ConversationContext instance
                         */
                        ConversationContext.create = function create(properties) {
                            return new ConversationContext(properties);
                        };
    
                        /**
                         * Encodes the specified ConversationContext message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ConversationContext.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationContext
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IConversationContext} message ConversationContext message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ConversationContext.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.messageEntries != null && message.messageEntries.length)
                                for (var i = 0; i < message.messageEntries.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.MessageEntry.encode(message.messageEntries[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ConversationContext message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ConversationContext.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationContext
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IConversationContext} message ConversationContext message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ConversationContext.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ConversationContext message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationContext
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.ConversationContext} ConversationContext
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ConversationContext.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ConversationContext();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.messageEntries && message.messageEntries.length))
                                            message.messageEntries = [];
                                        message.messageEntries.push($root.google.cloud.dialogflow.v2beta1.MessageEntry.decode(reader, reader.uint32()));
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ConversationContext message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationContext
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.ConversationContext} ConversationContext
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ConversationContext.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ConversationContext message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationContext
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ConversationContext.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.messageEntries != null && message.hasOwnProperty("messageEntries")) {
                                if (!Array.isArray(message.messageEntries))
                                    return "messageEntries: array expected";
                                for (var i = 0; i < message.messageEntries.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.MessageEntry.verify(message.messageEntries[i]);
                                    if (error)
                                        return "messageEntries." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates a ConversationContext message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationContext
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.ConversationContext} ConversationContext
                         */
                        ConversationContext.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.ConversationContext)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.ConversationContext();
                            if (object.messageEntries) {
                                if (!Array.isArray(object.messageEntries))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.ConversationContext.messageEntries: array expected");
                                message.messageEntries = [];
                                for (var i = 0; i < object.messageEntries.length; ++i) {
                                    if (typeof object.messageEntries[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.ConversationContext.messageEntries: object expected");
                                    message.messageEntries[i] = $root.google.cloud.dialogflow.v2beta1.MessageEntry.fromObject(object.messageEntries[i]);
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ConversationContext message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationContext
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ConversationContext} message ConversationContext
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ConversationContext.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.messageEntries = [];
                            if (message.messageEntries && message.messageEntries.length) {
                                object.messageEntries = [];
                                for (var j = 0; j < message.messageEntries.length; ++j)
                                    object.messageEntries[j] = $root.google.cloud.dialogflow.v2beta1.MessageEntry.toObject(message.messageEntries[j], options);
                            }
                            return object;
                        };
    
                        /**
                         * Converts this ConversationContext to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationContext
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ConversationContext.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ConversationContext
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationContext
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ConversationContext.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ConversationContext";
                        };
    
                        return ConversationContext;
                    })();
    
                    v2beta1.SummarizationSectionList = (function() {
    
                        /**
                         * Properties of a SummarizationSectionList.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ISummarizationSectionList
                         * @property {Array.<google.cloud.dialogflow.v2beta1.ISummarizationSection>|null} [summarizationSections] SummarizationSectionList summarizationSections
                         */
    
                        /**
                         * Constructs a new SummarizationSectionList.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a SummarizationSectionList.
                         * @implements ISummarizationSectionList
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ISummarizationSectionList=} [properties] Properties to set
                         */
                        function SummarizationSectionList(properties) {
                            this.summarizationSections = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SummarizationSectionList summarizationSections.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.ISummarizationSection>} summarizationSections
                         * @memberof google.cloud.dialogflow.v2beta1.SummarizationSectionList
                         * @instance
                         */
                        SummarizationSectionList.prototype.summarizationSections = $util.emptyArray;
    
                        /**
                         * Creates a new SummarizationSectionList instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.SummarizationSectionList
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISummarizationSectionList=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.SummarizationSectionList} SummarizationSectionList instance
                         */
                        SummarizationSectionList.create = function create(properties) {
                            return new SummarizationSectionList(properties);
                        };
    
                        /**
                         * Encodes the specified SummarizationSectionList message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SummarizationSectionList.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.SummarizationSectionList
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISummarizationSectionList} message SummarizationSectionList message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SummarizationSectionList.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.summarizationSections != null && message.summarizationSections.length)
                                for (var i = 0; i < message.summarizationSections.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.SummarizationSection.encode(message.summarizationSections[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SummarizationSectionList message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SummarizationSectionList.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SummarizationSectionList
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISummarizationSectionList} message SummarizationSectionList message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SummarizationSectionList.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SummarizationSectionList message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.SummarizationSectionList
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.SummarizationSectionList} SummarizationSectionList
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SummarizationSectionList.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.SummarizationSectionList();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.summarizationSections && message.summarizationSections.length))
                                            message.summarizationSections = [];
                                        message.summarizationSections.push($root.google.cloud.dialogflow.v2beta1.SummarizationSection.decode(reader, reader.uint32()));
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SummarizationSectionList message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SummarizationSectionList
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.SummarizationSectionList} SummarizationSectionList
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SummarizationSectionList.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SummarizationSectionList message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.SummarizationSectionList
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SummarizationSectionList.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.summarizationSections != null && message.hasOwnProperty("summarizationSections")) {
                                if (!Array.isArray(message.summarizationSections))
                                    return "summarizationSections: array expected";
                                for (var i = 0; i < message.summarizationSections.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.SummarizationSection.verify(message.summarizationSections[i]);
                                    if (error)
                                        return "summarizationSections." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates a SummarizationSectionList message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.SummarizationSectionList
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.SummarizationSectionList} SummarizationSectionList
                         */
                        SummarizationSectionList.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.SummarizationSectionList)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.SummarizationSectionList();
                            if (object.summarizationSections) {
                                if (!Array.isArray(object.summarizationSections))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.SummarizationSectionList.summarizationSections: array expected");
                                message.summarizationSections = [];
                                for (var i = 0; i < object.summarizationSections.length; ++i) {
                                    if (typeof object.summarizationSections[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.SummarizationSectionList.summarizationSections: object expected");
                                    message.summarizationSections[i] = $root.google.cloud.dialogflow.v2beta1.SummarizationSection.fromObject(object.summarizationSections[i]);
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SummarizationSectionList message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.SummarizationSectionList
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.SummarizationSectionList} message SummarizationSectionList
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SummarizationSectionList.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.summarizationSections = [];
                            if (message.summarizationSections && message.summarizationSections.length) {
                                object.summarizationSections = [];
                                for (var j = 0; j < message.summarizationSections.length; ++j)
                                    object.summarizationSections[j] = $root.google.cloud.dialogflow.v2beta1.SummarizationSection.toObject(message.summarizationSections[j], options);
                            }
                            return object;
                        };
    
                        /**
                         * Converts this SummarizationSectionList to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.SummarizationSectionList
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SummarizationSectionList.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SummarizationSectionList
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.SummarizationSectionList
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SummarizationSectionList.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.SummarizationSectionList";
                        };
    
                        return SummarizationSectionList;
                    })();
    
                    v2beta1.FewShotExample = (function() {
    
                        /**
                         * Properties of a FewShotExample.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IFewShotExample
                         * @property {google.cloud.dialogflow.v2beta1.IConversationContext|null} [conversationContext] FewShotExample conversationContext
                         * @property {Object.<string,string>|null} [extraInfo] FewShotExample extraInfo
                         * @property {google.cloud.dialogflow.v2beta1.ISummarizationSectionList|null} [summarizationSectionList] FewShotExample summarizationSectionList
                         * @property {google.cloud.dialogflow.v2beta1.IGeneratorSuggestion|null} [output] FewShotExample output
                         */
    
                        /**
                         * Constructs a new FewShotExample.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a FewShotExample.
                         * @implements IFewShotExample
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IFewShotExample=} [properties] Properties to set
                         */
                        function FewShotExample(properties) {
                            this.extraInfo = {};
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * FewShotExample conversationContext.
                         * @member {google.cloud.dialogflow.v2beta1.IConversationContext|null|undefined} conversationContext
                         * @memberof google.cloud.dialogflow.v2beta1.FewShotExample
                         * @instance
                         */
                        FewShotExample.prototype.conversationContext = null;
    
                        /**
                         * FewShotExample extraInfo.
                         * @member {Object.<string,string>} extraInfo
                         * @memberof google.cloud.dialogflow.v2beta1.FewShotExample
                         * @instance
                         */
                        FewShotExample.prototype.extraInfo = $util.emptyObject;
    
                        /**
                         * FewShotExample summarizationSectionList.
                         * @member {google.cloud.dialogflow.v2beta1.ISummarizationSectionList|null|undefined} summarizationSectionList
                         * @memberof google.cloud.dialogflow.v2beta1.FewShotExample
                         * @instance
                         */
                        FewShotExample.prototype.summarizationSectionList = null;
    
                        /**
                         * FewShotExample output.
                         * @member {google.cloud.dialogflow.v2beta1.IGeneratorSuggestion|null|undefined} output
                         * @memberof google.cloud.dialogflow.v2beta1.FewShotExample
                         * @instance
                         */
                        FewShotExample.prototype.output = null;
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * FewShotExample instructionList.
                         * @member {"summarizationSectionList"|undefined} instructionList
                         * @memberof google.cloud.dialogflow.v2beta1.FewShotExample
                         * @instance
                         */
                        Object.defineProperty(FewShotExample.prototype, "instructionList", {
                            get: $util.oneOfGetter($oneOfFields = ["summarizationSectionList"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new FewShotExample instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.FewShotExample
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IFewShotExample=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.FewShotExample} FewShotExample instance
                         */
                        FewShotExample.create = function create(properties) {
                            return new FewShotExample(properties);
                        };
    
                        /**
                         * Encodes the specified FewShotExample message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.FewShotExample.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.FewShotExample
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IFewShotExample} message FewShotExample message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        FewShotExample.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.conversationContext != null && Object.hasOwnProperty.call(message, "conversationContext"))
                                $root.google.cloud.dialogflow.v2beta1.ConversationContext.encode(message.conversationContext, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            if (message.extraInfo != null && Object.hasOwnProperty.call(message, "extraInfo"))
                                for (var keys = Object.keys(message.extraInfo), i = 0; i < keys.length; ++i)
                                    writer.uint32(/* id 4, wireType 2 =*/34).fork().uint32(/* id 1, wireType 2 =*/10).string(keys[i]).uint32(/* id 2, wireType 2 =*/18).string(message.extraInfo[keys[i]]).ldelim();
                            if (message.summarizationSectionList != null && Object.hasOwnProperty.call(message, "summarizationSectionList"))
                                $root.google.cloud.dialogflow.v2beta1.SummarizationSectionList.encode(message.summarizationSectionList, writer.uint32(/* id 6, wireType 2 =*/50).fork()).ldelim();
                            if (message.output != null && Object.hasOwnProperty.call(message, "output"))
                                $root.google.cloud.dialogflow.v2beta1.GeneratorSuggestion.encode(message.output, writer.uint32(/* id 7, wireType 2 =*/58).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified FewShotExample message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.FewShotExample.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.FewShotExample
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IFewShotExample} message FewShotExample message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        FewShotExample.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a FewShotExample message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.FewShotExample
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.FewShotExample} FewShotExample
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        FewShotExample.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.FewShotExample(), key, value;
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 3: {
                                        message.conversationContext = $root.google.cloud.dialogflow.v2beta1.ConversationContext.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 4: {
                                        if (message.extraInfo === $util.emptyObject)
                                            message.extraInfo = {};
                                        var end2 = reader.uint32() + reader.pos;
                                        key = "";
                                        value = "";
                                        while (reader.pos < end2) {
                                            var tag2 = reader.uint32();
                                            switch (tag2 >>> 3) {
                                            case 1:
                                                key = reader.string();
                                                break;
                                            case 2:
                                                value = reader.string();
                                                break;
                                            default:
                                                reader.skipType(tag2 & 7);
                                                break;
                                            }
                                        }
                                        message.extraInfo[key] = value;
                                        break;
                                    }
                                case 6: {
                                        message.summarizationSectionList = $root.google.cloud.dialogflow.v2beta1.SummarizationSectionList.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 7: {
                                        message.output = $root.google.cloud.dialogflow.v2beta1.GeneratorSuggestion.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a FewShotExample message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.FewShotExample
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.FewShotExample} FewShotExample
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        FewShotExample.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a FewShotExample message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.FewShotExample
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        FewShotExample.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.conversationContext != null && message.hasOwnProperty("conversationContext")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.ConversationContext.verify(message.conversationContext);
                                if (error)
                                    return "conversationContext." + error;
                            }
                            if (message.extraInfo != null && message.hasOwnProperty("extraInfo")) {
                                if (!$util.isObject(message.extraInfo))
                                    return "extraInfo: object expected";
                                var key = Object.keys(message.extraInfo);
                                for (var i = 0; i < key.length; ++i)
                                    if (!$util.isString(message.extraInfo[key[i]]))
                                        return "extraInfo: string{k:string} expected";
                            }
                            if (message.summarizationSectionList != null && message.hasOwnProperty("summarizationSectionList")) {
                                properties.instructionList = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2beta1.SummarizationSectionList.verify(message.summarizationSectionList);
                                    if (error)
                                        return "summarizationSectionList." + error;
                                }
                            }
                            if (message.output != null && message.hasOwnProperty("output")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.GeneratorSuggestion.verify(message.output);
                                if (error)
                                    return "output." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a FewShotExample message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.FewShotExample
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.FewShotExample} FewShotExample
                         */
                        FewShotExample.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.FewShotExample)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.FewShotExample();
                            if (object.conversationContext != null) {
                                if (typeof object.conversationContext !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.FewShotExample.conversationContext: object expected");
                                message.conversationContext = $root.google.cloud.dialogflow.v2beta1.ConversationContext.fromObject(object.conversationContext);
                            }
                            if (object.extraInfo) {
                                if (typeof object.extraInfo !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.FewShotExample.extraInfo: object expected");
                                message.extraInfo = {};
                                for (var keys = Object.keys(object.extraInfo), i = 0; i < keys.length; ++i)
                                    message.extraInfo[keys[i]] = String(object.extraInfo[keys[i]]);
                            }
                            if (object.summarizationSectionList != null) {
                                if (typeof object.summarizationSectionList !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.FewShotExample.summarizationSectionList: object expected");
                                message.summarizationSectionList = $root.google.cloud.dialogflow.v2beta1.SummarizationSectionList.fromObject(object.summarizationSectionList);
                            }
                            if (object.output != null) {
                                if (typeof object.output !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.FewShotExample.output: object expected");
                                message.output = $root.google.cloud.dialogflow.v2beta1.GeneratorSuggestion.fromObject(object.output);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a FewShotExample message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.FewShotExample
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.FewShotExample} message FewShotExample
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        FewShotExample.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.objects || options.defaults)
                                object.extraInfo = {};
                            if (options.defaults) {
                                object.conversationContext = null;
                                object.output = null;
                            }
                            if (message.conversationContext != null && message.hasOwnProperty("conversationContext"))
                                object.conversationContext = $root.google.cloud.dialogflow.v2beta1.ConversationContext.toObject(message.conversationContext, options);
                            var keys2;
                            if (message.extraInfo && (keys2 = Object.keys(message.extraInfo)).length) {
                                object.extraInfo = {};
                                for (var j = 0; j < keys2.length; ++j)
                                    object.extraInfo[keys2[j]] = message.extraInfo[keys2[j]];
                            }
                            if (message.summarizationSectionList != null && message.hasOwnProperty("summarizationSectionList")) {
                                object.summarizationSectionList = $root.google.cloud.dialogflow.v2beta1.SummarizationSectionList.toObject(message.summarizationSectionList, options);
                                if (options.oneofs)
                                    object.instructionList = "summarizationSectionList";
                            }
                            if (message.output != null && message.hasOwnProperty("output"))
                                object.output = $root.google.cloud.dialogflow.v2beta1.GeneratorSuggestion.toObject(message.output, options);
                            return object;
                        };
    
                        /**
                         * Converts this FewShotExample to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.FewShotExample
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        FewShotExample.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for FewShotExample
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.FewShotExample
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        FewShotExample.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.FewShotExample";
                        };
    
                        return FewShotExample;
                    })();
    
                    v2beta1.InferenceParameter = (function() {
    
                        /**
                         * Properties of an InferenceParameter.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IInferenceParameter
                         * @property {number|null} [maxOutputTokens] InferenceParameter maxOutputTokens
                         * @property {number|null} [temperature] InferenceParameter temperature
                         * @property {number|null} [topK] InferenceParameter topK
                         * @property {number|null} [topP] InferenceParameter topP
                         */
    
                        /**
                         * Constructs a new InferenceParameter.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an InferenceParameter.
                         * @implements IInferenceParameter
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IInferenceParameter=} [properties] Properties to set
                         */
                        function InferenceParameter(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * InferenceParameter maxOutputTokens.
                         * @member {number|null|undefined} maxOutputTokens
                         * @memberof google.cloud.dialogflow.v2beta1.InferenceParameter
                         * @instance
                         */
                        InferenceParameter.prototype.maxOutputTokens = null;
    
                        /**
                         * InferenceParameter temperature.
                         * @member {number|null|undefined} temperature
                         * @memberof google.cloud.dialogflow.v2beta1.InferenceParameter
                         * @instance
                         */
                        InferenceParameter.prototype.temperature = null;
    
                        /**
                         * InferenceParameter topK.
                         * @member {number|null|undefined} topK
                         * @memberof google.cloud.dialogflow.v2beta1.InferenceParameter
                         * @instance
                         */
                        InferenceParameter.prototype.topK = null;
    
                        /**
                         * InferenceParameter topP.
                         * @member {number|null|undefined} topP
                         * @memberof google.cloud.dialogflow.v2beta1.InferenceParameter
                         * @instance
                         */
                        InferenceParameter.prototype.topP = null;
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * InferenceParameter _maxOutputTokens.
                         * @member {"maxOutputTokens"|undefined} _maxOutputTokens
                         * @memberof google.cloud.dialogflow.v2beta1.InferenceParameter
                         * @instance
                         */
                        Object.defineProperty(InferenceParameter.prototype, "_maxOutputTokens", {
                            get: $util.oneOfGetter($oneOfFields = ["maxOutputTokens"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * InferenceParameter _temperature.
                         * @member {"temperature"|undefined} _temperature
                         * @memberof google.cloud.dialogflow.v2beta1.InferenceParameter
                         * @instance
                         */
                        Object.defineProperty(InferenceParameter.prototype, "_temperature", {
                            get: $util.oneOfGetter($oneOfFields = ["temperature"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * InferenceParameter _topK.
                         * @member {"topK"|undefined} _topK
                         * @memberof google.cloud.dialogflow.v2beta1.InferenceParameter
                         * @instance
                         */
                        Object.defineProperty(InferenceParameter.prototype, "_topK", {
                            get: $util.oneOfGetter($oneOfFields = ["topK"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * InferenceParameter _topP.
                         * @member {"topP"|undefined} _topP
                         * @memberof google.cloud.dialogflow.v2beta1.InferenceParameter
                         * @instance
                         */
                        Object.defineProperty(InferenceParameter.prototype, "_topP", {
                            get: $util.oneOfGetter($oneOfFields = ["topP"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new InferenceParameter instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.InferenceParameter
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IInferenceParameter=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.InferenceParameter} InferenceParameter instance
                         */
                        InferenceParameter.create = function create(properties) {
                            return new InferenceParameter(properties);
                        };
    
                        /**
                         * Encodes the specified InferenceParameter message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.InferenceParameter.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.InferenceParameter
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IInferenceParameter} message InferenceParameter message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        InferenceParameter.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.maxOutputTokens != null && Object.hasOwnProperty.call(message, "maxOutputTokens"))
                                writer.uint32(/* id 1, wireType 0 =*/8).int32(message.maxOutputTokens);
                            if (message.temperature != null && Object.hasOwnProperty.call(message, "temperature"))
                                writer.uint32(/* id 2, wireType 1 =*/17).double(message.temperature);
                            if (message.topK != null && Object.hasOwnProperty.call(message, "topK"))
                                writer.uint32(/* id 3, wireType 0 =*/24).int32(message.topK);
                            if (message.topP != null && Object.hasOwnProperty.call(message, "topP"))
                                writer.uint32(/* id 4, wireType 1 =*/33).double(message.topP);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified InferenceParameter message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.InferenceParameter.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.InferenceParameter
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IInferenceParameter} message InferenceParameter message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        InferenceParameter.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an InferenceParameter message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.InferenceParameter
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.InferenceParameter} InferenceParameter
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        InferenceParameter.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.InferenceParameter();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.maxOutputTokens = reader.int32();
                                        break;
                                    }
                                case 2: {
                                        message.temperature = reader.double();
                                        break;
                                    }
                                case 3: {
                                        message.topK = reader.int32();
                                        break;
                                    }
                                case 4: {
                                        message.topP = reader.double();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an InferenceParameter message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.InferenceParameter
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.InferenceParameter} InferenceParameter
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        InferenceParameter.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an InferenceParameter message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.InferenceParameter
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        InferenceParameter.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.maxOutputTokens != null && message.hasOwnProperty("maxOutputTokens")) {
                                properties._maxOutputTokens = 1;
                                if (!$util.isInteger(message.maxOutputTokens))
                                    return "maxOutputTokens: integer expected";
                            }
                            if (message.temperature != null && message.hasOwnProperty("temperature")) {
                                properties._temperature = 1;
                                if (typeof message.temperature !== "number")
                                    return "temperature: number expected";
                            }
                            if (message.topK != null && message.hasOwnProperty("topK")) {
                                properties._topK = 1;
                                if (!$util.isInteger(message.topK))
                                    return "topK: integer expected";
                            }
                            if (message.topP != null && message.hasOwnProperty("topP")) {
                                properties._topP = 1;
                                if (typeof message.topP !== "number")
                                    return "topP: number expected";
                            }
                            return null;
                        };
    
                        /**
                         * Creates an InferenceParameter message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.InferenceParameter
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.InferenceParameter} InferenceParameter
                         */
                        InferenceParameter.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.InferenceParameter)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.InferenceParameter();
                            if (object.maxOutputTokens != null)
                                message.maxOutputTokens = object.maxOutputTokens | 0;
                            if (object.temperature != null)
                                message.temperature = Number(object.temperature);
                            if (object.topK != null)
                                message.topK = object.topK | 0;
                            if (object.topP != null)
                                message.topP = Number(object.topP);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an InferenceParameter message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.InferenceParameter
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.InferenceParameter} message InferenceParameter
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        InferenceParameter.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (message.maxOutputTokens != null && message.hasOwnProperty("maxOutputTokens")) {
                                object.maxOutputTokens = message.maxOutputTokens;
                                if (options.oneofs)
                                    object._maxOutputTokens = "maxOutputTokens";
                            }
                            if (message.temperature != null && message.hasOwnProperty("temperature")) {
                                object.temperature = options.json && !isFinite(message.temperature) ? String(message.temperature) : message.temperature;
                                if (options.oneofs)
                                    object._temperature = "temperature";
                            }
                            if (message.topK != null && message.hasOwnProperty("topK")) {
                                object.topK = message.topK;
                                if (options.oneofs)
                                    object._topK = "topK";
                            }
                            if (message.topP != null && message.hasOwnProperty("topP")) {
                                object.topP = options.json && !isFinite(message.topP) ? String(message.topP) : message.topP;
                                if (options.oneofs)
                                    object._topP = "topP";
                            }
                            return object;
                        };
    
                        /**
                         * Converts this InferenceParameter to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.InferenceParameter
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        InferenceParameter.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for InferenceParameter
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.InferenceParameter
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        InferenceParameter.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.InferenceParameter";
                        };
    
                        return InferenceParameter;
                    })();
    
                    v2beta1.SummarizationSection = (function() {
    
                        /**
                         * Properties of a SummarizationSection.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ISummarizationSection
                         * @property {string|null} [key] SummarizationSection key
                         * @property {string|null} [definition] SummarizationSection definition
                         * @property {google.cloud.dialogflow.v2beta1.SummarizationSection.Type|null} [type] SummarizationSection type
                         */
    
                        /**
                         * Constructs a new SummarizationSection.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a SummarizationSection.
                         * @implements ISummarizationSection
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ISummarizationSection=} [properties] Properties to set
                         */
                        function SummarizationSection(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SummarizationSection key.
                         * @member {string} key
                         * @memberof google.cloud.dialogflow.v2beta1.SummarizationSection
                         * @instance
                         */
                        SummarizationSection.prototype.key = "";
    
                        /**
                         * SummarizationSection definition.
                         * @member {string} definition
                         * @memberof google.cloud.dialogflow.v2beta1.SummarizationSection
                         * @instance
                         */
                        SummarizationSection.prototype.definition = "";
    
                        /**
                         * SummarizationSection type.
                         * @member {google.cloud.dialogflow.v2beta1.SummarizationSection.Type} type
                         * @memberof google.cloud.dialogflow.v2beta1.SummarizationSection
                         * @instance
                         */
                        SummarizationSection.prototype.type = 0;
    
                        /**
                         * Creates a new SummarizationSection instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.SummarizationSection
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISummarizationSection=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.SummarizationSection} SummarizationSection instance
                         */
                        SummarizationSection.create = function create(properties) {
                            return new SummarizationSection(properties);
                        };
    
                        /**
                         * Encodes the specified SummarizationSection message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SummarizationSection.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.SummarizationSection
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISummarizationSection} message SummarizationSection message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SummarizationSection.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.key != null && Object.hasOwnProperty.call(message, "key"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.key);
                            if (message.definition != null && Object.hasOwnProperty.call(message, "definition"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.definition);
                            if (message.type != null && Object.hasOwnProperty.call(message, "type"))
                                writer.uint32(/* id 3, wireType 0 =*/24).int32(message.type);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SummarizationSection message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SummarizationSection.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SummarizationSection
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISummarizationSection} message SummarizationSection message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SummarizationSection.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SummarizationSection message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.SummarizationSection
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.SummarizationSection} SummarizationSection
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SummarizationSection.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.SummarizationSection();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.key = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.definition = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.type = reader.int32();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SummarizationSection message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SummarizationSection
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.SummarizationSection} SummarizationSection
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SummarizationSection.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SummarizationSection message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.SummarizationSection
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SummarizationSection.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.key != null && message.hasOwnProperty("key"))
                                if (!$util.isString(message.key))
                                    return "key: string expected";
                            if (message.definition != null && message.hasOwnProperty("definition"))
                                if (!$util.isString(message.definition))
                                    return "definition: string expected";
                            if (message.type != null && message.hasOwnProperty("type"))
                                switch (message.type) {
                                default:
                                    return "type: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                case 4:
                                case 5:
                                case 6:
                                case 7:
                                case 9:
                                case 10:
                                    break;
                                }
                            return null;
                        };
    
                        /**
                         * Creates a SummarizationSection message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.SummarizationSection
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.SummarizationSection} SummarizationSection
                         */
                        SummarizationSection.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.SummarizationSection)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.SummarizationSection();
                            if (object.key != null)
                                message.key = String(object.key);
                            if (object.definition != null)
                                message.definition = String(object.definition);
                            switch (object.type) {
                            default:
                                if (typeof object.type === "number") {
                                    message.type = object.type;
                                    break;
                                }
                                break;
                            case "TYPE_UNSPECIFIED":
                            case 0:
                                message.type = 0;
                                break;
                            case "SITUATION":
                            case 1:
                                message.type = 1;
                                break;
                            case "ACTION":
                            case 2:
                                message.type = 2;
                                break;
                            case "RESOLUTION":
                            case 3:
                                message.type = 3;
                                break;
                            case "REASON_FOR_CANCELLATION":
                            case 4:
                                message.type = 4;
                                break;
                            case "CUSTOMER_SATISFACTION":
                            case 5:
                                message.type = 5;
                                break;
                            case "ENTITIES":
                            case 6:
                                message.type = 6;
                                break;
                            case "CUSTOMER_DEFINED":
                            case 7:
                                message.type = 7;
                                break;
                            case "SITUATION_CONCISE":
                            case 9:
                                message.type = 9;
                                break;
                            case "ACTION_CONCISE":
                            case 10:
                                message.type = 10;
                                break;
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SummarizationSection message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.SummarizationSection
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.SummarizationSection} message SummarizationSection
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SummarizationSection.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.key = "";
                                object.definition = "";
                                object.type = options.enums === String ? "TYPE_UNSPECIFIED" : 0;
                            }
                            if (message.key != null && message.hasOwnProperty("key"))
                                object.key = message.key;
                            if (message.definition != null && message.hasOwnProperty("definition"))
                                object.definition = message.definition;
                            if (message.type != null && message.hasOwnProperty("type"))
                                object.type = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.SummarizationSection.Type[message.type] === undefined ? message.type : $root.google.cloud.dialogflow.v2beta1.SummarizationSection.Type[message.type] : message.type;
                            return object;
                        };
    
                        /**
                         * Converts this SummarizationSection to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.SummarizationSection
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SummarizationSection.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SummarizationSection
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.SummarizationSection
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SummarizationSection.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.SummarizationSection";
                        };
    
                        /**
                         * Type enum.
                         * @name google.cloud.dialogflow.v2beta1.SummarizationSection.Type
                         * @enum {number}
                         * @property {number} TYPE_UNSPECIFIED=0 TYPE_UNSPECIFIED value
                         * @property {number} SITUATION=1 SITUATION value
                         * @property {number} ACTION=2 ACTION value
                         * @property {number} RESOLUTION=3 RESOLUTION value
                         * @property {number} REASON_FOR_CANCELLATION=4 REASON_FOR_CANCELLATION value
                         * @property {number} CUSTOMER_SATISFACTION=5 CUSTOMER_SATISFACTION value
                         * @property {number} ENTITIES=6 ENTITIES value
                         * @property {number} CUSTOMER_DEFINED=7 CUSTOMER_DEFINED value
                         * @property {number} SITUATION_CONCISE=9 SITUATION_CONCISE value
                         * @property {number} ACTION_CONCISE=10 ACTION_CONCISE value
                         */
                        SummarizationSection.Type = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "TYPE_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "SITUATION"] = 1;
                            values[valuesById[2] = "ACTION"] = 2;
                            values[valuesById[3] = "RESOLUTION"] = 3;
                            values[valuesById[4] = "REASON_FOR_CANCELLATION"] = 4;
                            values[valuesById[5] = "CUSTOMER_SATISFACTION"] = 5;
                            values[valuesById[6] = "ENTITIES"] = 6;
                            values[valuesById[7] = "CUSTOMER_DEFINED"] = 7;
                            values[valuesById[9] = "SITUATION_CONCISE"] = 9;
                            values[valuesById[10] = "ACTION_CONCISE"] = 10;
                            return values;
                        })();
    
                        return SummarizationSection;
                    })();
    
                    v2beta1.SummarizationContext = (function() {
    
                        /**
                         * Properties of a SummarizationContext.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ISummarizationContext
                         * @property {Array.<google.cloud.dialogflow.v2beta1.ISummarizationSection>|null} [summarizationSections] SummarizationContext summarizationSections
                         * @property {Array.<google.cloud.dialogflow.v2beta1.IFewShotExample>|null} [fewShotExamples] SummarizationContext fewShotExamples
                         * @property {string|null} [version] SummarizationContext version
                         * @property {string|null} [outputLanguageCode] SummarizationContext outputLanguageCode
                         */
    
                        /**
                         * Constructs a new SummarizationContext.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a SummarizationContext.
                         * @implements ISummarizationContext
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ISummarizationContext=} [properties] Properties to set
                         */
                        function SummarizationContext(properties) {
                            this.summarizationSections = [];
                            this.fewShotExamples = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SummarizationContext summarizationSections.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.ISummarizationSection>} summarizationSections
                         * @memberof google.cloud.dialogflow.v2beta1.SummarizationContext
                         * @instance
                         */
                        SummarizationContext.prototype.summarizationSections = $util.emptyArray;
    
                        /**
                         * SummarizationContext fewShotExamples.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.IFewShotExample>} fewShotExamples
                         * @memberof google.cloud.dialogflow.v2beta1.SummarizationContext
                         * @instance
                         */
                        SummarizationContext.prototype.fewShotExamples = $util.emptyArray;
    
                        /**
                         * SummarizationContext version.
                         * @member {string} version
                         * @memberof google.cloud.dialogflow.v2beta1.SummarizationContext
                         * @instance
                         */
                        SummarizationContext.prototype.version = "";
    
                        /**
                         * SummarizationContext outputLanguageCode.
                         * @member {string} outputLanguageCode
                         * @memberof google.cloud.dialogflow.v2beta1.SummarizationContext
                         * @instance
                         */
                        SummarizationContext.prototype.outputLanguageCode = "";
    
                        /**
                         * Creates a new SummarizationContext instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.SummarizationContext
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISummarizationContext=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.SummarizationContext} SummarizationContext instance
                         */
                        SummarizationContext.create = function create(properties) {
                            return new SummarizationContext(properties);
                        };
    
                        /**
                         * Encodes the specified SummarizationContext message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SummarizationContext.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.SummarizationContext
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISummarizationContext} message SummarizationContext message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SummarizationContext.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.summarizationSections != null && message.summarizationSections.length)
                                for (var i = 0; i < message.summarizationSections.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.SummarizationSection.encode(message.summarizationSections[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.fewShotExamples != null && message.fewShotExamples.length)
                                for (var i = 0; i < message.fewShotExamples.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.FewShotExample.encode(message.fewShotExamples[i], writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.version != null && Object.hasOwnProperty.call(message, "version"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.version);
                            if (message.outputLanguageCode != null && Object.hasOwnProperty.call(message, "outputLanguageCode"))
                                writer.uint32(/* id 6, wireType 2 =*/50).string(message.outputLanguageCode);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SummarizationContext message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SummarizationContext.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SummarizationContext
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISummarizationContext} message SummarizationContext message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SummarizationContext.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SummarizationContext message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.SummarizationContext
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.SummarizationContext} SummarizationContext
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SummarizationContext.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.SummarizationContext();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.summarizationSections && message.summarizationSections.length))
                                            message.summarizationSections = [];
                                        message.summarizationSections.push($root.google.cloud.dialogflow.v2beta1.SummarizationSection.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 2: {
                                        if (!(message.fewShotExamples && message.fewShotExamples.length))
                                            message.fewShotExamples = [];
                                        message.fewShotExamples.push($root.google.cloud.dialogflow.v2beta1.FewShotExample.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 3: {
                                        message.version = reader.string();
                                        break;
                                    }
                                case 6: {
                                        message.outputLanguageCode = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SummarizationContext message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SummarizationContext
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.SummarizationContext} SummarizationContext
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SummarizationContext.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SummarizationContext message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.SummarizationContext
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SummarizationContext.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.summarizationSections != null && message.hasOwnProperty("summarizationSections")) {
                                if (!Array.isArray(message.summarizationSections))
                                    return "summarizationSections: array expected";
                                for (var i = 0; i < message.summarizationSections.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.SummarizationSection.verify(message.summarizationSections[i]);
                                    if (error)
                                        return "summarizationSections." + error;
                                }
                            }
                            if (message.fewShotExamples != null && message.hasOwnProperty("fewShotExamples")) {
                                if (!Array.isArray(message.fewShotExamples))
                                    return "fewShotExamples: array expected";
                                for (var i = 0; i < message.fewShotExamples.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.FewShotExample.verify(message.fewShotExamples[i]);
                                    if (error)
                                        return "fewShotExamples." + error;
                                }
                            }
                            if (message.version != null && message.hasOwnProperty("version"))
                                if (!$util.isString(message.version))
                                    return "version: string expected";
                            if (message.outputLanguageCode != null && message.hasOwnProperty("outputLanguageCode"))
                                if (!$util.isString(message.outputLanguageCode))
                                    return "outputLanguageCode: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a SummarizationContext message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.SummarizationContext
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.SummarizationContext} SummarizationContext
                         */
                        SummarizationContext.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.SummarizationContext)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.SummarizationContext();
                            if (object.summarizationSections) {
                                if (!Array.isArray(object.summarizationSections))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.SummarizationContext.summarizationSections: array expected");
                                message.summarizationSections = [];
                                for (var i = 0; i < object.summarizationSections.length; ++i) {
                                    if (typeof object.summarizationSections[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.SummarizationContext.summarizationSections: object expected");
                                    message.summarizationSections[i] = $root.google.cloud.dialogflow.v2beta1.SummarizationSection.fromObject(object.summarizationSections[i]);
                                }
                            }
                            if (object.fewShotExamples) {
                                if (!Array.isArray(object.fewShotExamples))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.SummarizationContext.fewShotExamples: array expected");
                                message.fewShotExamples = [];
                                for (var i = 0; i < object.fewShotExamples.length; ++i) {
                                    if (typeof object.fewShotExamples[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.SummarizationContext.fewShotExamples: object expected");
                                    message.fewShotExamples[i] = $root.google.cloud.dialogflow.v2beta1.FewShotExample.fromObject(object.fewShotExamples[i]);
                                }
                            }
                            if (object.version != null)
                                message.version = String(object.version);
                            if (object.outputLanguageCode != null)
                                message.outputLanguageCode = String(object.outputLanguageCode);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SummarizationContext message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.SummarizationContext
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.SummarizationContext} message SummarizationContext
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SummarizationContext.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults) {
                                object.summarizationSections = [];
                                object.fewShotExamples = [];
                            }
                            if (options.defaults) {
                                object.version = "";
                                object.outputLanguageCode = "";
                            }
                            if (message.summarizationSections && message.summarizationSections.length) {
                                object.summarizationSections = [];
                                for (var j = 0; j < message.summarizationSections.length; ++j)
                                    object.summarizationSections[j] = $root.google.cloud.dialogflow.v2beta1.SummarizationSection.toObject(message.summarizationSections[j], options);
                            }
                            if (message.fewShotExamples && message.fewShotExamples.length) {
                                object.fewShotExamples = [];
                                for (var j = 0; j < message.fewShotExamples.length; ++j)
                                    object.fewShotExamples[j] = $root.google.cloud.dialogflow.v2beta1.FewShotExample.toObject(message.fewShotExamples[j], options);
                            }
                            if (message.version != null && message.hasOwnProperty("version"))
                                object.version = message.version;
                            if (message.outputLanguageCode != null && message.hasOwnProperty("outputLanguageCode"))
                                object.outputLanguageCode = message.outputLanguageCode;
                            return object;
                        };
    
                        /**
                         * Converts this SummarizationContext to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.SummarizationContext
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SummarizationContext.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SummarizationContext
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.SummarizationContext
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SummarizationContext.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.SummarizationContext";
                        };
    
                        return SummarizationContext;
                    })();
    
                    v2beta1.FreeFormContext = (function() {
    
                        /**
                         * Properties of a FreeFormContext.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IFreeFormContext
                         * @property {string|null} [text] FreeFormContext text
                         */
    
                        /**
                         * Constructs a new FreeFormContext.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a FreeFormContext.
                         * @implements IFreeFormContext
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IFreeFormContext=} [properties] Properties to set
                         */
                        function FreeFormContext(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * FreeFormContext text.
                         * @member {string} text
                         * @memberof google.cloud.dialogflow.v2beta1.FreeFormContext
                         * @instance
                         */
                        FreeFormContext.prototype.text = "";
    
                        /**
                         * Creates a new FreeFormContext instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.FreeFormContext
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IFreeFormContext=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.FreeFormContext} FreeFormContext instance
                         */
                        FreeFormContext.create = function create(properties) {
                            return new FreeFormContext(properties);
                        };
    
                        /**
                         * Encodes the specified FreeFormContext message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.FreeFormContext.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.FreeFormContext
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IFreeFormContext} message FreeFormContext message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        FreeFormContext.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.text != null && Object.hasOwnProperty.call(message, "text"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.text);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified FreeFormContext message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.FreeFormContext.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.FreeFormContext
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IFreeFormContext} message FreeFormContext message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        FreeFormContext.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a FreeFormContext message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.FreeFormContext
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.FreeFormContext} FreeFormContext
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        FreeFormContext.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.FreeFormContext();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.text = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a FreeFormContext message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.FreeFormContext
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.FreeFormContext} FreeFormContext
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        FreeFormContext.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a FreeFormContext message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.FreeFormContext
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        FreeFormContext.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.text != null && message.hasOwnProperty("text"))
                                if (!$util.isString(message.text))
                                    return "text: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a FreeFormContext message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.FreeFormContext
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.FreeFormContext} FreeFormContext
                         */
                        FreeFormContext.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.FreeFormContext)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.FreeFormContext();
                            if (object.text != null)
                                message.text = String(object.text);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a FreeFormContext message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.FreeFormContext
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.FreeFormContext} message FreeFormContext
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        FreeFormContext.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.text = "";
                            if (message.text != null && message.hasOwnProperty("text"))
                                object.text = message.text;
                            return object;
                        };
    
                        /**
                         * Converts this FreeFormContext to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.FreeFormContext
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        FreeFormContext.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for FreeFormContext
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.FreeFormContext
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        FreeFormContext.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.FreeFormContext";
                        };
    
                        return FreeFormContext;
                    })();
    
                    v2beta1.Generator = (function() {
    
                        /**
                         * Properties of a Generator.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IGenerator
                         * @property {string|null} [name] Generator name
                         * @property {string|null} [description] Generator description
                         * @property {google.cloud.dialogflow.v2beta1.IFreeFormContext|null} [freeFormContext] Generator freeFormContext
                         * @property {google.cloud.dialogflow.v2beta1.ISummarizationContext|null} [summarizationContext] Generator summarizationContext
                         * @property {google.cloud.dialogflow.v2beta1.IInferenceParameter|null} [inferenceParameter] Generator inferenceParameter
                         * @property {google.cloud.dialogflow.v2beta1.TriggerEvent|null} [triggerEvent] Generator triggerEvent
                         * @property {string|null} [publishedModel] Generator publishedModel
                         * @property {google.protobuf.ITimestamp|null} [createTime] Generator createTime
                         * @property {google.protobuf.ITimestamp|null} [updateTime] Generator updateTime
                         */
    
                        /**
                         * Constructs a new Generator.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a Generator.
                         * @implements IGenerator
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IGenerator=} [properties] Properties to set
                         */
                        function Generator(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * Generator name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2beta1.Generator
                         * @instance
                         */
                        Generator.prototype.name = "";
    
                        /**
                         * Generator description.
                         * @member {string} description
                         * @memberof google.cloud.dialogflow.v2beta1.Generator
                         * @instance
                         */
                        Generator.prototype.description = "";
    
                        /**
                         * Generator freeFormContext.
                         * @member {google.cloud.dialogflow.v2beta1.IFreeFormContext|null|undefined} freeFormContext
                         * @memberof google.cloud.dialogflow.v2beta1.Generator
                         * @instance
                         */
                        Generator.prototype.freeFormContext = null;
    
                        /**
                         * Generator summarizationContext.
                         * @member {google.cloud.dialogflow.v2beta1.ISummarizationContext|null|undefined} summarizationContext
                         * @memberof google.cloud.dialogflow.v2beta1.Generator
                         * @instance
                         */
                        Generator.prototype.summarizationContext = null;
    
                        /**
                         * Generator inferenceParameter.
                         * @member {google.cloud.dialogflow.v2beta1.IInferenceParameter|null|undefined} inferenceParameter
                         * @memberof google.cloud.dialogflow.v2beta1.Generator
                         * @instance
                         */
                        Generator.prototype.inferenceParameter = null;
    
                        /**
                         * Generator triggerEvent.
                         * @member {google.cloud.dialogflow.v2beta1.TriggerEvent} triggerEvent
                         * @memberof google.cloud.dialogflow.v2beta1.Generator
                         * @instance
                         */
                        Generator.prototype.triggerEvent = 0;
    
                        /**
                         * Generator publishedModel.
                         * @member {string|null|undefined} publishedModel
                         * @memberof google.cloud.dialogflow.v2beta1.Generator
                         * @instance
                         */
                        Generator.prototype.publishedModel = null;
    
                        /**
                         * Generator createTime.
                         * @member {google.protobuf.ITimestamp|null|undefined} createTime
                         * @memberof google.cloud.dialogflow.v2beta1.Generator
                         * @instance
                         */
                        Generator.prototype.createTime = null;
    
                        /**
                         * Generator updateTime.
                         * @member {google.protobuf.ITimestamp|null|undefined} updateTime
                         * @memberof google.cloud.dialogflow.v2beta1.Generator
                         * @instance
                         */
                        Generator.prototype.updateTime = null;
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * Generator context.
                         * @member {"freeFormContext"|"summarizationContext"|undefined} context
                         * @memberof google.cloud.dialogflow.v2beta1.Generator
                         * @instance
                         */
                        Object.defineProperty(Generator.prototype, "context", {
                            get: $util.oneOfGetter($oneOfFields = ["freeFormContext", "summarizationContext"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Generator foundationModel.
                         * @member {"publishedModel"|undefined} foundationModel
                         * @memberof google.cloud.dialogflow.v2beta1.Generator
                         * @instance
                         */
                        Object.defineProperty(Generator.prototype, "foundationModel", {
                            get: $util.oneOfGetter($oneOfFields = ["publishedModel"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new Generator instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.Generator
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGenerator=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.Generator} Generator instance
                         */
                        Generator.create = function create(properties) {
                            return new Generator(properties);
                        };
    
                        /**
                         * Encodes the specified Generator message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Generator.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.Generator
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGenerator} message Generator message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        Generator.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            if (message.description != null && Object.hasOwnProperty.call(message, "description"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.description);
                            if (message.inferenceParameter != null && Object.hasOwnProperty.call(message, "inferenceParameter"))
                                $root.google.cloud.dialogflow.v2beta1.InferenceParameter.encode(message.inferenceParameter, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            if (message.triggerEvent != null && Object.hasOwnProperty.call(message, "triggerEvent"))
                                writer.uint32(/* id 5, wireType 0 =*/40).int32(message.triggerEvent);
                            if (message.createTime != null && Object.hasOwnProperty.call(message, "createTime"))
                                $root.google.protobuf.Timestamp.encode(message.createTime, writer.uint32(/* id 8, wireType 2 =*/66).fork()).ldelim();
                            if (message.updateTime != null && Object.hasOwnProperty.call(message, "updateTime"))
                                $root.google.protobuf.Timestamp.encode(message.updateTime, writer.uint32(/* id 9, wireType 2 =*/74).fork()).ldelim();
                            if (message.freeFormContext != null && Object.hasOwnProperty.call(message, "freeFormContext"))
                                $root.google.cloud.dialogflow.v2beta1.FreeFormContext.encode(message.freeFormContext, writer.uint32(/* id 11, wireType 2 =*/90).fork()).ldelim();
                            if (message.summarizationContext != null && Object.hasOwnProperty.call(message, "summarizationContext"))
                                $root.google.cloud.dialogflow.v2beta1.SummarizationContext.encode(message.summarizationContext, writer.uint32(/* id 13, wireType 2 =*/106).fork()).ldelim();
                            if (message.publishedModel != null && Object.hasOwnProperty.call(message, "publishedModel"))
                                writer.uint32(/* id 15, wireType 2 =*/122).string(message.publishedModel);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified Generator message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Generator.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.Generator
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGenerator} message Generator message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        Generator.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a Generator message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.Generator
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.Generator} Generator
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        Generator.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Generator();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.description = reader.string();
                                        break;
                                    }
                                case 11: {
                                        message.freeFormContext = $root.google.cloud.dialogflow.v2beta1.FreeFormContext.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 13: {
                                        message.summarizationContext = $root.google.cloud.dialogflow.v2beta1.SummarizationContext.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 4: {
                                        message.inferenceParameter = $root.google.cloud.dialogflow.v2beta1.InferenceParameter.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 5: {
                                        message.triggerEvent = reader.int32();
                                        break;
                                    }
                                case 15: {
                                        message.publishedModel = reader.string();
                                        break;
                                    }
                                case 8: {
                                        message.createTime = $root.google.protobuf.Timestamp.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 9: {
                                        message.updateTime = $root.google.protobuf.Timestamp.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a Generator message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.Generator
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.Generator} Generator
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        Generator.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a Generator message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.Generator
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        Generator.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            if (message.description != null && message.hasOwnProperty("description"))
                                if (!$util.isString(message.description))
                                    return "description: string expected";
                            if (message.freeFormContext != null && message.hasOwnProperty("freeFormContext")) {
                                properties.context = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2beta1.FreeFormContext.verify(message.freeFormContext);
                                    if (error)
                                        return "freeFormContext." + error;
                                }
                            }
                            if (message.summarizationContext != null && message.hasOwnProperty("summarizationContext")) {
                                if (properties.context === 1)
                                    return "context: multiple values";
                                properties.context = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2beta1.SummarizationContext.verify(message.summarizationContext);
                                    if (error)
                                        return "summarizationContext." + error;
                                }
                            }
                            if (message.inferenceParameter != null && message.hasOwnProperty("inferenceParameter")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.InferenceParameter.verify(message.inferenceParameter);
                                if (error)
                                    return "inferenceParameter." + error;
                            }
                            if (message.triggerEvent != null && message.hasOwnProperty("triggerEvent"))
                                switch (message.triggerEvent) {
                                default:
                                    return "triggerEvent: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                case 4:
                                    break;
                                }
                            if (message.publishedModel != null && message.hasOwnProperty("publishedModel")) {
                                properties.foundationModel = 1;
                                if (!$util.isString(message.publishedModel))
                                    return "publishedModel: string expected";
                            }
                            if (message.createTime != null && message.hasOwnProperty("createTime")) {
                                var error = $root.google.protobuf.Timestamp.verify(message.createTime);
                                if (error)
                                    return "createTime." + error;
                            }
                            if (message.updateTime != null && message.hasOwnProperty("updateTime")) {
                                var error = $root.google.protobuf.Timestamp.verify(message.updateTime);
                                if (error)
                                    return "updateTime." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a Generator message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.Generator
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.Generator} Generator
                         */
                        Generator.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.Generator)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.Generator();
                            if (object.name != null)
                                message.name = String(object.name);
                            if (object.description != null)
                                message.description = String(object.description);
                            if (object.freeFormContext != null) {
                                if (typeof object.freeFormContext !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.Generator.freeFormContext: object expected");
                                message.freeFormContext = $root.google.cloud.dialogflow.v2beta1.FreeFormContext.fromObject(object.freeFormContext);
                            }
                            if (object.summarizationContext != null) {
                                if (typeof object.summarizationContext !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.Generator.summarizationContext: object expected");
                                message.summarizationContext = $root.google.cloud.dialogflow.v2beta1.SummarizationContext.fromObject(object.summarizationContext);
                            }
                            if (object.inferenceParameter != null) {
                                if (typeof object.inferenceParameter !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.Generator.inferenceParameter: object expected");
                                message.inferenceParameter = $root.google.cloud.dialogflow.v2beta1.InferenceParameter.fromObject(object.inferenceParameter);
                            }
                            switch (object.triggerEvent) {
                            default:
                                if (typeof object.triggerEvent === "number") {
                                    message.triggerEvent = object.triggerEvent;
                                    break;
                                }
                                break;
                            case "TRIGGER_EVENT_UNSPECIFIED":
                            case 0:
                                message.triggerEvent = 0;
                                break;
                            case "END_OF_UTTERANCE":
                            case 1:
                                message.triggerEvent = 1;
                                break;
                            case "MANUAL_CALL":
                            case 2:
                                message.triggerEvent = 2;
                                break;
                            case "CUSTOMER_MESSAGE":
                            case 3:
                                message.triggerEvent = 3;
                                break;
                            case "AGENT_MESSAGE":
                            case 4:
                                message.triggerEvent = 4;
                                break;
                            }
                            if (object.publishedModel != null)
                                message.publishedModel = String(object.publishedModel);
                            if (object.createTime != null) {
                                if (typeof object.createTime !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.Generator.createTime: object expected");
                                message.createTime = $root.google.protobuf.Timestamp.fromObject(object.createTime);
                            }
                            if (object.updateTime != null) {
                                if (typeof object.updateTime !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.Generator.updateTime: object expected");
                                message.updateTime = $root.google.protobuf.Timestamp.fromObject(object.updateTime);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a Generator message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.Generator
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.Generator} message Generator
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        Generator.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.name = "";
                                object.description = "";
                                object.inferenceParameter = null;
                                object.triggerEvent = options.enums === String ? "TRIGGER_EVENT_UNSPECIFIED" : 0;
                                object.createTime = null;
                                object.updateTime = null;
                            }
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            if (message.description != null && message.hasOwnProperty("description"))
                                object.description = message.description;
                            if (message.inferenceParameter != null && message.hasOwnProperty("inferenceParameter"))
                                object.inferenceParameter = $root.google.cloud.dialogflow.v2beta1.InferenceParameter.toObject(message.inferenceParameter, options);
                            if (message.triggerEvent != null && message.hasOwnProperty("triggerEvent"))
                                object.triggerEvent = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.TriggerEvent[message.triggerEvent] === undefined ? message.triggerEvent : $root.google.cloud.dialogflow.v2beta1.TriggerEvent[message.triggerEvent] : message.triggerEvent;
                            if (message.createTime != null && message.hasOwnProperty("createTime"))
                                object.createTime = $root.google.protobuf.Timestamp.toObject(message.createTime, options);
                            if (message.updateTime != null && message.hasOwnProperty("updateTime"))
                                object.updateTime = $root.google.protobuf.Timestamp.toObject(message.updateTime, options);
                            if (message.freeFormContext != null && message.hasOwnProperty("freeFormContext")) {
                                object.freeFormContext = $root.google.cloud.dialogflow.v2beta1.FreeFormContext.toObject(message.freeFormContext, options);
                                if (options.oneofs)
                                    object.context = "freeFormContext";
                            }
                            if (message.summarizationContext != null && message.hasOwnProperty("summarizationContext")) {
                                object.summarizationContext = $root.google.cloud.dialogflow.v2beta1.SummarizationContext.toObject(message.summarizationContext, options);
                                if (options.oneofs)
                                    object.context = "summarizationContext";
                            }
                            if (message.publishedModel != null && message.hasOwnProperty("publishedModel")) {
                                object.publishedModel = message.publishedModel;
                                if (options.oneofs)
                                    object.foundationModel = "publishedModel";
                            }
                            return object;
                        };
    
                        /**
                         * Converts this Generator to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.Generator
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        Generator.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for Generator
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.Generator
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        Generator.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Generator";
                        };
    
                        return Generator;
                    })();
    
                    v2beta1.FreeFormSuggestion = (function() {
    
                        /**
                         * Properties of a FreeFormSuggestion.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IFreeFormSuggestion
                         * @property {string|null} [response] FreeFormSuggestion response
                         */
    
                        /**
                         * Constructs a new FreeFormSuggestion.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a FreeFormSuggestion.
                         * @implements IFreeFormSuggestion
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IFreeFormSuggestion=} [properties] Properties to set
                         */
                        function FreeFormSuggestion(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * FreeFormSuggestion response.
                         * @member {string} response
                         * @memberof google.cloud.dialogflow.v2beta1.FreeFormSuggestion
                         * @instance
                         */
                        FreeFormSuggestion.prototype.response = "";
    
                        /**
                         * Creates a new FreeFormSuggestion instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.FreeFormSuggestion
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IFreeFormSuggestion=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.FreeFormSuggestion} FreeFormSuggestion instance
                         */
                        FreeFormSuggestion.create = function create(properties) {
                            return new FreeFormSuggestion(properties);
                        };
    
                        /**
                         * Encodes the specified FreeFormSuggestion message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.FreeFormSuggestion.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.FreeFormSuggestion
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IFreeFormSuggestion} message FreeFormSuggestion message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        FreeFormSuggestion.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.response != null && Object.hasOwnProperty.call(message, "response"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.response);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified FreeFormSuggestion message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.FreeFormSuggestion.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.FreeFormSuggestion
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IFreeFormSuggestion} message FreeFormSuggestion message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        FreeFormSuggestion.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a FreeFormSuggestion message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.FreeFormSuggestion
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.FreeFormSuggestion} FreeFormSuggestion
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        FreeFormSuggestion.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.FreeFormSuggestion();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.response = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a FreeFormSuggestion message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.FreeFormSuggestion
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.FreeFormSuggestion} FreeFormSuggestion
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        FreeFormSuggestion.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a FreeFormSuggestion message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.FreeFormSuggestion
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        FreeFormSuggestion.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.response != null && message.hasOwnProperty("response"))
                                if (!$util.isString(message.response))
                                    return "response: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a FreeFormSuggestion message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.FreeFormSuggestion
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.FreeFormSuggestion} FreeFormSuggestion
                         */
                        FreeFormSuggestion.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.FreeFormSuggestion)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.FreeFormSuggestion();
                            if (object.response != null)
                                message.response = String(object.response);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a FreeFormSuggestion message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.FreeFormSuggestion
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.FreeFormSuggestion} message FreeFormSuggestion
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        FreeFormSuggestion.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.response = "";
                            if (message.response != null && message.hasOwnProperty("response"))
                                object.response = message.response;
                            return object;
                        };
    
                        /**
                         * Converts this FreeFormSuggestion to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.FreeFormSuggestion
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        FreeFormSuggestion.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for FreeFormSuggestion
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.FreeFormSuggestion
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        FreeFormSuggestion.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.FreeFormSuggestion";
                        };
    
                        return FreeFormSuggestion;
                    })();
    
                    v2beta1.SummarySuggestion = (function() {
    
                        /**
                         * Properties of a SummarySuggestion.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ISummarySuggestion
                         * @property {Array.<google.cloud.dialogflow.v2beta1.SummarySuggestion.ISummarySection>|null} [summarySections] SummarySuggestion summarySections
                         */
    
                        /**
                         * Constructs a new SummarySuggestion.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a SummarySuggestion.
                         * @implements ISummarySuggestion
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ISummarySuggestion=} [properties] Properties to set
                         */
                        function SummarySuggestion(properties) {
                            this.summarySections = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SummarySuggestion summarySections.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.SummarySuggestion.ISummarySection>} summarySections
                         * @memberof google.cloud.dialogflow.v2beta1.SummarySuggestion
                         * @instance
                         */
                        SummarySuggestion.prototype.summarySections = $util.emptyArray;
    
                        /**
                         * Creates a new SummarySuggestion instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.SummarySuggestion
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISummarySuggestion=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.SummarySuggestion} SummarySuggestion instance
                         */
                        SummarySuggestion.create = function create(properties) {
                            return new SummarySuggestion(properties);
                        };
    
                        /**
                         * Encodes the specified SummarySuggestion message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SummarySuggestion.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.SummarySuggestion
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISummarySuggestion} message SummarySuggestion message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SummarySuggestion.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.summarySections != null && message.summarySections.length)
                                for (var i = 0; i < message.summarySections.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.SummarySuggestion.SummarySection.encode(message.summarySections[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SummarySuggestion message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SummarySuggestion.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SummarySuggestion
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISummarySuggestion} message SummarySuggestion message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SummarySuggestion.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SummarySuggestion message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.SummarySuggestion
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.SummarySuggestion} SummarySuggestion
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SummarySuggestion.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.SummarySuggestion();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.summarySections && message.summarySections.length))
                                            message.summarySections = [];
                                        message.summarySections.push($root.google.cloud.dialogflow.v2beta1.SummarySuggestion.SummarySection.decode(reader, reader.uint32()));
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SummarySuggestion message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SummarySuggestion
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.SummarySuggestion} SummarySuggestion
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SummarySuggestion.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SummarySuggestion message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.SummarySuggestion
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SummarySuggestion.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.summarySections != null && message.hasOwnProperty("summarySections")) {
                                if (!Array.isArray(message.summarySections))
                                    return "summarySections: array expected";
                                for (var i = 0; i < message.summarySections.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.SummarySuggestion.SummarySection.verify(message.summarySections[i]);
                                    if (error)
                                        return "summarySections." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates a SummarySuggestion message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.SummarySuggestion
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.SummarySuggestion} SummarySuggestion
                         */
                        SummarySuggestion.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.SummarySuggestion)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.SummarySuggestion();
                            if (object.summarySections) {
                                if (!Array.isArray(object.summarySections))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.SummarySuggestion.summarySections: array expected");
                                message.summarySections = [];
                                for (var i = 0; i < object.summarySections.length; ++i) {
                                    if (typeof object.summarySections[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.SummarySuggestion.summarySections: object expected");
                                    message.summarySections[i] = $root.google.cloud.dialogflow.v2beta1.SummarySuggestion.SummarySection.fromObject(object.summarySections[i]);
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SummarySuggestion message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.SummarySuggestion
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.SummarySuggestion} message SummarySuggestion
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SummarySuggestion.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.summarySections = [];
                            if (message.summarySections && message.summarySections.length) {
                                object.summarySections = [];
                                for (var j = 0; j < message.summarySections.length; ++j)
                                    object.summarySections[j] = $root.google.cloud.dialogflow.v2beta1.SummarySuggestion.SummarySection.toObject(message.summarySections[j], options);
                            }
                            return object;
                        };
    
                        /**
                         * Converts this SummarySuggestion to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.SummarySuggestion
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SummarySuggestion.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SummarySuggestion
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.SummarySuggestion
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SummarySuggestion.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.SummarySuggestion";
                        };
    
                        SummarySuggestion.SummarySection = (function() {
    
                            /**
                             * Properties of a SummarySection.
                             * @memberof google.cloud.dialogflow.v2beta1.SummarySuggestion
                             * @interface ISummarySection
                             * @property {string|null} [section] SummarySection section
                             * @property {string|null} [summary] SummarySection summary
                             */
    
                            /**
                             * Constructs a new SummarySection.
                             * @memberof google.cloud.dialogflow.v2beta1.SummarySuggestion
                             * @classdesc Represents a SummarySection.
                             * @implements ISummarySection
                             * @constructor
                             * @param {google.cloud.dialogflow.v2beta1.SummarySuggestion.ISummarySection=} [properties] Properties to set
                             */
                            function SummarySection(properties) {
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * SummarySection section.
                             * @member {string} section
                             * @memberof google.cloud.dialogflow.v2beta1.SummarySuggestion.SummarySection
                             * @instance
                             */
                            SummarySection.prototype.section = "";
    
                            /**
                             * SummarySection summary.
                             * @member {string} summary
                             * @memberof google.cloud.dialogflow.v2beta1.SummarySuggestion.SummarySection
                             * @instance
                             */
                            SummarySection.prototype.summary = "";
    
                            /**
                             * Creates a new SummarySection instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2beta1.SummarySuggestion.SummarySection
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.SummarySuggestion.ISummarySection=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2beta1.SummarySuggestion.SummarySection} SummarySection instance
                             */
                            SummarySection.create = function create(properties) {
                                return new SummarySection(properties);
                            };
    
                            /**
                             * Encodes the specified SummarySection message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SummarySuggestion.SummarySection.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2beta1.SummarySuggestion.SummarySection
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.SummarySuggestion.ISummarySection} message SummarySection message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            SummarySection.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.section != null && Object.hasOwnProperty.call(message, "section"))
                                    writer.uint32(/* id 1, wireType 2 =*/10).string(message.section);
                                if (message.summary != null && Object.hasOwnProperty.call(message, "summary"))
                                    writer.uint32(/* id 2, wireType 2 =*/18).string(message.summary);
                                return writer;
                            };
    
                            /**
                             * Encodes the specified SummarySection message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SummarySuggestion.SummarySection.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.SummarySuggestion.SummarySection
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.SummarySuggestion.ISummarySection} message SummarySection message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            SummarySection.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a SummarySection message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2beta1.SummarySuggestion.SummarySection
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2beta1.SummarySuggestion.SummarySection} SummarySection
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            SummarySection.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.SummarySuggestion.SummarySection();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.section = reader.string();
                                            break;
                                        }
                                    case 2: {
                                            message.summary = reader.string();
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a SummarySection message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.SummarySuggestion.SummarySection
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2beta1.SummarySuggestion.SummarySection} SummarySection
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            SummarySection.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a SummarySection message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2beta1.SummarySuggestion.SummarySection
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            SummarySection.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.section != null && message.hasOwnProperty("section"))
                                    if (!$util.isString(message.section))
                                        return "section: string expected";
                                if (message.summary != null && message.hasOwnProperty("summary"))
                                    if (!$util.isString(message.summary))
                                        return "summary: string expected";
                                return null;
                            };
    
                            /**
                             * Creates a SummarySection message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2beta1.SummarySuggestion.SummarySection
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2beta1.SummarySuggestion.SummarySection} SummarySection
                             */
                            SummarySection.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2beta1.SummarySuggestion.SummarySection)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2beta1.SummarySuggestion.SummarySection();
                                if (object.section != null)
                                    message.section = String(object.section);
                                if (object.summary != null)
                                    message.summary = String(object.summary);
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a SummarySection message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2beta1.SummarySuggestion.SummarySection
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.SummarySuggestion.SummarySection} message SummarySection
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            SummarySection.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.defaults) {
                                    object.section = "";
                                    object.summary = "";
                                }
                                if (message.section != null && message.hasOwnProperty("section"))
                                    object.section = message.section;
                                if (message.summary != null && message.hasOwnProperty("summary"))
                                    object.summary = message.summary;
                                return object;
                            };
    
                            /**
                             * Converts this SummarySection to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2beta1.SummarySuggestion.SummarySection
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            SummarySection.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for SummarySection
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2beta1.SummarySuggestion.SummarySection
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            SummarySection.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.SummarySuggestion.SummarySection";
                            };
    
                            return SummarySection;
                        })();
    
                        return SummarySuggestion;
                    })();
    
                    v2beta1.GeneratorSuggestion = (function() {
    
                        /**
                         * Properties of a GeneratorSuggestion.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IGeneratorSuggestion
                         * @property {google.cloud.dialogflow.v2beta1.IFreeFormSuggestion|null} [freeFormSuggestion] GeneratorSuggestion freeFormSuggestion
                         * @property {google.cloud.dialogflow.v2beta1.ISummarySuggestion|null} [summarySuggestion] GeneratorSuggestion summarySuggestion
                         */
    
                        /**
                         * Constructs a new GeneratorSuggestion.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a GeneratorSuggestion.
                         * @implements IGeneratorSuggestion
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IGeneratorSuggestion=} [properties] Properties to set
                         */
                        function GeneratorSuggestion(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GeneratorSuggestion freeFormSuggestion.
                         * @member {google.cloud.dialogflow.v2beta1.IFreeFormSuggestion|null|undefined} freeFormSuggestion
                         * @memberof google.cloud.dialogflow.v2beta1.GeneratorSuggestion
                         * @instance
                         */
                        GeneratorSuggestion.prototype.freeFormSuggestion = null;
    
                        /**
                         * GeneratorSuggestion summarySuggestion.
                         * @member {google.cloud.dialogflow.v2beta1.ISummarySuggestion|null|undefined} summarySuggestion
                         * @memberof google.cloud.dialogflow.v2beta1.GeneratorSuggestion
                         * @instance
                         */
                        GeneratorSuggestion.prototype.summarySuggestion = null;
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * GeneratorSuggestion suggestion.
                         * @member {"freeFormSuggestion"|"summarySuggestion"|undefined} suggestion
                         * @memberof google.cloud.dialogflow.v2beta1.GeneratorSuggestion
                         * @instance
                         */
                        Object.defineProperty(GeneratorSuggestion.prototype, "suggestion", {
                            get: $util.oneOfGetter($oneOfFields = ["freeFormSuggestion", "summarySuggestion"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new GeneratorSuggestion instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.GeneratorSuggestion
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGeneratorSuggestion=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.GeneratorSuggestion} GeneratorSuggestion instance
                         */
                        GeneratorSuggestion.create = function create(properties) {
                            return new GeneratorSuggestion(properties);
                        };
    
                        /**
                         * Encodes the specified GeneratorSuggestion message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GeneratorSuggestion.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.GeneratorSuggestion
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGeneratorSuggestion} message GeneratorSuggestion message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GeneratorSuggestion.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.freeFormSuggestion != null && Object.hasOwnProperty.call(message, "freeFormSuggestion"))
                                $root.google.cloud.dialogflow.v2beta1.FreeFormSuggestion.encode(message.freeFormSuggestion, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.summarySuggestion != null && Object.hasOwnProperty.call(message, "summarySuggestion"))
                                $root.google.cloud.dialogflow.v2beta1.SummarySuggestion.encode(message.summarySuggestion, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GeneratorSuggestion message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GeneratorSuggestion.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GeneratorSuggestion
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGeneratorSuggestion} message GeneratorSuggestion message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GeneratorSuggestion.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GeneratorSuggestion message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.GeneratorSuggestion
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.GeneratorSuggestion} GeneratorSuggestion
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GeneratorSuggestion.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.GeneratorSuggestion();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.freeFormSuggestion = $root.google.cloud.dialogflow.v2beta1.FreeFormSuggestion.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.summarySuggestion = $root.google.cloud.dialogflow.v2beta1.SummarySuggestion.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GeneratorSuggestion message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GeneratorSuggestion
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.GeneratorSuggestion} GeneratorSuggestion
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GeneratorSuggestion.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GeneratorSuggestion message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.GeneratorSuggestion
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GeneratorSuggestion.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.freeFormSuggestion != null && message.hasOwnProperty("freeFormSuggestion")) {
                                properties.suggestion = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2beta1.FreeFormSuggestion.verify(message.freeFormSuggestion);
                                    if (error)
                                        return "freeFormSuggestion." + error;
                                }
                            }
                            if (message.summarySuggestion != null && message.hasOwnProperty("summarySuggestion")) {
                                if (properties.suggestion === 1)
                                    return "suggestion: multiple values";
                                properties.suggestion = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2beta1.SummarySuggestion.verify(message.summarySuggestion);
                                    if (error)
                                        return "summarySuggestion." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates a GeneratorSuggestion message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.GeneratorSuggestion
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.GeneratorSuggestion} GeneratorSuggestion
                         */
                        GeneratorSuggestion.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.GeneratorSuggestion)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.GeneratorSuggestion();
                            if (object.freeFormSuggestion != null) {
                                if (typeof object.freeFormSuggestion !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.GeneratorSuggestion.freeFormSuggestion: object expected");
                                message.freeFormSuggestion = $root.google.cloud.dialogflow.v2beta1.FreeFormSuggestion.fromObject(object.freeFormSuggestion);
                            }
                            if (object.summarySuggestion != null) {
                                if (typeof object.summarySuggestion !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.GeneratorSuggestion.summarySuggestion: object expected");
                                message.summarySuggestion = $root.google.cloud.dialogflow.v2beta1.SummarySuggestion.fromObject(object.summarySuggestion);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GeneratorSuggestion message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.GeneratorSuggestion
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.GeneratorSuggestion} message GeneratorSuggestion
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GeneratorSuggestion.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (message.freeFormSuggestion != null && message.hasOwnProperty("freeFormSuggestion")) {
                                object.freeFormSuggestion = $root.google.cloud.dialogflow.v2beta1.FreeFormSuggestion.toObject(message.freeFormSuggestion, options);
                                if (options.oneofs)
                                    object.suggestion = "freeFormSuggestion";
                            }
                            if (message.summarySuggestion != null && message.hasOwnProperty("summarySuggestion")) {
                                object.summarySuggestion = $root.google.cloud.dialogflow.v2beta1.SummarySuggestion.toObject(message.summarySuggestion, options);
                                if (options.oneofs)
                                    object.suggestion = "summarySuggestion";
                            }
                            return object;
                        };
    
                        /**
                         * Converts this GeneratorSuggestion to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.GeneratorSuggestion
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GeneratorSuggestion.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GeneratorSuggestion
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.GeneratorSuggestion
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GeneratorSuggestion.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.GeneratorSuggestion";
                        };
    
                        return GeneratorSuggestion;
                    })();
    
                    /**
                     * TriggerEvent enum.
                     * @name google.cloud.dialogflow.v2beta1.TriggerEvent
                     * @enum {number}
                     * @property {number} TRIGGER_EVENT_UNSPECIFIED=0 TRIGGER_EVENT_UNSPECIFIED value
                     * @property {number} END_OF_UTTERANCE=1 END_OF_UTTERANCE value
                     * @property {number} MANUAL_CALL=2 MANUAL_CALL value
                     * @property {number} CUSTOMER_MESSAGE=3 CUSTOMER_MESSAGE value
                     * @property {number} AGENT_MESSAGE=4 AGENT_MESSAGE value
                     */
                    v2beta1.TriggerEvent = (function() {
                        var valuesById = {}, values = Object.create(valuesById);
                        values[valuesById[0] = "TRIGGER_EVENT_UNSPECIFIED"] = 0;
                        values[valuesById[1] = "END_OF_UTTERANCE"] = 1;
                        values[valuesById[2] = "MANUAL_CALL"] = 2;
                        values[valuesById[3] = "CUSTOMER_MESSAGE"] = 3;
                        values[valuesById[4] = "AGENT_MESSAGE"] = 4;
                        return values;
                    })();
    
                    v2beta1.Sessions = (function() {
    
                        /**
                         * Constructs a new Sessions service.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a Sessions
                         * @extends $protobuf.rpc.Service
                         * @constructor
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         */
                        function Sessions(rpcImpl, requestDelimited, responseDelimited) {
                            $protobuf.rpc.Service.call(this, rpcImpl, requestDelimited, responseDelimited);
                        }
    
                        (Sessions.prototype = Object.create($protobuf.rpc.Service.prototype)).constructor = Sessions;
    
                        /**
                         * Creates new Sessions service using the specified rpc implementation.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.Sessions
                         * @static
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         * @returns {Sessions} RPC service. Useful where requests and/or responses are streamed.
                         */
                        Sessions.create = function create(rpcImpl, requestDelimited, responseDelimited) {
                            return new this(rpcImpl, requestDelimited, responseDelimited);
                        };
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Sessions|detectIntent}.
                         * @memberof google.cloud.dialogflow.v2beta1.Sessions
                         * @typedef DetectIntentCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.DetectIntentResponse} [response] DetectIntentResponse
                         */
    
                        /**
                         * Calls DetectIntent.
                         * @function detectIntent
                         * @memberof google.cloud.dialogflow.v2beta1.Sessions
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IDetectIntentRequest} request DetectIntentRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Sessions.DetectIntentCallback} callback Node-style callback called with the error, if any, and DetectIntentResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Sessions.prototype.detectIntent = function detectIntent(request, callback) {
                            return this.rpcCall(detectIntent, $root.google.cloud.dialogflow.v2beta1.DetectIntentRequest, $root.google.cloud.dialogflow.v2beta1.DetectIntentResponse, request, callback);
                        }, "name", { value: "DetectIntent" });
    
                        /**
                         * Calls DetectIntent.
                         * @function detectIntent
                         * @memberof google.cloud.dialogflow.v2beta1.Sessions
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IDetectIntentRequest} request DetectIntentRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.DetectIntentResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Sessions|streamingDetectIntent}.
                         * @memberof google.cloud.dialogflow.v2beta1.Sessions
                         * @typedef StreamingDetectIntentCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.StreamingDetectIntentResponse} [response] StreamingDetectIntentResponse
                         */
    
                        /**
                         * Calls StreamingDetectIntent.
                         * @function streamingDetectIntent
                         * @memberof google.cloud.dialogflow.v2beta1.Sessions
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IStreamingDetectIntentRequest} request StreamingDetectIntentRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Sessions.StreamingDetectIntentCallback} callback Node-style callback called with the error, if any, and StreamingDetectIntentResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Sessions.prototype.streamingDetectIntent = function streamingDetectIntent(request, callback) {
                            return this.rpcCall(streamingDetectIntent, $root.google.cloud.dialogflow.v2beta1.StreamingDetectIntentRequest, $root.google.cloud.dialogflow.v2beta1.StreamingDetectIntentResponse, request, callback);
                        }, "name", { value: "StreamingDetectIntent" });
    
                        /**
                         * Calls StreamingDetectIntent.
                         * @function streamingDetectIntent
                         * @memberof google.cloud.dialogflow.v2beta1.Sessions
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IStreamingDetectIntentRequest} request StreamingDetectIntentRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.StreamingDetectIntentResponse>} Promise
                         * @variation 2
                         */
    
                        return Sessions;
                    })();
    
                    v2beta1.DetectIntentRequest = (function() {
    
                        /**
                         * Properties of a DetectIntentRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IDetectIntentRequest
                         * @property {string|null} [session] DetectIntentRequest session
                         * @property {google.cloud.dialogflow.v2beta1.IQueryParameters|null} [queryParams] DetectIntentRequest queryParams
                         * @property {google.cloud.dialogflow.v2beta1.IQueryInput|null} [queryInput] DetectIntentRequest queryInput
                         * @property {google.cloud.dialogflow.v2beta1.IOutputAudioConfig|null} [outputAudioConfig] DetectIntentRequest outputAudioConfig
                         * @property {google.protobuf.IFieldMask|null} [outputAudioConfigMask] DetectIntentRequest outputAudioConfigMask
                         * @property {Uint8Array|null} [inputAudio] DetectIntentRequest inputAudio
                         */
    
                        /**
                         * Constructs a new DetectIntentRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a DetectIntentRequest.
                         * @implements IDetectIntentRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IDetectIntentRequest=} [properties] Properties to set
                         */
                        function DetectIntentRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * DetectIntentRequest session.
                         * @member {string} session
                         * @memberof google.cloud.dialogflow.v2beta1.DetectIntentRequest
                         * @instance
                         */
                        DetectIntentRequest.prototype.session = "";
    
                        /**
                         * DetectIntentRequest queryParams.
                         * @member {google.cloud.dialogflow.v2beta1.IQueryParameters|null|undefined} queryParams
                         * @memberof google.cloud.dialogflow.v2beta1.DetectIntentRequest
                         * @instance
                         */
                        DetectIntentRequest.prototype.queryParams = null;
    
                        /**
                         * DetectIntentRequest queryInput.
                         * @member {google.cloud.dialogflow.v2beta1.IQueryInput|null|undefined} queryInput
                         * @memberof google.cloud.dialogflow.v2beta1.DetectIntentRequest
                         * @instance
                         */
                        DetectIntentRequest.prototype.queryInput = null;
    
                        /**
                         * DetectIntentRequest outputAudioConfig.
                         * @member {google.cloud.dialogflow.v2beta1.IOutputAudioConfig|null|undefined} outputAudioConfig
                         * @memberof google.cloud.dialogflow.v2beta1.DetectIntentRequest
                         * @instance
                         */
                        DetectIntentRequest.prototype.outputAudioConfig = null;
    
                        /**
                         * DetectIntentRequest outputAudioConfigMask.
                         * @member {google.protobuf.IFieldMask|null|undefined} outputAudioConfigMask
                         * @memberof google.cloud.dialogflow.v2beta1.DetectIntentRequest
                         * @instance
                         */
                        DetectIntentRequest.prototype.outputAudioConfigMask = null;
    
                        /**
                         * DetectIntentRequest inputAudio.
                         * @member {Uint8Array} inputAudio
                         * @memberof google.cloud.dialogflow.v2beta1.DetectIntentRequest
                         * @instance
                         */
                        DetectIntentRequest.prototype.inputAudio = $util.newBuffer([]);
    
                        /**
                         * Creates a new DetectIntentRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.DetectIntentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDetectIntentRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.DetectIntentRequest} DetectIntentRequest instance
                         */
                        DetectIntentRequest.create = function create(properties) {
                            return new DetectIntentRequest(properties);
                        };
    
                        /**
                         * Encodes the specified DetectIntentRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.DetectIntentRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.DetectIntentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDetectIntentRequest} message DetectIntentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DetectIntentRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.session != null && Object.hasOwnProperty.call(message, "session"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.session);
                            if (message.queryParams != null && Object.hasOwnProperty.call(message, "queryParams"))
                                $root.google.cloud.dialogflow.v2beta1.QueryParameters.encode(message.queryParams, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.queryInput != null && Object.hasOwnProperty.call(message, "queryInput"))
                                $root.google.cloud.dialogflow.v2beta1.QueryInput.encode(message.queryInput, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            if (message.outputAudioConfig != null && Object.hasOwnProperty.call(message, "outputAudioConfig"))
                                $root.google.cloud.dialogflow.v2beta1.OutputAudioConfig.encode(message.outputAudioConfig, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            if (message.inputAudio != null && Object.hasOwnProperty.call(message, "inputAudio"))
                                writer.uint32(/* id 5, wireType 2 =*/42).bytes(message.inputAudio);
                            if (message.outputAudioConfigMask != null && Object.hasOwnProperty.call(message, "outputAudioConfigMask"))
                                $root.google.protobuf.FieldMask.encode(message.outputAudioConfigMask, writer.uint32(/* id 7, wireType 2 =*/58).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified DetectIntentRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.DetectIntentRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.DetectIntentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDetectIntentRequest} message DetectIntentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DetectIntentRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a DetectIntentRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.DetectIntentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.DetectIntentRequest} DetectIntentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DetectIntentRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.DetectIntentRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.session = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.queryParams = $root.google.cloud.dialogflow.v2beta1.QueryParameters.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 3: {
                                        message.queryInput = $root.google.cloud.dialogflow.v2beta1.QueryInput.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 4: {
                                        message.outputAudioConfig = $root.google.cloud.dialogflow.v2beta1.OutputAudioConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 7: {
                                        message.outputAudioConfigMask = $root.google.protobuf.FieldMask.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 5: {
                                        message.inputAudio = reader.bytes();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a DetectIntentRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.DetectIntentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.DetectIntentRequest} DetectIntentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DetectIntentRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a DetectIntentRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.DetectIntentRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        DetectIntentRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.session != null && message.hasOwnProperty("session"))
                                if (!$util.isString(message.session))
                                    return "session: string expected";
                            if (message.queryParams != null && message.hasOwnProperty("queryParams")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.QueryParameters.verify(message.queryParams);
                                if (error)
                                    return "queryParams." + error;
                            }
                            if (message.queryInput != null && message.hasOwnProperty("queryInput")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.QueryInput.verify(message.queryInput);
                                if (error)
                                    return "queryInput." + error;
                            }
                            if (message.outputAudioConfig != null && message.hasOwnProperty("outputAudioConfig")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.OutputAudioConfig.verify(message.outputAudioConfig);
                                if (error)
                                    return "outputAudioConfig." + error;
                            }
                            if (message.outputAudioConfigMask != null && message.hasOwnProperty("outputAudioConfigMask")) {
                                var error = $root.google.protobuf.FieldMask.verify(message.outputAudioConfigMask);
                                if (error)
                                    return "outputAudioConfigMask." + error;
                            }
                            if (message.inputAudio != null && message.hasOwnProperty("inputAudio"))
                                if (!(message.inputAudio && typeof message.inputAudio.length === "number" || $util.isString(message.inputAudio)))
                                    return "inputAudio: buffer expected";
                            return null;
                        };
    
                        /**
                         * Creates a DetectIntentRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.DetectIntentRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.DetectIntentRequest} DetectIntentRequest
                         */
                        DetectIntentRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.DetectIntentRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.DetectIntentRequest();
                            if (object.session != null)
                                message.session = String(object.session);
                            if (object.queryParams != null) {
                                if (typeof object.queryParams !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.DetectIntentRequest.queryParams: object expected");
                                message.queryParams = $root.google.cloud.dialogflow.v2beta1.QueryParameters.fromObject(object.queryParams);
                            }
                            if (object.queryInput != null) {
                                if (typeof object.queryInput !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.DetectIntentRequest.queryInput: object expected");
                                message.queryInput = $root.google.cloud.dialogflow.v2beta1.QueryInput.fromObject(object.queryInput);
                            }
                            if (object.outputAudioConfig != null) {
                                if (typeof object.outputAudioConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.DetectIntentRequest.outputAudioConfig: object expected");
                                message.outputAudioConfig = $root.google.cloud.dialogflow.v2beta1.OutputAudioConfig.fromObject(object.outputAudioConfig);
                            }
                            if (object.outputAudioConfigMask != null) {
                                if (typeof object.outputAudioConfigMask !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.DetectIntentRequest.outputAudioConfigMask: object expected");
                                message.outputAudioConfigMask = $root.google.protobuf.FieldMask.fromObject(object.outputAudioConfigMask);
                            }
                            if (object.inputAudio != null)
                                if (typeof object.inputAudio === "string")
                                    $util.base64.decode(object.inputAudio, message.inputAudio = $util.newBuffer($util.base64.length(object.inputAudio)), 0);
                                else if (object.inputAudio.length >= 0)
                                    message.inputAudio = object.inputAudio;
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a DetectIntentRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.DetectIntentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.DetectIntentRequest} message DetectIntentRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        DetectIntentRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.session = "";
                                object.queryParams = null;
                                object.queryInput = null;
                                object.outputAudioConfig = null;
                                if (options.bytes === String)
                                    object.inputAudio = "";
                                else {
                                    object.inputAudio = [];
                                    if (options.bytes !== Array)
                                        object.inputAudio = $util.newBuffer(object.inputAudio);
                                }
                                object.outputAudioConfigMask = null;
                            }
                            if (message.session != null && message.hasOwnProperty("session"))
                                object.session = message.session;
                            if (message.queryParams != null && message.hasOwnProperty("queryParams"))
                                object.queryParams = $root.google.cloud.dialogflow.v2beta1.QueryParameters.toObject(message.queryParams, options);
                            if (message.queryInput != null && message.hasOwnProperty("queryInput"))
                                object.queryInput = $root.google.cloud.dialogflow.v2beta1.QueryInput.toObject(message.queryInput, options);
                            if (message.outputAudioConfig != null && message.hasOwnProperty("outputAudioConfig"))
                                object.outputAudioConfig = $root.google.cloud.dialogflow.v2beta1.OutputAudioConfig.toObject(message.outputAudioConfig, options);
                            if (message.inputAudio != null && message.hasOwnProperty("inputAudio"))
                                object.inputAudio = options.bytes === String ? $util.base64.encode(message.inputAudio, 0, message.inputAudio.length) : options.bytes === Array ? Array.prototype.slice.call(message.inputAudio) : message.inputAudio;
                            if (message.outputAudioConfigMask != null && message.hasOwnProperty("outputAudioConfigMask"))
                                object.outputAudioConfigMask = $root.google.protobuf.FieldMask.toObject(message.outputAudioConfigMask, options);
                            return object;
                        };
    
                        /**
                         * Converts this DetectIntentRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.DetectIntentRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        DetectIntentRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for DetectIntentRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.DetectIntentRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        DetectIntentRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.DetectIntentRequest";
                        };
    
                        return DetectIntentRequest;
                    })();
    
                    v2beta1.DetectIntentResponse = (function() {
    
                        /**
                         * Properties of a DetectIntentResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IDetectIntentResponse
                         * @property {string|null} [responseId] DetectIntentResponse responseId
                         * @property {google.cloud.dialogflow.v2beta1.IQueryResult|null} [queryResult] DetectIntentResponse queryResult
                         * @property {Array.<google.cloud.dialogflow.v2beta1.IQueryResult>|null} [alternativeQueryResults] DetectIntentResponse alternativeQueryResults
                         * @property {google.rpc.IStatus|null} [webhookStatus] DetectIntentResponse webhookStatus
                         * @property {Uint8Array|null} [outputAudio] DetectIntentResponse outputAudio
                         * @property {google.cloud.dialogflow.v2beta1.IOutputAudioConfig|null} [outputAudioConfig] DetectIntentResponse outputAudioConfig
                         */
    
                        /**
                         * Constructs a new DetectIntentResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a DetectIntentResponse.
                         * @implements IDetectIntentResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IDetectIntentResponse=} [properties] Properties to set
                         */
                        function DetectIntentResponse(properties) {
                            this.alternativeQueryResults = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * DetectIntentResponse responseId.
                         * @member {string} responseId
                         * @memberof google.cloud.dialogflow.v2beta1.DetectIntentResponse
                         * @instance
                         */
                        DetectIntentResponse.prototype.responseId = "";
    
                        /**
                         * DetectIntentResponse queryResult.
                         * @member {google.cloud.dialogflow.v2beta1.IQueryResult|null|undefined} queryResult
                         * @memberof google.cloud.dialogflow.v2beta1.DetectIntentResponse
                         * @instance
                         */
                        DetectIntentResponse.prototype.queryResult = null;
    
                        /**
                         * DetectIntentResponse alternativeQueryResults.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.IQueryResult>} alternativeQueryResults
                         * @memberof google.cloud.dialogflow.v2beta1.DetectIntentResponse
                         * @instance
                         */
                        DetectIntentResponse.prototype.alternativeQueryResults = $util.emptyArray;
    
                        /**
                         * DetectIntentResponse webhookStatus.
                         * @member {google.rpc.IStatus|null|undefined} webhookStatus
                         * @memberof google.cloud.dialogflow.v2beta1.DetectIntentResponse
                         * @instance
                         */
                        DetectIntentResponse.prototype.webhookStatus = null;
    
                        /**
                         * DetectIntentResponse outputAudio.
                         * @member {Uint8Array} outputAudio
                         * @memberof google.cloud.dialogflow.v2beta1.DetectIntentResponse
                         * @instance
                         */
                        DetectIntentResponse.prototype.outputAudio = $util.newBuffer([]);
    
                        /**
                         * DetectIntentResponse outputAudioConfig.
                         * @member {google.cloud.dialogflow.v2beta1.IOutputAudioConfig|null|undefined} outputAudioConfig
                         * @memberof google.cloud.dialogflow.v2beta1.DetectIntentResponse
                         * @instance
                         */
                        DetectIntentResponse.prototype.outputAudioConfig = null;
    
                        /**
                         * Creates a new DetectIntentResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.DetectIntentResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDetectIntentResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.DetectIntentResponse} DetectIntentResponse instance
                         */
                        DetectIntentResponse.create = function create(properties) {
                            return new DetectIntentResponse(properties);
                        };
    
                        /**
                         * Encodes the specified DetectIntentResponse message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.DetectIntentResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.DetectIntentResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDetectIntentResponse} message DetectIntentResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DetectIntentResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.responseId != null && Object.hasOwnProperty.call(message, "responseId"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.responseId);
                            if (message.queryResult != null && Object.hasOwnProperty.call(message, "queryResult"))
                                $root.google.cloud.dialogflow.v2beta1.QueryResult.encode(message.queryResult, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.webhookStatus != null && Object.hasOwnProperty.call(message, "webhookStatus"))
                                $root.google.rpc.Status.encode(message.webhookStatus, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            if (message.outputAudio != null && Object.hasOwnProperty.call(message, "outputAudio"))
                                writer.uint32(/* id 4, wireType 2 =*/34).bytes(message.outputAudio);
                            if (message.alternativeQueryResults != null && message.alternativeQueryResults.length)
                                for (var i = 0; i < message.alternativeQueryResults.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.QueryResult.encode(message.alternativeQueryResults[i], writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                            if (message.outputAudioConfig != null && Object.hasOwnProperty.call(message, "outputAudioConfig"))
                                $root.google.cloud.dialogflow.v2beta1.OutputAudioConfig.encode(message.outputAudioConfig, writer.uint32(/* id 6, wireType 2 =*/50).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified DetectIntentResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.DetectIntentResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.DetectIntentResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDetectIntentResponse} message DetectIntentResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DetectIntentResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a DetectIntentResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.DetectIntentResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.DetectIntentResponse} DetectIntentResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DetectIntentResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.DetectIntentResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.responseId = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.queryResult = $root.google.cloud.dialogflow.v2beta1.QueryResult.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 5: {
                                        if (!(message.alternativeQueryResults && message.alternativeQueryResults.length))
                                            message.alternativeQueryResults = [];
                                        message.alternativeQueryResults.push($root.google.cloud.dialogflow.v2beta1.QueryResult.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 3: {
                                        message.webhookStatus = $root.google.rpc.Status.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 4: {
                                        message.outputAudio = reader.bytes();
                                        break;
                                    }
                                case 6: {
                                        message.outputAudioConfig = $root.google.cloud.dialogflow.v2beta1.OutputAudioConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a DetectIntentResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.DetectIntentResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.DetectIntentResponse} DetectIntentResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DetectIntentResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a DetectIntentResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.DetectIntentResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        DetectIntentResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.responseId != null && message.hasOwnProperty("responseId"))
                                if (!$util.isString(message.responseId))
                                    return "responseId: string expected";
                            if (message.queryResult != null && message.hasOwnProperty("queryResult")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.QueryResult.verify(message.queryResult);
                                if (error)
                                    return "queryResult." + error;
                            }
                            if (message.alternativeQueryResults != null && message.hasOwnProperty("alternativeQueryResults")) {
                                if (!Array.isArray(message.alternativeQueryResults))
                                    return "alternativeQueryResults: array expected";
                                for (var i = 0; i < message.alternativeQueryResults.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.QueryResult.verify(message.alternativeQueryResults[i]);
                                    if (error)
                                        return "alternativeQueryResults." + error;
                                }
                            }
                            if (message.webhookStatus != null && message.hasOwnProperty("webhookStatus")) {
                                var error = $root.google.rpc.Status.verify(message.webhookStatus);
                                if (error)
                                    return "webhookStatus." + error;
                            }
                            if (message.outputAudio != null && message.hasOwnProperty("outputAudio"))
                                if (!(message.outputAudio && typeof message.outputAudio.length === "number" || $util.isString(message.outputAudio)))
                                    return "outputAudio: buffer expected";
                            if (message.outputAudioConfig != null && message.hasOwnProperty("outputAudioConfig")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.OutputAudioConfig.verify(message.outputAudioConfig);
                                if (error)
                                    return "outputAudioConfig." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a DetectIntentResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.DetectIntentResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.DetectIntentResponse} DetectIntentResponse
                         */
                        DetectIntentResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.DetectIntentResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.DetectIntentResponse();
                            if (object.responseId != null)
                                message.responseId = String(object.responseId);
                            if (object.queryResult != null) {
                                if (typeof object.queryResult !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.DetectIntentResponse.queryResult: object expected");
                                message.queryResult = $root.google.cloud.dialogflow.v2beta1.QueryResult.fromObject(object.queryResult);
                            }
                            if (object.alternativeQueryResults) {
                                if (!Array.isArray(object.alternativeQueryResults))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.DetectIntentResponse.alternativeQueryResults: array expected");
                                message.alternativeQueryResults = [];
                                for (var i = 0; i < object.alternativeQueryResults.length; ++i) {
                                    if (typeof object.alternativeQueryResults[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.DetectIntentResponse.alternativeQueryResults: object expected");
                                    message.alternativeQueryResults[i] = $root.google.cloud.dialogflow.v2beta1.QueryResult.fromObject(object.alternativeQueryResults[i]);
                                }
                            }
                            if (object.webhookStatus != null) {
                                if (typeof object.webhookStatus !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.DetectIntentResponse.webhookStatus: object expected");
                                message.webhookStatus = $root.google.rpc.Status.fromObject(object.webhookStatus);
                            }
                            if (object.outputAudio != null)
                                if (typeof object.outputAudio === "string")
                                    $util.base64.decode(object.outputAudio, message.outputAudio = $util.newBuffer($util.base64.length(object.outputAudio)), 0);
                                else if (object.outputAudio.length >= 0)
                                    message.outputAudio = object.outputAudio;
                            if (object.outputAudioConfig != null) {
                                if (typeof object.outputAudioConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.DetectIntentResponse.outputAudioConfig: object expected");
                                message.outputAudioConfig = $root.google.cloud.dialogflow.v2beta1.OutputAudioConfig.fromObject(object.outputAudioConfig);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a DetectIntentResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.DetectIntentResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.DetectIntentResponse} message DetectIntentResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        DetectIntentResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.alternativeQueryResults = [];
                            if (options.defaults) {
                                object.responseId = "";
                                object.queryResult = null;
                                object.webhookStatus = null;
                                if (options.bytes === String)
                                    object.outputAudio = "";
                                else {
                                    object.outputAudio = [];
                                    if (options.bytes !== Array)
                                        object.outputAudio = $util.newBuffer(object.outputAudio);
                                }
                                object.outputAudioConfig = null;
                            }
                            if (message.responseId != null && message.hasOwnProperty("responseId"))
                                object.responseId = message.responseId;
                            if (message.queryResult != null && message.hasOwnProperty("queryResult"))
                                object.queryResult = $root.google.cloud.dialogflow.v2beta1.QueryResult.toObject(message.queryResult, options);
                            if (message.webhookStatus != null && message.hasOwnProperty("webhookStatus"))
                                object.webhookStatus = $root.google.rpc.Status.toObject(message.webhookStatus, options);
                            if (message.outputAudio != null && message.hasOwnProperty("outputAudio"))
                                object.outputAudio = options.bytes === String ? $util.base64.encode(message.outputAudio, 0, message.outputAudio.length) : options.bytes === Array ? Array.prototype.slice.call(message.outputAudio) : message.outputAudio;
                            if (message.alternativeQueryResults && message.alternativeQueryResults.length) {
                                object.alternativeQueryResults = [];
                                for (var j = 0; j < message.alternativeQueryResults.length; ++j)
                                    object.alternativeQueryResults[j] = $root.google.cloud.dialogflow.v2beta1.QueryResult.toObject(message.alternativeQueryResults[j], options);
                            }
                            if (message.outputAudioConfig != null && message.hasOwnProperty("outputAudioConfig"))
                                object.outputAudioConfig = $root.google.cloud.dialogflow.v2beta1.OutputAudioConfig.toObject(message.outputAudioConfig, options);
                            return object;
                        };
    
                        /**
                         * Converts this DetectIntentResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.DetectIntentResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        DetectIntentResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for DetectIntentResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.DetectIntentResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        DetectIntentResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.DetectIntentResponse";
                        };
    
                        return DetectIntentResponse;
                    })();
    
                    v2beta1.QueryParameters = (function() {
    
                        /**
                         * Properties of a QueryParameters.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IQueryParameters
                         * @property {string|null} [timeZone] QueryParameters timeZone
                         * @property {google.type.ILatLng|null} [geoLocation] QueryParameters geoLocation
                         * @property {Array.<google.cloud.dialogflow.v2beta1.IContext>|null} [contexts] QueryParameters contexts
                         * @property {boolean|null} [resetContexts] QueryParameters resetContexts
                         * @property {Array.<google.cloud.dialogflow.v2beta1.ISessionEntityType>|null} [sessionEntityTypes] QueryParameters sessionEntityTypes
                         * @property {google.protobuf.IStruct|null} [payload] QueryParameters payload
                         * @property {Array.<string>|null} [knowledgeBaseNames] QueryParameters knowledgeBaseNames
                         * @property {google.cloud.dialogflow.v2beta1.ISentimentAnalysisRequestConfig|null} [sentimentAnalysisRequestConfig] QueryParameters sentimentAnalysisRequestConfig
                         * @property {Array.<google.cloud.dialogflow.v2beta1.ISubAgent>|null} [subAgents] QueryParameters subAgents
                         * @property {Object.<string,string>|null} [webhookHeaders] QueryParameters webhookHeaders
                         * @property {string|null} [platform] QueryParameters platform
                         */
    
                        /**
                         * Constructs a new QueryParameters.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a QueryParameters.
                         * @implements IQueryParameters
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IQueryParameters=} [properties] Properties to set
                         */
                        function QueryParameters(properties) {
                            this.contexts = [];
                            this.sessionEntityTypes = [];
                            this.knowledgeBaseNames = [];
                            this.subAgents = [];
                            this.webhookHeaders = {};
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * QueryParameters timeZone.
                         * @member {string} timeZone
                         * @memberof google.cloud.dialogflow.v2beta1.QueryParameters
                         * @instance
                         */
                        QueryParameters.prototype.timeZone = "";
    
                        /**
                         * QueryParameters geoLocation.
                         * @member {google.type.ILatLng|null|undefined} geoLocation
                         * @memberof google.cloud.dialogflow.v2beta1.QueryParameters
                         * @instance
                         */
                        QueryParameters.prototype.geoLocation = null;
    
                        /**
                         * QueryParameters contexts.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.IContext>} contexts
                         * @memberof google.cloud.dialogflow.v2beta1.QueryParameters
                         * @instance
                         */
                        QueryParameters.prototype.contexts = $util.emptyArray;
    
                        /**
                         * QueryParameters resetContexts.
                         * @member {boolean} resetContexts
                         * @memberof google.cloud.dialogflow.v2beta1.QueryParameters
                         * @instance
                         */
                        QueryParameters.prototype.resetContexts = false;
    
                        /**
                         * QueryParameters sessionEntityTypes.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.ISessionEntityType>} sessionEntityTypes
                         * @memberof google.cloud.dialogflow.v2beta1.QueryParameters
                         * @instance
                         */
                        QueryParameters.prototype.sessionEntityTypes = $util.emptyArray;
    
                        /**
                         * QueryParameters payload.
                         * @member {google.protobuf.IStruct|null|undefined} payload
                         * @memberof google.cloud.dialogflow.v2beta1.QueryParameters
                         * @instance
                         */
                        QueryParameters.prototype.payload = null;
    
                        /**
                         * QueryParameters knowledgeBaseNames.
                         * @member {Array.<string>} knowledgeBaseNames
                         * @memberof google.cloud.dialogflow.v2beta1.QueryParameters
                         * @instance
                         */
                        QueryParameters.prototype.knowledgeBaseNames = $util.emptyArray;
    
                        /**
                         * QueryParameters sentimentAnalysisRequestConfig.
                         * @member {google.cloud.dialogflow.v2beta1.ISentimentAnalysisRequestConfig|null|undefined} sentimentAnalysisRequestConfig
                         * @memberof google.cloud.dialogflow.v2beta1.QueryParameters
                         * @instance
                         */
                        QueryParameters.prototype.sentimentAnalysisRequestConfig = null;
    
                        /**
                         * QueryParameters subAgents.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.ISubAgent>} subAgents
                         * @memberof google.cloud.dialogflow.v2beta1.QueryParameters
                         * @instance
                         */
                        QueryParameters.prototype.subAgents = $util.emptyArray;
    
                        /**
                         * QueryParameters webhookHeaders.
                         * @member {Object.<string,string>} webhookHeaders
                         * @memberof google.cloud.dialogflow.v2beta1.QueryParameters
                         * @instance
                         */
                        QueryParameters.prototype.webhookHeaders = $util.emptyObject;
    
                        /**
                         * QueryParameters platform.
                         * @member {string} platform
                         * @memberof google.cloud.dialogflow.v2beta1.QueryParameters
                         * @instance
                         */
                        QueryParameters.prototype.platform = "";
    
                        /**
                         * Creates a new QueryParameters instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.QueryParameters
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IQueryParameters=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.QueryParameters} QueryParameters instance
                         */
                        QueryParameters.create = function create(properties) {
                            return new QueryParameters(properties);
                        };
    
                        /**
                         * Encodes the specified QueryParameters message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.QueryParameters.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.QueryParameters
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IQueryParameters} message QueryParameters message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        QueryParameters.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.timeZone != null && Object.hasOwnProperty.call(message, "timeZone"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.timeZone);
                            if (message.geoLocation != null && Object.hasOwnProperty.call(message, "geoLocation"))
                                $root.google.type.LatLng.encode(message.geoLocation, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.contexts != null && message.contexts.length)
                                for (var i = 0; i < message.contexts.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.Context.encode(message.contexts[i], writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            if (message.resetContexts != null && Object.hasOwnProperty.call(message, "resetContexts"))
                                writer.uint32(/* id 4, wireType 0 =*/32).bool(message.resetContexts);
                            if (message.sessionEntityTypes != null && message.sessionEntityTypes.length)
                                for (var i = 0; i < message.sessionEntityTypes.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.SessionEntityType.encode(message.sessionEntityTypes[i], writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                            if (message.payload != null && Object.hasOwnProperty.call(message, "payload"))
                                $root.google.protobuf.Struct.encode(message.payload, writer.uint32(/* id 6, wireType 2 =*/50).fork()).ldelim();
                            if (message.sentimentAnalysisRequestConfig != null && Object.hasOwnProperty.call(message, "sentimentAnalysisRequestConfig"))
                                $root.google.cloud.dialogflow.v2beta1.SentimentAnalysisRequestConfig.encode(message.sentimentAnalysisRequestConfig, writer.uint32(/* id 10, wireType 2 =*/82).fork()).ldelim();
                            if (message.knowledgeBaseNames != null && message.knowledgeBaseNames.length)
                                for (var i = 0; i < message.knowledgeBaseNames.length; ++i)
                                    writer.uint32(/* id 12, wireType 2 =*/98).string(message.knowledgeBaseNames[i]);
                            if (message.subAgents != null && message.subAgents.length)
                                for (var i = 0; i < message.subAgents.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.SubAgent.encode(message.subAgents[i], writer.uint32(/* id 13, wireType 2 =*/106).fork()).ldelim();
                            if (message.webhookHeaders != null && Object.hasOwnProperty.call(message, "webhookHeaders"))
                                for (var keys = Object.keys(message.webhookHeaders), i = 0; i < keys.length; ++i)
                                    writer.uint32(/* id 14, wireType 2 =*/114).fork().uint32(/* id 1, wireType 2 =*/10).string(keys[i]).uint32(/* id 2, wireType 2 =*/18).string(message.webhookHeaders[keys[i]]).ldelim();
                            if (message.platform != null && Object.hasOwnProperty.call(message, "platform"))
                                writer.uint32(/* id 18, wireType 2 =*/146).string(message.platform);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified QueryParameters message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.QueryParameters.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.QueryParameters
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IQueryParameters} message QueryParameters message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        QueryParameters.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a QueryParameters message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.QueryParameters
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.QueryParameters} QueryParameters
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        QueryParameters.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.QueryParameters(), key, value;
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.timeZone = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.geoLocation = $root.google.type.LatLng.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 3: {
                                        if (!(message.contexts && message.contexts.length))
                                            message.contexts = [];
                                        message.contexts.push($root.google.cloud.dialogflow.v2beta1.Context.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 4: {
                                        message.resetContexts = reader.bool();
                                        break;
                                    }
                                case 5: {
                                        if (!(message.sessionEntityTypes && message.sessionEntityTypes.length))
                                            message.sessionEntityTypes = [];
                                        message.sessionEntityTypes.push($root.google.cloud.dialogflow.v2beta1.SessionEntityType.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 6: {
                                        message.payload = $root.google.protobuf.Struct.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 12: {
                                        if (!(message.knowledgeBaseNames && message.knowledgeBaseNames.length))
                                            message.knowledgeBaseNames = [];
                                        message.knowledgeBaseNames.push(reader.string());
                                        break;
                                    }
                                case 10: {
                                        message.sentimentAnalysisRequestConfig = $root.google.cloud.dialogflow.v2beta1.SentimentAnalysisRequestConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 13: {
                                        if (!(message.subAgents && message.subAgents.length))
                                            message.subAgents = [];
                                        message.subAgents.push($root.google.cloud.dialogflow.v2beta1.SubAgent.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 14: {
                                        if (message.webhookHeaders === $util.emptyObject)
                                            message.webhookHeaders = {};
                                        var end2 = reader.uint32() + reader.pos;
                                        key = "";
                                        value = "";
                                        while (reader.pos < end2) {
                                            var tag2 = reader.uint32();
                                            switch (tag2 >>> 3) {
                                            case 1:
                                                key = reader.string();
                                                break;
                                            case 2:
                                                value = reader.string();
                                                break;
                                            default:
                                                reader.skipType(tag2 & 7);
                                                break;
                                            }
                                        }
                                        message.webhookHeaders[key] = value;
                                        break;
                                    }
                                case 18: {
                                        message.platform = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a QueryParameters message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.QueryParameters
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.QueryParameters} QueryParameters
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        QueryParameters.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a QueryParameters message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.QueryParameters
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        QueryParameters.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.timeZone != null && message.hasOwnProperty("timeZone"))
                                if (!$util.isString(message.timeZone))
                                    return "timeZone: string expected";
                            if (message.geoLocation != null && message.hasOwnProperty("geoLocation")) {
                                var error = $root.google.type.LatLng.verify(message.geoLocation);
                                if (error)
                                    return "geoLocation." + error;
                            }
                            if (message.contexts != null && message.hasOwnProperty("contexts")) {
                                if (!Array.isArray(message.contexts))
                                    return "contexts: array expected";
                                for (var i = 0; i < message.contexts.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.Context.verify(message.contexts[i]);
                                    if (error)
                                        return "contexts." + error;
                                }
                            }
                            if (message.resetContexts != null && message.hasOwnProperty("resetContexts"))
                                if (typeof message.resetContexts !== "boolean")
                                    return "resetContexts: boolean expected";
                            if (message.sessionEntityTypes != null && message.hasOwnProperty("sessionEntityTypes")) {
                                if (!Array.isArray(message.sessionEntityTypes))
                                    return "sessionEntityTypes: array expected";
                                for (var i = 0; i < message.sessionEntityTypes.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.SessionEntityType.verify(message.sessionEntityTypes[i]);
                                    if (error)
                                        return "sessionEntityTypes." + error;
                                }
                            }
                            if (message.payload != null && message.hasOwnProperty("payload")) {
                                var error = $root.google.protobuf.Struct.verify(message.payload);
                                if (error)
                                    return "payload." + error;
                            }
                            if (message.knowledgeBaseNames != null && message.hasOwnProperty("knowledgeBaseNames")) {
                                if (!Array.isArray(message.knowledgeBaseNames))
                                    return "knowledgeBaseNames: array expected";
                                for (var i = 0; i < message.knowledgeBaseNames.length; ++i)
                                    if (!$util.isString(message.knowledgeBaseNames[i]))
                                        return "knowledgeBaseNames: string[] expected";
                            }
                            if (message.sentimentAnalysisRequestConfig != null && message.hasOwnProperty("sentimentAnalysisRequestConfig")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.SentimentAnalysisRequestConfig.verify(message.sentimentAnalysisRequestConfig);
                                if (error)
                                    return "sentimentAnalysisRequestConfig." + error;
                            }
                            if (message.subAgents != null && message.hasOwnProperty("subAgents")) {
                                if (!Array.isArray(message.subAgents))
                                    return "subAgents: array expected";
                                for (var i = 0; i < message.subAgents.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.SubAgent.verify(message.subAgents[i]);
                                    if (error)
                                        return "subAgents." + error;
                                }
                            }
                            if (message.webhookHeaders != null && message.hasOwnProperty("webhookHeaders")) {
                                if (!$util.isObject(message.webhookHeaders))
                                    return "webhookHeaders: object expected";
                                var key = Object.keys(message.webhookHeaders);
                                for (var i = 0; i < key.length; ++i)
                                    if (!$util.isString(message.webhookHeaders[key[i]]))
                                        return "webhookHeaders: string{k:string} expected";
                            }
                            if (message.platform != null && message.hasOwnProperty("platform"))
                                if (!$util.isString(message.platform))
                                    return "platform: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a QueryParameters message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.QueryParameters
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.QueryParameters} QueryParameters
                         */
                        QueryParameters.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.QueryParameters)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.QueryParameters();
                            if (object.timeZone != null)
                                message.timeZone = String(object.timeZone);
                            if (object.geoLocation != null) {
                                if (typeof object.geoLocation !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.QueryParameters.geoLocation: object expected");
                                message.geoLocation = $root.google.type.LatLng.fromObject(object.geoLocation);
                            }
                            if (object.contexts) {
                                if (!Array.isArray(object.contexts))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.QueryParameters.contexts: array expected");
                                message.contexts = [];
                                for (var i = 0; i < object.contexts.length; ++i) {
                                    if (typeof object.contexts[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.QueryParameters.contexts: object expected");
                                    message.contexts[i] = $root.google.cloud.dialogflow.v2beta1.Context.fromObject(object.contexts[i]);
                                }
                            }
                            if (object.resetContexts != null)
                                message.resetContexts = Boolean(object.resetContexts);
                            if (object.sessionEntityTypes) {
                                if (!Array.isArray(object.sessionEntityTypes))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.QueryParameters.sessionEntityTypes: array expected");
                                message.sessionEntityTypes = [];
                                for (var i = 0; i < object.sessionEntityTypes.length; ++i) {
                                    if (typeof object.sessionEntityTypes[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.QueryParameters.sessionEntityTypes: object expected");
                                    message.sessionEntityTypes[i] = $root.google.cloud.dialogflow.v2beta1.SessionEntityType.fromObject(object.sessionEntityTypes[i]);
                                }
                            }
                            if (object.payload != null) {
                                if (typeof object.payload !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.QueryParameters.payload: object expected");
                                message.payload = $root.google.protobuf.Struct.fromObject(object.payload);
                            }
                            if (object.knowledgeBaseNames) {
                                if (!Array.isArray(object.knowledgeBaseNames))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.QueryParameters.knowledgeBaseNames: array expected");
                                message.knowledgeBaseNames = [];
                                for (var i = 0; i < object.knowledgeBaseNames.length; ++i)
                                    message.knowledgeBaseNames[i] = String(object.knowledgeBaseNames[i]);
                            }
                            if (object.sentimentAnalysisRequestConfig != null) {
                                if (typeof object.sentimentAnalysisRequestConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.QueryParameters.sentimentAnalysisRequestConfig: object expected");
                                message.sentimentAnalysisRequestConfig = $root.google.cloud.dialogflow.v2beta1.SentimentAnalysisRequestConfig.fromObject(object.sentimentAnalysisRequestConfig);
                            }
                            if (object.subAgents) {
                                if (!Array.isArray(object.subAgents))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.QueryParameters.subAgents: array expected");
                                message.subAgents = [];
                                for (var i = 0; i < object.subAgents.length; ++i) {
                                    if (typeof object.subAgents[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.QueryParameters.subAgents: object expected");
                                    message.subAgents[i] = $root.google.cloud.dialogflow.v2beta1.SubAgent.fromObject(object.subAgents[i]);
                                }
                            }
                            if (object.webhookHeaders) {
                                if (typeof object.webhookHeaders !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.QueryParameters.webhookHeaders: object expected");
                                message.webhookHeaders = {};
                                for (var keys = Object.keys(object.webhookHeaders), i = 0; i < keys.length; ++i)
                                    message.webhookHeaders[keys[i]] = String(object.webhookHeaders[keys[i]]);
                            }
                            if (object.platform != null)
                                message.platform = String(object.platform);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a QueryParameters message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.QueryParameters
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.QueryParameters} message QueryParameters
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        QueryParameters.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults) {
                                object.contexts = [];
                                object.sessionEntityTypes = [];
                                object.knowledgeBaseNames = [];
                                object.subAgents = [];
                            }
                            if (options.objects || options.defaults)
                                object.webhookHeaders = {};
                            if (options.defaults) {
                                object.timeZone = "";
                                object.geoLocation = null;
                                object.resetContexts = false;
                                object.payload = null;
                                object.sentimentAnalysisRequestConfig = null;
                                object.platform = "";
                            }
                            if (message.timeZone != null && message.hasOwnProperty("timeZone"))
                                object.timeZone = message.timeZone;
                            if (message.geoLocation != null && message.hasOwnProperty("geoLocation"))
                                object.geoLocation = $root.google.type.LatLng.toObject(message.geoLocation, options);
                            if (message.contexts && message.contexts.length) {
                                object.contexts = [];
                                for (var j = 0; j < message.contexts.length; ++j)
                                    object.contexts[j] = $root.google.cloud.dialogflow.v2beta1.Context.toObject(message.contexts[j], options);
                            }
                            if (message.resetContexts != null && message.hasOwnProperty("resetContexts"))
                                object.resetContexts = message.resetContexts;
                            if (message.sessionEntityTypes && message.sessionEntityTypes.length) {
                                object.sessionEntityTypes = [];
                                for (var j = 0; j < message.sessionEntityTypes.length; ++j)
                                    object.sessionEntityTypes[j] = $root.google.cloud.dialogflow.v2beta1.SessionEntityType.toObject(message.sessionEntityTypes[j], options);
                            }
                            if (message.payload != null && message.hasOwnProperty("payload"))
                                object.payload = $root.google.protobuf.Struct.toObject(message.payload, options);
                            if (message.sentimentAnalysisRequestConfig != null && message.hasOwnProperty("sentimentAnalysisRequestConfig"))
                                object.sentimentAnalysisRequestConfig = $root.google.cloud.dialogflow.v2beta1.SentimentAnalysisRequestConfig.toObject(message.sentimentAnalysisRequestConfig, options);
                            if (message.knowledgeBaseNames && message.knowledgeBaseNames.length) {
                                object.knowledgeBaseNames = [];
                                for (var j = 0; j < message.knowledgeBaseNames.length; ++j)
                                    object.knowledgeBaseNames[j] = message.knowledgeBaseNames[j];
                            }
                            if (message.subAgents && message.subAgents.length) {
                                object.subAgents = [];
                                for (var j = 0; j < message.subAgents.length; ++j)
                                    object.subAgents[j] = $root.google.cloud.dialogflow.v2beta1.SubAgent.toObject(message.subAgents[j], options);
                            }
                            var keys2;
                            if (message.webhookHeaders && (keys2 = Object.keys(message.webhookHeaders)).length) {
                                object.webhookHeaders = {};
                                for (var j = 0; j < keys2.length; ++j)
                                    object.webhookHeaders[keys2[j]] = message.webhookHeaders[keys2[j]];
                            }
                            if (message.platform != null && message.hasOwnProperty("platform"))
                                object.platform = message.platform;
                            return object;
                        };
    
                        /**
                         * Converts this QueryParameters to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.QueryParameters
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        QueryParameters.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for QueryParameters
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.QueryParameters
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        QueryParameters.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.QueryParameters";
                        };
    
                        return QueryParameters;
                    })();
    
                    v2beta1.QueryInput = (function() {
    
                        /**
                         * Properties of a QueryInput.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IQueryInput
                         * @property {google.cloud.dialogflow.v2beta1.IInputAudioConfig|null} [audioConfig] QueryInput audioConfig
                         * @property {google.cloud.dialogflow.v2beta1.ITextInput|null} [text] QueryInput text
                         * @property {google.cloud.dialogflow.v2beta1.IEventInput|null} [event] QueryInput event
                         * @property {google.cloud.dialogflow.v2beta1.ITelephonyDtmfEvents|null} [dtmf] QueryInput dtmf
                         */
    
                        /**
                         * Constructs a new QueryInput.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a QueryInput.
                         * @implements IQueryInput
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IQueryInput=} [properties] Properties to set
                         */
                        function QueryInput(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * QueryInput audioConfig.
                         * @member {google.cloud.dialogflow.v2beta1.IInputAudioConfig|null|undefined} audioConfig
                         * @memberof google.cloud.dialogflow.v2beta1.QueryInput
                         * @instance
                         */
                        QueryInput.prototype.audioConfig = null;
    
                        /**
                         * QueryInput text.
                         * @member {google.cloud.dialogflow.v2beta1.ITextInput|null|undefined} text
                         * @memberof google.cloud.dialogflow.v2beta1.QueryInput
                         * @instance
                         */
                        QueryInput.prototype.text = null;
    
                        /**
                         * QueryInput event.
                         * @member {google.cloud.dialogflow.v2beta1.IEventInput|null|undefined} event
                         * @memberof google.cloud.dialogflow.v2beta1.QueryInput
                         * @instance
                         */
                        QueryInput.prototype.event = null;
    
                        /**
                         * QueryInput dtmf.
                         * @member {google.cloud.dialogflow.v2beta1.ITelephonyDtmfEvents|null|undefined} dtmf
                         * @memberof google.cloud.dialogflow.v2beta1.QueryInput
                         * @instance
                         */
                        QueryInput.prototype.dtmf = null;
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * QueryInput input.
                         * @member {"audioConfig"|"text"|"event"|"dtmf"|undefined} input
                         * @memberof google.cloud.dialogflow.v2beta1.QueryInput
                         * @instance
                         */
                        Object.defineProperty(QueryInput.prototype, "input", {
                            get: $util.oneOfGetter($oneOfFields = ["audioConfig", "text", "event", "dtmf"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new QueryInput instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.QueryInput
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IQueryInput=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.QueryInput} QueryInput instance
                         */
                        QueryInput.create = function create(properties) {
                            return new QueryInput(properties);
                        };
    
                        /**
                         * Encodes the specified QueryInput message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.QueryInput.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.QueryInput
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IQueryInput} message QueryInput message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        QueryInput.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.audioConfig != null && Object.hasOwnProperty.call(message, "audioConfig"))
                                $root.google.cloud.dialogflow.v2beta1.InputAudioConfig.encode(message.audioConfig, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.text != null && Object.hasOwnProperty.call(message, "text"))
                                $root.google.cloud.dialogflow.v2beta1.TextInput.encode(message.text, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.event != null && Object.hasOwnProperty.call(message, "event"))
                                $root.google.cloud.dialogflow.v2beta1.EventInput.encode(message.event, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            if (message.dtmf != null && Object.hasOwnProperty.call(message, "dtmf"))
                                $root.google.cloud.dialogflow.v2beta1.TelephonyDtmfEvents.encode(message.dtmf, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified QueryInput message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.QueryInput.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.QueryInput
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IQueryInput} message QueryInput message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        QueryInput.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a QueryInput message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.QueryInput
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.QueryInput} QueryInput
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        QueryInput.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.QueryInput();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.audioConfig = $root.google.cloud.dialogflow.v2beta1.InputAudioConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.text = $root.google.cloud.dialogflow.v2beta1.TextInput.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 3: {
                                        message.event = $root.google.cloud.dialogflow.v2beta1.EventInput.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 4: {
                                        message.dtmf = $root.google.cloud.dialogflow.v2beta1.TelephonyDtmfEvents.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a QueryInput message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.QueryInput
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.QueryInput} QueryInput
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        QueryInput.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a QueryInput message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.QueryInput
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        QueryInput.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.audioConfig != null && message.hasOwnProperty("audioConfig")) {
                                properties.input = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2beta1.InputAudioConfig.verify(message.audioConfig);
                                    if (error)
                                        return "audioConfig." + error;
                                }
                            }
                            if (message.text != null && message.hasOwnProperty("text")) {
                                if (properties.input === 1)
                                    return "input: multiple values";
                                properties.input = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2beta1.TextInput.verify(message.text);
                                    if (error)
                                        return "text." + error;
                                }
                            }
                            if (message.event != null && message.hasOwnProperty("event")) {
                                if (properties.input === 1)
                                    return "input: multiple values";
                                properties.input = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2beta1.EventInput.verify(message.event);
                                    if (error)
                                        return "event." + error;
                                }
                            }
                            if (message.dtmf != null && message.hasOwnProperty("dtmf")) {
                                if (properties.input === 1)
                                    return "input: multiple values";
                                properties.input = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2beta1.TelephonyDtmfEvents.verify(message.dtmf);
                                    if (error)
                                        return "dtmf." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates a QueryInput message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.QueryInput
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.QueryInput} QueryInput
                         */
                        QueryInput.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.QueryInput)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.QueryInput();
                            if (object.audioConfig != null) {
                                if (typeof object.audioConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.QueryInput.audioConfig: object expected");
                                message.audioConfig = $root.google.cloud.dialogflow.v2beta1.InputAudioConfig.fromObject(object.audioConfig);
                            }
                            if (object.text != null) {
                                if (typeof object.text !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.QueryInput.text: object expected");
                                message.text = $root.google.cloud.dialogflow.v2beta1.TextInput.fromObject(object.text);
                            }
                            if (object.event != null) {
                                if (typeof object.event !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.QueryInput.event: object expected");
                                message.event = $root.google.cloud.dialogflow.v2beta1.EventInput.fromObject(object.event);
                            }
                            if (object.dtmf != null) {
                                if (typeof object.dtmf !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.QueryInput.dtmf: object expected");
                                message.dtmf = $root.google.cloud.dialogflow.v2beta1.TelephonyDtmfEvents.fromObject(object.dtmf);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a QueryInput message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.QueryInput
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.QueryInput} message QueryInput
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        QueryInput.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (message.audioConfig != null && message.hasOwnProperty("audioConfig")) {
                                object.audioConfig = $root.google.cloud.dialogflow.v2beta1.InputAudioConfig.toObject(message.audioConfig, options);
                                if (options.oneofs)
                                    object.input = "audioConfig";
                            }
                            if (message.text != null && message.hasOwnProperty("text")) {
                                object.text = $root.google.cloud.dialogflow.v2beta1.TextInput.toObject(message.text, options);
                                if (options.oneofs)
                                    object.input = "text";
                            }
                            if (message.event != null && message.hasOwnProperty("event")) {
                                object.event = $root.google.cloud.dialogflow.v2beta1.EventInput.toObject(message.event, options);
                                if (options.oneofs)
                                    object.input = "event";
                            }
                            if (message.dtmf != null && message.hasOwnProperty("dtmf")) {
                                object.dtmf = $root.google.cloud.dialogflow.v2beta1.TelephonyDtmfEvents.toObject(message.dtmf, options);
                                if (options.oneofs)
                                    object.input = "dtmf";
                            }
                            return object;
                        };
    
                        /**
                         * Converts this QueryInput to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.QueryInput
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        QueryInput.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for QueryInput
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.QueryInput
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        QueryInput.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.QueryInput";
                        };
    
                        return QueryInput;
                    })();
    
                    v2beta1.QueryResult = (function() {
    
                        /**
                         * Properties of a QueryResult.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IQueryResult
                         * @property {string|null} [queryText] QueryResult queryText
                         * @property {string|null} [languageCode] QueryResult languageCode
                         * @property {number|null} [speechRecognitionConfidence] QueryResult speechRecognitionConfidence
                         * @property {string|null} [action] QueryResult action
                         * @property {google.protobuf.IStruct|null} [parameters] QueryResult parameters
                         * @property {boolean|null} [allRequiredParamsPresent] QueryResult allRequiredParamsPresent
                         * @property {boolean|null} [cancelsSlotFilling] QueryResult cancelsSlotFilling
                         * @property {string|null} [fulfillmentText] QueryResult fulfillmentText
                         * @property {Array.<google.cloud.dialogflow.v2beta1.Intent.IMessage>|null} [fulfillmentMessages] QueryResult fulfillmentMessages
                         * @property {string|null} [webhookSource] QueryResult webhookSource
                         * @property {google.protobuf.IStruct|null} [webhookPayload] QueryResult webhookPayload
                         * @property {Array.<google.cloud.dialogflow.v2beta1.IContext>|null} [outputContexts] QueryResult outputContexts
                         * @property {google.cloud.dialogflow.v2beta1.IIntent|null} [intent] QueryResult intent
                         * @property {number|null} [intentDetectionConfidence] QueryResult intentDetectionConfidence
                         * @property {google.protobuf.IStruct|null} [diagnosticInfo] QueryResult diagnosticInfo
                         * @property {google.cloud.dialogflow.v2beta1.ISentimentAnalysisResult|null} [sentimentAnalysisResult] QueryResult sentimentAnalysisResult
                         * @property {google.cloud.dialogflow.v2beta1.IKnowledgeAnswers|null} [knowledgeAnswers] QueryResult knowledgeAnswers
                         */
    
                        /**
                         * Constructs a new QueryResult.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a QueryResult.
                         * @implements IQueryResult
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IQueryResult=} [properties] Properties to set
                         */
                        function QueryResult(properties) {
                            this.fulfillmentMessages = [];
                            this.outputContexts = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * QueryResult queryText.
                         * @member {string} queryText
                         * @memberof google.cloud.dialogflow.v2beta1.QueryResult
                         * @instance
                         */
                        QueryResult.prototype.queryText = "";
    
                        /**
                         * QueryResult languageCode.
                         * @member {string} languageCode
                         * @memberof google.cloud.dialogflow.v2beta1.QueryResult
                         * @instance
                         */
                        QueryResult.prototype.languageCode = "";
    
                        /**
                         * QueryResult speechRecognitionConfidence.
                         * @member {number} speechRecognitionConfidence
                         * @memberof google.cloud.dialogflow.v2beta1.QueryResult
                         * @instance
                         */
                        QueryResult.prototype.speechRecognitionConfidence = 0;
    
                        /**
                         * QueryResult action.
                         * @member {string} action
                         * @memberof google.cloud.dialogflow.v2beta1.QueryResult
                         * @instance
                         */
                        QueryResult.prototype.action = "";
    
                        /**
                         * QueryResult parameters.
                         * @member {google.protobuf.IStruct|null|undefined} parameters
                         * @memberof google.cloud.dialogflow.v2beta1.QueryResult
                         * @instance
                         */
                        QueryResult.prototype.parameters = null;
    
                        /**
                         * QueryResult allRequiredParamsPresent.
                         * @member {boolean} allRequiredParamsPresent
                         * @memberof google.cloud.dialogflow.v2beta1.QueryResult
                         * @instance
                         */
                        QueryResult.prototype.allRequiredParamsPresent = false;
    
                        /**
                         * QueryResult cancelsSlotFilling.
                         * @member {boolean} cancelsSlotFilling
                         * @memberof google.cloud.dialogflow.v2beta1.QueryResult
                         * @instance
                         */
                        QueryResult.prototype.cancelsSlotFilling = false;
    
                        /**
                         * QueryResult fulfillmentText.
                         * @member {string} fulfillmentText
                         * @memberof google.cloud.dialogflow.v2beta1.QueryResult
                         * @instance
                         */
                        QueryResult.prototype.fulfillmentText = "";
    
                        /**
                         * QueryResult fulfillmentMessages.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.Intent.IMessage>} fulfillmentMessages
                         * @memberof google.cloud.dialogflow.v2beta1.QueryResult
                         * @instance
                         */
                        QueryResult.prototype.fulfillmentMessages = $util.emptyArray;
    
                        /**
                         * QueryResult webhookSource.
                         * @member {string} webhookSource
                         * @memberof google.cloud.dialogflow.v2beta1.QueryResult
                         * @instance
                         */
                        QueryResult.prototype.webhookSource = "";
    
                        /**
                         * QueryResult webhookPayload.
                         * @member {google.protobuf.IStruct|null|undefined} webhookPayload
                         * @memberof google.cloud.dialogflow.v2beta1.QueryResult
                         * @instance
                         */
                        QueryResult.prototype.webhookPayload = null;
    
                        /**
                         * QueryResult outputContexts.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.IContext>} outputContexts
                         * @memberof google.cloud.dialogflow.v2beta1.QueryResult
                         * @instance
                         */
                        QueryResult.prototype.outputContexts = $util.emptyArray;
    
                        /**
                         * QueryResult intent.
                         * @member {google.cloud.dialogflow.v2beta1.IIntent|null|undefined} intent
                         * @memberof google.cloud.dialogflow.v2beta1.QueryResult
                         * @instance
                         */
                        QueryResult.prototype.intent = null;
    
                        /**
                         * QueryResult intentDetectionConfidence.
                         * @member {number} intentDetectionConfidence
                         * @memberof google.cloud.dialogflow.v2beta1.QueryResult
                         * @instance
                         */
                        QueryResult.prototype.intentDetectionConfidence = 0;
    
                        /**
                         * QueryResult diagnosticInfo.
                         * @member {google.protobuf.IStruct|null|undefined} diagnosticInfo
                         * @memberof google.cloud.dialogflow.v2beta1.QueryResult
                         * @instance
                         */
                        QueryResult.prototype.diagnosticInfo = null;
    
                        /**
                         * QueryResult sentimentAnalysisResult.
                         * @member {google.cloud.dialogflow.v2beta1.ISentimentAnalysisResult|null|undefined} sentimentAnalysisResult
                         * @memberof google.cloud.dialogflow.v2beta1.QueryResult
                         * @instance
                         */
                        QueryResult.prototype.sentimentAnalysisResult = null;
    
                        /**
                         * QueryResult knowledgeAnswers.
                         * @member {google.cloud.dialogflow.v2beta1.IKnowledgeAnswers|null|undefined} knowledgeAnswers
                         * @memberof google.cloud.dialogflow.v2beta1.QueryResult
                         * @instance
                         */
                        QueryResult.prototype.knowledgeAnswers = null;
    
                        /**
                         * Creates a new QueryResult instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.QueryResult
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IQueryResult=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.QueryResult} QueryResult instance
                         */
                        QueryResult.create = function create(properties) {
                            return new QueryResult(properties);
                        };
    
                        /**
                         * Encodes the specified QueryResult message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.QueryResult.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.QueryResult
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IQueryResult} message QueryResult message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        QueryResult.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.queryText != null && Object.hasOwnProperty.call(message, "queryText"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.queryText);
                            if (message.speechRecognitionConfidence != null && Object.hasOwnProperty.call(message, "speechRecognitionConfidence"))
                                writer.uint32(/* id 2, wireType 5 =*/21).float(message.speechRecognitionConfidence);
                            if (message.action != null && Object.hasOwnProperty.call(message, "action"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.action);
                            if (message.parameters != null && Object.hasOwnProperty.call(message, "parameters"))
                                $root.google.protobuf.Struct.encode(message.parameters, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            if (message.allRequiredParamsPresent != null && Object.hasOwnProperty.call(message, "allRequiredParamsPresent"))
                                writer.uint32(/* id 5, wireType 0 =*/40).bool(message.allRequiredParamsPresent);
                            if (message.fulfillmentText != null && Object.hasOwnProperty.call(message, "fulfillmentText"))
                                writer.uint32(/* id 6, wireType 2 =*/50).string(message.fulfillmentText);
                            if (message.fulfillmentMessages != null && message.fulfillmentMessages.length)
                                for (var i = 0; i < message.fulfillmentMessages.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.Intent.Message.encode(message.fulfillmentMessages[i], writer.uint32(/* id 7, wireType 2 =*/58).fork()).ldelim();
                            if (message.webhookSource != null && Object.hasOwnProperty.call(message, "webhookSource"))
                                writer.uint32(/* id 8, wireType 2 =*/66).string(message.webhookSource);
                            if (message.webhookPayload != null && Object.hasOwnProperty.call(message, "webhookPayload"))
                                $root.google.protobuf.Struct.encode(message.webhookPayload, writer.uint32(/* id 9, wireType 2 =*/74).fork()).ldelim();
                            if (message.outputContexts != null && message.outputContexts.length)
                                for (var i = 0; i < message.outputContexts.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.Context.encode(message.outputContexts[i], writer.uint32(/* id 10, wireType 2 =*/82).fork()).ldelim();
                            if (message.intent != null && Object.hasOwnProperty.call(message, "intent"))
                                $root.google.cloud.dialogflow.v2beta1.Intent.encode(message.intent, writer.uint32(/* id 11, wireType 2 =*/90).fork()).ldelim();
                            if (message.intentDetectionConfidence != null && Object.hasOwnProperty.call(message, "intentDetectionConfidence"))
                                writer.uint32(/* id 12, wireType 5 =*/101).float(message.intentDetectionConfidence);
                            if (message.diagnosticInfo != null && Object.hasOwnProperty.call(message, "diagnosticInfo"))
                                $root.google.protobuf.Struct.encode(message.diagnosticInfo, writer.uint32(/* id 14, wireType 2 =*/114).fork()).ldelim();
                            if (message.languageCode != null && Object.hasOwnProperty.call(message, "languageCode"))
                                writer.uint32(/* id 15, wireType 2 =*/122).string(message.languageCode);
                            if (message.sentimentAnalysisResult != null && Object.hasOwnProperty.call(message, "sentimentAnalysisResult"))
                                $root.google.cloud.dialogflow.v2beta1.SentimentAnalysisResult.encode(message.sentimentAnalysisResult, writer.uint32(/* id 17, wireType 2 =*/138).fork()).ldelim();
                            if (message.knowledgeAnswers != null && Object.hasOwnProperty.call(message, "knowledgeAnswers"))
                                $root.google.cloud.dialogflow.v2beta1.KnowledgeAnswers.encode(message.knowledgeAnswers, writer.uint32(/* id 18, wireType 2 =*/146).fork()).ldelim();
                            if (message.cancelsSlotFilling != null && Object.hasOwnProperty.call(message, "cancelsSlotFilling"))
                                writer.uint32(/* id 21, wireType 0 =*/168).bool(message.cancelsSlotFilling);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified QueryResult message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.QueryResult.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.QueryResult
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IQueryResult} message QueryResult message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        QueryResult.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a QueryResult message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.QueryResult
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.QueryResult} QueryResult
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        QueryResult.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.QueryResult();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.queryText = reader.string();
                                        break;
                                    }
                                case 15: {
                                        message.languageCode = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.speechRecognitionConfidence = reader.float();
                                        break;
                                    }
                                case 3: {
                                        message.action = reader.string();
                                        break;
                                    }
                                case 4: {
                                        message.parameters = $root.google.protobuf.Struct.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 5: {
                                        message.allRequiredParamsPresent = reader.bool();
                                        break;
                                    }
                                case 21: {
                                        message.cancelsSlotFilling = reader.bool();
                                        break;
                                    }
                                case 6: {
                                        message.fulfillmentText = reader.string();
                                        break;
                                    }
                                case 7: {
                                        if (!(message.fulfillmentMessages && message.fulfillmentMessages.length))
                                            message.fulfillmentMessages = [];
                                        message.fulfillmentMessages.push($root.google.cloud.dialogflow.v2beta1.Intent.Message.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 8: {
                                        message.webhookSource = reader.string();
                                        break;
                                    }
                                case 9: {
                                        message.webhookPayload = $root.google.protobuf.Struct.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 10: {
                                        if (!(message.outputContexts && message.outputContexts.length))
                                            message.outputContexts = [];
                                        message.outputContexts.push($root.google.cloud.dialogflow.v2beta1.Context.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 11: {
                                        message.intent = $root.google.cloud.dialogflow.v2beta1.Intent.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 12: {
                                        message.intentDetectionConfidence = reader.float();
                                        break;
                                    }
                                case 14: {
                                        message.diagnosticInfo = $root.google.protobuf.Struct.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 17: {
                                        message.sentimentAnalysisResult = $root.google.cloud.dialogflow.v2beta1.SentimentAnalysisResult.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 18: {
                                        message.knowledgeAnswers = $root.google.cloud.dialogflow.v2beta1.KnowledgeAnswers.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a QueryResult message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.QueryResult
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.QueryResult} QueryResult
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        QueryResult.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a QueryResult message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.QueryResult
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        QueryResult.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.queryText != null && message.hasOwnProperty("queryText"))
                                if (!$util.isString(message.queryText))
                                    return "queryText: string expected";
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                if (!$util.isString(message.languageCode))
                                    return "languageCode: string expected";
                            if (message.speechRecognitionConfidence != null && message.hasOwnProperty("speechRecognitionConfidence"))
                                if (typeof message.speechRecognitionConfidence !== "number")
                                    return "speechRecognitionConfidence: number expected";
                            if (message.action != null && message.hasOwnProperty("action"))
                                if (!$util.isString(message.action))
                                    return "action: string expected";
                            if (message.parameters != null && message.hasOwnProperty("parameters")) {
                                var error = $root.google.protobuf.Struct.verify(message.parameters);
                                if (error)
                                    return "parameters." + error;
                            }
                            if (message.allRequiredParamsPresent != null && message.hasOwnProperty("allRequiredParamsPresent"))
                                if (typeof message.allRequiredParamsPresent !== "boolean")
                                    return "allRequiredParamsPresent: boolean expected";
                            if (message.cancelsSlotFilling != null && message.hasOwnProperty("cancelsSlotFilling"))
                                if (typeof message.cancelsSlotFilling !== "boolean")
                                    return "cancelsSlotFilling: boolean expected";
                            if (message.fulfillmentText != null && message.hasOwnProperty("fulfillmentText"))
                                if (!$util.isString(message.fulfillmentText))
                                    return "fulfillmentText: string expected";
                            if (message.fulfillmentMessages != null && message.hasOwnProperty("fulfillmentMessages")) {
                                if (!Array.isArray(message.fulfillmentMessages))
                                    return "fulfillmentMessages: array expected";
                                for (var i = 0; i < message.fulfillmentMessages.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.Intent.Message.verify(message.fulfillmentMessages[i]);
                                    if (error)
                                        return "fulfillmentMessages." + error;
                                }
                            }
                            if (message.webhookSource != null && message.hasOwnProperty("webhookSource"))
                                if (!$util.isString(message.webhookSource))
                                    return "webhookSource: string expected";
                            if (message.webhookPayload != null && message.hasOwnProperty("webhookPayload")) {
                                var error = $root.google.protobuf.Struct.verify(message.webhookPayload);
                                if (error)
                                    return "webhookPayload." + error;
                            }
                            if (message.outputContexts != null && message.hasOwnProperty("outputContexts")) {
                                if (!Array.isArray(message.outputContexts))
                                    return "outputContexts: array expected";
                                for (var i = 0; i < message.outputContexts.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.Context.verify(message.outputContexts[i]);
                                    if (error)
                                        return "outputContexts." + error;
                                }
                            }
                            if (message.intent != null && message.hasOwnProperty("intent")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.Intent.verify(message.intent);
                                if (error)
                                    return "intent." + error;
                            }
                            if (message.intentDetectionConfidence != null && message.hasOwnProperty("intentDetectionConfidence"))
                                if (typeof message.intentDetectionConfidence !== "number")
                                    return "intentDetectionConfidence: number expected";
                            if (message.diagnosticInfo != null && message.hasOwnProperty("diagnosticInfo")) {
                                var error = $root.google.protobuf.Struct.verify(message.diagnosticInfo);
                                if (error)
                                    return "diagnosticInfo." + error;
                            }
                            if (message.sentimentAnalysisResult != null && message.hasOwnProperty("sentimentAnalysisResult")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.SentimentAnalysisResult.verify(message.sentimentAnalysisResult);
                                if (error)
                                    return "sentimentAnalysisResult." + error;
                            }
                            if (message.knowledgeAnswers != null && message.hasOwnProperty("knowledgeAnswers")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.KnowledgeAnswers.verify(message.knowledgeAnswers);
                                if (error)
                                    return "knowledgeAnswers." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a QueryResult message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.QueryResult
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.QueryResult} QueryResult
                         */
                        QueryResult.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.QueryResult)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.QueryResult();
                            if (object.queryText != null)
                                message.queryText = String(object.queryText);
                            if (object.languageCode != null)
                                message.languageCode = String(object.languageCode);
                            if (object.speechRecognitionConfidence != null)
                                message.speechRecognitionConfidence = Number(object.speechRecognitionConfidence);
                            if (object.action != null)
                                message.action = String(object.action);
                            if (object.parameters != null) {
                                if (typeof object.parameters !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.QueryResult.parameters: object expected");
                                message.parameters = $root.google.protobuf.Struct.fromObject(object.parameters);
                            }
                            if (object.allRequiredParamsPresent != null)
                                message.allRequiredParamsPresent = Boolean(object.allRequiredParamsPresent);
                            if (object.cancelsSlotFilling != null)
                                message.cancelsSlotFilling = Boolean(object.cancelsSlotFilling);
                            if (object.fulfillmentText != null)
                                message.fulfillmentText = String(object.fulfillmentText);
                            if (object.fulfillmentMessages) {
                                if (!Array.isArray(object.fulfillmentMessages))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.QueryResult.fulfillmentMessages: array expected");
                                message.fulfillmentMessages = [];
                                for (var i = 0; i < object.fulfillmentMessages.length; ++i) {
                                    if (typeof object.fulfillmentMessages[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.QueryResult.fulfillmentMessages: object expected");
                                    message.fulfillmentMessages[i] = $root.google.cloud.dialogflow.v2beta1.Intent.Message.fromObject(object.fulfillmentMessages[i]);
                                }
                            }
                            if (object.webhookSource != null)
                                message.webhookSource = String(object.webhookSource);
                            if (object.webhookPayload != null) {
                                if (typeof object.webhookPayload !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.QueryResult.webhookPayload: object expected");
                                message.webhookPayload = $root.google.protobuf.Struct.fromObject(object.webhookPayload);
                            }
                            if (object.outputContexts) {
                                if (!Array.isArray(object.outputContexts))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.QueryResult.outputContexts: array expected");
                                message.outputContexts = [];
                                for (var i = 0; i < object.outputContexts.length; ++i) {
                                    if (typeof object.outputContexts[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.QueryResult.outputContexts: object expected");
                                    message.outputContexts[i] = $root.google.cloud.dialogflow.v2beta1.Context.fromObject(object.outputContexts[i]);
                                }
                            }
                            if (object.intent != null) {
                                if (typeof object.intent !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.QueryResult.intent: object expected");
                                message.intent = $root.google.cloud.dialogflow.v2beta1.Intent.fromObject(object.intent);
                            }
                            if (object.intentDetectionConfidence != null)
                                message.intentDetectionConfidence = Number(object.intentDetectionConfidence);
                            if (object.diagnosticInfo != null) {
                                if (typeof object.diagnosticInfo !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.QueryResult.diagnosticInfo: object expected");
                                message.diagnosticInfo = $root.google.protobuf.Struct.fromObject(object.diagnosticInfo);
                            }
                            if (object.sentimentAnalysisResult != null) {
                                if (typeof object.sentimentAnalysisResult !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.QueryResult.sentimentAnalysisResult: object expected");
                                message.sentimentAnalysisResult = $root.google.cloud.dialogflow.v2beta1.SentimentAnalysisResult.fromObject(object.sentimentAnalysisResult);
                            }
                            if (object.knowledgeAnswers != null) {
                                if (typeof object.knowledgeAnswers !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.QueryResult.knowledgeAnswers: object expected");
                                message.knowledgeAnswers = $root.google.cloud.dialogflow.v2beta1.KnowledgeAnswers.fromObject(object.knowledgeAnswers);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a QueryResult message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.QueryResult
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.QueryResult} message QueryResult
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        QueryResult.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults) {
                                object.fulfillmentMessages = [];
                                object.outputContexts = [];
                            }
                            if (options.defaults) {
                                object.queryText = "";
                                object.speechRecognitionConfidence = 0;
                                object.action = "";
                                object.parameters = null;
                                object.allRequiredParamsPresent = false;
                                object.fulfillmentText = "";
                                object.webhookSource = "";
                                object.webhookPayload = null;
                                object.intent = null;
                                object.intentDetectionConfidence = 0;
                                object.diagnosticInfo = null;
                                object.languageCode = "";
                                object.sentimentAnalysisResult = null;
                                object.knowledgeAnswers = null;
                                object.cancelsSlotFilling = false;
                            }
                            if (message.queryText != null && message.hasOwnProperty("queryText"))
                                object.queryText = message.queryText;
                            if (message.speechRecognitionConfidence != null && message.hasOwnProperty("speechRecognitionConfidence"))
                                object.speechRecognitionConfidence = options.json && !isFinite(message.speechRecognitionConfidence) ? String(message.speechRecognitionConfidence) : message.speechRecognitionConfidence;
                            if (message.action != null && message.hasOwnProperty("action"))
                                object.action = message.action;
                            if (message.parameters != null && message.hasOwnProperty("parameters"))
                                object.parameters = $root.google.protobuf.Struct.toObject(message.parameters, options);
                            if (message.allRequiredParamsPresent != null && message.hasOwnProperty("allRequiredParamsPresent"))
                                object.allRequiredParamsPresent = message.allRequiredParamsPresent;
                            if (message.fulfillmentText != null && message.hasOwnProperty("fulfillmentText"))
                                object.fulfillmentText = message.fulfillmentText;
                            if (message.fulfillmentMessages && message.fulfillmentMessages.length) {
                                object.fulfillmentMessages = [];
                                for (var j = 0; j < message.fulfillmentMessages.length; ++j)
                                    object.fulfillmentMessages[j] = $root.google.cloud.dialogflow.v2beta1.Intent.Message.toObject(message.fulfillmentMessages[j], options);
                            }
                            if (message.webhookSource != null && message.hasOwnProperty("webhookSource"))
                                object.webhookSource = message.webhookSource;
                            if (message.webhookPayload != null && message.hasOwnProperty("webhookPayload"))
                                object.webhookPayload = $root.google.protobuf.Struct.toObject(message.webhookPayload, options);
                            if (message.outputContexts && message.outputContexts.length) {
                                object.outputContexts = [];
                                for (var j = 0; j < message.outputContexts.length; ++j)
                                    object.outputContexts[j] = $root.google.cloud.dialogflow.v2beta1.Context.toObject(message.outputContexts[j], options);
                            }
                            if (message.intent != null && message.hasOwnProperty("intent"))
                                object.intent = $root.google.cloud.dialogflow.v2beta1.Intent.toObject(message.intent, options);
                            if (message.intentDetectionConfidence != null && message.hasOwnProperty("intentDetectionConfidence"))
                                object.intentDetectionConfidence = options.json && !isFinite(message.intentDetectionConfidence) ? String(message.intentDetectionConfidence) : message.intentDetectionConfidence;
                            if (message.diagnosticInfo != null && message.hasOwnProperty("diagnosticInfo"))
                                object.diagnosticInfo = $root.google.protobuf.Struct.toObject(message.diagnosticInfo, options);
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                object.languageCode = message.languageCode;
                            if (message.sentimentAnalysisResult != null && message.hasOwnProperty("sentimentAnalysisResult"))
                                object.sentimentAnalysisResult = $root.google.cloud.dialogflow.v2beta1.SentimentAnalysisResult.toObject(message.sentimentAnalysisResult, options);
                            if (message.knowledgeAnswers != null && message.hasOwnProperty("knowledgeAnswers"))
                                object.knowledgeAnswers = $root.google.cloud.dialogflow.v2beta1.KnowledgeAnswers.toObject(message.knowledgeAnswers, options);
                            if (message.cancelsSlotFilling != null && message.hasOwnProperty("cancelsSlotFilling"))
                                object.cancelsSlotFilling = message.cancelsSlotFilling;
                            return object;
                        };
    
                        /**
                         * Converts this QueryResult to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.QueryResult
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        QueryResult.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for QueryResult
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.QueryResult
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        QueryResult.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.QueryResult";
                        };
    
                        return QueryResult;
                    })();
    
                    v2beta1.KnowledgeAnswers = (function() {
    
                        /**
                         * Properties of a KnowledgeAnswers.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IKnowledgeAnswers
                         * @property {Array.<google.cloud.dialogflow.v2beta1.KnowledgeAnswers.IAnswer>|null} [answers] KnowledgeAnswers answers
                         */
    
                        /**
                         * Constructs a new KnowledgeAnswers.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a KnowledgeAnswers.
                         * @implements IKnowledgeAnswers
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IKnowledgeAnswers=} [properties] Properties to set
                         */
                        function KnowledgeAnswers(properties) {
                            this.answers = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * KnowledgeAnswers answers.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.KnowledgeAnswers.IAnswer>} answers
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAnswers
                         * @instance
                         */
                        KnowledgeAnswers.prototype.answers = $util.emptyArray;
    
                        /**
                         * Creates a new KnowledgeAnswers instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAnswers
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IKnowledgeAnswers=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.KnowledgeAnswers} KnowledgeAnswers instance
                         */
                        KnowledgeAnswers.create = function create(properties) {
                            return new KnowledgeAnswers(properties);
                        };
    
                        /**
                         * Encodes the specified KnowledgeAnswers message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.KnowledgeAnswers.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAnswers
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IKnowledgeAnswers} message KnowledgeAnswers message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        KnowledgeAnswers.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.answers != null && message.answers.length)
                                for (var i = 0; i < message.answers.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.KnowledgeAnswers.Answer.encode(message.answers[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified KnowledgeAnswers message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.KnowledgeAnswers.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAnswers
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IKnowledgeAnswers} message KnowledgeAnswers message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        KnowledgeAnswers.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a KnowledgeAnswers message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAnswers
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.KnowledgeAnswers} KnowledgeAnswers
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        KnowledgeAnswers.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.KnowledgeAnswers();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.answers && message.answers.length))
                                            message.answers = [];
                                        message.answers.push($root.google.cloud.dialogflow.v2beta1.KnowledgeAnswers.Answer.decode(reader, reader.uint32()));
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a KnowledgeAnswers message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAnswers
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.KnowledgeAnswers} KnowledgeAnswers
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        KnowledgeAnswers.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a KnowledgeAnswers message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAnswers
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        KnowledgeAnswers.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.answers != null && message.hasOwnProperty("answers")) {
                                if (!Array.isArray(message.answers))
                                    return "answers: array expected";
                                for (var i = 0; i < message.answers.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.KnowledgeAnswers.Answer.verify(message.answers[i]);
                                    if (error)
                                        return "answers." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates a KnowledgeAnswers message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAnswers
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.KnowledgeAnswers} KnowledgeAnswers
                         */
                        KnowledgeAnswers.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.KnowledgeAnswers)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.KnowledgeAnswers();
                            if (object.answers) {
                                if (!Array.isArray(object.answers))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.KnowledgeAnswers.answers: array expected");
                                message.answers = [];
                                for (var i = 0; i < object.answers.length; ++i) {
                                    if (typeof object.answers[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.KnowledgeAnswers.answers: object expected");
                                    message.answers[i] = $root.google.cloud.dialogflow.v2beta1.KnowledgeAnswers.Answer.fromObject(object.answers[i]);
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a KnowledgeAnswers message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAnswers
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.KnowledgeAnswers} message KnowledgeAnswers
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        KnowledgeAnswers.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.answers = [];
                            if (message.answers && message.answers.length) {
                                object.answers = [];
                                for (var j = 0; j < message.answers.length; ++j)
                                    object.answers[j] = $root.google.cloud.dialogflow.v2beta1.KnowledgeAnswers.Answer.toObject(message.answers[j], options);
                            }
                            return object;
                        };
    
                        /**
                         * Converts this KnowledgeAnswers to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAnswers
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        KnowledgeAnswers.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for KnowledgeAnswers
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAnswers
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        KnowledgeAnswers.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.KnowledgeAnswers";
                        };
    
                        KnowledgeAnswers.Answer = (function() {
    
                            /**
                             * Properties of an Answer.
                             * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAnswers
                             * @interface IAnswer
                             * @property {string|null} [source] Answer source
                             * @property {string|null} [faqQuestion] Answer faqQuestion
                             * @property {string|null} [answer] Answer answer
                             * @property {google.cloud.dialogflow.v2beta1.KnowledgeAnswers.Answer.MatchConfidenceLevel|null} [matchConfidenceLevel] Answer matchConfidenceLevel
                             * @property {number|null} [matchConfidence] Answer matchConfidence
                             */
    
                            /**
                             * Constructs a new Answer.
                             * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAnswers
                             * @classdesc Represents an Answer.
                             * @implements IAnswer
                             * @constructor
                             * @param {google.cloud.dialogflow.v2beta1.KnowledgeAnswers.IAnswer=} [properties] Properties to set
                             */
                            function Answer(properties) {
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * Answer source.
                             * @member {string} source
                             * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAnswers.Answer
                             * @instance
                             */
                            Answer.prototype.source = "";
    
                            /**
                             * Answer faqQuestion.
                             * @member {string} faqQuestion
                             * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAnswers.Answer
                             * @instance
                             */
                            Answer.prototype.faqQuestion = "";
    
                            /**
                             * Answer answer.
                             * @member {string} answer
                             * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAnswers.Answer
                             * @instance
                             */
                            Answer.prototype.answer = "";
    
                            /**
                             * Answer matchConfidenceLevel.
                             * @member {google.cloud.dialogflow.v2beta1.KnowledgeAnswers.Answer.MatchConfidenceLevel} matchConfidenceLevel
                             * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAnswers.Answer
                             * @instance
                             */
                            Answer.prototype.matchConfidenceLevel = 0;
    
                            /**
                             * Answer matchConfidence.
                             * @member {number} matchConfidence
                             * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAnswers.Answer
                             * @instance
                             */
                            Answer.prototype.matchConfidence = 0;
    
                            /**
                             * Creates a new Answer instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAnswers.Answer
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.KnowledgeAnswers.IAnswer=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2beta1.KnowledgeAnswers.Answer} Answer instance
                             */
                            Answer.create = function create(properties) {
                                return new Answer(properties);
                            };
    
                            /**
                             * Encodes the specified Answer message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.KnowledgeAnswers.Answer.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAnswers.Answer
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.KnowledgeAnswers.IAnswer} message Answer message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            Answer.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.source != null && Object.hasOwnProperty.call(message, "source"))
                                    writer.uint32(/* id 1, wireType 2 =*/10).string(message.source);
                                if (message.faqQuestion != null && Object.hasOwnProperty.call(message, "faqQuestion"))
                                    writer.uint32(/* id 2, wireType 2 =*/18).string(message.faqQuestion);
                                if (message.answer != null && Object.hasOwnProperty.call(message, "answer"))
                                    writer.uint32(/* id 3, wireType 2 =*/26).string(message.answer);
                                if (message.matchConfidenceLevel != null && Object.hasOwnProperty.call(message, "matchConfidenceLevel"))
                                    writer.uint32(/* id 4, wireType 0 =*/32).int32(message.matchConfidenceLevel);
                                if (message.matchConfidence != null && Object.hasOwnProperty.call(message, "matchConfidence"))
                                    writer.uint32(/* id 5, wireType 5 =*/45).float(message.matchConfidence);
                                return writer;
                            };
    
                            /**
                             * Encodes the specified Answer message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.KnowledgeAnswers.Answer.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAnswers.Answer
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.KnowledgeAnswers.IAnswer} message Answer message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            Answer.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes an Answer message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAnswers.Answer
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2beta1.KnowledgeAnswers.Answer} Answer
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            Answer.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.KnowledgeAnswers.Answer();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.source = reader.string();
                                            break;
                                        }
                                    case 2: {
                                            message.faqQuestion = reader.string();
                                            break;
                                        }
                                    case 3: {
                                            message.answer = reader.string();
                                            break;
                                        }
                                    case 4: {
                                            message.matchConfidenceLevel = reader.int32();
                                            break;
                                        }
                                    case 5: {
                                            message.matchConfidence = reader.float();
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes an Answer message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAnswers.Answer
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2beta1.KnowledgeAnswers.Answer} Answer
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            Answer.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies an Answer message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAnswers.Answer
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            Answer.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.source != null && message.hasOwnProperty("source"))
                                    if (!$util.isString(message.source))
                                        return "source: string expected";
                                if (message.faqQuestion != null && message.hasOwnProperty("faqQuestion"))
                                    if (!$util.isString(message.faqQuestion))
                                        return "faqQuestion: string expected";
                                if (message.answer != null && message.hasOwnProperty("answer"))
                                    if (!$util.isString(message.answer))
                                        return "answer: string expected";
                                if (message.matchConfidenceLevel != null && message.hasOwnProperty("matchConfidenceLevel"))
                                    switch (message.matchConfidenceLevel) {
                                    default:
                                        return "matchConfidenceLevel: enum value expected";
                                    case 0:
                                    case 1:
                                    case 2:
                                    case 3:
                                        break;
                                    }
                                if (message.matchConfidence != null && message.hasOwnProperty("matchConfidence"))
                                    if (typeof message.matchConfidence !== "number")
                                        return "matchConfidence: number expected";
                                return null;
                            };
    
                            /**
                             * Creates an Answer message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAnswers.Answer
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2beta1.KnowledgeAnswers.Answer} Answer
                             */
                            Answer.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2beta1.KnowledgeAnswers.Answer)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2beta1.KnowledgeAnswers.Answer();
                                if (object.source != null)
                                    message.source = String(object.source);
                                if (object.faqQuestion != null)
                                    message.faqQuestion = String(object.faqQuestion);
                                if (object.answer != null)
                                    message.answer = String(object.answer);
                                switch (object.matchConfidenceLevel) {
                                default:
                                    if (typeof object.matchConfidenceLevel === "number") {
                                        message.matchConfidenceLevel = object.matchConfidenceLevel;
                                        break;
                                    }
                                    break;
                                case "MATCH_CONFIDENCE_LEVEL_UNSPECIFIED":
                                case 0:
                                    message.matchConfidenceLevel = 0;
                                    break;
                                case "LOW":
                                case 1:
                                    message.matchConfidenceLevel = 1;
                                    break;
                                case "MEDIUM":
                                case 2:
                                    message.matchConfidenceLevel = 2;
                                    break;
                                case "HIGH":
                                case 3:
                                    message.matchConfidenceLevel = 3;
                                    break;
                                }
                                if (object.matchConfidence != null)
                                    message.matchConfidence = Number(object.matchConfidence);
                                return message;
                            };
    
                            /**
                             * Creates a plain object from an Answer message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAnswers.Answer
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.KnowledgeAnswers.Answer} message Answer
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            Answer.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.defaults) {
                                    object.source = "";
                                    object.faqQuestion = "";
                                    object.answer = "";
                                    object.matchConfidenceLevel = options.enums === String ? "MATCH_CONFIDENCE_LEVEL_UNSPECIFIED" : 0;
                                    object.matchConfidence = 0;
                                }
                                if (message.source != null && message.hasOwnProperty("source"))
                                    object.source = message.source;
                                if (message.faqQuestion != null && message.hasOwnProperty("faqQuestion"))
                                    object.faqQuestion = message.faqQuestion;
                                if (message.answer != null && message.hasOwnProperty("answer"))
                                    object.answer = message.answer;
                                if (message.matchConfidenceLevel != null && message.hasOwnProperty("matchConfidenceLevel"))
                                    object.matchConfidenceLevel = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.KnowledgeAnswers.Answer.MatchConfidenceLevel[message.matchConfidenceLevel] === undefined ? message.matchConfidenceLevel : $root.google.cloud.dialogflow.v2beta1.KnowledgeAnswers.Answer.MatchConfidenceLevel[message.matchConfidenceLevel] : message.matchConfidenceLevel;
                                if (message.matchConfidence != null && message.hasOwnProperty("matchConfidence"))
                                    object.matchConfidence = options.json && !isFinite(message.matchConfidence) ? String(message.matchConfidence) : message.matchConfidence;
                                return object;
                            };
    
                            /**
                             * Converts this Answer to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAnswers.Answer
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            Answer.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for Answer
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2beta1.KnowledgeAnswers.Answer
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            Answer.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.KnowledgeAnswers.Answer";
                            };
    
                            /**
                             * MatchConfidenceLevel enum.
                             * @name google.cloud.dialogflow.v2beta1.KnowledgeAnswers.Answer.MatchConfidenceLevel
                             * @enum {number}
                             * @property {number} MATCH_CONFIDENCE_LEVEL_UNSPECIFIED=0 MATCH_CONFIDENCE_LEVEL_UNSPECIFIED value
                             * @property {number} LOW=1 LOW value
                             * @property {number} MEDIUM=2 MEDIUM value
                             * @property {number} HIGH=3 HIGH value
                             */
                            Answer.MatchConfidenceLevel = (function() {
                                var valuesById = {}, values = Object.create(valuesById);
                                values[valuesById[0] = "MATCH_CONFIDENCE_LEVEL_UNSPECIFIED"] = 0;
                                values[valuesById[1] = "LOW"] = 1;
                                values[valuesById[2] = "MEDIUM"] = 2;
                                values[valuesById[3] = "HIGH"] = 3;
                                return values;
                            })();
    
                            return Answer;
                        })();
    
                        return KnowledgeAnswers;
                    })();
    
                    v2beta1.StreamingDetectIntentRequest = (function() {
    
                        /**
                         * Properties of a StreamingDetectIntentRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IStreamingDetectIntentRequest
                         * @property {string|null} [session] StreamingDetectIntentRequest session
                         * @property {google.cloud.dialogflow.v2beta1.IQueryParameters|null} [queryParams] StreamingDetectIntentRequest queryParams
                         * @property {google.cloud.dialogflow.v2beta1.IQueryInput|null} [queryInput] StreamingDetectIntentRequest queryInput
                         * @property {boolean|null} [singleUtterance] StreamingDetectIntentRequest singleUtterance
                         * @property {google.cloud.dialogflow.v2beta1.IOutputAudioConfig|null} [outputAudioConfig] StreamingDetectIntentRequest outputAudioConfig
                         * @property {google.protobuf.IFieldMask|null} [outputAudioConfigMask] StreamingDetectIntentRequest outputAudioConfigMask
                         * @property {Uint8Array|null} [inputAudio] StreamingDetectIntentRequest inputAudio
                         * @property {boolean|null} [enableDebuggingInfo] StreamingDetectIntentRequest enableDebuggingInfo
                         */
    
                        /**
                         * Constructs a new StreamingDetectIntentRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a StreamingDetectIntentRequest.
                         * @implements IStreamingDetectIntentRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IStreamingDetectIntentRequest=} [properties] Properties to set
                         */
                        function StreamingDetectIntentRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * StreamingDetectIntentRequest session.
                         * @member {string} session
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingDetectIntentRequest
                         * @instance
                         */
                        StreamingDetectIntentRequest.prototype.session = "";
    
                        /**
                         * StreamingDetectIntentRequest queryParams.
                         * @member {google.cloud.dialogflow.v2beta1.IQueryParameters|null|undefined} queryParams
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingDetectIntentRequest
                         * @instance
                         */
                        StreamingDetectIntentRequest.prototype.queryParams = null;
    
                        /**
                         * StreamingDetectIntentRequest queryInput.
                         * @member {google.cloud.dialogflow.v2beta1.IQueryInput|null|undefined} queryInput
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingDetectIntentRequest
                         * @instance
                         */
                        StreamingDetectIntentRequest.prototype.queryInput = null;
    
                        /**
                         * StreamingDetectIntentRequest singleUtterance.
                         * @member {boolean} singleUtterance
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingDetectIntentRequest
                         * @instance
                         */
                        StreamingDetectIntentRequest.prototype.singleUtterance = false;
    
                        /**
                         * StreamingDetectIntentRequest outputAudioConfig.
                         * @member {google.cloud.dialogflow.v2beta1.IOutputAudioConfig|null|undefined} outputAudioConfig
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingDetectIntentRequest
                         * @instance
                         */
                        StreamingDetectIntentRequest.prototype.outputAudioConfig = null;
    
                        /**
                         * StreamingDetectIntentRequest outputAudioConfigMask.
                         * @member {google.protobuf.IFieldMask|null|undefined} outputAudioConfigMask
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingDetectIntentRequest
                         * @instance
                         */
                        StreamingDetectIntentRequest.prototype.outputAudioConfigMask = null;
    
                        /**
                         * StreamingDetectIntentRequest inputAudio.
                         * @member {Uint8Array} inputAudio
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingDetectIntentRequest
                         * @instance
                         */
                        StreamingDetectIntentRequest.prototype.inputAudio = $util.newBuffer([]);
    
                        /**
                         * StreamingDetectIntentRequest enableDebuggingInfo.
                         * @member {boolean} enableDebuggingInfo
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingDetectIntentRequest
                         * @instance
                         */
                        StreamingDetectIntentRequest.prototype.enableDebuggingInfo = false;
    
                        /**
                         * Creates a new StreamingDetectIntentRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingDetectIntentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IStreamingDetectIntentRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.StreamingDetectIntentRequest} StreamingDetectIntentRequest instance
                         */
                        StreamingDetectIntentRequest.create = function create(properties) {
                            return new StreamingDetectIntentRequest(properties);
                        };
    
                        /**
                         * Encodes the specified StreamingDetectIntentRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.StreamingDetectIntentRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingDetectIntentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IStreamingDetectIntentRequest} message StreamingDetectIntentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        StreamingDetectIntentRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.session != null && Object.hasOwnProperty.call(message, "session"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.session);
                            if (message.queryParams != null && Object.hasOwnProperty.call(message, "queryParams"))
                                $root.google.cloud.dialogflow.v2beta1.QueryParameters.encode(message.queryParams, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.queryInput != null && Object.hasOwnProperty.call(message, "queryInput"))
                                $root.google.cloud.dialogflow.v2beta1.QueryInput.encode(message.queryInput, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            if (message.singleUtterance != null && Object.hasOwnProperty.call(message, "singleUtterance"))
                                writer.uint32(/* id 4, wireType 0 =*/32).bool(message.singleUtterance);
                            if (message.outputAudioConfig != null && Object.hasOwnProperty.call(message, "outputAudioConfig"))
                                $root.google.cloud.dialogflow.v2beta1.OutputAudioConfig.encode(message.outputAudioConfig, writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                            if (message.inputAudio != null && Object.hasOwnProperty.call(message, "inputAudio"))
                                writer.uint32(/* id 6, wireType 2 =*/50).bytes(message.inputAudio);
                            if (message.outputAudioConfigMask != null && Object.hasOwnProperty.call(message, "outputAudioConfigMask"))
                                $root.google.protobuf.FieldMask.encode(message.outputAudioConfigMask, writer.uint32(/* id 7, wireType 2 =*/58).fork()).ldelim();
                            if (message.enableDebuggingInfo != null && Object.hasOwnProperty.call(message, "enableDebuggingInfo"))
                                writer.uint32(/* id 8, wireType 0 =*/64).bool(message.enableDebuggingInfo);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified StreamingDetectIntentRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.StreamingDetectIntentRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingDetectIntentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IStreamingDetectIntentRequest} message StreamingDetectIntentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        StreamingDetectIntentRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a StreamingDetectIntentRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingDetectIntentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.StreamingDetectIntentRequest} StreamingDetectIntentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        StreamingDetectIntentRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.StreamingDetectIntentRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.session = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.queryParams = $root.google.cloud.dialogflow.v2beta1.QueryParameters.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 3: {
                                        message.queryInput = $root.google.cloud.dialogflow.v2beta1.QueryInput.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 4: {
                                        message.singleUtterance = reader.bool();
                                        break;
                                    }
                                case 5: {
                                        message.outputAudioConfig = $root.google.cloud.dialogflow.v2beta1.OutputAudioConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 7: {
                                        message.outputAudioConfigMask = $root.google.protobuf.FieldMask.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 6: {
                                        message.inputAudio = reader.bytes();
                                        break;
                                    }
                                case 8: {
                                        message.enableDebuggingInfo = reader.bool();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a StreamingDetectIntentRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingDetectIntentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.StreamingDetectIntentRequest} StreamingDetectIntentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        StreamingDetectIntentRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a StreamingDetectIntentRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingDetectIntentRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        StreamingDetectIntentRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.session != null && message.hasOwnProperty("session"))
                                if (!$util.isString(message.session))
                                    return "session: string expected";
                            if (message.queryParams != null && message.hasOwnProperty("queryParams")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.QueryParameters.verify(message.queryParams);
                                if (error)
                                    return "queryParams." + error;
                            }
                            if (message.queryInput != null && message.hasOwnProperty("queryInput")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.QueryInput.verify(message.queryInput);
                                if (error)
                                    return "queryInput." + error;
                            }
                            if (message.singleUtterance != null && message.hasOwnProperty("singleUtterance"))
                                if (typeof message.singleUtterance !== "boolean")
                                    return "singleUtterance: boolean expected";
                            if (message.outputAudioConfig != null && message.hasOwnProperty("outputAudioConfig")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.OutputAudioConfig.verify(message.outputAudioConfig);
                                if (error)
                                    return "outputAudioConfig." + error;
                            }
                            if (message.outputAudioConfigMask != null && message.hasOwnProperty("outputAudioConfigMask")) {
                                var error = $root.google.protobuf.FieldMask.verify(message.outputAudioConfigMask);
                                if (error)
                                    return "outputAudioConfigMask." + error;
                            }
                            if (message.inputAudio != null && message.hasOwnProperty("inputAudio"))
                                if (!(message.inputAudio && typeof message.inputAudio.length === "number" || $util.isString(message.inputAudio)))
                                    return "inputAudio: buffer expected";
                            if (message.enableDebuggingInfo != null && message.hasOwnProperty("enableDebuggingInfo"))
                                if (typeof message.enableDebuggingInfo !== "boolean")
                                    return "enableDebuggingInfo: boolean expected";
                            return null;
                        };
    
                        /**
                         * Creates a StreamingDetectIntentRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingDetectIntentRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.StreamingDetectIntentRequest} StreamingDetectIntentRequest
                         */
                        StreamingDetectIntentRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.StreamingDetectIntentRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.StreamingDetectIntentRequest();
                            if (object.session != null)
                                message.session = String(object.session);
                            if (object.queryParams != null) {
                                if (typeof object.queryParams !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.StreamingDetectIntentRequest.queryParams: object expected");
                                message.queryParams = $root.google.cloud.dialogflow.v2beta1.QueryParameters.fromObject(object.queryParams);
                            }
                            if (object.queryInput != null) {
                                if (typeof object.queryInput !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.StreamingDetectIntentRequest.queryInput: object expected");
                                message.queryInput = $root.google.cloud.dialogflow.v2beta1.QueryInput.fromObject(object.queryInput);
                            }
                            if (object.singleUtterance != null)
                                message.singleUtterance = Boolean(object.singleUtterance);
                            if (object.outputAudioConfig != null) {
                                if (typeof object.outputAudioConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.StreamingDetectIntentRequest.outputAudioConfig: object expected");
                                message.outputAudioConfig = $root.google.cloud.dialogflow.v2beta1.OutputAudioConfig.fromObject(object.outputAudioConfig);
                            }
                            if (object.outputAudioConfigMask != null) {
                                if (typeof object.outputAudioConfigMask !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.StreamingDetectIntentRequest.outputAudioConfigMask: object expected");
                                message.outputAudioConfigMask = $root.google.protobuf.FieldMask.fromObject(object.outputAudioConfigMask);
                            }
                            if (object.inputAudio != null)
                                if (typeof object.inputAudio === "string")
                                    $util.base64.decode(object.inputAudio, message.inputAudio = $util.newBuffer($util.base64.length(object.inputAudio)), 0);
                                else if (object.inputAudio.length >= 0)
                                    message.inputAudio = object.inputAudio;
                            if (object.enableDebuggingInfo != null)
                                message.enableDebuggingInfo = Boolean(object.enableDebuggingInfo);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a StreamingDetectIntentRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingDetectIntentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.StreamingDetectIntentRequest} message StreamingDetectIntentRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        StreamingDetectIntentRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.session = "";
                                object.queryParams = null;
                                object.queryInput = null;
                                object.singleUtterance = false;
                                object.outputAudioConfig = null;
                                if (options.bytes === String)
                                    object.inputAudio = "";
                                else {
                                    object.inputAudio = [];
                                    if (options.bytes !== Array)
                                        object.inputAudio = $util.newBuffer(object.inputAudio);
                                }
                                object.outputAudioConfigMask = null;
                                object.enableDebuggingInfo = false;
                            }
                            if (message.session != null && message.hasOwnProperty("session"))
                                object.session = message.session;
                            if (message.queryParams != null && message.hasOwnProperty("queryParams"))
                                object.queryParams = $root.google.cloud.dialogflow.v2beta1.QueryParameters.toObject(message.queryParams, options);
                            if (message.queryInput != null && message.hasOwnProperty("queryInput"))
                                object.queryInput = $root.google.cloud.dialogflow.v2beta1.QueryInput.toObject(message.queryInput, options);
                            if (message.singleUtterance != null && message.hasOwnProperty("singleUtterance"))
                                object.singleUtterance = message.singleUtterance;
                            if (message.outputAudioConfig != null && message.hasOwnProperty("outputAudioConfig"))
                                object.outputAudioConfig = $root.google.cloud.dialogflow.v2beta1.OutputAudioConfig.toObject(message.outputAudioConfig, options);
                            if (message.inputAudio != null && message.hasOwnProperty("inputAudio"))
                                object.inputAudio = options.bytes === String ? $util.base64.encode(message.inputAudio, 0, message.inputAudio.length) : options.bytes === Array ? Array.prototype.slice.call(message.inputAudio) : message.inputAudio;
                            if (message.outputAudioConfigMask != null && message.hasOwnProperty("outputAudioConfigMask"))
                                object.outputAudioConfigMask = $root.google.protobuf.FieldMask.toObject(message.outputAudioConfigMask, options);
                            if (message.enableDebuggingInfo != null && message.hasOwnProperty("enableDebuggingInfo"))
                                object.enableDebuggingInfo = message.enableDebuggingInfo;
                            return object;
                        };
    
                        /**
                         * Converts this StreamingDetectIntentRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingDetectIntentRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        StreamingDetectIntentRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for StreamingDetectIntentRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingDetectIntentRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        StreamingDetectIntentRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.StreamingDetectIntentRequest";
                        };
    
                        return StreamingDetectIntentRequest;
                    })();
    
                    v2beta1.CloudConversationDebuggingInfo = (function() {
    
                        /**
                         * Properties of a CloudConversationDebuggingInfo.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ICloudConversationDebuggingInfo
                         * @property {number|null} [audioDataChunks] CloudConversationDebuggingInfo audioDataChunks
                         * @property {google.protobuf.IDuration|null} [resultEndTimeOffset] CloudConversationDebuggingInfo resultEndTimeOffset
                         * @property {google.protobuf.IDuration|null} [firstAudioDuration] CloudConversationDebuggingInfo firstAudioDuration
                         * @property {boolean|null} [singleUtterance] CloudConversationDebuggingInfo singleUtterance
                         * @property {Array.<google.protobuf.IDuration>|null} [speechPartialResultsEndTimes] CloudConversationDebuggingInfo speechPartialResultsEndTimes
                         * @property {Array.<google.protobuf.IDuration>|null} [speechFinalResultsEndTimes] CloudConversationDebuggingInfo speechFinalResultsEndTimes
                         * @property {number|null} [partialResponses] CloudConversationDebuggingInfo partialResponses
                         * @property {number|null} [speakerIdPassiveLatencyMsOffset] CloudConversationDebuggingInfo speakerIdPassiveLatencyMsOffset
                         * @property {boolean|null} [bargeinEventTriggered] CloudConversationDebuggingInfo bargeinEventTriggered
                         * @property {boolean|null} [speechSingleUtterance] CloudConversationDebuggingInfo speechSingleUtterance
                         * @property {Array.<google.protobuf.IDuration>|null} [dtmfPartialResultsTimes] CloudConversationDebuggingInfo dtmfPartialResultsTimes
                         * @property {Array.<google.protobuf.IDuration>|null} [dtmfFinalResultsTimes] CloudConversationDebuggingInfo dtmfFinalResultsTimes
                         * @property {google.protobuf.IDuration|null} [singleUtteranceEndTimeOffset] CloudConversationDebuggingInfo singleUtteranceEndTimeOffset
                         * @property {google.protobuf.IDuration|null} [noSpeechTimeout] CloudConversationDebuggingInfo noSpeechTimeout
                         * @property {google.protobuf.IDuration|null} [endpointingTimeout] CloudConversationDebuggingInfo endpointingTimeout
                         * @property {boolean|null} [isInputText] CloudConversationDebuggingInfo isInputText
                         * @property {google.protobuf.IDuration|null} [clientHalfCloseTimeOffset] CloudConversationDebuggingInfo clientHalfCloseTimeOffset
                         * @property {google.protobuf.IDuration|null} [clientHalfCloseStreamingTimeOffset] CloudConversationDebuggingInfo clientHalfCloseStreamingTimeOffset
                         */
    
                        /**
                         * Constructs a new CloudConversationDebuggingInfo.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a CloudConversationDebuggingInfo.
                         * @implements ICloudConversationDebuggingInfo
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ICloudConversationDebuggingInfo=} [properties] Properties to set
                         */
                        function CloudConversationDebuggingInfo(properties) {
                            this.speechPartialResultsEndTimes = [];
                            this.speechFinalResultsEndTimes = [];
                            this.dtmfPartialResultsTimes = [];
                            this.dtmfFinalResultsTimes = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * CloudConversationDebuggingInfo audioDataChunks.
                         * @member {number} audioDataChunks
                         * @memberof google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo
                         * @instance
                         */
                        CloudConversationDebuggingInfo.prototype.audioDataChunks = 0;
    
                        /**
                         * CloudConversationDebuggingInfo resultEndTimeOffset.
                         * @member {google.protobuf.IDuration|null|undefined} resultEndTimeOffset
                         * @memberof google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo
                         * @instance
                         */
                        CloudConversationDebuggingInfo.prototype.resultEndTimeOffset = null;
    
                        /**
                         * CloudConversationDebuggingInfo firstAudioDuration.
                         * @member {google.protobuf.IDuration|null|undefined} firstAudioDuration
                         * @memberof google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo
                         * @instance
                         */
                        CloudConversationDebuggingInfo.prototype.firstAudioDuration = null;
    
                        /**
                         * CloudConversationDebuggingInfo singleUtterance.
                         * @member {boolean} singleUtterance
                         * @memberof google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo
                         * @instance
                         */
                        CloudConversationDebuggingInfo.prototype.singleUtterance = false;
    
                        /**
                         * CloudConversationDebuggingInfo speechPartialResultsEndTimes.
                         * @member {Array.<google.protobuf.IDuration>} speechPartialResultsEndTimes
                         * @memberof google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo
                         * @instance
                         */
                        CloudConversationDebuggingInfo.prototype.speechPartialResultsEndTimes = $util.emptyArray;
    
                        /**
                         * CloudConversationDebuggingInfo speechFinalResultsEndTimes.
                         * @member {Array.<google.protobuf.IDuration>} speechFinalResultsEndTimes
                         * @memberof google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo
                         * @instance
                         */
                        CloudConversationDebuggingInfo.prototype.speechFinalResultsEndTimes = $util.emptyArray;
    
                        /**
                         * CloudConversationDebuggingInfo partialResponses.
                         * @member {number} partialResponses
                         * @memberof google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo
                         * @instance
                         */
                        CloudConversationDebuggingInfo.prototype.partialResponses = 0;
    
                        /**
                         * CloudConversationDebuggingInfo speakerIdPassiveLatencyMsOffset.
                         * @member {number} speakerIdPassiveLatencyMsOffset
                         * @memberof google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo
                         * @instance
                         */
                        CloudConversationDebuggingInfo.prototype.speakerIdPassiveLatencyMsOffset = 0;
    
                        /**
                         * CloudConversationDebuggingInfo bargeinEventTriggered.
                         * @member {boolean} bargeinEventTriggered
                         * @memberof google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo
                         * @instance
                         */
                        CloudConversationDebuggingInfo.prototype.bargeinEventTriggered = false;
    
                        /**
                         * CloudConversationDebuggingInfo speechSingleUtterance.
                         * @member {boolean} speechSingleUtterance
                         * @memberof google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo
                         * @instance
                         */
                        CloudConversationDebuggingInfo.prototype.speechSingleUtterance = false;
    
                        /**
                         * CloudConversationDebuggingInfo dtmfPartialResultsTimes.
                         * @member {Array.<google.protobuf.IDuration>} dtmfPartialResultsTimes
                         * @memberof google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo
                         * @instance
                         */
                        CloudConversationDebuggingInfo.prototype.dtmfPartialResultsTimes = $util.emptyArray;
    
                        /**
                         * CloudConversationDebuggingInfo dtmfFinalResultsTimes.
                         * @member {Array.<google.protobuf.IDuration>} dtmfFinalResultsTimes
                         * @memberof google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo
                         * @instance
                         */
                        CloudConversationDebuggingInfo.prototype.dtmfFinalResultsTimes = $util.emptyArray;
    
                        /**
                         * CloudConversationDebuggingInfo singleUtteranceEndTimeOffset.
                         * @member {google.protobuf.IDuration|null|undefined} singleUtteranceEndTimeOffset
                         * @memberof google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo
                         * @instance
                         */
                        CloudConversationDebuggingInfo.prototype.singleUtteranceEndTimeOffset = null;
    
                        /**
                         * CloudConversationDebuggingInfo noSpeechTimeout.
                         * @member {google.protobuf.IDuration|null|undefined} noSpeechTimeout
                         * @memberof google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo
                         * @instance
                         */
                        CloudConversationDebuggingInfo.prototype.noSpeechTimeout = null;
    
                        /**
                         * CloudConversationDebuggingInfo endpointingTimeout.
                         * @member {google.protobuf.IDuration|null|undefined} endpointingTimeout
                         * @memberof google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo
                         * @instance
                         */
                        CloudConversationDebuggingInfo.prototype.endpointingTimeout = null;
    
                        /**
                         * CloudConversationDebuggingInfo isInputText.
                         * @member {boolean} isInputText
                         * @memberof google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo
                         * @instance
                         */
                        CloudConversationDebuggingInfo.prototype.isInputText = false;
    
                        /**
                         * CloudConversationDebuggingInfo clientHalfCloseTimeOffset.
                         * @member {google.protobuf.IDuration|null|undefined} clientHalfCloseTimeOffset
                         * @memberof google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo
                         * @instance
                         */
                        CloudConversationDebuggingInfo.prototype.clientHalfCloseTimeOffset = null;
    
                        /**
                         * CloudConversationDebuggingInfo clientHalfCloseStreamingTimeOffset.
                         * @member {google.protobuf.IDuration|null|undefined} clientHalfCloseStreamingTimeOffset
                         * @memberof google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo
                         * @instance
                         */
                        CloudConversationDebuggingInfo.prototype.clientHalfCloseStreamingTimeOffset = null;
    
                        /**
                         * Creates a new CloudConversationDebuggingInfo instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ICloudConversationDebuggingInfo=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo} CloudConversationDebuggingInfo instance
                         */
                        CloudConversationDebuggingInfo.create = function create(properties) {
                            return new CloudConversationDebuggingInfo(properties);
                        };
    
                        /**
                         * Encodes the specified CloudConversationDebuggingInfo message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ICloudConversationDebuggingInfo} message CloudConversationDebuggingInfo message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CloudConversationDebuggingInfo.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.audioDataChunks != null && Object.hasOwnProperty.call(message, "audioDataChunks"))
                                writer.uint32(/* id 1, wireType 0 =*/8).int32(message.audioDataChunks);
                            if (message.resultEndTimeOffset != null && Object.hasOwnProperty.call(message, "resultEndTimeOffset"))
                                $root.google.protobuf.Duration.encode(message.resultEndTimeOffset, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.firstAudioDuration != null && Object.hasOwnProperty.call(message, "firstAudioDuration"))
                                $root.google.protobuf.Duration.encode(message.firstAudioDuration, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            if (message.singleUtterance != null && Object.hasOwnProperty.call(message, "singleUtterance"))
                                writer.uint32(/* id 5, wireType 0 =*/40).bool(message.singleUtterance);
                            if (message.speechPartialResultsEndTimes != null && message.speechPartialResultsEndTimes.length)
                                for (var i = 0; i < message.speechPartialResultsEndTimes.length; ++i)
                                    $root.google.protobuf.Duration.encode(message.speechPartialResultsEndTimes[i], writer.uint32(/* id 6, wireType 2 =*/50).fork()).ldelim();
                            if (message.speechFinalResultsEndTimes != null && message.speechFinalResultsEndTimes.length)
                                for (var i = 0; i < message.speechFinalResultsEndTimes.length; ++i)
                                    $root.google.protobuf.Duration.encode(message.speechFinalResultsEndTimes[i], writer.uint32(/* id 7, wireType 2 =*/58).fork()).ldelim();
                            if (message.partialResponses != null && Object.hasOwnProperty.call(message, "partialResponses"))
                                writer.uint32(/* id 8, wireType 0 =*/64).int32(message.partialResponses);
                            if (message.speakerIdPassiveLatencyMsOffset != null && Object.hasOwnProperty.call(message, "speakerIdPassiveLatencyMsOffset"))
                                writer.uint32(/* id 9, wireType 0 =*/72).int32(message.speakerIdPassiveLatencyMsOffset);
                            if (message.bargeinEventTriggered != null && Object.hasOwnProperty.call(message, "bargeinEventTriggered"))
                                writer.uint32(/* id 10, wireType 0 =*/80).bool(message.bargeinEventTriggered);
                            if (message.speechSingleUtterance != null && Object.hasOwnProperty.call(message, "speechSingleUtterance"))
                                writer.uint32(/* id 11, wireType 0 =*/88).bool(message.speechSingleUtterance);
                            if (message.dtmfPartialResultsTimes != null && message.dtmfPartialResultsTimes.length)
                                for (var i = 0; i < message.dtmfPartialResultsTimes.length; ++i)
                                    $root.google.protobuf.Duration.encode(message.dtmfPartialResultsTimes[i], writer.uint32(/* id 12, wireType 2 =*/98).fork()).ldelim();
                            if (message.dtmfFinalResultsTimes != null && message.dtmfFinalResultsTimes.length)
                                for (var i = 0; i < message.dtmfFinalResultsTimes.length; ++i)
                                    $root.google.protobuf.Duration.encode(message.dtmfFinalResultsTimes[i], writer.uint32(/* id 13, wireType 2 =*/106).fork()).ldelim();
                            if (message.singleUtteranceEndTimeOffset != null && Object.hasOwnProperty.call(message, "singleUtteranceEndTimeOffset"))
                                $root.google.protobuf.Duration.encode(message.singleUtteranceEndTimeOffset, writer.uint32(/* id 14, wireType 2 =*/114).fork()).ldelim();
                            if (message.noSpeechTimeout != null && Object.hasOwnProperty.call(message, "noSpeechTimeout"))
                                $root.google.protobuf.Duration.encode(message.noSpeechTimeout, writer.uint32(/* id 15, wireType 2 =*/122).fork()).ldelim();
                            if (message.isInputText != null && Object.hasOwnProperty.call(message, "isInputText"))
                                writer.uint32(/* id 16, wireType 0 =*/128).bool(message.isInputText);
                            if (message.clientHalfCloseTimeOffset != null && Object.hasOwnProperty.call(message, "clientHalfCloseTimeOffset"))
                                $root.google.protobuf.Duration.encode(message.clientHalfCloseTimeOffset, writer.uint32(/* id 17, wireType 2 =*/138).fork()).ldelim();
                            if (message.clientHalfCloseStreamingTimeOffset != null && Object.hasOwnProperty.call(message, "clientHalfCloseStreamingTimeOffset"))
                                $root.google.protobuf.Duration.encode(message.clientHalfCloseStreamingTimeOffset, writer.uint32(/* id 18, wireType 2 =*/146).fork()).ldelim();
                            if (message.endpointingTimeout != null && Object.hasOwnProperty.call(message, "endpointingTimeout"))
                                $root.google.protobuf.Duration.encode(message.endpointingTimeout, writer.uint32(/* id 19, wireType 2 =*/154).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified CloudConversationDebuggingInfo message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ICloudConversationDebuggingInfo} message CloudConversationDebuggingInfo message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CloudConversationDebuggingInfo.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a CloudConversationDebuggingInfo message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo} CloudConversationDebuggingInfo
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CloudConversationDebuggingInfo.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.audioDataChunks = reader.int32();
                                        break;
                                    }
                                case 2: {
                                        message.resultEndTimeOffset = $root.google.protobuf.Duration.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 3: {
                                        message.firstAudioDuration = $root.google.protobuf.Duration.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 5: {
                                        message.singleUtterance = reader.bool();
                                        break;
                                    }
                                case 6: {
                                        if (!(message.speechPartialResultsEndTimes && message.speechPartialResultsEndTimes.length))
                                            message.speechPartialResultsEndTimes = [];
                                        message.speechPartialResultsEndTimes.push($root.google.protobuf.Duration.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 7: {
                                        if (!(message.speechFinalResultsEndTimes && message.speechFinalResultsEndTimes.length))
                                            message.speechFinalResultsEndTimes = [];
                                        message.speechFinalResultsEndTimes.push($root.google.protobuf.Duration.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 8: {
                                        message.partialResponses = reader.int32();
                                        break;
                                    }
                                case 9: {
                                        message.speakerIdPassiveLatencyMsOffset = reader.int32();
                                        break;
                                    }
                                case 10: {
                                        message.bargeinEventTriggered = reader.bool();
                                        break;
                                    }
                                case 11: {
                                        message.speechSingleUtterance = reader.bool();
                                        break;
                                    }
                                case 12: {
                                        if (!(message.dtmfPartialResultsTimes && message.dtmfPartialResultsTimes.length))
                                            message.dtmfPartialResultsTimes = [];
                                        message.dtmfPartialResultsTimes.push($root.google.protobuf.Duration.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 13: {
                                        if (!(message.dtmfFinalResultsTimes && message.dtmfFinalResultsTimes.length))
                                            message.dtmfFinalResultsTimes = [];
                                        message.dtmfFinalResultsTimes.push($root.google.protobuf.Duration.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 14: {
                                        message.singleUtteranceEndTimeOffset = $root.google.protobuf.Duration.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 15: {
                                        message.noSpeechTimeout = $root.google.protobuf.Duration.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 19: {
                                        message.endpointingTimeout = $root.google.protobuf.Duration.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 16: {
                                        message.isInputText = reader.bool();
                                        break;
                                    }
                                case 17: {
                                        message.clientHalfCloseTimeOffset = $root.google.protobuf.Duration.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 18: {
                                        message.clientHalfCloseStreamingTimeOffset = $root.google.protobuf.Duration.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a CloudConversationDebuggingInfo message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo} CloudConversationDebuggingInfo
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CloudConversationDebuggingInfo.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a CloudConversationDebuggingInfo message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        CloudConversationDebuggingInfo.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.audioDataChunks != null && message.hasOwnProperty("audioDataChunks"))
                                if (!$util.isInteger(message.audioDataChunks))
                                    return "audioDataChunks: integer expected";
                            if (message.resultEndTimeOffset != null && message.hasOwnProperty("resultEndTimeOffset")) {
                                var error = $root.google.protobuf.Duration.verify(message.resultEndTimeOffset);
                                if (error)
                                    return "resultEndTimeOffset." + error;
                            }
                            if (message.firstAudioDuration != null && message.hasOwnProperty("firstAudioDuration")) {
                                var error = $root.google.protobuf.Duration.verify(message.firstAudioDuration);
                                if (error)
                                    return "firstAudioDuration." + error;
                            }
                            if (message.singleUtterance != null && message.hasOwnProperty("singleUtterance"))
                                if (typeof message.singleUtterance !== "boolean")
                                    return "singleUtterance: boolean expected";
                            if (message.speechPartialResultsEndTimes != null && message.hasOwnProperty("speechPartialResultsEndTimes")) {
                                if (!Array.isArray(message.speechPartialResultsEndTimes))
                                    return "speechPartialResultsEndTimes: array expected";
                                for (var i = 0; i < message.speechPartialResultsEndTimes.length; ++i) {
                                    var error = $root.google.protobuf.Duration.verify(message.speechPartialResultsEndTimes[i]);
                                    if (error)
                                        return "speechPartialResultsEndTimes." + error;
                                }
                            }
                            if (message.speechFinalResultsEndTimes != null && message.hasOwnProperty("speechFinalResultsEndTimes")) {
                                if (!Array.isArray(message.speechFinalResultsEndTimes))
                                    return "speechFinalResultsEndTimes: array expected";
                                for (var i = 0; i < message.speechFinalResultsEndTimes.length; ++i) {
                                    var error = $root.google.protobuf.Duration.verify(message.speechFinalResultsEndTimes[i]);
                                    if (error)
                                        return "speechFinalResultsEndTimes." + error;
                                }
                            }
                            if (message.partialResponses != null && message.hasOwnProperty("partialResponses"))
                                if (!$util.isInteger(message.partialResponses))
                                    return "partialResponses: integer expected";
                            if (message.speakerIdPassiveLatencyMsOffset != null && message.hasOwnProperty("speakerIdPassiveLatencyMsOffset"))
                                if (!$util.isInteger(message.speakerIdPassiveLatencyMsOffset))
                                    return "speakerIdPassiveLatencyMsOffset: integer expected";
                            if (message.bargeinEventTriggered != null && message.hasOwnProperty("bargeinEventTriggered"))
                                if (typeof message.bargeinEventTriggered !== "boolean")
                                    return "bargeinEventTriggered: boolean expected";
                            if (message.speechSingleUtterance != null && message.hasOwnProperty("speechSingleUtterance"))
                                if (typeof message.speechSingleUtterance !== "boolean")
                                    return "speechSingleUtterance: boolean expected";
                            if (message.dtmfPartialResultsTimes != null && message.hasOwnProperty("dtmfPartialResultsTimes")) {
                                if (!Array.isArray(message.dtmfPartialResultsTimes))
                                    return "dtmfPartialResultsTimes: array expected";
                                for (var i = 0; i < message.dtmfPartialResultsTimes.length; ++i) {
                                    var error = $root.google.protobuf.Duration.verify(message.dtmfPartialResultsTimes[i]);
                                    if (error)
                                        return "dtmfPartialResultsTimes." + error;
                                }
                            }
                            if (message.dtmfFinalResultsTimes != null && message.hasOwnProperty("dtmfFinalResultsTimes")) {
                                if (!Array.isArray(message.dtmfFinalResultsTimes))
                                    return "dtmfFinalResultsTimes: array expected";
                                for (var i = 0; i < message.dtmfFinalResultsTimes.length; ++i) {
                                    var error = $root.google.protobuf.Duration.verify(message.dtmfFinalResultsTimes[i]);
                                    if (error)
                                        return "dtmfFinalResultsTimes." + error;
                                }
                            }
                            if (message.singleUtteranceEndTimeOffset != null && message.hasOwnProperty("singleUtteranceEndTimeOffset")) {
                                var error = $root.google.protobuf.Duration.verify(message.singleUtteranceEndTimeOffset);
                                if (error)
                                    return "singleUtteranceEndTimeOffset." + error;
                            }
                            if (message.noSpeechTimeout != null && message.hasOwnProperty("noSpeechTimeout")) {
                                var error = $root.google.protobuf.Duration.verify(message.noSpeechTimeout);
                                if (error)
                                    return "noSpeechTimeout." + error;
                            }
                            if (message.endpointingTimeout != null && message.hasOwnProperty("endpointingTimeout")) {
                                var error = $root.google.protobuf.Duration.verify(message.endpointingTimeout);
                                if (error)
                                    return "endpointingTimeout." + error;
                            }
                            if (message.isInputText != null && message.hasOwnProperty("isInputText"))
                                if (typeof message.isInputText !== "boolean")
                                    return "isInputText: boolean expected";
                            if (message.clientHalfCloseTimeOffset != null && message.hasOwnProperty("clientHalfCloseTimeOffset")) {
                                var error = $root.google.protobuf.Duration.verify(message.clientHalfCloseTimeOffset);
                                if (error)
                                    return "clientHalfCloseTimeOffset." + error;
                            }
                            if (message.clientHalfCloseStreamingTimeOffset != null && message.hasOwnProperty("clientHalfCloseStreamingTimeOffset")) {
                                var error = $root.google.protobuf.Duration.verify(message.clientHalfCloseStreamingTimeOffset);
                                if (error)
                                    return "clientHalfCloseStreamingTimeOffset." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a CloudConversationDebuggingInfo message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo} CloudConversationDebuggingInfo
                         */
                        CloudConversationDebuggingInfo.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo();
                            if (object.audioDataChunks != null)
                                message.audioDataChunks = object.audioDataChunks | 0;
                            if (object.resultEndTimeOffset != null) {
                                if (typeof object.resultEndTimeOffset !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo.resultEndTimeOffset: object expected");
                                message.resultEndTimeOffset = $root.google.protobuf.Duration.fromObject(object.resultEndTimeOffset);
                            }
                            if (object.firstAudioDuration != null) {
                                if (typeof object.firstAudioDuration !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo.firstAudioDuration: object expected");
                                message.firstAudioDuration = $root.google.protobuf.Duration.fromObject(object.firstAudioDuration);
                            }
                            if (object.singleUtterance != null)
                                message.singleUtterance = Boolean(object.singleUtterance);
                            if (object.speechPartialResultsEndTimes) {
                                if (!Array.isArray(object.speechPartialResultsEndTimes))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo.speechPartialResultsEndTimes: array expected");
                                message.speechPartialResultsEndTimes = [];
                                for (var i = 0; i < object.speechPartialResultsEndTimes.length; ++i) {
                                    if (typeof object.speechPartialResultsEndTimes[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo.speechPartialResultsEndTimes: object expected");
                                    message.speechPartialResultsEndTimes[i] = $root.google.protobuf.Duration.fromObject(object.speechPartialResultsEndTimes[i]);
                                }
                            }
                            if (object.speechFinalResultsEndTimes) {
                                if (!Array.isArray(object.speechFinalResultsEndTimes))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo.speechFinalResultsEndTimes: array expected");
                                message.speechFinalResultsEndTimes = [];
                                for (var i = 0; i < object.speechFinalResultsEndTimes.length; ++i) {
                                    if (typeof object.speechFinalResultsEndTimes[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo.speechFinalResultsEndTimes: object expected");
                                    message.speechFinalResultsEndTimes[i] = $root.google.protobuf.Duration.fromObject(object.speechFinalResultsEndTimes[i]);
                                }
                            }
                            if (object.partialResponses != null)
                                message.partialResponses = object.partialResponses | 0;
                            if (object.speakerIdPassiveLatencyMsOffset != null)
                                message.speakerIdPassiveLatencyMsOffset = object.speakerIdPassiveLatencyMsOffset | 0;
                            if (object.bargeinEventTriggered != null)
                                message.bargeinEventTriggered = Boolean(object.bargeinEventTriggered);
                            if (object.speechSingleUtterance != null)
                                message.speechSingleUtterance = Boolean(object.speechSingleUtterance);
                            if (object.dtmfPartialResultsTimes) {
                                if (!Array.isArray(object.dtmfPartialResultsTimes))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo.dtmfPartialResultsTimes: array expected");
                                message.dtmfPartialResultsTimes = [];
                                for (var i = 0; i < object.dtmfPartialResultsTimes.length; ++i) {
                                    if (typeof object.dtmfPartialResultsTimes[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo.dtmfPartialResultsTimes: object expected");
                                    message.dtmfPartialResultsTimes[i] = $root.google.protobuf.Duration.fromObject(object.dtmfPartialResultsTimes[i]);
                                }
                            }
                            if (object.dtmfFinalResultsTimes) {
                                if (!Array.isArray(object.dtmfFinalResultsTimes))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo.dtmfFinalResultsTimes: array expected");
                                message.dtmfFinalResultsTimes = [];
                                for (var i = 0; i < object.dtmfFinalResultsTimes.length; ++i) {
                                    if (typeof object.dtmfFinalResultsTimes[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo.dtmfFinalResultsTimes: object expected");
                                    message.dtmfFinalResultsTimes[i] = $root.google.protobuf.Duration.fromObject(object.dtmfFinalResultsTimes[i]);
                                }
                            }
                            if (object.singleUtteranceEndTimeOffset != null) {
                                if (typeof object.singleUtteranceEndTimeOffset !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo.singleUtteranceEndTimeOffset: object expected");
                                message.singleUtteranceEndTimeOffset = $root.google.protobuf.Duration.fromObject(object.singleUtteranceEndTimeOffset);
                            }
                            if (object.noSpeechTimeout != null) {
                                if (typeof object.noSpeechTimeout !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo.noSpeechTimeout: object expected");
                                message.noSpeechTimeout = $root.google.protobuf.Duration.fromObject(object.noSpeechTimeout);
                            }
                            if (object.endpointingTimeout != null) {
                                if (typeof object.endpointingTimeout !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo.endpointingTimeout: object expected");
                                message.endpointingTimeout = $root.google.protobuf.Duration.fromObject(object.endpointingTimeout);
                            }
                            if (object.isInputText != null)
                                message.isInputText = Boolean(object.isInputText);
                            if (object.clientHalfCloseTimeOffset != null) {
                                if (typeof object.clientHalfCloseTimeOffset !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo.clientHalfCloseTimeOffset: object expected");
                                message.clientHalfCloseTimeOffset = $root.google.protobuf.Duration.fromObject(object.clientHalfCloseTimeOffset);
                            }
                            if (object.clientHalfCloseStreamingTimeOffset != null) {
                                if (typeof object.clientHalfCloseStreamingTimeOffset !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo.clientHalfCloseStreamingTimeOffset: object expected");
                                message.clientHalfCloseStreamingTimeOffset = $root.google.protobuf.Duration.fromObject(object.clientHalfCloseStreamingTimeOffset);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a CloudConversationDebuggingInfo message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo} message CloudConversationDebuggingInfo
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        CloudConversationDebuggingInfo.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults) {
                                object.speechPartialResultsEndTimes = [];
                                object.speechFinalResultsEndTimes = [];
                                object.dtmfPartialResultsTimes = [];
                                object.dtmfFinalResultsTimes = [];
                            }
                            if (options.defaults) {
                                object.audioDataChunks = 0;
                                object.resultEndTimeOffset = null;
                                object.firstAudioDuration = null;
                                object.singleUtterance = false;
                                object.partialResponses = 0;
                                object.speakerIdPassiveLatencyMsOffset = 0;
                                object.bargeinEventTriggered = false;
                                object.speechSingleUtterance = false;
                                object.singleUtteranceEndTimeOffset = null;
                                object.noSpeechTimeout = null;
                                object.isInputText = false;
                                object.clientHalfCloseTimeOffset = null;
                                object.clientHalfCloseStreamingTimeOffset = null;
                                object.endpointingTimeout = null;
                            }
                            if (message.audioDataChunks != null && message.hasOwnProperty("audioDataChunks"))
                                object.audioDataChunks = message.audioDataChunks;
                            if (message.resultEndTimeOffset != null && message.hasOwnProperty("resultEndTimeOffset"))
                                object.resultEndTimeOffset = $root.google.protobuf.Duration.toObject(message.resultEndTimeOffset, options);
                            if (message.firstAudioDuration != null && message.hasOwnProperty("firstAudioDuration"))
                                object.firstAudioDuration = $root.google.protobuf.Duration.toObject(message.firstAudioDuration, options);
                            if (message.singleUtterance != null && message.hasOwnProperty("singleUtterance"))
                                object.singleUtterance = message.singleUtterance;
                            if (message.speechPartialResultsEndTimes && message.speechPartialResultsEndTimes.length) {
                                object.speechPartialResultsEndTimes = [];
                                for (var j = 0; j < message.speechPartialResultsEndTimes.length; ++j)
                                    object.speechPartialResultsEndTimes[j] = $root.google.protobuf.Duration.toObject(message.speechPartialResultsEndTimes[j], options);
                            }
                            if (message.speechFinalResultsEndTimes && message.speechFinalResultsEndTimes.length) {
                                object.speechFinalResultsEndTimes = [];
                                for (var j = 0; j < message.speechFinalResultsEndTimes.length; ++j)
                                    object.speechFinalResultsEndTimes[j] = $root.google.protobuf.Duration.toObject(message.speechFinalResultsEndTimes[j], options);
                            }
                            if (message.partialResponses != null && message.hasOwnProperty("partialResponses"))
                                object.partialResponses = message.partialResponses;
                            if (message.speakerIdPassiveLatencyMsOffset != null && message.hasOwnProperty("speakerIdPassiveLatencyMsOffset"))
                                object.speakerIdPassiveLatencyMsOffset = message.speakerIdPassiveLatencyMsOffset;
                            if (message.bargeinEventTriggered != null && message.hasOwnProperty("bargeinEventTriggered"))
                                object.bargeinEventTriggered = message.bargeinEventTriggered;
                            if (message.speechSingleUtterance != null && message.hasOwnProperty("speechSingleUtterance"))
                                object.speechSingleUtterance = message.speechSingleUtterance;
                            if (message.dtmfPartialResultsTimes && message.dtmfPartialResultsTimes.length) {
                                object.dtmfPartialResultsTimes = [];
                                for (var j = 0; j < message.dtmfPartialResultsTimes.length; ++j)
                                    object.dtmfPartialResultsTimes[j] = $root.google.protobuf.Duration.toObject(message.dtmfPartialResultsTimes[j], options);
                            }
                            if (message.dtmfFinalResultsTimes && message.dtmfFinalResultsTimes.length) {
                                object.dtmfFinalResultsTimes = [];
                                for (var j = 0; j < message.dtmfFinalResultsTimes.length; ++j)
                                    object.dtmfFinalResultsTimes[j] = $root.google.protobuf.Duration.toObject(message.dtmfFinalResultsTimes[j], options);
                            }
                            if (message.singleUtteranceEndTimeOffset != null && message.hasOwnProperty("singleUtteranceEndTimeOffset"))
                                object.singleUtteranceEndTimeOffset = $root.google.protobuf.Duration.toObject(message.singleUtteranceEndTimeOffset, options);
                            if (message.noSpeechTimeout != null && message.hasOwnProperty("noSpeechTimeout"))
                                object.noSpeechTimeout = $root.google.protobuf.Duration.toObject(message.noSpeechTimeout, options);
                            if (message.isInputText != null && message.hasOwnProperty("isInputText"))
                                object.isInputText = message.isInputText;
                            if (message.clientHalfCloseTimeOffset != null && message.hasOwnProperty("clientHalfCloseTimeOffset"))
                                object.clientHalfCloseTimeOffset = $root.google.protobuf.Duration.toObject(message.clientHalfCloseTimeOffset, options);
                            if (message.clientHalfCloseStreamingTimeOffset != null && message.hasOwnProperty("clientHalfCloseStreamingTimeOffset"))
                                object.clientHalfCloseStreamingTimeOffset = $root.google.protobuf.Duration.toObject(message.clientHalfCloseStreamingTimeOffset, options);
                            if (message.endpointingTimeout != null && message.hasOwnProperty("endpointingTimeout"))
                                object.endpointingTimeout = $root.google.protobuf.Duration.toObject(message.endpointingTimeout, options);
                            return object;
                        };
    
                        /**
                         * Converts this CloudConversationDebuggingInfo to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        CloudConversationDebuggingInfo.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for CloudConversationDebuggingInfo
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        CloudConversationDebuggingInfo.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo";
                        };
    
                        return CloudConversationDebuggingInfo;
                    })();
    
                    v2beta1.StreamingDetectIntentResponse = (function() {
    
                        /**
                         * Properties of a StreamingDetectIntentResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IStreamingDetectIntentResponse
                         * @property {string|null} [responseId] StreamingDetectIntentResponse responseId
                         * @property {google.cloud.dialogflow.v2beta1.IStreamingRecognitionResult|null} [recognitionResult] StreamingDetectIntentResponse recognitionResult
                         * @property {google.cloud.dialogflow.v2beta1.IQueryResult|null} [queryResult] StreamingDetectIntentResponse queryResult
                         * @property {Array.<google.cloud.dialogflow.v2beta1.IQueryResult>|null} [alternativeQueryResults] StreamingDetectIntentResponse alternativeQueryResults
                         * @property {google.rpc.IStatus|null} [webhookStatus] StreamingDetectIntentResponse webhookStatus
                         * @property {Uint8Array|null} [outputAudio] StreamingDetectIntentResponse outputAudio
                         * @property {google.cloud.dialogflow.v2beta1.IOutputAudioConfig|null} [outputAudioConfig] StreamingDetectIntentResponse outputAudioConfig
                         * @property {google.cloud.dialogflow.v2beta1.ICloudConversationDebuggingInfo|null} [debuggingInfo] StreamingDetectIntentResponse debuggingInfo
                         */
    
                        /**
                         * Constructs a new StreamingDetectIntentResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a StreamingDetectIntentResponse.
                         * @implements IStreamingDetectIntentResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IStreamingDetectIntentResponse=} [properties] Properties to set
                         */
                        function StreamingDetectIntentResponse(properties) {
                            this.alternativeQueryResults = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * StreamingDetectIntentResponse responseId.
                         * @member {string} responseId
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingDetectIntentResponse
                         * @instance
                         */
                        StreamingDetectIntentResponse.prototype.responseId = "";
    
                        /**
                         * StreamingDetectIntentResponse recognitionResult.
                         * @member {google.cloud.dialogflow.v2beta1.IStreamingRecognitionResult|null|undefined} recognitionResult
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingDetectIntentResponse
                         * @instance
                         */
                        StreamingDetectIntentResponse.prototype.recognitionResult = null;
    
                        /**
                         * StreamingDetectIntentResponse queryResult.
                         * @member {google.cloud.dialogflow.v2beta1.IQueryResult|null|undefined} queryResult
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingDetectIntentResponse
                         * @instance
                         */
                        StreamingDetectIntentResponse.prototype.queryResult = null;
    
                        /**
                         * StreamingDetectIntentResponse alternativeQueryResults.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.IQueryResult>} alternativeQueryResults
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingDetectIntentResponse
                         * @instance
                         */
                        StreamingDetectIntentResponse.prototype.alternativeQueryResults = $util.emptyArray;
    
                        /**
                         * StreamingDetectIntentResponse webhookStatus.
                         * @member {google.rpc.IStatus|null|undefined} webhookStatus
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingDetectIntentResponse
                         * @instance
                         */
                        StreamingDetectIntentResponse.prototype.webhookStatus = null;
    
                        /**
                         * StreamingDetectIntentResponse outputAudio.
                         * @member {Uint8Array} outputAudio
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingDetectIntentResponse
                         * @instance
                         */
                        StreamingDetectIntentResponse.prototype.outputAudio = $util.newBuffer([]);
    
                        /**
                         * StreamingDetectIntentResponse outputAudioConfig.
                         * @member {google.cloud.dialogflow.v2beta1.IOutputAudioConfig|null|undefined} outputAudioConfig
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingDetectIntentResponse
                         * @instance
                         */
                        StreamingDetectIntentResponse.prototype.outputAudioConfig = null;
    
                        /**
                         * StreamingDetectIntentResponse debuggingInfo.
                         * @member {google.cloud.dialogflow.v2beta1.ICloudConversationDebuggingInfo|null|undefined} debuggingInfo
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingDetectIntentResponse
                         * @instance
                         */
                        StreamingDetectIntentResponse.prototype.debuggingInfo = null;
    
                        /**
                         * Creates a new StreamingDetectIntentResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingDetectIntentResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IStreamingDetectIntentResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.StreamingDetectIntentResponse} StreamingDetectIntentResponse instance
                         */
                        StreamingDetectIntentResponse.create = function create(properties) {
                            return new StreamingDetectIntentResponse(properties);
                        };
    
                        /**
                         * Encodes the specified StreamingDetectIntentResponse message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.StreamingDetectIntentResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingDetectIntentResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IStreamingDetectIntentResponse} message StreamingDetectIntentResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        StreamingDetectIntentResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.responseId != null && Object.hasOwnProperty.call(message, "responseId"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.responseId);
                            if (message.recognitionResult != null && Object.hasOwnProperty.call(message, "recognitionResult"))
                                $root.google.cloud.dialogflow.v2beta1.StreamingRecognitionResult.encode(message.recognitionResult, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.queryResult != null && Object.hasOwnProperty.call(message, "queryResult"))
                                $root.google.cloud.dialogflow.v2beta1.QueryResult.encode(message.queryResult, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            if (message.webhookStatus != null && Object.hasOwnProperty.call(message, "webhookStatus"))
                                $root.google.rpc.Status.encode(message.webhookStatus, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            if (message.outputAudio != null && Object.hasOwnProperty.call(message, "outputAudio"))
                                writer.uint32(/* id 5, wireType 2 =*/42).bytes(message.outputAudio);
                            if (message.outputAudioConfig != null && Object.hasOwnProperty.call(message, "outputAudioConfig"))
                                $root.google.cloud.dialogflow.v2beta1.OutputAudioConfig.encode(message.outputAudioConfig, writer.uint32(/* id 6, wireType 2 =*/50).fork()).ldelim();
                            if (message.alternativeQueryResults != null && message.alternativeQueryResults.length)
                                for (var i = 0; i < message.alternativeQueryResults.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.QueryResult.encode(message.alternativeQueryResults[i], writer.uint32(/* id 7, wireType 2 =*/58).fork()).ldelim();
                            if (message.debuggingInfo != null && Object.hasOwnProperty.call(message, "debuggingInfo"))
                                $root.google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo.encode(message.debuggingInfo, writer.uint32(/* id 8, wireType 2 =*/66).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified StreamingDetectIntentResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.StreamingDetectIntentResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingDetectIntentResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IStreamingDetectIntentResponse} message StreamingDetectIntentResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        StreamingDetectIntentResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a StreamingDetectIntentResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingDetectIntentResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.StreamingDetectIntentResponse} StreamingDetectIntentResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        StreamingDetectIntentResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.StreamingDetectIntentResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.responseId = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.recognitionResult = $root.google.cloud.dialogflow.v2beta1.StreamingRecognitionResult.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 3: {
                                        message.queryResult = $root.google.cloud.dialogflow.v2beta1.QueryResult.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 7: {
                                        if (!(message.alternativeQueryResults && message.alternativeQueryResults.length))
                                            message.alternativeQueryResults = [];
                                        message.alternativeQueryResults.push($root.google.cloud.dialogflow.v2beta1.QueryResult.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 4: {
                                        message.webhookStatus = $root.google.rpc.Status.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 5: {
                                        message.outputAudio = reader.bytes();
                                        break;
                                    }
                                case 6: {
                                        message.outputAudioConfig = $root.google.cloud.dialogflow.v2beta1.OutputAudioConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 8: {
                                        message.debuggingInfo = $root.google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a StreamingDetectIntentResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingDetectIntentResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.StreamingDetectIntentResponse} StreamingDetectIntentResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        StreamingDetectIntentResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a StreamingDetectIntentResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingDetectIntentResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        StreamingDetectIntentResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.responseId != null && message.hasOwnProperty("responseId"))
                                if (!$util.isString(message.responseId))
                                    return "responseId: string expected";
                            if (message.recognitionResult != null && message.hasOwnProperty("recognitionResult")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.StreamingRecognitionResult.verify(message.recognitionResult);
                                if (error)
                                    return "recognitionResult." + error;
                            }
                            if (message.queryResult != null && message.hasOwnProperty("queryResult")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.QueryResult.verify(message.queryResult);
                                if (error)
                                    return "queryResult." + error;
                            }
                            if (message.alternativeQueryResults != null && message.hasOwnProperty("alternativeQueryResults")) {
                                if (!Array.isArray(message.alternativeQueryResults))
                                    return "alternativeQueryResults: array expected";
                                for (var i = 0; i < message.alternativeQueryResults.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.QueryResult.verify(message.alternativeQueryResults[i]);
                                    if (error)
                                        return "alternativeQueryResults." + error;
                                }
                            }
                            if (message.webhookStatus != null && message.hasOwnProperty("webhookStatus")) {
                                var error = $root.google.rpc.Status.verify(message.webhookStatus);
                                if (error)
                                    return "webhookStatus." + error;
                            }
                            if (message.outputAudio != null && message.hasOwnProperty("outputAudio"))
                                if (!(message.outputAudio && typeof message.outputAudio.length === "number" || $util.isString(message.outputAudio)))
                                    return "outputAudio: buffer expected";
                            if (message.outputAudioConfig != null && message.hasOwnProperty("outputAudioConfig")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.OutputAudioConfig.verify(message.outputAudioConfig);
                                if (error)
                                    return "outputAudioConfig." + error;
                            }
                            if (message.debuggingInfo != null && message.hasOwnProperty("debuggingInfo")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo.verify(message.debuggingInfo);
                                if (error)
                                    return "debuggingInfo." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a StreamingDetectIntentResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingDetectIntentResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.StreamingDetectIntentResponse} StreamingDetectIntentResponse
                         */
                        StreamingDetectIntentResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.StreamingDetectIntentResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.StreamingDetectIntentResponse();
                            if (object.responseId != null)
                                message.responseId = String(object.responseId);
                            if (object.recognitionResult != null) {
                                if (typeof object.recognitionResult !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.StreamingDetectIntentResponse.recognitionResult: object expected");
                                message.recognitionResult = $root.google.cloud.dialogflow.v2beta1.StreamingRecognitionResult.fromObject(object.recognitionResult);
                            }
                            if (object.queryResult != null) {
                                if (typeof object.queryResult !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.StreamingDetectIntentResponse.queryResult: object expected");
                                message.queryResult = $root.google.cloud.dialogflow.v2beta1.QueryResult.fromObject(object.queryResult);
                            }
                            if (object.alternativeQueryResults) {
                                if (!Array.isArray(object.alternativeQueryResults))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.StreamingDetectIntentResponse.alternativeQueryResults: array expected");
                                message.alternativeQueryResults = [];
                                for (var i = 0; i < object.alternativeQueryResults.length; ++i) {
                                    if (typeof object.alternativeQueryResults[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.StreamingDetectIntentResponse.alternativeQueryResults: object expected");
                                    message.alternativeQueryResults[i] = $root.google.cloud.dialogflow.v2beta1.QueryResult.fromObject(object.alternativeQueryResults[i]);
                                }
                            }
                            if (object.webhookStatus != null) {
                                if (typeof object.webhookStatus !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.StreamingDetectIntentResponse.webhookStatus: object expected");
                                message.webhookStatus = $root.google.rpc.Status.fromObject(object.webhookStatus);
                            }
                            if (object.outputAudio != null)
                                if (typeof object.outputAudio === "string")
                                    $util.base64.decode(object.outputAudio, message.outputAudio = $util.newBuffer($util.base64.length(object.outputAudio)), 0);
                                else if (object.outputAudio.length >= 0)
                                    message.outputAudio = object.outputAudio;
                            if (object.outputAudioConfig != null) {
                                if (typeof object.outputAudioConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.StreamingDetectIntentResponse.outputAudioConfig: object expected");
                                message.outputAudioConfig = $root.google.cloud.dialogflow.v2beta1.OutputAudioConfig.fromObject(object.outputAudioConfig);
                            }
                            if (object.debuggingInfo != null) {
                                if (typeof object.debuggingInfo !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.StreamingDetectIntentResponse.debuggingInfo: object expected");
                                message.debuggingInfo = $root.google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo.fromObject(object.debuggingInfo);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a StreamingDetectIntentResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingDetectIntentResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.StreamingDetectIntentResponse} message StreamingDetectIntentResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        StreamingDetectIntentResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.alternativeQueryResults = [];
                            if (options.defaults) {
                                object.responseId = "";
                                object.recognitionResult = null;
                                object.queryResult = null;
                                object.webhookStatus = null;
                                if (options.bytes === String)
                                    object.outputAudio = "";
                                else {
                                    object.outputAudio = [];
                                    if (options.bytes !== Array)
                                        object.outputAudio = $util.newBuffer(object.outputAudio);
                                }
                                object.outputAudioConfig = null;
                                object.debuggingInfo = null;
                            }
                            if (message.responseId != null && message.hasOwnProperty("responseId"))
                                object.responseId = message.responseId;
                            if (message.recognitionResult != null && message.hasOwnProperty("recognitionResult"))
                                object.recognitionResult = $root.google.cloud.dialogflow.v2beta1.StreamingRecognitionResult.toObject(message.recognitionResult, options);
                            if (message.queryResult != null && message.hasOwnProperty("queryResult"))
                                object.queryResult = $root.google.cloud.dialogflow.v2beta1.QueryResult.toObject(message.queryResult, options);
                            if (message.webhookStatus != null && message.hasOwnProperty("webhookStatus"))
                                object.webhookStatus = $root.google.rpc.Status.toObject(message.webhookStatus, options);
                            if (message.outputAudio != null && message.hasOwnProperty("outputAudio"))
                                object.outputAudio = options.bytes === String ? $util.base64.encode(message.outputAudio, 0, message.outputAudio.length) : options.bytes === Array ? Array.prototype.slice.call(message.outputAudio) : message.outputAudio;
                            if (message.outputAudioConfig != null && message.hasOwnProperty("outputAudioConfig"))
                                object.outputAudioConfig = $root.google.cloud.dialogflow.v2beta1.OutputAudioConfig.toObject(message.outputAudioConfig, options);
                            if (message.alternativeQueryResults && message.alternativeQueryResults.length) {
                                object.alternativeQueryResults = [];
                                for (var j = 0; j < message.alternativeQueryResults.length; ++j)
                                    object.alternativeQueryResults[j] = $root.google.cloud.dialogflow.v2beta1.QueryResult.toObject(message.alternativeQueryResults[j], options);
                            }
                            if (message.debuggingInfo != null && message.hasOwnProperty("debuggingInfo"))
                                object.debuggingInfo = $root.google.cloud.dialogflow.v2beta1.CloudConversationDebuggingInfo.toObject(message.debuggingInfo, options);
                            return object;
                        };
    
                        /**
                         * Converts this StreamingDetectIntentResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingDetectIntentResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        StreamingDetectIntentResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for StreamingDetectIntentResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingDetectIntentResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        StreamingDetectIntentResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.StreamingDetectIntentResponse";
                        };
    
                        return StreamingDetectIntentResponse;
                    })();
    
                    v2beta1.StreamingRecognitionResult = (function() {
    
                        /**
                         * Properties of a StreamingRecognitionResult.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IStreamingRecognitionResult
                         * @property {google.cloud.dialogflow.v2beta1.StreamingRecognitionResult.MessageType|null} [messageType] StreamingRecognitionResult messageType
                         * @property {string|null} [transcript] StreamingRecognitionResult transcript
                         * @property {boolean|null} [isFinal] StreamingRecognitionResult isFinal
                         * @property {number|null} [confidence] StreamingRecognitionResult confidence
                         * @property {number|null} [stability] StreamingRecognitionResult stability
                         * @property {Array.<google.cloud.dialogflow.v2beta1.ISpeechWordInfo>|null} [speechWordInfo] StreamingRecognitionResult speechWordInfo
                         * @property {google.protobuf.IDuration|null} [speechEndOffset] StreamingRecognitionResult speechEndOffset
                         * @property {string|null} [languageCode] StreamingRecognitionResult languageCode
                         * @property {google.cloud.dialogflow.v2beta1.ITelephonyDtmfEvents|null} [dtmfDigits] StreamingRecognitionResult dtmfDigits
                         */
    
                        /**
                         * Constructs a new StreamingRecognitionResult.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a StreamingRecognitionResult.
                         * @implements IStreamingRecognitionResult
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IStreamingRecognitionResult=} [properties] Properties to set
                         */
                        function StreamingRecognitionResult(properties) {
                            this.speechWordInfo = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * StreamingRecognitionResult messageType.
                         * @member {google.cloud.dialogflow.v2beta1.StreamingRecognitionResult.MessageType} messageType
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingRecognitionResult
                         * @instance
                         */
                        StreamingRecognitionResult.prototype.messageType = 0;
    
                        /**
                         * StreamingRecognitionResult transcript.
                         * @member {string} transcript
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingRecognitionResult
                         * @instance
                         */
                        StreamingRecognitionResult.prototype.transcript = "";
    
                        /**
                         * StreamingRecognitionResult isFinal.
                         * @member {boolean} isFinal
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingRecognitionResult
                         * @instance
                         */
                        StreamingRecognitionResult.prototype.isFinal = false;
    
                        /**
                         * StreamingRecognitionResult confidence.
                         * @member {number} confidence
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingRecognitionResult
                         * @instance
                         */
                        StreamingRecognitionResult.prototype.confidence = 0;
    
                        /**
                         * StreamingRecognitionResult stability.
                         * @member {number} stability
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingRecognitionResult
                         * @instance
                         */
                        StreamingRecognitionResult.prototype.stability = 0;
    
                        /**
                         * StreamingRecognitionResult speechWordInfo.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.ISpeechWordInfo>} speechWordInfo
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingRecognitionResult
                         * @instance
                         */
                        StreamingRecognitionResult.prototype.speechWordInfo = $util.emptyArray;
    
                        /**
                         * StreamingRecognitionResult speechEndOffset.
                         * @member {google.protobuf.IDuration|null|undefined} speechEndOffset
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingRecognitionResult
                         * @instance
                         */
                        StreamingRecognitionResult.prototype.speechEndOffset = null;
    
                        /**
                         * StreamingRecognitionResult languageCode.
                         * @member {string} languageCode
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingRecognitionResult
                         * @instance
                         */
                        StreamingRecognitionResult.prototype.languageCode = "";
    
                        /**
                         * StreamingRecognitionResult dtmfDigits.
                         * @member {google.cloud.dialogflow.v2beta1.ITelephonyDtmfEvents|null|undefined} dtmfDigits
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingRecognitionResult
                         * @instance
                         */
                        StreamingRecognitionResult.prototype.dtmfDigits = null;
    
                        /**
                         * Creates a new StreamingRecognitionResult instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingRecognitionResult
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IStreamingRecognitionResult=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.StreamingRecognitionResult} StreamingRecognitionResult instance
                         */
                        StreamingRecognitionResult.create = function create(properties) {
                            return new StreamingRecognitionResult(properties);
                        };
    
                        /**
                         * Encodes the specified StreamingRecognitionResult message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.StreamingRecognitionResult.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingRecognitionResult
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IStreamingRecognitionResult} message StreamingRecognitionResult message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        StreamingRecognitionResult.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.messageType != null && Object.hasOwnProperty.call(message, "messageType"))
                                writer.uint32(/* id 1, wireType 0 =*/8).int32(message.messageType);
                            if (message.transcript != null && Object.hasOwnProperty.call(message, "transcript"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.transcript);
                            if (message.isFinal != null && Object.hasOwnProperty.call(message, "isFinal"))
                                writer.uint32(/* id 3, wireType 0 =*/24).bool(message.isFinal);
                            if (message.confidence != null && Object.hasOwnProperty.call(message, "confidence"))
                                writer.uint32(/* id 4, wireType 5 =*/37).float(message.confidence);
                            if (message.dtmfDigits != null && Object.hasOwnProperty.call(message, "dtmfDigits"))
                                $root.google.cloud.dialogflow.v2beta1.TelephonyDtmfEvents.encode(message.dtmfDigits, writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                            if (message.stability != null && Object.hasOwnProperty.call(message, "stability"))
                                writer.uint32(/* id 6, wireType 5 =*/53).float(message.stability);
                            if (message.speechWordInfo != null && message.speechWordInfo.length)
                                for (var i = 0; i < message.speechWordInfo.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.SpeechWordInfo.encode(message.speechWordInfo[i], writer.uint32(/* id 7, wireType 2 =*/58).fork()).ldelim();
                            if (message.speechEndOffset != null && Object.hasOwnProperty.call(message, "speechEndOffset"))
                                $root.google.protobuf.Duration.encode(message.speechEndOffset, writer.uint32(/* id 8, wireType 2 =*/66).fork()).ldelim();
                            if (message.languageCode != null && Object.hasOwnProperty.call(message, "languageCode"))
                                writer.uint32(/* id 10, wireType 2 =*/82).string(message.languageCode);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified StreamingRecognitionResult message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.StreamingRecognitionResult.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingRecognitionResult
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IStreamingRecognitionResult} message StreamingRecognitionResult message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        StreamingRecognitionResult.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a StreamingRecognitionResult message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingRecognitionResult
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.StreamingRecognitionResult} StreamingRecognitionResult
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        StreamingRecognitionResult.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.StreamingRecognitionResult();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.messageType = reader.int32();
                                        break;
                                    }
                                case 2: {
                                        message.transcript = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.isFinal = reader.bool();
                                        break;
                                    }
                                case 4: {
                                        message.confidence = reader.float();
                                        break;
                                    }
                                case 6: {
                                        message.stability = reader.float();
                                        break;
                                    }
                                case 7: {
                                        if (!(message.speechWordInfo && message.speechWordInfo.length))
                                            message.speechWordInfo = [];
                                        message.speechWordInfo.push($root.google.cloud.dialogflow.v2beta1.SpeechWordInfo.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 8: {
                                        message.speechEndOffset = $root.google.protobuf.Duration.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 10: {
                                        message.languageCode = reader.string();
                                        break;
                                    }
                                case 5: {
                                        message.dtmfDigits = $root.google.cloud.dialogflow.v2beta1.TelephonyDtmfEvents.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a StreamingRecognitionResult message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingRecognitionResult
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.StreamingRecognitionResult} StreamingRecognitionResult
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        StreamingRecognitionResult.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a StreamingRecognitionResult message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingRecognitionResult
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        StreamingRecognitionResult.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.messageType != null && message.hasOwnProperty("messageType"))
                                switch (message.messageType) {
                                default:
                                    return "messageType: enum value expected";
                                case 0:
                                case 1:
                                case 3:
                                case 2:
                                case 4:
                                    break;
                                }
                            if (message.transcript != null && message.hasOwnProperty("transcript"))
                                if (!$util.isString(message.transcript))
                                    return "transcript: string expected";
                            if (message.isFinal != null && message.hasOwnProperty("isFinal"))
                                if (typeof message.isFinal !== "boolean")
                                    return "isFinal: boolean expected";
                            if (message.confidence != null && message.hasOwnProperty("confidence"))
                                if (typeof message.confidence !== "number")
                                    return "confidence: number expected";
                            if (message.stability != null && message.hasOwnProperty("stability"))
                                if (typeof message.stability !== "number")
                                    return "stability: number expected";
                            if (message.speechWordInfo != null && message.hasOwnProperty("speechWordInfo")) {
                                if (!Array.isArray(message.speechWordInfo))
                                    return "speechWordInfo: array expected";
                                for (var i = 0; i < message.speechWordInfo.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.SpeechWordInfo.verify(message.speechWordInfo[i]);
                                    if (error)
                                        return "speechWordInfo." + error;
                                }
                            }
                            if (message.speechEndOffset != null && message.hasOwnProperty("speechEndOffset")) {
                                var error = $root.google.protobuf.Duration.verify(message.speechEndOffset);
                                if (error)
                                    return "speechEndOffset." + error;
                            }
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                if (!$util.isString(message.languageCode))
                                    return "languageCode: string expected";
                            if (message.dtmfDigits != null && message.hasOwnProperty("dtmfDigits")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.TelephonyDtmfEvents.verify(message.dtmfDigits);
                                if (error)
                                    return "dtmfDigits." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a StreamingRecognitionResult message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingRecognitionResult
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.StreamingRecognitionResult} StreamingRecognitionResult
                         */
                        StreamingRecognitionResult.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.StreamingRecognitionResult)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.StreamingRecognitionResult();
                            switch (object.messageType) {
                            default:
                                if (typeof object.messageType === "number") {
                                    message.messageType = object.messageType;
                                    break;
                                }
                                break;
                            case "MESSAGE_TYPE_UNSPECIFIED":
                            case 0:
                                message.messageType = 0;
                                break;
                            case "TRANSCRIPT":
                            case 1:
                                message.messageType = 1;
                                break;
                            case "DTMF_DIGITS":
                            case 3:
                                message.messageType = 3;
                                break;
                            case "END_OF_SINGLE_UTTERANCE":
                            case 2:
                                message.messageType = 2;
                                break;
                            case "PARTIAL_DTMF_DIGITS":
                            case 4:
                                message.messageType = 4;
                                break;
                            }
                            if (object.transcript != null)
                                message.transcript = String(object.transcript);
                            if (object.isFinal != null)
                                message.isFinal = Boolean(object.isFinal);
                            if (object.confidence != null)
                                message.confidence = Number(object.confidence);
                            if (object.stability != null)
                                message.stability = Number(object.stability);
                            if (object.speechWordInfo) {
                                if (!Array.isArray(object.speechWordInfo))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.StreamingRecognitionResult.speechWordInfo: array expected");
                                message.speechWordInfo = [];
                                for (var i = 0; i < object.speechWordInfo.length; ++i) {
                                    if (typeof object.speechWordInfo[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.StreamingRecognitionResult.speechWordInfo: object expected");
                                    message.speechWordInfo[i] = $root.google.cloud.dialogflow.v2beta1.SpeechWordInfo.fromObject(object.speechWordInfo[i]);
                                }
                            }
                            if (object.speechEndOffset != null) {
                                if (typeof object.speechEndOffset !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.StreamingRecognitionResult.speechEndOffset: object expected");
                                message.speechEndOffset = $root.google.protobuf.Duration.fromObject(object.speechEndOffset);
                            }
                            if (object.languageCode != null)
                                message.languageCode = String(object.languageCode);
                            if (object.dtmfDigits != null) {
                                if (typeof object.dtmfDigits !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.StreamingRecognitionResult.dtmfDigits: object expected");
                                message.dtmfDigits = $root.google.cloud.dialogflow.v2beta1.TelephonyDtmfEvents.fromObject(object.dtmfDigits);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a StreamingRecognitionResult message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingRecognitionResult
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.StreamingRecognitionResult} message StreamingRecognitionResult
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        StreamingRecognitionResult.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.speechWordInfo = [];
                            if (options.defaults) {
                                object.messageType = options.enums === String ? "MESSAGE_TYPE_UNSPECIFIED" : 0;
                                object.transcript = "";
                                object.isFinal = false;
                                object.confidence = 0;
                                object.dtmfDigits = null;
                                object.stability = 0;
                                object.speechEndOffset = null;
                                object.languageCode = "";
                            }
                            if (message.messageType != null && message.hasOwnProperty("messageType"))
                                object.messageType = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.StreamingRecognitionResult.MessageType[message.messageType] === undefined ? message.messageType : $root.google.cloud.dialogflow.v2beta1.StreamingRecognitionResult.MessageType[message.messageType] : message.messageType;
                            if (message.transcript != null && message.hasOwnProperty("transcript"))
                                object.transcript = message.transcript;
                            if (message.isFinal != null && message.hasOwnProperty("isFinal"))
                                object.isFinal = message.isFinal;
                            if (message.confidence != null && message.hasOwnProperty("confidence"))
                                object.confidence = options.json && !isFinite(message.confidence) ? String(message.confidence) : message.confidence;
                            if (message.dtmfDigits != null && message.hasOwnProperty("dtmfDigits"))
                                object.dtmfDigits = $root.google.cloud.dialogflow.v2beta1.TelephonyDtmfEvents.toObject(message.dtmfDigits, options);
                            if (message.stability != null && message.hasOwnProperty("stability"))
                                object.stability = options.json && !isFinite(message.stability) ? String(message.stability) : message.stability;
                            if (message.speechWordInfo && message.speechWordInfo.length) {
                                object.speechWordInfo = [];
                                for (var j = 0; j < message.speechWordInfo.length; ++j)
                                    object.speechWordInfo[j] = $root.google.cloud.dialogflow.v2beta1.SpeechWordInfo.toObject(message.speechWordInfo[j], options);
                            }
                            if (message.speechEndOffset != null && message.hasOwnProperty("speechEndOffset"))
                                object.speechEndOffset = $root.google.protobuf.Duration.toObject(message.speechEndOffset, options);
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                object.languageCode = message.languageCode;
                            return object;
                        };
    
                        /**
                         * Converts this StreamingRecognitionResult to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingRecognitionResult
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        StreamingRecognitionResult.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for StreamingRecognitionResult
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.StreamingRecognitionResult
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        StreamingRecognitionResult.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.StreamingRecognitionResult";
                        };
    
                        /**
                         * MessageType enum.
                         * @name google.cloud.dialogflow.v2beta1.StreamingRecognitionResult.MessageType
                         * @enum {number}
                         * @property {number} MESSAGE_TYPE_UNSPECIFIED=0 MESSAGE_TYPE_UNSPECIFIED value
                         * @property {number} TRANSCRIPT=1 TRANSCRIPT value
                         * @property {number} DTMF_DIGITS=3 DTMF_DIGITS value
                         * @property {number} END_OF_SINGLE_UTTERANCE=2 END_OF_SINGLE_UTTERANCE value
                         * @property {number} PARTIAL_DTMF_DIGITS=4 PARTIAL_DTMF_DIGITS value
                         */
                        StreamingRecognitionResult.MessageType = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "MESSAGE_TYPE_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "TRANSCRIPT"] = 1;
                            values[valuesById[3] = "DTMF_DIGITS"] = 3;
                            values[valuesById[2] = "END_OF_SINGLE_UTTERANCE"] = 2;
                            values[valuesById[4] = "PARTIAL_DTMF_DIGITS"] = 4;
                            return values;
                        })();
    
                        return StreamingRecognitionResult;
                    })();
    
                    v2beta1.TextInput = (function() {
    
                        /**
                         * Properties of a TextInput.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ITextInput
                         * @property {string|null} [text] TextInput text
                         * @property {string|null} [languageCode] TextInput languageCode
                         */
    
                        /**
                         * Constructs a new TextInput.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a TextInput.
                         * @implements ITextInput
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ITextInput=} [properties] Properties to set
                         */
                        function TextInput(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * TextInput text.
                         * @member {string} text
                         * @memberof google.cloud.dialogflow.v2beta1.TextInput
                         * @instance
                         */
                        TextInput.prototype.text = "";
    
                        /**
                         * TextInput languageCode.
                         * @member {string} languageCode
                         * @memberof google.cloud.dialogflow.v2beta1.TextInput
                         * @instance
                         */
                        TextInput.prototype.languageCode = "";
    
                        /**
                         * Creates a new TextInput instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.TextInput
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ITextInput=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.TextInput} TextInput instance
                         */
                        TextInput.create = function create(properties) {
                            return new TextInput(properties);
                        };
    
                        /**
                         * Encodes the specified TextInput message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.TextInput.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.TextInput
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ITextInput} message TextInput message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        TextInput.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.text != null && Object.hasOwnProperty.call(message, "text"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.text);
                            if (message.languageCode != null && Object.hasOwnProperty.call(message, "languageCode"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.languageCode);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified TextInput message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.TextInput.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.TextInput
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ITextInput} message TextInput message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        TextInput.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a TextInput message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.TextInput
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.TextInput} TextInput
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        TextInput.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.TextInput();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.text = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.languageCode = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a TextInput message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.TextInput
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.TextInput} TextInput
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        TextInput.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a TextInput message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.TextInput
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        TextInput.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.text != null && message.hasOwnProperty("text"))
                                if (!$util.isString(message.text))
                                    return "text: string expected";
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                if (!$util.isString(message.languageCode))
                                    return "languageCode: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a TextInput message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.TextInput
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.TextInput} TextInput
                         */
                        TextInput.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.TextInput)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.TextInput();
                            if (object.text != null)
                                message.text = String(object.text);
                            if (object.languageCode != null)
                                message.languageCode = String(object.languageCode);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a TextInput message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.TextInput
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.TextInput} message TextInput
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        TextInput.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.text = "";
                                object.languageCode = "";
                            }
                            if (message.text != null && message.hasOwnProperty("text"))
                                object.text = message.text;
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                object.languageCode = message.languageCode;
                            return object;
                        };
    
                        /**
                         * Converts this TextInput to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.TextInput
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        TextInput.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for TextInput
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.TextInput
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        TextInput.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.TextInput";
                        };
    
                        return TextInput;
                    })();
    
                    v2beta1.EventInput = (function() {
    
                        /**
                         * Properties of an EventInput.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IEventInput
                         * @property {string|null} [name] EventInput name
                         * @property {google.protobuf.IStruct|null} [parameters] EventInput parameters
                         * @property {string|null} [languageCode] EventInput languageCode
                         */
    
                        /**
                         * Constructs a new EventInput.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an EventInput.
                         * @implements IEventInput
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IEventInput=} [properties] Properties to set
                         */
                        function EventInput(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * EventInput name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2beta1.EventInput
                         * @instance
                         */
                        EventInput.prototype.name = "";
    
                        /**
                         * EventInput parameters.
                         * @member {google.protobuf.IStruct|null|undefined} parameters
                         * @memberof google.cloud.dialogflow.v2beta1.EventInput
                         * @instance
                         */
                        EventInput.prototype.parameters = null;
    
                        /**
                         * EventInput languageCode.
                         * @member {string} languageCode
                         * @memberof google.cloud.dialogflow.v2beta1.EventInput
                         * @instance
                         */
                        EventInput.prototype.languageCode = "";
    
                        /**
                         * Creates a new EventInput instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.EventInput
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IEventInput=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.EventInput} EventInput instance
                         */
                        EventInput.create = function create(properties) {
                            return new EventInput(properties);
                        };
    
                        /**
                         * Encodes the specified EventInput message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.EventInput.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.EventInput
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IEventInput} message EventInput message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        EventInput.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            if (message.parameters != null && Object.hasOwnProperty.call(message, "parameters"))
                                $root.google.protobuf.Struct.encode(message.parameters, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.languageCode != null && Object.hasOwnProperty.call(message, "languageCode"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.languageCode);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified EventInput message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.EventInput.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.EventInput
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IEventInput} message EventInput message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        EventInput.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an EventInput message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.EventInput
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.EventInput} EventInput
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        EventInput.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.EventInput();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.parameters = $root.google.protobuf.Struct.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 3: {
                                        message.languageCode = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an EventInput message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.EventInput
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.EventInput} EventInput
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        EventInput.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an EventInput message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.EventInput
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        EventInput.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            if (message.parameters != null && message.hasOwnProperty("parameters")) {
                                var error = $root.google.protobuf.Struct.verify(message.parameters);
                                if (error)
                                    return "parameters." + error;
                            }
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                if (!$util.isString(message.languageCode))
                                    return "languageCode: string expected";
                            return null;
                        };
    
                        /**
                         * Creates an EventInput message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.EventInput
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.EventInput} EventInput
                         */
                        EventInput.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.EventInput)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.EventInput();
                            if (object.name != null)
                                message.name = String(object.name);
                            if (object.parameters != null) {
                                if (typeof object.parameters !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.EventInput.parameters: object expected");
                                message.parameters = $root.google.protobuf.Struct.fromObject(object.parameters);
                            }
                            if (object.languageCode != null)
                                message.languageCode = String(object.languageCode);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an EventInput message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.EventInput
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.EventInput} message EventInput
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        EventInput.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.name = "";
                                object.parameters = null;
                                object.languageCode = "";
                            }
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            if (message.parameters != null && message.hasOwnProperty("parameters"))
                                object.parameters = $root.google.protobuf.Struct.toObject(message.parameters, options);
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                object.languageCode = message.languageCode;
                            return object;
                        };
    
                        /**
                         * Converts this EventInput to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.EventInput
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        EventInput.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for EventInput
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.EventInput
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        EventInput.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.EventInput";
                        };
    
                        return EventInput;
                    })();
    
                    v2beta1.SentimentAnalysisRequestConfig = (function() {
    
                        /**
                         * Properties of a SentimentAnalysisRequestConfig.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ISentimentAnalysisRequestConfig
                         * @property {boolean|null} [analyzeQueryTextSentiment] SentimentAnalysisRequestConfig analyzeQueryTextSentiment
                         */
    
                        /**
                         * Constructs a new SentimentAnalysisRequestConfig.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a SentimentAnalysisRequestConfig.
                         * @implements ISentimentAnalysisRequestConfig
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ISentimentAnalysisRequestConfig=} [properties] Properties to set
                         */
                        function SentimentAnalysisRequestConfig(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SentimentAnalysisRequestConfig analyzeQueryTextSentiment.
                         * @member {boolean} analyzeQueryTextSentiment
                         * @memberof google.cloud.dialogflow.v2beta1.SentimentAnalysisRequestConfig
                         * @instance
                         */
                        SentimentAnalysisRequestConfig.prototype.analyzeQueryTextSentiment = false;
    
                        /**
                         * Creates a new SentimentAnalysisRequestConfig instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.SentimentAnalysisRequestConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISentimentAnalysisRequestConfig=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.SentimentAnalysisRequestConfig} SentimentAnalysisRequestConfig instance
                         */
                        SentimentAnalysisRequestConfig.create = function create(properties) {
                            return new SentimentAnalysisRequestConfig(properties);
                        };
    
                        /**
                         * Encodes the specified SentimentAnalysisRequestConfig message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SentimentAnalysisRequestConfig.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.SentimentAnalysisRequestConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISentimentAnalysisRequestConfig} message SentimentAnalysisRequestConfig message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SentimentAnalysisRequestConfig.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.analyzeQueryTextSentiment != null && Object.hasOwnProperty.call(message, "analyzeQueryTextSentiment"))
                                writer.uint32(/* id 1, wireType 0 =*/8).bool(message.analyzeQueryTextSentiment);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SentimentAnalysisRequestConfig message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SentimentAnalysisRequestConfig.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SentimentAnalysisRequestConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISentimentAnalysisRequestConfig} message SentimentAnalysisRequestConfig message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SentimentAnalysisRequestConfig.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SentimentAnalysisRequestConfig message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.SentimentAnalysisRequestConfig
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.SentimentAnalysisRequestConfig} SentimentAnalysisRequestConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SentimentAnalysisRequestConfig.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.SentimentAnalysisRequestConfig();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.analyzeQueryTextSentiment = reader.bool();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SentimentAnalysisRequestConfig message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SentimentAnalysisRequestConfig
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.SentimentAnalysisRequestConfig} SentimentAnalysisRequestConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SentimentAnalysisRequestConfig.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SentimentAnalysisRequestConfig message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.SentimentAnalysisRequestConfig
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SentimentAnalysisRequestConfig.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.analyzeQueryTextSentiment != null && message.hasOwnProperty("analyzeQueryTextSentiment"))
                                if (typeof message.analyzeQueryTextSentiment !== "boolean")
                                    return "analyzeQueryTextSentiment: boolean expected";
                            return null;
                        };
    
                        /**
                         * Creates a SentimentAnalysisRequestConfig message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.SentimentAnalysisRequestConfig
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.SentimentAnalysisRequestConfig} SentimentAnalysisRequestConfig
                         */
                        SentimentAnalysisRequestConfig.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.SentimentAnalysisRequestConfig)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.SentimentAnalysisRequestConfig();
                            if (object.analyzeQueryTextSentiment != null)
                                message.analyzeQueryTextSentiment = Boolean(object.analyzeQueryTextSentiment);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SentimentAnalysisRequestConfig message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.SentimentAnalysisRequestConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.SentimentAnalysisRequestConfig} message SentimentAnalysisRequestConfig
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SentimentAnalysisRequestConfig.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.analyzeQueryTextSentiment = false;
                            if (message.analyzeQueryTextSentiment != null && message.hasOwnProperty("analyzeQueryTextSentiment"))
                                object.analyzeQueryTextSentiment = message.analyzeQueryTextSentiment;
                            return object;
                        };
    
                        /**
                         * Converts this SentimentAnalysisRequestConfig to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.SentimentAnalysisRequestConfig
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SentimentAnalysisRequestConfig.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SentimentAnalysisRequestConfig
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.SentimentAnalysisRequestConfig
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SentimentAnalysisRequestConfig.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.SentimentAnalysisRequestConfig";
                        };
    
                        return SentimentAnalysisRequestConfig;
                    })();
    
                    v2beta1.SentimentAnalysisResult = (function() {
    
                        /**
                         * Properties of a SentimentAnalysisResult.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ISentimentAnalysisResult
                         * @property {google.cloud.dialogflow.v2beta1.ISentiment|null} [queryTextSentiment] SentimentAnalysisResult queryTextSentiment
                         */
    
                        /**
                         * Constructs a new SentimentAnalysisResult.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a SentimentAnalysisResult.
                         * @implements ISentimentAnalysisResult
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ISentimentAnalysisResult=} [properties] Properties to set
                         */
                        function SentimentAnalysisResult(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SentimentAnalysisResult queryTextSentiment.
                         * @member {google.cloud.dialogflow.v2beta1.ISentiment|null|undefined} queryTextSentiment
                         * @memberof google.cloud.dialogflow.v2beta1.SentimentAnalysisResult
                         * @instance
                         */
                        SentimentAnalysisResult.prototype.queryTextSentiment = null;
    
                        /**
                         * Creates a new SentimentAnalysisResult instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.SentimentAnalysisResult
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISentimentAnalysisResult=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.SentimentAnalysisResult} SentimentAnalysisResult instance
                         */
                        SentimentAnalysisResult.create = function create(properties) {
                            return new SentimentAnalysisResult(properties);
                        };
    
                        /**
                         * Encodes the specified SentimentAnalysisResult message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SentimentAnalysisResult.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.SentimentAnalysisResult
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISentimentAnalysisResult} message SentimentAnalysisResult message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SentimentAnalysisResult.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.queryTextSentiment != null && Object.hasOwnProperty.call(message, "queryTextSentiment"))
                                $root.google.cloud.dialogflow.v2beta1.Sentiment.encode(message.queryTextSentiment, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SentimentAnalysisResult message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SentimentAnalysisResult.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SentimentAnalysisResult
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISentimentAnalysisResult} message SentimentAnalysisResult message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SentimentAnalysisResult.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SentimentAnalysisResult message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.SentimentAnalysisResult
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.SentimentAnalysisResult} SentimentAnalysisResult
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SentimentAnalysisResult.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.SentimentAnalysisResult();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.queryTextSentiment = $root.google.cloud.dialogflow.v2beta1.Sentiment.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SentimentAnalysisResult message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SentimentAnalysisResult
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.SentimentAnalysisResult} SentimentAnalysisResult
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SentimentAnalysisResult.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SentimentAnalysisResult message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.SentimentAnalysisResult
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SentimentAnalysisResult.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.queryTextSentiment != null && message.hasOwnProperty("queryTextSentiment")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.Sentiment.verify(message.queryTextSentiment);
                                if (error)
                                    return "queryTextSentiment." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a SentimentAnalysisResult message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.SentimentAnalysisResult
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.SentimentAnalysisResult} SentimentAnalysisResult
                         */
                        SentimentAnalysisResult.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.SentimentAnalysisResult)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.SentimentAnalysisResult();
                            if (object.queryTextSentiment != null) {
                                if (typeof object.queryTextSentiment !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.SentimentAnalysisResult.queryTextSentiment: object expected");
                                message.queryTextSentiment = $root.google.cloud.dialogflow.v2beta1.Sentiment.fromObject(object.queryTextSentiment);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SentimentAnalysisResult message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.SentimentAnalysisResult
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.SentimentAnalysisResult} message SentimentAnalysisResult
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SentimentAnalysisResult.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.queryTextSentiment = null;
                            if (message.queryTextSentiment != null && message.hasOwnProperty("queryTextSentiment"))
                                object.queryTextSentiment = $root.google.cloud.dialogflow.v2beta1.Sentiment.toObject(message.queryTextSentiment, options);
                            return object;
                        };
    
                        /**
                         * Converts this SentimentAnalysisResult to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.SentimentAnalysisResult
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SentimentAnalysisResult.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SentimentAnalysisResult
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.SentimentAnalysisResult
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SentimentAnalysisResult.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.SentimentAnalysisResult";
                        };
    
                        return SentimentAnalysisResult;
                    })();
    
                    v2beta1.Sentiment = (function() {
    
                        /**
                         * Properties of a Sentiment.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ISentiment
                         * @property {number|null} [score] Sentiment score
                         * @property {number|null} [magnitude] Sentiment magnitude
                         */
    
                        /**
                         * Constructs a new Sentiment.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a Sentiment.
                         * @implements ISentiment
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ISentiment=} [properties] Properties to set
                         */
                        function Sentiment(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * Sentiment score.
                         * @member {number} score
                         * @memberof google.cloud.dialogflow.v2beta1.Sentiment
                         * @instance
                         */
                        Sentiment.prototype.score = 0;
    
                        /**
                         * Sentiment magnitude.
                         * @member {number} magnitude
                         * @memberof google.cloud.dialogflow.v2beta1.Sentiment
                         * @instance
                         */
                        Sentiment.prototype.magnitude = 0;
    
                        /**
                         * Creates a new Sentiment instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.Sentiment
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISentiment=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.Sentiment} Sentiment instance
                         */
                        Sentiment.create = function create(properties) {
                            return new Sentiment(properties);
                        };
    
                        /**
                         * Encodes the specified Sentiment message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Sentiment.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.Sentiment
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISentiment} message Sentiment message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        Sentiment.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.score != null && Object.hasOwnProperty.call(message, "score"))
                                writer.uint32(/* id 1, wireType 5 =*/13).float(message.score);
                            if (message.magnitude != null && Object.hasOwnProperty.call(message, "magnitude"))
                                writer.uint32(/* id 2, wireType 5 =*/21).float(message.magnitude);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified Sentiment message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Sentiment.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.Sentiment
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISentiment} message Sentiment message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        Sentiment.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a Sentiment message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.Sentiment
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.Sentiment} Sentiment
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        Sentiment.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Sentiment();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.score = reader.float();
                                        break;
                                    }
                                case 2: {
                                        message.magnitude = reader.float();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a Sentiment message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.Sentiment
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.Sentiment} Sentiment
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        Sentiment.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a Sentiment message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.Sentiment
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        Sentiment.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.score != null && message.hasOwnProperty("score"))
                                if (typeof message.score !== "number")
                                    return "score: number expected";
                            if (message.magnitude != null && message.hasOwnProperty("magnitude"))
                                if (typeof message.magnitude !== "number")
                                    return "magnitude: number expected";
                            return null;
                        };
    
                        /**
                         * Creates a Sentiment message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.Sentiment
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.Sentiment} Sentiment
                         */
                        Sentiment.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.Sentiment)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.Sentiment();
                            if (object.score != null)
                                message.score = Number(object.score);
                            if (object.magnitude != null)
                                message.magnitude = Number(object.magnitude);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a Sentiment message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.Sentiment
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.Sentiment} message Sentiment
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        Sentiment.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.score = 0;
                                object.magnitude = 0;
                            }
                            if (message.score != null && message.hasOwnProperty("score"))
                                object.score = options.json && !isFinite(message.score) ? String(message.score) : message.score;
                            if (message.magnitude != null && message.hasOwnProperty("magnitude"))
                                object.magnitude = options.json && !isFinite(message.magnitude) ? String(message.magnitude) : message.magnitude;
                            return object;
                        };
    
                        /**
                         * Converts this Sentiment to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.Sentiment
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        Sentiment.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for Sentiment
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.Sentiment
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        Sentiment.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Sentiment";
                        };
    
                        return Sentiment;
                    })();
    
                    v2beta1.Contexts = (function() {
    
                        /**
                         * Constructs a new Contexts service.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a Contexts
                         * @extends $protobuf.rpc.Service
                         * @constructor
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         */
                        function Contexts(rpcImpl, requestDelimited, responseDelimited) {
                            $protobuf.rpc.Service.call(this, rpcImpl, requestDelimited, responseDelimited);
                        }
    
                        (Contexts.prototype = Object.create($protobuf.rpc.Service.prototype)).constructor = Contexts;
    
                        /**
                         * Creates new Contexts service using the specified rpc implementation.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.Contexts
                         * @static
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         * @returns {Contexts} RPC service. Useful where requests and/or responses are streamed.
                         */
                        Contexts.create = function create(rpcImpl, requestDelimited, responseDelimited) {
                            return new this(rpcImpl, requestDelimited, responseDelimited);
                        };
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Contexts|listContexts}.
                         * @memberof google.cloud.dialogflow.v2beta1.Contexts
                         * @typedef ListContextsCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.ListContextsResponse} [response] ListContextsResponse
                         */
    
                        /**
                         * Calls ListContexts.
                         * @function listContexts
                         * @memberof google.cloud.dialogflow.v2beta1.Contexts
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IListContextsRequest} request ListContextsRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Contexts.ListContextsCallback} callback Node-style callback called with the error, if any, and ListContextsResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Contexts.prototype.listContexts = function listContexts(request, callback) {
                            return this.rpcCall(listContexts, $root.google.cloud.dialogflow.v2beta1.ListContextsRequest, $root.google.cloud.dialogflow.v2beta1.ListContextsResponse, request, callback);
                        }, "name", { value: "ListContexts" });
    
                        /**
                         * Calls ListContexts.
                         * @function listContexts
                         * @memberof google.cloud.dialogflow.v2beta1.Contexts
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IListContextsRequest} request ListContextsRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.ListContextsResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Contexts|getContext}.
                         * @memberof google.cloud.dialogflow.v2beta1.Contexts
                         * @typedef GetContextCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.Context} [response] Context
                         */
    
                        /**
                         * Calls GetContext.
                         * @function getContext
                         * @memberof google.cloud.dialogflow.v2beta1.Contexts
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IGetContextRequest} request GetContextRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Contexts.GetContextCallback} callback Node-style callback called with the error, if any, and Context
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Contexts.prototype.getContext = function getContext(request, callback) {
                            return this.rpcCall(getContext, $root.google.cloud.dialogflow.v2beta1.GetContextRequest, $root.google.cloud.dialogflow.v2beta1.Context, request, callback);
                        }, "name", { value: "GetContext" });
    
                        /**
                         * Calls GetContext.
                         * @function getContext
                         * @memberof google.cloud.dialogflow.v2beta1.Contexts
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IGetContextRequest} request GetContextRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.Context>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Contexts|createContext}.
                         * @memberof google.cloud.dialogflow.v2beta1.Contexts
                         * @typedef CreateContextCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.Context} [response] Context
                         */
    
                        /**
                         * Calls CreateContext.
                         * @function createContext
                         * @memberof google.cloud.dialogflow.v2beta1.Contexts
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.ICreateContextRequest} request CreateContextRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Contexts.CreateContextCallback} callback Node-style callback called with the error, if any, and Context
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Contexts.prototype.createContext = function createContext(request, callback) {
                            return this.rpcCall(createContext, $root.google.cloud.dialogflow.v2beta1.CreateContextRequest, $root.google.cloud.dialogflow.v2beta1.Context, request, callback);
                        }, "name", { value: "CreateContext" });
    
                        /**
                         * Calls CreateContext.
                         * @function createContext
                         * @memberof google.cloud.dialogflow.v2beta1.Contexts
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.ICreateContextRequest} request CreateContextRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.Context>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Contexts|updateContext}.
                         * @memberof google.cloud.dialogflow.v2beta1.Contexts
                         * @typedef UpdateContextCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.Context} [response] Context
                         */
    
                        /**
                         * Calls UpdateContext.
                         * @function updateContext
                         * @memberof google.cloud.dialogflow.v2beta1.Contexts
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateContextRequest} request UpdateContextRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Contexts.UpdateContextCallback} callback Node-style callback called with the error, if any, and Context
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Contexts.prototype.updateContext = function updateContext(request, callback) {
                            return this.rpcCall(updateContext, $root.google.cloud.dialogflow.v2beta1.UpdateContextRequest, $root.google.cloud.dialogflow.v2beta1.Context, request, callback);
                        }, "name", { value: "UpdateContext" });
    
                        /**
                         * Calls UpdateContext.
                         * @function updateContext
                         * @memberof google.cloud.dialogflow.v2beta1.Contexts
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateContextRequest} request UpdateContextRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.Context>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Contexts|deleteContext}.
                         * @memberof google.cloud.dialogflow.v2beta1.Contexts
                         * @typedef DeleteContextCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.protobuf.Empty} [response] Empty
                         */
    
                        /**
                         * Calls DeleteContext.
                         * @function deleteContext
                         * @memberof google.cloud.dialogflow.v2beta1.Contexts
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteContextRequest} request DeleteContextRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Contexts.DeleteContextCallback} callback Node-style callback called with the error, if any, and Empty
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Contexts.prototype.deleteContext = function deleteContext(request, callback) {
                            return this.rpcCall(deleteContext, $root.google.cloud.dialogflow.v2beta1.DeleteContextRequest, $root.google.protobuf.Empty, request, callback);
                        }, "name", { value: "DeleteContext" });
    
                        /**
                         * Calls DeleteContext.
                         * @function deleteContext
                         * @memberof google.cloud.dialogflow.v2beta1.Contexts
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteContextRequest} request DeleteContextRequest message or plain object
                         * @returns {Promise<google.protobuf.Empty>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Contexts|deleteAllContexts}.
                         * @memberof google.cloud.dialogflow.v2beta1.Contexts
                         * @typedef DeleteAllContextsCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.protobuf.Empty} [response] Empty
                         */
    
                        /**
                         * Calls DeleteAllContexts.
                         * @function deleteAllContexts
                         * @memberof google.cloud.dialogflow.v2beta1.Contexts
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteAllContextsRequest} request DeleteAllContextsRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Contexts.DeleteAllContextsCallback} callback Node-style callback called with the error, if any, and Empty
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Contexts.prototype.deleteAllContexts = function deleteAllContexts(request, callback) {
                            return this.rpcCall(deleteAllContexts, $root.google.cloud.dialogflow.v2beta1.DeleteAllContextsRequest, $root.google.protobuf.Empty, request, callback);
                        }, "name", { value: "DeleteAllContexts" });
    
                        /**
                         * Calls DeleteAllContexts.
                         * @function deleteAllContexts
                         * @memberof google.cloud.dialogflow.v2beta1.Contexts
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteAllContextsRequest} request DeleteAllContextsRequest message or plain object
                         * @returns {Promise<google.protobuf.Empty>} Promise
                         * @variation 2
                         */
    
                        return Contexts;
                    })();
    
                    v2beta1.Context = (function() {
    
                        /**
                         * Properties of a Context.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IContext
                         * @property {string|null} [name] Context name
                         * @property {number|null} [lifespanCount] Context lifespanCount
                         * @property {google.protobuf.IStruct|null} [parameters] Context parameters
                         */
    
                        /**
                         * Constructs a new Context.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a Context.
                         * @implements IContext
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IContext=} [properties] Properties to set
                         */
                        function Context(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * Context name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2beta1.Context
                         * @instance
                         */
                        Context.prototype.name = "";
    
                        /**
                         * Context lifespanCount.
                         * @member {number} lifespanCount
                         * @memberof google.cloud.dialogflow.v2beta1.Context
                         * @instance
                         */
                        Context.prototype.lifespanCount = 0;
    
                        /**
                         * Context parameters.
                         * @member {google.protobuf.IStruct|null|undefined} parameters
                         * @memberof google.cloud.dialogflow.v2beta1.Context
                         * @instance
                         */
                        Context.prototype.parameters = null;
    
                        /**
                         * Creates a new Context instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.Context
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IContext=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.Context} Context instance
                         */
                        Context.create = function create(properties) {
                            return new Context(properties);
                        };
    
                        /**
                         * Encodes the specified Context message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Context.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.Context
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IContext} message Context message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        Context.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            if (message.lifespanCount != null && Object.hasOwnProperty.call(message, "lifespanCount"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.lifespanCount);
                            if (message.parameters != null && Object.hasOwnProperty.call(message, "parameters"))
                                $root.google.protobuf.Struct.encode(message.parameters, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified Context message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Context.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.Context
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IContext} message Context message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        Context.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a Context message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.Context
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.Context} Context
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        Context.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Context();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.lifespanCount = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.parameters = $root.google.protobuf.Struct.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a Context message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.Context
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.Context} Context
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        Context.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a Context message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.Context
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        Context.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            if (message.lifespanCount != null && message.hasOwnProperty("lifespanCount"))
                                if (!$util.isInteger(message.lifespanCount))
                                    return "lifespanCount: integer expected";
                            if (message.parameters != null && message.hasOwnProperty("parameters")) {
                                var error = $root.google.protobuf.Struct.verify(message.parameters);
                                if (error)
                                    return "parameters." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a Context message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.Context
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.Context} Context
                         */
                        Context.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.Context)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.Context();
                            if (object.name != null)
                                message.name = String(object.name);
                            if (object.lifespanCount != null)
                                message.lifespanCount = object.lifespanCount | 0;
                            if (object.parameters != null) {
                                if (typeof object.parameters !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.Context.parameters: object expected");
                                message.parameters = $root.google.protobuf.Struct.fromObject(object.parameters);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a Context message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.Context
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.Context} message Context
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        Context.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.name = "";
                                object.lifespanCount = 0;
                                object.parameters = null;
                            }
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            if (message.lifespanCount != null && message.hasOwnProperty("lifespanCount"))
                                object.lifespanCount = message.lifespanCount;
                            if (message.parameters != null && message.hasOwnProperty("parameters"))
                                object.parameters = $root.google.protobuf.Struct.toObject(message.parameters, options);
                            return object;
                        };
    
                        /**
                         * Converts this Context to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.Context
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        Context.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for Context
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.Context
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        Context.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Context";
                        };
    
                        return Context;
                    })();
    
                    v2beta1.ListContextsRequest = (function() {
    
                        /**
                         * Properties of a ListContextsRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IListContextsRequest
                         * @property {string|null} [parent] ListContextsRequest parent
                         * @property {number|null} [pageSize] ListContextsRequest pageSize
                         * @property {string|null} [pageToken] ListContextsRequest pageToken
                         */
    
                        /**
                         * Constructs a new ListContextsRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a ListContextsRequest.
                         * @implements IListContextsRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IListContextsRequest=} [properties] Properties to set
                         */
                        function ListContextsRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListContextsRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.ListContextsRequest
                         * @instance
                         */
                        ListContextsRequest.prototype.parent = "";
    
                        /**
                         * ListContextsRequest pageSize.
                         * @member {number} pageSize
                         * @memberof google.cloud.dialogflow.v2beta1.ListContextsRequest
                         * @instance
                         */
                        ListContextsRequest.prototype.pageSize = 0;
    
                        /**
                         * ListContextsRequest pageToken.
                         * @member {string} pageToken
                         * @memberof google.cloud.dialogflow.v2beta1.ListContextsRequest
                         * @instance
                         */
                        ListContextsRequest.prototype.pageToken = "";
    
                        /**
                         * Creates a new ListContextsRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.ListContextsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListContextsRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.ListContextsRequest} ListContextsRequest instance
                         */
                        ListContextsRequest.create = function create(properties) {
                            return new ListContextsRequest(properties);
                        };
    
                        /**
                         * Encodes the specified ListContextsRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListContextsRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.ListContextsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListContextsRequest} message ListContextsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListContextsRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.pageSize != null && Object.hasOwnProperty.call(message, "pageSize"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.pageSize);
                            if (message.pageToken != null && Object.hasOwnProperty.call(message, "pageToken"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.pageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListContextsRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListContextsRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListContextsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListContextsRequest} message ListContextsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListContextsRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListContextsRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.ListContextsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.ListContextsRequest} ListContextsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListContextsRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ListContextsRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.pageSize = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.pageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListContextsRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListContextsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.ListContextsRequest} ListContextsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListContextsRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListContextsRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.ListContextsRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListContextsRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                if (!$util.isInteger(message.pageSize))
                                    return "pageSize: integer expected";
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                if (!$util.isString(message.pageToken))
                                    return "pageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListContextsRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListContextsRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.ListContextsRequest} ListContextsRequest
                         */
                        ListContextsRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.ListContextsRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.ListContextsRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.pageSize != null)
                                message.pageSize = object.pageSize | 0;
                            if (object.pageToken != null)
                                message.pageToken = String(object.pageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListContextsRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListContextsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ListContextsRequest} message ListContextsRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListContextsRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.pageSize = 0;
                                object.pageToken = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                object.pageSize = message.pageSize;
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                object.pageToken = message.pageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListContextsRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.ListContextsRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListContextsRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListContextsRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.ListContextsRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListContextsRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ListContextsRequest";
                        };
    
                        return ListContextsRequest;
                    })();
    
                    v2beta1.ListContextsResponse = (function() {
    
                        /**
                         * Properties of a ListContextsResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IListContextsResponse
                         * @property {Array.<google.cloud.dialogflow.v2beta1.IContext>|null} [contexts] ListContextsResponse contexts
                         * @property {string|null} [nextPageToken] ListContextsResponse nextPageToken
                         */
    
                        /**
                         * Constructs a new ListContextsResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a ListContextsResponse.
                         * @implements IListContextsResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IListContextsResponse=} [properties] Properties to set
                         */
                        function ListContextsResponse(properties) {
                            this.contexts = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListContextsResponse contexts.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.IContext>} contexts
                         * @memberof google.cloud.dialogflow.v2beta1.ListContextsResponse
                         * @instance
                         */
                        ListContextsResponse.prototype.contexts = $util.emptyArray;
    
                        /**
                         * ListContextsResponse nextPageToken.
                         * @member {string} nextPageToken
                         * @memberof google.cloud.dialogflow.v2beta1.ListContextsResponse
                         * @instance
                         */
                        ListContextsResponse.prototype.nextPageToken = "";
    
                        /**
                         * Creates a new ListContextsResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.ListContextsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListContextsResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.ListContextsResponse} ListContextsResponse instance
                         */
                        ListContextsResponse.create = function create(properties) {
                            return new ListContextsResponse(properties);
                        };
    
                        /**
                         * Encodes the specified ListContextsResponse message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListContextsResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.ListContextsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListContextsResponse} message ListContextsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListContextsResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.contexts != null && message.contexts.length)
                                for (var i = 0; i < message.contexts.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.Context.encode(message.contexts[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.nextPageToken != null && Object.hasOwnProperty.call(message, "nextPageToken"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.nextPageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListContextsResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListContextsResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListContextsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListContextsResponse} message ListContextsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListContextsResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListContextsResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.ListContextsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.ListContextsResponse} ListContextsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListContextsResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ListContextsResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.contexts && message.contexts.length))
                                            message.contexts = [];
                                        message.contexts.push($root.google.cloud.dialogflow.v2beta1.Context.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 2: {
                                        message.nextPageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListContextsResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListContextsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.ListContextsResponse} ListContextsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListContextsResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListContextsResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.ListContextsResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListContextsResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.contexts != null && message.hasOwnProperty("contexts")) {
                                if (!Array.isArray(message.contexts))
                                    return "contexts: array expected";
                                for (var i = 0; i < message.contexts.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.Context.verify(message.contexts[i]);
                                    if (error)
                                        return "contexts." + error;
                                }
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                if (!$util.isString(message.nextPageToken))
                                    return "nextPageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListContextsResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListContextsResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.ListContextsResponse} ListContextsResponse
                         */
                        ListContextsResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.ListContextsResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.ListContextsResponse();
                            if (object.contexts) {
                                if (!Array.isArray(object.contexts))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.ListContextsResponse.contexts: array expected");
                                message.contexts = [];
                                for (var i = 0; i < object.contexts.length; ++i) {
                                    if (typeof object.contexts[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.ListContextsResponse.contexts: object expected");
                                    message.contexts[i] = $root.google.cloud.dialogflow.v2beta1.Context.fromObject(object.contexts[i]);
                                }
                            }
                            if (object.nextPageToken != null)
                                message.nextPageToken = String(object.nextPageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListContextsResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListContextsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ListContextsResponse} message ListContextsResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListContextsResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.contexts = [];
                            if (options.defaults)
                                object.nextPageToken = "";
                            if (message.contexts && message.contexts.length) {
                                object.contexts = [];
                                for (var j = 0; j < message.contexts.length; ++j)
                                    object.contexts[j] = $root.google.cloud.dialogflow.v2beta1.Context.toObject(message.contexts[j], options);
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                object.nextPageToken = message.nextPageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListContextsResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.ListContextsResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListContextsResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListContextsResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.ListContextsResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListContextsResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ListContextsResponse";
                        };
    
                        return ListContextsResponse;
                    })();
    
                    v2beta1.GetContextRequest = (function() {
    
                        /**
                         * Properties of a GetContextRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IGetContextRequest
                         * @property {string|null} [name] GetContextRequest name
                         */
    
                        /**
                         * Constructs a new GetContextRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a GetContextRequest.
                         * @implements IGetContextRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IGetContextRequest=} [properties] Properties to set
                         */
                        function GetContextRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GetContextRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2beta1.GetContextRequest
                         * @instance
                         */
                        GetContextRequest.prototype.name = "";
    
                        /**
                         * Creates a new GetContextRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.GetContextRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetContextRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.GetContextRequest} GetContextRequest instance
                         */
                        GetContextRequest.create = function create(properties) {
                            return new GetContextRequest(properties);
                        };
    
                        /**
                         * Encodes the specified GetContextRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GetContextRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.GetContextRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetContextRequest} message GetContextRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetContextRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GetContextRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GetContextRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GetContextRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetContextRequest} message GetContextRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetContextRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GetContextRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.GetContextRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.GetContextRequest} GetContextRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetContextRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.GetContextRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GetContextRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GetContextRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.GetContextRequest} GetContextRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetContextRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GetContextRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.GetContextRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GetContextRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a GetContextRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.GetContextRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.GetContextRequest} GetContextRequest
                         */
                        GetContextRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.GetContextRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.GetContextRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GetContextRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.GetContextRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.GetContextRequest} message GetContextRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GetContextRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.name = "";
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            return object;
                        };
    
                        /**
                         * Converts this GetContextRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.GetContextRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GetContextRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GetContextRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.GetContextRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GetContextRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.GetContextRequest";
                        };
    
                        return GetContextRequest;
                    })();
    
                    v2beta1.CreateContextRequest = (function() {
    
                        /**
                         * Properties of a CreateContextRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ICreateContextRequest
                         * @property {string|null} [parent] CreateContextRequest parent
                         * @property {google.cloud.dialogflow.v2beta1.IContext|null} [context] CreateContextRequest context
                         */
    
                        /**
                         * Constructs a new CreateContextRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a CreateContextRequest.
                         * @implements ICreateContextRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ICreateContextRequest=} [properties] Properties to set
                         */
                        function CreateContextRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * CreateContextRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.CreateContextRequest
                         * @instance
                         */
                        CreateContextRequest.prototype.parent = "";
    
                        /**
                         * CreateContextRequest context.
                         * @member {google.cloud.dialogflow.v2beta1.IContext|null|undefined} context
                         * @memberof google.cloud.dialogflow.v2beta1.CreateContextRequest
                         * @instance
                         */
                        CreateContextRequest.prototype.context = null;
    
                        /**
                         * Creates a new CreateContextRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.CreateContextRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ICreateContextRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.CreateContextRequest} CreateContextRequest instance
                         */
                        CreateContextRequest.create = function create(properties) {
                            return new CreateContextRequest(properties);
                        };
    
                        /**
                         * Encodes the specified CreateContextRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.CreateContextRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.CreateContextRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ICreateContextRequest} message CreateContextRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateContextRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.context != null && Object.hasOwnProperty.call(message, "context"))
                                $root.google.cloud.dialogflow.v2beta1.Context.encode(message.context, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified CreateContextRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.CreateContextRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.CreateContextRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ICreateContextRequest} message CreateContextRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateContextRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a CreateContextRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.CreateContextRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.CreateContextRequest} CreateContextRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateContextRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.CreateContextRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.context = $root.google.cloud.dialogflow.v2beta1.Context.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a CreateContextRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.CreateContextRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.CreateContextRequest} CreateContextRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateContextRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a CreateContextRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.CreateContextRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        CreateContextRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.context != null && message.hasOwnProperty("context")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.Context.verify(message.context);
                                if (error)
                                    return "context." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a CreateContextRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.CreateContextRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.CreateContextRequest} CreateContextRequest
                         */
                        CreateContextRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.CreateContextRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.CreateContextRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.context != null) {
                                if (typeof object.context !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.CreateContextRequest.context: object expected");
                                message.context = $root.google.cloud.dialogflow.v2beta1.Context.fromObject(object.context);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a CreateContextRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.CreateContextRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.CreateContextRequest} message CreateContextRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        CreateContextRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.context = null;
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.context != null && message.hasOwnProperty("context"))
                                object.context = $root.google.cloud.dialogflow.v2beta1.Context.toObject(message.context, options);
                            return object;
                        };
    
                        /**
                         * Converts this CreateContextRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.CreateContextRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        CreateContextRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for CreateContextRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.CreateContextRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        CreateContextRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.CreateContextRequest";
                        };
    
                        return CreateContextRequest;
                    })();
    
                    v2beta1.UpdateContextRequest = (function() {
    
                        /**
                         * Properties of an UpdateContextRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IUpdateContextRequest
                         * @property {google.cloud.dialogflow.v2beta1.IContext|null} [context] UpdateContextRequest context
                         * @property {google.protobuf.IFieldMask|null} [updateMask] UpdateContextRequest updateMask
                         */
    
                        /**
                         * Constructs a new UpdateContextRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an UpdateContextRequest.
                         * @implements IUpdateContextRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateContextRequest=} [properties] Properties to set
                         */
                        function UpdateContextRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * UpdateContextRequest context.
                         * @member {google.cloud.dialogflow.v2beta1.IContext|null|undefined} context
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateContextRequest
                         * @instance
                         */
                        UpdateContextRequest.prototype.context = null;
    
                        /**
                         * UpdateContextRequest updateMask.
                         * @member {google.protobuf.IFieldMask|null|undefined} updateMask
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateContextRequest
                         * @instance
                         */
                        UpdateContextRequest.prototype.updateMask = null;
    
                        /**
                         * Creates a new UpdateContextRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateContextRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateContextRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.UpdateContextRequest} UpdateContextRequest instance
                         */
                        UpdateContextRequest.create = function create(properties) {
                            return new UpdateContextRequest(properties);
                        };
    
                        /**
                         * Encodes the specified UpdateContextRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.UpdateContextRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateContextRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateContextRequest} message UpdateContextRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UpdateContextRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.context != null && Object.hasOwnProperty.call(message, "context"))
                                $root.google.cloud.dialogflow.v2beta1.Context.encode(message.context, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.updateMask != null && Object.hasOwnProperty.call(message, "updateMask"))
                                $root.google.protobuf.FieldMask.encode(message.updateMask, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified UpdateContextRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.UpdateContextRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateContextRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateContextRequest} message UpdateContextRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UpdateContextRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an UpdateContextRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateContextRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.UpdateContextRequest} UpdateContextRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UpdateContextRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.UpdateContextRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.context = $root.google.cloud.dialogflow.v2beta1.Context.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.updateMask = $root.google.protobuf.FieldMask.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an UpdateContextRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateContextRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.UpdateContextRequest} UpdateContextRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UpdateContextRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an UpdateContextRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateContextRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        UpdateContextRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.context != null && message.hasOwnProperty("context")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.Context.verify(message.context);
                                if (error)
                                    return "context." + error;
                            }
                            if (message.updateMask != null && message.hasOwnProperty("updateMask")) {
                                var error = $root.google.protobuf.FieldMask.verify(message.updateMask);
                                if (error)
                                    return "updateMask." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates an UpdateContextRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateContextRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.UpdateContextRequest} UpdateContextRequest
                         */
                        UpdateContextRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.UpdateContextRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.UpdateContextRequest();
                            if (object.context != null) {
                                if (typeof object.context !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.UpdateContextRequest.context: object expected");
                                message.context = $root.google.cloud.dialogflow.v2beta1.Context.fromObject(object.context);
                            }
                            if (object.updateMask != null) {
                                if (typeof object.updateMask !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.UpdateContextRequest.updateMask: object expected");
                                message.updateMask = $root.google.protobuf.FieldMask.fromObject(object.updateMask);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an UpdateContextRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateContextRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.UpdateContextRequest} message UpdateContextRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        UpdateContextRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.context = null;
                                object.updateMask = null;
                            }
                            if (message.context != null && message.hasOwnProperty("context"))
                                object.context = $root.google.cloud.dialogflow.v2beta1.Context.toObject(message.context, options);
                            if (message.updateMask != null && message.hasOwnProperty("updateMask"))
                                object.updateMask = $root.google.protobuf.FieldMask.toObject(message.updateMask, options);
                            return object;
                        };
    
                        /**
                         * Converts this UpdateContextRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateContextRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        UpdateContextRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for UpdateContextRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateContextRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        UpdateContextRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.UpdateContextRequest";
                        };
    
                        return UpdateContextRequest;
                    })();
    
                    v2beta1.DeleteContextRequest = (function() {
    
                        /**
                         * Properties of a DeleteContextRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IDeleteContextRequest
                         * @property {string|null} [name] DeleteContextRequest name
                         */
    
                        /**
                         * Constructs a new DeleteContextRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a DeleteContextRequest.
                         * @implements IDeleteContextRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteContextRequest=} [properties] Properties to set
                         */
                        function DeleteContextRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * DeleteContextRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteContextRequest
                         * @instance
                         */
                        DeleteContextRequest.prototype.name = "";
    
                        /**
                         * Creates a new DeleteContextRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteContextRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteContextRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.DeleteContextRequest} DeleteContextRequest instance
                         */
                        DeleteContextRequest.create = function create(properties) {
                            return new DeleteContextRequest(properties);
                        };
    
                        /**
                         * Encodes the specified DeleteContextRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.DeleteContextRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteContextRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteContextRequest} message DeleteContextRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteContextRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified DeleteContextRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.DeleteContextRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteContextRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteContextRequest} message DeleteContextRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteContextRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a DeleteContextRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteContextRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.DeleteContextRequest} DeleteContextRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteContextRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.DeleteContextRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a DeleteContextRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteContextRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.DeleteContextRequest} DeleteContextRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteContextRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a DeleteContextRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteContextRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        DeleteContextRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a DeleteContextRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteContextRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.DeleteContextRequest} DeleteContextRequest
                         */
                        DeleteContextRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.DeleteContextRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.DeleteContextRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a DeleteContextRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteContextRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.DeleteContextRequest} message DeleteContextRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        DeleteContextRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.name = "";
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            return object;
                        };
    
                        /**
                         * Converts this DeleteContextRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteContextRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        DeleteContextRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for DeleteContextRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteContextRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        DeleteContextRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.DeleteContextRequest";
                        };
    
                        return DeleteContextRequest;
                    })();
    
                    v2beta1.DeleteAllContextsRequest = (function() {
    
                        /**
                         * Properties of a DeleteAllContextsRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IDeleteAllContextsRequest
                         * @property {string|null} [parent] DeleteAllContextsRequest parent
                         */
    
                        /**
                         * Constructs a new DeleteAllContextsRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a DeleteAllContextsRequest.
                         * @implements IDeleteAllContextsRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteAllContextsRequest=} [properties] Properties to set
                         */
                        function DeleteAllContextsRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * DeleteAllContextsRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteAllContextsRequest
                         * @instance
                         */
                        DeleteAllContextsRequest.prototype.parent = "";
    
                        /**
                         * Creates a new DeleteAllContextsRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteAllContextsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteAllContextsRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.DeleteAllContextsRequest} DeleteAllContextsRequest instance
                         */
                        DeleteAllContextsRequest.create = function create(properties) {
                            return new DeleteAllContextsRequest(properties);
                        };
    
                        /**
                         * Encodes the specified DeleteAllContextsRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.DeleteAllContextsRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteAllContextsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteAllContextsRequest} message DeleteAllContextsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteAllContextsRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified DeleteAllContextsRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.DeleteAllContextsRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteAllContextsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteAllContextsRequest} message DeleteAllContextsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteAllContextsRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a DeleteAllContextsRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteAllContextsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.DeleteAllContextsRequest} DeleteAllContextsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteAllContextsRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.DeleteAllContextsRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a DeleteAllContextsRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteAllContextsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.DeleteAllContextsRequest} DeleteAllContextsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteAllContextsRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a DeleteAllContextsRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteAllContextsRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        DeleteAllContextsRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a DeleteAllContextsRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteAllContextsRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.DeleteAllContextsRequest} DeleteAllContextsRequest
                         */
                        DeleteAllContextsRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.DeleteAllContextsRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.DeleteAllContextsRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a DeleteAllContextsRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteAllContextsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.DeleteAllContextsRequest} message DeleteAllContextsRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        DeleteAllContextsRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.parent = "";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            return object;
                        };
    
                        /**
                         * Converts this DeleteAllContextsRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteAllContextsRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        DeleteAllContextsRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for DeleteAllContextsRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteAllContextsRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        DeleteAllContextsRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.DeleteAllContextsRequest";
                        };
    
                        return DeleteAllContextsRequest;
                    })();
    
                    v2beta1.Intents = (function() {
    
                        /**
                         * Constructs a new Intents service.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an Intents
                         * @extends $protobuf.rpc.Service
                         * @constructor
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         */
                        function Intents(rpcImpl, requestDelimited, responseDelimited) {
                            $protobuf.rpc.Service.call(this, rpcImpl, requestDelimited, responseDelimited);
                        }
    
                        (Intents.prototype = Object.create($protobuf.rpc.Service.prototype)).constructor = Intents;
    
                        /**
                         * Creates new Intents service using the specified rpc implementation.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.Intents
                         * @static
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         * @returns {Intents} RPC service. Useful where requests and/or responses are streamed.
                         */
                        Intents.create = function create(rpcImpl, requestDelimited, responseDelimited) {
                            return new this(rpcImpl, requestDelimited, responseDelimited);
                        };
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Intents|listIntents}.
                         * @memberof google.cloud.dialogflow.v2beta1.Intents
                         * @typedef ListIntentsCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.ListIntentsResponse} [response] ListIntentsResponse
                         */
    
                        /**
                         * Calls ListIntents.
                         * @function listIntents
                         * @memberof google.cloud.dialogflow.v2beta1.Intents
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IListIntentsRequest} request ListIntentsRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Intents.ListIntentsCallback} callback Node-style callback called with the error, if any, and ListIntentsResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Intents.prototype.listIntents = function listIntents(request, callback) {
                            return this.rpcCall(listIntents, $root.google.cloud.dialogflow.v2beta1.ListIntentsRequest, $root.google.cloud.dialogflow.v2beta1.ListIntentsResponse, request, callback);
                        }, "name", { value: "ListIntents" });
    
                        /**
                         * Calls ListIntents.
                         * @function listIntents
                         * @memberof google.cloud.dialogflow.v2beta1.Intents
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IListIntentsRequest} request ListIntentsRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.ListIntentsResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Intents|getIntent}.
                         * @memberof google.cloud.dialogflow.v2beta1.Intents
                         * @typedef GetIntentCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.Intent} [response] Intent
                         */
    
                        /**
                         * Calls GetIntent.
                         * @function getIntent
                         * @memberof google.cloud.dialogflow.v2beta1.Intents
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IGetIntentRequest} request GetIntentRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Intents.GetIntentCallback} callback Node-style callback called with the error, if any, and Intent
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Intents.prototype.getIntent = function getIntent(request, callback) {
                            return this.rpcCall(getIntent, $root.google.cloud.dialogflow.v2beta1.GetIntentRequest, $root.google.cloud.dialogflow.v2beta1.Intent, request, callback);
                        }, "name", { value: "GetIntent" });
    
                        /**
                         * Calls GetIntent.
                         * @function getIntent
                         * @memberof google.cloud.dialogflow.v2beta1.Intents
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IGetIntentRequest} request GetIntentRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.Intent>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Intents|createIntent}.
                         * @memberof google.cloud.dialogflow.v2beta1.Intents
                         * @typedef CreateIntentCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.Intent} [response] Intent
                         */
    
                        /**
                         * Calls CreateIntent.
                         * @function createIntent
                         * @memberof google.cloud.dialogflow.v2beta1.Intents
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.ICreateIntentRequest} request CreateIntentRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Intents.CreateIntentCallback} callback Node-style callback called with the error, if any, and Intent
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Intents.prototype.createIntent = function createIntent(request, callback) {
                            return this.rpcCall(createIntent, $root.google.cloud.dialogflow.v2beta1.CreateIntentRequest, $root.google.cloud.dialogflow.v2beta1.Intent, request, callback);
                        }, "name", { value: "CreateIntent" });
    
                        /**
                         * Calls CreateIntent.
                         * @function createIntent
                         * @memberof google.cloud.dialogflow.v2beta1.Intents
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.ICreateIntentRequest} request CreateIntentRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.Intent>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Intents|updateIntent}.
                         * @memberof google.cloud.dialogflow.v2beta1.Intents
                         * @typedef UpdateIntentCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.Intent} [response] Intent
                         */
    
                        /**
                         * Calls UpdateIntent.
                         * @function updateIntent
                         * @memberof google.cloud.dialogflow.v2beta1.Intents
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateIntentRequest} request UpdateIntentRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Intents.UpdateIntentCallback} callback Node-style callback called with the error, if any, and Intent
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Intents.prototype.updateIntent = function updateIntent(request, callback) {
                            return this.rpcCall(updateIntent, $root.google.cloud.dialogflow.v2beta1.UpdateIntentRequest, $root.google.cloud.dialogflow.v2beta1.Intent, request, callback);
                        }, "name", { value: "UpdateIntent" });
    
                        /**
                         * Calls UpdateIntent.
                         * @function updateIntent
                         * @memberof google.cloud.dialogflow.v2beta1.Intents
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateIntentRequest} request UpdateIntentRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.Intent>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Intents|deleteIntent}.
                         * @memberof google.cloud.dialogflow.v2beta1.Intents
                         * @typedef DeleteIntentCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.protobuf.Empty} [response] Empty
                         */
    
                        /**
                         * Calls DeleteIntent.
                         * @function deleteIntent
                         * @memberof google.cloud.dialogflow.v2beta1.Intents
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteIntentRequest} request DeleteIntentRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Intents.DeleteIntentCallback} callback Node-style callback called with the error, if any, and Empty
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Intents.prototype.deleteIntent = function deleteIntent(request, callback) {
                            return this.rpcCall(deleteIntent, $root.google.cloud.dialogflow.v2beta1.DeleteIntentRequest, $root.google.protobuf.Empty, request, callback);
                        }, "name", { value: "DeleteIntent" });
    
                        /**
                         * Calls DeleteIntent.
                         * @function deleteIntent
                         * @memberof google.cloud.dialogflow.v2beta1.Intents
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteIntentRequest} request DeleteIntentRequest message or plain object
                         * @returns {Promise<google.protobuf.Empty>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Intents|batchUpdateIntents}.
                         * @memberof google.cloud.dialogflow.v2beta1.Intents
                         * @typedef BatchUpdateIntentsCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.longrunning.Operation} [response] Operation
                         */
    
                        /**
                         * Calls BatchUpdateIntents.
                         * @function batchUpdateIntents
                         * @memberof google.cloud.dialogflow.v2beta1.Intents
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IBatchUpdateIntentsRequest} request BatchUpdateIntentsRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Intents.BatchUpdateIntentsCallback} callback Node-style callback called with the error, if any, and Operation
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Intents.prototype.batchUpdateIntents = function batchUpdateIntents(request, callback) {
                            return this.rpcCall(batchUpdateIntents, $root.google.cloud.dialogflow.v2beta1.BatchUpdateIntentsRequest, $root.google.longrunning.Operation, request, callback);
                        }, "name", { value: "BatchUpdateIntents" });
    
                        /**
                         * Calls BatchUpdateIntents.
                         * @function batchUpdateIntents
                         * @memberof google.cloud.dialogflow.v2beta1.Intents
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IBatchUpdateIntentsRequest} request BatchUpdateIntentsRequest message or plain object
                         * @returns {Promise<google.longrunning.Operation>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Intents|batchDeleteIntents}.
                         * @memberof google.cloud.dialogflow.v2beta1.Intents
                         * @typedef BatchDeleteIntentsCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.longrunning.Operation} [response] Operation
                         */
    
                        /**
                         * Calls BatchDeleteIntents.
                         * @function batchDeleteIntents
                         * @memberof google.cloud.dialogflow.v2beta1.Intents
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IBatchDeleteIntentsRequest} request BatchDeleteIntentsRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Intents.BatchDeleteIntentsCallback} callback Node-style callback called with the error, if any, and Operation
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Intents.prototype.batchDeleteIntents = function batchDeleteIntents(request, callback) {
                            return this.rpcCall(batchDeleteIntents, $root.google.cloud.dialogflow.v2beta1.BatchDeleteIntentsRequest, $root.google.longrunning.Operation, request, callback);
                        }, "name", { value: "BatchDeleteIntents" });
    
                        /**
                         * Calls BatchDeleteIntents.
                         * @function batchDeleteIntents
                         * @memberof google.cloud.dialogflow.v2beta1.Intents
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IBatchDeleteIntentsRequest} request BatchDeleteIntentsRequest message or plain object
                         * @returns {Promise<google.longrunning.Operation>} Promise
                         * @variation 2
                         */
    
                        return Intents;
                    })();
    
                    v2beta1.Intent = (function() {
    
                        /**
                         * Properties of an Intent.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IIntent
                         * @property {string|null} [name] Intent name
                         * @property {string|null} [displayName] Intent displayName
                         * @property {google.cloud.dialogflow.v2beta1.Intent.WebhookState|null} [webhookState] Intent webhookState
                         * @property {number|null} [priority] Intent priority
                         * @property {boolean|null} [isFallback] Intent isFallback
                         * @property {boolean|null} [mlEnabled] Intent mlEnabled
                         * @property {boolean|null} [mlDisabled] Intent mlDisabled
                         * @property {boolean|null} [liveAgentHandoff] Intent liveAgentHandoff
                         * @property {boolean|null} [endInteraction] Intent endInteraction
                         * @property {Array.<string>|null} [inputContextNames] Intent inputContextNames
                         * @property {Array.<string>|null} [events] Intent events
                         * @property {Array.<google.cloud.dialogflow.v2beta1.Intent.ITrainingPhrase>|null} [trainingPhrases] Intent trainingPhrases
                         * @property {string|null} [action] Intent action
                         * @property {Array.<google.cloud.dialogflow.v2beta1.IContext>|null} [outputContexts] Intent outputContexts
                         * @property {boolean|null} [resetContexts] Intent resetContexts
                         * @property {Array.<google.cloud.dialogflow.v2beta1.Intent.IParameter>|null} [parameters] Intent parameters
                         * @property {Array.<google.cloud.dialogflow.v2beta1.Intent.IMessage>|null} [messages] Intent messages
                         * @property {Array.<google.cloud.dialogflow.v2beta1.Intent.Message.Platform>|null} [defaultResponsePlatforms] Intent defaultResponsePlatforms
                         * @property {string|null} [rootFollowupIntentName] Intent rootFollowupIntentName
                         * @property {string|null} [parentFollowupIntentName] Intent parentFollowupIntentName
                         * @property {Array.<google.cloud.dialogflow.v2beta1.Intent.IFollowupIntentInfo>|null} [followupIntentInfo] Intent followupIntentInfo
                         */
    
                        /**
                         * Constructs a new Intent.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an Intent.
                         * @implements IIntent
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IIntent=} [properties] Properties to set
                         */
                        function Intent(properties) {
                            this.inputContextNames = [];
                            this.events = [];
                            this.trainingPhrases = [];
                            this.outputContexts = [];
                            this.parameters = [];
                            this.messages = [];
                            this.defaultResponsePlatforms = [];
                            this.followupIntentInfo = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * Intent name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2beta1.Intent
                         * @instance
                         */
                        Intent.prototype.name = "";
    
                        /**
                         * Intent displayName.
                         * @member {string} displayName
                         * @memberof google.cloud.dialogflow.v2beta1.Intent
                         * @instance
                         */
                        Intent.prototype.displayName = "";
    
                        /**
                         * Intent webhookState.
                         * @member {google.cloud.dialogflow.v2beta1.Intent.WebhookState} webhookState
                         * @memberof google.cloud.dialogflow.v2beta1.Intent
                         * @instance
                         */
                        Intent.prototype.webhookState = 0;
    
                        /**
                         * Intent priority.
                         * @member {number} priority
                         * @memberof google.cloud.dialogflow.v2beta1.Intent
                         * @instance
                         */
                        Intent.prototype.priority = 0;
    
                        /**
                         * Intent isFallback.
                         * @member {boolean} isFallback
                         * @memberof google.cloud.dialogflow.v2beta1.Intent
                         * @instance
                         */
                        Intent.prototype.isFallback = false;
    
                        /**
                         * Intent mlEnabled.
                         * @member {boolean} mlEnabled
                         * @memberof google.cloud.dialogflow.v2beta1.Intent
                         * @instance
                         */
                        Intent.prototype.mlEnabled = false;
    
                        /**
                         * Intent mlDisabled.
                         * @member {boolean} mlDisabled
                         * @memberof google.cloud.dialogflow.v2beta1.Intent
                         * @instance
                         */
                        Intent.prototype.mlDisabled = false;
    
                        /**
                         * Intent liveAgentHandoff.
                         * @member {boolean} liveAgentHandoff
                         * @memberof google.cloud.dialogflow.v2beta1.Intent
                         * @instance
                         */
                        Intent.prototype.liveAgentHandoff = false;
    
                        /**
                         * Intent endInteraction.
                         * @member {boolean} endInteraction
                         * @memberof google.cloud.dialogflow.v2beta1.Intent
                         * @instance
                         */
                        Intent.prototype.endInteraction = false;
    
                        /**
                         * Intent inputContextNames.
                         * @member {Array.<string>} inputContextNames
                         * @memberof google.cloud.dialogflow.v2beta1.Intent
                         * @instance
                         */
                        Intent.prototype.inputContextNames = $util.emptyArray;
    
                        /**
                         * Intent events.
                         * @member {Array.<string>} events
                         * @memberof google.cloud.dialogflow.v2beta1.Intent
                         * @instance
                         */
                        Intent.prototype.events = $util.emptyArray;
    
                        /**
                         * Intent trainingPhrases.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.Intent.ITrainingPhrase>} trainingPhrases
                         * @memberof google.cloud.dialogflow.v2beta1.Intent
                         * @instance
                         */
                        Intent.prototype.trainingPhrases = $util.emptyArray;
    
                        /**
                         * Intent action.
                         * @member {string} action
                         * @memberof google.cloud.dialogflow.v2beta1.Intent
                         * @instance
                         */
                        Intent.prototype.action = "";
    
                        /**
                         * Intent outputContexts.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.IContext>} outputContexts
                         * @memberof google.cloud.dialogflow.v2beta1.Intent
                         * @instance
                         */
                        Intent.prototype.outputContexts = $util.emptyArray;
    
                        /**
                         * Intent resetContexts.
                         * @member {boolean} resetContexts
                         * @memberof google.cloud.dialogflow.v2beta1.Intent
                         * @instance
                         */
                        Intent.prototype.resetContexts = false;
    
                        /**
                         * Intent parameters.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.Intent.IParameter>} parameters
                         * @memberof google.cloud.dialogflow.v2beta1.Intent
                         * @instance
                         */
                        Intent.prototype.parameters = $util.emptyArray;
    
                        /**
                         * Intent messages.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.Intent.IMessage>} messages
                         * @memberof google.cloud.dialogflow.v2beta1.Intent
                         * @instance
                         */
                        Intent.prototype.messages = $util.emptyArray;
    
                        /**
                         * Intent defaultResponsePlatforms.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.Intent.Message.Platform>} defaultResponsePlatforms
                         * @memberof google.cloud.dialogflow.v2beta1.Intent
                         * @instance
                         */
                        Intent.prototype.defaultResponsePlatforms = $util.emptyArray;
    
                        /**
                         * Intent rootFollowupIntentName.
                         * @member {string} rootFollowupIntentName
                         * @memberof google.cloud.dialogflow.v2beta1.Intent
                         * @instance
                         */
                        Intent.prototype.rootFollowupIntentName = "";
    
                        /**
                         * Intent parentFollowupIntentName.
                         * @member {string} parentFollowupIntentName
                         * @memberof google.cloud.dialogflow.v2beta1.Intent
                         * @instance
                         */
                        Intent.prototype.parentFollowupIntentName = "";
    
                        /**
                         * Intent followupIntentInfo.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.Intent.IFollowupIntentInfo>} followupIntentInfo
                         * @memberof google.cloud.dialogflow.v2beta1.Intent
                         * @instance
                         */
                        Intent.prototype.followupIntentInfo = $util.emptyArray;
    
                        /**
                         * Creates a new Intent instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.Intent
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IIntent=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.Intent} Intent instance
                         */
                        Intent.create = function create(properties) {
                            return new Intent(properties);
                        };
    
                        /**
                         * Encodes the specified Intent message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.Intent
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IIntent} message Intent message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        Intent.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            if (message.displayName != null && Object.hasOwnProperty.call(message, "displayName"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.displayName);
                            if (message.priority != null && Object.hasOwnProperty.call(message, "priority"))
                                writer.uint32(/* id 3, wireType 0 =*/24).int32(message.priority);
                            if (message.isFallback != null && Object.hasOwnProperty.call(message, "isFallback"))
                                writer.uint32(/* id 4, wireType 0 =*/32).bool(message.isFallback);
                            if (message.mlEnabled != null && Object.hasOwnProperty.call(message, "mlEnabled"))
                                writer.uint32(/* id 5, wireType 0 =*/40).bool(message.mlEnabled);
                            if (message.webhookState != null && Object.hasOwnProperty.call(message, "webhookState"))
                                writer.uint32(/* id 6, wireType 0 =*/48).int32(message.webhookState);
                            if (message.inputContextNames != null && message.inputContextNames.length)
                                for (var i = 0; i < message.inputContextNames.length; ++i)
                                    writer.uint32(/* id 7, wireType 2 =*/58).string(message.inputContextNames[i]);
                            if (message.events != null && message.events.length)
                                for (var i = 0; i < message.events.length; ++i)
                                    writer.uint32(/* id 8, wireType 2 =*/66).string(message.events[i]);
                            if (message.trainingPhrases != null && message.trainingPhrases.length)
                                for (var i = 0; i < message.trainingPhrases.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.encode(message.trainingPhrases[i], writer.uint32(/* id 9, wireType 2 =*/74).fork()).ldelim();
                            if (message.action != null && Object.hasOwnProperty.call(message, "action"))
                                writer.uint32(/* id 10, wireType 2 =*/82).string(message.action);
                            if (message.outputContexts != null && message.outputContexts.length)
                                for (var i = 0; i < message.outputContexts.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.Context.encode(message.outputContexts[i], writer.uint32(/* id 11, wireType 2 =*/90).fork()).ldelim();
                            if (message.resetContexts != null && Object.hasOwnProperty.call(message, "resetContexts"))
                                writer.uint32(/* id 12, wireType 0 =*/96).bool(message.resetContexts);
                            if (message.parameters != null && message.parameters.length)
                                for (var i = 0; i < message.parameters.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.Intent.Parameter.encode(message.parameters[i], writer.uint32(/* id 13, wireType 2 =*/106).fork()).ldelim();
                            if (message.messages != null && message.messages.length)
                                for (var i = 0; i < message.messages.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.Intent.Message.encode(message.messages[i], writer.uint32(/* id 14, wireType 2 =*/114).fork()).ldelim();
                            if (message.defaultResponsePlatforms != null && message.defaultResponsePlatforms.length) {
                                writer.uint32(/* id 15, wireType 2 =*/122).fork();
                                for (var i = 0; i < message.defaultResponsePlatforms.length; ++i)
                                    writer.int32(message.defaultResponsePlatforms[i]);
                                writer.ldelim();
                            }
                            if (message.rootFollowupIntentName != null && Object.hasOwnProperty.call(message, "rootFollowupIntentName"))
                                writer.uint32(/* id 16, wireType 2 =*/130).string(message.rootFollowupIntentName);
                            if (message.parentFollowupIntentName != null && Object.hasOwnProperty.call(message, "parentFollowupIntentName"))
                                writer.uint32(/* id 17, wireType 2 =*/138).string(message.parentFollowupIntentName);
                            if (message.followupIntentInfo != null && message.followupIntentInfo.length)
                                for (var i = 0; i < message.followupIntentInfo.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.Intent.FollowupIntentInfo.encode(message.followupIntentInfo[i], writer.uint32(/* id 18, wireType 2 =*/146).fork()).ldelim();
                            if (message.mlDisabled != null && Object.hasOwnProperty.call(message, "mlDisabled"))
                                writer.uint32(/* id 19, wireType 0 =*/152).bool(message.mlDisabled);
                            if (message.liveAgentHandoff != null && Object.hasOwnProperty.call(message, "liveAgentHandoff"))
                                writer.uint32(/* id 20, wireType 0 =*/160).bool(message.liveAgentHandoff);
                            if (message.endInteraction != null && Object.hasOwnProperty.call(message, "endInteraction"))
                                writer.uint32(/* id 21, wireType 0 =*/168).bool(message.endInteraction);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified Intent message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.Intent
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IIntent} message Intent message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        Intent.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an Intent message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.Intent
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.Intent} Intent
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        Intent.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Intent();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.displayName = reader.string();
                                        break;
                                    }
                                case 6: {
                                        message.webhookState = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.priority = reader.int32();
                                        break;
                                    }
                                case 4: {
                                        message.isFallback = reader.bool();
                                        break;
                                    }
                                case 5: {
                                        message.mlEnabled = reader.bool();
                                        break;
                                    }
                                case 19: {
                                        message.mlDisabled = reader.bool();
                                        break;
                                    }
                                case 20: {
                                        message.liveAgentHandoff = reader.bool();
                                        break;
                                    }
                                case 21: {
                                        message.endInteraction = reader.bool();
                                        break;
                                    }
                                case 7: {
                                        if (!(message.inputContextNames && message.inputContextNames.length))
                                            message.inputContextNames = [];
                                        message.inputContextNames.push(reader.string());
                                        break;
                                    }
                                case 8: {
                                        if (!(message.events && message.events.length))
                                            message.events = [];
                                        message.events.push(reader.string());
                                        break;
                                    }
                                case 9: {
                                        if (!(message.trainingPhrases && message.trainingPhrases.length))
                                            message.trainingPhrases = [];
                                        message.trainingPhrases.push($root.google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 10: {
                                        message.action = reader.string();
                                        break;
                                    }
                                case 11: {
                                        if (!(message.outputContexts && message.outputContexts.length))
                                            message.outputContexts = [];
                                        message.outputContexts.push($root.google.cloud.dialogflow.v2beta1.Context.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 12: {
                                        message.resetContexts = reader.bool();
                                        break;
                                    }
                                case 13: {
                                        if (!(message.parameters && message.parameters.length))
                                            message.parameters = [];
                                        message.parameters.push($root.google.cloud.dialogflow.v2beta1.Intent.Parameter.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 14: {
                                        if (!(message.messages && message.messages.length))
                                            message.messages = [];
                                        message.messages.push($root.google.cloud.dialogflow.v2beta1.Intent.Message.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 15: {
                                        if (!(message.defaultResponsePlatforms && message.defaultResponsePlatforms.length))
                                            message.defaultResponsePlatforms = [];
                                        if ((tag & 7) === 2) {
                                            var end2 = reader.uint32() + reader.pos;
                                            while (reader.pos < end2)
                                                message.defaultResponsePlatforms.push(reader.int32());
                                        } else
                                            message.defaultResponsePlatforms.push(reader.int32());
                                        break;
                                    }
                                case 16: {
                                        message.rootFollowupIntentName = reader.string();
                                        break;
                                    }
                                case 17: {
                                        message.parentFollowupIntentName = reader.string();
                                        break;
                                    }
                                case 18: {
                                        if (!(message.followupIntentInfo && message.followupIntentInfo.length))
                                            message.followupIntentInfo = [];
                                        message.followupIntentInfo.push($root.google.cloud.dialogflow.v2beta1.Intent.FollowupIntentInfo.decode(reader, reader.uint32()));
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an Intent message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.Intent
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.Intent} Intent
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        Intent.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an Intent message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.Intent
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        Intent.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            if (message.displayName != null && message.hasOwnProperty("displayName"))
                                if (!$util.isString(message.displayName))
                                    return "displayName: string expected";
                            if (message.webhookState != null && message.hasOwnProperty("webhookState"))
                                switch (message.webhookState) {
                                default:
                                    return "webhookState: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                    break;
                                }
                            if (message.priority != null && message.hasOwnProperty("priority"))
                                if (!$util.isInteger(message.priority))
                                    return "priority: integer expected";
                            if (message.isFallback != null && message.hasOwnProperty("isFallback"))
                                if (typeof message.isFallback !== "boolean")
                                    return "isFallback: boolean expected";
                            if (message.mlEnabled != null && message.hasOwnProperty("mlEnabled"))
                                if (typeof message.mlEnabled !== "boolean")
                                    return "mlEnabled: boolean expected";
                            if (message.mlDisabled != null && message.hasOwnProperty("mlDisabled"))
                                if (typeof message.mlDisabled !== "boolean")
                                    return "mlDisabled: boolean expected";
                            if (message.liveAgentHandoff != null && message.hasOwnProperty("liveAgentHandoff"))
                                if (typeof message.liveAgentHandoff !== "boolean")
                                    return "liveAgentHandoff: boolean expected";
                            if (message.endInteraction != null && message.hasOwnProperty("endInteraction"))
                                if (typeof message.endInteraction !== "boolean")
                                    return "endInteraction: boolean expected";
                            if (message.inputContextNames != null && message.hasOwnProperty("inputContextNames")) {
                                if (!Array.isArray(message.inputContextNames))
                                    return "inputContextNames: array expected";
                                for (var i = 0; i < message.inputContextNames.length; ++i)
                                    if (!$util.isString(message.inputContextNames[i]))
                                        return "inputContextNames: string[] expected";
                            }
                            if (message.events != null && message.hasOwnProperty("events")) {
                                if (!Array.isArray(message.events))
                                    return "events: array expected";
                                for (var i = 0; i < message.events.length; ++i)
                                    if (!$util.isString(message.events[i]))
                                        return "events: string[] expected";
                            }
                            if (message.trainingPhrases != null && message.hasOwnProperty("trainingPhrases")) {
                                if (!Array.isArray(message.trainingPhrases))
                                    return "trainingPhrases: array expected";
                                for (var i = 0; i < message.trainingPhrases.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.verify(message.trainingPhrases[i]);
                                    if (error)
                                        return "trainingPhrases." + error;
                                }
                            }
                            if (message.action != null && message.hasOwnProperty("action"))
                                if (!$util.isString(message.action))
                                    return "action: string expected";
                            if (message.outputContexts != null && message.hasOwnProperty("outputContexts")) {
                                if (!Array.isArray(message.outputContexts))
                                    return "outputContexts: array expected";
                                for (var i = 0; i < message.outputContexts.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.Context.verify(message.outputContexts[i]);
                                    if (error)
                                        return "outputContexts." + error;
                                }
                            }
                            if (message.resetContexts != null && message.hasOwnProperty("resetContexts"))
                                if (typeof message.resetContexts !== "boolean")
                                    return "resetContexts: boolean expected";
                            if (message.parameters != null && message.hasOwnProperty("parameters")) {
                                if (!Array.isArray(message.parameters))
                                    return "parameters: array expected";
                                for (var i = 0; i < message.parameters.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.Intent.Parameter.verify(message.parameters[i]);
                                    if (error)
                                        return "parameters." + error;
                                }
                            }
                            if (message.messages != null && message.hasOwnProperty("messages")) {
                                if (!Array.isArray(message.messages))
                                    return "messages: array expected";
                                for (var i = 0; i < message.messages.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.Intent.Message.verify(message.messages[i]);
                                    if (error)
                                        return "messages." + error;
                                }
                            }
                            if (message.defaultResponsePlatforms != null && message.hasOwnProperty("defaultResponsePlatforms")) {
                                if (!Array.isArray(message.defaultResponsePlatforms))
                                    return "defaultResponsePlatforms: array expected";
                                for (var i = 0; i < message.defaultResponsePlatforms.length; ++i)
                                    switch (message.defaultResponsePlatforms[i]) {
                                    default:
                                        return "defaultResponsePlatforms: enum value[] expected";
                                    case 0:
                                    case 1:
                                    case 2:
                                    case 3:
                                    case 4:
                                    case 5:
                                    case 6:
                                    case 7:
                                    case 8:
                                    case 10:
                                    case 11:
                                        break;
                                    }
                            }
                            if (message.rootFollowupIntentName != null && message.hasOwnProperty("rootFollowupIntentName"))
                                if (!$util.isString(message.rootFollowupIntentName))
                                    return "rootFollowupIntentName: string expected";
                            if (message.parentFollowupIntentName != null && message.hasOwnProperty("parentFollowupIntentName"))
                                if (!$util.isString(message.parentFollowupIntentName))
                                    return "parentFollowupIntentName: string expected";
                            if (message.followupIntentInfo != null && message.hasOwnProperty("followupIntentInfo")) {
                                if (!Array.isArray(message.followupIntentInfo))
                                    return "followupIntentInfo: array expected";
                                for (var i = 0; i < message.followupIntentInfo.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.Intent.FollowupIntentInfo.verify(message.followupIntentInfo[i]);
                                    if (error)
                                        return "followupIntentInfo." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates an Intent message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.Intent
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.Intent} Intent
                         */
                        Intent.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.Intent)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.Intent();
                            if (object.name != null)
                                message.name = String(object.name);
                            if (object.displayName != null)
                                message.displayName = String(object.displayName);
                            switch (object.webhookState) {
                            default:
                                if (typeof object.webhookState === "number") {
                                    message.webhookState = object.webhookState;
                                    break;
                                }
                                break;
                            case "WEBHOOK_STATE_UNSPECIFIED":
                            case 0:
                                message.webhookState = 0;
                                break;
                            case "WEBHOOK_STATE_ENABLED":
                            case 1:
                                message.webhookState = 1;
                                break;
                            case "WEBHOOK_STATE_ENABLED_FOR_SLOT_FILLING":
                            case 2:
                                message.webhookState = 2;
                                break;
                            }
                            if (object.priority != null)
                                message.priority = object.priority | 0;
                            if (object.isFallback != null)
                                message.isFallback = Boolean(object.isFallback);
                            if (object.mlEnabled != null)
                                message.mlEnabled = Boolean(object.mlEnabled);
                            if (object.mlDisabled != null)
                                message.mlDisabled = Boolean(object.mlDisabled);
                            if (object.liveAgentHandoff != null)
                                message.liveAgentHandoff = Boolean(object.liveAgentHandoff);
                            if (object.endInteraction != null)
                                message.endInteraction = Boolean(object.endInteraction);
                            if (object.inputContextNames) {
                                if (!Array.isArray(object.inputContextNames))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.inputContextNames: array expected");
                                message.inputContextNames = [];
                                for (var i = 0; i < object.inputContextNames.length; ++i)
                                    message.inputContextNames[i] = String(object.inputContextNames[i]);
                            }
                            if (object.events) {
                                if (!Array.isArray(object.events))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.events: array expected");
                                message.events = [];
                                for (var i = 0; i < object.events.length; ++i)
                                    message.events[i] = String(object.events[i]);
                            }
                            if (object.trainingPhrases) {
                                if (!Array.isArray(object.trainingPhrases))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.trainingPhrases: array expected");
                                message.trainingPhrases = [];
                                for (var i = 0; i < object.trainingPhrases.length; ++i) {
                                    if (typeof object.trainingPhrases[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.trainingPhrases: object expected");
                                    message.trainingPhrases[i] = $root.google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.fromObject(object.trainingPhrases[i]);
                                }
                            }
                            if (object.action != null)
                                message.action = String(object.action);
                            if (object.outputContexts) {
                                if (!Array.isArray(object.outputContexts))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.outputContexts: array expected");
                                message.outputContexts = [];
                                for (var i = 0; i < object.outputContexts.length; ++i) {
                                    if (typeof object.outputContexts[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.outputContexts: object expected");
                                    message.outputContexts[i] = $root.google.cloud.dialogflow.v2beta1.Context.fromObject(object.outputContexts[i]);
                                }
                            }
                            if (object.resetContexts != null)
                                message.resetContexts = Boolean(object.resetContexts);
                            if (object.parameters) {
                                if (!Array.isArray(object.parameters))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.parameters: array expected");
                                message.parameters = [];
                                for (var i = 0; i < object.parameters.length; ++i) {
                                    if (typeof object.parameters[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.parameters: object expected");
                                    message.parameters[i] = $root.google.cloud.dialogflow.v2beta1.Intent.Parameter.fromObject(object.parameters[i]);
                                }
                            }
                            if (object.messages) {
                                if (!Array.isArray(object.messages))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.messages: array expected");
                                message.messages = [];
                                for (var i = 0; i < object.messages.length; ++i) {
                                    if (typeof object.messages[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.messages: object expected");
                                    message.messages[i] = $root.google.cloud.dialogflow.v2beta1.Intent.Message.fromObject(object.messages[i]);
                                }
                            }
                            if (object.defaultResponsePlatforms) {
                                if (!Array.isArray(object.defaultResponsePlatforms))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.defaultResponsePlatforms: array expected");
                                message.defaultResponsePlatforms = [];
                                for (var i = 0; i < object.defaultResponsePlatforms.length; ++i)
                                    switch (object.defaultResponsePlatforms[i]) {
                                    default:
                                        if (typeof object.defaultResponsePlatforms[i] === "number") {
                                            message.defaultResponsePlatforms[i] = object.defaultResponsePlatforms[i];
                                            break;
                                        }
                                    case "PLATFORM_UNSPECIFIED":
                                    case 0:
                                        message.defaultResponsePlatforms[i] = 0;
                                        break;
                                    case "FACEBOOK":
                                    case 1:
                                        message.defaultResponsePlatforms[i] = 1;
                                        break;
                                    case "SLACK":
                                    case 2:
                                        message.defaultResponsePlatforms[i] = 2;
                                        break;
                                    case "TELEGRAM":
                                    case 3:
                                        message.defaultResponsePlatforms[i] = 3;
                                        break;
                                    case "KIK":
                                    case 4:
                                        message.defaultResponsePlatforms[i] = 4;
                                        break;
                                    case "SKYPE":
                                    case 5:
                                        message.defaultResponsePlatforms[i] = 5;
                                        break;
                                    case "LINE":
                                    case 6:
                                        message.defaultResponsePlatforms[i] = 6;
                                        break;
                                    case "VIBER":
                                    case 7:
                                        message.defaultResponsePlatforms[i] = 7;
                                        break;
                                    case "ACTIONS_ON_GOOGLE":
                                    case 8:
                                        message.defaultResponsePlatforms[i] = 8;
                                        break;
                                    case "TELEPHONY":
                                    case 10:
                                        message.defaultResponsePlatforms[i] = 10;
                                        break;
                                    case "GOOGLE_HANGOUTS":
                                    case 11:
                                        message.defaultResponsePlatforms[i] = 11;
                                        break;
                                    }
                            }
                            if (object.rootFollowupIntentName != null)
                                message.rootFollowupIntentName = String(object.rootFollowupIntentName);
                            if (object.parentFollowupIntentName != null)
                                message.parentFollowupIntentName = String(object.parentFollowupIntentName);
                            if (object.followupIntentInfo) {
                                if (!Array.isArray(object.followupIntentInfo))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.followupIntentInfo: array expected");
                                message.followupIntentInfo = [];
                                for (var i = 0; i < object.followupIntentInfo.length; ++i) {
                                    if (typeof object.followupIntentInfo[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.followupIntentInfo: object expected");
                                    message.followupIntentInfo[i] = $root.google.cloud.dialogflow.v2beta1.Intent.FollowupIntentInfo.fromObject(object.followupIntentInfo[i]);
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an Intent message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.Intent
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.Intent} message Intent
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        Intent.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults) {
                                object.inputContextNames = [];
                                object.events = [];
                                object.trainingPhrases = [];
                                object.outputContexts = [];
                                object.parameters = [];
                                object.messages = [];
                                object.defaultResponsePlatforms = [];
                                object.followupIntentInfo = [];
                            }
                            if (options.defaults) {
                                object.name = "";
                                object.displayName = "";
                                object.priority = 0;
                                object.isFallback = false;
                                object.mlEnabled = false;
                                object.webhookState = options.enums === String ? "WEBHOOK_STATE_UNSPECIFIED" : 0;
                                object.action = "";
                                object.resetContexts = false;
                                object.rootFollowupIntentName = "";
                                object.parentFollowupIntentName = "";
                                object.mlDisabled = false;
                                object.liveAgentHandoff = false;
                                object.endInteraction = false;
                            }
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            if (message.displayName != null && message.hasOwnProperty("displayName"))
                                object.displayName = message.displayName;
                            if (message.priority != null && message.hasOwnProperty("priority"))
                                object.priority = message.priority;
                            if (message.isFallback != null && message.hasOwnProperty("isFallback"))
                                object.isFallback = message.isFallback;
                            if (message.mlEnabled != null && message.hasOwnProperty("mlEnabled"))
                                object.mlEnabled = message.mlEnabled;
                            if (message.webhookState != null && message.hasOwnProperty("webhookState"))
                                object.webhookState = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.Intent.WebhookState[message.webhookState] === undefined ? message.webhookState : $root.google.cloud.dialogflow.v2beta1.Intent.WebhookState[message.webhookState] : message.webhookState;
                            if (message.inputContextNames && message.inputContextNames.length) {
                                object.inputContextNames = [];
                                for (var j = 0; j < message.inputContextNames.length; ++j)
                                    object.inputContextNames[j] = message.inputContextNames[j];
                            }
                            if (message.events && message.events.length) {
                                object.events = [];
                                for (var j = 0; j < message.events.length; ++j)
                                    object.events[j] = message.events[j];
                            }
                            if (message.trainingPhrases && message.trainingPhrases.length) {
                                object.trainingPhrases = [];
                                for (var j = 0; j < message.trainingPhrases.length; ++j)
                                    object.trainingPhrases[j] = $root.google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.toObject(message.trainingPhrases[j], options);
                            }
                            if (message.action != null && message.hasOwnProperty("action"))
                                object.action = message.action;
                            if (message.outputContexts && message.outputContexts.length) {
                                object.outputContexts = [];
                                for (var j = 0; j < message.outputContexts.length; ++j)
                                    object.outputContexts[j] = $root.google.cloud.dialogflow.v2beta1.Context.toObject(message.outputContexts[j], options);
                            }
                            if (message.resetContexts != null && message.hasOwnProperty("resetContexts"))
                                object.resetContexts = message.resetContexts;
                            if (message.parameters && message.parameters.length) {
                                object.parameters = [];
                                for (var j = 0; j < message.parameters.length; ++j)
                                    object.parameters[j] = $root.google.cloud.dialogflow.v2beta1.Intent.Parameter.toObject(message.parameters[j], options);
                            }
                            if (message.messages && message.messages.length) {
                                object.messages = [];
                                for (var j = 0; j < message.messages.length; ++j)
                                    object.messages[j] = $root.google.cloud.dialogflow.v2beta1.Intent.Message.toObject(message.messages[j], options);
                            }
                            if (message.defaultResponsePlatforms && message.defaultResponsePlatforms.length) {
                                object.defaultResponsePlatforms = [];
                                for (var j = 0; j < message.defaultResponsePlatforms.length; ++j)
                                    object.defaultResponsePlatforms[j] = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.Intent.Message.Platform[message.defaultResponsePlatforms[j]] === undefined ? message.defaultResponsePlatforms[j] : $root.google.cloud.dialogflow.v2beta1.Intent.Message.Platform[message.defaultResponsePlatforms[j]] : message.defaultResponsePlatforms[j];
                            }
                            if (message.rootFollowupIntentName != null && message.hasOwnProperty("rootFollowupIntentName"))
                                object.rootFollowupIntentName = message.rootFollowupIntentName;
                            if (message.parentFollowupIntentName != null && message.hasOwnProperty("parentFollowupIntentName"))
                                object.parentFollowupIntentName = message.parentFollowupIntentName;
                            if (message.followupIntentInfo && message.followupIntentInfo.length) {
                                object.followupIntentInfo = [];
                                for (var j = 0; j < message.followupIntentInfo.length; ++j)
                                    object.followupIntentInfo[j] = $root.google.cloud.dialogflow.v2beta1.Intent.FollowupIntentInfo.toObject(message.followupIntentInfo[j], options);
                            }
                            if (message.mlDisabled != null && message.hasOwnProperty("mlDisabled"))
                                object.mlDisabled = message.mlDisabled;
                            if (message.liveAgentHandoff != null && message.hasOwnProperty("liveAgentHandoff"))
                                object.liveAgentHandoff = message.liveAgentHandoff;
                            if (message.endInteraction != null && message.hasOwnProperty("endInteraction"))
                                object.endInteraction = message.endInteraction;
                            return object;
                        };
    
                        /**
                         * Converts this Intent to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.Intent
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        Intent.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for Intent
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.Intent
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        Intent.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Intent";
                        };
    
                        /**
                         * WebhookState enum.
                         * @name google.cloud.dialogflow.v2beta1.Intent.WebhookState
                         * @enum {number}
                         * @property {number} WEBHOOK_STATE_UNSPECIFIED=0 WEBHOOK_STATE_UNSPECIFIED value
                         * @property {number} WEBHOOK_STATE_ENABLED=1 WEBHOOK_STATE_ENABLED value
                         * @property {number} WEBHOOK_STATE_ENABLED_FOR_SLOT_FILLING=2 WEBHOOK_STATE_ENABLED_FOR_SLOT_FILLING value
                         */
                        Intent.WebhookState = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "WEBHOOK_STATE_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "WEBHOOK_STATE_ENABLED"] = 1;
                            values[valuesById[2] = "WEBHOOK_STATE_ENABLED_FOR_SLOT_FILLING"] = 2;
                            return values;
                        })();
    
                        Intent.TrainingPhrase = (function() {
    
                            /**
                             * Properties of a TrainingPhrase.
                             * @memberof google.cloud.dialogflow.v2beta1.Intent
                             * @interface ITrainingPhrase
                             * @property {string|null} [name] TrainingPhrase name
                             * @property {google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.Type|null} [type] TrainingPhrase type
                             * @property {Array.<google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.IPart>|null} [parts] TrainingPhrase parts
                             * @property {number|null} [timesAddedCount] TrainingPhrase timesAddedCount
                             */
    
                            /**
                             * Constructs a new TrainingPhrase.
                             * @memberof google.cloud.dialogflow.v2beta1.Intent
                             * @classdesc Represents a TrainingPhrase.
                             * @implements ITrainingPhrase
                             * @constructor
                             * @param {google.cloud.dialogflow.v2beta1.Intent.ITrainingPhrase=} [properties] Properties to set
                             */
                            function TrainingPhrase(properties) {
                                this.parts = [];
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * TrainingPhrase name.
                             * @member {string} name
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase
                             * @instance
                             */
                            TrainingPhrase.prototype.name = "";
    
                            /**
                             * TrainingPhrase type.
                             * @member {google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.Type} type
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase
                             * @instance
                             */
                            TrainingPhrase.prototype.type = 0;
    
                            /**
                             * TrainingPhrase parts.
                             * @member {Array.<google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.IPart>} parts
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase
                             * @instance
                             */
                            TrainingPhrase.prototype.parts = $util.emptyArray;
    
                            /**
                             * TrainingPhrase timesAddedCount.
                             * @member {number} timesAddedCount
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase
                             * @instance
                             */
                            TrainingPhrase.prototype.timesAddedCount = 0;
    
                            /**
                             * Creates a new TrainingPhrase instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.Intent.ITrainingPhrase=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase} TrainingPhrase instance
                             */
                            TrainingPhrase.create = function create(properties) {
                                return new TrainingPhrase(properties);
                            };
    
                            /**
                             * Encodes the specified TrainingPhrase message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.Intent.ITrainingPhrase} message TrainingPhrase message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            TrainingPhrase.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                    writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                                if (message.type != null && Object.hasOwnProperty.call(message, "type"))
                                    writer.uint32(/* id 2, wireType 0 =*/16).int32(message.type);
                                if (message.parts != null && message.parts.length)
                                    for (var i = 0; i < message.parts.length; ++i)
                                        $root.google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.Part.encode(message.parts[i], writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                                if (message.timesAddedCount != null && Object.hasOwnProperty.call(message, "timesAddedCount"))
                                    writer.uint32(/* id 4, wireType 0 =*/32).int32(message.timesAddedCount);
                                return writer;
                            };
    
                            /**
                             * Encodes the specified TrainingPhrase message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.Intent.ITrainingPhrase} message TrainingPhrase message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            TrainingPhrase.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a TrainingPhrase message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase} TrainingPhrase
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            TrainingPhrase.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.name = reader.string();
                                            break;
                                        }
                                    case 2: {
                                            message.type = reader.int32();
                                            break;
                                        }
                                    case 3: {
                                            if (!(message.parts && message.parts.length))
                                                message.parts = [];
                                            message.parts.push($root.google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.Part.decode(reader, reader.uint32()));
                                            break;
                                        }
                                    case 4: {
                                            message.timesAddedCount = reader.int32();
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a TrainingPhrase message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase} TrainingPhrase
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            TrainingPhrase.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a TrainingPhrase message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            TrainingPhrase.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.name != null && message.hasOwnProperty("name"))
                                    if (!$util.isString(message.name))
                                        return "name: string expected";
                                if (message.type != null && message.hasOwnProperty("type"))
                                    switch (message.type) {
                                    default:
                                        return "type: enum value expected";
                                    case 0:
                                    case 1:
                                    case 2:
                                        break;
                                    }
                                if (message.parts != null && message.hasOwnProperty("parts")) {
                                    if (!Array.isArray(message.parts))
                                        return "parts: array expected";
                                    for (var i = 0; i < message.parts.length; ++i) {
                                        var error = $root.google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.Part.verify(message.parts[i]);
                                        if (error)
                                            return "parts." + error;
                                    }
                                }
                                if (message.timesAddedCount != null && message.hasOwnProperty("timesAddedCount"))
                                    if (!$util.isInteger(message.timesAddedCount))
                                        return "timesAddedCount: integer expected";
                                return null;
                            };
    
                            /**
                             * Creates a TrainingPhrase message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase} TrainingPhrase
                             */
                            TrainingPhrase.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase();
                                if (object.name != null)
                                    message.name = String(object.name);
                                switch (object.type) {
                                default:
                                    if (typeof object.type === "number") {
                                        message.type = object.type;
                                        break;
                                    }
                                    break;
                                case "TYPE_UNSPECIFIED":
                                case 0:
                                    message.type = 0;
                                    break;
                                case "EXAMPLE":
                                case 1:
                                    message.type = 1;
                                    break;
                                case "TEMPLATE":
                                case 2:
                                    message.type = 2;
                                    break;
                                }
                                if (object.parts) {
                                    if (!Array.isArray(object.parts))
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.parts: array expected");
                                    message.parts = [];
                                    for (var i = 0; i < object.parts.length; ++i) {
                                        if (typeof object.parts[i] !== "object")
                                            throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.parts: object expected");
                                        message.parts[i] = $root.google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.Part.fromObject(object.parts[i]);
                                    }
                                }
                                if (object.timesAddedCount != null)
                                    message.timesAddedCount = object.timesAddedCount | 0;
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a TrainingPhrase message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase} message TrainingPhrase
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            TrainingPhrase.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.arrays || options.defaults)
                                    object.parts = [];
                                if (options.defaults) {
                                    object.name = "";
                                    object.type = options.enums === String ? "TYPE_UNSPECIFIED" : 0;
                                    object.timesAddedCount = 0;
                                }
                                if (message.name != null && message.hasOwnProperty("name"))
                                    object.name = message.name;
                                if (message.type != null && message.hasOwnProperty("type"))
                                    object.type = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.Type[message.type] === undefined ? message.type : $root.google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.Type[message.type] : message.type;
                                if (message.parts && message.parts.length) {
                                    object.parts = [];
                                    for (var j = 0; j < message.parts.length; ++j)
                                        object.parts[j] = $root.google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.Part.toObject(message.parts[j], options);
                                }
                                if (message.timesAddedCount != null && message.hasOwnProperty("timesAddedCount"))
                                    object.timesAddedCount = message.timesAddedCount;
                                return object;
                            };
    
                            /**
                             * Converts this TrainingPhrase to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            TrainingPhrase.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for TrainingPhrase
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            TrainingPhrase.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase";
                            };
    
                            /**
                             * Type enum.
                             * @name google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.Type
                             * @enum {number}
                             * @property {number} TYPE_UNSPECIFIED=0 TYPE_UNSPECIFIED value
                             * @property {number} EXAMPLE=1 EXAMPLE value
                             * @property {number} TEMPLATE=2 TEMPLATE value
                             */
                            TrainingPhrase.Type = (function() {
                                var valuesById = {}, values = Object.create(valuesById);
                                values[valuesById[0] = "TYPE_UNSPECIFIED"] = 0;
                                values[valuesById[1] = "EXAMPLE"] = 1;
                                values[valuesById[2] = "TEMPLATE"] = 2;
                                return values;
                            })();
    
                            TrainingPhrase.Part = (function() {
    
                                /**
                                 * Properties of a Part.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase
                                 * @interface IPart
                                 * @property {string|null} [text] Part text
                                 * @property {string|null} [entityType] Part entityType
                                 * @property {string|null} [alias] Part alias
                                 * @property {boolean|null} [userDefined] Part userDefined
                                 */
    
                                /**
                                 * Constructs a new Part.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase
                                 * @classdesc Represents a Part.
                                 * @implements IPart
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.IPart=} [properties] Properties to set
                                 */
                                function Part(properties) {
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * Part text.
                                 * @member {string} text
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.Part
                                 * @instance
                                 */
                                Part.prototype.text = "";
    
                                /**
                                 * Part entityType.
                                 * @member {string} entityType
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.Part
                                 * @instance
                                 */
                                Part.prototype.entityType = "";
    
                                /**
                                 * Part alias.
                                 * @member {string} alias
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.Part
                                 * @instance
                                 */
                                Part.prototype.alias = "";
    
                                /**
                                 * Part userDefined.
                                 * @member {boolean} userDefined
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.Part
                                 * @instance
                                 */
                                Part.prototype.userDefined = false;
    
                                /**
                                 * Creates a new Part instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.Part
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.IPart=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.Part} Part instance
                                 */
                                Part.create = function create(properties) {
                                    return new Part(properties);
                                };
    
                                /**
                                 * Encodes the specified Part message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.Part.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.Part
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.IPart} message Part message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                Part.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.text != null && Object.hasOwnProperty.call(message, "text"))
                                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.text);
                                    if (message.entityType != null && Object.hasOwnProperty.call(message, "entityType"))
                                        writer.uint32(/* id 2, wireType 2 =*/18).string(message.entityType);
                                    if (message.alias != null && Object.hasOwnProperty.call(message, "alias"))
                                        writer.uint32(/* id 3, wireType 2 =*/26).string(message.alias);
                                    if (message.userDefined != null && Object.hasOwnProperty.call(message, "userDefined"))
                                        writer.uint32(/* id 4, wireType 0 =*/32).bool(message.userDefined);
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified Part message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.Part.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.Part
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.IPart} message Part message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                Part.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a Part message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.Part
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.Part} Part
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                Part.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.Part();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                message.text = reader.string();
                                                break;
                                            }
                                        case 2: {
                                                message.entityType = reader.string();
                                                break;
                                            }
                                        case 3: {
                                                message.alias = reader.string();
                                                break;
                                            }
                                        case 4: {
                                                message.userDefined = reader.bool();
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a Part message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.Part
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.Part} Part
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                Part.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a Part message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.Part
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                Part.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.text != null && message.hasOwnProperty("text"))
                                        if (!$util.isString(message.text))
                                            return "text: string expected";
                                    if (message.entityType != null && message.hasOwnProperty("entityType"))
                                        if (!$util.isString(message.entityType))
                                            return "entityType: string expected";
                                    if (message.alias != null && message.hasOwnProperty("alias"))
                                        if (!$util.isString(message.alias))
                                            return "alias: string expected";
                                    if (message.userDefined != null && message.hasOwnProperty("userDefined"))
                                        if (typeof message.userDefined !== "boolean")
                                            return "userDefined: boolean expected";
                                    return null;
                                };
    
                                /**
                                 * Creates a Part message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.Part
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.Part} Part
                                 */
                                Part.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.Part)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.Part();
                                    if (object.text != null)
                                        message.text = String(object.text);
                                    if (object.entityType != null)
                                        message.entityType = String(object.entityType);
                                    if (object.alias != null)
                                        message.alias = String(object.alias);
                                    if (object.userDefined != null)
                                        message.userDefined = Boolean(object.userDefined);
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a Part message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.Part
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.Part} message Part
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                Part.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.defaults) {
                                        object.text = "";
                                        object.entityType = "";
                                        object.alias = "";
                                        object.userDefined = false;
                                    }
                                    if (message.text != null && message.hasOwnProperty("text"))
                                        object.text = message.text;
                                    if (message.entityType != null && message.hasOwnProperty("entityType"))
                                        object.entityType = message.entityType;
                                    if (message.alias != null && message.hasOwnProperty("alias"))
                                        object.alias = message.alias;
                                    if (message.userDefined != null && message.hasOwnProperty("userDefined"))
                                        object.userDefined = message.userDefined;
                                    return object;
                                };
    
                                /**
                                 * Converts this Part to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.Part
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                Part.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for Part
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.Part
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                Part.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Intent.TrainingPhrase.Part";
                                };
    
                                return Part;
                            })();
    
                            return TrainingPhrase;
                        })();
    
                        Intent.Parameter = (function() {
    
                            /**
                             * Properties of a Parameter.
                             * @memberof google.cloud.dialogflow.v2beta1.Intent
                             * @interface IParameter
                             * @property {string|null} [name] Parameter name
                             * @property {string|null} [displayName] Parameter displayName
                             * @property {string|null} [value] Parameter value
                             * @property {string|null} [defaultValue] Parameter defaultValue
                             * @property {string|null} [entityTypeDisplayName] Parameter entityTypeDisplayName
                             * @property {boolean|null} [mandatory] Parameter mandatory
                             * @property {Array.<string>|null} [prompts] Parameter prompts
                             * @property {boolean|null} [isList] Parameter isList
                             */
    
                            /**
                             * Constructs a new Parameter.
                             * @memberof google.cloud.dialogflow.v2beta1.Intent
                             * @classdesc Represents a Parameter.
                             * @implements IParameter
                             * @constructor
                             * @param {google.cloud.dialogflow.v2beta1.Intent.IParameter=} [properties] Properties to set
                             */
                            function Parameter(properties) {
                                this.prompts = [];
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * Parameter name.
                             * @member {string} name
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.Parameter
                             * @instance
                             */
                            Parameter.prototype.name = "";
    
                            /**
                             * Parameter displayName.
                             * @member {string} displayName
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.Parameter
                             * @instance
                             */
                            Parameter.prototype.displayName = "";
    
                            /**
                             * Parameter value.
                             * @member {string} value
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.Parameter
                             * @instance
                             */
                            Parameter.prototype.value = "";
    
                            /**
                             * Parameter defaultValue.
                             * @member {string} defaultValue
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.Parameter
                             * @instance
                             */
                            Parameter.prototype.defaultValue = "";
    
                            /**
                             * Parameter entityTypeDisplayName.
                             * @member {string} entityTypeDisplayName
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.Parameter
                             * @instance
                             */
                            Parameter.prototype.entityTypeDisplayName = "";
    
                            /**
                             * Parameter mandatory.
                             * @member {boolean} mandatory
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.Parameter
                             * @instance
                             */
                            Parameter.prototype.mandatory = false;
    
                            /**
                             * Parameter prompts.
                             * @member {Array.<string>} prompts
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.Parameter
                             * @instance
                             */
                            Parameter.prototype.prompts = $util.emptyArray;
    
                            /**
                             * Parameter isList.
                             * @member {boolean} isList
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.Parameter
                             * @instance
                             */
                            Parameter.prototype.isList = false;
    
                            /**
                             * Creates a new Parameter instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.Parameter
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.Intent.IParameter=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2beta1.Intent.Parameter} Parameter instance
                             */
                            Parameter.create = function create(properties) {
                                return new Parameter(properties);
                            };
    
                            /**
                             * Encodes the specified Parameter message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Parameter.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.Parameter
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.Intent.IParameter} message Parameter message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            Parameter.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                    writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                                if (message.displayName != null && Object.hasOwnProperty.call(message, "displayName"))
                                    writer.uint32(/* id 2, wireType 2 =*/18).string(message.displayName);
                                if (message.value != null && Object.hasOwnProperty.call(message, "value"))
                                    writer.uint32(/* id 3, wireType 2 =*/26).string(message.value);
                                if (message.defaultValue != null && Object.hasOwnProperty.call(message, "defaultValue"))
                                    writer.uint32(/* id 4, wireType 2 =*/34).string(message.defaultValue);
                                if (message.entityTypeDisplayName != null && Object.hasOwnProperty.call(message, "entityTypeDisplayName"))
                                    writer.uint32(/* id 5, wireType 2 =*/42).string(message.entityTypeDisplayName);
                                if (message.mandatory != null && Object.hasOwnProperty.call(message, "mandatory"))
                                    writer.uint32(/* id 6, wireType 0 =*/48).bool(message.mandatory);
                                if (message.prompts != null && message.prompts.length)
                                    for (var i = 0; i < message.prompts.length; ++i)
                                        writer.uint32(/* id 7, wireType 2 =*/58).string(message.prompts[i]);
                                if (message.isList != null && Object.hasOwnProperty.call(message, "isList"))
                                    writer.uint32(/* id 8, wireType 0 =*/64).bool(message.isList);
                                return writer;
                            };
    
                            /**
                             * Encodes the specified Parameter message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Parameter.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.Parameter
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.Intent.IParameter} message Parameter message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            Parameter.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a Parameter message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.Parameter
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2beta1.Intent.Parameter} Parameter
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            Parameter.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Intent.Parameter();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.name = reader.string();
                                            break;
                                        }
                                    case 2: {
                                            message.displayName = reader.string();
                                            break;
                                        }
                                    case 3: {
                                            message.value = reader.string();
                                            break;
                                        }
                                    case 4: {
                                            message.defaultValue = reader.string();
                                            break;
                                        }
                                    case 5: {
                                            message.entityTypeDisplayName = reader.string();
                                            break;
                                        }
                                    case 6: {
                                            message.mandatory = reader.bool();
                                            break;
                                        }
                                    case 7: {
                                            if (!(message.prompts && message.prompts.length))
                                                message.prompts = [];
                                            message.prompts.push(reader.string());
                                            break;
                                        }
                                    case 8: {
                                            message.isList = reader.bool();
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a Parameter message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.Parameter
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2beta1.Intent.Parameter} Parameter
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            Parameter.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a Parameter message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.Parameter
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            Parameter.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.name != null && message.hasOwnProperty("name"))
                                    if (!$util.isString(message.name))
                                        return "name: string expected";
                                if (message.displayName != null && message.hasOwnProperty("displayName"))
                                    if (!$util.isString(message.displayName))
                                        return "displayName: string expected";
                                if (message.value != null && message.hasOwnProperty("value"))
                                    if (!$util.isString(message.value))
                                        return "value: string expected";
                                if (message.defaultValue != null && message.hasOwnProperty("defaultValue"))
                                    if (!$util.isString(message.defaultValue))
                                        return "defaultValue: string expected";
                                if (message.entityTypeDisplayName != null && message.hasOwnProperty("entityTypeDisplayName"))
                                    if (!$util.isString(message.entityTypeDisplayName))
                                        return "entityTypeDisplayName: string expected";
                                if (message.mandatory != null && message.hasOwnProperty("mandatory"))
                                    if (typeof message.mandatory !== "boolean")
                                        return "mandatory: boolean expected";
                                if (message.prompts != null && message.hasOwnProperty("prompts")) {
                                    if (!Array.isArray(message.prompts))
                                        return "prompts: array expected";
                                    for (var i = 0; i < message.prompts.length; ++i)
                                        if (!$util.isString(message.prompts[i]))
                                            return "prompts: string[] expected";
                                }
                                if (message.isList != null && message.hasOwnProperty("isList"))
                                    if (typeof message.isList !== "boolean")
                                        return "isList: boolean expected";
                                return null;
                            };
    
                            /**
                             * Creates a Parameter message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.Parameter
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2beta1.Intent.Parameter} Parameter
                             */
                            Parameter.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2beta1.Intent.Parameter)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2beta1.Intent.Parameter();
                                if (object.name != null)
                                    message.name = String(object.name);
                                if (object.displayName != null)
                                    message.displayName = String(object.displayName);
                                if (object.value != null)
                                    message.value = String(object.value);
                                if (object.defaultValue != null)
                                    message.defaultValue = String(object.defaultValue);
                                if (object.entityTypeDisplayName != null)
                                    message.entityTypeDisplayName = String(object.entityTypeDisplayName);
                                if (object.mandatory != null)
                                    message.mandatory = Boolean(object.mandatory);
                                if (object.prompts) {
                                    if (!Array.isArray(object.prompts))
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Parameter.prompts: array expected");
                                    message.prompts = [];
                                    for (var i = 0; i < object.prompts.length; ++i)
                                        message.prompts[i] = String(object.prompts[i]);
                                }
                                if (object.isList != null)
                                    message.isList = Boolean(object.isList);
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a Parameter message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.Parameter
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.Intent.Parameter} message Parameter
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            Parameter.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.arrays || options.defaults)
                                    object.prompts = [];
                                if (options.defaults) {
                                    object.name = "";
                                    object.displayName = "";
                                    object.value = "";
                                    object.defaultValue = "";
                                    object.entityTypeDisplayName = "";
                                    object.mandatory = false;
                                    object.isList = false;
                                }
                                if (message.name != null && message.hasOwnProperty("name"))
                                    object.name = message.name;
                                if (message.displayName != null && message.hasOwnProperty("displayName"))
                                    object.displayName = message.displayName;
                                if (message.value != null && message.hasOwnProperty("value"))
                                    object.value = message.value;
                                if (message.defaultValue != null && message.hasOwnProperty("defaultValue"))
                                    object.defaultValue = message.defaultValue;
                                if (message.entityTypeDisplayName != null && message.hasOwnProperty("entityTypeDisplayName"))
                                    object.entityTypeDisplayName = message.entityTypeDisplayName;
                                if (message.mandatory != null && message.hasOwnProperty("mandatory"))
                                    object.mandatory = message.mandatory;
                                if (message.prompts && message.prompts.length) {
                                    object.prompts = [];
                                    for (var j = 0; j < message.prompts.length; ++j)
                                        object.prompts[j] = message.prompts[j];
                                }
                                if (message.isList != null && message.hasOwnProperty("isList"))
                                    object.isList = message.isList;
                                return object;
                            };
    
                            /**
                             * Converts this Parameter to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.Parameter
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            Parameter.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for Parameter
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.Parameter
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            Parameter.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Intent.Parameter";
                            };
    
                            return Parameter;
                        })();
    
                        Intent.Message = (function() {
    
                            /**
                             * Properties of a Message.
                             * @memberof google.cloud.dialogflow.v2beta1.Intent
                             * @interface IMessage
                             * @property {google.cloud.dialogflow.v2beta1.Intent.Message.IText|null} [text] Message text
                             * @property {google.cloud.dialogflow.v2beta1.Intent.Message.IImage|null} [image] Message image
                             * @property {google.cloud.dialogflow.v2beta1.Intent.Message.IQuickReplies|null} [quickReplies] Message quickReplies
                             * @property {google.cloud.dialogflow.v2beta1.Intent.Message.ICard|null} [card] Message card
                             * @property {google.protobuf.IStruct|null} [payload] Message payload
                             * @property {google.cloud.dialogflow.v2beta1.Intent.Message.ISimpleResponses|null} [simpleResponses] Message simpleResponses
                             * @property {google.cloud.dialogflow.v2beta1.Intent.Message.IBasicCard|null} [basicCard] Message basicCard
                             * @property {google.cloud.dialogflow.v2beta1.Intent.Message.ISuggestions|null} [suggestions] Message suggestions
                             * @property {google.cloud.dialogflow.v2beta1.Intent.Message.ILinkOutSuggestion|null} [linkOutSuggestion] Message linkOutSuggestion
                             * @property {google.cloud.dialogflow.v2beta1.Intent.Message.IListSelect|null} [listSelect] Message listSelect
                             * @property {google.cloud.dialogflow.v2beta1.Intent.Message.ICarouselSelect|null} [carouselSelect] Message carouselSelect
                             * @property {google.cloud.dialogflow.v2beta1.Intent.Message.ITelephonyPlayAudio|null} [telephonyPlayAudio] Message telephonyPlayAudio
                             * @property {google.cloud.dialogflow.v2beta1.Intent.Message.ITelephonySynthesizeSpeech|null} [telephonySynthesizeSpeech] Message telephonySynthesizeSpeech
                             * @property {google.cloud.dialogflow.v2beta1.Intent.Message.ITelephonyTransferCall|null} [telephonyTransferCall] Message telephonyTransferCall
                             * @property {google.cloud.dialogflow.v2beta1.Intent.Message.IRbmText|null} [rbmText] Message rbmText
                             * @property {google.cloud.dialogflow.v2beta1.Intent.Message.IRbmStandaloneCard|null} [rbmStandaloneRichCard] Message rbmStandaloneRichCard
                             * @property {google.cloud.dialogflow.v2beta1.Intent.Message.IRbmCarouselCard|null} [rbmCarouselRichCard] Message rbmCarouselRichCard
                             * @property {google.cloud.dialogflow.v2beta1.Intent.Message.IBrowseCarouselCard|null} [browseCarouselCard] Message browseCarouselCard
                             * @property {google.cloud.dialogflow.v2beta1.Intent.Message.ITableCard|null} [tableCard] Message tableCard
                             * @property {google.cloud.dialogflow.v2beta1.Intent.Message.IMediaContent|null} [mediaContent] Message mediaContent
                             * @property {google.cloud.dialogflow.v2beta1.Intent.Message.Platform|null} [platform] Message platform
                             */
    
                            /**
                             * Constructs a new Message.
                             * @memberof google.cloud.dialogflow.v2beta1.Intent
                             * @classdesc Represents a Message.
                             * @implements IMessage
                             * @constructor
                             * @param {google.cloud.dialogflow.v2beta1.Intent.IMessage=} [properties] Properties to set
                             */
                            function Message(properties) {
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * Message text.
                             * @member {google.cloud.dialogflow.v2beta1.Intent.Message.IText|null|undefined} text
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                             * @instance
                             */
                            Message.prototype.text = null;
    
                            /**
                             * Message image.
                             * @member {google.cloud.dialogflow.v2beta1.Intent.Message.IImage|null|undefined} image
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                             * @instance
                             */
                            Message.prototype.image = null;
    
                            /**
                             * Message quickReplies.
                             * @member {google.cloud.dialogflow.v2beta1.Intent.Message.IQuickReplies|null|undefined} quickReplies
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                             * @instance
                             */
                            Message.prototype.quickReplies = null;
    
                            /**
                             * Message card.
                             * @member {google.cloud.dialogflow.v2beta1.Intent.Message.ICard|null|undefined} card
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                             * @instance
                             */
                            Message.prototype.card = null;
    
                            /**
                             * Message payload.
                             * @member {google.protobuf.IStruct|null|undefined} payload
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                             * @instance
                             */
                            Message.prototype.payload = null;
    
                            /**
                             * Message simpleResponses.
                             * @member {google.cloud.dialogflow.v2beta1.Intent.Message.ISimpleResponses|null|undefined} simpleResponses
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                             * @instance
                             */
                            Message.prototype.simpleResponses = null;
    
                            /**
                             * Message basicCard.
                             * @member {google.cloud.dialogflow.v2beta1.Intent.Message.IBasicCard|null|undefined} basicCard
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                             * @instance
                             */
                            Message.prototype.basicCard = null;
    
                            /**
                             * Message suggestions.
                             * @member {google.cloud.dialogflow.v2beta1.Intent.Message.ISuggestions|null|undefined} suggestions
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                             * @instance
                             */
                            Message.prototype.suggestions = null;
    
                            /**
                             * Message linkOutSuggestion.
                             * @member {google.cloud.dialogflow.v2beta1.Intent.Message.ILinkOutSuggestion|null|undefined} linkOutSuggestion
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                             * @instance
                             */
                            Message.prototype.linkOutSuggestion = null;
    
                            /**
                             * Message listSelect.
                             * @member {google.cloud.dialogflow.v2beta1.Intent.Message.IListSelect|null|undefined} listSelect
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                             * @instance
                             */
                            Message.prototype.listSelect = null;
    
                            /**
                             * Message carouselSelect.
                             * @member {google.cloud.dialogflow.v2beta1.Intent.Message.ICarouselSelect|null|undefined} carouselSelect
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                             * @instance
                             */
                            Message.prototype.carouselSelect = null;
    
                            /**
                             * Message telephonyPlayAudio.
                             * @member {google.cloud.dialogflow.v2beta1.Intent.Message.ITelephonyPlayAudio|null|undefined} telephonyPlayAudio
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                             * @instance
                             */
                            Message.prototype.telephonyPlayAudio = null;
    
                            /**
                             * Message telephonySynthesizeSpeech.
                             * @member {google.cloud.dialogflow.v2beta1.Intent.Message.ITelephonySynthesizeSpeech|null|undefined} telephonySynthesizeSpeech
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                             * @instance
                             */
                            Message.prototype.telephonySynthesizeSpeech = null;
    
                            /**
                             * Message telephonyTransferCall.
                             * @member {google.cloud.dialogflow.v2beta1.Intent.Message.ITelephonyTransferCall|null|undefined} telephonyTransferCall
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                             * @instance
                             */
                            Message.prototype.telephonyTransferCall = null;
    
                            /**
                             * Message rbmText.
                             * @member {google.cloud.dialogflow.v2beta1.Intent.Message.IRbmText|null|undefined} rbmText
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                             * @instance
                             */
                            Message.prototype.rbmText = null;
    
                            /**
                             * Message rbmStandaloneRichCard.
                             * @member {google.cloud.dialogflow.v2beta1.Intent.Message.IRbmStandaloneCard|null|undefined} rbmStandaloneRichCard
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                             * @instance
                             */
                            Message.prototype.rbmStandaloneRichCard = null;
    
                            /**
                             * Message rbmCarouselRichCard.
                             * @member {google.cloud.dialogflow.v2beta1.Intent.Message.IRbmCarouselCard|null|undefined} rbmCarouselRichCard
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                             * @instance
                             */
                            Message.prototype.rbmCarouselRichCard = null;
    
                            /**
                             * Message browseCarouselCard.
                             * @member {google.cloud.dialogflow.v2beta1.Intent.Message.IBrowseCarouselCard|null|undefined} browseCarouselCard
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                             * @instance
                             */
                            Message.prototype.browseCarouselCard = null;
    
                            /**
                             * Message tableCard.
                             * @member {google.cloud.dialogflow.v2beta1.Intent.Message.ITableCard|null|undefined} tableCard
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                             * @instance
                             */
                            Message.prototype.tableCard = null;
    
                            /**
                             * Message mediaContent.
                             * @member {google.cloud.dialogflow.v2beta1.Intent.Message.IMediaContent|null|undefined} mediaContent
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                             * @instance
                             */
                            Message.prototype.mediaContent = null;
    
                            /**
                             * Message platform.
                             * @member {google.cloud.dialogflow.v2beta1.Intent.Message.Platform} platform
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                             * @instance
                             */
                            Message.prototype.platform = 0;
    
                            // OneOf field names bound to virtual getters and setters
                            var $oneOfFields;
    
                            /**
                             * Message message.
                             * @member {"text"|"image"|"quickReplies"|"card"|"payload"|"simpleResponses"|"basicCard"|"suggestions"|"linkOutSuggestion"|"listSelect"|"carouselSelect"|"telephonyPlayAudio"|"telephonySynthesizeSpeech"|"telephonyTransferCall"|"rbmText"|"rbmStandaloneRichCard"|"rbmCarouselRichCard"|"browseCarouselCard"|"tableCard"|"mediaContent"|undefined} message
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                             * @instance
                             */
                            Object.defineProperty(Message.prototype, "message", {
                                get: $util.oneOfGetter($oneOfFields = ["text", "image", "quickReplies", "card", "payload", "simpleResponses", "basicCard", "suggestions", "linkOutSuggestion", "listSelect", "carouselSelect", "telephonyPlayAudio", "telephonySynthesizeSpeech", "telephonyTransferCall", "rbmText", "rbmStandaloneRichCard", "rbmCarouselRichCard", "browseCarouselCard", "tableCard", "mediaContent"]),
                                set: $util.oneOfSetter($oneOfFields)
                            });
    
                            /**
                             * Creates a new Message instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.Intent.IMessage=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2beta1.Intent.Message} Message instance
                             */
                            Message.create = function create(properties) {
                                return new Message(properties);
                            };
    
                            /**
                             * Encodes the specified Message message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.Intent.IMessage} message Message message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            Message.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.text != null && Object.hasOwnProperty.call(message, "text"))
                                    $root.google.cloud.dialogflow.v2beta1.Intent.Message.Text.encode(message.text, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                                if (message.image != null && Object.hasOwnProperty.call(message, "image"))
                                    $root.google.cloud.dialogflow.v2beta1.Intent.Message.Image.encode(message.image, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                                if (message.quickReplies != null && Object.hasOwnProperty.call(message, "quickReplies"))
                                    $root.google.cloud.dialogflow.v2beta1.Intent.Message.QuickReplies.encode(message.quickReplies, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                                if (message.card != null && Object.hasOwnProperty.call(message, "card"))
                                    $root.google.cloud.dialogflow.v2beta1.Intent.Message.Card.encode(message.card, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                                if (message.payload != null && Object.hasOwnProperty.call(message, "payload"))
                                    $root.google.protobuf.Struct.encode(message.payload, writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                                if (message.platform != null && Object.hasOwnProperty.call(message, "platform"))
                                    writer.uint32(/* id 6, wireType 0 =*/48).int32(message.platform);
                                if (message.simpleResponses != null && Object.hasOwnProperty.call(message, "simpleResponses"))
                                    $root.google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponses.encode(message.simpleResponses, writer.uint32(/* id 7, wireType 2 =*/58).fork()).ldelim();
                                if (message.basicCard != null && Object.hasOwnProperty.call(message, "basicCard"))
                                    $root.google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.encode(message.basicCard, writer.uint32(/* id 8, wireType 2 =*/66).fork()).ldelim();
                                if (message.suggestions != null && Object.hasOwnProperty.call(message, "suggestions"))
                                    $root.google.cloud.dialogflow.v2beta1.Intent.Message.Suggestions.encode(message.suggestions, writer.uint32(/* id 9, wireType 2 =*/74).fork()).ldelim();
                                if (message.linkOutSuggestion != null && Object.hasOwnProperty.call(message, "linkOutSuggestion"))
                                    $root.google.cloud.dialogflow.v2beta1.Intent.Message.LinkOutSuggestion.encode(message.linkOutSuggestion, writer.uint32(/* id 10, wireType 2 =*/82).fork()).ldelim();
                                if (message.listSelect != null && Object.hasOwnProperty.call(message, "listSelect"))
                                    $root.google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.encode(message.listSelect, writer.uint32(/* id 11, wireType 2 =*/90).fork()).ldelim();
                                if (message.carouselSelect != null && Object.hasOwnProperty.call(message, "carouselSelect"))
                                    $root.google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect.encode(message.carouselSelect, writer.uint32(/* id 12, wireType 2 =*/98).fork()).ldelim();
                                if (message.telephonyPlayAudio != null && Object.hasOwnProperty.call(message, "telephonyPlayAudio"))
                                    $root.google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyPlayAudio.encode(message.telephonyPlayAudio, writer.uint32(/* id 13, wireType 2 =*/106).fork()).ldelim();
                                if (message.telephonySynthesizeSpeech != null && Object.hasOwnProperty.call(message, "telephonySynthesizeSpeech"))
                                    $root.google.cloud.dialogflow.v2beta1.Intent.Message.TelephonySynthesizeSpeech.encode(message.telephonySynthesizeSpeech, writer.uint32(/* id 14, wireType 2 =*/114).fork()).ldelim();
                                if (message.telephonyTransferCall != null && Object.hasOwnProperty.call(message, "telephonyTransferCall"))
                                    $root.google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyTransferCall.encode(message.telephonyTransferCall, writer.uint32(/* id 15, wireType 2 =*/122).fork()).ldelim();
                                if (message.rbmText != null && Object.hasOwnProperty.call(message, "rbmText"))
                                    $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmText.encode(message.rbmText, writer.uint32(/* id 18, wireType 2 =*/146).fork()).ldelim();
                                if (message.rbmStandaloneRichCard != null && Object.hasOwnProperty.call(message, "rbmStandaloneRichCard"))
                                    $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmStandaloneCard.encode(message.rbmStandaloneRichCard, writer.uint32(/* id 19, wireType 2 =*/154).fork()).ldelim();
                                if (message.rbmCarouselRichCard != null && Object.hasOwnProperty.call(message, "rbmCarouselRichCard"))
                                    $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmCarouselCard.encode(message.rbmCarouselRichCard, writer.uint32(/* id 20, wireType 2 =*/162).fork()).ldelim();
                                if (message.browseCarouselCard != null && Object.hasOwnProperty.call(message, "browseCarouselCard"))
                                    $root.google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.encode(message.browseCarouselCard, writer.uint32(/* id 22, wireType 2 =*/178).fork()).ldelim();
                                if (message.tableCard != null && Object.hasOwnProperty.call(message, "tableCard"))
                                    $root.google.cloud.dialogflow.v2beta1.Intent.Message.TableCard.encode(message.tableCard, writer.uint32(/* id 23, wireType 2 =*/186).fork()).ldelim();
                                if (message.mediaContent != null && Object.hasOwnProperty.call(message, "mediaContent"))
                                    $root.google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.encode(message.mediaContent, writer.uint32(/* id 24, wireType 2 =*/194).fork()).ldelim();
                                return writer;
                            };
    
                            /**
                             * Encodes the specified Message message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.Intent.IMessage} message Message message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            Message.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a Message message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2beta1.Intent.Message} Message
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            Message.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.text = $root.google.cloud.dialogflow.v2beta1.Intent.Message.Text.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 2: {
                                            message.image = $root.google.cloud.dialogflow.v2beta1.Intent.Message.Image.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 3: {
                                            message.quickReplies = $root.google.cloud.dialogflow.v2beta1.Intent.Message.QuickReplies.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 4: {
                                            message.card = $root.google.cloud.dialogflow.v2beta1.Intent.Message.Card.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 5: {
                                            message.payload = $root.google.protobuf.Struct.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 7: {
                                            message.simpleResponses = $root.google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponses.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 8: {
                                            message.basicCard = $root.google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 9: {
                                            message.suggestions = $root.google.cloud.dialogflow.v2beta1.Intent.Message.Suggestions.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 10: {
                                            message.linkOutSuggestion = $root.google.cloud.dialogflow.v2beta1.Intent.Message.LinkOutSuggestion.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 11: {
                                            message.listSelect = $root.google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 12: {
                                            message.carouselSelect = $root.google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 13: {
                                            message.telephonyPlayAudio = $root.google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyPlayAudio.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 14: {
                                            message.telephonySynthesizeSpeech = $root.google.cloud.dialogflow.v2beta1.Intent.Message.TelephonySynthesizeSpeech.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 15: {
                                            message.telephonyTransferCall = $root.google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyTransferCall.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 18: {
                                            message.rbmText = $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmText.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 19: {
                                            message.rbmStandaloneRichCard = $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmStandaloneCard.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 20: {
                                            message.rbmCarouselRichCard = $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmCarouselCard.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 22: {
                                            message.browseCarouselCard = $root.google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 23: {
                                            message.tableCard = $root.google.cloud.dialogflow.v2beta1.Intent.Message.TableCard.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 24: {
                                            message.mediaContent = $root.google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 6: {
                                            message.platform = reader.int32();
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a Message message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2beta1.Intent.Message} Message
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            Message.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a Message message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            Message.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                var properties = {};
                                if (message.text != null && message.hasOwnProperty("text")) {
                                    properties.message = 1;
                                    {
                                        var error = $root.google.cloud.dialogflow.v2beta1.Intent.Message.Text.verify(message.text);
                                        if (error)
                                            return "text." + error;
                                    }
                                }
                                if (message.image != null && message.hasOwnProperty("image")) {
                                    if (properties.message === 1)
                                        return "message: multiple values";
                                    properties.message = 1;
                                    {
                                        var error = $root.google.cloud.dialogflow.v2beta1.Intent.Message.Image.verify(message.image);
                                        if (error)
                                            return "image." + error;
                                    }
                                }
                                if (message.quickReplies != null && message.hasOwnProperty("quickReplies")) {
                                    if (properties.message === 1)
                                        return "message: multiple values";
                                    properties.message = 1;
                                    {
                                        var error = $root.google.cloud.dialogflow.v2beta1.Intent.Message.QuickReplies.verify(message.quickReplies);
                                        if (error)
                                            return "quickReplies." + error;
                                    }
                                }
                                if (message.card != null && message.hasOwnProperty("card")) {
                                    if (properties.message === 1)
                                        return "message: multiple values";
                                    properties.message = 1;
                                    {
                                        var error = $root.google.cloud.dialogflow.v2beta1.Intent.Message.Card.verify(message.card);
                                        if (error)
                                            return "card." + error;
                                    }
                                }
                                if (message.payload != null && message.hasOwnProperty("payload")) {
                                    if (properties.message === 1)
                                        return "message: multiple values";
                                    properties.message = 1;
                                    {
                                        var error = $root.google.protobuf.Struct.verify(message.payload);
                                        if (error)
                                            return "payload." + error;
                                    }
                                }
                                if (message.simpleResponses != null && message.hasOwnProperty("simpleResponses")) {
                                    if (properties.message === 1)
                                        return "message: multiple values";
                                    properties.message = 1;
                                    {
                                        var error = $root.google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponses.verify(message.simpleResponses);
                                        if (error)
                                            return "simpleResponses." + error;
                                    }
                                }
                                if (message.basicCard != null && message.hasOwnProperty("basicCard")) {
                                    if (properties.message === 1)
                                        return "message: multiple values";
                                    properties.message = 1;
                                    {
                                        var error = $root.google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.verify(message.basicCard);
                                        if (error)
                                            return "basicCard." + error;
                                    }
                                }
                                if (message.suggestions != null && message.hasOwnProperty("suggestions")) {
                                    if (properties.message === 1)
                                        return "message: multiple values";
                                    properties.message = 1;
                                    {
                                        var error = $root.google.cloud.dialogflow.v2beta1.Intent.Message.Suggestions.verify(message.suggestions);
                                        if (error)
                                            return "suggestions." + error;
                                    }
                                }
                                if (message.linkOutSuggestion != null && message.hasOwnProperty("linkOutSuggestion")) {
                                    if (properties.message === 1)
                                        return "message: multiple values";
                                    properties.message = 1;
                                    {
                                        var error = $root.google.cloud.dialogflow.v2beta1.Intent.Message.LinkOutSuggestion.verify(message.linkOutSuggestion);
                                        if (error)
                                            return "linkOutSuggestion." + error;
                                    }
                                }
                                if (message.listSelect != null && message.hasOwnProperty("listSelect")) {
                                    if (properties.message === 1)
                                        return "message: multiple values";
                                    properties.message = 1;
                                    {
                                        var error = $root.google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.verify(message.listSelect);
                                        if (error)
                                            return "listSelect." + error;
                                    }
                                }
                                if (message.carouselSelect != null && message.hasOwnProperty("carouselSelect")) {
                                    if (properties.message === 1)
                                        return "message: multiple values";
                                    properties.message = 1;
                                    {
                                        var error = $root.google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect.verify(message.carouselSelect);
                                        if (error)
                                            return "carouselSelect." + error;
                                    }
                                }
                                if (message.telephonyPlayAudio != null && message.hasOwnProperty("telephonyPlayAudio")) {
                                    if (properties.message === 1)
                                        return "message: multiple values";
                                    properties.message = 1;
                                    {
                                        var error = $root.google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyPlayAudio.verify(message.telephonyPlayAudio);
                                        if (error)
                                            return "telephonyPlayAudio." + error;
                                    }
                                }
                                if (message.telephonySynthesizeSpeech != null && message.hasOwnProperty("telephonySynthesizeSpeech")) {
                                    if (properties.message === 1)
                                        return "message: multiple values";
                                    properties.message = 1;
                                    {
                                        var error = $root.google.cloud.dialogflow.v2beta1.Intent.Message.TelephonySynthesizeSpeech.verify(message.telephonySynthesizeSpeech);
                                        if (error)
                                            return "telephonySynthesizeSpeech." + error;
                                    }
                                }
                                if (message.telephonyTransferCall != null && message.hasOwnProperty("telephonyTransferCall")) {
                                    if (properties.message === 1)
                                        return "message: multiple values";
                                    properties.message = 1;
                                    {
                                        var error = $root.google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyTransferCall.verify(message.telephonyTransferCall);
                                        if (error)
                                            return "telephonyTransferCall." + error;
                                    }
                                }
                                if (message.rbmText != null && message.hasOwnProperty("rbmText")) {
                                    if (properties.message === 1)
                                        return "message: multiple values";
                                    properties.message = 1;
                                    {
                                        var error = $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmText.verify(message.rbmText);
                                        if (error)
                                            return "rbmText." + error;
                                    }
                                }
                                if (message.rbmStandaloneRichCard != null && message.hasOwnProperty("rbmStandaloneRichCard")) {
                                    if (properties.message === 1)
                                        return "message: multiple values";
                                    properties.message = 1;
                                    {
                                        var error = $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmStandaloneCard.verify(message.rbmStandaloneRichCard);
                                        if (error)
                                            return "rbmStandaloneRichCard." + error;
                                    }
                                }
                                if (message.rbmCarouselRichCard != null && message.hasOwnProperty("rbmCarouselRichCard")) {
                                    if (properties.message === 1)
                                        return "message: multiple values";
                                    properties.message = 1;
                                    {
                                        var error = $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmCarouselCard.verify(message.rbmCarouselRichCard);
                                        if (error)
                                            return "rbmCarouselRichCard." + error;
                                    }
                                }
                                if (message.browseCarouselCard != null && message.hasOwnProperty("browseCarouselCard")) {
                                    if (properties.message === 1)
                                        return "message: multiple values";
                                    properties.message = 1;
                                    {
                                        var error = $root.google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.verify(message.browseCarouselCard);
                                        if (error)
                                            return "browseCarouselCard." + error;
                                    }
                                }
                                if (message.tableCard != null && message.hasOwnProperty("tableCard")) {
                                    if (properties.message === 1)
                                        return "message: multiple values";
                                    properties.message = 1;
                                    {
                                        var error = $root.google.cloud.dialogflow.v2beta1.Intent.Message.TableCard.verify(message.tableCard);
                                        if (error)
                                            return "tableCard." + error;
                                    }
                                }
                                if (message.mediaContent != null && message.hasOwnProperty("mediaContent")) {
                                    if (properties.message === 1)
                                        return "message: multiple values";
                                    properties.message = 1;
                                    {
                                        var error = $root.google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.verify(message.mediaContent);
                                        if (error)
                                            return "mediaContent." + error;
                                    }
                                }
                                if (message.platform != null && message.hasOwnProperty("platform"))
                                    switch (message.platform) {
                                    default:
                                        return "platform: enum value expected";
                                    case 0:
                                    case 1:
                                    case 2:
                                    case 3:
                                    case 4:
                                    case 5:
                                    case 6:
                                    case 7:
                                    case 8:
                                    case 10:
                                    case 11:
                                        break;
                                    }
                                return null;
                            };
    
                            /**
                             * Creates a Message message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2beta1.Intent.Message} Message
                             */
                            Message.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2beta1.Intent.Message)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message();
                                if (object.text != null) {
                                    if (typeof object.text !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.text: object expected");
                                    message.text = $root.google.cloud.dialogflow.v2beta1.Intent.Message.Text.fromObject(object.text);
                                }
                                if (object.image != null) {
                                    if (typeof object.image !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.image: object expected");
                                    message.image = $root.google.cloud.dialogflow.v2beta1.Intent.Message.Image.fromObject(object.image);
                                }
                                if (object.quickReplies != null) {
                                    if (typeof object.quickReplies !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.quickReplies: object expected");
                                    message.quickReplies = $root.google.cloud.dialogflow.v2beta1.Intent.Message.QuickReplies.fromObject(object.quickReplies);
                                }
                                if (object.card != null) {
                                    if (typeof object.card !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.card: object expected");
                                    message.card = $root.google.cloud.dialogflow.v2beta1.Intent.Message.Card.fromObject(object.card);
                                }
                                if (object.payload != null) {
                                    if (typeof object.payload !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.payload: object expected");
                                    message.payload = $root.google.protobuf.Struct.fromObject(object.payload);
                                }
                                if (object.simpleResponses != null) {
                                    if (typeof object.simpleResponses !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.simpleResponses: object expected");
                                    message.simpleResponses = $root.google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponses.fromObject(object.simpleResponses);
                                }
                                if (object.basicCard != null) {
                                    if (typeof object.basicCard !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.basicCard: object expected");
                                    message.basicCard = $root.google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.fromObject(object.basicCard);
                                }
                                if (object.suggestions != null) {
                                    if (typeof object.suggestions !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.suggestions: object expected");
                                    message.suggestions = $root.google.cloud.dialogflow.v2beta1.Intent.Message.Suggestions.fromObject(object.suggestions);
                                }
                                if (object.linkOutSuggestion != null) {
                                    if (typeof object.linkOutSuggestion !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.linkOutSuggestion: object expected");
                                    message.linkOutSuggestion = $root.google.cloud.dialogflow.v2beta1.Intent.Message.LinkOutSuggestion.fromObject(object.linkOutSuggestion);
                                }
                                if (object.listSelect != null) {
                                    if (typeof object.listSelect !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.listSelect: object expected");
                                    message.listSelect = $root.google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.fromObject(object.listSelect);
                                }
                                if (object.carouselSelect != null) {
                                    if (typeof object.carouselSelect !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.carouselSelect: object expected");
                                    message.carouselSelect = $root.google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect.fromObject(object.carouselSelect);
                                }
                                if (object.telephonyPlayAudio != null) {
                                    if (typeof object.telephonyPlayAudio !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.telephonyPlayAudio: object expected");
                                    message.telephonyPlayAudio = $root.google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyPlayAudio.fromObject(object.telephonyPlayAudio);
                                }
                                if (object.telephonySynthesizeSpeech != null) {
                                    if (typeof object.telephonySynthesizeSpeech !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.telephonySynthesizeSpeech: object expected");
                                    message.telephonySynthesizeSpeech = $root.google.cloud.dialogflow.v2beta1.Intent.Message.TelephonySynthesizeSpeech.fromObject(object.telephonySynthesizeSpeech);
                                }
                                if (object.telephonyTransferCall != null) {
                                    if (typeof object.telephonyTransferCall !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.telephonyTransferCall: object expected");
                                    message.telephonyTransferCall = $root.google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyTransferCall.fromObject(object.telephonyTransferCall);
                                }
                                if (object.rbmText != null) {
                                    if (typeof object.rbmText !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.rbmText: object expected");
                                    message.rbmText = $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmText.fromObject(object.rbmText);
                                }
                                if (object.rbmStandaloneRichCard != null) {
                                    if (typeof object.rbmStandaloneRichCard !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.rbmStandaloneRichCard: object expected");
                                    message.rbmStandaloneRichCard = $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmStandaloneCard.fromObject(object.rbmStandaloneRichCard);
                                }
                                if (object.rbmCarouselRichCard != null) {
                                    if (typeof object.rbmCarouselRichCard !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.rbmCarouselRichCard: object expected");
                                    message.rbmCarouselRichCard = $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmCarouselCard.fromObject(object.rbmCarouselRichCard);
                                }
                                if (object.browseCarouselCard != null) {
                                    if (typeof object.browseCarouselCard !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.browseCarouselCard: object expected");
                                    message.browseCarouselCard = $root.google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.fromObject(object.browseCarouselCard);
                                }
                                if (object.tableCard != null) {
                                    if (typeof object.tableCard !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.tableCard: object expected");
                                    message.tableCard = $root.google.cloud.dialogflow.v2beta1.Intent.Message.TableCard.fromObject(object.tableCard);
                                }
                                if (object.mediaContent != null) {
                                    if (typeof object.mediaContent !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.mediaContent: object expected");
                                    message.mediaContent = $root.google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.fromObject(object.mediaContent);
                                }
                                switch (object.platform) {
                                default:
                                    if (typeof object.platform === "number") {
                                        message.platform = object.platform;
                                        break;
                                    }
                                    break;
                                case "PLATFORM_UNSPECIFIED":
                                case 0:
                                    message.platform = 0;
                                    break;
                                case "FACEBOOK":
                                case 1:
                                    message.platform = 1;
                                    break;
                                case "SLACK":
                                case 2:
                                    message.platform = 2;
                                    break;
                                case "TELEGRAM":
                                case 3:
                                    message.platform = 3;
                                    break;
                                case "KIK":
                                case 4:
                                    message.platform = 4;
                                    break;
                                case "SKYPE":
                                case 5:
                                    message.platform = 5;
                                    break;
                                case "LINE":
                                case 6:
                                    message.platform = 6;
                                    break;
                                case "VIBER":
                                case 7:
                                    message.platform = 7;
                                    break;
                                case "ACTIONS_ON_GOOGLE":
                                case 8:
                                    message.platform = 8;
                                    break;
                                case "TELEPHONY":
                                case 10:
                                    message.platform = 10;
                                    break;
                                case "GOOGLE_HANGOUTS":
                                case 11:
                                    message.platform = 11;
                                    break;
                                }
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a Message message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.Intent.Message} message Message
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            Message.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.defaults)
                                    object.platform = options.enums === String ? "PLATFORM_UNSPECIFIED" : 0;
                                if (message.text != null && message.hasOwnProperty("text")) {
                                    object.text = $root.google.cloud.dialogflow.v2beta1.Intent.Message.Text.toObject(message.text, options);
                                    if (options.oneofs)
                                        object.message = "text";
                                }
                                if (message.image != null && message.hasOwnProperty("image")) {
                                    object.image = $root.google.cloud.dialogflow.v2beta1.Intent.Message.Image.toObject(message.image, options);
                                    if (options.oneofs)
                                        object.message = "image";
                                }
                                if (message.quickReplies != null && message.hasOwnProperty("quickReplies")) {
                                    object.quickReplies = $root.google.cloud.dialogflow.v2beta1.Intent.Message.QuickReplies.toObject(message.quickReplies, options);
                                    if (options.oneofs)
                                        object.message = "quickReplies";
                                }
                                if (message.card != null && message.hasOwnProperty("card")) {
                                    object.card = $root.google.cloud.dialogflow.v2beta1.Intent.Message.Card.toObject(message.card, options);
                                    if (options.oneofs)
                                        object.message = "card";
                                }
                                if (message.payload != null && message.hasOwnProperty("payload")) {
                                    object.payload = $root.google.protobuf.Struct.toObject(message.payload, options);
                                    if (options.oneofs)
                                        object.message = "payload";
                                }
                                if (message.platform != null && message.hasOwnProperty("platform"))
                                    object.platform = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.Intent.Message.Platform[message.platform] === undefined ? message.platform : $root.google.cloud.dialogflow.v2beta1.Intent.Message.Platform[message.platform] : message.platform;
                                if (message.simpleResponses != null && message.hasOwnProperty("simpleResponses")) {
                                    object.simpleResponses = $root.google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponses.toObject(message.simpleResponses, options);
                                    if (options.oneofs)
                                        object.message = "simpleResponses";
                                }
                                if (message.basicCard != null && message.hasOwnProperty("basicCard")) {
                                    object.basicCard = $root.google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.toObject(message.basicCard, options);
                                    if (options.oneofs)
                                        object.message = "basicCard";
                                }
                                if (message.suggestions != null && message.hasOwnProperty("suggestions")) {
                                    object.suggestions = $root.google.cloud.dialogflow.v2beta1.Intent.Message.Suggestions.toObject(message.suggestions, options);
                                    if (options.oneofs)
                                        object.message = "suggestions";
                                }
                                if (message.linkOutSuggestion != null && message.hasOwnProperty("linkOutSuggestion")) {
                                    object.linkOutSuggestion = $root.google.cloud.dialogflow.v2beta1.Intent.Message.LinkOutSuggestion.toObject(message.linkOutSuggestion, options);
                                    if (options.oneofs)
                                        object.message = "linkOutSuggestion";
                                }
                                if (message.listSelect != null && message.hasOwnProperty("listSelect")) {
                                    object.listSelect = $root.google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.toObject(message.listSelect, options);
                                    if (options.oneofs)
                                        object.message = "listSelect";
                                }
                                if (message.carouselSelect != null && message.hasOwnProperty("carouselSelect")) {
                                    object.carouselSelect = $root.google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect.toObject(message.carouselSelect, options);
                                    if (options.oneofs)
                                        object.message = "carouselSelect";
                                }
                                if (message.telephonyPlayAudio != null && message.hasOwnProperty("telephonyPlayAudio")) {
                                    object.telephonyPlayAudio = $root.google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyPlayAudio.toObject(message.telephonyPlayAudio, options);
                                    if (options.oneofs)
                                        object.message = "telephonyPlayAudio";
                                }
                                if (message.telephonySynthesizeSpeech != null && message.hasOwnProperty("telephonySynthesizeSpeech")) {
                                    object.telephonySynthesizeSpeech = $root.google.cloud.dialogflow.v2beta1.Intent.Message.TelephonySynthesizeSpeech.toObject(message.telephonySynthesizeSpeech, options);
                                    if (options.oneofs)
                                        object.message = "telephonySynthesizeSpeech";
                                }
                                if (message.telephonyTransferCall != null && message.hasOwnProperty("telephonyTransferCall")) {
                                    object.telephonyTransferCall = $root.google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyTransferCall.toObject(message.telephonyTransferCall, options);
                                    if (options.oneofs)
                                        object.message = "telephonyTransferCall";
                                }
                                if (message.rbmText != null && message.hasOwnProperty("rbmText")) {
                                    object.rbmText = $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmText.toObject(message.rbmText, options);
                                    if (options.oneofs)
                                        object.message = "rbmText";
                                }
                                if (message.rbmStandaloneRichCard != null && message.hasOwnProperty("rbmStandaloneRichCard")) {
                                    object.rbmStandaloneRichCard = $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmStandaloneCard.toObject(message.rbmStandaloneRichCard, options);
                                    if (options.oneofs)
                                        object.message = "rbmStandaloneRichCard";
                                }
                                if (message.rbmCarouselRichCard != null && message.hasOwnProperty("rbmCarouselRichCard")) {
                                    object.rbmCarouselRichCard = $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmCarouselCard.toObject(message.rbmCarouselRichCard, options);
                                    if (options.oneofs)
                                        object.message = "rbmCarouselRichCard";
                                }
                                if (message.browseCarouselCard != null && message.hasOwnProperty("browseCarouselCard")) {
                                    object.browseCarouselCard = $root.google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.toObject(message.browseCarouselCard, options);
                                    if (options.oneofs)
                                        object.message = "browseCarouselCard";
                                }
                                if (message.tableCard != null && message.hasOwnProperty("tableCard")) {
                                    object.tableCard = $root.google.cloud.dialogflow.v2beta1.Intent.Message.TableCard.toObject(message.tableCard, options);
                                    if (options.oneofs)
                                        object.message = "tableCard";
                                }
                                if (message.mediaContent != null && message.hasOwnProperty("mediaContent")) {
                                    object.mediaContent = $root.google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.toObject(message.mediaContent, options);
                                    if (options.oneofs)
                                        object.message = "mediaContent";
                                }
                                return object;
                            };
    
                            /**
                             * Converts this Message to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            Message.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for Message
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            Message.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Intent.Message";
                            };
    
                            /**
                             * Platform enum.
                             * @name google.cloud.dialogflow.v2beta1.Intent.Message.Platform
                             * @enum {number}
                             * @property {number} PLATFORM_UNSPECIFIED=0 PLATFORM_UNSPECIFIED value
                             * @property {number} FACEBOOK=1 FACEBOOK value
                             * @property {number} SLACK=2 SLACK value
                             * @property {number} TELEGRAM=3 TELEGRAM value
                             * @property {number} KIK=4 KIK value
                             * @property {number} SKYPE=5 SKYPE value
                             * @property {number} LINE=6 LINE value
                             * @property {number} VIBER=7 VIBER value
                             * @property {number} ACTIONS_ON_GOOGLE=8 ACTIONS_ON_GOOGLE value
                             * @property {number} TELEPHONY=10 TELEPHONY value
                             * @property {number} GOOGLE_HANGOUTS=11 GOOGLE_HANGOUTS value
                             */
                            Message.Platform = (function() {
                                var valuesById = {}, values = Object.create(valuesById);
                                values[valuesById[0] = "PLATFORM_UNSPECIFIED"] = 0;
                                values[valuesById[1] = "FACEBOOK"] = 1;
                                values[valuesById[2] = "SLACK"] = 2;
                                values[valuesById[3] = "TELEGRAM"] = 3;
                                values[valuesById[4] = "KIK"] = 4;
                                values[valuesById[5] = "SKYPE"] = 5;
                                values[valuesById[6] = "LINE"] = 6;
                                values[valuesById[7] = "VIBER"] = 7;
                                values[valuesById[8] = "ACTIONS_ON_GOOGLE"] = 8;
                                values[valuesById[10] = "TELEPHONY"] = 10;
                                values[valuesById[11] = "GOOGLE_HANGOUTS"] = 11;
                                return values;
                            })();
    
                            Message.Text = (function() {
    
                                /**
                                 * Properties of a Text.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @interface IText
                                 * @property {Array.<string>|null} [text] Text text
                                 */
    
                                /**
                                 * Constructs a new Text.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @classdesc Represents a Text.
                                 * @implements IText
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IText=} [properties] Properties to set
                                 */
                                function Text(properties) {
                                    this.text = [];
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * Text text.
                                 * @member {Array.<string>} text
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Text
                                 * @instance
                                 */
                                Text.prototype.text = $util.emptyArray;
    
                                /**
                                 * Creates a new Text instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Text
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IText=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.Text} Text instance
                                 */
                                Text.create = function create(properties) {
                                    return new Text(properties);
                                };
    
                                /**
                                 * Encodes the specified Text message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.Text.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Text
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IText} message Text message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                Text.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.text != null && message.text.length)
                                        for (var i = 0; i < message.text.length; ++i)
                                            writer.uint32(/* id 1, wireType 2 =*/10).string(message.text[i]);
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified Text message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.Text.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Text
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IText} message Text message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                Text.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a Text message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Text
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.Text} Text
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                Text.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.Text();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                if (!(message.text && message.text.length))
                                                    message.text = [];
                                                message.text.push(reader.string());
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a Text message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Text
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.Text} Text
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                Text.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a Text message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Text
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                Text.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.text != null && message.hasOwnProperty("text")) {
                                        if (!Array.isArray(message.text))
                                            return "text: array expected";
                                        for (var i = 0; i < message.text.length; ++i)
                                            if (!$util.isString(message.text[i]))
                                                return "text: string[] expected";
                                    }
                                    return null;
                                };
    
                                /**
                                 * Creates a Text message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Text
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.Text} Text
                                 */
                                Text.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2beta1.Intent.Message.Text)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.Text();
                                    if (object.text) {
                                        if (!Array.isArray(object.text))
                                            throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.Text.text: array expected");
                                        message.text = [];
                                        for (var i = 0; i < object.text.length; ++i)
                                            message.text[i] = String(object.text[i]);
                                    }
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a Text message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Text
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.Text} message Text
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                Text.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.arrays || options.defaults)
                                        object.text = [];
                                    if (message.text && message.text.length) {
                                        object.text = [];
                                        for (var j = 0; j < message.text.length; ++j)
                                            object.text[j] = message.text[j];
                                    }
                                    return object;
                                };
    
                                /**
                                 * Converts this Text to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Text
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                Text.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for Text
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Text
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                Text.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Intent.Message.Text";
                                };
    
                                return Text;
                            })();
    
                            Message.Image = (function() {
    
                                /**
                                 * Properties of an Image.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @interface IImage
                                 * @property {string|null} [imageUri] Image imageUri
                                 * @property {string|null} [accessibilityText] Image accessibilityText
                                 */
    
                                /**
                                 * Constructs a new Image.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @classdesc Represents an Image.
                                 * @implements IImage
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IImage=} [properties] Properties to set
                                 */
                                function Image(properties) {
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * Image imageUri.
                                 * @member {string} imageUri
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Image
                                 * @instance
                                 */
                                Image.prototype.imageUri = "";
    
                                /**
                                 * Image accessibilityText.
                                 * @member {string} accessibilityText
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Image
                                 * @instance
                                 */
                                Image.prototype.accessibilityText = "";
    
                                /**
                                 * Creates a new Image instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Image
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IImage=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.Image} Image instance
                                 */
                                Image.create = function create(properties) {
                                    return new Image(properties);
                                };
    
                                /**
                                 * Encodes the specified Image message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.Image.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Image
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IImage} message Image message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                Image.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.imageUri != null && Object.hasOwnProperty.call(message, "imageUri"))
                                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.imageUri);
                                    if (message.accessibilityText != null && Object.hasOwnProperty.call(message, "accessibilityText"))
                                        writer.uint32(/* id 2, wireType 2 =*/18).string(message.accessibilityText);
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified Image message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.Image.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Image
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IImage} message Image message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                Image.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes an Image message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Image
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.Image} Image
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                Image.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.Image();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                message.imageUri = reader.string();
                                                break;
                                            }
                                        case 2: {
                                                message.accessibilityText = reader.string();
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes an Image message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Image
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.Image} Image
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                Image.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies an Image message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Image
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                Image.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.imageUri != null && message.hasOwnProperty("imageUri"))
                                        if (!$util.isString(message.imageUri))
                                            return "imageUri: string expected";
                                    if (message.accessibilityText != null && message.hasOwnProperty("accessibilityText"))
                                        if (!$util.isString(message.accessibilityText))
                                            return "accessibilityText: string expected";
                                    return null;
                                };
    
                                /**
                                 * Creates an Image message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Image
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.Image} Image
                                 */
                                Image.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2beta1.Intent.Message.Image)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.Image();
                                    if (object.imageUri != null)
                                        message.imageUri = String(object.imageUri);
                                    if (object.accessibilityText != null)
                                        message.accessibilityText = String(object.accessibilityText);
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from an Image message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Image
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.Image} message Image
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                Image.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.defaults) {
                                        object.imageUri = "";
                                        object.accessibilityText = "";
                                    }
                                    if (message.imageUri != null && message.hasOwnProperty("imageUri"))
                                        object.imageUri = message.imageUri;
                                    if (message.accessibilityText != null && message.hasOwnProperty("accessibilityText"))
                                        object.accessibilityText = message.accessibilityText;
                                    return object;
                                };
    
                                /**
                                 * Converts this Image to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Image
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                Image.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for Image
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Image
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                Image.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Intent.Message.Image";
                                };
    
                                return Image;
                            })();
    
                            Message.QuickReplies = (function() {
    
                                /**
                                 * Properties of a QuickReplies.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @interface IQuickReplies
                                 * @property {string|null} [title] QuickReplies title
                                 * @property {Array.<string>|null} [quickReplies] QuickReplies quickReplies
                                 */
    
                                /**
                                 * Constructs a new QuickReplies.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @classdesc Represents a QuickReplies.
                                 * @implements IQuickReplies
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IQuickReplies=} [properties] Properties to set
                                 */
                                function QuickReplies(properties) {
                                    this.quickReplies = [];
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * QuickReplies title.
                                 * @member {string} title
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.QuickReplies
                                 * @instance
                                 */
                                QuickReplies.prototype.title = "";
    
                                /**
                                 * QuickReplies quickReplies.
                                 * @member {Array.<string>} quickReplies
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.QuickReplies
                                 * @instance
                                 */
                                QuickReplies.prototype.quickReplies = $util.emptyArray;
    
                                /**
                                 * Creates a new QuickReplies instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.QuickReplies
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IQuickReplies=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.QuickReplies} QuickReplies instance
                                 */
                                QuickReplies.create = function create(properties) {
                                    return new QuickReplies(properties);
                                };
    
                                /**
                                 * Encodes the specified QuickReplies message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.QuickReplies.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.QuickReplies
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IQuickReplies} message QuickReplies message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                QuickReplies.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.title != null && Object.hasOwnProperty.call(message, "title"))
                                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.title);
                                    if (message.quickReplies != null && message.quickReplies.length)
                                        for (var i = 0; i < message.quickReplies.length; ++i)
                                            writer.uint32(/* id 2, wireType 2 =*/18).string(message.quickReplies[i]);
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified QuickReplies message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.QuickReplies.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.QuickReplies
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IQuickReplies} message QuickReplies message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                QuickReplies.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a QuickReplies message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.QuickReplies
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.QuickReplies} QuickReplies
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                QuickReplies.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.QuickReplies();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                message.title = reader.string();
                                                break;
                                            }
                                        case 2: {
                                                if (!(message.quickReplies && message.quickReplies.length))
                                                    message.quickReplies = [];
                                                message.quickReplies.push(reader.string());
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a QuickReplies message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.QuickReplies
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.QuickReplies} QuickReplies
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                QuickReplies.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a QuickReplies message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.QuickReplies
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                QuickReplies.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.title != null && message.hasOwnProperty("title"))
                                        if (!$util.isString(message.title))
                                            return "title: string expected";
                                    if (message.quickReplies != null && message.hasOwnProperty("quickReplies")) {
                                        if (!Array.isArray(message.quickReplies))
                                            return "quickReplies: array expected";
                                        for (var i = 0; i < message.quickReplies.length; ++i)
                                            if (!$util.isString(message.quickReplies[i]))
                                                return "quickReplies: string[] expected";
                                    }
                                    return null;
                                };
    
                                /**
                                 * Creates a QuickReplies message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.QuickReplies
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.QuickReplies} QuickReplies
                                 */
                                QuickReplies.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2beta1.Intent.Message.QuickReplies)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.QuickReplies();
                                    if (object.title != null)
                                        message.title = String(object.title);
                                    if (object.quickReplies) {
                                        if (!Array.isArray(object.quickReplies))
                                            throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.QuickReplies.quickReplies: array expected");
                                        message.quickReplies = [];
                                        for (var i = 0; i < object.quickReplies.length; ++i)
                                            message.quickReplies[i] = String(object.quickReplies[i]);
                                    }
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a QuickReplies message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.QuickReplies
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.QuickReplies} message QuickReplies
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                QuickReplies.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.arrays || options.defaults)
                                        object.quickReplies = [];
                                    if (options.defaults)
                                        object.title = "";
                                    if (message.title != null && message.hasOwnProperty("title"))
                                        object.title = message.title;
                                    if (message.quickReplies && message.quickReplies.length) {
                                        object.quickReplies = [];
                                        for (var j = 0; j < message.quickReplies.length; ++j)
                                            object.quickReplies[j] = message.quickReplies[j];
                                    }
                                    return object;
                                };
    
                                /**
                                 * Converts this QuickReplies to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.QuickReplies
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                QuickReplies.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for QuickReplies
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.QuickReplies
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                QuickReplies.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Intent.Message.QuickReplies";
                                };
    
                                return QuickReplies;
                            })();
    
                            Message.Card = (function() {
    
                                /**
                                 * Properties of a Card.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @interface ICard
                                 * @property {string|null} [title] Card title
                                 * @property {string|null} [subtitle] Card subtitle
                                 * @property {string|null} [imageUri] Card imageUri
                                 * @property {Array.<google.cloud.dialogflow.v2beta1.Intent.Message.Card.IButton>|null} [buttons] Card buttons
                                 */
    
                                /**
                                 * Constructs a new Card.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @classdesc Represents a Card.
                                 * @implements ICard
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ICard=} [properties] Properties to set
                                 */
                                function Card(properties) {
                                    this.buttons = [];
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * Card title.
                                 * @member {string} title
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Card
                                 * @instance
                                 */
                                Card.prototype.title = "";
    
                                /**
                                 * Card subtitle.
                                 * @member {string} subtitle
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Card
                                 * @instance
                                 */
                                Card.prototype.subtitle = "";
    
                                /**
                                 * Card imageUri.
                                 * @member {string} imageUri
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Card
                                 * @instance
                                 */
                                Card.prototype.imageUri = "";
    
                                /**
                                 * Card buttons.
                                 * @member {Array.<google.cloud.dialogflow.v2beta1.Intent.Message.Card.IButton>} buttons
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Card
                                 * @instance
                                 */
                                Card.prototype.buttons = $util.emptyArray;
    
                                /**
                                 * Creates a new Card instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Card
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ICard=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.Card} Card instance
                                 */
                                Card.create = function create(properties) {
                                    return new Card(properties);
                                };
    
                                /**
                                 * Encodes the specified Card message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.Card.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Card
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ICard} message Card message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                Card.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.title != null && Object.hasOwnProperty.call(message, "title"))
                                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.title);
                                    if (message.subtitle != null && Object.hasOwnProperty.call(message, "subtitle"))
                                        writer.uint32(/* id 2, wireType 2 =*/18).string(message.subtitle);
                                    if (message.imageUri != null && Object.hasOwnProperty.call(message, "imageUri"))
                                        writer.uint32(/* id 3, wireType 2 =*/26).string(message.imageUri);
                                    if (message.buttons != null && message.buttons.length)
                                        for (var i = 0; i < message.buttons.length; ++i)
                                            $root.google.cloud.dialogflow.v2beta1.Intent.Message.Card.Button.encode(message.buttons[i], writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified Card message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.Card.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Card
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ICard} message Card message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                Card.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a Card message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Card
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.Card} Card
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                Card.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.Card();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                message.title = reader.string();
                                                break;
                                            }
                                        case 2: {
                                                message.subtitle = reader.string();
                                                break;
                                            }
                                        case 3: {
                                                message.imageUri = reader.string();
                                                break;
                                            }
                                        case 4: {
                                                if (!(message.buttons && message.buttons.length))
                                                    message.buttons = [];
                                                message.buttons.push($root.google.cloud.dialogflow.v2beta1.Intent.Message.Card.Button.decode(reader, reader.uint32()));
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a Card message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Card
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.Card} Card
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                Card.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a Card message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Card
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                Card.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.title != null && message.hasOwnProperty("title"))
                                        if (!$util.isString(message.title))
                                            return "title: string expected";
                                    if (message.subtitle != null && message.hasOwnProperty("subtitle"))
                                        if (!$util.isString(message.subtitle))
                                            return "subtitle: string expected";
                                    if (message.imageUri != null && message.hasOwnProperty("imageUri"))
                                        if (!$util.isString(message.imageUri))
                                            return "imageUri: string expected";
                                    if (message.buttons != null && message.hasOwnProperty("buttons")) {
                                        if (!Array.isArray(message.buttons))
                                            return "buttons: array expected";
                                        for (var i = 0; i < message.buttons.length; ++i) {
                                            var error = $root.google.cloud.dialogflow.v2beta1.Intent.Message.Card.Button.verify(message.buttons[i]);
                                            if (error)
                                                return "buttons." + error;
                                        }
                                    }
                                    return null;
                                };
    
                                /**
                                 * Creates a Card message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Card
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.Card} Card
                                 */
                                Card.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2beta1.Intent.Message.Card)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.Card();
                                    if (object.title != null)
                                        message.title = String(object.title);
                                    if (object.subtitle != null)
                                        message.subtitle = String(object.subtitle);
                                    if (object.imageUri != null)
                                        message.imageUri = String(object.imageUri);
                                    if (object.buttons) {
                                        if (!Array.isArray(object.buttons))
                                            throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.Card.buttons: array expected");
                                        message.buttons = [];
                                        for (var i = 0; i < object.buttons.length; ++i) {
                                            if (typeof object.buttons[i] !== "object")
                                                throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.Card.buttons: object expected");
                                            message.buttons[i] = $root.google.cloud.dialogflow.v2beta1.Intent.Message.Card.Button.fromObject(object.buttons[i]);
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a Card message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Card
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.Card} message Card
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                Card.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.arrays || options.defaults)
                                        object.buttons = [];
                                    if (options.defaults) {
                                        object.title = "";
                                        object.subtitle = "";
                                        object.imageUri = "";
                                    }
                                    if (message.title != null && message.hasOwnProperty("title"))
                                        object.title = message.title;
                                    if (message.subtitle != null && message.hasOwnProperty("subtitle"))
                                        object.subtitle = message.subtitle;
                                    if (message.imageUri != null && message.hasOwnProperty("imageUri"))
                                        object.imageUri = message.imageUri;
                                    if (message.buttons && message.buttons.length) {
                                        object.buttons = [];
                                        for (var j = 0; j < message.buttons.length; ++j)
                                            object.buttons[j] = $root.google.cloud.dialogflow.v2beta1.Intent.Message.Card.Button.toObject(message.buttons[j], options);
                                    }
                                    return object;
                                };
    
                                /**
                                 * Converts this Card to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Card
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                Card.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for Card
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Card
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                Card.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Intent.Message.Card";
                                };
    
                                Card.Button = (function() {
    
                                    /**
                                     * Properties of a Button.
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Card
                                     * @interface IButton
                                     * @property {string|null} [text] Button text
                                     * @property {string|null} [postback] Button postback
                                     */
    
                                    /**
                                     * Constructs a new Button.
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Card
                                     * @classdesc Represents a Button.
                                     * @implements IButton
                                     * @constructor
                                     * @param {google.cloud.dialogflow.v2beta1.Intent.Message.Card.IButton=} [properties] Properties to set
                                     */
                                    function Button(properties) {
                                        if (properties)
                                            for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                                if (properties[keys[i]] != null)
                                                    this[keys[i]] = properties[keys[i]];
                                    }
    
                                    /**
                                     * Button text.
                                     * @member {string} text
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Card.Button
                                     * @instance
                                     */
                                    Button.prototype.text = "";
    
                                    /**
                                     * Button postback.
                                     * @member {string} postback
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Card.Button
                                     * @instance
                                     */
                                    Button.prototype.postback = "";
    
                                    /**
                                     * Creates a new Button instance using the specified properties.
                                     * @function create
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Card.Button
                                     * @static
                                     * @param {google.cloud.dialogflow.v2beta1.Intent.Message.Card.IButton=} [properties] Properties to set
                                     * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.Card.Button} Button instance
                                     */
                                    Button.create = function create(properties) {
                                        return new Button(properties);
                                    };
    
                                    /**
                                     * Encodes the specified Button message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.Card.Button.verify|verify} messages.
                                     * @function encode
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Card.Button
                                     * @static
                                     * @param {google.cloud.dialogflow.v2beta1.Intent.Message.Card.IButton} message Button message or plain object to encode
                                     * @param {$protobuf.Writer} [writer] Writer to encode to
                                     * @returns {$protobuf.Writer} Writer
                                     */
                                    Button.encode = function encode(message, writer) {
                                        if (!writer)
                                            writer = $Writer.create();
                                        if (message.text != null && Object.hasOwnProperty.call(message, "text"))
                                            writer.uint32(/* id 1, wireType 2 =*/10).string(message.text);
                                        if (message.postback != null && Object.hasOwnProperty.call(message, "postback"))
                                            writer.uint32(/* id 2, wireType 2 =*/18).string(message.postback);
                                        return writer;
                                    };
    
                                    /**
                                     * Encodes the specified Button message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.Card.Button.verify|verify} messages.
                                     * @function encodeDelimited
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Card.Button
                                     * @static
                                     * @param {google.cloud.dialogflow.v2beta1.Intent.Message.Card.IButton} message Button message or plain object to encode
                                     * @param {$protobuf.Writer} [writer] Writer to encode to
                                     * @returns {$protobuf.Writer} Writer
                                     */
                                    Button.encodeDelimited = function encodeDelimited(message, writer) {
                                        return this.encode(message, writer).ldelim();
                                    };
    
                                    /**
                                     * Decodes a Button message from the specified reader or buffer.
                                     * @function decode
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Card.Button
                                     * @static
                                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                     * @param {number} [length] Message length if known beforehand
                                     * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.Card.Button} Button
                                     * @throws {Error} If the payload is not a reader or valid buffer
                                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                     */
                                    Button.decode = function decode(reader, length) {
                                        if (!(reader instanceof $Reader))
                                            reader = $Reader.create(reader);
                                        var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.Card.Button();
                                        while (reader.pos < end) {
                                            var tag = reader.uint32();
                                            switch (tag >>> 3) {
                                            case 1: {
                                                    message.text = reader.string();
                                                    break;
                                                }
                                            case 2: {
                                                    message.postback = reader.string();
                                                    break;
                                                }
                                            default:
                                                reader.skipType(tag & 7);
                                                break;
                                            }
                                        }
                                        return message;
                                    };
    
                                    /**
                                     * Decodes a Button message from the specified reader or buffer, length delimited.
                                     * @function decodeDelimited
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Card.Button
                                     * @static
                                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                     * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.Card.Button} Button
                                     * @throws {Error} If the payload is not a reader or valid buffer
                                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                     */
                                    Button.decodeDelimited = function decodeDelimited(reader) {
                                        if (!(reader instanceof $Reader))
                                            reader = new $Reader(reader);
                                        return this.decode(reader, reader.uint32());
                                    };
    
                                    /**
                                     * Verifies a Button message.
                                     * @function verify
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Card.Button
                                     * @static
                                     * @param {Object.<string,*>} message Plain object to verify
                                     * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                     */
                                    Button.verify = function verify(message) {
                                        if (typeof message !== "object" || message === null)
                                            return "object expected";
                                        if (message.text != null && message.hasOwnProperty("text"))
                                            if (!$util.isString(message.text))
                                                return "text: string expected";
                                        if (message.postback != null && message.hasOwnProperty("postback"))
                                            if (!$util.isString(message.postback))
                                                return "postback: string expected";
                                        return null;
                                    };
    
                                    /**
                                     * Creates a Button message from a plain object. Also converts values to their respective internal types.
                                     * @function fromObject
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Card.Button
                                     * @static
                                     * @param {Object.<string,*>} object Plain object
                                     * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.Card.Button} Button
                                     */
                                    Button.fromObject = function fromObject(object) {
                                        if (object instanceof $root.google.cloud.dialogflow.v2beta1.Intent.Message.Card.Button)
                                            return object;
                                        var message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.Card.Button();
                                        if (object.text != null)
                                            message.text = String(object.text);
                                        if (object.postback != null)
                                            message.postback = String(object.postback);
                                        return message;
                                    };
    
                                    /**
                                     * Creates a plain object from a Button message. Also converts values to other types if specified.
                                     * @function toObject
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Card.Button
                                     * @static
                                     * @param {google.cloud.dialogflow.v2beta1.Intent.Message.Card.Button} message Button
                                     * @param {$protobuf.IConversionOptions} [options] Conversion options
                                     * @returns {Object.<string,*>} Plain object
                                     */
                                    Button.toObject = function toObject(message, options) {
                                        if (!options)
                                            options = {};
                                        var object = {};
                                        if (options.defaults) {
                                            object.text = "";
                                            object.postback = "";
                                        }
                                        if (message.text != null && message.hasOwnProperty("text"))
                                            object.text = message.text;
                                        if (message.postback != null && message.hasOwnProperty("postback"))
                                            object.postback = message.postback;
                                        return object;
                                    };
    
                                    /**
                                     * Converts this Button to JSON.
                                     * @function toJSON
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Card.Button
                                     * @instance
                                     * @returns {Object.<string,*>} JSON object
                                     */
                                    Button.prototype.toJSON = function toJSON() {
                                        return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                    };
    
                                    /**
                                     * Gets the default type url for Button
                                     * @function getTypeUrl
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Card.Button
                                     * @static
                                     * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                     * @returns {string} The default type url
                                     */
                                    Button.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                        if (typeUrlPrefix === undefined) {
                                            typeUrlPrefix = "type.googleapis.com";
                                        }
                                        return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Intent.Message.Card.Button";
                                    };
    
                                    return Button;
                                })();
    
                                return Card;
                            })();
    
                            Message.SimpleResponse = (function() {
    
                                /**
                                 * Properties of a SimpleResponse.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @interface ISimpleResponse
                                 * @property {string|null} [textToSpeech] SimpleResponse textToSpeech
                                 * @property {string|null} [ssml] SimpleResponse ssml
                                 * @property {string|null} [displayText] SimpleResponse displayText
                                 */
    
                                /**
                                 * Constructs a new SimpleResponse.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @classdesc Represents a SimpleResponse.
                                 * @implements ISimpleResponse
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ISimpleResponse=} [properties] Properties to set
                                 */
                                function SimpleResponse(properties) {
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * SimpleResponse textToSpeech.
                                 * @member {string} textToSpeech
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponse
                                 * @instance
                                 */
                                SimpleResponse.prototype.textToSpeech = "";
    
                                /**
                                 * SimpleResponse ssml.
                                 * @member {string} ssml
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponse
                                 * @instance
                                 */
                                SimpleResponse.prototype.ssml = "";
    
                                /**
                                 * SimpleResponse displayText.
                                 * @member {string} displayText
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponse
                                 * @instance
                                 */
                                SimpleResponse.prototype.displayText = "";
    
                                /**
                                 * Creates a new SimpleResponse instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponse
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ISimpleResponse=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponse} SimpleResponse instance
                                 */
                                SimpleResponse.create = function create(properties) {
                                    return new SimpleResponse(properties);
                                };
    
                                /**
                                 * Encodes the specified SimpleResponse message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponse.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponse
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ISimpleResponse} message SimpleResponse message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                SimpleResponse.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.textToSpeech != null && Object.hasOwnProperty.call(message, "textToSpeech"))
                                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.textToSpeech);
                                    if (message.ssml != null && Object.hasOwnProperty.call(message, "ssml"))
                                        writer.uint32(/* id 2, wireType 2 =*/18).string(message.ssml);
                                    if (message.displayText != null && Object.hasOwnProperty.call(message, "displayText"))
                                        writer.uint32(/* id 3, wireType 2 =*/26).string(message.displayText);
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified SimpleResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponse.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponse
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ISimpleResponse} message SimpleResponse message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                SimpleResponse.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a SimpleResponse message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponse
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponse} SimpleResponse
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                SimpleResponse.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponse();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                message.textToSpeech = reader.string();
                                                break;
                                            }
                                        case 2: {
                                                message.ssml = reader.string();
                                                break;
                                            }
                                        case 3: {
                                                message.displayText = reader.string();
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a SimpleResponse message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponse
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponse} SimpleResponse
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                SimpleResponse.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a SimpleResponse message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponse
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                SimpleResponse.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.textToSpeech != null && message.hasOwnProperty("textToSpeech"))
                                        if (!$util.isString(message.textToSpeech))
                                            return "textToSpeech: string expected";
                                    if (message.ssml != null && message.hasOwnProperty("ssml"))
                                        if (!$util.isString(message.ssml))
                                            return "ssml: string expected";
                                    if (message.displayText != null && message.hasOwnProperty("displayText"))
                                        if (!$util.isString(message.displayText))
                                            return "displayText: string expected";
                                    return null;
                                };
    
                                /**
                                 * Creates a SimpleResponse message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponse
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponse} SimpleResponse
                                 */
                                SimpleResponse.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponse)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponse();
                                    if (object.textToSpeech != null)
                                        message.textToSpeech = String(object.textToSpeech);
                                    if (object.ssml != null)
                                        message.ssml = String(object.ssml);
                                    if (object.displayText != null)
                                        message.displayText = String(object.displayText);
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a SimpleResponse message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponse
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponse} message SimpleResponse
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                SimpleResponse.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.defaults) {
                                        object.textToSpeech = "";
                                        object.ssml = "";
                                        object.displayText = "";
                                    }
                                    if (message.textToSpeech != null && message.hasOwnProperty("textToSpeech"))
                                        object.textToSpeech = message.textToSpeech;
                                    if (message.ssml != null && message.hasOwnProperty("ssml"))
                                        object.ssml = message.ssml;
                                    if (message.displayText != null && message.hasOwnProperty("displayText"))
                                        object.displayText = message.displayText;
                                    return object;
                                };
    
                                /**
                                 * Converts this SimpleResponse to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponse
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                SimpleResponse.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for SimpleResponse
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponse
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                SimpleResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponse";
                                };
    
                                return SimpleResponse;
                            })();
    
                            Message.SimpleResponses = (function() {
    
                                /**
                                 * Properties of a SimpleResponses.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @interface ISimpleResponses
                                 * @property {Array.<google.cloud.dialogflow.v2beta1.Intent.Message.ISimpleResponse>|null} [simpleResponses] SimpleResponses simpleResponses
                                 */
    
                                /**
                                 * Constructs a new SimpleResponses.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @classdesc Represents a SimpleResponses.
                                 * @implements ISimpleResponses
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ISimpleResponses=} [properties] Properties to set
                                 */
                                function SimpleResponses(properties) {
                                    this.simpleResponses = [];
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * SimpleResponses simpleResponses.
                                 * @member {Array.<google.cloud.dialogflow.v2beta1.Intent.Message.ISimpleResponse>} simpleResponses
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponses
                                 * @instance
                                 */
                                SimpleResponses.prototype.simpleResponses = $util.emptyArray;
    
                                /**
                                 * Creates a new SimpleResponses instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponses
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ISimpleResponses=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponses} SimpleResponses instance
                                 */
                                SimpleResponses.create = function create(properties) {
                                    return new SimpleResponses(properties);
                                };
    
                                /**
                                 * Encodes the specified SimpleResponses message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponses.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponses
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ISimpleResponses} message SimpleResponses message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                SimpleResponses.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.simpleResponses != null && message.simpleResponses.length)
                                        for (var i = 0; i < message.simpleResponses.length; ++i)
                                            $root.google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponse.encode(message.simpleResponses[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified SimpleResponses message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponses.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponses
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ISimpleResponses} message SimpleResponses message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                SimpleResponses.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a SimpleResponses message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponses
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponses} SimpleResponses
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                SimpleResponses.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponses();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                if (!(message.simpleResponses && message.simpleResponses.length))
                                                    message.simpleResponses = [];
                                                message.simpleResponses.push($root.google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponse.decode(reader, reader.uint32()));
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a SimpleResponses message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponses
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponses} SimpleResponses
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                SimpleResponses.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a SimpleResponses message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponses
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                SimpleResponses.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.simpleResponses != null && message.hasOwnProperty("simpleResponses")) {
                                        if (!Array.isArray(message.simpleResponses))
                                            return "simpleResponses: array expected";
                                        for (var i = 0; i < message.simpleResponses.length; ++i) {
                                            var error = $root.google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponse.verify(message.simpleResponses[i]);
                                            if (error)
                                                return "simpleResponses." + error;
                                        }
                                    }
                                    return null;
                                };
    
                                /**
                                 * Creates a SimpleResponses message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponses
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponses} SimpleResponses
                                 */
                                SimpleResponses.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponses)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponses();
                                    if (object.simpleResponses) {
                                        if (!Array.isArray(object.simpleResponses))
                                            throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponses.simpleResponses: array expected");
                                        message.simpleResponses = [];
                                        for (var i = 0; i < object.simpleResponses.length; ++i) {
                                            if (typeof object.simpleResponses[i] !== "object")
                                                throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponses.simpleResponses: object expected");
                                            message.simpleResponses[i] = $root.google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponse.fromObject(object.simpleResponses[i]);
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a SimpleResponses message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponses
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponses} message SimpleResponses
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                SimpleResponses.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.arrays || options.defaults)
                                        object.simpleResponses = [];
                                    if (message.simpleResponses && message.simpleResponses.length) {
                                        object.simpleResponses = [];
                                        for (var j = 0; j < message.simpleResponses.length; ++j)
                                            object.simpleResponses[j] = $root.google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponse.toObject(message.simpleResponses[j], options);
                                    }
                                    return object;
                                };
    
                                /**
                                 * Converts this SimpleResponses to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponses
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                SimpleResponses.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for SimpleResponses
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponses
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                SimpleResponses.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Intent.Message.SimpleResponses";
                                };
    
                                return SimpleResponses;
                            })();
    
                            Message.BasicCard = (function() {
    
                                /**
                                 * Properties of a BasicCard.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @interface IBasicCard
                                 * @property {string|null} [title] BasicCard title
                                 * @property {string|null} [subtitle] BasicCard subtitle
                                 * @property {string|null} [formattedText] BasicCard formattedText
                                 * @property {google.cloud.dialogflow.v2beta1.Intent.Message.IImage|null} [image] BasicCard image
                                 * @property {Array.<google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.IButton>|null} [buttons] BasicCard buttons
                                 */
    
                                /**
                                 * Constructs a new BasicCard.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @classdesc Represents a BasicCard.
                                 * @implements IBasicCard
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IBasicCard=} [properties] Properties to set
                                 */
                                function BasicCard(properties) {
                                    this.buttons = [];
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * BasicCard title.
                                 * @member {string} title
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard
                                 * @instance
                                 */
                                BasicCard.prototype.title = "";
    
                                /**
                                 * BasicCard subtitle.
                                 * @member {string} subtitle
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard
                                 * @instance
                                 */
                                BasicCard.prototype.subtitle = "";
    
                                /**
                                 * BasicCard formattedText.
                                 * @member {string} formattedText
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard
                                 * @instance
                                 */
                                BasicCard.prototype.formattedText = "";
    
                                /**
                                 * BasicCard image.
                                 * @member {google.cloud.dialogflow.v2beta1.Intent.Message.IImage|null|undefined} image
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard
                                 * @instance
                                 */
                                BasicCard.prototype.image = null;
    
                                /**
                                 * BasicCard buttons.
                                 * @member {Array.<google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.IButton>} buttons
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard
                                 * @instance
                                 */
                                BasicCard.prototype.buttons = $util.emptyArray;
    
                                /**
                                 * Creates a new BasicCard instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IBasicCard=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard} BasicCard instance
                                 */
                                BasicCard.create = function create(properties) {
                                    return new BasicCard(properties);
                                };
    
                                /**
                                 * Encodes the specified BasicCard message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IBasicCard} message BasicCard message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                BasicCard.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.title != null && Object.hasOwnProperty.call(message, "title"))
                                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.title);
                                    if (message.subtitle != null && Object.hasOwnProperty.call(message, "subtitle"))
                                        writer.uint32(/* id 2, wireType 2 =*/18).string(message.subtitle);
                                    if (message.formattedText != null && Object.hasOwnProperty.call(message, "formattedText"))
                                        writer.uint32(/* id 3, wireType 2 =*/26).string(message.formattedText);
                                    if (message.image != null && Object.hasOwnProperty.call(message, "image"))
                                        $root.google.cloud.dialogflow.v2beta1.Intent.Message.Image.encode(message.image, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                                    if (message.buttons != null && message.buttons.length)
                                        for (var i = 0; i < message.buttons.length; ++i)
                                            $root.google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button.encode(message.buttons[i], writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified BasicCard message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IBasicCard} message BasicCard message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                BasicCard.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a BasicCard message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard} BasicCard
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                BasicCard.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                message.title = reader.string();
                                                break;
                                            }
                                        case 2: {
                                                message.subtitle = reader.string();
                                                break;
                                            }
                                        case 3: {
                                                message.formattedText = reader.string();
                                                break;
                                            }
                                        case 4: {
                                                message.image = $root.google.cloud.dialogflow.v2beta1.Intent.Message.Image.decode(reader, reader.uint32());
                                                break;
                                            }
                                        case 5: {
                                                if (!(message.buttons && message.buttons.length))
                                                    message.buttons = [];
                                                message.buttons.push($root.google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button.decode(reader, reader.uint32()));
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a BasicCard message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard} BasicCard
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                BasicCard.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a BasicCard message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                BasicCard.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.title != null && message.hasOwnProperty("title"))
                                        if (!$util.isString(message.title))
                                            return "title: string expected";
                                    if (message.subtitle != null && message.hasOwnProperty("subtitle"))
                                        if (!$util.isString(message.subtitle))
                                            return "subtitle: string expected";
                                    if (message.formattedText != null && message.hasOwnProperty("formattedText"))
                                        if (!$util.isString(message.formattedText))
                                            return "formattedText: string expected";
                                    if (message.image != null && message.hasOwnProperty("image")) {
                                        var error = $root.google.cloud.dialogflow.v2beta1.Intent.Message.Image.verify(message.image);
                                        if (error)
                                            return "image." + error;
                                    }
                                    if (message.buttons != null && message.hasOwnProperty("buttons")) {
                                        if (!Array.isArray(message.buttons))
                                            return "buttons: array expected";
                                        for (var i = 0; i < message.buttons.length; ++i) {
                                            var error = $root.google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button.verify(message.buttons[i]);
                                            if (error)
                                                return "buttons." + error;
                                        }
                                    }
                                    return null;
                                };
    
                                /**
                                 * Creates a BasicCard message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard} BasicCard
                                 */
                                BasicCard.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard();
                                    if (object.title != null)
                                        message.title = String(object.title);
                                    if (object.subtitle != null)
                                        message.subtitle = String(object.subtitle);
                                    if (object.formattedText != null)
                                        message.formattedText = String(object.formattedText);
                                    if (object.image != null) {
                                        if (typeof object.image !== "object")
                                            throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.image: object expected");
                                        message.image = $root.google.cloud.dialogflow.v2beta1.Intent.Message.Image.fromObject(object.image);
                                    }
                                    if (object.buttons) {
                                        if (!Array.isArray(object.buttons))
                                            throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.buttons: array expected");
                                        message.buttons = [];
                                        for (var i = 0; i < object.buttons.length; ++i) {
                                            if (typeof object.buttons[i] !== "object")
                                                throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.buttons: object expected");
                                            message.buttons[i] = $root.google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button.fromObject(object.buttons[i]);
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a BasicCard message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard} message BasicCard
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                BasicCard.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.arrays || options.defaults)
                                        object.buttons = [];
                                    if (options.defaults) {
                                        object.title = "";
                                        object.subtitle = "";
                                        object.formattedText = "";
                                        object.image = null;
                                    }
                                    if (message.title != null && message.hasOwnProperty("title"))
                                        object.title = message.title;
                                    if (message.subtitle != null && message.hasOwnProperty("subtitle"))
                                        object.subtitle = message.subtitle;
                                    if (message.formattedText != null && message.hasOwnProperty("formattedText"))
                                        object.formattedText = message.formattedText;
                                    if (message.image != null && message.hasOwnProperty("image"))
                                        object.image = $root.google.cloud.dialogflow.v2beta1.Intent.Message.Image.toObject(message.image, options);
                                    if (message.buttons && message.buttons.length) {
                                        object.buttons = [];
                                        for (var j = 0; j < message.buttons.length; ++j)
                                            object.buttons[j] = $root.google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button.toObject(message.buttons[j], options);
                                    }
                                    return object;
                                };
    
                                /**
                                 * Converts this BasicCard to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                BasicCard.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for BasicCard
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                BasicCard.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard";
                                };
    
                                BasicCard.Button = (function() {
    
                                    /**
                                     * Properties of a Button.
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard
                                     * @interface IButton
                                     * @property {string|null} [title] Button title
                                     * @property {google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button.IOpenUriAction|null} [openUriAction] Button openUriAction
                                     */
    
                                    /**
                                     * Constructs a new Button.
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard
                                     * @classdesc Represents a Button.
                                     * @implements IButton
                                     * @constructor
                                     * @param {google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.IButton=} [properties] Properties to set
                                     */
                                    function Button(properties) {
                                        if (properties)
                                            for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                                if (properties[keys[i]] != null)
                                                    this[keys[i]] = properties[keys[i]];
                                    }
    
                                    /**
                                     * Button title.
                                     * @member {string} title
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button
                                     * @instance
                                     */
                                    Button.prototype.title = "";
    
                                    /**
                                     * Button openUriAction.
                                     * @member {google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button.IOpenUriAction|null|undefined} openUriAction
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button
                                     * @instance
                                     */
                                    Button.prototype.openUriAction = null;
    
                                    /**
                                     * Creates a new Button instance using the specified properties.
                                     * @function create
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button
                                     * @static
                                     * @param {google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.IButton=} [properties] Properties to set
                                     * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button} Button instance
                                     */
                                    Button.create = function create(properties) {
                                        return new Button(properties);
                                    };
    
                                    /**
                                     * Encodes the specified Button message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button.verify|verify} messages.
                                     * @function encode
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button
                                     * @static
                                     * @param {google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.IButton} message Button message or plain object to encode
                                     * @param {$protobuf.Writer} [writer] Writer to encode to
                                     * @returns {$protobuf.Writer} Writer
                                     */
                                    Button.encode = function encode(message, writer) {
                                        if (!writer)
                                            writer = $Writer.create();
                                        if (message.title != null && Object.hasOwnProperty.call(message, "title"))
                                            writer.uint32(/* id 1, wireType 2 =*/10).string(message.title);
                                        if (message.openUriAction != null && Object.hasOwnProperty.call(message, "openUriAction"))
                                            $root.google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button.OpenUriAction.encode(message.openUriAction, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                                        return writer;
                                    };
    
                                    /**
                                     * Encodes the specified Button message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button.verify|verify} messages.
                                     * @function encodeDelimited
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button
                                     * @static
                                     * @param {google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.IButton} message Button message or plain object to encode
                                     * @param {$protobuf.Writer} [writer] Writer to encode to
                                     * @returns {$protobuf.Writer} Writer
                                     */
                                    Button.encodeDelimited = function encodeDelimited(message, writer) {
                                        return this.encode(message, writer).ldelim();
                                    };
    
                                    /**
                                     * Decodes a Button message from the specified reader or buffer.
                                     * @function decode
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button
                                     * @static
                                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                     * @param {number} [length] Message length if known beforehand
                                     * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button} Button
                                     * @throws {Error} If the payload is not a reader or valid buffer
                                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                     */
                                    Button.decode = function decode(reader, length) {
                                        if (!(reader instanceof $Reader))
                                            reader = $Reader.create(reader);
                                        var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button();
                                        while (reader.pos < end) {
                                            var tag = reader.uint32();
                                            switch (tag >>> 3) {
                                            case 1: {
                                                    message.title = reader.string();
                                                    break;
                                                }
                                            case 2: {
                                                    message.openUriAction = $root.google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button.OpenUriAction.decode(reader, reader.uint32());
                                                    break;
                                                }
                                            default:
                                                reader.skipType(tag & 7);
                                                break;
                                            }
                                        }
                                        return message;
                                    };
    
                                    /**
                                     * Decodes a Button message from the specified reader or buffer, length delimited.
                                     * @function decodeDelimited
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button
                                     * @static
                                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                     * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button} Button
                                     * @throws {Error} If the payload is not a reader or valid buffer
                                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                     */
                                    Button.decodeDelimited = function decodeDelimited(reader) {
                                        if (!(reader instanceof $Reader))
                                            reader = new $Reader(reader);
                                        return this.decode(reader, reader.uint32());
                                    };
    
                                    /**
                                     * Verifies a Button message.
                                     * @function verify
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button
                                     * @static
                                     * @param {Object.<string,*>} message Plain object to verify
                                     * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                     */
                                    Button.verify = function verify(message) {
                                        if (typeof message !== "object" || message === null)
                                            return "object expected";
                                        if (message.title != null && message.hasOwnProperty("title"))
                                            if (!$util.isString(message.title))
                                                return "title: string expected";
                                        if (message.openUriAction != null && message.hasOwnProperty("openUriAction")) {
                                            var error = $root.google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button.OpenUriAction.verify(message.openUriAction);
                                            if (error)
                                                return "openUriAction." + error;
                                        }
                                        return null;
                                    };
    
                                    /**
                                     * Creates a Button message from a plain object. Also converts values to their respective internal types.
                                     * @function fromObject
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button
                                     * @static
                                     * @param {Object.<string,*>} object Plain object
                                     * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button} Button
                                     */
                                    Button.fromObject = function fromObject(object) {
                                        if (object instanceof $root.google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button)
                                            return object;
                                        var message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button();
                                        if (object.title != null)
                                            message.title = String(object.title);
                                        if (object.openUriAction != null) {
                                            if (typeof object.openUriAction !== "object")
                                                throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button.openUriAction: object expected");
                                            message.openUriAction = $root.google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button.OpenUriAction.fromObject(object.openUriAction);
                                        }
                                        return message;
                                    };
    
                                    /**
                                     * Creates a plain object from a Button message. Also converts values to other types if specified.
                                     * @function toObject
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button
                                     * @static
                                     * @param {google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button} message Button
                                     * @param {$protobuf.IConversionOptions} [options] Conversion options
                                     * @returns {Object.<string,*>} Plain object
                                     */
                                    Button.toObject = function toObject(message, options) {
                                        if (!options)
                                            options = {};
                                        var object = {};
                                        if (options.defaults) {
                                            object.title = "";
                                            object.openUriAction = null;
                                        }
                                        if (message.title != null && message.hasOwnProperty("title"))
                                            object.title = message.title;
                                        if (message.openUriAction != null && message.hasOwnProperty("openUriAction"))
                                            object.openUriAction = $root.google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button.OpenUriAction.toObject(message.openUriAction, options);
                                        return object;
                                    };
    
                                    /**
                                     * Converts this Button to JSON.
                                     * @function toJSON
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button
                                     * @instance
                                     * @returns {Object.<string,*>} JSON object
                                     */
                                    Button.prototype.toJSON = function toJSON() {
                                        return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                    };
    
                                    /**
                                     * Gets the default type url for Button
                                     * @function getTypeUrl
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button
                                     * @static
                                     * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                     * @returns {string} The default type url
                                     */
                                    Button.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                        if (typeUrlPrefix === undefined) {
                                            typeUrlPrefix = "type.googleapis.com";
                                        }
                                        return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button";
                                    };
    
                                    Button.OpenUriAction = (function() {
    
                                        /**
                                         * Properties of an OpenUriAction.
                                         * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button
                                         * @interface IOpenUriAction
                                         * @property {string|null} [uri] OpenUriAction uri
                                         */
    
                                        /**
                                         * Constructs a new OpenUriAction.
                                         * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button
                                         * @classdesc Represents an OpenUriAction.
                                         * @implements IOpenUriAction
                                         * @constructor
                                         * @param {google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button.IOpenUriAction=} [properties] Properties to set
                                         */
                                        function OpenUriAction(properties) {
                                            if (properties)
                                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                                    if (properties[keys[i]] != null)
                                                        this[keys[i]] = properties[keys[i]];
                                        }
    
                                        /**
                                         * OpenUriAction uri.
                                         * @member {string} uri
                                         * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button.OpenUriAction
                                         * @instance
                                         */
                                        OpenUriAction.prototype.uri = "";
    
                                        /**
                                         * Creates a new OpenUriAction instance using the specified properties.
                                         * @function create
                                         * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button.OpenUriAction
                                         * @static
                                         * @param {google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button.IOpenUriAction=} [properties] Properties to set
                                         * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button.OpenUriAction} OpenUriAction instance
                                         */
                                        OpenUriAction.create = function create(properties) {
                                            return new OpenUriAction(properties);
                                        };
    
                                        /**
                                         * Encodes the specified OpenUriAction message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button.OpenUriAction.verify|verify} messages.
                                         * @function encode
                                         * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button.OpenUriAction
                                         * @static
                                         * @param {google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button.IOpenUriAction} message OpenUriAction message or plain object to encode
                                         * @param {$protobuf.Writer} [writer] Writer to encode to
                                         * @returns {$protobuf.Writer} Writer
                                         */
                                        OpenUriAction.encode = function encode(message, writer) {
                                            if (!writer)
                                                writer = $Writer.create();
                                            if (message.uri != null && Object.hasOwnProperty.call(message, "uri"))
                                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.uri);
                                            return writer;
                                        };
    
                                        /**
                                         * Encodes the specified OpenUriAction message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button.OpenUriAction.verify|verify} messages.
                                         * @function encodeDelimited
                                         * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button.OpenUriAction
                                         * @static
                                         * @param {google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button.IOpenUriAction} message OpenUriAction message or plain object to encode
                                         * @param {$protobuf.Writer} [writer] Writer to encode to
                                         * @returns {$protobuf.Writer} Writer
                                         */
                                        OpenUriAction.encodeDelimited = function encodeDelimited(message, writer) {
                                            return this.encode(message, writer).ldelim();
                                        };
    
                                        /**
                                         * Decodes an OpenUriAction message from the specified reader or buffer.
                                         * @function decode
                                         * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button.OpenUriAction
                                         * @static
                                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                         * @param {number} [length] Message length if known beforehand
                                         * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button.OpenUriAction} OpenUriAction
                                         * @throws {Error} If the payload is not a reader or valid buffer
                                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                         */
                                        OpenUriAction.decode = function decode(reader, length) {
                                            if (!(reader instanceof $Reader))
                                                reader = $Reader.create(reader);
                                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button.OpenUriAction();
                                            while (reader.pos < end) {
                                                var tag = reader.uint32();
                                                switch (tag >>> 3) {
                                                case 1: {
                                                        message.uri = reader.string();
                                                        break;
                                                    }
                                                default:
                                                    reader.skipType(tag & 7);
                                                    break;
                                                }
                                            }
                                            return message;
                                        };
    
                                        /**
                                         * Decodes an OpenUriAction message from the specified reader or buffer, length delimited.
                                         * @function decodeDelimited
                                         * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button.OpenUriAction
                                         * @static
                                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                         * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button.OpenUriAction} OpenUriAction
                                         * @throws {Error} If the payload is not a reader or valid buffer
                                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                         */
                                        OpenUriAction.decodeDelimited = function decodeDelimited(reader) {
                                            if (!(reader instanceof $Reader))
                                                reader = new $Reader(reader);
                                            return this.decode(reader, reader.uint32());
                                        };
    
                                        /**
                                         * Verifies an OpenUriAction message.
                                         * @function verify
                                         * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button.OpenUriAction
                                         * @static
                                         * @param {Object.<string,*>} message Plain object to verify
                                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                         */
                                        OpenUriAction.verify = function verify(message) {
                                            if (typeof message !== "object" || message === null)
                                                return "object expected";
                                            if (message.uri != null && message.hasOwnProperty("uri"))
                                                if (!$util.isString(message.uri))
                                                    return "uri: string expected";
                                            return null;
                                        };
    
                                        /**
                                         * Creates an OpenUriAction message from a plain object. Also converts values to their respective internal types.
                                         * @function fromObject
                                         * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button.OpenUriAction
                                         * @static
                                         * @param {Object.<string,*>} object Plain object
                                         * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button.OpenUriAction} OpenUriAction
                                         */
                                        OpenUriAction.fromObject = function fromObject(object) {
                                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button.OpenUriAction)
                                                return object;
                                            var message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button.OpenUriAction();
                                            if (object.uri != null)
                                                message.uri = String(object.uri);
                                            return message;
                                        };
    
                                        /**
                                         * Creates a plain object from an OpenUriAction message. Also converts values to other types if specified.
                                         * @function toObject
                                         * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button.OpenUriAction
                                         * @static
                                         * @param {google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button.OpenUriAction} message OpenUriAction
                                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                                         * @returns {Object.<string,*>} Plain object
                                         */
                                        OpenUriAction.toObject = function toObject(message, options) {
                                            if (!options)
                                                options = {};
                                            var object = {};
                                            if (options.defaults)
                                                object.uri = "";
                                            if (message.uri != null && message.hasOwnProperty("uri"))
                                                object.uri = message.uri;
                                            return object;
                                        };
    
                                        /**
                                         * Converts this OpenUriAction to JSON.
                                         * @function toJSON
                                         * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button.OpenUriAction
                                         * @instance
                                         * @returns {Object.<string,*>} JSON object
                                         */
                                        OpenUriAction.prototype.toJSON = function toJSON() {
                                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                        };
    
                                        /**
                                         * Gets the default type url for OpenUriAction
                                         * @function getTypeUrl
                                         * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button.OpenUriAction
                                         * @static
                                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                         * @returns {string} The default type url
                                         */
                                        OpenUriAction.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                            if (typeUrlPrefix === undefined) {
                                                typeUrlPrefix = "type.googleapis.com";
                                            }
                                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button.OpenUriAction";
                                        };
    
                                        return OpenUriAction;
                                    })();
    
                                    return Button;
                                })();
    
                                return BasicCard;
                            })();
    
                            Message.Suggestion = (function() {
    
                                /**
                                 * Properties of a Suggestion.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @interface ISuggestion
                                 * @property {string|null} [title] Suggestion title
                                 */
    
                                /**
                                 * Constructs a new Suggestion.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @classdesc Represents a Suggestion.
                                 * @implements ISuggestion
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ISuggestion=} [properties] Properties to set
                                 */
                                function Suggestion(properties) {
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * Suggestion title.
                                 * @member {string} title
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Suggestion
                                 * @instance
                                 */
                                Suggestion.prototype.title = "";
    
                                /**
                                 * Creates a new Suggestion instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Suggestion
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ISuggestion=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.Suggestion} Suggestion instance
                                 */
                                Suggestion.create = function create(properties) {
                                    return new Suggestion(properties);
                                };
    
                                /**
                                 * Encodes the specified Suggestion message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.Suggestion.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Suggestion
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ISuggestion} message Suggestion message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                Suggestion.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.title != null && Object.hasOwnProperty.call(message, "title"))
                                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.title);
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified Suggestion message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.Suggestion.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Suggestion
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ISuggestion} message Suggestion message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                Suggestion.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a Suggestion message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Suggestion
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.Suggestion} Suggestion
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                Suggestion.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.Suggestion();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                message.title = reader.string();
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a Suggestion message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Suggestion
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.Suggestion} Suggestion
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                Suggestion.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a Suggestion message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Suggestion
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                Suggestion.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.title != null && message.hasOwnProperty("title"))
                                        if (!$util.isString(message.title))
                                            return "title: string expected";
                                    return null;
                                };
    
                                /**
                                 * Creates a Suggestion message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Suggestion
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.Suggestion} Suggestion
                                 */
                                Suggestion.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2beta1.Intent.Message.Suggestion)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.Suggestion();
                                    if (object.title != null)
                                        message.title = String(object.title);
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a Suggestion message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Suggestion
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.Suggestion} message Suggestion
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                Suggestion.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.defaults)
                                        object.title = "";
                                    if (message.title != null && message.hasOwnProperty("title"))
                                        object.title = message.title;
                                    return object;
                                };
    
                                /**
                                 * Converts this Suggestion to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Suggestion
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                Suggestion.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for Suggestion
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Suggestion
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                Suggestion.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Intent.Message.Suggestion";
                                };
    
                                return Suggestion;
                            })();
    
                            Message.Suggestions = (function() {
    
                                /**
                                 * Properties of a Suggestions.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @interface ISuggestions
                                 * @property {Array.<google.cloud.dialogflow.v2beta1.Intent.Message.ISuggestion>|null} [suggestions] Suggestions suggestions
                                 */
    
                                /**
                                 * Constructs a new Suggestions.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @classdesc Represents a Suggestions.
                                 * @implements ISuggestions
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ISuggestions=} [properties] Properties to set
                                 */
                                function Suggestions(properties) {
                                    this.suggestions = [];
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * Suggestions suggestions.
                                 * @member {Array.<google.cloud.dialogflow.v2beta1.Intent.Message.ISuggestion>} suggestions
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Suggestions
                                 * @instance
                                 */
                                Suggestions.prototype.suggestions = $util.emptyArray;
    
                                /**
                                 * Creates a new Suggestions instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Suggestions
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ISuggestions=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.Suggestions} Suggestions instance
                                 */
                                Suggestions.create = function create(properties) {
                                    return new Suggestions(properties);
                                };
    
                                /**
                                 * Encodes the specified Suggestions message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.Suggestions.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Suggestions
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ISuggestions} message Suggestions message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                Suggestions.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.suggestions != null && message.suggestions.length)
                                        for (var i = 0; i < message.suggestions.length; ++i)
                                            $root.google.cloud.dialogflow.v2beta1.Intent.Message.Suggestion.encode(message.suggestions[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified Suggestions message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.Suggestions.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Suggestions
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ISuggestions} message Suggestions message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                Suggestions.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a Suggestions message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Suggestions
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.Suggestions} Suggestions
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                Suggestions.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.Suggestions();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                if (!(message.suggestions && message.suggestions.length))
                                                    message.suggestions = [];
                                                message.suggestions.push($root.google.cloud.dialogflow.v2beta1.Intent.Message.Suggestion.decode(reader, reader.uint32()));
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a Suggestions message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Suggestions
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.Suggestions} Suggestions
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                Suggestions.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a Suggestions message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Suggestions
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                Suggestions.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.suggestions != null && message.hasOwnProperty("suggestions")) {
                                        if (!Array.isArray(message.suggestions))
                                            return "suggestions: array expected";
                                        for (var i = 0; i < message.suggestions.length; ++i) {
                                            var error = $root.google.cloud.dialogflow.v2beta1.Intent.Message.Suggestion.verify(message.suggestions[i]);
                                            if (error)
                                                return "suggestions." + error;
                                        }
                                    }
                                    return null;
                                };
    
                                /**
                                 * Creates a Suggestions message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Suggestions
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.Suggestions} Suggestions
                                 */
                                Suggestions.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2beta1.Intent.Message.Suggestions)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.Suggestions();
                                    if (object.suggestions) {
                                        if (!Array.isArray(object.suggestions))
                                            throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.Suggestions.suggestions: array expected");
                                        message.suggestions = [];
                                        for (var i = 0; i < object.suggestions.length; ++i) {
                                            if (typeof object.suggestions[i] !== "object")
                                                throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.Suggestions.suggestions: object expected");
                                            message.suggestions[i] = $root.google.cloud.dialogflow.v2beta1.Intent.Message.Suggestion.fromObject(object.suggestions[i]);
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a Suggestions message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Suggestions
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.Suggestions} message Suggestions
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                Suggestions.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.arrays || options.defaults)
                                        object.suggestions = [];
                                    if (message.suggestions && message.suggestions.length) {
                                        object.suggestions = [];
                                        for (var j = 0; j < message.suggestions.length; ++j)
                                            object.suggestions[j] = $root.google.cloud.dialogflow.v2beta1.Intent.Message.Suggestion.toObject(message.suggestions[j], options);
                                    }
                                    return object;
                                };
    
                                /**
                                 * Converts this Suggestions to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Suggestions
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                Suggestions.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for Suggestions
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.Suggestions
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                Suggestions.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Intent.Message.Suggestions";
                                };
    
                                return Suggestions;
                            })();
    
                            Message.LinkOutSuggestion = (function() {
    
                                /**
                                 * Properties of a LinkOutSuggestion.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @interface ILinkOutSuggestion
                                 * @property {string|null} [destinationName] LinkOutSuggestion destinationName
                                 * @property {string|null} [uri] LinkOutSuggestion uri
                                 */
    
                                /**
                                 * Constructs a new LinkOutSuggestion.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @classdesc Represents a LinkOutSuggestion.
                                 * @implements ILinkOutSuggestion
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ILinkOutSuggestion=} [properties] Properties to set
                                 */
                                function LinkOutSuggestion(properties) {
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * LinkOutSuggestion destinationName.
                                 * @member {string} destinationName
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.LinkOutSuggestion
                                 * @instance
                                 */
                                LinkOutSuggestion.prototype.destinationName = "";
    
                                /**
                                 * LinkOutSuggestion uri.
                                 * @member {string} uri
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.LinkOutSuggestion
                                 * @instance
                                 */
                                LinkOutSuggestion.prototype.uri = "";
    
                                /**
                                 * Creates a new LinkOutSuggestion instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.LinkOutSuggestion
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ILinkOutSuggestion=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.LinkOutSuggestion} LinkOutSuggestion instance
                                 */
                                LinkOutSuggestion.create = function create(properties) {
                                    return new LinkOutSuggestion(properties);
                                };
    
                                /**
                                 * Encodes the specified LinkOutSuggestion message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.LinkOutSuggestion.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.LinkOutSuggestion
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ILinkOutSuggestion} message LinkOutSuggestion message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                LinkOutSuggestion.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.destinationName != null && Object.hasOwnProperty.call(message, "destinationName"))
                                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.destinationName);
                                    if (message.uri != null && Object.hasOwnProperty.call(message, "uri"))
                                        writer.uint32(/* id 2, wireType 2 =*/18).string(message.uri);
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified LinkOutSuggestion message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.LinkOutSuggestion.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.LinkOutSuggestion
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ILinkOutSuggestion} message LinkOutSuggestion message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                LinkOutSuggestion.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a LinkOutSuggestion message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.LinkOutSuggestion
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.LinkOutSuggestion} LinkOutSuggestion
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                LinkOutSuggestion.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.LinkOutSuggestion();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                message.destinationName = reader.string();
                                                break;
                                            }
                                        case 2: {
                                                message.uri = reader.string();
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a LinkOutSuggestion message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.LinkOutSuggestion
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.LinkOutSuggestion} LinkOutSuggestion
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                LinkOutSuggestion.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a LinkOutSuggestion message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.LinkOutSuggestion
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                LinkOutSuggestion.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.destinationName != null && message.hasOwnProperty("destinationName"))
                                        if (!$util.isString(message.destinationName))
                                            return "destinationName: string expected";
                                    if (message.uri != null && message.hasOwnProperty("uri"))
                                        if (!$util.isString(message.uri))
                                            return "uri: string expected";
                                    return null;
                                };
    
                                /**
                                 * Creates a LinkOutSuggestion message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.LinkOutSuggestion
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.LinkOutSuggestion} LinkOutSuggestion
                                 */
                                LinkOutSuggestion.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2beta1.Intent.Message.LinkOutSuggestion)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.LinkOutSuggestion();
                                    if (object.destinationName != null)
                                        message.destinationName = String(object.destinationName);
                                    if (object.uri != null)
                                        message.uri = String(object.uri);
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a LinkOutSuggestion message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.LinkOutSuggestion
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.LinkOutSuggestion} message LinkOutSuggestion
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                LinkOutSuggestion.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.defaults) {
                                        object.destinationName = "";
                                        object.uri = "";
                                    }
                                    if (message.destinationName != null && message.hasOwnProperty("destinationName"))
                                        object.destinationName = message.destinationName;
                                    if (message.uri != null && message.hasOwnProperty("uri"))
                                        object.uri = message.uri;
                                    return object;
                                };
    
                                /**
                                 * Converts this LinkOutSuggestion to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.LinkOutSuggestion
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                LinkOutSuggestion.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for LinkOutSuggestion
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.LinkOutSuggestion
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                LinkOutSuggestion.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Intent.Message.LinkOutSuggestion";
                                };
    
                                return LinkOutSuggestion;
                            })();
    
                            Message.ListSelect = (function() {
    
                                /**
                                 * Properties of a ListSelect.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @interface IListSelect
                                 * @property {string|null} [title] ListSelect title
                                 * @property {Array.<google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.IItem>|null} [items] ListSelect items
                                 * @property {string|null} [subtitle] ListSelect subtitle
                                 */
    
                                /**
                                 * Constructs a new ListSelect.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @classdesc Represents a ListSelect.
                                 * @implements IListSelect
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IListSelect=} [properties] Properties to set
                                 */
                                function ListSelect(properties) {
                                    this.items = [];
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * ListSelect title.
                                 * @member {string} title
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect
                                 * @instance
                                 */
                                ListSelect.prototype.title = "";
    
                                /**
                                 * ListSelect items.
                                 * @member {Array.<google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.IItem>} items
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect
                                 * @instance
                                 */
                                ListSelect.prototype.items = $util.emptyArray;
    
                                /**
                                 * ListSelect subtitle.
                                 * @member {string} subtitle
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect
                                 * @instance
                                 */
                                ListSelect.prototype.subtitle = "";
    
                                /**
                                 * Creates a new ListSelect instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IListSelect=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect} ListSelect instance
                                 */
                                ListSelect.create = function create(properties) {
                                    return new ListSelect(properties);
                                };
    
                                /**
                                 * Encodes the specified ListSelect message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IListSelect} message ListSelect message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                ListSelect.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.title != null && Object.hasOwnProperty.call(message, "title"))
                                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.title);
                                    if (message.items != null && message.items.length)
                                        for (var i = 0; i < message.items.length; ++i)
                                            $root.google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.Item.encode(message.items[i], writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                                    if (message.subtitle != null && Object.hasOwnProperty.call(message, "subtitle"))
                                        writer.uint32(/* id 3, wireType 2 =*/26).string(message.subtitle);
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified ListSelect message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IListSelect} message ListSelect message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                ListSelect.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a ListSelect message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect} ListSelect
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                ListSelect.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                message.title = reader.string();
                                                break;
                                            }
                                        case 2: {
                                                if (!(message.items && message.items.length))
                                                    message.items = [];
                                                message.items.push($root.google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.Item.decode(reader, reader.uint32()));
                                                break;
                                            }
                                        case 3: {
                                                message.subtitle = reader.string();
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a ListSelect message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect} ListSelect
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                ListSelect.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a ListSelect message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                ListSelect.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.title != null && message.hasOwnProperty("title"))
                                        if (!$util.isString(message.title))
                                            return "title: string expected";
                                    if (message.items != null && message.hasOwnProperty("items")) {
                                        if (!Array.isArray(message.items))
                                            return "items: array expected";
                                        for (var i = 0; i < message.items.length; ++i) {
                                            var error = $root.google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.Item.verify(message.items[i]);
                                            if (error)
                                                return "items." + error;
                                        }
                                    }
                                    if (message.subtitle != null && message.hasOwnProperty("subtitle"))
                                        if (!$util.isString(message.subtitle))
                                            return "subtitle: string expected";
                                    return null;
                                };
    
                                /**
                                 * Creates a ListSelect message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect} ListSelect
                                 */
                                ListSelect.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect();
                                    if (object.title != null)
                                        message.title = String(object.title);
                                    if (object.items) {
                                        if (!Array.isArray(object.items))
                                            throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.items: array expected");
                                        message.items = [];
                                        for (var i = 0; i < object.items.length; ++i) {
                                            if (typeof object.items[i] !== "object")
                                                throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.items: object expected");
                                            message.items[i] = $root.google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.Item.fromObject(object.items[i]);
                                        }
                                    }
                                    if (object.subtitle != null)
                                        message.subtitle = String(object.subtitle);
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a ListSelect message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect} message ListSelect
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                ListSelect.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.arrays || options.defaults)
                                        object.items = [];
                                    if (options.defaults) {
                                        object.title = "";
                                        object.subtitle = "";
                                    }
                                    if (message.title != null && message.hasOwnProperty("title"))
                                        object.title = message.title;
                                    if (message.items && message.items.length) {
                                        object.items = [];
                                        for (var j = 0; j < message.items.length; ++j)
                                            object.items[j] = $root.google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.Item.toObject(message.items[j], options);
                                    }
                                    if (message.subtitle != null && message.hasOwnProperty("subtitle"))
                                        object.subtitle = message.subtitle;
                                    return object;
                                };
    
                                /**
                                 * Converts this ListSelect to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                ListSelect.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for ListSelect
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                ListSelect.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect";
                                };
    
                                ListSelect.Item = (function() {
    
                                    /**
                                     * Properties of an Item.
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect
                                     * @interface IItem
                                     * @property {google.cloud.dialogflow.v2beta1.Intent.Message.ISelectItemInfo|null} [info] Item info
                                     * @property {string|null} [title] Item title
                                     * @property {string|null} [description] Item description
                                     * @property {google.cloud.dialogflow.v2beta1.Intent.Message.IImage|null} [image] Item image
                                     */
    
                                    /**
                                     * Constructs a new Item.
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect
                                     * @classdesc Represents an Item.
                                     * @implements IItem
                                     * @constructor
                                     * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.IItem=} [properties] Properties to set
                                     */
                                    function Item(properties) {
                                        if (properties)
                                            for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                                if (properties[keys[i]] != null)
                                                    this[keys[i]] = properties[keys[i]];
                                    }
    
                                    /**
                                     * Item info.
                                     * @member {google.cloud.dialogflow.v2beta1.Intent.Message.ISelectItemInfo|null|undefined} info
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.Item
                                     * @instance
                                     */
                                    Item.prototype.info = null;
    
                                    /**
                                     * Item title.
                                     * @member {string} title
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.Item
                                     * @instance
                                     */
                                    Item.prototype.title = "";
    
                                    /**
                                     * Item description.
                                     * @member {string} description
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.Item
                                     * @instance
                                     */
                                    Item.prototype.description = "";
    
                                    /**
                                     * Item image.
                                     * @member {google.cloud.dialogflow.v2beta1.Intent.Message.IImage|null|undefined} image
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.Item
                                     * @instance
                                     */
                                    Item.prototype.image = null;
    
                                    /**
                                     * Creates a new Item instance using the specified properties.
                                     * @function create
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.Item
                                     * @static
                                     * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.IItem=} [properties] Properties to set
                                     * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.Item} Item instance
                                     */
                                    Item.create = function create(properties) {
                                        return new Item(properties);
                                    };
    
                                    /**
                                     * Encodes the specified Item message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.Item.verify|verify} messages.
                                     * @function encode
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.Item
                                     * @static
                                     * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.IItem} message Item message or plain object to encode
                                     * @param {$protobuf.Writer} [writer] Writer to encode to
                                     * @returns {$protobuf.Writer} Writer
                                     */
                                    Item.encode = function encode(message, writer) {
                                        if (!writer)
                                            writer = $Writer.create();
                                        if (message.info != null && Object.hasOwnProperty.call(message, "info"))
                                            $root.google.cloud.dialogflow.v2beta1.Intent.Message.SelectItemInfo.encode(message.info, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                                        if (message.title != null && Object.hasOwnProperty.call(message, "title"))
                                            writer.uint32(/* id 2, wireType 2 =*/18).string(message.title);
                                        if (message.description != null && Object.hasOwnProperty.call(message, "description"))
                                            writer.uint32(/* id 3, wireType 2 =*/26).string(message.description);
                                        if (message.image != null && Object.hasOwnProperty.call(message, "image"))
                                            $root.google.cloud.dialogflow.v2beta1.Intent.Message.Image.encode(message.image, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                                        return writer;
                                    };
    
                                    /**
                                     * Encodes the specified Item message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.Item.verify|verify} messages.
                                     * @function encodeDelimited
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.Item
                                     * @static
                                     * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.IItem} message Item message or plain object to encode
                                     * @param {$protobuf.Writer} [writer] Writer to encode to
                                     * @returns {$protobuf.Writer} Writer
                                     */
                                    Item.encodeDelimited = function encodeDelimited(message, writer) {
                                        return this.encode(message, writer).ldelim();
                                    };
    
                                    /**
                                     * Decodes an Item message from the specified reader or buffer.
                                     * @function decode
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.Item
                                     * @static
                                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                     * @param {number} [length] Message length if known beforehand
                                     * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.Item} Item
                                     * @throws {Error} If the payload is not a reader or valid buffer
                                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                     */
                                    Item.decode = function decode(reader, length) {
                                        if (!(reader instanceof $Reader))
                                            reader = $Reader.create(reader);
                                        var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.Item();
                                        while (reader.pos < end) {
                                            var tag = reader.uint32();
                                            switch (tag >>> 3) {
                                            case 1: {
                                                    message.info = $root.google.cloud.dialogflow.v2beta1.Intent.Message.SelectItemInfo.decode(reader, reader.uint32());
                                                    break;
                                                }
                                            case 2: {
                                                    message.title = reader.string();
                                                    break;
                                                }
                                            case 3: {
                                                    message.description = reader.string();
                                                    break;
                                                }
                                            case 4: {
                                                    message.image = $root.google.cloud.dialogflow.v2beta1.Intent.Message.Image.decode(reader, reader.uint32());
                                                    break;
                                                }
                                            default:
                                                reader.skipType(tag & 7);
                                                break;
                                            }
                                        }
                                        return message;
                                    };
    
                                    /**
                                     * Decodes an Item message from the specified reader or buffer, length delimited.
                                     * @function decodeDelimited
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.Item
                                     * @static
                                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                     * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.Item} Item
                                     * @throws {Error} If the payload is not a reader or valid buffer
                                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                     */
                                    Item.decodeDelimited = function decodeDelimited(reader) {
                                        if (!(reader instanceof $Reader))
                                            reader = new $Reader(reader);
                                        return this.decode(reader, reader.uint32());
                                    };
    
                                    /**
                                     * Verifies an Item message.
                                     * @function verify
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.Item
                                     * @static
                                     * @param {Object.<string,*>} message Plain object to verify
                                     * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                     */
                                    Item.verify = function verify(message) {
                                        if (typeof message !== "object" || message === null)
                                            return "object expected";
                                        if (message.info != null && message.hasOwnProperty("info")) {
                                            var error = $root.google.cloud.dialogflow.v2beta1.Intent.Message.SelectItemInfo.verify(message.info);
                                            if (error)
                                                return "info." + error;
                                        }
                                        if (message.title != null && message.hasOwnProperty("title"))
                                            if (!$util.isString(message.title))
                                                return "title: string expected";
                                        if (message.description != null && message.hasOwnProperty("description"))
                                            if (!$util.isString(message.description))
                                                return "description: string expected";
                                        if (message.image != null && message.hasOwnProperty("image")) {
                                            var error = $root.google.cloud.dialogflow.v2beta1.Intent.Message.Image.verify(message.image);
                                            if (error)
                                                return "image." + error;
                                        }
                                        return null;
                                    };
    
                                    /**
                                     * Creates an Item message from a plain object. Also converts values to their respective internal types.
                                     * @function fromObject
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.Item
                                     * @static
                                     * @param {Object.<string,*>} object Plain object
                                     * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.Item} Item
                                     */
                                    Item.fromObject = function fromObject(object) {
                                        if (object instanceof $root.google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.Item)
                                            return object;
                                        var message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.Item();
                                        if (object.info != null) {
                                            if (typeof object.info !== "object")
                                                throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.Item.info: object expected");
                                            message.info = $root.google.cloud.dialogflow.v2beta1.Intent.Message.SelectItemInfo.fromObject(object.info);
                                        }
                                        if (object.title != null)
                                            message.title = String(object.title);
                                        if (object.description != null)
                                            message.description = String(object.description);
                                        if (object.image != null) {
                                            if (typeof object.image !== "object")
                                                throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.Item.image: object expected");
                                            message.image = $root.google.cloud.dialogflow.v2beta1.Intent.Message.Image.fromObject(object.image);
                                        }
                                        return message;
                                    };
    
                                    /**
                                     * Creates a plain object from an Item message. Also converts values to other types if specified.
                                     * @function toObject
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.Item
                                     * @static
                                     * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.Item} message Item
                                     * @param {$protobuf.IConversionOptions} [options] Conversion options
                                     * @returns {Object.<string,*>} Plain object
                                     */
                                    Item.toObject = function toObject(message, options) {
                                        if (!options)
                                            options = {};
                                        var object = {};
                                        if (options.defaults) {
                                            object.info = null;
                                            object.title = "";
                                            object.description = "";
                                            object.image = null;
                                        }
                                        if (message.info != null && message.hasOwnProperty("info"))
                                            object.info = $root.google.cloud.dialogflow.v2beta1.Intent.Message.SelectItemInfo.toObject(message.info, options);
                                        if (message.title != null && message.hasOwnProperty("title"))
                                            object.title = message.title;
                                        if (message.description != null && message.hasOwnProperty("description"))
                                            object.description = message.description;
                                        if (message.image != null && message.hasOwnProperty("image"))
                                            object.image = $root.google.cloud.dialogflow.v2beta1.Intent.Message.Image.toObject(message.image, options);
                                        return object;
                                    };
    
                                    /**
                                     * Converts this Item to JSON.
                                     * @function toJSON
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.Item
                                     * @instance
                                     * @returns {Object.<string,*>} JSON object
                                     */
                                    Item.prototype.toJSON = function toJSON() {
                                        return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                    };
    
                                    /**
                                     * Gets the default type url for Item
                                     * @function getTypeUrl
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.Item
                                     * @static
                                     * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                     * @returns {string} The default type url
                                     */
                                    Item.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                        if (typeUrlPrefix === undefined) {
                                            typeUrlPrefix = "type.googleapis.com";
                                        }
                                        return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Intent.Message.ListSelect.Item";
                                    };
    
                                    return Item;
                                })();
    
                                return ListSelect;
                            })();
    
                            Message.CarouselSelect = (function() {
    
                                /**
                                 * Properties of a CarouselSelect.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @interface ICarouselSelect
                                 * @property {Array.<google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect.IItem>|null} [items] CarouselSelect items
                                 */
    
                                /**
                                 * Constructs a new CarouselSelect.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @classdesc Represents a CarouselSelect.
                                 * @implements ICarouselSelect
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ICarouselSelect=} [properties] Properties to set
                                 */
                                function CarouselSelect(properties) {
                                    this.items = [];
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * CarouselSelect items.
                                 * @member {Array.<google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect.IItem>} items
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect
                                 * @instance
                                 */
                                CarouselSelect.prototype.items = $util.emptyArray;
    
                                /**
                                 * Creates a new CarouselSelect instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ICarouselSelect=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect} CarouselSelect instance
                                 */
                                CarouselSelect.create = function create(properties) {
                                    return new CarouselSelect(properties);
                                };
    
                                /**
                                 * Encodes the specified CarouselSelect message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ICarouselSelect} message CarouselSelect message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                CarouselSelect.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.items != null && message.items.length)
                                        for (var i = 0; i < message.items.length; ++i)
                                            $root.google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect.Item.encode(message.items[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified CarouselSelect message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ICarouselSelect} message CarouselSelect message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                CarouselSelect.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a CarouselSelect message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect} CarouselSelect
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                CarouselSelect.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                if (!(message.items && message.items.length))
                                                    message.items = [];
                                                message.items.push($root.google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect.Item.decode(reader, reader.uint32()));
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a CarouselSelect message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect} CarouselSelect
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                CarouselSelect.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a CarouselSelect message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                CarouselSelect.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.items != null && message.hasOwnProperty("items")) {
                                        if (!Array.isArray(message.items))
                                            return "items: array expected";
                                        for (var i = 0; i < message.items.length; ++i) {
                                            var error = $root.google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect.Item.verify(message.items[i]);
                                            if (error)
                                                return "items." + error;
                                        }
                                    }
                                    return null;
                                };
    
                                /**
                                 * Creates a CarouselSelect message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect} CarouselSelect
                                 */
                                CarouselSelect.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect();
                                    if (object.items) {
                                        if (!Array.isArray(object.items))
                                            throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect.items: array expected");
                                        message.items = [];
                                        for (var i = 0; i < object.items.length; ++i) {
                                            if (typeof object.items[i] !== "object")
                                                throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect.items: object expected");
                                            message.items[i] = $root.google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect.Item.fromObject(object.items[i]);
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a CarouselSelect message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect} message CarouselSelect
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                CarouselSelect.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.arrays || options.defaults)
                                        object.items = [];
                                    if (message.items && message.items.length) {
                                        object.items = [];
                                        for (var j = 0; j < message.items.length; ++j)
                                            object.items[j] = $root.google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect.Item.toObject(message.items[j], options);
                                    }
                                    return object;
                                };
    
                                /**
                                 * Converts this CarouselSelect to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                CarouselSelect.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for CarouselSelect
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                CarouselSelect.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect";
                                };
    
                                CarouselSelect.Item = (function() {
    
                                    /**
                                     * Properties of an Item.
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect
                                     * @interface IItem
                                     * @property {google.cloud.dialogflow.v2beta1.Intent.Message.ISelectItemInfo|null} [info] Item info
                                     * @property {string|null} [title] Item title
                                     * @property {string|null} [description] Item description
                                     * @property {google.cloud.dialogflow.v2beta1.Intent.Message.IImage|null} [image] Item image
                                     */
    
                                    /**
                                     * Constructs a new Item.
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect
                                     * @classdesc Represents an Item.
                                     * @implements IItem
                                     * @constructor
                                     * @param {google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect.IItem=} [properties] Properties to set
                                     */
                                    function Item(properties) {
                                        if (properties)
                                            for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                                if (properties[keys[i]] != null)
                                                    this[keys[i]] = properties[keys[i]];
                                    }
    
                                    /**
                                     * Item info.
                                     * @member {google.cloud.dialogflow.v2beta1.Intent.Message.ISelectItemInfo|null|undefined} info
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect.Item
                                     * @instance
                                     */
                                    Item.prototype.info = null;
    
                                    /**
                                     * Item title.
                                     * @member {string} title
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect.Item
                                     * @instance
                                     */
                                    Item.prototype.title = "";
    
                                    /**
                                     * Item description.
                                     * @member {string} description
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect.Item
                                     * @instance
                                     */
                                    Item.prototype.description = "";
    
                                    /**
                                     * Item image.
                                     * @member {google.cloud.dialogflow.v2beta1.Intent.Message.IImage|null|undefined} image
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect.Item
                                     * @instance
                                     */
                                    Item.prototype.image = null;
    
                                    /**
                                     * Creates a new Item instance using the specified properties.
                                     * @function create
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect.Item
                                     * @static
                                     * @param {google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect.IItem=} [properties] Properties to set
                                     * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect.Item} Item instance
                                     */
                                    Item.create = function create(properties) {
                                        return new Item(properties);
                                    };
    
                                    /**
                                     * Encodes the specified Item message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect.Item.verify|verify} messages.
                                     * @function encode
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect.Item
                                     * @static
                                     * @param {google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect.IItem} message Item message or plain object to encode
                                     * @param {$protobuf.Writer} [writer] Writer to encode to
                                     * @returns {$protobuf.Writer} Writer
                                     */
                                    Item.encode = function encode(message, writer) {
                                        if (!writer)
                                            writer = $Writer.create();
                                        if (message.info != null && Object.hasOwnProperty.call(message, "info"))
                                            $root.google.cloud.dialogflow.v2beta1.Intent.Message.SelectItemInfo.encode(message.info, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                                        if (message.title != null && Object.hasOwnProperty.call(message, "title"))
                                            writer.uint32(/* id 2, wireType 2 =*/18).string(message.title);
                                        if (message.description != null && Object.hasOwnProperty.call(message, "description"))
                                            writer.uint32(/* id 3, wireType 2 =*/26).string(message.description);
                                        if (message.image != null && Object.hasOwnProperty.call(message, "image"))
                                            $root.google.cloud.dialogflow.v2beta1.Intent.Message.Image.encode(message.image, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                                        return writer;
                                    };
    
                                    /**
                                     * Encodes the specified Item message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect.Item.verify|verify} messages.
                                     * @function encodeDelimited
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect.Item
                                     * @static
                                     * @param {google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect.IItem} message Item message or plain object to encode
                                     * @param {$protobuf.Writer} [writer] Writer to encode to
                                     * @returns {$protobuf.Writer} Writer
                                     */
                                    Item.encodeDelimited = function encodeDelimited(message, writer) {
                                        return this.encode(message, writer).ldelim();
                                    };
    
                                    /**
                                     * Decodes an Item message from the specified reader or buffer.
                                     * @function decode
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect.Item
                                     * @static
                                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                     * @param {number} [length] Message length if known beforehand
                                     * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect.Item} Item
                                     * @throws {Error} If the payload is not a reader or valid buffer
                                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                     */
                                    Item.decode = function decode(reader, length) {
                                        if (!(reader instanceof $Reader))
                                            reader = $Reader.create(reader);
                                        var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect.Item();
                                        while (reader.pos < end) {
                                            var tag = reader.uint32();
                                            switch (tag >>> 3) {
                                            case 1: {
                                                    message.info = $root.google.cloud.dialogflow.v2beta1.Intent.Message.SelectItemInfo.decode(reader, reader.uint32());
                                                    break;
                                                }
                                            case 2: {
                                                    message.title = reader.string();
                                                    break;
                                                }
                                            case 3: {
                                                    message.description = reader.string();
                                                    break;
                                                }
                                            case 4: {
                                                    message.image = $root.google.cloud.dialogflow.v2beta1.Intent.Message.Image.decode(reader, reader.uint32());
                                                    break;
                                                }
                                            default:
                                                reader.skipType(tag & 7);
                                                break;
                                            }
                                        }
                                        return message;
                                    };
    
                                    /**
                                     * Decodes an Item message from the specified reader or buffer, length delimited.
                                     * @function decodeDelimited
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect.Item
                                     * @static
                                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                     * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect.Item} Item
                                     * @throws {Error} If the payload is not a reader or valid buffer
                                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                     */
                                    Item.decodeDelimited = function decodeDelimited(reader) {
                                        if (!(reader instanceof $Reader))
                                            reader = new $Reader(reader);
                                        return this.decode(reader, reader.uint32());
                                    };
    
                                    /**
                                     * Verifies an Item message.
                                     * @function verify
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect.Item
                                     * @static
                                     * @param {Object.<string,*>} message Plain object to verify
                                     * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                     */
                                    Item.verify = function verify(message) {
                                        if (typeof message !== "object" || message === null)
                                            return "object expected";
                                        if (message.info != null && message.hasOwnProperty("info")) {
                                            var error = $root.google.cloud.dialogflow.v2beta1.Intent.Message.SelectItemInfo.verify(message.info);
                                            if (error)
                                                return "info." + error;
                                        }
                                        if (message.title != null && message.hasOwnProperty("title"))
                                            if (!$util.isString(message.title))
                                                return "title: string expected";
                                        if (message.description != null && message.hasOwnProperty("description"))
                                            if (!$util.isString(message.description))
                                                return "description: string expected";
                                        if (message.image != null && message.hasOwnProperty("image")) {
                                            var error = $root.google.cloud.dialogflow.v2beta1.Intent.Message.Image.verify(message.image);
                                            if (error)
                                                return "image." + error;
                                        }
                                        return null;
                                    };
    
                                    /**
                                     * Creates an Item message from a plain object. Also converts values to their respective internal types.
                                     * @function fromObject
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect.Item
                                     * @static
                                     * @param {Object.<string,*>} object Plain object
                                     * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect.Item} Item
                                     */
                                    Item.fromObject = function fromObject(object) {
                                        if (object instanceof $root.google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect.Item)
                                            return object;
                                        var message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect.Item();
                                        if (object.info != null) {
                                            if (typeof object.info !== "object")
                                                throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect.Item.info: object expected");
                                            message.info = $root.google.cloud.dialogflow.v2beta1.Intent.Message.SelectItemInfo.fromObject(object.info);
                                        }
                                        if (object.title != null)
                                            message.title = String(object.title);
                                        if (object.description != null)
                                            message.description = String(object.description);
                                        if (object.image != null) {
                                            if (typeof object.image !== "object")
                                                throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect.Item.image: object expected");
                                            message.image = $root.google.cloud.dialogflow.v2beta1.Intent.Message.Image.fromObject(object.image);
                                        }
                                        return message;
                                    };
    
                                    /**
                                     * Creates a plain object from an Item message. Also converts values to other types if specified.
                                     * @function toObject
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect.Item
                                     * @static
                                     * @param {google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect.Item} message Item
                                     * @param {$protobuf.IConversionOptions} [options] Conversion options
                                     * @returns {Object.<string,*>} Plain object
                                     */
                                    Item.toObject = function toObject(message, options) {
                                        if (!options)
                                            options = {};
                                        var object = {};
                                        if (options.defaults) {
                                            object.info = null;
                                            object.title = "";
                                            object.description = "";
                                            object.image = null;
                                        }
                                        if (message.info != null && message.hasOwnProperty("info"))
                                            object.info = $root.google.cloud.dialogflow.v2beta1.Intent.Message.SelectItemInfo.toObject(message.info, options);
                                        if (message.title != null && message.hasOwnProperty("title"))
                                            object.title = message.title;
                                        if (message.description != null && message.hasOwnProperty("description"))
                                            object.description = message.description;
                                        if (message.image != null && message.hasOwnProperty("image"))
                                            object.image = $root.google.cloud.dialogflow.v2beta1.Intent.Message.Image.toObject(message.image, options);
                                        return object;
                                    };
    
                                    /**
                                     * Converts this Item to JSON.
                                     * @function toJSON
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect.Item
                                     * @instance
                                     * @returns {Object.<string,*>} JSON object
                                     */
                                    Item.prototype.toJSON = function toJSON() {
                                        return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                    };
    
                                    /**
                                     * Gets the default type url for Item
                                     * @function getTypeUrl
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect.Item
                                     * @static
                                     * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                     * @returns {string} The default type url
                                     */
                                    Item.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                        if (typeUrlPrefix === undefined) {
                                            typeUrlPrefix = "type.googleapis.com";
                                        }
                                        return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Intent.Message.CarouselSelect.Item";
                                    };
    
                                    return Item;
                                })();
    
                                return CarouselSelect;
                            })();
    
                            Message.SelectItemInfo = (function() {
    
                                /**
                                 * Properties of a SelectItemInfo.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @interface ISelectItemInfo
                                 * @property {string|null} [key] SelectItemInfo key
                                 * @property {Array.<string>|null} [synonyms] SelectItemInfo synonyms
                                 */
    
                                /**
                                 * Constructs a new SelectItemInfo.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @classdesc Represents a SelectItemInfo.
                                 * @implements ISelectItemInfo
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ISelectItemInfo=} [properties] Properties to set
                                 */
                                function SelectItemInfo(properties) {
                                    this.synonyms = [];
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * SelectItemInfo key.
                                 * @member {string} key
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.SelectItemInfo
                                 * @instance
                                 */
                                SelectItemInfo.prototype.key = "";
    
                                /**
                                 * SelectItemInfo synonyms.
                                 * @member {Array.<string>} synonyms
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.SelectItemInfo
                                 * @instance
                                 */
                                SelectItemInfo.prototype.synonyms = $util.emptyArray;
    
                                /**
                                 * Creates a new SelectItemInfo instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.SelectItemInfo
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ISelectItemInfo=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.SelectItemInfo} SelectItemInfo instance
                                 */
                                SelectItemInfo.create = function create(properties) {
                                    return new SelectItemInfo(properties);
                                };
    
                                /**
                                 * Encodes the specified SelectItemInfo message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.SelectItemInfo.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.SelectItemInfo
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ISelectItemInfo} message SelectItemInfo message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                SelectItemInfo.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.key != null && Object.hasOwnProperty.call(message, "key"))
                                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.key);
                                    if (message.synonyms != null && message.synonyms.length)
                                        for (var i = 0; i < message.synonyms.length; ++i)
                                            writer.uint32(/* id 2, wireType 2 =*/18).string(message.synonyms[i]);
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified SelectItemInfo message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.SelectItemInfo.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.SelectItemInfo
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ISelectItemInfo} message SelectItemInfo message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                SelectItemInfo.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a SelectItemInfo message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.SelectItemInfo
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.SelectItemInfo} SelectItemInfo
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                SelectItemInfo.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.SelectItemInfo();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                message.key = reader.string();
                                                break;
                                            }
                                        case 2: {
                                                if (!(message.synonyms && message.synonyms.length))
                                                    message.synonyms = [];
                                                message.synonyms.push(reader.string());
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a SelectItemInfo message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.SelectItemInfo
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.SelectItemInfo} SelectItemInfo
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                SelectItemInfo.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a SelectItemInfo message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.SelectItemInfo
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                SelectItemInfo.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.key != null && message.hasOwnProperty("key"))
                                        if (!$util.isString(message.key))
                                            return "key: string expected";
                                    if (message.synonyms != null && message.hasOwnProperty("synonyms")) {
                                        if (!Array.isArray(message.synonyms))
                                            return "synonyms: array expected";
                                        for (var i = 0; i < message.synonyms.length; ++i)
                                            if (!$util.isString(message.synonyms[i]))
                                                return "synonyms: string[] expected";
                                    }
                                    return null;
                                };
    
                                /**
                                 * Creates a SelectItemInfo message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.SelectItemInfo
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.SelectItemInfo} SelectItemInfo
                                 */
                                SelectItemInfo.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2beta1.Intent.Message.SelectItemInfo)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.SelectItemInfo();
                                    if (object.key != null)
                                        message.key = String(object.key);
                                    if (object.synonyms) {
                                        if (!Array.isArray(object.synonyms))
                                            throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.SelectItemInfo.synonyms: array expected");
                                        message.synonyms = [];
                                        for (var i = 0; i < object.synonyms.length; ++i)
                                            message.synonyms[i] = String(object.synonyms[i]);
                                    }
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a SelectItemInfo message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.SelectItemInfo
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.SelectItemInfo} message SelectItemInfo
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                SelectItemInfo.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.arrays || options.defaults)
                                        object.synonyms = [];
                                    if (options.defaults)
                                        object.key = "";
                                    if (message.key != null && message.hasOwnProperty("key"))
                                        object.key = message.key;
                                    if (message.synonyms && message.synonyms.length) {
                                        object.synonyms = [];
                                        for (var j = 0; j < message.synonyms.length; ++j)
                                            object.synonyms[j] = message.synonyms[j];
                                    }
                                    return object;
                                };
    
                                /**
                                 * Converts this SelectItemInfo to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.SelectItemInfo
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                SelectItemInfo.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for SelectItemInfo
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.SelectItemInfo
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                SelectItemInfo.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Intent.Message.SelectItemInfo";
                                };
    
                                return SelectItemInfo;
                            })();
    
                            Message.TelephonyPlayAudio = (function() {
    
                                /**
                                 * Properties of a TelephonyPlayAudio.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @interface ITelephonyPlayAudio
                                 * @property {string|null} [audioUri] TelephonyPlayAudio audioUri
                                 */
    
                                /**
                                 * Constructs a new TelephonyPlayAudio.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @classdesc Represents a TelephonyPlayAudio.
                                 * @implements ITelephonyPlayAudio
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ITelephonyPlayAudio=} [properties] Properties to set
                                 */
                                function TelephonyPlayAudio(properties) {
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * TelephonyPlayAudio audioUri.
                                 * @member {string} audioUri
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyPlayAudio
                                 * @instance
                                 */
                                TelephonyPlayAudio.prototype.audioUri = "";
    
                                /**
                                 * Creates a new TelephonyPlayAudio instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyPlayAudio
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ITelephonyPlayAudio=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyPlayAudio} TelephonyPlayAudio instance
                                 */
                                TelephonyPlayAudio.create = function create(properties) {
                                    return new TelephonyPlayAudio(properties);
                                };
    
                                /**
                                 * Encodes the specified TelephonyPlayAudio message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyPlayAudio.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyPlayAudio
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ITelephonyPlayAudio} message TelephonyPlayAudio message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                TelephonyPlayAudio.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.audioUri != null && Object.hasOwnProperty.call(message, "audioUri"))
                                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.audioUri);
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified TelephonyPlayAudio message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyPlayAudio.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyPlayAudio
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ITelephonyPlayAudio} message TelephonyPlayAudio message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                TelephonyPlayAudio.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a TelephonyPlayAudio message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyPlayAudio
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyPlayAudio} TelephonyPlayAudio
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                TelephonyPlayAudio.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyPlayAudio();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                message.audioUri = reader.string();
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a TelephonyPlayAudio message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyPlayAudio
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyPlayAudio} TelephonyPlayAudio
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                TelephonyPlayAudio.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a TelephonyPlayAudio message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyPlayAudio
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                TelephonyPlayAudio.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.audioUri != null && message.hasOwnProperty("audioUri"))
                                        if (!$util.isString(message.audioUri))
                                            return "audioUri: string expected";
                                    return null;
                                };
    
                                /**
                                 * Creates a TelephonyPlayAudio message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyPlayAudio
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyPlayAudio} TelephonyPlayAudio
                                 */
                                TelephonyPlayAudio.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyPlayAudio)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyPlayAudio();
                                    if (object.audioUri != null)
                                        message.audioUri = String(object.audioUri);
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a TelephonyPlayAudio message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyPlayAudio
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyPlayAudio} message TelephonyPlayAudio
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                TelephonyPlayAudio.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.defaults)
                                        object.audioUri = "";
                                    if (message.audioUri != null && message.hasOwnProperty("audioUri"))
                                        object.audioUri = message.audioUri;
                                    return object;
                                };
    
                                /**
                                 * Converts this TelephonyPlayAudio to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyPlayAudio
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                TelephonyPlayAudio.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for TelephonyPlayAudio
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyPlayAudio
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                TelephonyPlayAudio.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyPlayAudio";
                                };
    
                                return TelephonyPlayAudio;
                            })();
    
                            Message.TelephonySynthesizeSpeech = (function() {
    
                                /**
                                 * Properties of a TelephonySynthesizeSpeech.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @interface ITelephonySynthesizeSpeech
                                 * @property {string|null} [text] TelephonySynthesizeSpeech text
                                 * @property {string|null} [ssml] TelephonySynthesizeSpeech ssml
                                 */
    
                                /**
                                 * Constructs a new TelephonySynthesizeSpeech.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @classdesc Represents a TelephonySynthesizeSpeech.
                                 * @implements ITelephonySynthesizeSpeech
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ITelephonySynthesizeSpeech=} [properties] Properties to set
                                 */
                                function TelephonySynthesizeSpeech(properties) {
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * TelephonySynthesizeSpeech text.
                                 * @member {string|null|undefined} text
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TelephonySynthesizeSpeech
                                 * @instance
                                 */
                                TelephonySynthesizeSpeech.prototype.text = null;
    
                                /**
                                 * TelephonySynthesizeSpeech ssml.
                                 * @member {string|null|undefined} ssml
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TelephonySynthesizeSpeech
                                 * @instance
                                 */
                                TelephonySynthesizeSpeech.prototype.ssml = null;
    
                                // OneOf field names bound to virtual getters and setters
                                var $oneOfFields;
    
                                /**
                                 * TelephonySynthesizeSpeech source.
                                 * @member {"text"|"ssml"|undefined} source
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TelephonySynthesizeSpeech
                                 * @instance
                                 */
                                Object.defineProperty(TelephonySynthesizeSpeech.prototype, "source", {
                                    get: $util.oneOfGetter($oneOfFields = ["text", "ssml"]),
                                    set: $util.oneOfSetter($oneOfFields)
                                });
    
                                /**
                                 * Creates a new TelephonySynthesizeSpeech instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TelephonySynthesizeSpeech
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ITelephonySynthesizeSpeech=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.TelephonySynthesizeSpeech} TelephonySynthesizeSpeech instance
                                 */
                                TelephonySynthesizeSpeech.create = function create(properties) {
                                    return new TelephonySynthesizeSpeech(properties);
                                };
    
                                /**
                                 * Encodes the specified TelephonySynthesizeSpeech message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.TelephonySynthesizeSpeech.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TelephonySynthesizeSpeech
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ITelephonySynthesizeSpeech} message TelephonySynthesizeSpeech message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                TelephonySynthesizeSpeech.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.text != null && Object.hasOwnProperty.call(message, "text"))
                                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.text);
                                    if (message.ssml != null && Object.hasOwnProperty.call(message, "ssml"))
                                        writer.uint32(/* id 2, wireType 2 =*/18).string(message.ssml);
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified TelephonySynthesizeSpeech message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.TelephonySynthesizeSpeech.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TelephonySynthesizeSpeech
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ITelephonySynthesizeSpeech} message TelephonySynthesizeSpeech message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                TelephonySynthesizeSpeech.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a TelephonySynthesizeSpeech message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TelephonySynthesizeSpeech
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.TelephonySynthesizeSpeech} TelephonySynthesizeSpeech
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                TelephonySynthesizeSpeech.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.TelephonySynthesizeSpeech();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                message.text = reader.string();
                                                break;
                                            }
                                        case 2: {
                                                message.ssml = reader.string();
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a TelephonySynthesizeSpeech message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TelephonySynthesizeSpeech
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.TelephonySynthesizeSpeech} TelephonySynthesizeSpeech
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                TelephonySynthesizeSpeech.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a TelephonySynthesizeSpeech message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TelephonySynthesizeSpeech
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                TelephonySynthesizeSpeech.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    var properties = {};
                                    if (message.text != null && message.hasOwnProperty("text")) {
                                        properties.source = 1;
                                        if (!$util.isString(message.text))
                                            return "text: string expected";
                                    }
                                    if (message.ssml != null && message.hasOwnProperty("ssml")) {
                                        if (properties.source === 1)
                                            return "source: multiple values";
                                        properties.source = 1;
                                        if (!$util.isString(message.ssml))
                                            return "ssml: string expected";
                                    }
                                    return null;
                                };
    
                                /**
                                 * Creates a TelephonySynthesizeSpeech message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TelephonySynthesizeSpeech
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.TelephonySynthesizeSpeech} TelephonySynthesizeSpeech
                                 */
                                TelephonySynthesizeSpeech.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2beta1.Intent.Message.TelephonySynthesizeSpeech)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.TelephonySynthesizeSpeech();
                                    if (object.text != null)
                                        message.text = String(object.text);
                                    if (object.ssml != null)
                                        message.ssml = String(object.ssml);
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a TelephonySynthesizeSpeech message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TelephonySynthesizeSpeech
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.TelephonySynthesizeSpeech} message TelephonySynthesizeSpeech
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                TelephonySynthesizeSpeech.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (message.text != null && message.hasOwnProperty("text")) {
                                        object.text = message.text;
                                        if (options.oneofs)
                                            object.source = "text";
                                    }
                                    if (message.ssml != null && message.hasOwnProperty("ssml")) {
                                        object.ssml = message.ssml;
                                        if (options.oneofs)
                                            object.source = "ssml";
                                    }
                                    return object;
                                };
    
                                /**
                                 * Converts this TelephonySynthesizeSpeech to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TelephonySynthesizeSpeech
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                TelephonySynthesizeSpeech.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for TelephonySynthesizeSpeech
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TelephonySynthesizeSpeech
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                TelephonySynthesizeSpeech.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Intent.Message.TelephonySynthesizeSpeech";
                                };
    
                                return TelephonySynthesizeSpeech;
                            })();
    
                            Message.TelephonyTransferCall = (function() {
    
                                /**
                                 * Properties of a TelephonyTransferCall.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @interface ITelephonyTransferCall
                                 * @property {string|null} [phoneNumber] TelephonyTransferCall phoneNumber
                                 */
    
                                /**
                                 * Constructs a new TelephonyTransferCall.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @classdesc Represents a TelephonyTransferCall.
                                 * @implements ITelephonyTransferCall
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ITelephonyTransferCall=} [properties] Properties to set
                                 */
                                function TelephonyTransferCall(properties) {
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * TelephonyTransferCall phoneNumber.
                                 * @member {string} phoneNumber
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyTransferCall
                                 * @instance
                                 */
                                TelephonyTransferCall.prototype.phoneNumber = "";
    
                                /**
                                 * Creates a new TelephonyTransferCall instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyTransferCall
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ITelephonyTransferCall=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyTransferCall} TelephonyTransferCall instance
                                 */
                                TelephonyTransferCall.create = function create(properties) {
                                    return new TelephonyTransferCall(properties);
                                };
    
                                /**
                                 * Encodes the specified TelephonyTransferCall message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyTransferCall.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyTransferCall
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ITelephonyTransferCall} message TelephonyTransferCall message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                TelephonyTransferCall.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.phoneNumber != null && Object.hasOwnProperty.call(message, "phoneNumber"))
                                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.phoneNumber);
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified TelephonyTransferCall message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyTransferCall.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyTransferCall
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ITelephonyTransferCall} message TelephonyTransferCall message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                TelephonyTransferCall.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a TelephonyTransferCall message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyTransferCall
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyTransferCall} TelephonyTransferCall
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                TelephonyTransferCall.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyTransferCall();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                message.phoneNumber = reader.string();
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a TelephonyTransferCall message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyTransferCall
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyTransferCall} TelephonyTransferCall
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                TelephonyTransferCall.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a TelephonyTransferCall message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyTransferCall
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                TelephonyTransferCall.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.phoneNumber != null && message.hasOwnProperty("phoneNumber"))
                                        if (!$util.isString(message.phoneNumber))
                                            return "phoneNumber: string expected";
                                    return null;
                                };
    
                                /**
                                 * Creates a TelephonyTransferCall message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyTransferCall
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyTransferCall} TelephonyTransferCall
                                 */
                                TelephonyTransferCall.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyTransferCall)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyTransferCall();
                                    if (object.phoneNumber != null)
                                        message.phoneNumber = String(object.phoneNumber);
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a TelephonyTransferCall message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyTransferCall
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyTransferCall} message TelephonyTransferCall
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                TelephonyTransferCall.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.defaults)
                                        object.phoneNumber = "";
                                    if (message.phoneNumber != null && message.hasOwnProperty("phoneNumber"))
                                        object.phoneNumber = message.phoneNumber;
                                    return object;
                                };
    
                                /**
                                 * Converts this TelephonyTransferCall to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyTransferCall
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                TelephonyTransferCall.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for TelephonyTransferCall
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyTransferCall
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                TelephonyTransferCall.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Intent.Message.TelephonyTransferCall";
                                };
    
                                return TelephonyTransferCall;
                            })();
    
                            Message.RbmText = (function() {
    
                                /**
                                 * Properties of a RbmText.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @interface IRbmText
                                 * @property {string|null} [text] RbmText text
                                 * @property {Array.<google.cloud.dialogflow.v2beta1.Intent.Message.IRbmSuggestion>|null} [rbmSuggestion] RbmText rbmSuggestion
                                 */
    
                                /**
                                 * Constructs a new RbmText.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @classdesc Represents a RbmText.
                                 * @implements IRbmText
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IRbmText=} [properties] Properties to set
                                 */
                                function RbmText(properties) {
                                    this.rbmSuggestion = [];
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * RbmText text.
                                 * @member {string} text
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmText
                                 * @instance
                                 */
                                RbmText.prototype.text = "";
    
                                /**
                                 * RbmText rbmSuggestion.
                                 * @member {Array.<google.cloud.dialogflow.v2beta1.Intent.Message.IRbmSuggestion>} rbmSuggestion
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmText
                                 * @instance
                                 */
                                RbmText.prototype.rbmSuggestion = $util.emptyArray;
    
                                /**
                                 * Creates a new RbmText instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmText
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IRbmText=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.RbmText} RbmText instance
                                 */
                                RbmText.create = function create(properties) {
                                    return new RbmText(properties);
                                };
    
                                /**
                                 * Encodes the specified RbmText message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.RbmText.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmText
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IRbmText} message RbmText message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                RbmText.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.text != null && Object.hasOwnProperty.call(message, "text"))
                                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.text);
                                    if (message.rbmSuggestion != null && message.rbmSuggestion.length)
                                        for (var i = 0; i < message.rbmSuggestion.length; ++i)
                                            $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestion.encode(message.rbmSuggestion[i], writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified RbmText message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.RbmText.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmText
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IRbmText} message RbmText message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                RbmText.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a RbmText message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmText
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.RbmText} RbmText
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                RbmText.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmText();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                message.text = reader.string();
                                                break;
                                            }
                                        case 2: {
                                                if (!(message.rbmSuggestion && message.rbmSuggestion.length))
                                                    message.rbmSuggestion = [];
                                                message.rbmSuggestion.push($root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestion.decode(reader, reader.uint32()));
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a RbmText message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmText
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.RbmText} RbmText
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                RbmText.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a RbmText message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmText
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                RbmText.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.text != null && message.hasOwnProperty("text"))
                                        if (!$util.isString(message.text))
                                            return "text: string expected";
                                    if (message.rbmSuggestion != null && message.hasOwnProperty("rbmSuggestion")) {
                                        if (!Array.isArray(message.rbmSuggestion))
                                            return "rbmSuggestion: array expected";
                                        for (var i = 0; i < message.rbmSuggestion.length; ++i) {
                                            var error = $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestion.verify(message.rbmSuggestion[i]);
                                            if (error)
                                                return "rbmSuggestion." + error;
                                        }
                                    }
                                    return null;
                                };
    
                                /**
                                 * Creates a RbmText message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmText
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.RbmText} RbmText
                                 */
                                RbmText.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmText)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmText();
                                    if (object.text != null)
                                        message.text = String(object.text);
                                    if (object.rbmSuggestion) {
                                        if (!Array.isArray(object.rbmSuggestion))
                                            throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.RbmText.rbmSuggestion: array expected");
                                        message.rbmSuggestion = [];
                                        for (var i = 0; i < object.rbmSuggestion.length; ++i) {
                                            if (typeof object.rbmSuggestion[i] !== "object")
                                                throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.RbmText.rbmSuggestion: object expected");
                                            message.rbmSuggestion[i] = $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestion.fromObject(object.rbmSuggestion[i]);
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a RbmText message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmText
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.RbmText} message RbmText
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                RbmText.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.arrays || options.defaults)
                                        object.rbmSuggestion = [];
                                    if (options.defaults)
                                        object.text = "";
                                    if (message.text != null && message.hasOwnProperty("text"))
                                        object.text = message.text;
                                    if (message.rbmSuggestion && message.rbmSuggestion.length) {
                                        object.rbmSuggestion = [];
                                        for (var j = 0; j < message.rbmSuggestion.length; ++j)
                                            object.rbmSuggestion[j] = $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestion.toObject(message.rbmSuggestion[j], options);
                                    }
                                    return object;
                                };
    
                                /**
                                 * Converts this RbmText to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmText
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                RbmText.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for RbmText
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmText
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                RbmText.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Intent.Message.RbmText";
                                };
    
                                return RbmText;
                            })();
    
                            Message.RbmCarouselCard = (function() {
    
                                /**
                                 * Properties of a RbmCarouselCard.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @interface IRbmCarouselCard
                                 * @property {google.cloud.dialogflow.v2beta1.Intent.Message.RbmCarouselCard.CardWidth|null} [cardWidth] RbmCarouselCard cardWidth
                                 * @property {Array.<google.cloud.dialogflow.v2beta1.Intent.Message.IRbmCardContent>|null} [cardContents] RbmCarouselCard cardContents
                                 */
    
                                /**
                                 * Constructs a new RbmCarouselCard.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @classdesc Represents a RbmCarouselCard.
                                 * @implements IRbmCarouselCard
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IRbmCarouselCard=} [properties] Properties to set
                                 */
                                function RbmCarouselCard(properties) {
                                    this.cardContents = [];
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * RbmCarouselCard cardWidth.
                                 * @member {google.cloud.dialogflow.v2beta1.Intent.Message.RbmCarouselCard.CardWidth} cardWidth
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmCarouselCard
                                 * @instance
                                 */
                                RbmCarouselCard.prototype.cardWidth = 0;
    
                                /**
                                 * RbmCarouselCard cardContents.
                                 * @member {Array.<google.cloud.dialogflow.v2beta1.Intent.Message.IRbmCardContent>} cardContents
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmCarouselCard
                                 * @instance
                                 */
                                RbmCarouselCard.prototype.cardContents = $util.emptyArray;
    
                                /**
                                 * Creates a new RbmCarouselCard instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmCarouselCard
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IRbmCarouselCard=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.RbmCarouselCard} RbmCarouselCard instance
                                 */
                                RbmCarouselCard.create = function create(properties) {
                                    return new RbmCarouselCard(properties);
                                };
    
                                /**
                                 * Encodes the specified RbmCarouselCard message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.RbmCarouselCard.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmCarouselCard
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IRbmCarouselCard} message RbmCarouselCard message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                RbmCarouselCard.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.cardWidth != null && Object.hasOwnProperty.call(message, "cardWidth"))
                                        writer.uint32(/* id 1, wireType 0 =*/8).int32(message.cardWidth);
                                    if (message.cardContents != null && message.cardContents.length)
                                        for (var i = 0; i < message.cardContents.length; ++i)
                                            $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.encode(message.cardContents[i], writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified RbmCarouselCard message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.RbmCarouselCard.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmCarouselCard
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IRbmCarouselCard} message RbmCarouselCard message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                RbmCarouselCard.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a RbmCarouselCard message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmCarouselCard
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.RbmCarouselCard} RbmCarouselCard
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                RbmCarouselCard.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmCarouselCard();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                message.cardWidth = reader.int32();
                                                break;
                                            }
                                        case 2: {
                                                if (!(message.cardContents && message.cardContents.length))
                                                    message.cardContents = [];
                                                message.cardContents.push($root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.decode(reader, reader.uint32()));
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a RbmCarouselCard message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmCarouselCard
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.RbmCarouselCard} RbmCarouselCard
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                RbmCarouselCard.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a RbmCarouselCard message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmCarouselCard
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                RbmCarouselCard.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.cardWidth != null && message.hasOwnProperty("cardWidth"))
                                        switch (message.cardWidth) {
                                        default:
                                            return "cardWidth: enum value expected";
                                        case 0:
                                        case 1:
                                        case 2:
                                            break;
                                        }
                                    if (message.cardContents != null && message.hasOwnProperty("cardContents")) {
                                        if (!Array.isArray(message.cardContents))
                                            return "cardContents: array expected";
                                        for (var i = 0; i < message.cardContents.length; ++i) {
                                            var error = $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.verify(message.cardContents[i]);
                                            if (error)
                                                return "cardContents." + error;
                                        }
                                    }
                                    return null;
                                };
    
                                /**
                                 * Creates a RbmCarouselCard message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmCarouselCard
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.RbmCarouselCard} RbmCarouselCard
                                 */
                                RbmCarouselCard.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmCarouselCard)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmCarouselCard();
                                    switch (object.cardWidth) {
                                    default:
                                        if (typeof object.cardWidth === "number") {
                                            message.cardWidth = object.cardWidth;
                                            break;
                                        }
                                        break;
                                    case "CARD_WIDTH_UNSPECIFIED":
                                    case 0:
                                        message.cardWidth = 0;
                                        break;
                                    case "SMALL":
                                    case 1:
                                        message.cardWidth = 1;
                                        break;
                                    case "MEDIUM":
                                    case 2:
                                        message.cardWidth = 2;
                                        break;
                                    }
                                    if (object.cardContents) {
                                        if (!Array.isArray(object.cardContents))
                                            throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.RbmCarouselCard.cardContents: array expected");
                                        message.cardContents = [];
                                        for (var i = 0; i < object.cardContents.length; ++i) {
                                            if (typeof object.cardContents[i] !== "object")
                                                throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.RbmCarouselCard.cardContents: object expected");
                                            message.cardContents[i] = $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.fromObject(object.cardContents[i]);
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a RbmCarouselCard message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmCarouselCard
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.RbmCarouselCard} message RbmCarouselCard
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                RbmCarouselCard.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.arrays || options.defaults)
                                        object.cardContents = [];
                                    if (options.defaults)
                                        object.cardWidth = options.enums === String ? "CARD_WIDTH_UNSPECIFIED" : 0;
                                    if (message.cardWidth != null && message.hasOwnProperty("cardWidth"))
                                        object.cardWidth = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmCarouselCard.CardWidth[message.cardWidth] === undefined ? message.cardWidth : $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmCarouselCard.CardWidth[message.cardWidth] : message.cardWidth;
                                    if (message.cardContents && message.cardContents.length) {
                                        object.cardContents = [];
                                        for (var j = 0; j < message.cardContents.length; ++j)
                                            object.cardContents[j] = $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.toObject(message.cardContents[j], options);
                                    }
                                    return object;
                                };
    
                                /**
                                 * Converts this RbmCarouselCard to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmCarouselCard
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                RbmCarouselCard.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for RbmCarouselCard
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmCarouselCard
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                RbmCarouselCard.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Intent.Message.RbmCarouselCard";
                                };
    
                                /**
                                 * CardWidth enum.
                                 * @name google.cloud.dialogflow.v2beta1.Intent.Message.RbmCarouselCard.CardWidth
                                 * @enum {number}
                                 * @property {number} CARD_WIDTH_UNSPECIFIED=0 CARD_WIDTH_UNSPECIFIED value
                                 * @property {number} SMALL=1 SMALL value
                                 * @property {number} MEDIUM=2 MEDIUM value
                                 */
                                RbmCarouselCard.CardWidth = (function() {
                                    var valuesById = {}, values = Object.create(valuesById);
                                    values[valuesById[0] = "CARD_WIDTH_UNSPECIFIED"] = 0;
                                    values[valuesById[1] = "SMALL"] = 1;
                                    values[valuesById[2] = "MEDIUM"] = 2;
                                    return values;
                                })();
    
                                return RbmCarouselCard;
                            })();
    
                            Message.RbmStandaloneCard = (function() {
    
                                /**
                                 * Properties of a RbmStandaloneCard.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @interface IRbmStandaloneCard
                                 * @property {google.cloud.dialogflow.v2beta1.Intent.Message.RbmStandaloneCard.CardOrientation|null} [cardOrientation] RbmStandaloneCard cardOrientation
                                 * @property {google.cloud.dialogflow.v2beta1.Intent.Message.RbmStandaloneCard.ThumbnailImageAlignment|null} [thumbnailImageAlignment] RbmStandaloneCard thumbnailImageAlignment
                                 * @property {google.cloud.dialogflow.v2beta1.Intent.Message.IRbmCardContent|null} [cardContent] RbmStandaloneCard cardContent
                                 */
    
                                /**
                                 * Constructs a new RbmStandaloneCard.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @classdesc Represents a RbmStandaloneCard.
                                 * @implements IRbmStandaloneCard
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IRbmStandaloneCard=} [properties] Properties to set
                                 */
                                function RbmStandaloneCard(properties) {
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * RbmStandaloneCard cardOrientation.
                                 * @member {google.cloud.dialogflow.v2beta1.Intent.Message.RbmStandaloneCard.CardOrientation} cardOrientation
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmStandaloneCard
                                 * @instance
                                 */
                                RbmStandaloneCard.prototype.cardOrientation = 0;
    
                                /**
                                 * RbmStandaloneCard thumbnailImageAlignment.
                                 * @member {google.cloud.dialogflow.v2beta1.Intent.Message.RbmStandaloneCard.ThumbnailImageAlignment} thumbnailImageAlignment
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmStandaloneCard
                                 * @instance
                                 */
                                RbmStandaloneCard.prototype.thumbnailImageAlignment = 0;
    
                                /**
                                 * RbmStandaloneCard cardContent.
                                 * @member {google.cloud.dialogflow.v2beta1.Intent.Message.IRbmCardContent|null|undefined} cardContent
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmStandaloneCard
                                 * @instance
                                 */
                                RbmStandaloneCard.prototype.cardContent = null;
    
                                /**
                                 * Creates a new RbmStandaloneCard instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmStandaloneCard
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IRbmStandaloneCard=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.RbmStandaloneCard} RbmStandaloneCard instance
                                 */
                                RbmStandaloneCard.create = function create(properties) {
                                    return new RbmStandaloneCard(properties);
                                };
    
                                /**
                                 * Encodes the specified RbmStandaloneCard message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.RbmStandaloneCard.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmStandaloneCard
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IRbmStandaloneCard} message RbmStandaloneCard message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                RbmStandaloneCard.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.cardOrientation != null && Object.hasOwnProperty.call(message, "cardOrientation"))
                                        writer.uint32(/* id 1, wireType 0 =*/8).int32(message.cardOrientation);
                                    if (message.thumbnailImageAlignment != null && Object.hasOwnProperty.call(message, "thumbnailImageAlignment"))
                                        writer.uint32(/* id 2, wireType 0 =*/16).int32(message.thumbnailImageAlignment);
                                    if (message.cardContent != null && Object.hasOwnProperty.call(message, "cardContent"))
                                        $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.encode(message.cardContent, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified RbmStandaloneCard message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.RbmStandaloneCard.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmStandaloneCard
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IRbmStandaloneCard} message RbmStandaloneCard message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                RbmStandaloneCard.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a RbmStandaloneCard message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmStandaloneCard
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.RbmStandaloneCard} RbmStandaloneCard
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                RbmStandaloneCard.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmStandaloneCard();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                message.cardOrientation = reader.int32();
                                                break;
                                            }
                                        case 2: {
                                                message.thumbnailImageAlignment = reader.int32();
                                                break;
                                            }
                                        case 3: {
                                                message.cardContent = $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.decode(reader, reader.uint32());
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a RbmStandaloneCard message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmStandaloneCard
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.RbmStandaloneCard} RbmStandaloneCard
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                RbmStandaloneCard.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a RbmStandaloneCard message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmStandaloneCard
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                RbmStandaloneCard.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.cardOrientation != null && message.hasOwnProperty("cardOrientation"))
                                        switch (message.cardOrientation) {
                                        default:
                                            return "cardOrientation: enum value expected";
                                        case 0:
                                        case 1:
                                        case 2:
                                            break;
                                        }
                                    if (message.thumbnailImageAlignment != null && message.hasOwnProperty("thumbnailImageAlignment"))
                                        switch (message.thumbnailImageAlignment) {
                                        default:
                                            return "thumbnailImageAlignment: enum value expected";
                                        case 0:
                                        case 1:
                                        case 2:
                                            break;
                                        }
                                    if (message.cardContent != null && message.hasOwnProperty("cardContent")) {
                                        var error = $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.verify(message.cardContent);
                                        if (error)
                                            return "cardContent." + error;
                                    }
                                    return null;
                                };
    
                                /**
                                 * Creates a RbmStandaloneCard message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmStandaloneCard
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.RbmStandaloneCard} RbmStandaloneCard
                                 */
                                RbmStandaloneCard.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmStandaloneCard)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmStandaloneCard();
                                    switch (object.cardOrientation) {
                                    default:
                                        if (typeof object.cardOrientation === "number") {
                                            message.cardOrientation = object.cardOrientation;
                                            break;
                                        }
                                        break;
                                    case "CARD_ORIENTATION_UNSPECIFIED":
                                    case 0:
                                        message.cardOrientation = 0;
                                        break;
                                    case "HORIZONTAL":
                                    case 1:
                                        message.cardOrientation = 1;
                                        break;
                                    case "VERTICAL":
                                    case 2:
                                        message.cardOrientation = 2;
                                        break;
                                    }
                                    switch (object.thumbnailImageAlignment) {
                                    default:
                                        if (typeof object.thumbnailImageAlignment === "number") {
                                            message.thumbnailImageAlignment = object.thumbnailImageAlignment;
                                            break;
                                        }
                                        break;
                                    case "THUMBNAIL_IMAGE_ALIGNMENT_UNSPECIFIED":
                                    case 0:
                                        message.thumbnailImageAlignment = 0;
                                        break;
                                    case "LEFT":
                                    case 1:
                                        message.thumbnailImageAlignment = 1;
                                        break;
                                    case "RIGHT":
                                    case 2:
                                        message.thumbnailImageAlignment = 2;
                                        break;
                                    }
                                    if (object.cardContent != null) {
                                        if (typeof object.cardContent !== "object")
                                            throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.RbmStandaloneCard.cardContent: object expected");
                                        message.cardContent = $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.fromObject(object.cardContent);
                                    }
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a RbmStandaloneCard message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmStandaloneCard
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.RbmStandaloneCard} message RbmStandaloneCard
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                RbmStandaloneCard.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.defaults) {
                                        object.cardOrientation = options.enums === String ? "CARD_ORIENTATION_UNSPECIFIED" : 0;
                                        object.thumbnailImageAlignment = options.enums === String ? "THUMBNAIL_IMAGE_ALIGNMENT_UNSPECIFIED" : 0;
                                        object.cardContent = null;
                                    }
                                    if (message.cardOrientation != null && message.hasOwnProperty("cardOrientation"))
                                        object.cardOrientation = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmStandaloneCard.CardOrientation[message.cardOrientation] === undefined ? message.cardOrientation : $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmStandaloneCard.CardOrientation[message.cardOrientation] : message.cardOrientation;
                                    if (message.thumbnailImageAlignment != null && message.hasOwnProperty("thumbnailImageAlignment"))
                                        object.thumbnailImageAlignment = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmStandaloneCard.ThumbnailImageAlignment[message.thumbnailImageAlignment] === undefined ? message.thumbnailImageAlignment : $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmStandaloneCard.ThumbnailImageAlignment[message.thumbnailImageAlignment] : message.thumbnailImageAlignment;
                                    if (message.cardContent != null && message.hasOwnProperty("cardContent"))
                                        object.cardContent = $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.toObject(message.cardContent, options);
                                    return object;
                                };
    
                                /**
                                 * Converts this RbmStandaloneCard to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmStandaloneCard
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                RbmStandaloneCard.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for RbmStandaloneCard
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmStandaloneCard
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                RbmStandaloneCard.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Intent.Message.RbmStandaloneCard";
                                };
    
                                /**
                                 * CardOrientation enum.
                                 * @name google.cloud.dialogflow.v2beta1.Intent.Message.RbmStandaloneCard.CardOrientation
                                 * @enum {number}
                                 * @property {number} CARD_ORIENTATION_UNSPECIFIED=0 CARD_ORIENTATION_UNSPECIFIED value
                                 * @property {number} HORIZONTAL=1 HORIZONTAL value
                                 * @property {number} VERTICAL=2 VERTICAL value
                                 */
                                RbmStandaloneCard.CardOrientation = (function() {
                                    var valuesById = {}, values = Object.create(valuesById);
                                    values[valuesById[0] = "CARD_ORIENTATION_UNSPECIFIED"] = 0;
                                    values[valuesById[1] = "HORIZONTAL"] = 1;
                                    values[valuesById[2] = "VERTICAL"] = 2;
                                    return values;
                                })();
    
                                /**
                                 * ThumbnailImageAlignment enum.
                                 * @name google.cloud.dialogflow.v2beta1.Intent.Message.RbmStandaloneCard.ThumbnailImageAlignment
                                 * @enum {number}
                                 * @property {number} THUMBNAIL_IMAGE_ALIGNMENT_UNSPECIFIED=0 THUMBNAIL_IMAGE_ALIGNMENT_UNSPECIFIED value
                                 * @property {number} LEFT=1 LEFT value
                                 * @property {number} RIGHT=2 RIGHT value
                                 */
                                RbmStandaloneCard.ThumbnailImageAlignment = (function() {
                                    var valuesById = {}, values = Object.create(valuesById);
                                    values[valuesById[0] = "THUMBNAIL_IMAGE_ALIGNMENT_UNSPECIFIED"] = 0;
                                    values[valuesById[1] = "LEFT"] = 1;
                                    values[valuesById[2] = "RIGHT"] = 2;
                                    return values;
                                })();
    
                                return RbmStandaloneCard;
                            })();
    
                            Message.RbmCardContent = (function() {
    
                                /**
                                 * Properties of a RbmCardContent.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @interface IRbmCardContent
                                 * @property {string|null} [title] RbmCardContent title
                                 * @property {string|null} [description] RbmCardContent description
                                 * @property {google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.IRbmMedia|null} [media] RbmCardContent media
                                 * @property {Array.<google.cloud.dialogflow.v2beta1.Intent.Message.IRbmSuggestion>|null} [suggestions] RbmCardContent suggestions
                                 */
    
                                /**
                                 * Constructs a new RbmCardContent.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @classdesc Represents a RbmCardContent.
                                 * @implements IRbmCardContent
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IRbmCardContent=} [properties] Properties to set
                                 */
                                function RbmCardContent(properties) {
                                    this.suggestions = [];
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * RbmCardContent title.
                                 * @member {string} title
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent
                                 * @instance
                                 */
                                RbmCardContent.prototype.title = "";
    
                                /**
                                 * RbmCardContent description.
                                 * @member {string} description
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent
                                 * @instance
                                 */
                                RbmCardContent.prototype.description = "";
    
                                /**
                                 * RbmCardContent media.
                                 * @member {google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.IRbmMedia|null|undefined} media
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent
                                 * @instance
                                 */
                                RbmCardContent.prototype.media = null;
    
                                /**
                                 * RbmCardContent suggestions.
                                 * @member {Array.<google.cloud.dialogflow.v2beta1.Intent.Message.IRbmSuggestion>} suggestions
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent
                                 * @instance
                                 */
                                RbmCardContent.prototype.suggestions = $util.emptyArray;
    
                                /**
                                 * Creates a new RbmCardContent instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IRbmCardContent=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent} RbmCardContent instance
                                 */
                                RbmCardContent.create = function create(properties) {
                                    return new RbmCardContent(properties);
                                };
    
                                /**
                                 * Encodes the specified RbmCardContent message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IRbmCardContent} message RbmCardContent message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                RbmCardContent.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.title != null && Object.hasOwnProperty.call(message, "title"))
                                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.title);
                                    if (message.description != null && Object.hasOwnProperty.call(message, "description"))
                                        writer.uint32(/* id 2, wireType 2 =*/18).string(message.description);
                                    if (message.media != null && Object.hasOwnProperty.call(message, "media"))
                                        $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.RbmMedia.encode(message.media, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                                    if (message.suggestions != null && message.suggestions.length)
                                        for (var i = 0; i < message.suggestions.length; ++i)
                                            $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestion.encode(message.suggestions[i], writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified RbmCardContent message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IRbmCardContent} message RbmCardContent message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                RbmCardContent.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a RbmCardContent message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent} RbmCardContent
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                RbmCardContent.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                message.title = reader.string();
                                                break;
                                            }
                                        case 2: {
                                                message.description = reader.string();
                                                break;
                                            }
                                        case 3: {
                                                message.media = $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.RbmMedia.decode(reader, reader.uint32());
                                                break;
                                            }
                                        case 4: {
                                                if (!(message.suggestions && message.suggestions.length))
                                                    message.suggestions = [];
                                                message.suggestions.push($root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestion.decode(reader, reader.uint32()));
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a RbmCardContent message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent} RbmCardContent
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                RbmCardContent.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a RbmCardContent message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                RbmCardContent.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.title != null && message.hasOwnProperty("title"))
                                        if (!$util.isString(message.title))
                                            return "title: string expected";
                                    if (message.description != null && message.hasOwnProperty("description"))
                                        if (!$util.isString(message.description))
                                            return "description: string expected";
                                    if (message.media != null && message.hasOwnProperty("media")) {
                                        var error = $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.RbmMedia.verify(message.media);
                                        if (error)
                                            return "media." + error;
                                    }
                                    if (message.suggestions != null && message.hasOwnProperty("suggestions")) {
                                        if (!Array.isArray(message.suggestions))
                                            return "suggestions: array expected";
                                        for (var i = 0; i < message.suggestions.length; ++i) {
                                            var error = $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestion.verify(message.suggestions[i]);
                                            if (error)
                                                return "suggestions." + error;
                                        }
                                    }
                                    return null;
                                };
    
                                /**
                                 * Creates a RbmCardContent message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent} RbmCardContent
                                 */
                                RbmCardContent.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent();
                                    if (object.title != null)
                                        message.title = String(object.title);
                                    if (object.description != null)
                                        message.description = String(object.description);
                                    if (object.media != null) {
                                        if (typeof object.media !== "object")
                                            throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.media: object expected");
                                        message.media = $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.RbmMedia.fromObject(object.media);
                                    }
                                    if (object.suggestions) {
                                        if (!Array.isArray(object.suggestions))
                                            throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.suggestions: array expected");
                                        message.suggestions = [];
                                        for (var i = 0; i < object.suggestions.length; ++i) {
                                            if (typeof object.suggestions[i] !== "object")
                                                throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.suggestions: object expected");
                                            message.suggestions[i] = $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestion.fromObject(object.suggestions[i]);
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a RbmCardContent message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent} message RbmCardContent
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                RbmCardContent.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.arrays || options.defaults)
                                        object.suggestions = [];
                                    if (options.defaults) {
                                        object.title = "";
                                        object.description = "";
                                        object.media = null;
                                    }
                                    if (message.title != null && message.hasOwnProperty("title"))
                                        object.title = message.title;
                                    if (message.description != null && message.hasOwnProperty("description"))
                                        object.description = message.description;
                                    if (message.media != null && message.hasOwnProperty("media"))
                                        object.media = $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.RbmMedia.toObject(message.media, options);
                                    if (message.suggestions && message.suggestions.length) {
                                        object.suggestions = [];
                                        for (var j = 0; j < message.suggestions.length; ++j)
                                            object.suggestions[j] = $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestion.toObject(message.suggestions[j], options);
                                    }
                                    return object;
                                };
    
                                /**
                                 * Converts this RbmCardContent to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                RbmCardContent.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for RbmCardContent
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                RbmCardContent.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent";
                                };
    
                                RbmCardContent.RbmMedia = (function() {
    
                                    /**
                                     * Properties of a RbmMedia.
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent
                                     * @interface IRbmMedia
                                     * @property {string|null} [fileUri] RbmMedia fileUri
                                     * @property {string|null} [thumbnailUri] RbmMedia thumbnailUri
                                     * @property {google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.RbmMedia.Height|null} [height] RbmMedia height
                                     */
    
                                    /**
                                     * Constructs a new RbmMedia.
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent
                                     * @classdesc Represents a RbmMedia.
                                     * @implements IRbmMedia
                                     * @constructor
                                     * @param {google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.IRbmMedia=} [properties] Properties to set
                                     */
                                    function RbmMedia(properties) {
                                        if (properties)
                                            for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                                if (properties[keys[i]] != null)
                                                    this[keys[i]] = properties[keys[i]];
                                    }
    
                                    /**
                                     * RbmMedia fileUri.
                                     * @member {string} fileUri
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.RbmMedia
                                     * @instance
                                     */
                                    RbmMedia.prototype.fileUri = "";
    
                                    /**
                                     * RbmMedia thumbnailUri.
                                     * @member {string} thumbnailUri
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.RbmMedia
                                     * @instance
                                     */
                                    RbmMedia.prototype.thumbnailUri = "";
    
                                    /**
                                     * RbmMedia height.
                                     * @member {google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.RbmMedia.Height} height
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.RbmMedia
                                     * @instance
                                     */
                                    RbmMedia.prototype.height = 0;
    
                                    /**
                                     * Creates a new RbmMedia instance using the specified properties.
                                     * @function create
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.RbmMedia
                                     * @static
                                     * @param {google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.IRbmMedia=} [properties] Properties to set
                                     * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.RbmMedia} RbmMedia instance
                                     */
                                    RbmMedia.create = function create(properties) {
                                        return new RbmMedia(properties);
                                    };
    
                                    /**
                                     * Encodes the specified RbmMedia message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.RbmMedia.verify|verify} messages.
                                     * @function encode
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.RbmMedia
                                     * @static
                                     * @param {google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.IRbmMedia} message RbmMedia message or plain object to encode
                                     * @param {$protobuf.Writer} [writer] Writer to encode to
                                     * @returns {$protobuf.Writer} Writer
                                     */
                                    RbmMedia.encode = function encode(message, writer) {
                                        if (!writer)
                                            writer = $Writer.create();
                                        if (message.fileUri != null && Object.hasOwnProperty.call(message, "fileUri"))
                                            writer.uint32(/* id 1, wireType 2 =*/10).string(message.fileUri);
                                        if (message.thumbnailUri != null && Object.hasOwnProperty.call(message, "thumbnailUri"))
                                            writer.uint32(/* id 2, wireType 2 =*/18).string(message.thumbnailUri);
                                        if (message.height != null && Object.hasOwnProperty.call(message, "height"))
                                            writer.uint32(/* id 3, wireType 0 =*/24).int32(message.height);
                                        return writer;
                                    };
    
                                    /**
                                     * Encodes the specified RbmMedia message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.RbmMedia.verify|verify} messages.
                                     * @function encodeDelimited
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.RbmMedia
                                     * @static
                                     * @param {google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.IRbmMedia} message RbmMedia message or plain object to encode
                                     * @param {$protobuf.Writer} [writer] Writer to encode to
                                     * @returns {$protobuf.Writer} Writer
                                     */
                                    RbmMedia.encodeDelimited = function encodeDelimited(message, writer) {
                                        return this.encode(message, writer).ldelim();
                                    };
    
                                    /**
                                     * Decodes a RbmMedia message from the specified reader or buffer.
                                     * @function decode
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.RbmMedia
                                     * @static
                                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                     * @param {number} [length] Message length if known beforehand
                                     * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.RbmMedia} RbmMedia
                                     * @throws {Error} If the payload is not a reader or valid buffer
                                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                     */
                                    RbmMedia.decode = function decode(reader, length) {
                                        if (!(reader instanceof $Reader))
                                            reader = $Reader.create(reader);
                                        var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.RbmMedia();
                                        while (reader.pos < end) {
                                            var tag = reader.uint32();
                                            switch (tag >>> 3) {
                                            case 1: {
                                                    message.fileUri = reader.string();
                                                    break;
                                                }
                                            case 2: {
                                                    message.thumbnailUri = reader.string();
                                                    break;
                                                }
                                            case 3: {
                                                    message.height = reader.int32();
                                                    break;
                                                }
                                            default:
                                                reader.skipType(tag & 7);
                                                break;
                                            }
                                        }
                                        return message;
                                    };
    
                                    /**
                                     * Decodes a RbmMedia message from the specified reader or buffer, length delimited.
                                     * @function decodeDelimited
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.RbmMedia
                                     * @static
                                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                     * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.RbmMedia} RbmMedia
                                     * @throws {Error} If the payload is not a reader or valid buffer
                                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                     */
                                    RbmMedia.decodeDelimited = function decodeDelimited(reader) {
                                        if (!(reader instanceof $Reader))
                                            reader = new $Reader(reader);
                                        return this.decode(reader, reader.uint32());
                                    };
    
                                    /**
                                     * Verifies a RbmMedia message.
                                     * @function verify
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.RbmMedia
                                     * @static
                                     * @param {Object.<string,*>} message Plain object to verify
                                     * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                     */
                                    RbmMedia.verify = function verify(message) {
                                        if (typeof message !== "object" || message === null)
                                            return "object expected";
                                        if (message.fileUri != null && message.hasOwnProperty("fileUri"))
                                            if (!$util.isString(message.fileUri))
                                                return "fileUri: string expected";
                                        if (message.thumbnailUri != null && message.hasOwnProperty("thumbnailUri"))
                                            if (!$util.isString(message.thumbnailUri))
                                                return "thumbnailUri: string expected";
                                        if (message.height != null && message.hasOwnProperty("height"))
                                            switch (message.height) {
                                            default:
                                                return "height: enum value expected";
                                            case 0:
                                            case 1:
                                            case 2:
                                            case 3:
                                                break;
                                            }
                                        return null;
                                    };
    
                                    /**
                                     * Creates a RbmMedia message from a plain object. Also converts values to their respective internal types.
                                     * @function fromObject
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.RbmMedia
                                     * @static
                                     * @param {Object.<string,*>} object Plain object
                                     * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.RbmMedia} RbmMedia
                                     */
                                    RbmMedia.fromObject = function fromObject(object) {
                                        if (object instanceof $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.RbmMedia)
                                            return object;
                                        var message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.RbmMedia();
                                        if (object.fileUri != null)
                                            message.fileUri = String(object.fileUri);
                                        if (object.thumbnailUri != null)
                                            message.thumbnailUri = String(object.thumbnailUri);
                                        switch (object.height) {
                                        default:
                                            if (typeof object.height === "number") {
                                                message.height = object.height;
                                                break;
                                            }
                                            break;
                                        case "HEIGHT_UNSPECIFIED":
                                        case 0:
                                            message.height = 0;
                                            break;
                                        case "SHORT":
                                        case 1:
                                            message.height = 1;
                                            break;
                                        case "MEDIUM":
                                        case 2:
                                            message.height = 2;
                                            break;
                                        case "TALL":
                                        case 3:
                                            message.height = 3;
                                            break;
                                        }
                                        return message;
                                    };
    
                                    /**
                                     * Creates a plain object from a RbmMedia message. Also converts values to other types if specified.
                                     * @function toObject
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.RbmMedia
                                     * @static
                                     * @param {google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.RbmMedia} message RbmMedia
                                     * @param {$protobuf.IConversionOptions} [options] Conversion options
                                     * @returns {Object.<string,*>} Plain object
                                     */
                                    RbmMedia.toObject = function toObject(message, options) {
                                        if (!options)
                                            options = {};
                                        var object = {};
                                        if (options.defaults) {
                                            object.fileUri = "";
                                            object.thumbnailUri = "";
                                            object.height = options.enums === String ? "HEIGHT_UNSPECIFIED" : 0;
                                        }
                                        if (message.fileUri != null && message.hasOwnProperty("fileUri"))
                                            object.fileUri = message.fileUri;
                                        if (message.thumbnailUri != null && message.hasOwnProperty("thumbnailUri"))
                                            object.thumbnailUri = message.thumbnailUri;
                                        if (message.height != null && message.hasOwnProperty("height"))
                                            object.height = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.RbmMedia.Height[message.height] === undefined ? message.height : $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.RbmMedia.Height[message.height] : message.height;
                                        return object;
                                    };
    
                                    /**
                                     * Converts this RbmMedia to JSON.
                                     * @function toJSON
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.RbmMedia
                                     * @instance
                                     * @returns {Object.<string,*>} JSON object
                                     */
                                    RbmMedia.prototype.toJSON = function toJSON() {
                                        return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                    };
    
                                    /**
                                     * Gets the default type url for RbmMedia
                                     * @function getTypeUrl
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.RbmMedia
                                     * @static
                                     * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                     * @returns {string} The default type url
                                     */
                                    RbmMedia.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                        if (typeUrlPrefix === undefined) {
                                            typeUrlPrefix = "type.googleapis.com";
                                        }
                                        return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.RbmMedia";
                                    };
    
                                    /**
                                     * Height enum.
                                     * @name google.cloud.dialogflow.v2beta1.Intent.Message.RbmCardContent.RbmMedia.Height
                                     * @enum {number}
                                     * @property {number} HEIGHT_UNSPECIFIED=0 HEIGHT_UNSPECIFIED value
                                     * @property {number} SHORT=1 SHORT value
                                     * @property {number} MEDIUM=2 MEDIUM value
                                     * @property {number} TALL=3 TALL value
                                     */
                                    RbmMedia.Height = (function() {
                                        var valuesById = {}, values = Object.create(valuesById);
                                        values[valuesById[0] = "HEIGHT_UNSPECIFIED"] = 0;
                                        values[valuesById[1] = "SHORT"] = 1;
                                        values[valuesById[2] = "MEDIUM"] = 2;
                                        values[valuesById[3] = "TALL"] = 3;
                                        return values;
                                    })();
    
                                    return RbmMedia;
                                })();
    
                                return RbmCardContent;
                            })();
    
                            Message.RbmSuggestion = (function() {
    
                                /**
                                 * Properties of a RbmSuggestion.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @interface IRbmSuggestion
                                 * @property {google.cloud.dialogflow.v2beta1.Intent.Message.IRbmSuggestedReply|null} [reply] RbmSuggestion reply
                                 * @property {google.cloud.dialogflow.v2beta1.Intent.Message.IRbmSuggestedAction|null} [action] RbmSuggestion action
                                 */
    
                                /**
                                 * Constructs a new RbmSuggestion.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @classdesc Represents a RbmSuggestion.
                                 * @implements IRbmSuggestion
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IRbmSuggestion=} [properties] Properties to set
                                 */
                                function RbmSuggestion(properties) {
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * RbmSuggestion reply.
                                 * @member {google.cloud.dialogflow.v2beta1.Intent.Message.IRbmSuggestedReply|null|undefined} reply
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestion
                                 * @instance
                                 */
                                RbmSuggestion.prototype.reply = null;
    
                                /**
                                 * RbmSuggestion action.
                                 * @member {google.cloud.dialogflow.v2beta1.Intent.Message.IRbmSuggestedAction|null|undefined} action
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestion
                                 * @instance
                                 */
                                RbmSuggestion.prototype.action = null;
    
                                // OneOf field names bound to virtual getters and setters
                                var $oneOfFields;
    
                                /**
                                 * RbmSuggestion suggestion.
                                 * @member {"reply"|"action"|undefined} suggestion
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestion
                                 * @instance
                                 */
                                Object.defineProperty(RbmSuggestion.prototype, "suggestion", {
                                    get: $util.oneOfGetter($oneOfFields = ["reply", "action"]),
                                    set: $util.oneOfSetter($oneOfFields)
                                });
    
                                /**
                                 * Creates a new RbmSuggestion instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestion
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IRbmSuggestion=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestion} RbmSuggestion instance
                                 */
                                RbmSuggestion.create = function create(properties) {
                                    return new RbmSuggestion(properties);
                                };
    
                                /**
                                 * Encodes the specified RbmSuggestion message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestion.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestion
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IRbmSuggestion} message RbmSuggestion message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                RbmSuggestion.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.reply != null && Object.hasOwnProperty.call(message, "reply"))
                                        $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedReply.encode(message.reply, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                                    if (message.action != null && Object.hasOwnProperty.call(message, "action"))
                                        $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.encode(message.action, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified RbmSuggestion message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestion.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestion
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IRbmSuggestion} message RbmSuggestion message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                RbmSuggestion.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a RbmSuggestion message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestion
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestion} RbmSuggestion
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                RbmSuggestion.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestion();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                message.reply = $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedReply.decode(reader, reader.uint32());
                                                break;
                                            }
                                        case 2: {
                                                message.action = $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.decode(reader, reader.uint32());
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a RbmSuggestion message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestion
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestion} RbmSuggestion
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                RbmSuggestion.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a RbmSuggestion message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestion
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                RbmSuggestion.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    var properties = {};
                                    if (message.reply != null && message.hasOwnProperty("reply")) {
                                        properties.suggestion = 1;
                                        {
                                            var error = $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedReply.verify(message.reply);
                                            if (error)
                                                return "reply." + error;
                                        }
                                    }
                                    if (message.action != null && message.hasOwnProperty("action")) {
                                        if (properties.suggestion === 1)
                                            return "suggestion: multiple values";
                                        properties.suggestion = 1;
                                        {
                                            var error = $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.verify(message.action);
                                            if (error)
                                                return "action." + error;
                                        }
                                    }
                                    return null;
                                };
    
                                /**
                                 * Creates a RbmSuggestion message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestion
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestion} RbmSuggestion
                                 */
                                RbmSuggestion.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestion)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestion();
                                    if (object.reply != null) {
                                        if (typeof object.reply !== "object")
                                            throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestion.reply: object expected");
                                        message.reply = $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedReply.fromObject(object.reply);
                                    }
                                    if (object.action != null) {
                                        if (typeof object.action !== "object")
                                            throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestion.action: object expected");
                                        message.action = $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.fromObject(object.action);
                                    }
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a RbmSuggestion message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestion
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestion} message RbmSuggestion
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                RbmSuggestion.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (message.reply != null && message.hasOwnProperty("reply")) {
                                        object.reply = $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedReply.toObject(message.reply, options);
                                        if (options.oneofs)
                                            object.suggestion = "reply";
                                    }
                                    if (message.action != null && message.hasOwnProperty("action")) {
                                        object.action = $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.toObject(message.action, options);
                                        if (options.oneofs)
                                            object.suggestion = "action";
                                    }
                                    return object;
                                };
    
                                /**
                                 * Converts this RbmSuggestion to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestion
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                RbmSuggestion.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for RbmSuggestion
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestion
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                RbmSuggestion.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestion";
                                };
    
                                return RbmSuggestion;
                            })();
    
                            Message.RbmSuggestedReply = (function() {
    
                                /**
                                 * Properties of a RbmSuggestedReply.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @interface IRbmSuggestedReply
                                 * @property {string|null} [text] RbmSuggestedReply text
                                 * @property {string|null} [postbackData] RbmSuggestedReply postbackData
                                 */
    
                                /**
                                 * Constructs a new RbmSuggestedReply.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @classdesc Represents a RbmSuggestedReply.
                                 * @implements IRbmSuggestedReply
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IRbmSuggestedReply=} [properties] Properties to set
                                 */
                                function RbmSuggestedReply(properties) {
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * RbmSuggestedReply text.
                                 * @member {string} text
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedReply
                                 * @instance
                                 */
                                RbmSuggestedReply.prototype.text = "";
    
                                /**
                                 * RbmSuggestedReply postbackData.
                                 * @member {string} postbackData
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedReply
                                 * @instance
                                 */
                                RbmSuggestedReply.prototype.postbackData = "";
    
                                /**
                                 * Creates a new RbmSuggestedReply instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedReply
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IRbmSuggestedReply=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedReply} RbmSuggestedReply instance
                                 */
                                RbmSuggestedReply.create = function create(properties) {
                                    return new RbmSuggestedReply(properties);
                                };
    
                                /**
                                 * Encodes the specified RbmSuggestedReply message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedReply.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedReply
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IRbmSuggestedReply} message RbmSuggestedReply message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                RbmSuggestedReply.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.text != null && Object.hasOwnProperty.call(message, "text"))
                                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.text);
                                    if (message.postbackData != null && Object.hasOwnProperty.call(message, "postbackData"))
                                        writer.uint32(/* id 2, wireType 2 =*/18).string(message.postbackData);
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified RbmSuggestedReply message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedReply.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedReply
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IRbmSuggestedReply} message RbmSuggestedReply message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                RbmSuggestedReply.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a RbmSuggestedReply message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedReply
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedReply} RbmSuggestedReply
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                RbmSuggestedReply.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedReply();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                message.text = reader.string();
                                                break;
                                            }
                                        case 2: {
                                                message.postbackData = reader.string();
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a RbmSuggestedReply message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedReply
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedReply} RbmSuggestedReply
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                RbmSuggestedReply.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a RbmSuggestedReply message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedReply
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                RbmSuggestedReply.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.text != null && message.hasOwnProperty("text"))
                                        if (!$util.isString(message.text))
                                            return "text: string expected";
                                    if (message.postbackData != null && message.hasOwnProperty("postbackData"))
                                        if (!$util.isString(message.postbackData))
                                            return "postbackData: string expected";
                                    return null;
                                };
    
                                /**
                                 * Creates a RbmSuggestedReply message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedReply
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedReply} RbmSuggestedReply
                                 */
                                RbmSuggestedReply.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedReply)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedReply();
                                    if (object.text != null)
                                        message.text = String(object.text);
                                    if (object.postbackData != null)
                                        message.postbackData = String(object.postbackData);
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a RbmSuggestedReply message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedReply
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedReply} message RbmSuggestedReply
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                RbmSuggestedReply.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.defaults) {
                                        object.text = "";
                                        object.postbackData = "";
                                    }
                                    if (message.text != null && message.hasOwnProperty("text"))
                                        object.text = message.text;
                                    if (message.postbackData != null && message.hasOwnProperty("postbackData"))
                                        object.postbackData = message.postbackData;
                                    return object;
                                };
    
                                /**
                                 * Converts this RbmSuggestedReply to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedReply
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                RbmSuggestedReply.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for RbmSuggestedReply
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedReply
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                RbmSuggestedReply.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedReply";
                                };
    
                                return RbmSuggestedReply;
                            })();
    
                            Message.RbmSuggestedAction = (function() {
    
                                /**
                                 * Properties of a RbmSuggestedAction.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @interface IRbmSuggestedAction
                                 * @property {string|null} [text] RbmSuggestedAction text
                                 * @property {string|null} [postbackData] RbmSuggestedAction postbackData
                                 * @property {google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.IRbmSuggestedActionDial|null} [dial] RbmSuggestedAction dial
                                 * @property {google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.IRbmSuggestedActionOpenUri|null} [openUrl] RbmSuggestedAction openUrl
                                 * @property {google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.IRbmSuggestedActionShareLocation|null} [shareLocation] RbmSuggestedAction shareLocation
                                 */
    
                                /**
                                 * Constructs a new RbmSuggestedAction.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @classdesc Represents a RbmSuggestedAction.
                                 * @implements IRbmSuggestedAction
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IRbmSuggestedAction=} [properties] Properties to set
                                 */
                                function RbmSuggestedAction(properties) {
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * RbmSuggestedAction text.
                                 * @member {string} text
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction
                                 * @instance
                                 */
                                RbmSuggestedAction.prototype.text = "";
    
                                /**
                                 * RbmSuggestedAction postbackData.
                                 * @member {string} postbackData
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction
                                 * @instance
                                 */
                                RbmSuggestedAction.prototype.postbackData = "";
    
                                /**
                                 * RbmSuggestedAction dial.
                                 * @member {google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.IRbmSuggestedActionDial|null|undefined} dial
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction
                                 * @instance
                                 */
                                RbmSuggestedAction.prototype.dial = null;
    
                                /**
                                 * RbmSuggestedAction openUrl.
                                 * @member {google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.IRbmSuggestedActionOpenUri|null|undefined} openUrl
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction
                                 * @instance
                                 */
                                RbmSuggestedAction.prototype.openUrl = null;
    
                                /**
                                 * RbmSuggestedAction shareLocation.
                                 * @member {google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.IRbmSuggestedActionShareLocation|null|undefined} shareLocation
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction
                                 * @instance
                                 */
                                RbmSuggestedAction.prototype.shareLocation = null;
    
                                // OneOf field names bound to virtual getters and setters
                                var $oneOfFields;
    
                                /**
                                 * RbmSuggestedAction action.
                                 * @member {"dial"|"openUrl"|"shareLocation"|undefined} action
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction
                                 * @instance
                                 */
                                Object.defineProperty(RbmSuggestedAction.prototype, "action", {
                                    get: $util.oneOfGetter($oneOfFields = ["dial", "openUrl", "shareLocation"]),
                                    set: $util.oneOfSetter($oneOfFields)
                                });
    
                                /**
                                 * Creates a new RbmSuggestedAction instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IRbmSuggestedAction=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction} RbmSuggestedAction instance
                                 */
                                RbmSuggestedAction.create = function create(properties) {
                                    return new RbmSuggestedAction(properties);
                                };
    
                                /**
                                 * Encodes the specified RbmSuggestedAction message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IRbmSuggestedAction} message RbmSuggestedAction message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                RbmSuggestedAction.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.text != null && Object.hasOwnProperty.call(message, "text"))
                                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.text);
                                    if (message.postbackData != null && Object.hasOwnProperty.call(message, "postbackData"))
                                        writer.uint32(/* id 2, wireType 2 =*/18).string(message.postbackData);
                                    if (message.dial != null && Object.hasOwnProperty.call(message, "dial"))
                                        $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionDial.encode(message.dial, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                                    if (message.openUrl != null && Object.hasOwnProperty.call(message, "openUrl"))
                                        $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionOpenUri.encode(message.openUrl, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                                    if (message.shareLocation != null && Object.hasOwnProperty.call(message, "shareLocation"))
                                        $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionShareLocation.encode(message.shareLocation, writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified RbmSuggestedAction message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IRbmSuggestedAction} message RbmSuggestedAction message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                RbmSuggestedAction.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a RbmSuggestedAction message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction} RbmSuggestedAction
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                RbmSuggestedAction.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                message.text = reader.string();
                                                break;
                                            }
                                        case 2: {
                                                message.postbackData = reader.string();
                                                break;
                                            }
                                        case 3: {
                                                message.dial = $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionDial.decode(reader, reader.uint32());
                                                break;
                                            }
                                        case 4: {
                                                message.openUrl = $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionOpenUri.decode(reader, reader.uint32());
                                                break;
                                            }
                                        case 5: {
                                                message.shareLocation = $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionShareLocation.decode(reader, reader.uint32());
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a RbmSuggestedAction message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction} RbmSuggestedAction
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                RbmSuggestedAction.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a RbmSuggestedAction message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                RbmSuggestedAction.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    var properties = {};
                                    if (message.text != null && message.hasOwnProperty("text"))
                                        if (!$util.isString(message.text))
                                            return "text: string expected";
                                    if (message.postbackData != null && message.hasOwnProperty("postbackData"))
                                        if (!$util.isString(message.postbackData))
                                            return "postbackData: string expected";
                                    if (message.dial != null && message.hasOwnProperty("dial")) {
                                        properties.action = 1;
                                        {
                                            var error = $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionDial.verify(message.dial);
                                            if (error)
                                                return "dial." + error;
                                        }
                                    }
                                    if (message.openUrl != null && message.hasOwnProperty("openUrl")) {
                                        if (properties.action === 1)
                                            return "action: multiple values";
                                        properties.action = 1;
                                        {
                                            var error = $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionOpenUri.verify(message.openUrl);
                                            if (error)
                                                return "openUrl." + error;
                                        }
                                    }
                                    if (message.shareLocation != null && message.hasOwnProperty("shareLocation")) {
                                        if (properties.action === 1)
                                            return "action: multiple values";
                                        properties.action = 1;
                                        {
                                            var error = $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionShareLocation.verify(message.shareLocation);
                                            if (error)
                                                return "shareLocation." + error;
                                        }
                                    }
                                    return null;
                                };
    
                                /**
                                 * Creates a RbmSuggestedAction message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction} RbmSuggestedAction
                                 */
                                RbmSuggestedAction.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction();
                                    if (object.text != null)
                                        message.text = String(object.text);
                                    if (object.postbackData != null)
                                        message.postbackData = String(object.postbackData);
                                    if (object.dial != null) {
                                        if (typeof object.dial !== "object")
                                            throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.dial: object expected");
                                        message.dial = $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionDial.fromObject(object.dial);
                                    }
                                    if (object.openUrl != null) {
                                        if (typeof object.openUrl !== "object")
                                            throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.openUrl: object expected");
                                        message.openUrl = $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionOpenUri.fromObject(object.openUrl);
                                    }
                                    if (object.shareLocation != null) {
                                        if (typeof object.shareLocation !== "object")
                                            throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.shareLocation: object expected");
                                        message.shareLocation = $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionShareLocation.fromObject(object.shareLocation);
                                    }
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a RbmSuggestedAction message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction} message RbmSuggestedAction
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                RbmSuggestedAction.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.defaults) {
                                        object.text = "";
                                        object.postbackData = "";
                                    }
                                    if (message.text != null && message.hasOwnProperty("text"))
                                        object.text = message.text;
                                    if (message.postbackData != null && message.hasOwnProperty("postbackData"))
                                        object.postbackData = message.postbackData;
                                    if (message.dial != null && message.hasOwnProperty("dial")) {
                                        object.dial = $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionDial.toObject(message.dial, options);
                                        if (options.oneofs)
                                            object.action = "dial";
                                    }
                                    if (message.openUrl != null && message.hasOwnProperty("openUrl")) {
                                        object.openUrl = $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionOpenUri.toObject(message.openUrl, options);
                                        if (options.oneofs)
                                            object.action = "openUrl";
                                    }
                                    if (message.shareLocation != null && message.hasOwnProperty("shareLocation")) {
                                        object.shareLocation = $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionShareLocation.toObject(message.shareLocation, options);
                                        if (options.oneofs)
                                            object.action = "shareLocation";
                                    }
                                    return object;
                                };
    
                                /**
                                 * Converts this RbmSuggestedAction to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                RbmSuggestedAction.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for RbmSuggestedAction
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                RbmSuggestedAction.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction";
                                };
    
                                RbmSuggestedAction.RbmSuggestedActionDial = (function() {
    
                                    /**
                                     * Properties of a RbmSuggestedActionDial.
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction
                                     * @interface IRbmSuggestedActionDial
                                     * @property {string|null} [phoneNumber] RbmSuggestedActionDial phoneNumber
                                     */
    
                                    /**
                                     * Constructs a new RbmSuggestedActionDial.
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction
                                     * @classdesc Represents a RbmSuggestedActionDial.
                                     * @implements IRbmSuggestedActionDial
                                     * @constructor
                                     * @param {google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.IRbmSuggestedActionDial=} [properties] Properties to set
                                     */
                                    function RbmSuggestedActionDial(properties) {
                                        if (properties)
                                            for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                                if (properties[keys[i]] != null)
                                                    this[keys[i]] = properties[keys[i]];
                                    }
    
                                    /**
                                     * RbmSuggestedActionDial phoneNumber.
                                     * @member {string} phoneNumber
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionDial
                                     * @instance
                                     */
                                    RbmSuggestedActionDial.prototype.phoneNumber = "";
    
                                    /**
                                     * Creates a new RbmSuggestedActionDial instance using the specified properties.
                                     * @function create
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionDial
                                     * @static
                                     * @param {google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.IRbmSuggestedActionDial=} [properties] Properties to set
                                     * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionDial} RbmSuggestedActionDial instance
                                     */
                                    RbmSuggestedActionDial.create = function create(properties) {
                                        return new RbmSuggestedActionDial(properties);
                                    };
    
                                    /**
                                     * Encodes the specified RbmSuggestedActionDial message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionDial.verify|verify} messages.
                                     * @function encode
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionDial
                                     * @static
                                     * @param {google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.IRbmSuggestedActionDial} message RbmSuggestedActionDial message or plain object to encode
                                     * @param {$protobuf.Writer} [writer] Writer to encode to
                                     * @returns {$protobuf.Writer} Writer
                                     */
                                    RbmSuggestedActionDial.encode = function encode(message, writer) {
                                        if (!writer)
                                            writer = $Writer.create();
                                        if (message.phoneNumber != null && Object.hasOwnProperty.call(message, "phoneNumber"))
                                            writer.uint32(/* id 1, wireType 2 =*/10).string(message.phoneNumber);
                                        return writer;
                                    };
    
                                    /**
                                     * Encodes the specified RbmSuggestedActionDial message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionDial.verify|verify} messages.
                                     * @function encodeDelimited
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionDial
                                     * @static
                                     * @param {google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.IRbmSuggestedActionDial} message RbmSuggestedActionDial message or plain object to encode
                                     * @param {$protobuf.Writer} [writer] Writer to encode to
                                     * @returns {$protobuf.Writer} Writer
                                     */
                                    RbmSuggestedActionDial.encodeDelimited = function encodeDelimited(message, writer) {
                                        return this.encode(message, writer).ldelim();
                                    };
    
                                    /**
                                     * Decodes a RbmSuggestedActionDial message from the specified reader or buffer.
                                     * @function decode
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionDial
                                     * @static
                                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                     * @param {number} [length] Message length if known beforehand
                                     * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionDial} RbmSuggestedActionDial
                                     * @throws {Error} If the payload is not a reader or valid buffer
                                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                     */
                                    RbmSuggestedActionDial.decode = function decode(reader, length) {
                                        if (!(reader instanceof $Reader))
                                            reader = $Reader.create(reader);
                                        var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionDial();
                                        while (reader.pos < end) {
                                            var tag = reader.uint32();
                                            switch (tag >>> 3) {
                                            case 1: {
                                                    message.phoneNumber = reader.string();
                                                    break;
                                                }
                                            default:
                                                reader.skipType(tag & 7);
                                                break;
                                            }
                                        }
                                        return message;
                                    };
    
                                    /**
                                     * Decodes a RbmSuggestedActionDial message from the specified reader or buffer, length delimited.
                                     * @function decodeDelimited
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionDial
                                     * @static
                                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                     * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionDial} RbmSuggestedActionDial
                                     * @throws {Error} If the payload is not a reader or valid buffer
                                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                     */
                                    RbmSuggestedActionDial.decodeDelimited = function decodeDelimited(reader) {
                                        if (!(reader instanceof $Reader))
                                            reader = new $Reader(reader);
                                        return this.decode(reader, reader.uint32());
                                    };
    
                                    /**
                                     * Verifies a RbmSuggestedActionDial message.
                                     * @function verify
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionDial
                                     * @static
                                     * @param {Object.<string,*>} message Plain object to verify
                                     * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                     */
                                    RbmSuggestedActionDial.verify = function verify(message) {
                                        if (typeof message !== "object" || message === null)
                                            return "object expected";
                                        if (message.phoneNumber != null && message.hasOwnProperty("phoneNumber"))
                                            if (!$util.isString(message.phoneNumber))
                                                return "phoneNumber: string expected";
                                        return null;
                                    };
    
                                    /**
                                     * Creates a RbmSuggestedActionDial message from a plain object. Also converts values to their respective internal types.
                                     * @function fromObject
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionDial
                                     * @static
                                     * @param {Object.<string,*>} object Plain object
                                     * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionDial} RbmSuggestedActionDial
                                     */
                                    RbmSuggestedActionDial.fromObject = function fromObject(object) {
                                        if (object instanceof $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionDial)
                                            return object;
                                        var message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionDial();
                                        if (object.phoneNumber != null)
                                            message.phoneNumber = String(object.phoneNumber);
                                        return message;
                                    };
    
                                    /**
                                     * Creates a plain object from a RbmSuggestedActionDial message. Also converts values to other types if specified.
                                     * @function toObject
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionDial
                                     * @static
                                     * @param {google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionDial} message RbmSuggestedActionDial
                                     * @param {$protobuf.IConversionOptions} [options] Conversion options
                                     * @returns {Object.<string,*>} Plain object
                                     */
                                    RbmSuggestedActionDial.toObject = function toObject(message, options) {
                                        if (!options)
                                            options = {};
                                        var object = {};
                                        if (options.defaults)
                                            object.phoneNumber = "";
                                        if (message.phoneNumber != null && message.hasOwnProperty("phoneNumber"))
                                            object.phoneNumber = message.phoneNumber;
                                        return object;
                                    };
    
                                    /**
                                     * Converts this RbmSuggestedActionDial to JSON.
                                     * @function toJSON
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionDial
                                     * @instance
                                     * @returns {Object.<string,*>} JSON object
                                     */
                                    RbmSuggestedActionDial.prototype.toJSON = function toJSON() {
                                        return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                    };
    
                                    /**
                                     * Gets the default type url for RbmSuggestedActionDial
                                     * @function getTypeUrl
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionDial
                                     * @static
                                     * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                     * @returns {string} The default type url
                                     */
                                    RbmSuggestedActionDial.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                        if (typeUrlPrefix === undefined) {
                                            typeUrlPrefix = "type.googleapis.com";
                                        }
                                        return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionDial";
                                    };
    
                                    return RbmSuggestedActionDial;
                                })();
    
                                RbmSuggestedAction.RbmSuggestedActionOpenUri = (function() {
    
                                    /**
                                     * Properties of a RbmSuggestedActionOpenUri.
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction
                                     * @interface IRbmSuggestedActionOpenUri
                                     * @property {string|null} [uri] RbmSuggestedActionOpenUri uri
                                     */
    
                                    /**
                                     * Constructs a new RbmSuggestedActionOpenUri.
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction
                                     * @classdesc Represents a RbmSuggestedActionOpenUri.
                                     * @implements IRbmSuggestedActionOpenUri
                                     * @constructor
                                     * @param {google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.IRbmSuggestedActionOpenUri=} [properties] Properties to set
                                     */
                                    function RbmSuggestedActionOpenUri(properties) {
                                        if (properties)
                                            for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                                if (properties[keys[i]] != null)
                                                    this[keys[i]] = properties[keys[i]];
                                    }
    
                                    /**
                                     * RbmSuggestedActionOpenUri uri.
                                     * @member {string} uri
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionOpenUri
                                     * @instance
                                     */
                                    RbmSuggestedActionOpenUri.prototype.uri = "";
    
                                    /**
                                     * Creates a new RbmSuggestedActionOpenUri instance using the specified properties.
                                     * @function create
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionOpenUri
                                     * @static
                                     * @param {google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.IRbmSuggestedActionOpenUri=} [properties] Properties to set
                                     * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionOpenUri} RbmSuggestedActionOpenUri instance
                                     */
                                    RbmSuggestedActionOpenUri.create = function create(properties) {
                                        return new RbmSuggestedActionOpenUri(properties);
                                    };
    
                                    /**
                                     * Encodes the specified RbmSuggestedActionOpenUri message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionOpenUri.verify|verify} messages.
                                     * @function encode
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionOpenUri
                                     * @static
                                     * @param {google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.IRbmSuggestedActionOpenUri} message RbmSuggestedActionOpenUri message or plain object to encode
                                     * @param {$protobuf.Writer} [writer] Writer to encode to
                                     * @returns {$protobuf.Writer} Writer
                                     */
                                    RbmSuggestedActionOpenUri.encode = function encode(message, writer) {
                                        if (!writer)
                                            writer = $Writer.create();
                                        if (message.uri != null && Object.hasOwnProperty.call(message, "uri"))
                                            writer.uint32(/* id 1, wireType 2 =*/10).string(message.uri);
                                        return writer;
                                    };
    
                                    /**
                                     * Encodes the specified RbmSuggestedActionOpenUri message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionOpenUri.verify|verify} messages.
                                     * @function encodeDelimited
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionOpenUri
                                     * @static
                                     * @param {google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.IRbmSuggestedActionOpenUri} message RbmSuggestedActionOpenUri message or plain object to encode
                                     * @param {$protobuf.Writer} [writer] Writer to encode to
                                     * @returns {$protobuf.Writer} Writer
                                     */
                                    RbmSuggestedActionOpenUri.encodeDelimited = function encodeDelimited(message, writer) {
                                        return this.encode(message, writer).ldelim();
                                    };
    
                                    /**
                                     * Decodes a RbmSuggestedActionOpenUri message from the specified reader or buffer.
                                     * @function decode
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionOpenUri
                                     * @static
                                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                     * @param {number} [length] Message length if known beforehand
                                     * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionOpenUri} RbmSuggestedActionOpenUri
                                     * @throws {Error} If the payload is not a reader or valid buffer
                                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                     */
                                    RbmSuggestedActionOpenUri.decode = function decode(reader, length) {
                                        if (!(reader instanceof $Reader))
                                            reader = $Reader.create(reader);
                                        var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionOpenUri();
                                        while (reader.pos < end) {
                                            var tag = reader.uint32();
                                            switch (tag >>> 3) {
                                            case 1: {
                                                    message.uri = reader.string();
                                                    break;
                                                }
                                            default:
                                                reader.skipType(tag & 7);
                                                break;
                                            }
                                        }
                                        return message;
                                    };
    
                                    /**
                                     * Decodes a RbmSuggestedActionOpenUri message from the specified reader or buffer, length delimited.
                                     * @function decodeDelimited
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionOpenUri
                                     * @static
                                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                     * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionOpenUri} RbmSuggestedActionOpenUri
                                     * @throws {Error} If the payload is not a reader or valid buffer
                                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                     */
                                    RbmSuggestedActionOpenUri.decodeDelimited = function decodeDelimited(reader) {
                                        if (!(reader instanceof $Reader))
                                            reader = new $Reader(reader);
                                        return this.decode(reader, reader.uint32());
                                    };
    
                                    /**
                                     * Verifies a RbmSuggestedActionOpenUri message.
                                     * @function verify
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionOpenUri
                                     * @static
                                     * @param {Object.<string,*>} message Plain object to verify
                                     * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                     */
                                    RbmSuggestedActionOpenUri.verify = function verify(message) {
                                        if (typeof message !== "object" || message === null)
                                            return "object expected";
                                        if (message.uri != null && message.hasOwnProperty("uri"))
                                            if (!$util.isString(message.uri))
                                                return "uri: string expected";
                                        return null;
                                    };
    
                                    /**
                                     * Creates a RbmSuggestedActionOpenUri message from a plain object. Also converts values to their respective internal types.
                                     * @function fromObject
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionOpenUri
                                     * @static
                                     * @param {Object.<string,*>} object Plain object
                                     * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionOpenUri} RbmSuggestedActionOpenUri
                                     */
                                    RbmSuggestedActionOpenUri.fromObject = function fromObject(object) {
                                        if (object instanceof $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionOpenUri)
                                            return object;
                                        var message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionOpenUri();
                                        if (object.uri != null)
                                            message.uri = String(object.uri);
                                        return message;
                                    };
    
                                    /**
                                     * Creates a plain object from a RbmSuggestedActionOpenUri message. Also converts values to other types if specified.
                                     * @function toObject
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionOpenUri
                                     * @static
                                     * @param {google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionOpenUri} message RbmSuggestedActionOpenUri
                                     * @param {$protobuf.IConversionOptions} [options] Conversion options
                                     * @returns {Object.<string,*>} Plain object
                                     */
                                    RbmSuggestedActionOpenUri.toObject = function toObject(message, options) {
                                        if (!options)
                                            options = {};
                                        var object = {};
                                        if (options.defaults)
                                            object.uri = "";
                                        if (message.uri != null && message.hasOwnProperty("uri"))
                                            object.uri = message.uri;
                                        return object;
                                    };
    
                                    /**
                                     * Converts this RbmSuggestedActionOpenUri to JSON.
                                     * @function toJSON
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionOpenUri
                                     * @instance
                                     * @returns {Object.<string,*>} JSON object
                                     */
                                    RbmSuggestedActionOpenUri.prototype.toJSON = function toJSON() {
                                        return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                    };
    
                                    /**
                                     * Gets the default type url for RbmSuggestedActionOpenUri
                                     * @function getTypeUrl
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionOpenUri
                                     * @static
                                     * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                     * @returns {string} The default type url
                                     */
                                    RbmSuggestedActionOpenUri.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                        if (typeUrlPrefix === undefined) {
                                            typeUrlPrefix = "type.googleapis.com";
                                        }
                                        return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionOpenUri";
                                    };
    
                                    return RbmSuggestedActionOpenUri;
                                })();
    
                                RbmSuggestedAction.RbmSuggestedActionShareLocation = (function() {
    
                                    /**
                                     * Properties of a RbmSuggestedActionShareLocation.
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction
                                     * @interface IRbmSuggestedActionShareLocation
                                     */
    
                                    /**
                                     * Constructs a new RbmSuggestedActionShareLocation.
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction
                                     * @classdesc Represents a RbmSuggestedActionShareLocation.
                                     * @implements IRbmSuggestedActionShareLocation
                                     * @constructor
                                     * @param {google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.IRbmSuggestedActionShareLocation=} [properties] Properties to set
                                     */
                                    function RbmSuggestedActionShareLocation(properties) {
                                        if (properties)
                                            for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                                if (properties[keys[i]] != null)
                                                    this[keys[i]] = properties[keys[i]];
                                    }
    
                                    /**
                                     * Creates a new RbmSuggestedActionShareLocation instance using the specified properties.
                                     * @function create
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionShareLocation
                                     * @static
                                     * @param {google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.IRbmSuggestedActionShareLocation=} [properties] Properties to set
                                     * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionShareLocation} RbmSuggestedActionShareLocation instance
                                     */
                                    RbmSuggestedActionShareLocation.create = function create(properties) {
                                        return new RbmSuggestedActionShareLocation(properties);
                                    };
    
                                    /**
                                     * Encodes the specified RbmSuggestedActionShareLocation message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionShareLocation.verify|verify} messages.
                                     * @function encode
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionShareLocation
                                     * @static
                                     * @param {google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.IRbmSuggestedActionShareLocation} message RbmSuggestedActionShareLocation message or plain object to encode
                                     * @param {$protobuf.Writer} [writer] Writer to encode to
                                     * @returns {$protobuf.Writer} Writer
                                     */
                                    RbmSuggestedActionShareLocation.encode = function encode(message, writer) {
                                        if (!writer)
                                            writer = $Writer.create();
                                        return writer;
                                    };
    
                                    /**
                                     * Encodes the specified RbmSuggestedActionShareLocation message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionShareLocation.verify|verify} messages.
                                     * @function encodeDelimited
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionShareLocation
                                     * @static
                                     * @param {google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.IRbmSuggestedActionShareLocation} message RbmSuggestedActionShareLocation message or plain object to encode
                                     * @param {$protobuf.Writer} [writer] Writer to encode to
                                     * @returns {$protobuf.Writer} Writer
                                     */
                                    RbmSuggestedActionShareLocation.encodeDelimited = function encodeDelimited(message, writer) {
                                        return this.encode(message, writer).ldelim();
                                    };
    
                                    /**
                                     * Decodes a RbmSuggestedActionShareLocation message from the specified reader or buffer.
                                     * @function decode
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionShareLocation
                                     * @static
                                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                     * @param {number} [length] Message length if known beforehand
                                     * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionShareLocation} RbmSuggestedActionShareLocation
                                     * @throws {Error} If the payload is not a reader or valid buffer
                                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                     */
                                    RbmSuggestedActionShareLocation.decode = function decode(reader, length) {
                                        if (!(reader instanceof $Reader))
                                            reader = $Reader.create(reader);
                                        var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionShareLocation();
                                        while (reader.pos < end) {
                                            var tag = reader.uint32();
                                            switch (tag >>> 3) {
                                            default:
                                                reader.skipType(tag & 7);
                                                break;
                                            }
                                        }
                                        return message;
                                    };
    
                                    /**
                                     * Decodes a RbmSuggestedActionShareLocation message from the specified reader or buffer, length delimited.
                                     * @function decodeDelimited
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionShareLocation
                                     * @static
                                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                     * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionShareLocation} RbmSuggestedActionShareLocation
                                     * @throws {Error} If the payload is not a reader or valid buffer
                                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                     */
                                    RbmSuggestedActionShareLocation.decodeDelimited = function decodeDelimited(reader) {
                                        if (!(reader instanceof $Reader))
                                            reader = new $Reader(reader);
                                        return this.decode(reader, reader.uint32());
                                    };
    
                                    /**
                                     * Verifies a RbmSuggestedActionShareLocation message.
                                     * @function verify
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionShareLocation
                                     * @static
                                     * @param {Object.<string,*>} message Plain object to verify
                                     * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                     */
                                    RbmSuggestedActionShareLocation.verify = function verify(message) {
                                        if (typeof message !== "object" || message === null)
                                            return "object expected";
                                        return null;
                                    };
    
                                    /**
                                     * Creates a RbmSuggestedActionShareLocation message from a plain object. Also converts values to their respective internal types.
                                     * @function fromObject
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionShareLocation
                                     * @static
                                     * @param {Object.<string,*>} object Plain object
                                     * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionShareLocation} RbmSuggestedActionShareLocation
                                     */
                                    RbmSuggestedActionShareLocation.fromObject = function fromObject(object) {
                                        if (object instanceof $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionShareLocation)
                                            return object;
                                        return new $root.google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionShareLocation();
                                    };
    
                                    /**
                                     * Creates a plain object from a RbmSuggestedActionShareLocation message. Also converts values to other types if specified.
                                     * @function toObject
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionShareLocation
                                     * @static
                                     * @param {google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionShareLocation} message RbmSuggestedActionShareLocation
                                     * @param {$protobuf.IConversionOptions} [options] Conversion options
                                     * @returns {Object.<string,*>} Plain object
                                     */
                                    RbmSuggestedActionShareLocation.toObject = function toObject() {
                                        return {};
                                    };
    
                                    /**
                                     * Converts this RbmSuggestedActionShareLocation to JSON.
                                     * @function toJSON
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionShareLocation
                                     * @instance
                                     * @returns {Object.<string,*>} JSON object
                                     */
                                    RbmSuggestedActionShareLocation.prototype.toJSON = function toJSON() {
                                        return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                    };
    
                                    /**
                                     * Gets the default type url for RbmSuggestedActionShareLocation
                                     * @function getTypeUrl
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionShareLocation
                                     * @static
                                     * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                     * @returns {string} The default type url
                                     */
                                    RbmSuggestedActionShareLocation.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                        if (typeUrlPrefix === undefined) {
                                            typeUrlPrefix = "type.googleapis.com";
                                        }
                                        return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Intent.Message.RbmSuggestedAction.RbmSuggestedActionShareLocation";
                                    };
    
                                    return RbmSuggestedActionShareLocation;
                                })();
    
                                return RbmSuggestedAction;
                            })();
    
                            Message.MediaContent = (function() {
    
                                /**
                                 * Properties of a MediaContent.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @interface IMediaContent
                                 * @property {google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.ResponseMediaType|null} [mediaType] MediaContent mediaType
                                 * @property {Array.<google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.IResponseMediaObject>|null} [mediaObjects] MediaContent mediaObjects
                                 */
    
                                /**
                                 * Constructs a new MediaContent.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @classdesc Represents a MediaContent.
                                 * @implements IMediaContent
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IMediaContent=} [properties] Properties to set
                                 */
                                function MediaContent(properties) {
                                    this.mediaObjects = [];
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * MediaContent mediaType.
                                 * @member {google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.ResponseMediaType} mediaType
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent
                                 * @instance
                                 */
                                MediaContent.prototype.mediaType = 0;
    
                                /**
                                 * MediaContent mediaObjects.
                                 * @member {Array.<google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.IResponseMediaObject>} mediaObjects
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent
                                 * @instance
                                 */
                                MediaContent.prototype.mediaObjects = $util.emptyArray;
    
                                /**
                                 * Creates a new MediaContent instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IMediaContent=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent} MediaContent instance
                                 */
                                MediaContent.create = function create(properties) {
                                    return new MediaContent(properties);
                                };
    
                                /**
                                 * Encodes the specified MediaContent message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IMediaContent} message MediaContent message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                MediaContent.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.mediaType != null && Object.hasOwnProperty.call(message, "mediaType"))
                                        writer.uint32(/* id 1, wireType 0 =*/8).int32(message.mediaType);
                                    if (message.mediaObjects != null && message.mediaObjects.length)
                                        for (var i = 0; i < message.mediaObjects.length; ++i)
                                            $root.google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.ResponseMediaObject.encode(message.mediaObjects[i], writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified MediaContent message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IMediaContent} message MediaContent message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                MediaContent.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a MediaContent message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent} MediaContent
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                MediaContent.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                message.mediaType = reader.int32();
                                                break;
                                            }
                                        case 2: {
                                                if (!(message.mediaObjects && message.mediaObjects.length))
                                                    message.mediaObjects = [];
                                                message.mediaObjects.push($root.google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.ResponseMediaObject.decode(reader, reader.uint32()));
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a MediaContent message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent} MediaContent
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                MediaContent.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a MediaContent message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                MediaContent.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.mediaType != null && message.hasOwnProperty("mediaType"))
                                        switch (message.mediaType) {
                                        default:
                                            return "mediaType: enum value expected";
                                        case 0:
                                        case 1:
                                            break;
                                        }
                                    if (message.mediaObjects != null && message.hasOwnProperty("mediaObjects")) {
                                        if (!Array.isArray(message.mediaObjects))
                                            return "mediaObjects: array expected";
                                        for (var i = 0; i < message.mediaObjects.length; ++i) {
                                            var error = $root.google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.ResponseMediaObject.verify(message.mediaObjects[i]);
                                            if (error)
                                                return "mediaObjects." + error;
                                        }
                                    }
                                    return null;
                                };
    
                                /**
                                 * Creates a MediaContent message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent} MediaContent
                                 */
                                MediaContent.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent();
                                    switch (object.mediaType) {
                                    default:
                                        if (typeof object.mediaType === "number") {
                                            message.mediaType = object.mediaType;
                                            break;
                                        }
                                        break;
                                    case "RESPONSE_MEDIA_TYPE_UNSPECIFIED":
                                    case 0:
                                        message.mediaType = 0;
                                        break;
                                    case "AUDIO":
                                    case 1:
                                        message.mediaType = 1;
                                        break;
                                    }
                                    if (object.mediaObjects) {
                                        if (!Array.isArray(object.mediaObjects))
                                            throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.mediaObjects: array expected");
                                        message.mediaObjects = [];
                                        for (var i = 0; i < object.mediaObjects.length; ++i) {
                                            if (typeof object.mediaObjects[i] !== "object")
                                                throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.mediaObjects: object expected");
                                            message.mediaObjects[i] = $root.google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.ResponseMediaObject.fromObject(object.mediaObjects[i]);
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a MediaContent message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent} message MediaContent
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                MediaContent.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.arrays || options.defaults)
                                        object.mediaObjects = [];
                                    if (options.defaults)
                                        object.mediaType = options.enums === String ? "RESPONSE_MEDIA_TYPE_UNSPECIFIED" : 0;
                                    if (message.mediaType != null && message.hasOwnProperty("mediaType"))
                                        object.mediaType = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.ResponseMediaType[message.mediaType] === undefined ? message.mediaType : $root.google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.ResponseMediaType[message.mediaType] : message.mediaType;
                                    if (message.mediaObjects && message.mediaObjects.length) {
                                        object.mediaObjects = [];
                                        for (var j = 0; j < message.mediaObjects.length; ++j)
                                            object.mediaObjects[j] = $root.google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.ResponseMediaObject.toObject(message.mediaObjects[j], options);
                                    }
                                    return object;
                                };
    
                                /**
                                 * Converts this MediaContent to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                MediaContent.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for MediaContent
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                MediaContent.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent";
                                };
    
                                /**
                                 * ResponseMediaType enum.
                                 * @name google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.ResponseMediaType
                                 * @enum {number}
                                 * @property {number} RESPONSE_MEDIA_TYPE_UNSPECIFIED=0 RESPONSE_MEDIA_TYPE_UNSPECIFIED value
                                 * @property {number} AUDIO=1 AUDIO value
                                 */
                                MediaContent.ResponseMediaType = (function() {
                                    var valuesById = {}, values = Object.create(valuesById);
                                    values[valuesById[0] = "RESPONSE_MEDIA_TYPE_UNSPECIFIED"] = 0;
                                    values[valuesById[1] = "AUDIO"] = 1;
                                    return values;
                                })();
    
                                MediaContent.ResponseMediaObject = (function() {
    
                                    /**
                                     * Properties of a ResponseMediaObject.
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent
                                     * @interface IResponseMediaObject
                                     * @property {string|null} [name] ResponseMediaObject name
                                     * @property {string|null} [description] ResponseMediaObject description
                                     * @property {google.cloud.dialogflow.v2beta1.Intent.Message.IImage|null} [largeImage] ResponseMediaObject largeImage
                                     * @property {google.cloud.dialogflow.v2beta1.Intent.Message.IImage|null} [icon] ResponseMediaObject icon
                                     * @property {string|null} [contentUrl] ResponseMediaObject contentUrl
                                     */
    
                                    /**
                                     * Constructs a new ResponseMediaObject.
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent
                                     * @classdesc Represents a ResponseMediaObject.
                                     * @implements IResponseMediaObject
                                     * @constructor
                                     * @param {google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.IResponseMediaObject=} [properties] Properties to set
                                     */
                                    function ResponseMediaObject(properties) {
                                        if (properties)
                                            for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                                if (properties[keys[i]] != null)
                                                    this[keys[i]] = properties[keys[i]];
                                    }
    
                                    /**
                                     * ResponseMediaObject name.
                                     * @member {string} name
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.ResponseMediaObject
                                     * @instance
                                     */
                                    ResponseMediaObject.prototype.name = "";
    
                                    /**
                                     * ResponseMediaObject description.
                                     * @member {string} description
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.ResponseMediaObject
                                     * @instance
                                     */
                                    ResponseMediaObject.prototype.description = "";
    
                                    /**
                                     * ResponseMediaObject largeImage.
                                     * @member {google.cloud.dialogflow.v2beta1.Intent.Message.IImage|null|undefined} largeImage
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.ResponseMediaObject
                                     * @instance
                                     */
                                    ResponseMediaObject.prototype.largeImage = null;
    
                                    /**
                                     * ResponseMediaObject icon.
                                     * @member {google.cloud.dialogflow.v2beta1.Intent.Message.IImage|null|undefined} icon
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.ResponseMediaObject
                                     * @instance
                                     */
                                    ResponseMediaObject.prototype.icon = null;
    
                                    /**
                                     * ResponseMediaObject contentUrl.
                                     * @member {string} contentUrl
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.ResponseMediaObject
                                     * @instance
                                     */
                                    ResponseMediaObject.prototype.contentUrl = "";
    
                                    // OneOf field names bound to virtual getters and setters
                                    var $oneOfFields;
    
                                    /**
                                     * ResponseMediaObject image.
                                     * @member {"largeImage"|"icon"|undefined} image
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.ResponseMediaObject
                                     * @instance
                                     */
                                    Object.defineProperty(ResponseMediaObject.prototype, "image", {
                                        get: $util.oneOfGetter($oneOfFields = ["largeImage", "icon"]),
                                        set: $util.oneOfSetter($oneOfFields)
                                    });
    
                                    /**
                                     * Creates a new ResponseMediaObject instance using the specified properties.
                                     * @function create
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.ResponseMediaObject
                                     * @static
                                     * @param {google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.IResponseMediaObject=} [properties] Properties to set
                                     * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.ResponseMediaObject} ResponseMediaObject instance
                                     */
                                    ResponseMediaObject.create = function create(properties) {
                                        return new ResponseMediaObject(properties);
                                    };
    
                                    /**
                                     * Encodes the specified ResponseMediaObject message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.ResponseMediaObject.verify|verify} messages.
                                     * @function encode
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.ResponseMediaObject
                                     * @static
                                     * @param {google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.IResponseMediaObject} message ResponseMediaObject message or plain object to encode
                                     * @param {$protobuf.Writer} [writer] Writer to encode to
                                     * @returns {$protobuf.Writer} Writer
                                     */
                                    ResponseMediaObject.encode = function encode(message, writer) {
                                        if (!writer)
                                            writer = $Writer.create();
                                        if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                            writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                                        if (message.description != null && Object.hasOwnProperty.call(message, "description"))
                                            writer.uint32(/* id 2, wireType 2 =*/18).string(message.description);
                                        if (message.largeImage != null && Object.hasOwnProperty.call(message, "largeImage"))
                                            $root.google.cloud.dialogflow.v2beta1.Intent.Message.Image.encode(message.largeImage, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                                        if (message.icon != null && Object.hasOwnProperty.call(message, "icon"))
                                            $root.google.cloud.dialogflow.v2beta1.Intent.Message.Image.encode(message.icon, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                                        if (message.contentUrl != null && Object.hasOwnProperty.call(message, "contentUrl"))
                                            writer.uint32(/* id 5, wireType 2 =*/42).string(message.contentUrl);
                                        return writer;
                                    };
    
                                    /**
                                     * Encodes the specified ResponseMediaObject message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.ResponseMediaObject.verify|verify} messages.
                                     * @function encodeDelimited
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.ResponseMediaObject
                                     * @static
                                     * @param {google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.IResponseMediaObject} message ResponseMediaObject message or plain object to encode
                                     * @param {$protobuf.Writer} [writer] Writer to encode to
                                     * @returns {$protobuf.Writer} Writer
                                     */
                                    ResponseMediaObject.encodeDelimited = function encodeDelimited(message, writer) {
                                        return this.encode(message, writer).ldelim();
                                    };
    
                                    /**
                                     * Decodes a ResponseMediaObject message from the specified reader or buffer.
                                     * @function decode
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.ResponseMediaObject
                                     * @static
                                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                     * @param {number} [length] Message length if known beforehand
                                     * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.ResponseMediaObject} ResponseMediaObject
                                     * @throws {Error} If the payload is not a reader or valid buffer
                                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                     */
                                    ResponseMediaObject.decode = function decode(reader, length) {
                                        if (!(reader instanceof $Reader))
                                            reader = $Reader.create(reader);
                                        var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.ResponseMediaObject();
                                        while (reader.pos < end) {
                                            var tag = reader.uint32();
                                            switch (tag >>> 3) {
                                            case 1: {
                                                    message.name = reader.string();
                                                    break;
                                                }
                                            case 2: {
                                                    message.description = reader.string();
                                                    break;
                                                }
                                            case 3: {
                                                    message.largeImage = $root.google.cloud.dialogflow.v2beta1.Intent.Message.Image.decode(reader, reader.uint32());
                                                    break;
                                                }
                                            case 4: {
                                                    message.icon = $root.google.cloud.dialogflow.v2beta1.Intent.Message.Image.decode(reader, reader.uint32());
                                                    break;
                                                }
                                            case 5: {
                                                    message.contentUrl = reader.string();
                                                    break;
                                                }
                                            default:
                                                reader.skipType(tag & 7);
                                                break;
                                            }
                                        }
                                        return message;
                                    };
    
                                    /**
                                     * Decodes a ResponseMediaObject message from the specified reader or buffer, length delimited.
                                     * @function decodeDelimited
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.ResponseMediaObject
                                     * @static
                                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                     * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.ResponseMediaObject} ResponseMediaObject
                                     * @throws {Error} If the payload is not a reader or valid buffer
                                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                     */
                                    ResponseMediaObject.decodeDelimited = function decodeDelimited(reader) {
                                        if (!(reader instanceof $Reader))
                                            reader = new $Reader(reader);
                                        return this.decode(reader, reader.uint32());
                                    };
    
                                    /**
                                     * Verifies a ResponseMediaObject message.
                                     * @function verify
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.ResponseMediaObject
                                     * @static
                                     * @param {Object.<string,*>} message Plain object to verify
                                     * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                     */
                                    ResponseMediaObject.verify = function verify(message) {
                                        if (typeof message !== "object" || message === null)
                                            return "object expected";
                                        var properties = {};
                                        if (message.name != null && message.hasOwnProperty("name"))
                                            if (!$util.isString(message.name))
                                                return "name: string expected";
                                        if (message.description != null && message.hasOwnProperty("description"))
                                            if (!$util.isString(message.description))
                                                return "description: string expected";
                                        if (message.largeImage != null && message.hasOwnProperty("largeImage")) {
                                            properties.image = 1;
                                            {
                                                var error = $root.google.cloud.dialogflow.v2beta1.Intent.Message.Image.verify(message.largeImage);
                                                if (error)
                                                    return "largeImage." + error;
                                            }
                                        }
                                        if (message.icon != null && message.hasOwnProperty("icon")) {
                                            if (properties.image === 1)
                                                return "image: multiple values";
                                            properties.image = 1;
                                            {
                                                var error = $root.google.cloud.dialogflow.v2beta1.Intent.Message.Image.verify(message.icon);
                                                if (error)
                                                    return "icon." + error;
                                            }
                                        }
                                        if (message.contentUrl != null && message.hasOwnProperty("contentUrl"))
                                            if (!$util.isString(message.contentUrl))
                                                return "contentUrl: string expected";
                                        return null;
                                    };
    
                                    /**
                                     * Creates a ResponseMediaObject message from a plain object. Also converts values to their respective internal types.
                                     * @function fromObject
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.ResponseMediaObject
                                     * @static
                                     * @param {Object.<string,*>} object Plain object
                                     * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.ResponseMediaObject} ResponseMediaObject
                                     */
                                    ResponseMediaObject.fromObject = function fromObject(object) {
                                        if (object instanceof $root.google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.ResponseMediaObject)
                                            return object;
                                        var message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.ResponseMediaObject();
                                        if (object.name != null)
                                            message.name = String(object.name);
                                        if (object.description != null)
                                            message.description = String(object.description);
                                        if (object.largeImage != null) {
                                            if (typeof object.largeImage !== "object")
                                                throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.ResponseMediaObject.largeImage: object expected");
                                            message.largeImage = $root.google.cloud.dialogflow.v2beta1.Intent.Message.Image.fromObject(object.largeImage);
                                        }
                                        if (object.icon != null) {
                                            if (typeof object.icon !== "object")
                                                throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.ResponseMediaObject.icon: object expected");
                                            message.icon = $root.google.cloud.dialogflow.v2beta1.Intent.Message.Image.fromObject(object.icon);
                                        }
                                        if (object.contentUrl != null)
                                            message.contentUrl = String(object.contentUrl);
                                        return message;
                                    };
    
                                    /**
                                     * Creates a plain object from a ResponseMediaObject message. Also converts values to other types if specified.
                                     * @function toObject
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.ResponseMediaObject
                                     * @static
                                     * @param {google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.ResponseMediaObject} message ResponseMediaObject
                                     * @param {$protobuf.IConversionOptions} [options] Conversion options
                                     * @returns {Object.<string,*>} Plain object
                                     */
                                    ResponseMediaObject.toObject = function toObject(message, options) {
                                        if (!options)
                                            options = {};
                                        var object = {};
                                        if (options.defaults) {
                                            object.name = "";
                                            object.description = "";
                                            object.contentUrl = "";
                                        }
                                        if (message.name != null && message.hasOwnProperty("name"))
                                            object.name = message.name;
                                        if (message.description != null && message.hasOwnProperty("description"))
                                            object.description = message.description;
                                        if (message.largeImage != null && message.hasOwnProperty("largeImage")) {
                                            object.largeImage = $root.google.cloud.dialogflow.v2beta1.Intent.Message.Image.toObject(message.largeImage, options);
                                            if (options.oneofs)
                                                object.image = "largeImage";
                                        }
                                        if (message.icon != null && message.hasOwnProperty("icon")) {
                                            object.icon = $root.google.cloud.dialogflow.v2beta1.Intent.Message.Image.toObject(message.icon, options);
                                            if (options.oneofs)
                                                object.image = "icon";
                                        }
                                        if (message.contentUrl != null && message.hasOwnProperty("contentUrl"))
                                            object.contentUrl = message.contentUrl;
                                        return object;
                                    };
    
                                    /**
                                     * Converts this ResponseMediaObject to JSON.
                                     * @function toJSON
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.ResponseMediaObject
                                     * @instance
                                     * @returns {Object.<string,*>} JSON object
                                     */
                                    ResponseMediaObject.prototype.toJSON = function toJSON() {
                                        return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                    };
    
                                    /**
                                     * Gets the default type url for ResponseMediaObject
                                     * @function getTypeUrl
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.ResponseMediaObject
                                     * @static
                                     * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                     * @returns {string} The default type url
                                     */
                                    ResponseMediaObject.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                        if (typeUrlPrefix === undefined) {
                                            typeUrlPrefix = "type.googleapis.com";
                                        }
                                        return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Intent.Message.MediaContent.ResponseMediaObject";
                                    };
    
                                    return ResponseMediaObject;
                                })();
    
                                return MediaContent;
                            })();
    
                            Message.BrowseCarouselCard = (function() {
    
                                /**
                                 * Properties of a BrowseCarouselCard.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @interface IBrowseCarouselCard
                                 * @property {Array.<google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.IBrowseCarouselCardItem>|null} [items] BrowseCarouselCard items
                                 * @property {google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.ImageDisplayOptions|null} [imageDisplayOptions] BrowseCarouselCard imageDisplayOptions
                                 */
    
                                /**
                                 * Constructs a new BrowseCarouselCard.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @classdesc Represents a BrowseCarouselCard.
                                 * @implements IBrowseCarouselCard
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IBrowseCarouselCard=} [properties] Properties to set
                                 */
                                function BrowseCarouselCard(properties) {
                                    this.items = [];
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * BrowseCarouselCard items.
                                 * @member {Array.<google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.IBrowseCarouselCardItem>} items
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard
                                 * @instance
                                 */
                                BrowseCarouselCard.prototype.items = $util.emptyArray;
    
                                /**
                                 * BrowseCarouselCard imageDisplayOptions.
                                 * @member {google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.ImageDisplayOptions} imageDisplayOptions
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard
                                 * @instance
                                 */
                                BrowseCarouselCard.prototype.imageDisplayOptions = 0;
    
                                /**
                                 * Creates a new BrowseCarouselCard instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IBrowseCarouselCard=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard} BrowseCarouselCard instance
                                 */
                                BrowseCarouselCard.create = function create(properties) {
                                    return new BrowseCarouselCard(properties);
                                };
    
                                /**
                                 * Encodes the specified BrowseCarouselCard message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IBrowseCarouselCard} message BrowseCarouselCard message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                BrowseCarouselCard.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.items != null && message.items.length)
                                        for (var i = 0; i < message.items.length; ++i)
                                            $root.google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.encode(message.items[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                                    if (message.imageDisplayOptions != null && Object.hasOwnProperty.call(message, "imageDisplayOptions"))
                                        writer.uint32(/* id 2, wireType 0 =*/16).int32(message.imageDisplayOptions);
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified BrowseCarouselCard message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IBrowseCarouselCard} message BrowseCarouselCard message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                BrowseCarouselCard.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a BrowseCarouselCard message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard} BrowseCarouselCard
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                BrowseCarouselCard.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                if (!(message.items && message.items.length))
                                                    message.items = [];
                                                message.items.push($root.google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.decode(reader, reader.uint32()));
                                                break;
                                            }
                                        case 2: {
                                                message.imageDisplayOptions = reader.int32();
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a BrowseCarouselCard message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard} BrowseCarouselCard
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                BrowseCarouselCard.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a BrowseCarouselCard message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                BrowseCarouselCard.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.items != null && message.hasOwnProperty("items")) {
                                        if (!Array.isArray(message.items))
                                            return "items: array expected";
                                        for (var i = 0; i < message.items.length; ++i) {
                                            var error = $root.google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.verify(message.items[i]);
                                            if (error)
                                                return "items." + error;
                                        }
                                    }
                                    if (message.imageDisplayOptions != null && message.hasOwnProperty("imageDisplayOptions"))
                                        switch (message.imageDisplayOptions) {
                                        default:
                                            return "imageDisplayOptions: enum value expected";
                                        case 0:
                                        case 1:
                                        case 2:
                                        case 3:
                                        case 4:
                                            break;
                                        }
                                    return null;
                                };
    
                                /**
                                 * Creates a BrowseCarouselCard message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard} BrowseCarouselCard
                                 */
                                BrowseCarouselCard.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard();
                                    if (object.items) {
                                        if (!Array.isArray(object.items))
                                            throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.items: array expected");
                                        message.items = [];
                                        for (var i = 0; i < object.items.length; ++i) {
                                            if (typeof object.items[i] !== "object")
                                                throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.items: object expected");
                                            message.items[i] = $root.google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.fromObject(object.items[i]);
                                        }
                                    }
                                    switch (object.imageDisplayOptions) {
                                    default:
                                        if (typeof object.imageDisplayOptions === "number") {
                                            message.imageDisplayOptions = object.imageDisplayOptions;
                                            break;
                                        }
                                        break;
                                    case "IMAGE_DISPLAY_OPTIONS_UNSPECIFIED":
                                    case 0:
                                        message.imageDisplayOptions = 0;
                                        break;
                                    case "GRAY":
                                    case 1:
                                        message.imageDisplayOptions = 1;
                                        break;
                                    case "WHITE":
                                    case 2:
                                        message.imageDisplayOptions = 2;
                                        break;
                                    case "CROPPED":
                                    case 3:
                                        message.imageDisplayOptions = 3;
                                        break;
                                    case "BLURRED_BACKGROUND":
                                    case 4:
                                        message.imageDisplayOptions = 4;
                                        break;
                                    }
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a BrowseCarouselCard message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard} message BrowseCarouselCard
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                BrowseCarouselCard.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.arrays || options.defaults)
                                        object.items = [];
                                    if (options.defaults)
                                        object.imageDisplayOptions = options.enums === String ? "IMAGE_DISPLAY_OPTIONS_UNSPECIFIED" : 0;
                                    if (message.items && message.items.length) {
                                        object.items = [];
                                        for (var j = 0; j < message.items.length; ++j)
                                            object.items[j] = $root.google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.toObject(message.items[j], options);
                                    }
                                    if (message.imageDisplayOptions != null && message.hasOwnProperty("imageDisplayOptions"))
                                        object.imageDisplayOptions = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.ImageDisplayOptions[message.imageDisplayOptions] === undefined ? message.imageDisplayOptions : $root.google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.ImageDisplayOptions[message.imageDisplayOptions] : message.imageDisplayOptions;
                                    return object;
                                };
    
                                /**
                                 * Converts this BrowseCarouselCard to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                BrowseCarouselCard.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for BrowseCarouselCard
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                BrowseCarouselCard.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard";
                                };
    
                                BrowseCarouselCard.BrowseCarouselCardItem = (function() {
    
                                    /**
                                     * Properties of a BrowseCarouselCardItem.
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard
                                     * @interface IBrowseCarouselCardItem
                                     * @property {google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.IOpenUrlAction|null} [openUriAction] BrowseCarouselCardItem openUriAction
                                     * @property {string|null} [title] BrowseCarouselCardItem title
                                     * @property {string|null} [description] BrowseCarouselCardItem description
                                     * @property {google.cloud.dialogflow.v2beta1.Intent.Message.IImage|null} [image] BrowseCarouselCardItem image
                                     * @property {string|null} [footer] BrowseCarouselCardItem footer
                                     */
    
                                    /**
                                     * Constructs a new BrowseCarouselCardItem.
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard
                                     * @classdesc Represents a BrowseCarouselCardItem.
                                     * @implements IBrowseCarouselCardItem
                                     * @constructor
                                     * @param {google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.IBrowseCarouselCardItem=} [properties] Properties to set
                                     */
                                    function BrowseCarouselCardItem(properties) {
                                        if (properties)
                                            for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                                if (properties[keys[i]] != null)
                                                    this[keys[i]] = properties[keys[i]];
                                    }
    
                                    /**
                                     * BrowseCarouselCardItem openUriAction.
                                     * @member {google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.IOpenUrlAction|null|undefined} openUriAction
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem
                                     * @instance
                                     */
                                    BrowseCarouselCardItem.prototype.openUriAction = null;
    
                                    /**
                                     * BrowseCarouselCardItem title.
                                     * @member {string} title
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem
                                     * @instance
                                     */
                                    BrowseCarouselCardItem.prototype.title = "";
    
                                    /**
                                     * BrowseCarouselCardItem description.
                                     * @member {string} description
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem
                                     * @instance
                                     */
                                    BrowseCarouselCardItem.prototype.description = "";
    
                                    /**
                                     * BrowseCarouselCardItem image.
                                     * @member {google.cloud.dialogflow.v2beta1.Intent.Message.IImage|null|undefined} image
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem
                                     * @instance
                                     */
                                    BrowseCarouselCardItem.prototype.image = null;
    
                                    /**
                                     * BrowseCarouselCardItem footer.
                                     * @member {string} footer
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem
                                     * @instance
                                     */
                                    BrowseCarouselCardItem.prototype.footer = "";
    
                                    /**
                                     * Creates a new BrowseCarouselCardItem instance using the specified properties.
                                     * @function create
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem
                                     * @static
                                     * @param {google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.IBrowseCarouselCardItem=} [properties] Properties to set
                                     * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem} BrowseCarouselCardItem instance
                                     */
                                    BrowseCarouselCardItem.create = function create(properties) {
                                        return new BrowseCarouselCardItem(properties);
                                    };
    
                                    /**
                                     * Encodes the specified BrowseCarouselCardItem message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.verify|verify} messages.
                                     * @function encode
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem
                                     * @static
                                     * @param {google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.IBrowseCarouselCardItem} message BrowseCarouselCardItem message or plain object to encode
                                     * @param {$protobuf.Writer} [writer] Writer to encode to
                                     * @returns {$protobuf.Writer} Writer
                                     */
                                    BrowseCarouselCardItem.encode = function encode(message, writer) {
                                        if (!writer)
                                            writer = $Writer.create();
                                        if (message.openUriAction != null && Object.hasOwnProperty.call(message, "openUriAction"))
                                            $root.google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction.encode(message.openUriAction, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                                        if (message.title != null && Object.hasOwnProperty.call(message, "title"))
                                            writer.uint32(/* id 2, wireType 2 =*/18).string(message.title);
                                        if (message.description != null && Object.hasOwnProperty.call(message, "description"))
                                            writer.uint32(/* id 3, wireType 2 =*/26).string(message.description);
                                        if (message.image != null && Object.hasOwnProperty.call(message, "image"))
                                            $root.google.cloud.dialogflow.v2beta1.Intent.Message.Image.encode(message.image, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                                        if (message.footer != null && Object.hasOwnProperty.call(message, "footer"))
                                            writer.uint32(/* id 5, wireType 2 =*/42).string(message.footer);
                                        return writer;
                                    };
    
                                    /**
                                     * Encodes the specified BrowseCarouselCardItem message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.verify|verify} messages.
                                     * @function encodeDelimited
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem
                                     * @static
                                     * @param {google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.IBrowseCarouselCardItem} message BrowseCarouselCardItem message or plain object to encode
                                     * @param {$protobuf.Writer} [writer] Writer to encode to
                                     * @returns {$protobuf.Writer} Writer
                                     */
                                    BrowseCarouselCardItem.encodeDelimited = function encodeDelimited(message, writer) {
                                        return this.encode(message, writer).ldelim();
                                    };
    
                                    /**
                                     * Decodes a BrowseCarouselCardItem message from the specified reader or buffer.
                                     * @function decode
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem
                                     * @static
                                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                     * @param {number} [length] Message length if known beforehand
                                     * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem} BrowseCarouselCardItem
                                     * @throws {Error} If the payload is not a reader or valid buffer
                                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                     */
                                    BrowseCarouselCardItem.decode = function decode(reader, length) {
                                        if (!(reader instanceof $Reader))
                                            reader = $Reader.create(reader);
                                        var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem();
                                        while (reader.pos < end) {
                                            var tag = reader.uint32();
                                            switch (tag >>> 3) {
                                            case 1: {
                                                    message.openUriAction = $root.google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction.decode(reader, reader.uint32());
                                                    break;
                                                }
                                            case 2: {
                                                    message.title = reader.string();
                                                    break;
                                                }
                                            case 3: {
                                                    message.description = reader.string();
                                                    break;
                                                }
                                            case 4: {
                                                    message.image = $root.google.cloud.dialogflow.v2beta1.Intent.Message.Image.decode(reader, reader.uint32());
                                                    break;
                                                }
                                            case 5: {
                                                    message.footer = reader.string();
                                                    break;
                                                }
                                            default:
                                                reader.skipType(tag & 7);
                                                break;
                                            }
                                        }
                                        return message;
                                    };
    
                                    /**
                                     * Decodes a BrowseCarouselCardItem message from the specified reader or buffer, length delimited.
                                     * @function decodeDelimited
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem
                                     * @static
                                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                     * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem} BrowseCarouselCardItem
                                     * @throws {Error} If the payload is not a reader or valid buffer
                                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                     */
                                    BrowseCarouselCardItem.decodeDelimited = function decodeDelimited(reader) {
                                        if (!(reader instanceof $Reader))
                                            reader = new $Reader(reader);
                                        return this.decode(reader, reader.uint32());
                                    };
    
                                    /**
                                     * Verifies a BrowseCarouselCardItem message.
                                     * @function verify
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem
                                     * @static
                                     * @param {Object.<string,*>} message Plain object to verify
                                     * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                     */
                                    BrowseCarouselCardItem.verify = function verify(message) {
                                        if (typeof message !== "object" || message === null)
                                            return "object expected";
                                        if (message.openUriAction != null && message.hasOwnProperty("openUriAction")) {
                                            var error = $root.google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction.verify(message.openUriAction);
                                            if (error)
                                                return "openUriAction." + error;
                                        }
                                        if (message.title != null && message.hasOwnProperty("title"))
                                            if (!$util.isString(message.title))
                                                return "title: string expected";
                                        if (message.description != null && message.hasOwnProperty("description"))
                                            if (!$util.isString(message.description))
                                                return "description: string expected";
                                        if (message.image != null && message.hasOwnProperty("image")) {
                                            var error = $root.google.cloud.dialogflow.v2beta1.Intent.Message.Image.verify(message.image);
                                            if (error)
                                                return "image." + error;
                                        }
                                        if (message.footer != null && message.hasOwnProperty("footer"))
                                            if (!$util.isString(message.footer))
                                                return "footer: string expected";
                                        return null;
                                    };
    
                                    /**
                                     * Creates a BrowseCarouselCardItem message from a plain object. Also converts values to their respective internal types.
                                     * @function fromObject
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem
                                     * @static
                                     * @param {Object.<string,*>} object Plain object
                                     * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem} BrowseCarouselCardItem
                                     */
                                    BrowseCarouselCardItem.fromObject = function fromObject(object) {
                                        if (object instanceof $root.google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem)
                                            return object;
                                        var message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem();
                                        if (object.openUriAction != null) {
                                            if (typeof object.openUriAction !== "object")
                                                throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.openUriAction: object expected");
                                            message.openUriAction = $root.google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction.fromObject(object.openUriAction);
                                        }
                                        if (object.title != null)
                                            message.title = String(object.title);
                                        if (object.description != null)
                                            message.description = String(object.description);
                                        if (object.image != null) {
                                            if (typeof object.image !== "object")
                                                throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.image: object expected");
                                            message.image = $root.google.cloud.dialogflow.v2beta1.Intent.Message.Image.fromObject(object.image);
                                        }
                                        if (object.footer != null)
                                            message.footer = String(object.footer);
                                        return message;
                                    };
    
                                    /**
                                     * Creates a plain object from a BrowseCarouselCardItem message. Also converts values to other types if specified.
                                     * @function toObject
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem
                                     * @static
                                     * @param {google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem} message BrowseCarouselCardItem
                                     * @param {$protobuf.IConversionOptions} [options] Conversion options
                                     * @returns {Object.<string,*>} Plain object
                                     */
                                    BrowseCarouselCardItem.toObject = function toObject(message, options) {
                                        if (!options)
                                            options = {};
                                        var object = {};
                                        if (options.defaults) {
                                            object.openUriAction = null;
                                            object.title = "";
                                            object.description = "";
                                            object.image = null;
                                            object.footer = "";
                                        }
                                        if (message.openUriAction != null && message.hasOwnProperty("openUriAction"))
                                            object.openUriAction = $root.google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction.toObject(message.openUriAction, options);
                                        if (message.title != null && message.hasOwnProperty("title"))
                                            object.title = message.title;
                                        if (message.description != null && message.hasOwnProperty("description"))
                                            object.description = message.description;
                                        if (message.image != null && message.hasOwnProperty("image"))
                                            object.image = $root.google.cloud.dialogflow.v2beta1.Intent.Message.Image.toObject(message.image, options);
                                        if (message.footer != null && message.hasOwnProperty("footer"))
                                            object.footer = message.footer;
                                        return object;
                                    };
    
                                    /**
                                     * Converts this BrowseCarouselCardItem to JSON.
                                     * @function toJSON
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem
                                     * @instance
                                     * @returns {Object.<string,*>} JSON object
                                     */
                                    BrowseCarouselCardItem.prototype.toJSON = function toJSON() {
                                        return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                    };
    
                                    /**
                                     * Gets the default type url for BrowseCarouselCardItem
                                     * @function getTypeUrl
                                     * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem
                                     * @static
                                     * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                     * @returns {string} The default type url
                                     */
                                    BrowseCarouselCardItem.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                        if (typeUrlPrefix === undefined) {
                                            typeUrlPrefix = "type.googleapis.com";
                                        }
                                        return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem";
                                    };
    
                                    BrowseCarouselCardItem.OpenUrlAction = (function() {
    
                                        /**
                                         * Properties of an OpenUrlAction.
                                         * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem
                                         * @interface IOpenUrlAction
                                         * @property {string|null} [url] OpenUrlAction url
                                         * @property {google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction.UrlTypeHint|null} [urlTypeHint] OpenUrlAction urlTypeHint
                                         */
    
                                        /**
                                         * Constructs a new OpenUrlAction.
                                         * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem
                                         * @classdesc Represents an OpenUrlAction.
                                         * @implements IOpenUrlAction
                                         * @constructor
                                         * @param {google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.IOpenUrlAction=} [properties] Properties to set
                                         */
                                        function OpenUrlAction(properties) {
                                            if (properties)
                                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                                    if (properties[keys[i]] != null)
                                                        this[keys[i]] = properties[keys[i]];
                                        }
    
                                        /**
                                         * OpenUrlAction url.
                                         * @member {string} url
                                         * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction
                                         * @instance
                                         */
                                        OpenUrlAction.prototype.url = "";
    
                                        /**
                                         * OpenUrlAction urlTypeHint.
                                         * @member {google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction.UrlTypeHint} urlTypeHint
                                         * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction
                                         * @instance
                                         */
                                        OpenUrlAction.prototype.urlTypeHint = 0;
    
                                        /**
                                         * Creates a new OpenUrlAction instance using the specified properties.
                                         * @function create
                                         * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction
                                         * @static
                                         * @param {google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.IOpenUrlAction=} [properties] Properties to set
                                         * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction} OpenUrlAction instance
                                         */
                                        OpenUrlAction.create = function create(properties) {
                                            return new OpenUrlAction(properties);
                                        };
    
                                        /**
                                         * Encodes the specified OpenUrlAction message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction.verify|verify} messages.
                                         * @function encode
                                         * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction
                                         * @static
                                         * @param {google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.IOpenUrlAction} message OpenUrlAction message or plain object to encode
                                         * @param {$protobuf.Writer} [writer] Writer to encode to
                                         * @returns {$protobuf.Writer} Writer
                                         */
                                        OpenUrlAction.encode = function encode(message, writer) {
                                            if (!writer)
                                                writer = $Writer.create();
                                            if (message.url != null && Object.hasOwnProperty.call(message, "url"))
                                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.url);
                                            if (message.urlTypeHint != null && Object.hasOwnProperty.call(message, "urlTypeHint"))
                                                writer.uint32(/* id 3, wireType 0 =*/24).int32(message.urlTypeHint);
                                            return writer;
                                        };
    
                                        /**
                                         * Encodes the specified OpenUrlAction message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction.verify|verify} messages.
                                         * @function encodeDelimited
                                         * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction
                                         * @static
                                         * @param {google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.IOpenUrlAction} message OpenUrlAction message or plain object to encode
                                         * @param {$protobuf.Writer} [writer] Writer to encode to
                                         * @returns {$protobuf.Writer} Writer
                                         */
                                        OpenUrlAction.encodeDelimited = function encodeDelimited(message, writer) {
                                            return this.encode(message, writer).ldelim();
                                        };
    
                                        /**
                                         * Decodes an OpenUrlAction message from the specified reader or buffer.
                                         * @function decode
                                         * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction
                                         * @static
                                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                         * @param {number} [length] Message length if known beforehand
                                         * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction} OpenUrlAction
                                         * @throws {Error} If the payload is not a reader or valid buffer
                                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                         */
                                        OpenUrlAction.decode = function decode(reader, length) {
                                            if (!(reader instanceof $Reader))
                                                reader = $Reader.create(reader);
                                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction();
                                            while (reader.pos < end) {
                                                var tag = reader.uint32();
                                                switch (tag >>> 3) {
                                                case 1: {
                                                        message.url = reader.string();
                                                        break;
                                                    }
                                                case 3: {
                                                        message.urlTypeHint = reader.int32();
                                                        break;
                                                    }
                                                default:
                                                    reader.skipType(tag & 7);
                                                    break;
                                                }
                                            }
                                            return message;
                                        };
    
                                        /**
                                         * Decodes an OpenUrlAction message from the specified reader or buffer, length delimited.
                                         * @function decodeDelimited
                                         * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction
                                         * @static
                                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                         * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction} OpenUrlAction
                                         * @throws {Error} If the payload is not a reader or valid buffer
                                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                         */
                                        OpenUrlAction.decodeDelimited = function decodeDelimited(reader) {
                                            if (!(reader instanceof $Reader))
                                                reader = new $Reader(reader);
                                            return this.decode(reader, reader.uint32());
                                        };
    
                                        /**
                                         * Verifies an OpenUrlAction message.
                                         * @function verify
                                         * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction
                                         * @static
                                         * @param {Object.<string,*>} message Plain object to verify
                                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                         */
                                        OpenUrlAction.verify = function verify(message) {
                                            if (typeof message !== "object" || message === null)
                                                return "object expected";
                                            if (message.url != null && message.hasOwnProperty("url"))
                                                if (!$util.isString(message.url))
                                                    return "url: string expected";
                                            if (message.urlTypeHint != null && message.hasOwnProperty("urlTypeHint"))
                                                switch (message.urlTypeHint) {
                                                default:
                                                    return "urlTypeHint: enum value expected";
                                                case 0:
                                                case 1:
                                                case 2:
                                                    break;
                                                }
                                            return null;
                                        };
    
                                        /**
                                         * Creates an OpenUrlAction message from a plain object. Also converts values to their respective internal types.
                                         * @function fromObject
                                         * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction
                                         * @static
                                         * @param {Object.<string,*>} object Plain object
                                         * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction} OpenUrlAction
                                         */
                                        OpenUrlAction.fromObject = function fromObject(object) {
                                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction)
                                                return object;
                                            var message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction();
                                            if (object.url != null)
                                                message.url = String(object.url);
                                            switch (object.urlTypeHint) {
                                            default:
                                                if (typeof object.urlTypeHint === "number") {
                                                    message.urlTypeHint = object.urlTypeHint;
                                                    break;
                                                }
                                                break;
                                            case "URL_TYPE_HINT_UNSPECIFIED":
                                            case 0:
                                                message.urlTypeHint = 0;
                                                break;
                                            case "AMP_ACTION":
                                            case 1:
                                                message.urlTypeHint = 1;
                                                break;
                                            case "AMP_CONTENT":
                                            case 2:
                                                message.urlTypeHint = 2;
                                                break;
                                            }
                                            return message;
                                        };
    
                                        /**
                                         * Creates a plain object from an OpenUrlAction message. Also converts values to other types if specified.
                                         * @function toObject
                                         * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction
                                         * @static
                                         * @param {google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction} message OpenUrlAction
                                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                                         * @returns {Object.<string,*>} Plain object
                                         */
                                        OpenUrlAction.toObject = function toObject(message, options) {
                                            if (!options)
                                                options = {};
                                            var object = {};
                                            if (options.defaults) {
                                                object.url = "";
                                                object.urlTypeHint = options.enums === String ? "URL_TYPE_HINT_UNSPECIFIED" : 0;
                                            }
                                            if (message.url != null && message.hasOwnProperty("url"))
                                                object.url = message.url;
                                            if (message.urlTypeHint != null && message.hasOwnProperty("urlTypeHint"))
                                                object.urlTypeHint = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction.UrlTypeHint[message.urlTypeHint] === undefined ? message.urlTypeHint : $root.google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction.UrlTypeHint[message.urlTypeHint] : message.urlTypeHint;
                                            return object;
                                        };
    
                                        /**
                                         * Converts this OpenUrlAction to JSON.
                                         * @function toJSON
                                         * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction
                                         * @instance
                                         * @returns {Object.<string,*>} JSON object
                                         */
                                        OpenUrlAction.prototype.toJSON = function toJSON() {
                                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                        };
    
                                        /**
                                         * Gets the default type url for OpenUrlAction
                                         * @function getTypeUrl
                                         * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction
                                         * @static
                                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                         * @returns {string} The default type url
                                         */
                                        OpenUrlAction.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                            if (typeUrlPrefix === undefined) {
                                                typeUrlPrefix = "type.googleapis.com";
                                            }
                                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction";
                                        };
    
                                        /**
                                         * UrlTypeHint enum.
                                         * @name google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.BrowseCarouselCardItem.OpenUrlAction.UrlTypeHint
                                         * @enum {number}
                                         * @property {number} URL_TYPE_HINT_UNSPECIFIED=0 URL_TYPE_HINT_UNSPECIFIED value
                                         * @property {number} AMP_ACTION=1 AMP_ACTION value
                                         * @property {number} AMP_CONTENT=2 AMP_CONTENT value
                                         */
                                        OpenUrlAction.UrlTypeHint = (function() {
                                            var valuesById = {}, values = Object.create(valuesById);
                                            values[valuesById[0] = "URL_TYPE_HINT_UNSPECIFIED"] = 0;
                                            values[valuesById[1] = "AMP_ACTION"] = 1;
                                            values[valuesById[2] = "AMP_CONTENT"] = 2;
                                            return values;
                                        })();
    
                                        return OpenUrlAction;
                                    })();
    
                                    return BrowseCarouselCardItem;
                                })();
    
                                /**
                                 * ImageDisplayOptions enum.
                                 * @name google.cloud.dialogflow.v2beta1.Intent.Message.BrowseCarouselCard.ImageDisplayOptions
                                 * @enum {number}
                                 * @property {number} IMAGE_DISPLAY_OPTIONS_UNSPECIFIED=0 IMAGE_DISPLAY_OPTIONS_UNSPECIFIED value
                                 * @property {number} GRAY=1 GRAY value
                                 * @property {number} WHITE=2 WHITE value
                                 * @property {number} CROPPED=3 CROPPED value
                                 * @property {number} BLURRED_BACKGROUND=4 BLURRED_BACKGROUND value
                                 */
                                BrowseCarouselCard.ImageDisplayOptions = (function() {
                                    var valuesById = {}, values = Object.create(valuesById);
                                    values[valuesById[0] = "IMAGE_DISPLAY_OPTIONS_UNSPECIFIED"] = 0;
                                    values[valuesById[1] = "GRAY"] = 1;
                                    values[valuesById[2] = "WHITE"] = 2;
                                    values[valuesById[3] = "CROPPED"] = 3;
                                    values[valuesById[4] = "BLURRED_BACKGROUND"] = 4;
                                    return values;
                                })();
    
                                return BrowseCarouselCard;
                            })();
    
                            Message.TableCard = (function() {
    
                                /**
                                 * Properties of a TableCard.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @interface ITableCard
                                 * @property {string|null} [title] TableCard title
                                 * @property {string|null} [subtitle] TableCard subtitle
                                 * @property {google.cloud.dialogflow.v2beta1.Intent.Message.IImage|null} [image] TableCard image
                                 * @property {Array.<google.cloud.dialogflow.v2beta1.Intent.Message.IColumnProperties>|null} [columnProperties] TableCard columnProperties
                                 * @property {Array.<google.cloud.dialogflow.v2beta1.Intent.Message.ITableCardRow>|null} [rows] TableCard rows
                                 * @property {Array.<google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.IButton>|null} [buttons] TableCard buttons
                                 */
    
                                /**
                                 * Constructs a new TableCard.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @classdesc Represents a TableCard.
                                 * @implements ITableCard
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ITableCard=} [properties] Properties to set
                                 */
                                function TableCard(properties) {
                                    this.columnProperties = [];
                                    this.rows = [];
                                    this.buttons = [];
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * TableCard title.
                                 * @member {string} title
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TableCard
                                 * @instance
                                 */
                                TableCard.prototype.title = "";
    
                                /**
                                 * TableCard subtitle.
                                 * @member {string} subtitle
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TableCard
                                 * @instance
                                 */
                                TableCard.prototype.subtitle = "";
    
                                /**
                                 * TableCard image.
                                 * @member {google.cloud.dialogflow.v2beta1.Intent.Message.IImage|null|undefined} image
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TableCard
                                 * @instance
                                 */
                                TableCard.prototype.image = null;
    
                                /**
                                 * TableCard columnProperties.
                                 * @member {Array.<google.cloud.dialogflow.v2beta1.Intent.Message.IColumnProperties>} columnProperties
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TableCard
                                 * @instance
                                 */
                                TableCard.prototype.columnProperties = $util.emptyArray;
    
                                /**
                                 * TableCard rows.
                                 * @member {Array.<google.cloud.dialogflow.v2beta1.Intent.Message.ITableCardRow>} rows
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TableCard
                                 * @instance
                                 */
                                TableCard.prototype.rows = $util.emptyArray;
    
                                /**
                                 * TableCard buttons.
                                 * @member {Array.<google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.IButton>} buttons
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TableCard
                                 * @instance
                                 */
                                TableCard.prototype.buttons = $util.emptyArray;
    
                                /**
                                 * Creates a new TableCard instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TableCard
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ITableCard=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.TableCard} TableCard instance
                                 */
                                TableCard.create = function create(properties) {
                                    return new TableCard(properties);
                                };
    
                                /**
                                 * Encodes the specified TableCard message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.TableCard.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TableCard
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ITableCard} message TableCard message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                TableCard.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.title != null && Object.hasOwnProperty.call(message, "title"))
                                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.title);
                                    if (message.subtitle != null && Object.hasOwnProperty.call(message, "subtitle"))
                                        writer.uint32(/* id 2, wireType 2 =*/18).string(message.subtitle);
                                    if (message.image != null && Object.hasOwnProperty.call(message, "image"))
                                        $root.google.cloud.dialogflow.v2beta1.Intent.Message.Image.encode(message.image, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                                    if (message.columnProperties != null && message.columnProperties.length)
                                        for (var i = 0; i < message.columnProperties.length; ++i)
                                            $root.google.cloud.dialogflow.v2beta1.Intent.Message.ColumnProperties.encode(message.columnProperties[i], writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                                    if (message.rows != null && message.rows.length)
                                        for (var i = 0; i < message.rows.length; ++i)
                                            $root.google.cloud.dialogflow.v2beta1.Intent.Message.TableCardRow.encode(message.rows[i], writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                                    if (message.buttons != null && message.buttons.length)
                                        for (var i = 0; i < message.buttons.length; ++i)
                                            $root.google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button.encode(message.buttons[i], writer.uint32(/* id 6, wireType 2 =*/50).fork()).ldelim();
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified TableCard message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.TableCard.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TableCard
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ITableCard} message TableCard message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                TableCard.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a TableCard message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TableCard
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.TableCard} TableCard
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                TableCard.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.TableCard();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                message.title = reader.string();
                                                break;
                                            }
                                        case 2: {
                                                message.subtitle = reader.string();
                                                break;
                                            }
                                        case 3: {
                                                message.image = $root.google.cloud.dialogflow.v2beta1.Intent.Message.Image.decode(reader, reader.uint32());
                                                break;
                                            }
                                        case 4: {
                                                if (!(message.columnProperties && message.columnProperties.length))
                                                    message.columnProperties = [];
                                                message.columnProperties.push($root.google.cloud.dialogflow.v2beta1.Intent.Message.ColumnProperties.decode(reader, reader.uint32()));
                                                break;
                                            }
                                        case 5: {
                                                if (!(message.rows && message.rows.length))
                                                    message.rows = [];
                                                message.rows.push($root.google.cloud.dialogflow.v2beta1.Intent.Message.TableCardRow.decode(reader, reader.uint32()));
                                                break;
                                            }
                                        case 6: {
                                                if (!(message.buttons && message.buttons.length))
                                                    message.buttons = [];
                                                message.buttons.push($root.google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button.decode(reader, reader.uint32()));
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a TableCard message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TableCard
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.TableCard} TableCard
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                TableCard.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a TableCard message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TableCard
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                TableCard.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.title != null && message.hasOwnProperty("title"))
                                        if (!$util.isString(message.title))
                                            return "title: string expected";
                                    if (message.subtitle != null && message.hasOwnProperty("subtitle"))
                                        if (!$util.isString(message.subtitle))
                                            return "subtitle: string expected";
                                    if (message.image != null && message.hasOwnProperty("image")) {
                                        var error = $root.google.cloud.dialogflow.v2beta1.Intent.Message.Image.verify(message.image);
                                        if (error)
                                            return "image." + error;
                                    }
                                    if (message.columnProperties != null && message.hasOwnProperty("columnProperties")) {
                                        if (!Array.isArray(message.columnProperties))
                                            return "columnProperties: array expected";
                                        for (var i = 0; i < message.columnProperties.length; ++i) {
                                            var error = $root.google.cloud.dialogflow.v2beta1.Intent.Message.ColumnProperties.verify(message.columnProperties[i]);
                                            if (error)
                                                return "columnProperties." + error;
                                        }
                                    }
                                    if (message.rows != null && message.hasOwnProperty("rows")) {
                                        if (!Array.isArray(message.rows))
                                            return "rows: array expected";
                                        for (var i = 0; i < message.rows.length; ++i) {
                                            var error = $root.google.cloud.dialogflow.v2beta1.Intent.Message.TableCardRow.verify(message.rows[i]);
                                            if (error)
                                                return "rows." + error;
                                        }
                                    }
                                    if (message.buttons != null && message.hasOwnProperty("buttons")) {
                                        if (!Array.isArray(message.buttons))
                                            return "buttons: array expected";
                                        for (var i = 0; i < message.buttons.length; ++i) {
                                            var error = $root.google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button.verify(message.buttons[i]);
                                            if (error)
                                                return "buttons." + error;
                                        }
                                    }
                                    return null;
                                };
    
                                /**
                                 * Creates a TableCard message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TableCard
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.TableCard} TableCard
                                 */
                                TableCard.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2beta1.Intent.Message.TableCard)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.TableCard();
                                    if (object.title != null)
                                        message.title = String(object.title);
                                    if (object.subtitle != null)
                                        message.subtitle = String(object.subtitle);
                                    if (object.image != null) {
                                        if (typeof object.image !== "object")
                                            throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.TableCard.image: object expected");
                                        message.image = $root.google.cloud.dialogflow.v2beta1.Intent.Message.Image.fromObject(object.image);
                                    }
                                    if (object.columnProperties) {
                                        if (!Array.isArray(object.columnProperties))
                                            throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.TableCard.columnProperties: array expected");
                                        message.columnProperties = [];
                                        for (var i = 0; i < object.columnProperties.length; ++i) {
                                            if (typeof object.columnProperties[i] !== "object")
                                                throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.TableCard.columnProperties: object expected");
                                            message.columnProperties[i] = $root.google.cloud.dialogflow.v2beta1.Intent.Message.ColumnProperties.fromObject(object.columnProperties[i]);
                                        }
                                    }
                                    if (object.rows) {
                                        if (!Array.isArray(object.rows))
                                            throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.TableCard.rows: array expected");
                                        message.rows = [];
                                        for (var i = 0; i < object.rows.length; ++i) {
                                            if (typeof object.rows[i] !== "object")
                                                throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.TableCard.rows: object expected");
                                            message.rows[i] = $root.google.cloud.dialogflow.v2beta1.Intent.Message.TableCardRow.fromObject(object.rows[i]);
                                        }
                                    }
                                    if (object.buttons) {
                                        if (!Array.isArray(object.buttons))
                                            throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.TableCard.buttons: array expected");
                                        message.buttons = [];
                                        for (var i = 0; i < object.buttons.length; ++i) {
                                            if (typeof object.buttons[i] !== "object")
                                                throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.TableCard.buttons: object expected");
                                            message.buttons[i] = $root.google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button.fromObject(object.buttons[i]);
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a TableCard message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TableCard
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.TableCard} message TableCard
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                TableCard.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.arrays || options.defaults) {
                                        object.columnProperties = [];
                                        object.rows = [];
                                        object.buttons = [];
                                    }
                                    if (options.defaults) {
                                        object.title = "";
                                        object.subtitle = "";
                                        object.image = null;
                                    }
                                    if (message.title != null && message.hasOwnProperty("title"))
                                        object.title = message.title;
                                    if (message.subtitle != null && message.hasOwnProperty("subtitle"))
                                        object.subtitle = message.subtitle;
                                    if (message.image != null && message.hasOwnProperty("image"))
                                        object.image = $root.google.cloud.dialogflow.v2beta1.Intent.Message.Image.toObject(message.image, options);
                                    if (message.columnProperties && message.columnProperties.length) {
                                        object.columnProperties = [];
                                        for (var j = 0; j < message.columnProperties.length; ++j)
                                            object.columnProperties[j] = $root.google.cloud.dialogflow.v2beta1.Intent.Message.ColumnProperties.toObject(message.columnProperties[j], options);
                                    }
                                    if (message.rows && message.rows.length) {
                                        object.rows = [];
                                        for (var j = 0; j < message.rows.length; ++j)
                                            object.rows[j] = $root.google.cloud.dialogflow.v2beta1.Intent.Message.TableCardRow.toObject(message.rows[j], options);
                                    }
                                    if (message.buttons && message.buttons.length) {
                                        object.buttons = [];
                                        for (var j = 0; j < message.buttons.length; ++j)
                                            object.buttons[j] = $root.google.cloud.dialogflow.v2beta1.Intent.Message.BasicCard.Button.toObject(message.buttons[j], options);
                                    }
                                    return object;
                                };
    
                                /**
                                 * Converts this TableCard to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TableCard
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                TableCard.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for TableCard
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TableCard
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                TableCard.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Intent.Message.TableCard";
                                };
    
                                return TableCard;
                            })();
    
                            Message.ColumnProperties = (function() {
    
                                /**
                                 * Properties of a ColumnProperties.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @interface IColumnProperties
                                 * @property {string|null} [header] ColumnProperties header
                                 * @property {google.cloud.dialogflow.v2beta1.Intent.Message.ColumnProperties.HorizontalAlignment|null} [horizontalAlignment] ColumnProperties horizontalAlignment
                                 */
    
                                /**
                                 * Constructs a new ColumnProperties.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @classdesc Represents a ColumnProperties.
                                 * @implements IColumnProperties
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IColumnProperties=} [properties] Properties to set
                                 */
                                function ColumnProperties(properties) {
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * ColumnProperties header.
                                 * @member {string} header
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.ColumnProperties
                                 * @instance
                                 */
                                ColumnProperties.prototype.header = "";
    
                                /**
                                 * ColumnProperties horizontalAlignment.
                                 * @member {google.cloud.dialogflow.v2beta1.Intent.Message.ColumnProperties.HorizontalAlignment} horizontalAlignment
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.ColumnProperties
                                 * @instance
                                 */
                                ColumnProperties.prototype.horizontalAlignment = 0;
    
                                /**
                                 * Creates a new ColumnProperties instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.ColumnProperties
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IColumnProperties=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.ColumnProperties} ColumnProperties instance
                                 */
                                ColumnProperties.create = function create(properties) {
                                    return new ColumnProperties(properties);
                                };
    
                                /**
                                 * Encodes the specified ColumnProperties message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.ColumnProperties.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.ColumnProperties
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IColumnProperties} message ColumnProperties message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                ColumnProperties.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.header != null && Object.hasOwnProperty.call(message, "header"))
                                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.header);
                                    if (message.horizontalAlignment != null && Object.hasOwnProperty.call(message, "horizontalAlignment"))
                                        writer.uint32(/* id 2, wireType 0 =*/16).int32(message.horizontalAlignment);
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified ColumnProperties message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.ColumnProperties.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.ColumnProperties
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.IColumnProperties} message ColumnProperties message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                ColumnProperties.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a ColumnProperties message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.ColumnProperties
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.ColumnProperties} ColumnProperties
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                ColumnProperties.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.ColumnProperties();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                message.header = reader.string();
                                                break;
                                            }
                                        case 2: {
                                                message.horizontalAlignment = reader.int32();
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a ColumnProperties message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.ColumnProperties
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.ColumnProperties} ColumnProperties
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                ColumnProperties.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a ColumnProperties message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.ColumnProperties
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                ColumnProperties.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.header != null && message.hasOwnProperty("header"))
                                        if (!$util.isString(message.header))
                                            return "header: string expected";
                                    if (message.horizontalAlignment != null && message.hasOwnProperty("horizontalAlignment"))
                                        switch (message.horizontalAlignment) {
                                        default:
                                            return "horizontalAlignment: enum value expected";
                                        case 0:
                                        case 1:
                                        case 2:
                                        case 3:
                                            break;
                                        }
                                    return null;
                                };
    
                                /**
                                 * Creates a ColumnProperties message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.ColumnProperties
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.ColumnProperties} ColumnProperties
                                 */
                                ColumnProperties.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2beta1.Intent.Message.ColumnProperties)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.ColumnProperties();
                                    if (object.header != null)
                                        message.header = String(object.header);
                                    switch (object.horizontalAlignment) {
                                    default:
                                        if (typeof object.horizontalAlignment === "number") {
                                            message.horizontalAlignment = object.horizontalAlignment;
                                            break;
                                        }
                                        break;
                                    case "HORIZONTAL_ALIGNMENT_UNSPECIFIED":
                                    case 0:
                                        message.horizontalAlignment = 0;
                                        break;
                                    case "LEADING":
                                    case 1:
                                        message.horizontalAlignment = 1;
                                        break;
                                    case "CENTER":
                                    case 2:
                                        message.horizontalAlignment = 2;
                                        break;
                                    case "TRAILING":
                                    case 3:
                                        message.horizontalAlignment = 3;
                                        break;
                                    }
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a ColumnProperties message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.ColumnProperties
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ColumnProperties} message ColumnProperties
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                ColumnProperties.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.defaults) {
                                        object.header = "";
                                        object.horizontalAlignment = options.enums === String ? "HORIZONTAL_ALIGNMENT_UNSPECIFIED" : 0;
                                    }
                                    if (message.header != null && message.hasOwnProperty("header"))
                                        object.header = message.header;
                                    if (message.horizontalAlignment != null && message.hasOwnProperty("horizontalAlignment"))
                                        object.horizontalAlignment = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.Intent.Message.ColumnProperties.HorizontalAlignment[message.horizontalAlignment] === undefined ? message.horizontalAlignment : $root.google.cloud.dialogflow.v2beta1.Intent.Message.ColumnProperties.HorizontalAlignment[message.horizontalAlignment] : message.horizontalAlignment;
                                    return object;
                                };
    
                                /**
                                 * Converts this ColumnProperties to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.ColumnProperties
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                ColumnProperties.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for ColumnProperties
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.ColumnProperties
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                ColumnProperties.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Intent.Message.ColumnProperties";
                                };
    
                                /**
                                 * HorizontalAlignment enum.
                                 * @name google.cloud.dialogflow.v2beta1.Intent.Message.ColumnProperties.HorizontalAlignment
                                 * @enum {number}
                                 * @property {number} HORIZONTAL_ALIGNMENT_UNSPECIFIED=0 HORIZONTAL_ALIGNMENT_UNSPECIFIED value
                                 * @property {number} LEADING=1 LEADING value
                                 * @property {number} CENTER=2 CENTER value
                                 * @property {number} TRAILING=3 TRAILING value
                                 */
                                ColumnProperties.HorizontalAlignment = (function() {
                                    var valuesById = {}, values = Object.create(valuesById);
                                    values[valuesById[0] = "HORIZONTAL_ALIGNMENT_UNSPECIFIED"] = 0;
                                    values[valuesById[1] = "LEADING"] = 1;
                                    values[valuesById[2] = "CENTER"] = 2;
                                    values[valuesById[3] = "TRAILING"] = 3;
                                    return values;
                                })();
    
                                return ColumnProperties;
                            })();
    
                            Message.TableCardRow = (function() {
    
                                /**
                                 * Properties of a TableCardRow.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @interface ITableCardRow
                                 * @property {Array.<google.cloud.dialogflow.v2beta1.Intent.Message.ITableCardCell>|null} [cells] TableCardRow cells
                                 * @property {boolean|null} [dividerAfter] TableCardRow dividerAfter
                                 */
    
                                /**
                                 * Constructs a new TableCardRow.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @classdesc Represents a TableCardRow.
                                 * @implements ITableCardRow
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ITableCardRow=} [properties] Properties to set
                                 */
                                function TableCardRow(properties) {
                                    this.cells = [];
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * TableCardRow cells.
                                 * @member {Array.<google.cloud.dialogflow.v2beta1.Intent.Message.ITableCardCell>} cells
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TableCardRow
                                 * @instance
                                 */
                                TableCardRow.prototype.cells = $util.emptyArray;
    
                                /**
                                 * TableCardRow dividerAfter.
                                 * @member {boolean} dividerAfter
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TableCardRow
                                 * @instance
                                 */
                                TableCardRow.prototype.dividerAfter = false;
    
                                /**
                                 * Creates a new TableCardRow instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TableCardRow
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ITableCardRow=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.TableCardRow} TableCardRow instance
                                 */
                                TableCardRow.create = function create(properties) {
                                    return new TableCardRow(properties);
                                };
    
                                /**
                                 * Encodes the specified TableCardRow message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.TableCardRow.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TableCardRow
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ITableCardRow} message TableCardRow message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                TableCardRow.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.cells != null && message.cells.length)
                                        for (var i = 0; i < message.cells.length; ++i)
                                            $root.google.cloud.dialogflow.v2beta1.Intent.Message.TableCardCell.encode(message.cells[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                                    if (message.dividerAfter != null && Object.hasOwnProperty.call(message, "dividerAfter"))
                                        writer.uint32(/* id 2, wireType 0 =*/16).bool(message.dividerAfter);
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified TableCardRow message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.TableCardRow.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TableCardRow
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ITableCardRow} message TableCardRow message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                TableCardRow.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a TableCardRow message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TableCardRow
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.TableCardRow} TableCardRow
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                TableCardRow.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.TableCardRow();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                if (!(message.cells && message.cells.length))
                                                    message.cells = [];
                                                message.cells.push($root.google.cloud.dialogflow.v2beta1.Intent.Message.TableCardCell.decode(reader, reader.uint32()));
                                                break;
                                            }
                                        case 2: {
                                                message.dividerAfter = reader.bool();
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a TableCardRow message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TableCardRow
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.TableCardRow} TableCardRow
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                TableCardRow.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a TableCardRow message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TableCardRow
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                TableCardRow.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.cells != null && message.hasOwnProperty("cells")) {
                                        if (!Array.isArray(message.cells))
                                            return "cells: array expected";
                                        for (var i = 0; i < message.cells.length; ++i) {
                                            var error = $root.google.cloud.dialogflow.v2beta1.Intent.Message.TableCardCell.verify(message.cells[i]);
                                            if (error)
                                                return "cells." + error;
                                        }
                                    }
                                    if (message.dividerAfter != null && message.hasOwnProperty("dividerAfter"))
                                        if (typeof message.dividerAfter !== "boolean")
                                            return "dividerAfter: boolean expected";
                                    return null;
                                };
    
                                /**
                                 * Creates a TableCardRow message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TableCardRow
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.TableCardRow} TableCardRow
                                 */
                                TableCardRow.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2beta1.Intent.Message.TableCardRow)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.TableCardRow();
                                    if (object.cells) {
                                        if (!Array.isArray(object.cells))
                                            throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.TableCardRow.cells: array expected");
                                        message.cells = [];
                                        for (var i = 0; i < object.cells.length; ++i) {
                                            if (typeof object.cells[i] !== "object")
                                                throw TypeError(".google.cloud.dialogflow.v2beta1.Intent.Message.TableCardRow.cells: object expected");
                                            message.cells[i] = $root.google.cloud.dialogflow.v2beta1.Intent.Message.TableCardCell.fromObject(object.cells[i]);
                                        }
                                    }
                                    if (object.dividerAfter != null)
                                        message.dividerAfter = Boolean(object.dividerAfter);
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a TableCardRow message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TableCardRow
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.TableCardRow} message TableCardRow
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                TableCardRow.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.arrays || options.defaults)
                                        object.cells = [];
                                    if (options.defaults)
                                        object.dividerAfter = false;
                                    if (message.cells && message.cells.length) {
                                        object.cells = [];
                                        for (var j = 0; j < message.cells.length; ++j)
                                            object.cells[j] = $root.google.cloud.dialogflow.v2beta1.Intent.Message.TableCardCell.toObject(message.cells[j], options);
                                    }
                                    if (message.dividerAfter != null && message.hasOwnProperty("dividerAfter"))
                                        object.dividerAfter = message.dividerAfter;
                                    return object;
                                };
    
                                /**
                                 * Converts this TableCardRow to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TableCardRow
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                TableCardRow.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for TableCardRow
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TableCardRow
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                TableCardRow.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Intent.Message.TableCardRow";
                                };
    
                                return TableCardRow;
                            })();
    
                            Message.TableCardCell = (function() {
    
                                /**
                                 * Properties of a TableCardCell.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @interface ITableCardCell
                                 * @property {string|null} [text] TableCardCell text
                                 */
    
                                /**
                                 * Constructs a new TableCardCell.
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message
                                 * @classdesc Represents a TableCardCell.
                                 * @implements ITableCardCell
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ITableCardCell=} [properties] Properties to set
                                 */
                                function TableCardCell(properties) {
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * TableCardCell text.
                                 * @member {string} text
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TableCardCell
                                 * @instance
                                 */
                                TableCardCell.prototype.text = "";
    
                                /**
                                 * Creates a new TableCardCell instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TableCardCell
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ITableCardCell=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.TableCardCell} TableCardCell instance
                                 */
                                TableCardCell.create = function create(properties) {
                                    return new TableCardCell(properties);
                                };
    
                                /**
                                 * Encodes the specified TableCardCell message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.TableCardCell.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TableCardCell
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ITableCardCell} message TableCardCell message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                TableCardCell.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.text != null && Object.hasOwnProperty.call(message, "text"))
                                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.text);
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified TableCardCell message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.Message.TableCardCell.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TableCardCell
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.ITableCardCell} message TableCardCell message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                TableCardCell.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a TableCardCell message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TableCardCell
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.TableCardCell} TableCardCell
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                TableCardCell.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.TableCardCell();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                message.text = reader.string();
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a TableCardCell message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TableCardCell
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.TableCardCell} TableCardCell
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                TableCardCell.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a TableCardCell message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TableCardCell
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                TableCardCell.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.text != null && message.hasOwnProperty("text"))
                                        if (!$util.isString(message.text))
                                            return "text: string expected";
                                    return null;
                                };
    
                                /**
                                 * Creates a TableCardCell message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TableCardCell
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2beta1.Intent.Message.TableCardCell} TableCardCell
                                 */
                                TableCardCell.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2beta1.Intent.Message.TableCardCell)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2beta1.Intent.Message.TableCardCell();
                                    if (object.text != null)
                                        message.text = String(object.text);
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a TableCardCell message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TableCardCell
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Intent.Message.TableCardCell} message TableCardCell
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                TableCardCell.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.defaults)
                                        object.text = "";
                                    if (message.text != null && message.hasOwnProperty("text"))
                                        object.text = message.text;
                                    return object;
                                };
    
                                /**
                                 * Converts this TableCardCell to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TableCardCell
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                TableCardCell.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for TableCardCell
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2beta1.Intent.Message.TableCardCell
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                TableCardCell.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Intent.Message.TableCardCell";
                                };
    
                                return TableCardCell;
                            })();
    
                            return Message;
                        })();
    
                        Intent.FollowupIntentInfo = (function() {
    
                            /**
                             * Properties of a FollowupIntentInfo.
                             * @memberof google.cloud.dialogflow.v2beta1.Intent
                             * @interface IFollowupIntentInfo
                             * @property {string|null} [followupIntentName] FollowupIntentInfo followupIntentName
                             * @property {string|null} [parentFollowupIntentName] FollowupIntentInfo parentFollowupIntentName
                             */
    
                            /**
                             * Constructs a new FollowupIntentInfo.
                             * @memberof google.cloud.dialogflow.v2beta1.Intent
                             * @classdesc Represents a FollowupIntentInfo.
                             * @implements IFollowupIntentInfo
                             * @constructor
                             * @param {google.cloud.dialogflow.v2beta1.Intent.IFollowupIntentInfo=} [properties] Properties to set
                             */
                            function FollowupIntentInfo(properties) {
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * FollowupIntentInfo followupIntentName.
                             * @member {string} followupIntentName
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.FollowupIntentInfo
                             * @instance
                             */
                            FollowupIntentInfo.prototype.followupIntentName = "";
    
                            /**
                             * FollowupIntentInfo parentFollowupIntentName.
                             * @member {string} parentFollowupIntentName
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.FollowupIntentInfo
                             * @instance
                             */
                            FollowupIntentInfo.prototype.parentFollowupIntentName = "";
    
                            /**
                             * Creates a new FollowupIntentInfo instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.FollowupIntentInfo
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.Intent.IFollowupIntentInfo=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2beta1.Intent.FollowupIntentInfo} FollowupIntentInfo instance
                             */
                            FollowupIntentInfo.create = function create(properties) {
                                return new FollowupIntentInfo(properties);
                            };
    
                            /**
                             * Encodes the specified FollowupIntentInfo message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.FollowupIntentInfo.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.FollowupIntentInfo
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.Intent.IFollowupIntentInfo} message FollowupIntentInfo message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            FollowupIntentInfo.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.followupIntentName != null && Object.hasOwnProperty.call(message, "followupIntentName"))
                                    writer.uint32(/* id 1, wireType 2 =*/10).string(message.followupIntentName);
                                if (message.parentFollowupIntentName != null && Object.hasOwnProperty.call(message, "parentFollowupIntentName"))
                                    writer.uint32(/* id 2, wireType 2 =*/18).string(message.parentFollowupIntentName);
                                return writer;
                            };
    
                            /**
                             * Encodes the specified FollowupIntentInfo message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Intent.FollowupIntentInfo.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.FollowupIntentInfo
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.Intent.IFollowupIntentInfo} message FollowupIntentInfo message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            FollowupIntentInfo.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a FollowupIntentInfo message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.FollowupIntentInfo
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2beta1.Intent.FollowupIntentInfo} FollowupIntentInfo
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            FollowupIntentInfo.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Intent.FollowupIntentInfo();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.followupIntentName = reader.string();
                                            break;
                                        }
                                    case 2: {
                                            message.parentFollowupIntentName = reader.string();
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a FollowupIntentInfo message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.FollowupIntentInfo
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2beta1.Intent.FollowupIntentInfo} FollowupIntentInfo
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            FollowupIntentInfo.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a FollowupIntentInfo message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.FollowupIntentInfo
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            FollowupIntentInfo.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.followupIntentName != null && message.hasOwnProperty("followupIntentName"))
                                    if (!$util.isString(message.followupIntentName))
                                        return "followupIntentName: string expected";
                                if (message.parentFollowupIntentName != null && message.hasOwnProperty("parentFollowupIntentName"))
                                    if (!$util.isString(message.parentFollowupIntentName))
                                        return "parentFollowupIntentName: string expected";
                                return null;
                            };
    
                            /**
                             * Creates a FollowupIntentInfo message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.FollowupIntentInfo
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2beta1.Intent.FollowupIntentInfo} FollowupIntentInfo
                             */
                            FollowupIntentInfo.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2beta1.Intent.FollowupIntentInfo)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2beta1.Intent.FollowupIntentInfo();
                                if (object.followupIntentName != null)
                                    message.followupIntentName = String(object.followupIntentName);
                                if (object.parentFollowupIntentName != null)
                                    message.parentFollowupIntentName = String(object.parentFollowupIntentName);
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a FollowupIntentInfo message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.FollowupIntentInfo
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.Intent.FollowupIntentInfo} message FollowupIntentInfo
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            FollowupIntentInfo.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.defaults) {
                                    object.followupIntentName = "";
                                    object.parentFollowupIntentName = "";
                                }
                                if (message.followupIntentName != null && message.hasOwnProperty("followupIntentName"))
                                    object.followupIntentName = message.followupIntentName;
                                if (message.parentFollowupIntentName != null && message.hasOwnProperty("parentFollowupIntentName"))
                                    object.parentFollowupIntentName = message.parentFollowupIntentName;
                                return object;
                            };
    
                            /**
                             * Converts this FollowupIntentInfo to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.FollowupIntentInfo
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            FollowupIntentInfo.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for FollowupIntentInfo
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2beta1.Intent.FollowupIntentInfo
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            FollowupIntentInfo.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Intent.FollowupIntentInfo";
                            };
    
                            return FollowupIntentInfo;
                        })();
    
                        return Intent;
                    })();
    
                    v2beta1.ListIntentsRequest = (function() {
    
                        /**
                         * Properties of a ListIntentsRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IListIntentsRequest
                         * @property {string|null} [parent] ListIntentsRequest parent
                         * @property {string|null} [languageCode] ListIntentsRequest languageCode
                         * @property {google.cloud.dialogflow.v2beta1.IntentView|null} [intentView] ListIntentsRequest intentView
                         * @property {number|null} [pageSize] ListIntentsRequest pageSize
                         * @property {string|null} [pageToken] ListIntentsRequest pageToken
                         */
    
                        /**
                         * Constructs a new ListIntentsRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a ListIntentsRequest.
                         * @implements IListIntentsRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IListIntentsRequest=} [properties] Properties to set
                         */
                        function ListIntentsRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListIntentsRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.ListIntentsRequest
                         * @instance
                         */
                        ListIntentsRequest.prototype.parent = "";
    
                        /**
                         * ListIntentsRequest languageCode.
                         * @member {string} languageCode
                         * @memberof google.cloud.dialogflow.v2beta1.ListIntentsRequest
                         * @instance
                         */
                        ListIntentsRequest.prototype.languageCode = "";
    
                        /**
                         * ListIntentsRequest intentView.
                         * @member {google.cloud.dialogflow.v2beta1.IntentView} intentView
                         * @memberof google.cloud.dialogflow.v2beta1.ListIntentsRequest
                         * @instance
                         */
                        ListIntentsRequest.prototype.intentView = 0;
    
                        /**
                         * ListIntentsRequest pageSize.
                         * @member {number} pageSize
                         * @memberof google.cloud.dialogflow.v2beta1.ListIntentsRequest
                         * @instance
                         */
                        ListIntentsRequest.prototype.pageSize = 0;
    
                        /**
                         * ListIntentsRequest pageToken.
                         * @member {string} pageToken
                         * @memberof google.cloud.dialogflow.v2beta1.ListIntentsRequest
                         * @instance
                         */
                        ListIntentsRequest.prototype.pageToken = "";
    
                        /**
                         * Creates a new ListIntentsRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.ListIntentsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListIntentsRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.ListIntentsRequest} ListIntentsRequest instance
                         */
                        ListIntentsRequest.create = function create(properties) {
                            return new ListIntentsRequest(properties);
                        };
    
                        /**
                         * Encodes the specified ListIntentsRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListIntentsRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.ListIntentsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListIntentsRequest} message ListIntentsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListIntentsRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.languageCode != null && Object.hasOwnProperty.call(message, "languageCode"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.languageCode);
                            if (message.intentView != null && Object.hasOwnProperty.call(message, "intentView"))
                                writer.uint32(/* id 3, wireType 0 =*/24).int32(message.intentView);
                            if (message.pageSize != null && Object.hasOwnProperty.call(message, "pageSize"))
                                writer.uint32(/* id 4, wireType 0 =*/32).int32(message.pageSize);
                            if (message.pageToken != null && Object.hasOwnProperty.call(message, "pageToken"))
                                writer.uint32(/* id 5, wireType 2 =*/42).string(message.pageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListIntentsRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListIntentsRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListIntentsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListIntentsRequest} message ListIntentsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListIntentsRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListIntentsRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.ListIntentsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.ListIntentsRequest} ListIntentsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListIntentsRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ListIntentsRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.languageCode = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.intentView = reader.int32();
                                        break;
                                    }
                                case 4: {
                                        message.pageSize = reader.int32();
                                        break;
                                    }
                                case 5: {
                                        message.pageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListIntentsRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListIntentsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.ListIntentsRequest} ListIntentsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListIntentsRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListIntentsRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.ListIntentsRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListIntentsRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                if (!$util.isString(message.languageCode))
                                    return "languageCode: string expected";
                            if (message.intentView != null && message.hasOwnProperty("intentView"))
                                switch (message.intentView) {
                                default:
                                    return "intentView: enum value expected";
                                case 0:
                                case 1:
                                    break;
                                }
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                if (!$util.isInteger(message.pageSize))
                                    return "pageSize: integer expected";
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                if (!$util.isString(message.pageToken))
                                    return "pageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListIntentsRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListIntentsRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.ListIntentsRequest} ListIntentsRequest
                         */
                        ListIntentsRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.ListIntentsRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.ListIntentsRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.languageCode != null)
                                message.languageCode = String(object.languageCode);
                            switch (object.intentView) {
                            default:
                                if (typeof object.intentView === "number") {
                                    message.intentView = object.intentView;
                                    break;
                                }
                                break;
                            case "INTENT_VIEW_UNSPECIFIED":
                            case 0:
                                message.intentView = 0;
                                break;
                            case "INTENT_VIEW_FULL":
                            case 1:
                                message.intentView = 1;
                                break;
                            }
                            if (object.pageSize != null)
                                message.pageSize = object.pageSize | 0;
                            if (object.pageToken != null)
                                message.pageToken = String(object.pageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListIntentsRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListIntentsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ListIntentsRequest} message ListIntentsRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListIntentsRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.languageCode = "";
                                object.intentView = options.enums === String ? "INTENT_VIEW_UNSPECIFIED" : 0;
                                object.pageSize = 0;
                                object.pageToken = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                object.languageCode = message.languageCode;
                            if (message.intentView != null && message.hasOwnProperty("intentView"))
                                object.intentView = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.IntentView[message.intentView] === undefined ? message.intentView : $root.google.cloud.dialogflow.v2beta1.IntentView[message.intentView] : message.intentView;
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                object.pageSize = message.pageSize;
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                object.pageToken = message.pageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListIntentsRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.ListIntentsRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListIntentsRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListIntentsRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.ListIntentsRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListIntentsRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ListIntentsRequest";
                        };
    
                        return ListIntentsRequest;
                    })();
    
                    v2beta1.ListIntentsResponse = (function() {
    
                        /**
                         * Properties of a ListIntentsResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IListIntentsResponse
                         * @property {Array.<google.cloud.dialogflow.v2beta1.IIntent>|null} [intents] ListIntentsResponse intents
                         * @property {string|null} [nextPageToken] ListIntentsResponse nextPageToken
                         */
    
                        /**
                         * Constructs a new ListIntentsResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a ListIntentsResponse.
                         * @implements IListIntentsResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IListIntentsResponse=} [properties] Properties to set
                         */
                        function ListIntentsResponse(properties) {
                            this.intents = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListIntentsResponse intents.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.IIntent>} intents
                         * @memberof google.cloud.dialogflow.v2beta1.ListIntentsResponse
                         * @instance
                         */
                        ListIntentsResponse.prototype.intents = $util.emptyArray;
    
                        /**
                         * ListIntentsResponse nextPageToken.
                         * @member {string} nextPageToken
                         * @memberof google.cloud.dialogflow.v2beta1.ListIntentsResponse
                         * @instance
                         */
                        ListIntentsResponse.prototype.nextPageToken = "";
    
                        /**
                         * Creates a new ListIntentsResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.ListIntentsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListIntentsResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.ListIntentsResponse} ListIntentsResponse instance
                         */
                        ListIntentsResponse.create = function create(properties) {
                            return new ListIntentsResponse(properties);
                        };
    
                        /**
                         * Encodes the specified ListIntentsResponse message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListIntentsResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.ListIntentsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListIntentsResponse} message ListIntentsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListIntentsResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.intents != null && message.intents.length)
                                for (var i = 0; i < message.intents.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.Intent.encode(message.intents[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.nextPageToken != null && Object.hasOwnProperty.call(message, "nextPageToken"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.nextPageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListIntentsResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListIntentsResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListIntentsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListIntentsResponse} message ListIntentsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListIntentsResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListIntentsResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.ListIntentsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.ListIntentsResponse} ListIntentsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListIntentsResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ListIntentsResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.intents && message.intents.length))
                                            message.intents = [];
                                        message.intents.push($root.google.cloud.dialogflow.v2beta1.Intent.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 2: {
                                        message.nextPageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListIntentsResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListIntentsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.ListIntentsResponse} ListIntentsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListIntentsResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListIntentsResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.ListIntentsResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListIntentsResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.intents != null && message.hasOwnProperty("intents")) {
                                if (!Array.isArray(message.intents))
                                    return "intents: array expected";
                                for (var i = 0; i < message.intents.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.Intent.verify(message.intents[i]);
                                    if (error)
                                        return "intents." + error;
                                }
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                if (!$util.isString(message.nextPageToken))
                                    return "nextPageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListIntentsResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListIntentsResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.ListIntentsResponse} ListIntentsResponse
                         */
                        ListIntentsResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.ListIntentsResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.ListIntentsResponse();
                            if (object.intents) {
                                if (!Array.isArray(object.intents))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.ListIntentsResponse.intents: array expected");
                                message.intents = [];
                                for (var i = 0; i < object.intents.length; ++i) {
                                    if (typeof object.intents[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.ListIntentsResponse.intents: object expected");
                                    message.intents[i] = $root.google.cloud.dialogflow.v2beta1.Intent.fromObject(object.intents[i]);
                                }
                            }
                            if (object.nextPageToken != null)
                                message.nextPageToken = String(object.nextPageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListIntentsResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListIntentsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ListIntentsResponse} message ListIntentsResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListIntentsResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.intents = [];
                            if (options.defaults)
                                object.nextPageToken = "";
                            if (message.intents && message.intents.length) {
                                object.intents = [];
                                for (var j = 0; j < message.intents.length; ++j)
                                    object.intents[j] = $root.google.cloud.dialogflow.v2beta1.Intent.toObject(message.intents[j], options);
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                object.nextPageToken = message.nextPageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListIntentsResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.ListIntentsResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListIntentsResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListIntentsResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.ListIntentsResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListIntentsResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ListIntentsResponse";
                        };
    
                        return ListIntentsResponse;
                    })();
    
                    v2beta1.GetIntentRequest = (function() {
    
                        /**
                         * Properties of a GetIntentRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IGetIntentRequest
                         * @property {string|null} [name] GetIntentRequest name
                         * @property {string|null} [languageCode] GetIntentRequest languageCode
                         * @property {google.cloud.dialogflow.v2beta1.IntentView|null} [intentView] GetIntentRequest intentView
                         */
    
                        /**
                         * Constructs a new GetIntentRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a GetIntentRequest.
                         * @implements IGetIntentRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IGetIntentRequest=} [properties] Properties to set
                         */
                        function GetIntentRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GetIntentRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2beta1.GetIntentRequest
                         * @instance
                         */
                        GetIntentRequest.prototype.name = "";
    
                        /**
                         * GetIntentRequest languageCode.
                         * @member {string} languageCode
                         * @memberof google.cloud.dialogflow.v2beta1.GetIntentRequest
                         * @instance
                         */
                        GetIntentRequest.prototype.languageCode = "";
    
                        /**
                         * GetIntentRequest intentView.
                         * @member {google.cloud.dialogflow.v2beta1.IntentView} intentView
                         * @memberof google.cloud.dialogflow.v2beta1.GetIntentRequest
                         * @instance
                         */
                        GetIntentRequest.prototype.intentView = 0;
    
                        /**
                         * Creates a new GetIntentRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.GetIntentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetIntentRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.GetIntentRequest} GetIntentRequest instance
                         */
                        GetIntentRequest.create = function create(properties) {
                            return new GetIntentRequest(properties);
                        };
    
                        /**
                         * Encodes the specified GetIntentRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GetIntentRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.GetIntentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetIntentRequest} message GetIntentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetIntentRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            if (message.languageCode != null && Object.hasOwnProperty.call(message, "languageCode"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.languageCode);
                            if (message.intentView != null && Object.hasOwnProperty.call(message, "intentView"))
                                writer.uint32(/* id 3, wireType 0 =*/24).int32(message.intentView);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GetIntentRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GetIntentRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GetIntentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetIntentRequest} message GetIntentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetIntentRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GetIntentRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.GetIntentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.GetIntentRequest} GetIntentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetIntentRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.GetIntentRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.languageCode = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.intentView = reader.int32();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GetIntentRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GetIntentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.GetIntentRequest} GetIntentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetIntentRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GetIntentRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.GetIntentRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GetIntentRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                if (!$util.isString(message.languageCode))
                                    return "languageCode: string expected";
                            if (message.intentView != null && message.hasOwnProperty("intentView"))
                                switch (message.intentView) {
                                default:
                                    return "intentView: enum value expected";
                                case 0:
                                case 1:
                                    break;
                                }
                            return null;
                        };
    
                        /**
                         * Creates a GetIntentRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.GetIntentRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.GetIntentRequest} GetIntentRequest
                         */
                        GetIntentRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.GetIntentRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.GetIntentRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            if (object.languageCode != null)
                                message.languageCode = String(object.languageCode);
                            switch (object.intentView) {
                            default:
                                if (typeof object.intentView === "number") {
                                    message.intentView = object.intentView;
                                    break;
                                }
                                break;
                            case "INTENT_VIEW_UNSPECIFIED":
                            case 0:
                                message.intentView = 0;
                                break;
                            case "INTENT_VIEW_FULL":
                            case 1:
                                message.intentView = 1;
                                break;
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GetIntentRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.GetIntentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.GetIntentRequest} message GetIntentRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GetIntentRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.name = "";
                                object.languageCode = "";
                                object.intentView = options.enums === String ? "INTENT_VIEW_UNSPECIFIED" : 0;
                            }
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                object.languageCode = message.languageCode;
                            if (message.intentView != null && message.hasOwnProperty("intentView"))
                                object.intentView = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.IntentView[message.intentView] === undefined ? message.intentView : $root.google.cloud.dialogflow.v2beta1.IntentView[message.intentView] : message.intentView;
                            return object;
                        };
    
                        /**
                         * Converts this GetIntentRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.GetIntentRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GetIntentRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GetIntentRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.GetIntentRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GetIntentRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.GetIntentRequest";
                        };
    
                        return GetIntentRequest;
                    })();
    
                    v2beta1.CreateIntentRequest = (function() {
    
                        /**
                         * Properties of a CreateIntentRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ICreateIntentRequest
                         * @property {string|null} [parent] CreateIntentRequest parent
                         * @property {google.cloud.dialogflow.v2beta1.IIntent|null} [intent] CreateIntentRequest intent
                         * @property {string|null} [languageCode] CreateIntentRequest languageCode
                         * @property {google.cloud.dialogflow.v2beta1.IntentView|null} [intentView] CreateIntentRequest intentView
                         */
    
                        /**
                         * Constructs a new CreateIntentRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a CreateIntentRequest.
                         * @implements ICreateIntentRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ICreateIntentRequest=} [properties] Properties to set
                         */
                        function CreateIntentRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * CreateIntentRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.CreateIntentRequest
                         * @instance
                         */
                        CreateIntentRequest.prototype.parent = "";
    
                        /**
                         * CreateIntentRequest intent.
                         * @member {google.cloud.dialogflow.v2beta1.IIntent|null|undefined} intent
                         * @memberof google.cloud.dialogflow.v2beta1.CreateIntentRequest
                         * @instance
                         */
                        CreateIntentRequest.prototype.intent = null;
    
                        /**
                         * CreateIntentRequest languageCode.
                         * @member {string} languageCode
                         * @memberof google.cloud.dialogflow.v2beta1.CreateIntentRequest
                         * @instance
                         */
                        CreateIntentRequest.prototype.languageCode = "";
    
                        /**
                         * CreateIntentRequest intentView.
                         * @member {google.cloud.dialogflow.v2beta1.IntentView} intentView
                         * @memberof google.cloud.dialogflow.v2beta1.CreateIntentRequest
                         * @instance
                         */
                        CreateIntentRequest.prototype.intentView = 0;
    
                        /**
                         * Creates a new CreateIntentRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.CreateIntentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ICreateIntentRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.CreateIntentRequest} CreateIntentRequest instance
                         */
                        CreateIntentRequest.create = function create(properties) {
                            return new CreateIntentRequest(properties);
                        };
    
                        /**
                         * Encodes the specified CreateIntentRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.CreateIntentRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.CreateIntentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ICreateIntentRequest} message CreateIntentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateIntentRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.intent != null && Object.hasOwnProperty.call(message, "intent"))
                                $root.google.cloud.dialogflow.v2beta1.Intent.encode(message.intent, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.languageCode != null && Object.hasOwnProperty.call(message, "languageCode"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.languageCode);
                            if (message.intentView != null && Object.hasOwnProperty.call(message, "intentView"))
                                writer.uint32(/* id 4, wireType 0 =*/32).int32(message.intentView);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified CreateIntentRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.CreateIntentRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.CreateIntentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ICreateIntentRequest} message CreateIntentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateIntentRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a CreateIntentRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.CreateIntentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.CreateIntentRequest} CreateIntentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateIntentRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.CreateIntentRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.intent = $root.google.cloud.dialogflow.v2beta1.Intent.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 3: {
                                        message.languageCode = reader.string();
                                        break;
                                    }
                                case 4: {
                                        message.intentView = reader.int32();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a CreateIntentRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.CreateIntentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.CreateIntentRequest} CreateIntentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateIntentRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a CreateIntentRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.CreateIntentRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        CreateIntentRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.intent != null && message.hasOwnProperty("intent")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.Intent.verify(message.intent);
                                if (error)
                                    return "intent." + error;
                            }
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                if (!$util.isString(message.languageCode))
                                    return "languageCode: string expected";
                            if (message.intentView != null && message.hasOwnProperty("intentView"))
                                switch (message.intentView) {
                                default:
                                    return "intentView: enum value expected";
                                case 0:
                                case 1:
                                    break;
                                }
                            return null;
                        };
    
                        /**
                         * Creates a CreateIntentRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.CreateIntentRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.CreateIntentRequest} CreateIntentRequest
                         */
                        CreateIntentRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.CreateIntentRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.CreateIntentRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.intent != null) {
                                if (typeof object.intent !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.CreateIntentRequest.intent: object expected");
                                message.intent = $root.google.cloud.dialogflow.v2beta1.Intent.fromObject(object.intent);
                            }
                            if (object.languageCode != null)
                                message.languageCode = String(object.languageCode);
                            switch (object.intentView) {
                            default:
                                if (typeof object.intentView === "number") {
                                    message.intentView = object.intentView;
                                    break;
                                }
                                break;
                            case "INTENT_VIEW_UNSPECIFIED":
                            case 0:
                                message.intentView = 0;
                                break;
                            case "INTENT_VIEW_FULL":
                            case 1:
                                message.intentView = 1;
                                break;
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a CreateIntentRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.CreateIntentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.CreateIntentRequest} message CreateIntentRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        CreateIntentRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.intent = null;
                                object.languageCode = "";
                                object.intentView = options.enums === String ? "INTENT_VIEW_UNSPECIFIED" : 0;
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.intent != null && message.hasOwnProperty("intent"))
                                object.intent = $root.google.cloud.dialogflow.v2beta1.Intent.toObject(message.intent, options);
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                object.languageCode = message.languageCode;
                            if (message.intentView != null && message.hasOwnProperty("intentView"))
                                object.intentView = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.IntentView[message.intentView] === undefined ? message.intentView : $root.google.cloud.dialogflow.v2beta1.IntentView[message.intentView] : message.intentView;
                            return object;
                        };
    
                        /**
                         * Converts this CreateIntentRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.CreateIntentRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        CreateIntentRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for CreateIntentRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.CreateIntentRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        CreateIntentRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.CreateIntentRequest";
                        };
    
                        return CreateIntentRequest;
                    })();
    
                    v2beta1.UpdateIntentRequest = (function() {
    
                        /**
                         * Properties of an UpdateIntentRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IUpdateIntentRequest
                         * @property {google.cloud.dialogflow.v2beta1.IIntent|null} [intent] UpdateIntentRequest intent
                         * @property {string|null} [languageCode] UpdateIntentRequest languageCode
                         * @property {google.protobuf.IFieldMask|null} [updateMask] UpdateIntentRequest updateMask
                         * @property {google.cloud.dialogflow.v2beta1.IntentView|null} [intentView] UpdateIntentRequest intentView
                         */
    
                        /**
                         * Constructs a new UpdateIntentRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an UpdateIntentRequest.
                         * @implements IUpdateIntentRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateIntentRequest=} [properties] Properties to set
                         */
                        function UpdateIntentRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * UpdateIntentRequest intent.
                         * @member {google.cloud.dialogflow.v2beta1.IIntent|null|undefined} intent
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateIntentRequest
                         * @instance
                         */
                        UpdateIntentRequest.prototype.intent = null;
    
                        /**
                         * UpdateIntentRequest languageCode.
                         * @member {string} languageCode
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateIntentRequest
                         * @instance
                         */
                        UpdateIntentRequest.prototype.languageCode = "";
    
                        /**
                         * UpdateIntentRequest updateMask.
                         * @member {google.protobuf.IFieldMask|null|undefined} updateMask
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateIntentRequest
                         * @instance
                         */
                        UpdateIntentRequest.prototype.updateMask = null;
    
                        /**
                         * UpdateIntentRequest intentView.
                         * @member {google.cloud.dialogflow.v2beta1.IntentView} intentView
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateIntentRequest
                         * @instance
                         */
                        UpdateIntentRequest.prototype.intentView = 0;
    
                        /**
                         * Creates a new UpdateIntentRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateIntentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateIntentRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.UpdateIntentRequest} UpdateIntentRequest instance
                         */
                        UpdateIntentRequest.create = function create(properties) {
                            return new UpdateIntentRequest(properties);
                        };
    
                        /**
                         * Encodes the specified UpdateIntentRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.UpdateIntentRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateIntentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateIntentRequest} message UpdateIntentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UpdateIntentRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.intent != null && Object.hasOwnProperty.call(message, "intent"))
                                $root.google.cloud.dialogflow.v2beta1.Intent.encode(message.intent, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.languageCode != null && Object.hasOwnProperty.call(message, "languageCode"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.languageCode);
                            if (message.updateMask != null && Object.hasOwnProperty.call(message, "updateMask"))
                                $root.google.protobuf.FieldMask.encode(message.updateMask, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            if (message.intentView != null && Object.hasOwnProperty.call(message, "intentView"))
                                writer.uint32(/* id 4, wireType 0 =*/32).int32(message.intentView);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified UpdateIntentRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.UpdateIntentRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateIntentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateIntentRequest} message UpdateIntentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UpdateIntentRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an UpdateIntentRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateIntentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.UpdateIntentRequest} UpdateIntentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UpdateIntentRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.UpdateIntentRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.intent = $root.google.cloud.dialogflow.v2beta1.Intent.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.languageCode = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.updateMask = $root.google.protobuf.FieldMask.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 4: {
                                        message.intentView = reader.int32();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an UpdateIntentRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateIntentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.UpdateIntentRequest} UpdateIntentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UpdateIntentRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an UpdateIntentRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateIntentRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        UpdateIntentRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.intent != null && message.hasOwnProperty("intent")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.Intent.verify(message.intent);
                                if (error)
                                    return "intent." + error;
                            }
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                if (!$util.isString(message.languageCode))
                                    return "languageCode: string expected";
                            if (message.updateMask != null && message.hasOwnProperty("updateMask")) {
                                var error = $root.google.protobuf.FieldMask.verify(message.updateMask);
                                if (error)
                                    return "updateMask." + error;
                            }
                            if (message.intentView != null && message.hasOwnProperty("intentView"))
                                switch (message.intentView) {
                                default:
                                    return "intentView: enum value expected";
                                case 0:
                                case 1:
                                    break;
                                }
                            return null;
                        };
    
                        /**
                         * Creates an UpdateIntentRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateIntentRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.UpdateIntentRequest} UpdateIntentRequest
                         */
                        UpdateIntentRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.UpdateIntentRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.UpdateIntentRequest();
                            if (object.intent != null) {
                                if (typeof object.intent !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.UpdateIntentRequest.intent: object expected");
                                message.intent = $root.google.cloud.dialogflow.v2beta1.Intent.fromObject(object.intent);
                            }
                            if (object.languageCode != null)
                                message.languageCode = String(object.languageCode);
                            if (object.updateMask != null) {
                                if (typeof object.updateMask !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.UpdateIntentRequest.updateMask: object expected");
                                message.updateMask = $root.google.protobuf.FieldMask.fromObject(object.updateMask);
                            }
                            switch (object.intentView) {
                            default:
                                if (typeof object.intentView === "number") {
                                    message.intentView = object.intentView;
                                    break;
                                }
                                break;
                            case "INTENT_VIEW_UNSPECIFIED":
                            case 0:
                                message.intentView = 0;
                                break;
                            case "INTENT_VIEW_FULL":
                            case 1:
                                message.intentView = 1;
                                break;
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an UpdateIntentRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateIntentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.UpdateIntentRequest} message UpdateIntentRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        UpdateIntentRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.intent = null;
                                object.languageCode = "";
                                object.updateMask = null;
                                object.intentView = options.enums === String ? "INTENT_VIEW_UNSPECIFIED" : 0;
                            }
                            if (message.intent != null && message.hasOwnProperty("intent"))
                                object.intent = $root.google.cloud.dialogflow.v2beta1.Intent.toObject(message.intent, options);
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                object.languageCode = message.languageCode;
                            if (message.updateMask != null && message.hasOwnProperty("updateMask"))
                                object.updateMask = $root.google.protobuf.FieldMask.toObject(message.updateMask, options);
                            if (message.intentView != null && message.hasOwnProperty("intentView"))
                                object.intentView = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.IntentView[message.intentView] === undefined ? message.intentView : $root.google.cloud.dialogflow.v2beta1.IntentView[message.intentView] : message.intentView;
                            return object;
                        };
    
                        /**
                         * Converts this UpdateIntentRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateIntentRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        UpdateIntentRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for UpdateIntentRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateIntentRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        UpdateIntentRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.UpdateIntentRequest";
                        };
    
                        return UpdateIntentRequest;
                    })();
    
                    v2beta1.DeleteIntentRequest = (function() {
    
                        /**
                         * Properties of a DeleteIntentRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IDeleteIntentRequest
                         * @property {string|null} [name] DeleteIntentRequest name
                         */
    
                        /**
                         * Constructs a new DeleteIntentRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a DeleteIntentRequest.
                         * @implements IDeleteIntentRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteIntentRequest=} [properties] Properties to set
                         */
                        function DeleteIntentRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * DeleteIntentRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteIntentRequest
                         * @instance
                         */
                        DeleteIntentRequest.prototype.name = "";
    
                        /**
                         * Creates a new DeleteIntentRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteIntentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteIntentRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.DeleteIntentRequest} DeleteIntentRequest instance
                         */
                        DeleteIntentRequest.create = function create(properties) {
                            return new DeleteIntentRequest(properties);
                        };
    
                        /**
                         * Encodes the specified DeleteIntentRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.DeleteIntentRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteIntentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteIntentRequest} message DeleteIntentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteIntentRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified DeleteIntentRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.DeleteIntentRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteIntentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteIntentRequest} message DeleteIntentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteIntentRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a DeleteIntentRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteIntentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.DeleteIntentRequest} DeleteIntentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteIntentRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.DeleteIntentRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a DeleteIntentRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteIntentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.DeleteIntentRequest} DeleteIntentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteIntentRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a DeleteIntentRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteIntentRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        DeleteIntentRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a DeleteIntentRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteIntentRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.DeleteIntentRequest} DeleteIntentRequest
                         */
                        DeleteIntentRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.DeleteIntentRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.DeleteIntentRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a DeleteIntentRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteIntentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.DeleteIntentRequest} message DeleteIntentRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        DeleteIntentRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.name = "";
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            return object;
                        };
    
                        /**
                         * Converts this DeleteIntentRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteIntentRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        DeleteIntentRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for DeleteIntentRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteIntentRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        DeleteIntentRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.DeleteIntentRequest";
                        };
    
                        return DeleteIntentRequest;
                    })();
    
                    v2beta1.BatchUpdateIntentsRequest = (function() {
    
                        /**
                         * Properties of a BatchUpdateIntentsRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IBatchUpdateIntentsRequest
                         * @property {string|null} [parent] BatchUpdateIntentsRequest parent
                         * @property {string|null} [intentBatchUri] BatchUpdateIntentsRequest intentBatchUri
                         * @property {google.cloud.dialogflow.v2beta1.IIntentBatch|null} [intentBatchInline] BatchUpdateIntentsRequest intentBatchInline
                         * @property {string|null} [languageCode] BatchUpdateIntentsRequest languageCode
                         * @property {google.protobuf.IFieldMask|null} [updateMask] BatchUpdateIntentsRequest updateMask
                         * @property {google.cloud.dialogflow.v2beta1.IntentView|null} [intentView] BatchUpdateIntentsRequest intentView
                         */
    
                        /**
                         * Constructs a new BatchUpdateIntentsRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a BatchUpdateIntentsRequest.
                         * @implements IBatchUpdateIntentsRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IBatchUpdateIntentsRequest=} [properties] Properties to set
                         */
                        function BatchUpdateIntentsRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * BatchUpdateIntentsRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateIntentsRequest
                         * @instance
                         */
                        BatchUpdateIntentsRequest.prototype.parent = "";
    
                        /**
                         * BatchUpdateIntentsRequest intentBatchUri.
                         * @member {string|null|undefined} intentBatchUri
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateIntentsRequest
                         * @instance
                         */
                        BatchUpdateIntentsRequest.prototype.intentBatchUri = null;
    
                        /**
                         * BatchUpdateIntentsRequest intentBatchInline.
                         * @member {google.cloud.dialogflow.v2beta1.IIntentBatch|null|undefined} intentBatchInline
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateIntentsRequest
                         * @instance
                         */
                        BatchUpdateIntentsRequest.prototype.intentBatchInline = null;
    
                        /**
                         * BatchUpdateIntentsRequest languageCode.
                         * @member {string} languageCode
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateIntentsRequest
                         * @instance
                         */
                        BatchUpdateIntentsRequest.prototype.languageCode = "";
    
                        /**
                         * BatchUpdateIntentsRequest updateMask.
                         * @member {google.protobuf.IFieldMask|null|undefined} updateMask
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateIntentsRequest
                         * @instance
                         */
                        BatchUpdateIntentsRequest.prototype.updateMask = null;
    
                        /**
                         * BatchUpdateIntentsRequest intentView.
                         * @member {google.cloud.dialogflow.v2beta1.IntentView} intentView
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateIntentsRequest
                         * @instance
                         */
                        BatchUpdateIntentsRequest.prototype.intentView = 0;
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * BatchUpdateIntentsRequest intentBatch.
                         * @member {"intentBatchUri"|"intentBatchInline"|undefined} intentBatch
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateIntentsRequest
                         * @instance
                         */
                        Object.defineProperty(BatchUpdateIntentsRequest.prototype, "intentBatch", {
                            get: $util.oneOfGetter($oneOfFields = ["intentBatchUri", "intentBatchInline"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new BatchUpdateIntentsRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateIntentsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IBatchUpdateIntentsRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.BatchUpdateIntentsRequest} BatchUpdateIntentsRequest instance
                         */
                        BatchUpdateIntentsRequest.create = function create(properties) {
                            return new BatchUpdateIntentsRequest(properties);
                        };
    
                        /**
                         * Encodes the specified BatchUpdateIntentsRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.BatchUpdateIntentsRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateIntentsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IBatchUpdateIntentsRequest} message BatchUpdateIntentsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        BatchUpdateIntentsRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.intentBatchUri != null && Object.hasOwnProperty.call(message, "intentBatchUri"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.intentBatchUri);
                            if (message.intentBatchInline != null && Object.hasOwnProperty.call(message, "intentBatchInline"))
                                $root.google.cloud.dialogflow.v2beta1.IntentBatch.encode(message.intentBatchInline, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            if (message.languageCode != null && Object.hasOwnProperty.call(message, "languageCode"))
                                writer.uint32(/* id 4, wireType 2 =*/34).string(message.languageCode);
                            if (message.updateMask != null && Object.hasOwnProperty.call(message, "updateMask"))
                                $root.google.protobuf.FieldMask.encode(message.updateMask, writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                            if (message.intentView != null && Object.hasOwnProperty.call(message, "intentView"))
                                writer.uint32(/* id 6, wireType 0 =*/48).int32(message.intentView);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified BatchUpdateIntentsRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.BatchUpdateIntentsRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateIntentsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IBatchUpdateIntentsRequest} message BatchUpdateIntentsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        BatchUpdateIntentsRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a BatchUpdateIntentsRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateIntentsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.BatchUpdateIntentsRequest} BatchUpdateIntentsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        BatchUpdateIntentsRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.BatchUpdateIntentsRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.intentBatchUri = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.intentBatchInline = $root.google.cloud.dialogflow.v2beta1.IntentBatch.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 4: {
                                        message.languageCode = reader.string();
                                        break;
                                    }
                                case 5: {
                                        message.updateMask = $root.google.protobuf.FieldMask.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 6: {
                                        message.intentView = reader.int32();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a BatchUpdateIntentsRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateIntentsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.BatchUpdateIntentsRequest} BatchUpdateIntentsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        BatchUpdateIntentsRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a BatchUpdateIntentsRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateIntentsRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        BatchUpdateIntentsRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.intentBatchUri != null && message.hasOwnProperty("intentBatchUri")) {
                                properties.intentBatch = 1;
                                if (!$util.isString(message.intentBatchUri))
                                    return "intentBatchUri: string expected";
                            }
                            if (message.intentBatchInline != null && message.hasOwnProperty("intentBatchInline")) {
                                if (properties.intentBatch === 1)
                                    return "intentBatch: multiple values";
                                properties.intentBatch = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2beta1.IntentBatch.verify(message.intentBatchInline);
                                    if (error)
                                        return "intentBatchInline." + error;
                                }
                            }
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                if (!$util.isString(message.languageCode))
                                    return "languageCode: string expected";
                            if (message.updateMask != null && message.hasOwnProperty("updateMask")) {
                                var error = $root.google.protobuf.FieldMask.verify(message.updateMask);
                                if (error)
                                    return "updateMask." + error;
                            }
                            if (message.intentView != null && message.hasOwnProperty("intentView"))
                                switch (message.intentView) {
                                default:
                                    return "intentView: enum value expected";
                                case 0:
                                case 1:
                                    break;
                                }
                            return null;
                        };
    
                        /**
                         * Creates a BatchUpdateIntentsRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateIntentsRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.BatchUpdateIntentsRequest} BatchUpdateIntentsRequest
                         */
                        BatchUpdateIntentsRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.BatchUpdateIntentsRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.BatchUpdateIntentsRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.intentBatchUri != null)
                                message.intentBatchUri = String(object.intentBatchUri);
                            if (object.intentBatchInline != null) {
                                if (typeof object.intentBatchInline !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.BatchUpdateIntentsRequest.intentBatchInline: object expected");
                                message.intentBatchInline = $root.google.cloud.dialogflow.v2beta1.IntentBatch.fromObject(object.intentBatchInline);
                            }
                            if (object.languageCode != null)
                                message.languageCode = String(object.languageCode);
                            if (object.updateMask != null) {
                                if (typeof object.updateMask !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.BatchUpdateIntentsRequest.updateMask: object expected");
                                message.updateMask = $root.google.protobuf.FieldMask.fromObject(object.updateMask);
                            }
                            switch (object.intentView) {
                            default:
                                if (typeof object.intentView === "number") {
                                    message.intentView = object.intentView;
                                    break;
                                }
                                break;
                            case "INTENT_VIEW_UNSPECIFIED":
                            case 0:
                                message.intentView = 0;
                                break;
                            case "INTENT_VIEW_FULL":
                            case 1:
                                message.intentView = 1;
                                break;
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a BatchUpdateIntentsRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateIntentsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.BatchUpdateIntentsRequest} message BatchUpdateIntentsRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        BatchUpdateIntentsRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.languageCode = "";
                                object.updateMask = null;
                                object.intentView = options.enums === String ? "INTENT_VIEW_UNSPECIFIED" : 0;
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.intentBatchUri != null && message.hasOwnProperty("intentBatchUri")) {
                                object.intentBatchUri = message.intentBatchUri;
                                if (options.oneofs)
                                    object.intentBatch = "intentBatchUri";
                            }
                            if (message.intentBatchInline != null && message.hasOwnProperty("intentBatchInline")) {
                                object.intentBatchInline = $root.google.cloud.dialogflow.v2beta1.IntentBatch.toObject(message.intentBatchInline, options);
                                if (options.oneofs)
                                    object.intentBatch = "intentBatchInline";
                            }
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                object.languageCode = message.languageCode;
                            if (message.updateMask != null && message.hasOwnProperty("updateMask"))
                                object.updateMask = $root.google.protobuf.FieldMask.toObject(message.updateMask, options);
                            if (message.intentView != null && message.hasOwnProperty("intentView"))
                                object.intentView = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.IntentView[message.intentView] === undefined ? message.intentView : $root.google.cloud.dialogflow.v2beta1.IntentView[message.intentView] : message.intentView;
                            return object;
                        };
    
                        /**
                         * Converts this BatchUpdateIntentsRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateIntentsRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        BatchUpdateIntentsRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for BatchUpdateIntentsRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateIntentsRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        BatchUpdateIntentsRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.BatchUpdateIntentsRequest";
                        };
    
                        return BatchUpdateIntentsRequest;
                    })();
    
                    v2beta1.BatchUpdateIntentsResponse = (function() {
    
                        /**
                         * Properties of a BatchUpdateIntentsResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IBatchUpdateIntentsResponse
                         * @property {Array.<google.cloud.dialogflow.v2beta1.IIntent>|null} [intents] BatchUpdateIntentsResponse intents
                         */
    
                        /**
                         * Constructs a new BatchUpdateIntentsResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a BatchUpdateIntentsResponse.
                         * @implements IBatchUpdateIntentsResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IBatchUpdateIntentsResponse=} [properties] Properties to set
                         */
                        function BatchUpdateIntentsResponse(properties) {
                            this.intents = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * BatchUpdateIntentsResponse intents.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.IIntent>} intents
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateIntentsResponse
                         * @instance
                         */
                        BatchUpdateIntentsResponse.prototype.intents = $util.emptyArray;
    
                        /**
                         * Creates a new BatchUpdateIntentsResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateIntentsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IBatchUpdateIntentsResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.BatchUpdateIntentsResponse} BatchUpdateIntentsResponse instance
                         */
                        BatchUpdateIntentsResponse.create = function create(properties) {
                            return new BatchUpdateIntentsResponse(properties);
                        };
    
                        /**
                         * Encodes the specified BatchUpdateIntentsResponse message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.BatchUpdateIntentsResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateIntentsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IBatchUpdateIntentsResponse} message BatchUpdateIntentsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        BatchUpdateIntentsResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.intents != null && message.intents.length)
                                for (var i = 0; i < message.intents.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.Intent.encode(message.intents[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified BatchUpdateIntentsResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.BatchUpdateIntentsResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateIntentsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IBatchUpdateIntentsResponse} message BatchUpdateIntentsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        BatchUpdateIntentsResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a BatchUpdateIntentsResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateIntentsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.BatchUpdateIntentsResponse} BatchUpdateIntentsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        BatchUpdateIntentsResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.BatchUpdateIntentsResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.intents && message.intents.length))
                                            message.intents = [];
                                        message.intents.push($root.google.cloud.dialogflow.v2beta1.Intent.decode(reader, reader.uint32()));
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a BatchUpdateIntentsResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateIntentsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.BatchUpdateIntentsResponse} BatchUpdateIntentsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        BatchUpdateIntentsResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a BatchUpdateIntentsResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateIntentsResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        BatchUpdateIntentsResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.intents != null && message.hasOwnProperty("intents")) {
                                if (!Array.isArray(message.intents))
                                    return "intents: array expected";
                                for (var i = 0; i < message.intents.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.Intent.verify(message.intents[i]);
                                    if (error)
                                        return "intents." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates a BatchUpdateIntentsResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateIntentsResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.BatchUpdateIntentsResponse} BatchUpdateIntentsResponse
                         */
                        BatchUpdateIntentsResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.BatchUpdateIntentsResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.BatchUpdateIntentsResponse();
                            if (object.intents) {
                                if (!Array.isArray(object.intents))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.BatchUpdateIntentsResponse.intents: array expected");
                                message.intents = [];
                                for (var i = 0; i < object.intents.length; ++i) {
                                    if (typeof object.intents[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.BatchUpdateIntentsResponse.intents: object expected");
                                    message.intents[i] = $root.google.cloud.dialogflow.v2beta1.Intent.fromObject(object.intents[i]);
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a BatchUpdateIntentsResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateIntentsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.BatchUpdateIntentsResponse} message BatchUpdateIntentsResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        BatchUpdateIntentsResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.intents = [];
                            if (message.intents && message.intents.length) {
                                object.intents = [];
                                for (var j = 0; j < message.intents.length; ++j)
                                    object.intents[j] = $root.google.cloud.dialogflow.v2beta1.Intent.toObject(message.intents[j], options);
                            }
                            return object;
                        };
    
                        /**
                         * Converts this BatchUpdateIntentsResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateIntentsResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        BatchUpdateIntentsResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for BatchUpdateIntentsResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateIntentsResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        BatchUpdateIntentsResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.BatchUpdateIntentsResponse";
                        };
    
                        return BatchUpdateIntentsResponse;
                    })();
    
                    v2beta1.BatchDeleteIntentsRequest = (function() {
    
                        /**
                         * Properties of a BatchDeleteIntentsRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IBatchDeleteIntentsRequest
                         * @property {string|null} [parent] BatchDeleteIntentsRequest parent
                         * @property {Array.<google.cloud.dialogflow.v2beta1.IIntent>|null} [intents] BatchDeleteIntentsRequest intents
                         */
    
                        /**
                         * Constructs a new BatchDeleteIntentsRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a BatchDeleteIntentsRequest.
                         * @implements IBatchDeleteIntentsRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IBatchDeleteIntentsRequest=} [properties] Properties to set
                         */
                        function BatchDeleteIntentsRequest(properties) {
                            this.intents = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * BatchDeleteIntentsRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.BatchDeleteIntentsRequest
                         * @instance
                         */
                        BatchDeleteIntentsRequest.prototype.parent = "";
    
                        /**
                         * BatchDeleteIntentsRequest intents.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.IIntent>} intents
                         * @memberof google.cloud.dialogflow.v2beta1.BatchDeleteIntentsRequest
                         * @instance
                         */
                        BatchDeleteIntentsRequest.prototype.intents = $util.emptyArray;
    
                        /**
                         * Creates a new BatchDeleteIntentsRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.BatchDeleteIntentsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IBatchDeleteIntentsRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.BatchDeleteIntentsRequest} BatchDeleteIntentsRequest instance
                         */
                        BatchDeleteIntentsRequest.create = function create(properties) {
                            return new BatchDeleteIntentsRequest(properties);
                        };
    
                        /**
                         * Encodes the specified BatchDeleteIntentsRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.BatchDeleteIntentsRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.BatchDeleteIntentsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IBatchDeleteIntentsRequest} message BatchDeleteIntentsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        BatchDeleteIntentsRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.intents != null && message.intents.length)
                                for (var i = 0; i < message.intents.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.Intent.encode(message.intents[i], writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified BatchDeleteIntentsRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.BatchDeleteIntentsRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.BatchDeleteIntentsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IBatchDeleteIntentsRequest} message BatchDeleteIntentsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        BatchDeleteIntentsRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a BatchDeleteIntentsRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.BatchDeleteIntentsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.BatchDeleteIntentsRequest} BatchDeleteIntentsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        BatchDeleteIntentsRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.BatchDeleteIntentsRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        if (!(message.intents && message.intents.length))
                                            message.intents = [];
                                        message.intents.push($root.google.cloud.dialogflow.v2beta1.Intent.decode(reader, reader.uint32()));
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a BatchDeleteIntentsRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.BatchDeleteIntentsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.BatchDeleteIntentsRequest} BatchDeleteIntentsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        BatchDeleteIntentsRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a BatchDeleteIntentsRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.BatchDeleteIntentsRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        BatchDeleteIntentsRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.intents != null && message.hasOwnProperty("intents")) {
                                if (!Array.isArray(message.intents))
                                    return "intents: array expected";
                                for (var i = 0; i < message.intents.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.Intent.verify(message.intents[i]);
                                    if (error)
                                        return "intents." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates a BatchDeleteIntentsRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.BatchDeleteIntentsRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.BatchDeleteIntentsRequest} BatchDeleteIntentsRequest
                         */
                        BatchDeleteIntentsRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.BatchDeleteIntentsRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.BatchDeleteIntentsRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.intents) {
                                if (!Array.isArray(object.intents))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.BatchDeleteIntentsRequest.intents: array expected");
                                message.intents = [];
                                for (var i = 0; i < object.intents.length; ++i) {
                                    if (typeof object.intents[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.BatchDeleteIntentsRequest.intents: object expected");
                                    message.intents[i] = $root.google.cloud.dialogflow.v2beta1.Intent.fromObject(object.intents[i]);
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a BatchDeleteIntentsRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.BatchDeleteIntentsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.BatchDeleteIntentsRequest} message BatchDeleteIntentsRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        BatchDeleteIntentsRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.intents = [];
                            if (options.defaults)
                                object.parent = "";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.intents && message.intents.length) {
                                object.intents = [];
                                for (var j = 0; j < message.intents.length; ++j)
                                    object.intents[j] = $root.google.cloud.dialogflow.v2beta1.Intent.toObject(message.intents[j], options);
                            }
                            return object;
                        };
    
                        /**
                         * Converts this BatchDeleteIntentsRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.BatchDeleteIntentsRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        BatchDeleteIntentsRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for BatchDeleteIntentsRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.BatchDeleteIntentsRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        BatchDeleteIntentsRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.BatchDeleteIntentsRequest";
                        };
    
                        return BatchDeleteIntentsRequest;
                    })();
    
                    /**
                     * IntentView enum.
                     * @name google.cloud.dialogflow.v2beta1.IntentView
                     * @enum {number}
                     * @property {number} INTENT_VIEW_UNSPECIFIED=0 INTENT_VIEW_UNSPECIFIED value
                     * @property {number} INTENT_VIEW_FULL=1 INTENT_VIEW_FULL value
                     */
                    v2beta1.IntentView = (function() {
                        var valuesById = {}, values = Object.create(valuesById);
                        values[valuesById[0] = "INTENT_VIEW_UNSPECIFIED"] = 0;
                        values[valuesById[1] = "INTENT_VIEW_FULL"] = 1;
                        return values;
                    })();
    
                    v2beta1.IntentBatch = (function() {
    
                        /**
                         * Properties of an IntentBatch.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IIntentBatch
                         * @property {Array.<google.cloud.dialogflow.v2beta1.IIntent>|null} [intents] IntentBatch intents
                         */
    
                        /**
                         * Constructs a new IntentBatch.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an IntentBatch.
                         * @implements IIntentBatch
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IIntentBatch=} [properties] Properties to set
                         */
                        function IntentBatch(properties) {
                            this.intents = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * IntentBatch intents.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.IIntent>} intents
                         * @memberof google.cloud.dialogflow.v2beta1.IntentBatch
                         * @instance
                         */
                        IntentBatch.prototype.intents = $util.emptyArray;
    
                        /**
                         * Creates a new IntentBatch instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.IntentBatch
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IIntentBatch=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.IntentBatch} IntentBatch instance
                         */
                        IntentBatch.create = function create(properties) {
                            return new IntentBatch(properties);
                        };
    
                        /**
                         * Encodes the specified IntentBatch message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.IntentBatch.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.IntentBatch
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IIntentBatch} message IntentBatch message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        IntentBatch.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.intents != null && message.intents.length)
                                for (var i = 0; i < message.intents.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.Intent.encode(message.intents[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified IntentBatch message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.IntentBatch.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.IntentBatch
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IIntentBatch} message IntentBatch message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        IntentBatch.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an IntentBatch message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.IntentBatch
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.IntentBatch} IntentBatch
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        IntentBatch.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.IntentBatch();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.intents && message.intents.length))
                                            message.intents = [];
                                        message.intents.push($root.google.cloud.dialogflow.v2beta1.Intent.decode(reader, reader.uint32()));
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an IntentBatch message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.IntentBatch
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.IntentBatch} IntentBatch
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        IntentBatch.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an IntentBatch message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.IntentBatch
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        IntentBatch.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.intents != null && message.hasOwnProperty("intents")) {
                                if (!Array.isArray(message.intents))
                                    return "intents: array expected";
                                for (var i = 0; i < message.intents.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.Intent.verify(message.intents[i]);
                                    if (error)
                                        return "intents." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates an IntentBatch message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.IntentBatch
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.IntentBatch} IntentBatch
                         */
                        IntentBatch.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.IntentBatch)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.IntentBatch();
                            if (object.intents) {
                                if (!Array.isArray(object.intents))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.IntentBatch.intents: array expected");
                                message.intents = [];
                                for (var i = 0; i < object.intents.length; ++i) {
                                    if (typeof object.intents[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.IntentBatch.intents: object expected");
                                    message.intents[i] = $root.google.cloud.dialogflow.v2beta1.Intent.fromObject(object.intents[i]);
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an IntentBatch message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.IntentBatch
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IntentBatch} message IntentBatch
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        IntentBatch.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.intents = [];
                            if (message.intents && message.intents.length) {
                                object.intents = [];
                                for (var j = 0; j < message.intents.length; ++j)
                                    object.intents[j] = $root.google.cloud.dialogflow.v2beta1.Intent.toObject(message.intents[j], options);
                            }
                            return object;
                        };
    
                        /**
                         * Converts this IntentBatch to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.IntentBatch
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        IntentBatch.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for IntentBatch
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.IntentBatch
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        IntentBatch.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.IntentBatch";
                        };
    
                        return IntentBatch;
                    })();
    
                    v2beta1.SessionEntityTypes = (function() {
    
                        /**
                         * Constructs a new SessionEntityTypes service.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a SessionEntityTypes
                         * @extends $protobuf.rpc.Service
                         * @constructor
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         */
                        function SessionEntityTypes(rpcImpl, requestDelimited, responseDelimited) {
                            $protobuf.rpc.Service.call(this, rpcImpl, requestDelimited, responseDelimited);
                        }
    
                        (SessionEntityTypes.prototype = Object.create($protobuf.rpc.Service.prototype)).constructor = SessionEntityTypes;
    
                        /**
                         * Creates new SessionEntityTypes service using the specified rpc implementation.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.SessionEntityTypes
                         * @static
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         * @returns {SessionEntityTypes} RPC service. Useful where requests and/or responses are streamed.
                         */
                        SessionEntityTypes.create = function create(rpcImpl, requestDelimited, responseDelimited) {
                            return new this(rpcImpl, requestDelimited, responseDelimited);
                        };
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.SessionEntityTypes|listSessionEntityTypes}.
                         * @memberof google.cloud.dialogflow.v2beta1.SessionEntityTypes
                         * @typedef ListSessionEntityTypesCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.ListSessionEntityTypesResponse} [response] ListSessionEntityTypesResponse
                         */
    
                        /**
                         * Calls ListSessionEntityTypes.
                         * @function listSessionEntityTypes
                         * @memberof google.cloud.dialogflow.v2beta1.SessionEntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IListSessionEntityTypesRequest} request ListSessionEntityTypesRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.SessionEntityTypes.ListSessionEntityTypesCallback} callback Node-style callback called with the error, if any, and ListSessionEntityTypesResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(SessionEntityTypes.prototype.listSessionEntityTypes = function listSessionEntityTypes(request, callback) {
                            return this.rpcCall(listSessionEntityTypes, $root.google.cloud.dialogflow.v2beta1.ListSessionEntityTypesRequest, $root.google.cloud.dialogflow.v2beta1.ListSessionEntityTypesResponse, request, callback);
                        }, "name", { value: "ListSessionEntityTypes" });
    
                        /**
                         * Calls ListSessionEntityTypes.
                         * @function listSessionEntityTypes
                         * @memberof google.cloud.dialogflow.v2beta1.SessionEntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IListSessionEntityTypesRequest} request ListSessionEntityTypesRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.ListSessionEntityTypesResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.SessionEntityTypes|getSessionEntityType}.
                         * @memberof google.cloud.dialogflow.v2beta1.SessionEntityTypes
                         * @typedef GetSessionEntityTypeCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.SessionEntityType} [response] SessionEntityType
                         */
    
                        /**
                         * Calls GetSessionEntityType.
                         * @function getSessionEntityType
                         * @memberof google.cloud.dialogflow.v2beta1.SessionEntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IGetSessionEntityTypeRequest} request GetSessionEntityTypeRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.SessionEntityTypes.GetSessionEntityTypeCallback} callback Node-style callback called with the error, if any, and SessionEntityType
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(SessionEntityTypes.prototype.getSessionEntityType = function getSessionEntityType(request, callback) {
                            return this.rpcCall(getSessionEntityType, $root.google.cloud.dialogflow.v2beta1.GetSessionEntityTypeRequest, $root.google.cloud.dialogflow.v2beta1.SessionEntityType, request, callback);
                        }, "name", { value: "GetSessionEntityType" });
    
                        /**
                         * Calls GetSessionEntityType.
                         * @function getSessionEntityType
                         * @memberof google.cloud.dialogflow.v2beta1.SessionEntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IGetSessionEntityTypeRequest} request GetSessionEntityTypeRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.SessionEntityType>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.SessionEntityTypes|createSessionEntityType}.
                         * @memberof google.cloud.dialogflow.v2beta1.SessionEntityTypes
                         * @typedef CreateSessionEntityTypeCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.SessionEntityType} [response] SessionEntityType
                         */
    
                        /**
                         * Calls CreateSessionEntityType.
                         * @function createSessionEntityType
                         * @memberof google.cloud.dialogflow.v2beta1.SessionEntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.ICreateSessionEntityTypeRequest} request CreateSessionEntityTypeRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.SessionEntityTypes.CreateSessionEntityTypeCallback} callback Node-style callback called with the error, if any, and SessionEntityType
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(SessionEntityTypes.prototype.createSessionEntityType = function createSessionEntityType(request, callback) {
                            return this.rpcCall(createSessionEntityType, $root.google.cloud.dialogflow.v2beta1.CreateSessionEntityTypeRequest, $root.google.cloud.dialogflow.v2beta1.SessionEntityType, request, callback);
                        }, "name", { value: "CreateSessionEntityType" });
    
                        /**
                         * Calls CreateSessionEntityType.
                         * @function createSessionEntityType
                         * @memberof google.cloud.dialogflow.v2beta1.SessionEntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.ICreateSessionEntityTypeRequest} request CreateSessionEntityTypeRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.SessionEntityType>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.SessionEntityTypes|updateSessionEntityType}.
                         * @memberof google.cloud.dialogflow.v2beta1.SessionEntityTypes
                         * @typedef UpdateSessionEntityTypeCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.SessionEntityType} [response] SessionEntityType
                         */
    
                        /**
                         * Calls UpdateSessionEntityType.
                         * @function updateSessionEntityType
                         * @memberof google.cloud.dialogflow.v2beta1.SessionEntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateSessionEntityTypeRequest} request UpdateSessionEntityTypeRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.SessionEntityTypes.UpdateSessionEntityTypeCallback} callback Node-style callback called with the error, if any, and SessionEntityType
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(SessionEntityTypes.prototype.updateSessionEntityType = function updateSessionEntityType(request, callback) {
                            return this.rpcCall(updateSessionEntityType, $root.google.cloud.dialogflow.v2beta1.UpdateSessionEntityTypeRequest, $root.google.cloud.dialogflow.v2beta1.SessionEntityType, request, callback);
                        }, "name", { value: "UpdateSessionEntityType" });
    
                        /**
                         * Calls UpdateSessionEntityType.
                         * @function updateSessionEntityType
                         * @memberof google.cloud.dialogflow.v2beta1.SessionEntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateSessionEntityTypeRequest} request UpdateSessionEntityTypeRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.SessionEntityType>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.SessionEntityTypes|deleteSessionEntityType}.
                         * @memberof google.cloud.dialogflow.v2beta1.SessionEntityTypes
                         * @typedef DeleteSessionEntityTypeCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.protobuf.Empty} [response] Empty
                         */
    
                        /**
                         * Calls DeleteSessionEntityType.
                         * @function deleteSessionEntityType
                         * @memberof google.cloud.dialogflow.v2beta1.SessionEntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteSessionEntityTypeRequest} request DeleteSessionEntityTypeRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.SessionEntityTypes.DeleteSessionEntityTypeCallback} callback Node-style callback called with the error, if any, and Empty
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(SessionEntityTypes.prototype.deleteSessionEntityType = function deleteSessionEntityType(request, callback) {
                            return this.rpcCall(deleteSessionEntityType, $root.google.cloud.dialogflow.v2beta1.DeleteSessionEntityTypeRequest, $root.google.protobuf.Empty, request, callback);
                        }, "name", { value: "DeleteSessionEntityType" });
    
                        /**
                         * Calls DeleteSessionEntityType.
                         * @function deleteSessionEntityType
                         * @memberof google.cloud.dialogflow.v2beta1.SessionEntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteSessionEntityTypeRequest} request DeleteSessionEntityTypeRequest message or plain object
                         * @returns {Promise<google.protobuf.Empty>} Promise
                         * @variation 2
                         */
    
                        return SessionEntityTypes;
                    })();
    
                    v2beta1.SessionEntityType = (function() {
    
                        /**
                         * Properties of a SessionEntityType.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ISessionEntityType
                         * @property {string|null} [name] SessionEntityType name
                         * @property {google.cloud.dialogflow.v2beta1.SessionEntityType.EntityOverrideMode|null} [entityOverrideMode] SessionEntityType entityOverrideMode
                         * @property {Array.<google.cloud.dialogflow.v2beta1.EntityType.IEntity>|null} [entities] SessionEntityType entities
                         */
    
                        /**
                         * Constructs a new SessionEntityType.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a SessionEntityType.
                         * @implements ISessionEntityType
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ISessionEntityType=} [properties] Properties to set
                         */
                        function SessionEntityType(properties) {
                            this.entities = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SessionEntityType name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2beta1.SessionEntityType
                         * @instance
                         */
                        SessionEntityType.prototype.name = "";
    
                        /**
                         * SessionEntityType entityOverrideMode.
                         * @member {google.cloud.dialogflow.v2beta1.SessionEntityType.EntityOverrideMode} entityOverrideMode
                         * @memberof google.cloud.dialogflow.v2beta1.SessionEntityType
                         * @instance
                         */
                        SessionEntityType.prototype.entityOverrideMode = 0;
    
                        /**
                         * SessionEntityType entities.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.EntityType.IEntity>} entities
                         * @memberof google.cloud.dialogflow.v2beta1.SessionEntityType
                         * @instance
                         */
                        SessionEntityType.prototype.entities = $util.emptyArray;
    
                        /**
                         * Creates a new SessionEntityType instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.SessionEntityType
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISessionEntityType=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.SessionEntityType} SessionEntityType instance
                         */
                        SessionEntityType.create = function create(properties) {
                            return new SessionEntityType(properties);
                        };
    
                        /**
                         * Encodes the specified SessionEntityType message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SessionEntityType.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.SessionEntityType
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISessionEntityType} message SessionEntityType message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SessionEntityType.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            if (message.entityOverrideMode != null && Object.hasOwnProperty.call(message, "entityOverrideMode"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.entityOverrideMode);
                            if (message.entities != null && message.entities.length)
                                for (var i = 0; i < message.entities.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.EntityType.Entity.encode(message.entities[i], writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SessionEntityType message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SessionEntityType.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SessionEntityType
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISessionEntityType} message SessionEntityType message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SessionEntityType.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SessionEntityType message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.SessionEntityType
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.SessionEntityType} SessionEntityType
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SessionEntityType.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.SessionEntityType();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.entityOverrideMode = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        if (!(message.entities && message.entities.length))
                                            message.entities = [];
                                        message.entities.push($root.google.cloud.dialogflow.v2beta1.EntityType.Entity.decode(reader, reader.uint32()));
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SessionEntityType message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SessionEntityType
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.SessionEntityType} SessionEntityType
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SessionEntityType.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SessionEntityType message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.SessionEntityType
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SessionEntityType.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            if (message.entityOverrideMode != null && message.hasOwnProperty("entityOverrideMode"))
                                switch (message.entityOverrideMode) {
                                default:
                                    return "entityOverrideMode: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                    break;
                                }
                            if (message.entities != null && message.hasOwnProperty("entities")) {
                                if (!Array.isArray(message.entities))
                                    return "entities: array expected";
                                for (var i = 0; i < message.entities.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.EntityType.Entity.verify(message.entities[i]);
                                    if (error)
                                        return "entities." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates a SessionEntityType message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.SessionEntityType
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.SessionEntityType} SessionEntityType
                         */
                        SessionEntityType.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.SessionEntityType)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.SessionEntityType();
                            if (object.name != null)
                                message.name = String(object.name);
                            switch (object.entityOverrideMode) {
                            default:
                                if (typeof object.entityOverrideMode === "number") {
                                    message.entityOverrideMode = object.entityOverrideMode;
                                    break;
                                }
                                break;
                            case "ENTITY_OVERRIDE_MODE_UNSPECIFIED":
                            case 0:
                                message.entityOverrideMode = 0;
                                break;
                            case "ENTITY_OVERRIDE_MODE_OVERRIDE":
                            case 1:
                                message.entityOverrideMode = 1;
                                break;
                            case "ENTITY_OVERRIDE_MODE_SUPPLEMENT":
                            case 2:
                                message.entityOverrideMode = 2;
                                break;
                            }
                            if (object.entities) {
                                if (!Array.isArray(object.entities))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.SessionEntityType.entities: array expected");
                                message.entities = [];
                                for (var i = 0; i < object.entities.length; ++i) {
                                    if (typeof object.entities[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.SessionEntityType.entities: object expected");
                                    message.entities[i] = $root.google.cloud.dialogflow.v2beta1.EntityType.Entity.fromObject(object.entities[i]);
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SessionEntityType message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.SessionEntityType
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.SessionEntityType} message SessionEntityType
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SessionEntityType.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.entities = [];
                            if (options.defaults) {
                                object.name = "";
                                object.entityOverrideMode = options.enums === String ? "ENTITY_OVERRIDE_MODE_UNSPECIFIED" : 0;
                            }
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            if (message.entityOverrideMode != null && message.hasOwnProperty("entityOverrideMode"))
                                object.entityOverrideMode = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.SessionEntityType.EntityOverrideMode[message.entityOverrideMode] === undefined ? message.entityOverrideMode : $root.google.cloud.dialogflow.v2beta1.SessionEntityType.EntityOverrideMode[message.entityOverrideMode] : message.entityOverrideMode;
                            if (message.entities && message.entities.length) {
                                object.entities = [];
                                for (var j = 0; j < message.entities.length; ++j)
                                    object.entities[j] = $root.google.cloud.dialogflow.v2beta1.EntityType.Entity.toObject(message.entities[j], options);
                            }
                            return object;
                        };
    
                        /**
                         * Converts this SessionEntityType to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.SessionEntityType
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SessionEntityType.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SessionEntityType
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.SessionEntityType
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SessionEntityType.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.SessionEntityType";
                        };
    
                        /**
                         * EntityOverrideMode enum.
                         * @name google.cloud.dialogflow.v2beta1.SessionEntityType.EntityOverrideMode
                         * @enum {number}
                         * @property {number} ENTITY_OVERRIDE_MODE_UNSPECIFIED=0 ENTITY_OVERRIDE_MODE_UNSPECIFIED value
                         * @property {number} ENTITY_OVERRIDE_MODE_OVERRIDE=1 ENTITY_OVERRIDE_MODE_OVERRIDE value
                         * @property {number} ENTITY_OVERRIDE_MODE_SUPPLEMENT=2 ENTITY_OVERRIDE_MODE_SUPPLEMENT value
                         */
                        SessionEntityType.EntityOverrideMode = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "ENTITY_OVERRIDE_MODE_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "ENTITY_OVERRIDE_MODE_OVERRIDE"] = 1;
                            values[valuesById[2] = "ENTITY_OVERRIDE_MODE_SUPPLEMENT"] = 2;
                            return values;
                        })();
    
                        return SessionEntityType;
                    })();
    
                    v2beta1.ListSessionEntityTypesRequest = (function() {
    
                        /**
                         * Properties of a ListSessionEntityTypesRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IListSessionEntityTypesRequest
                         * @property {string|null} [parent] ListSessionEntityTypesRequest parent
                         * @property {number|null} [pageSize] ListSessionEntityTypesRequest pageSize
                         * @property {string|null} [pageToken] ListSessionEntityTypesRequest pageToken
                         */
    
                        /**
                         * Constructs a new ListSessionEntityTypesRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a ListSessionEntityTypesRequest.
                         * @implements IListSessionEntityTypesRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IListSessionEntityTypesRequest=} [properties] Properties to set
                         */
                        function ListSessionEntityTypesRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListSessionEntityTypesRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.ListSessionEntityTypesRequest
                         * @instance
                         */
                        ListSessionEntityTypesRequest.prototype.parent = "";
    
                        /**
                         * ListSessionEntityTypesRequest pageSize.
                         * @member {number} pageSize
                         * @memberof google.cloud.dialogflow.v2beta1.ListSessionEntityTypesRequest
                         * @instance
                         */
                        ListSessionEntityTypesRequest.prototype.pageSize = 0;
    
                        /**
                         * ListSessionEntityTypesRequest pageToken.
                         * @member {string} pageToken
                         * @memberof google.cloud.dialogflow.v2beta1.ListSessionEntityTypesRequest
                         * @instance
                         */
                        ListSessionEntityTypesRequest.prototype.pageToken = "";
    
                        /**
                         * Creates a new ListSessionEntityTypesRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.ListSessionEntityTypesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListSessionEntityTypesRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.ListSessionEntityTypesRequest} ListSessionEntityTypesRequest instance
                         */
                        ListSessionEntityTypesRequest.create = function create(properties) {
                            return new ListSessionEntityTypesRequest(properties);
                        };
    
                        /**
                         * Encodes the specified ListSessionEntityTypesRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListSessionEntityTypesRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.ListSessionEntityTypesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListSessionEntityTypesRequest} message ListSessionEntityTypesRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListSessionEntityTypesRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.pageSize != null && Object.hasOwnProperty.call(message, "pageSize"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.pageSize);
                            if (message.pageToken != null && Object.hasOwnProperty.call(message, "pageToken"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.pageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListSessionEntityTypesRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListSessionEntityTypesRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListSessionEntityTypesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListSessionEntityTypesRequest} message ListSessionEntityTypesRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListSessionEntityTypesRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListSessionEntityTypesRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.ListSessionEntityTypesRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.ListSessionEntityTypesRequest} ListSessionEntityTypesRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListSessionEntityTypesRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ListSessionEntityTypesRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.pageSize = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.pageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListSessionEntityTypesRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListSessionEntityTypesRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.ListSessionEntityTypesRequest} ListSessionEntityTypesRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListSessionEntityTypesRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListSessionEntityTypesRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.ListSessionEntityTypesRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListSessionEntityTypesRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                if (!$util.isInteger(message.pageSize))
                                    return "pageSize: integer expected";
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                if (!$util.isString(message.pageToken))
                                    return "pageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListSessionEntityTypesRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListSessionEntityTypesRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.ListSessionEntityTypesRequest} ListSessionEntityTypesRequest
                         */
                        ListSessionEntityTypesRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.ListSessionEntityTypesRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.ListSessionEntityTypesRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.pageSize != null)
                                message.pageSize = object.pageSize | 0;
                            if (object.pageToken != null)
                                message.pageToken = String(object.pageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListSessionEntityTypesRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListSessionEntityTypesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ListSessionEntityTypesRequest} message ListSessionEntityTypesRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListSessionEntityTypesRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.pageSize = 0;
                                object.pageToken = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                object.pageSize = message.pageSize;
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                object.pageToken = message.pageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListSessionEntityTypesRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.ListSessionEntityTypesRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListSessionEntityTypesRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListSessionEntityTypesRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.ListSessionEntityTypesRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListSessionEntityTypesRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ListSessionEntityTypesRequest";
                        };
    
                        return ListSessionEntityTypesRequest;
                    })();
    
                    v2beta1.ListSessionEntityTypesResponse = (function() {
    
                        /**
                         * Properties of a ListSessionEntityTypesResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IListSessionEntityTypesResponse
                         * @property {Array.<google.cloud.dialogflow.v2beta1.ISessionEntityType>|null} [sessionEntityTypes] ListSessionEntityTypesResponse sessionEntityTypes
                         * @property {string|null} [nextPageToken] ListSessionEntityTypesResponse nextPageToken
                         */
    
                        /**
                         * Constructs a new ListSessionEntityTypesResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a ListSessionEntityTypesResponse.
                         * @implements IListSessionEntityTypesResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IListSessionEntityTypesResponse=} [properties] Properties to set
                         */
                        function ListSessionEntityTypesResponse(properties) {
                            this.sessionEntityTypes = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListSessionEntityTypesResponse sessionEntityTypes.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.ISessionEntityType>} sessionEntityTypes
                         * @memberof google.cloud.dialogflow.v2beta1.ListSessionEntityTypesResponse
                         * @instance
                         */
                        ListSessionEntityTypesResponse.prototype.sessionEntityTypes = $util.emptyArray;
    
                        /**
                         * ListSessionEntityTypesResponse nextPageToken.
                         * @member {string} nextPageToken
                         * @memberof google.cloud.dialogflow.v2beta1.ListSessionEntityTypesResponse
                         * @instance
                         */
                        ListSessionEntityTypesResponse.prototype.nextPageToken = "";
    
                        /**
                         * Creates a new ListSessionEntityTypesResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.ListSessionEntityTypesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListSessionEntityTypesResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.ListSessionEntityTypesResponse} ListSessionEntityTypesResponse instance
                         */
                        ListSessionEntityTypesResponse.create = function create(properties) {
                            return new ListSessionEntityTypesResponse(properties);
                        };
    
                        /**
                         * Encodes the specified ListSessionEntityTypesResponse message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListSessionEntityTypesResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.ListSessionEntityTypesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListSessionEntityTypesResponse} message ListSessionEntityTypesResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListSessionEntityTypesResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.sessionEntityTypes != null && message.sessionEntityTypes.length)
                                for (var i = 0; i < message.sessionEntityTypes.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.SessionEntityType.encode(message.sessionEntityTypes[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.nextPageToken != null && Object.hasOwnProperty.call(message, "nextPageToken"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.nextPageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListSessionEntityTypesResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListSessionEntityTypesResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListSessionEntityTypesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListSessionEntityTypesResponse} message ListSessionEntityTypesResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListSessionEntityTypesResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListSessionEntityTypesResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.ListSessionEntityTypesResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.ListSessionEntityTypesResponse} ListSessionEntityTypesResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListSessionEntityTypesResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ListSessionEntityTypesResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.sessionEntityTypes && message.sessionEntityTypes.length))
                                            message.sessionEntityTypes = [];
                                        message.sessionEntityTypes.push($root.google.cloud.dialogflow.v2beta1.SessionEntityType.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 2: {
                                        message.nextPageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListSessionEntityTypesResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListSessionEntityTypesResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.ListSessionEntityTypesResponse} ListSessionEntityTypesResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListSessionEntityTypesResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListSessionEntityTypesResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.ListSessionEntityTypesResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListSessionEntityTypesResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.sessionEntityTypes != null && message.hasOwnProperty("sessionEntityTypes")) {
                                if (!Array.isArray(message.sessionEntityTypes))
                                    return "sessionEntityTypes: array expected";
                                for (var i = 0; i < message.sessionEntityTypes.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.SessionEntityType.verify(message.sessionEntityTypes[i]);
                                    if (error)
                                        return "sessionEntityTypes." + error;
                                }
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                if (!$util.isString(message.nextPageToken))
                                    return "nextPageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListSessionEntityTypesResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListSessionEntityTypesResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.ListSessionEntityTypesResponse} ListSessionEntityTypesResponse
                         */
                        ListSessionEntityTypesResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.ListSessionEntityTypesResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.ListSessionEntityTypesResponse();
                            if (object.sessionEntityTypes) {
                                if (!Array.isArray(object.sessionEntityTypes))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.ListSessionEntityTypesResponse.sessionEntityTypes: array expected");
                                message.sessionEntityTypes = [];
                                for (var i = 0; i < object.sessionEntityTypes.length; ++i) {
                                    if (typeof object.sessionEntityTypes[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.ListSessionEntityTypesResponse.sessionEntityTypes: object expected");
                                    message.sessionEntityTypes[i] = $root.google.cloud.dialogflow.v2beta1.SessionEntityType.fromObject(object.sessionEntityTypes[i]);
                                }
                            }
                            if (object.nextPageToken != null)
                                message.nextPageToken = String(object.nextPageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListSessionEntityTypesResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListSessionEntityTypesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ListSessionEntityTypesResponse} message ListSessionEntityTypesResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListSessionEntityTypesResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.sessionEntityTypes = [];
                            if (options.defaults)
                                object.nextPageToken = "";
                            if (message.sessionEntityTypes && message.sessionEntityTypes.length) {
                                object.sessionEntityTypes = [];
                                for (var j = 0; j < message.sessionEntityTypes.length; ++j)
                                    object.sessionEntityTypes[j] = $root.google.cloud.dialogflow.v2beta1.SessionEntityType.toObject(message.sessionEntityTypes[j], options);
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                object.nextPageToken = message.nextPageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListSessionEntityTypesResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.ListSessionEntityTypesResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListSessionEntityTypesResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListSessionEntityTypesResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.ListSessionEntityTypesResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListSessionEntityTypesResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ListSessionEntityTypesResponse";
                        };
    
                        return ListSessionEntityTypesResponse;
                    })();
    
                    v2beta1.GetSessionEntityTypeRequest = (function() {
    
                        /**
                         * Properties of a GetSessionEntityTypeRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IGetSessionEntityTypeRequest
                         * @property {string|null} [name] GetSessionEntityTypeRequest name
                         */
    
                        /**
                         * Constructs a new GetSessionEntityTypeRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a GetSessionEntityTypeRequest.
                         * @implements IGetSessionEntityTypeRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IGetSessionEntityTypeRequest=} [properties] Properties to set
                         */
                        function GetSessionEntityTypeRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GetSessionEntityTypeRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2beta1.GetSessionEntityTypeRequest
                         * @instance
                         */
                        GetSessionEntityTypeRequest.prototype.name = "";
    
                        /**
                         * Creates a new GetSessionEntityTypeRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.GetSessionEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetSessionEntityTypeRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.GetSessionEntityTypeRequest} GetSessionEntityTypeRequest instance
                         */
                        GetSessionEntityTypeRequest.create = function create(properties) {
                            return new GetSessionEntityTypeRequest(properties);
                        };
    
                        /**
                         * Encodes the specified GetSessionEntityTypeRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GetSessionEntityTypeRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.GetSessionEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetSessionEntityTypeRequest} message GetSessionEntityTypeRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetSessionEntityTypeRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GetSessionEntityTypeRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GetSessionEntityTypeRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GetSessionEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetSessionEntityTypeRequest} message GetSessionEntityTypeRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetSessionEntityTypeRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GetSessionEntityTypeRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.GetSessionEntityTypeRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.GetSessionEntityTypeRequest} GetSessionEntityTypeRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetSessionEntityTypeRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.GetSessionEntityTypeRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GetSessionEntityTypeRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GetSessionEntityTypeRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.GetSessionEntityTypeRequest} GetSessionEntityTypeRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetSessionEntityTypeRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GetSessionEntityTypeRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.GetSessionEntityTypeRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GetSessionEntityTypeRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a GetSessionEntityTypeRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.GetSessionEntityTypeRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.GetSessionEntityTypeRequest} GetSessionEntityTypeRequest
                         */
                        GetSessionEntityTypeRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.GetSessionEntityTypeRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.GetSessionEntityTypeRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GetSessionEntityTypeRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.GetSessionEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.GetSessionEntityTypeRequest} message GetSessionEntityTypeRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GetSessionEntityTypeRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.name = "";
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            return object;
                        };
    
                        /**
                         * Converts this GetSessionEntityTypeRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.GetSessionEntityTypeRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GetSessionEntityTypeRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GetSessionEntityTypeRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.GetSessionEntityTypeRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GetSessionEntityTypeRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.GetSessionEntityTypeRequest";
                        };
    
                        return GetSessionEntityTypeRequest;
                    })();
    
                    v2beta1.CreateSessionEntityTypeRequest = (function() {
    
                        /**
                         * Properties of a CreateSessionEntityTypeRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ICreateSessionEntityTypeRequest
                         * @property {string|null} [parent] CreateSessionEntityTypeRequest parent
                         * @property {google.cloud.dialogflow.v2beta1.ISessionEntityType|null} [sessionEntityType] CreateSessionEntityTypeRequest sessionEntityType
                         */
    
                        /**
                         * Constructs a new CreateSessionEntityTypeRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a CreateSessionEntityTypeRequest.
                         * @implements ICreateSessionEntityTypeRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ICreateSessionEntityTypeRequest=} [properties] Properties to set
                         */
                        function CreateSessionEntityTypeRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * CreateSessionEntityTypeRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.CreateSessionEntityTypeRequest
                         * @instance
                         */
                        CreateSessionEntityTypeRequest.prototype.parent = "";
    
                        /**
                         * CreateSessionEntityTypeRequest sessionEntityType.
                         * @member {google.cloud.dialogflow.v2beta1.ISessionEntityType|null|undefined} sessionEntityType
                         * @memberof google.cloud.dialogflow.v2beta1.CreateSessionEntityTypeRequest
                         * @instance
                         */
                        CreateSessionEntityTypeRequest.prototype.sessionEntityType = null;
    
                        /**
                         * Creates a new CreateSessionEntityTypeRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.CreateSessionEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ICreateSessionEntityTypeRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.CreateSessionEntityTypeRequest} CreateSessionEntityTypeRequest instance
                         */
                        CreateSessionEntityTypeRequest.create = function create(properties) {
                            return new CreateSessionEntityTypeRequest(properties);
                        };
    
                        /**
                         * Encodes the specified CreateSessionEntityTypeRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.CreateSessionEntityTypeRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.CreateSessionEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ICreateSessionEntityTypeRequest} message CreateSessionEntityTypeRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateSessionEntityTypeRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.sessionEntityType != null && Object.hasOwnProperty.call(message, "sessionEntityType"))
                                $root.google.cloud.dialogflow.v2beta1.SessionEntityType.encode(message.sessionEntityType, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified CreateSessionEntityTypeRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.CreateSessionEntityTypeRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.CreateSessionEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ICreateSessionEntityTypeRequest} message CreateSessionEntityTypeRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateSessionEntityTypeRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a CreateSessionEntityTypeRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.CreateSessionEntityTypeRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.CreateSessionEntityTypeRequest} CreateSessionEntityTypeRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateSessionEntityTypeRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.CreateSessionEntityTypeRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.sessionEntityType = $root.google.cloud.dialogflow.v2beta1.SessionEntityType.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a CreateSessionEntityTypeRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.CreateSessionEntityTypeRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.CreateSessionEntityTypeRequest} CreateSessionEntityTypeRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateSessionEntityTypeRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a CreateSessionEntityTypeRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.CreateSessionEntityTypeRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        CreateSessionEntityTypeRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.sessionEntityType != null && message.hasOwnProperty("sessionEntityType")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.SessionEntityType.verify(message.sessionEntityType);
                                if (error)
                                    return "sessionEntityType." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a CreateSessionEntityTypeRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.CreateSessionEntityTypeRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.CreateSessionEntityTypeRequest} CreateSessionEntityTypeRequest
                         */
                        CreateSessionEntityTypeRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.CreateSessionEntityTypeRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.CreateSessionEntityTypeRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.sessionEntityType != null) {
                                if (typeof object.sessionEntityType !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.CreateSessionEntityTypeRequest.sessionEntityType: object expected");
                                message.sessionEntityType = $root.google.cloud.dialogflow.v2beta1.SessionEntityType.fromObject(object.sessionEntityType);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a CreateSessionEntityTypeRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.CreateSessionEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.CreateSessionEntityTypeRequest} message CreateSessionEntityTypeRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        CreateSessionEntityTypeRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.sessionEntityType = null;
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.sessionEntityType != null && message.hasOwnProperty("sessionEntityType"))
                                object.sessionEntityType = $root.google.cloud.dialogflow.v2beta1.SessionEntityType.toObject(message.sessionEntityType, options);
                            return object;
                        };
    
                        /**
                         * Converts this CreateSessionEntityTypeRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.CreateSessionEntityTypeRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        CreateSessionEntityTypeRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for CreateSessionEntityTypeRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.CreateSessionEntityTypeRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        CreateSessionEntityTypeRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.CreateSessionEntityTypeRequest";
                        };
    
                        return CreateSessionEntityTypeRequest;
                    })();
    
                    v2beta1.UpdateSessionEntityTypeRequest = (function() {
    
                        /**
                         * Properties of an UpdateSessionEntityTypeRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IUpdateSessionEntityTypeRequest
                         * @property {google.cloud.dialogflow.v2beta1.ISessionEntityType|null} [sessionEntityType] UpdateSessionEntityTypeRequest sessionEntityType
                         * @property {google.protobuf.IFieldMask|null} [updateMask] UpdateSessionEntityTypeRequest updateMask
                         */
    
                        /**
                         * Constructs a new UpdateSessionEntityTypeRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an UpdateSessionEntityTypeRequest.
                         * @implements IUpdateSessionEntityTypeRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateSessionEntityTypeRequest=} [properties] Properties to set
                         */
                        function UpdateSessionEntityTypeRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * UpdateSessionEntityTypeRequest sessionEntityType.
                         * @member {google.cloud.dialogflow.v2beta1.ISessionEntityType|null|undefined} sessionEntityType
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateSessionEntityTypeRequest
                         * @instance
                         */
                        UpdateSessionEntityTypeRequest.prototype.sessionEntityType = null;
    
                        /**
                         * UpdateSessionEntityTypeRequest updateMask.
                         * @member {google.protobuf.IFieldMask|null|undefined} updateMask
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateSessionEntityTypeRequest
                         * @instance
                         */
                        UpdateSessionEntityTypeRequest.prototype.updateMask = null;
    
                        /**
                         * Creates a new UpdateSessionEntityTypeRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateSessionEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateSessionEntityTypeRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.UpdateSessionEntityTypeRequest} UpdateSessionEntityTypeRequest instance
                         */
                        UpdateSessionEntityTypeRequest.create = function create(properties) {
                            return new UpdateSessionEntityTypeRequest(properties);
                        };
    
                        /**
                         * Encodes the specified UpdateSessionEntityTypeRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.UpdateSessionEntityTypeRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateSessionEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateSessionEntityTypeRequest} message UpdateSessionEntityTypeRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UpdateSessionEntityTypeRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.sessionEntityType != null && Object.hasOwnProperty.call(message, "sessionEntityType"))
                                $root.google.cloud.dialogflow.v2beta1.SessionEntityType.encode(message.sessionEntityType, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.updateMask != null && Object.hasOwnProperty.call(message, "updateMask"))
                                $root.google.protobuf.FieldMask.encode(message.updateMask, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified UpdateSessionEntityTypeRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.UpdateSessionEntityTypeRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateSessionEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateSessionEntityTypeRequest} message UpdateSessionEntityTypeRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UpdateSessionEntityTypeRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an UpdateSessionEntityTypeRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateSessionEntityTypeRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.UpdateSessionEntityTypeRequest} UpdateSessionEntityTypeRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UpdateSessionEntityTypeRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.UpdateSessionEntityTypeRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.sessionEntityType = $root.google.cloud.dialogflow.v2beta1.SessionEntityType.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.updateMask = $root.google.protobuf.FieldMask.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an UpdateSessionEntityTypeRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateSessionEntityTypeRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.UpdateSessionEntityTypeRequest} UpdateSessionEntityTypeRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UpdateSessionEntityTypeRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an UpdateSessionEntityTypeRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateSessionEntityTypeRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        UpdateSessionEntityTypeRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.sessionEntityType != null && message.hasOwnProperty("sessionEntityType")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.SessionEntityType.verify(message.sessionEntityType);
                                if (error)
                                    return "sessionEntityType." + error;
                            }
                            if (message.updateMask != null && message.hasOwnProperty("updateMask")) {
                                var error = $root.google.protobuf.FieldMask.verify(message.updateMask);
                                if (error)
                                    return "updateMask." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates an UpdateSessionEntityTypeRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateSessionEntityTypeRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.UpdateSessionEntityTypeRequest} UpdateSessionEntityTypeRequest
                         */
                        UpdateSessionEntityTypeRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.UpdateSessionEntityTypeRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.UpdateSessionEntityTypeRequest();
                            if (object.sessionEntityType != null) {
                                if (typeof object.sessionEntityType !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.UpdateSessionEntityTypeRequest.sessionEntityType: object expected");
                                message.sessionEntityType = $root.google.cloud.dialogflow.v2beta1.SessionEntityType.fromObject(object.sessionEntityType);
                            }
                            if (object.updateMask != null) {
                                if (typeof object.updateMask !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.UpdateSessionEntityTypeRequest.updateMask: object expected");
                                message.updateMask = $root.google.protobuf.FieldMask.fromObject(object.updateMask);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an UpdateSessionEntityTypeRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateSessionEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.UpdateSessionEntityTypeRequest} message UpdateSessionEntityTypeRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        UpdateSessionEntityTypeRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.sessionEntityType = null;
                                object.updateMask = null;
                            }
                            if (message.sessionEntityType != null && message.hasOwnProperty("sessionEntityType"))
                                object.sessionEntityType = $root.google.cloud.dialogflow.v2beta1.SessionEntityType.toObject(message.sessionEntityType, options);
                            if (message.updateMask != null && message.hasOwnProperty("updateMask"))
                                object.updateMask = $root.google.protobuf.FieldMask.toObject(message.updateMask, options);
                            return object;
                        };
    
                        /**
                         * Converts this UpdateSessionEntityTypeRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateSessionEntityTypeRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        UpdateSessionEntityTypeRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for UpdateSessionEntityTypeRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateSessionEntityTypeRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        UpdateSessionEntityTypeRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.UpdateSessionEntityTypeRequest";
                        };
    
                        return UpdateSessionEntityTypeRequest;
                    })();
    
                    v2beta1.DeleteSessionEntityTypeRequest = (function() {
    
                        /**
                         * Properties of a DeleteSessionEntityTypeRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IDeleteSessionEntityTypeRequest
                         * @property {string|null} [name] DeleteSessionEntityTypeRequest name
                         */
    
                        /**
                         * Constructs a new DeleteSessionEntityTypeRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a DeleteSessionEntityTypeRequest.
                         * @implements IDeleteSessionEntityTypeRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteSessionEntityTypeRequest=} [properties] Properties to set
                         */
                        function DeleteSessionEntityTypeRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * DeleteSessionEntityTypeRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteSessionEntityTypeRequest
                         * @instance
                         */
                        DeleteSessionEntityTypeRequest.prototype.name = "";
    
                        /**
                         * Creates a new DeleteSessionEntityTypeRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteSessionEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteSessionEntityTypeRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.DeleteSessionEntityTypeRequest} DeleteSessionEntityTypeRequest instance
                         */
                        DeleteSessionEntityTypeRequest.create = function create(properties) {
                            return new DeleteSessionEntityTypeRequest(properties);
                        };
    
                        /**
                         * Encodes the specified DeleteSessionEntityTypeRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.DeleteSessionEntityTypeRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteSessionEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteSessionEntityTypeRequest} message DeleteSessionEntityTypeRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteSessionEntityTypeRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified DeleteSessionEntityTypeRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.DeleteSessionEntityTypeRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteSessionEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteSessionEntityTypeRequest} message DeleteSessionEntityTypeRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteSessionEntityTypeRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a DeleteSessionEntityTypeRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteSessionEntityTypeRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.DeleteSessionEntityTypeRequest} DeleteSessionEntityTypeRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteSessionEntityTypeRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.DeleteSessionEntityTypeRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a DeleteSessionEntityTypeRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteSessionEntityTypeRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.DeleteSessionEntityTypeRequest} DeleteSessionEntityTypeRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteSessionEntityTypeRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a DeleteSessionEntityTypeRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteSessionEntityTypeRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        DeleteSessionEntityTypeRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a DeleteSessionEntityTypeRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteSessionEntityTypeRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.DeleteSessionEntityTypeRequest} DeleteSessionEntityTypeRequest
                         */
                        DeleteSessionEntityTypeRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.DeleteSessionEntityTypeRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.DeleteSessionEntityTypeRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a DeleteSessionEntityTypeRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteSessionEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.DeleteSessionEntityTypeRequest} message DeleteSessionEntityTypeRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        DeleteSessionEntityTypeRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.name = "";
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            return object;
                        };
    
                        /**
                         * Converts this DeleteSessionEntityTypeRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteSessionEntityTypeRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        DeleteSessionEntityTypeRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for DeleteSessionEntityTypeRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteSessionEntityTypeRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        DeleteSessionEntityTypeRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.DeleteSessionEntityTypeRequest";
                        };
    
                        return DeleteSessionEntityTypeRequest;
                    })();
    
                    v2beta1.EntityTypes = (function() {
    
                        /**
                         * Constructs a new EntityTypes service.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an EntityTypes
                         * @extends $protobuf.rpc.Service
                         * @constructor
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         */
                        function EntityTypes(rpcImpl, requestDelimited, responseDelimited) {
                            $protobuf.rpc.Service.call(this, rpcImpl, requestDelimited, responseDelimited);
                        }
    
                        (EntityTypes.prototype = Object.create($protobuf.rpc.Service.prototype)).constructor = EntityTypes;
    
                        /**
                         * Creates new EntityTypes service using the specified rpc implementation.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.EntityTypes
                         * @static
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         * @returns {EntityTypes} RPC service. Useful where requests and/or responses are streamed.
                         */
                        EntityTypes.create = function create(rpcImpl, requestDelimited, responseDelimited) {
                            return new this(rpcImpl, requestDelimited, responseDelimited);
                        };
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.EntityTypes|listEntityTypes}.
                         * @memberof google.cloud.dialogflow.v2beta1.EntityTypes
                         * @typedef ListEntityTypesCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.ListEntityTypesResponse} [response] ListEntityTypesResponse
                         */
    
                        /**
                         * Calls ListEntityTypes.
                         * @function listEntityTypes
                         * @memberof google.cloud.dialogflow.v2beta1.EntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IListEntityTypesRequest} request ListEntityTypesRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.EntityTypes.ListEntityTypesCallback} callback Node-style callback called with the error, if any, and ListEntityTypesResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(EntityTypes.prototype.listEntityTypes = function listEntityTypes(request, callback) {
                            return this.rpcCall(listEntityTypes, $root.google.cloud.dialogflow.v2beta1.ListEntityTypesRequest, $root.google.cloud.dialogflow.v2beta1.ListEntityTypesResponse, request, callback);
                        }, "name", { value: "ListEntityTypes" });
    
                        /**
                         * Calls ListEntityTypes.
                         * @function listEntityTypes
                         * @memberof google.cloud.dialogflow.v2beta1.EntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IListEntityTypesRequest} request ListEntityTypesRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.ListEntityTypesResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.EntityTypes|getEntityType}.
                         * @memberof google.cloud.dialogflow.v2beta1.EntityTypes
                         * @typedef GetEntityTypeCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.EntityType} [response] EntityType
                         */
    
                        /**
                         * Calls GetEntityType.
                         * @function getEntityType
                         * @memberof google.cloud.dialogflow.v2beta1.EntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IGetEntityTypeRequest} request GetEntityTypeRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.EntityTypes.GetEntityTypeCallback} callback Node-style callback called with the error, if any, and EntityType
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(EntityTypes.prototype.getEntityType = function getEntityType(request, callback) {
                            return this.rpcCall(getEntityType, $root.google.cloud.dialogflow.v2beta1.GetEntityTypeRequest, $root.google.cloud.dialogflow.v2beta1.EntityType, request, callback);
                        }, "name", { value: "GetEntityType" });
    
                        /**
                         * Calls GetEntityType.
                         * @function getEntityType
                         * @memberof google.cloud.dialogflow.v2beta1.EntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IGetEntityTypeRequest} request GetEntityTypeRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.EntityType>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.EntityTypes|createEntityType}.
                         * @memberof google.cloud.dialogflow.v2beta1.EntityTypes
                         * @typedef CreateEntityTypeCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.EntityType} [response] EntityType
                         */
    
                        /**
                         * Calls CreateEntityType.
                         * @function createEntityType
                         * @memberof google.cloud.dialogflow.v2beta1.EntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.ICreateEntityTypeRequest} request CreateEntityTypeRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.EntityTypes.CreateEntityTypeCallback} callback Node-style callback called with the error, if any, and EntityType
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(EntityTypes.prototype.createEntityType = function createEntityType(request, callback) {
                            return this.rpcCall(createEntityType, $root.google.cloud.dialogflow.v2beta1.CreateEntityTypeRequest, $root.google.cloud.dialogflow.v2beta1.EntityType, request, callback);
                        }, "name", { value: "CreateEntityType" });
    
                        /**
                         * Calls CreateEntityType.
                         * @function createEntityType
                         * @memberof google.cloud.dialogflow.v2beta1.EntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.ICreateEntityTypeRequest} request CreateEntityTypeRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.EntityType>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.EntityTypes|updateEntityType}.
                         * @memberof google.cloud.dialogflow.v2beta1.EntityTypes
                         * @typedef UpdateEntityTypeCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.EntityType} [response] EntityType
                         */
    
                        /**
                         * Calls UpdateEntityType.
                         * @function updateEntityType
                         * @memberof google.cloud.dialogflow.v2beta1.EntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateEntityTypeRequest} request UpdateEntityTypeRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.EntityTypes.UpdateEntityTypeCallback} callback Node-style callback called with the error, if any, and EntityType
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(EntityTypes.prototype.updateEntityType = function updateEntityType(request, callback) {
                            return this.rpcCall(updateEntityType, $root.google.cloud.dialogflow.v2beta1.UpdateEntityTypeRequest, $root.google.cloud.dialogflow.v2beta1.EntityType, request, callback);
                        }, "name", { value: "UpdateEntityType" });
    
                        /**
                         * Calls UpdateEntityType.
                         * @function updateEntityType
                         * @memberof google.cloud.dialogflow.v2beta1.EntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateEntityTypeRequest} request UpdateEntityTypeRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.EntityType>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.EntityTypes|deleteEntityType}.
                         * @memberof google.cloud.dialogflow.v2beta1.EntityTypes
                         * @typedef DeleteEntityTypeCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.protobuf.Empty} [response] Empty
                         */
    
                        /**
                         * Calls DeleteEntityType.
                         * @function deleteEntityType
                         * @memberof google.cloud.dialogflow.v2beta1.EntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteEntityTypeRequest} request DeleteEntityTypeRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.EntityTypes.DeleteEntityTypeCallback} callback Node-style callback called with the error, if any, and Empty
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(EntityTypes.prototype.deleteEntityType = function deleteEntityType(request, callback) {
                            return this.rpcCall(deleteEntityType, $root.google.cloud.dialogflow.v2beta1.DeleteEntityTypeRequest, $root.google.protobuf.Empty, request, callback);
                        }, "name", { value: "DeleteEntityType" });
    
                        /**
                         * Calls DeleteEntityType.
                         * @function deleteEntityType
                         * @memberof google.cloud.dialogflow.v2beta1.EntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteEntityTypeRequest} request DeleteEntityTypeRequest message or plain object
                         * @returns {Promise<google.protobuf.Empty>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.EntityTypes|batchUpdateEntityTypes}.
                         * @memberof google.cloud.dialogflow.v2beta1.EntityTypes
                         * @typedef BatchUpdateEntityTypesCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.longrunning.Operation} [response] Operation
                         */
    
                        /**
                         * Calls BatchUpdateEntityTypes.
                         * @function batchUpdateEntityTypes
                         * @memberof google.cloud.dialogflow.v2beta1.EntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IBatchUpdateEntityTypesRequest} request BatchUpdateEntityTypesRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.EntityTypes.BatchUpdateEntityTypesCallback} callback Node-style callback called with the error, if any, and Operation
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(EntityTypes.prototype.batchUpdateEntityTypes = function batchUpdateEntityTypes(request, callback) {
                            return this.rpcCall(batchUpdateEntityTypes, $root.google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesRequest, $root.google.longrunning.Operation, request, callback);
                        }, "name", { value: "BatchUpdateEntityTypes" });
    
                        /**
                         * Calls BatchUpdateEntityTypes.
                         * @function batchUpdateEntityTypes
                         * @memberof google.cloud.dialogflow.v2beta1.EntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IBatchUpdateEntityTypesRequest} request BatchUpdateEntityTypesRequest message or plain object
                         * @returns {Promise<google.longrunning.Operation>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.EntityTypes|batchDeleteEntityTypes}.
                         * @memberof google.cloud.dialogflow.v2beta1.EntityTypes
                         * @typedef BatchDeleteEntityTypesCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.longrunning.Operation} [response] Operation
                         */
    
                        /**
                         * Calls BatchDeleteEntityTypes.
                         * @function batchDeleteEntityTypes
                         * @memberof google.cloud.dialogflow.v2beta1.EntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IBatchDeleteEntityTypesRequest} request BatchDeleteEntityTypesRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.EntityTypes.BatchDeleteEntityTypesCallback} callback Node-style callback called with the error, if any, and Operation
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(EntityTypes.prototype.batchDeleteEntityTypes = function batchDeleteEntityTypes(request, callback) {
                            return this.rpcCall(batchDeleteEntityTypes, $root.google.cloud.dialogflow.v2beta1.BatchDeleteEntityTypesRequest, $root.google.longrunning.Operation, request, callback);
                        }, "name", { value: "BatchDeleteEntityTypes" });
    
                        /**
                         * Calls BatchDeleteEntityTypes.
                         * @function batchDeleteEntityTypes
                         * @memberof google.cloud.dialogflow.v2beta1.EntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IBatchDeleteEntityTypesRequest} request BatchDeleteEntityTypesRequest message or plain object
                         * @returns {Promise<google.longrunning.Operation>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.EntityTypes|batchCreateEntities}.
                         * @memberof google.cloud.dialogflow.v2beta1.EntityTypes
                         * @typedef BatchCreateEntitiesCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.longrunning.Operation} [response] Operation
                         */
    
                        /**
                         * Calls BatchCreateEntities.
                         * @function batchCreateEntities
                         * @memberof google.cloud.dialogflow.v2beta1.EntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IBatchCreateEntitiesRequest} request BatchCreateEntitiesRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.EntityTypes.BatchCreateEntitiesCallback} callback Node-style callback called with the error, if any, and Operation
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(EntityTypes.prototype.batchCreateEntities = function batchCreateEntities(request, callback) {
                            return this.rpcCall(batchCreateEntities, $root.google.cloud.dialogflow.v2beta1.BatchCreateEntitiesRequest, $root.google.longrunning.Operation, request, callback);
                        }, "name", { value: "BatchCreateEntities" });
    
                        /**
                         * Calls BatchCreateEntities.
                         * @function batchCreateEntities
                         * @memberof google.cloud.dialogflow.v2beta1.EntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IBatchCreateEntitiesRequest} request BatchCreateEntitiesRequest message or plain object
                         * @returns {Promise<google.longrunning.Operation>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.EntityTypes|batchUpdateEntities}.
                         * @memberof google.cloud.dialogflow.v2beta1.EntityTypes
                         * @typedef BatchUpdateEntitiesCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.longrunning.Operation} [response] Operation
                         */
    
                        /**
                         * Calls BatchUpdateEntities.
                         * @function batchUpdateEntities
                         * @memberof google.cloud.dialogflow.v2beta1.EntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IBatchUpdateEntitiesRequest} request BatchUpdateEntitiesRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.EntityTypes.BatchUpdateEntitiesCallback} callback Node-style callback called with the error, if any, and Operation
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(EntityTypes.prototype.batchUpdateEntities = function batchUpdateEntities(request, callback) {
                            return this.rpcCall(batchUpdateEntities, $root.google.cloud.dialogflow.v2beta1.BatchUpdateEntitiesRequest, $root.google.longrunning.Operation, request, callback);
                        }, "name", { value: "BatchUpdateEntities" });
    
                        /**
                         * Calls BatchUpdateEntities.
                         * @function batchUpdateEntities
                         * @memberof google.cloud.dialogflow.v2beta1.EntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IBatchUpdateEntitiesRequest} request BatchUpdateEntitiesRequest message or plain object
                         * @returns {Promise<google.longrunning.Operation>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.EntityTypes|batchDeleteEntities}.
                         * @memberof google.cloud.dialogflow.v2beta1.EntityTypes
                         * @typedef BatchDeleteEntitiesCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.longrunning.Operation} [response] Operation
                         */
    
                        /**
                         * Calls BatchDeleteEntities.
                         * @function batchDeleteEntities
                         * @memberof google.cloud.dialogflow.v2beta1.EntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IBatchDeleteEntitiesRequest} request BatchDeleteEntitiesRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.EntityTypes.BatchDeleteEntitiesCallback} callback Node-style callback called with the error, if any, and Operation
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(EntityTypes.prototype.batchDeleteEntities = function batchDeleteEntities(request, callback) {
                            return this.rpcCall(batchDeleteEntities, $root.google.cloud.dialogflow.v2beta1.BatchDeleteEntitiesRequest, $root.google.longrunning.Operation, request, callback);
                        }, "name", { value: "BatchDeleteEntities" });
    
                        /**
                         * Calls BatchDeleteEntities.
                         * @function batchDeleteEntities
                         * @memberof google.cloud.dialogflow.v2beta1.EntityTypes
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IBatchDeleteEntitiesRequest} request BatchDeleteEntitiesRequest message or plain object
                         * @returns {Promise<google.longrunning.Operation>} Promise
                         * @variation 2
                         */
    
                        return EntityTypes;
                    })();
    
                    v2beta1.EntityType = (function() {
    
                        /**
                         * Properties of an EntityType.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IEntityType
                         * @property {string|null} [name] EntityType name
                         * @property {string|null} [displayName] EntityType displayName
                         * @property {google.cloud.dialogflow.v2beta1.EntityType.Kind|null} [kind] EntityType kind
                         * @property {google.cloud.dialogflow.v2beta1.EntityType.AutoExpansionMode|null} [autoExpansionMode] EntityType autoExpansionMode
                         * @property {Array.<google.cloud.dialogflow.v2beta1.EntityType.IEntity>|null} [entities] EntityType entities
                         * @property {boolean|null} [enableFuzzyExtraction] EntityType enableFuzzyExtraction
                         */
    
                        /**
                         * Constructs a new EntityType.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an EntityType.
                         * @implements IEntityType
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IEntityType=} [properties] Properties to set
                         */
                        function EntityType(properties) {
                            this.entities = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * EntityType name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2beta1.EntityType
                         * @instance
                         */
                        EntityType.prototype.name = "";
    
                        /**
                         * EntityType displayName.
                         * @member {string} displayName
                         * @memberof google.cloud.dialogflow.v2beta1.EntityType
                         * @instance
                         */
                        EntityType.prototype.displayName = "";
    
                        /**
                         * EntityType kind.
                         * @member {google.cloud.dialogflow.v2beta1.EntityType.Kind} kind
                         * @memberof google.cloud.dialogflow.v2beta1.EntityType
                         * @instance
                         */
                        EntityType.prototype.kind = 0;
    
                        /**
                         * EntityType autoExpansionMode.
                         * @member {google.cloud.dialogflow.v2beta1.EntityType.AutoExpansionMode} autoExpansionMode
                         * @memberof google.cloud.dialogflow.v2beta1.EntityType
                         * @instance
                         */
                        EntityType.prototype.autoExpansionMode = 0;
    
                        /**
                         * EntityType entities.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.EntityType.IEntity>} entities
                         * @memberof google.cloud.dialogflow.v2beta1.EntityType
                         * @instance
                         */
                        EntityType.prototype.entities = $util.emptyArray;
    
                        /**
                         * EntityType enableFuzzyExtraction.
                         * @member {boolean} enableFuzzyExtraction
                         * @memberof google.cloud.dialogflow.v2beta1.EntityType
                         * @instance
                         */
                        EntityType.prototype.enableFuzzyExtraction = false;
    
                        /**
                         * Creates a new EntityType instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.EntityType
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IEntityType=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.EntityType} EntityType instance
                         */
                        EntityType.create = function create(properties) {
                            return new EntityType(properties);
                        };
    
                        /**
                         * Encodes the specified EntityType message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.EntityType.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.EntityType
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IEntityType} message EntityType message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        EntityType.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            if (message.displayName != null && Object.hasOwnProperty.call(message, "displayName"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.displayName);
                            if (message.kind != null && Object.hasOwnProperty.call(message, "kind"))
                                writer.uint32(/* id 3, wireType 0 =*/24).int32(message.kind);
                            if (message.autoExpansionMode != null && Object.hasOwnProperty.call(message, "autoExpansionMode"))
                                writer.uint32(/* id 4, wireType 0 =*/32).int32(message.autoExpansionMode);
                            if (message.entities != null && message.entities.length)
                                for (var i = 0; i < message.entities.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.EntityType.Entity.encode(message.entities[i], writer.uint32(/* id 6, wireType 2 =*/50).fork()).ldelim();
                            if (message.enableFuzzyExtraction != null && Object.hasOwnProperty.call(message, "enableFuzzyExtraction"))
                                writer.uint32(/* id 7, wireType 0 =*/56).bool(message.enableFuzzyExtraction);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified EntityType message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.EntityType.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.EntityType
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IEntityType} message EntityType message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        EntityType.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an EntityType message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.EntityType
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.EntityType} EntityType
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        EntityType.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.EntityType();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.displayName = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.kind = reader.int32();
                                        break;
                                    }
                                case 4: {
                                        message.autoExpansionMode = reader.int32();
                                        break;
                                    }
                                case 6: {
                                        if (!(message.entities && message.entities.length))
                                            message.entities = [];
                                        message.entities.push($root.google.cloud.dialogflow.v2beta1.EntityType.Entity.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 7: {
                                        message.enableFuzzyExtraction = reader.bool();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an EntityType message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.EntityType
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.EntityType} EntityType
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        EntityType.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an EntityType message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.EntityType
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        EntityType.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            if (message.displayName != null && message.hasOwnProperty("displayName"))
                                if (!$util.isString(message.displayName))
                                    return "displayName: string expected";
                            if (message.kind != null && message.hasOwnProperty("kind"))
                                switch (message.kind) {
                                default:
                                    return "kind: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                    break;
                                }
                            if (message.autoExpansionMode != null && message.hasOwnProperty("autoExpansionMode"))
                                switch (message.autoExpansionMode) {
                                default:
                                    return "autoExpansionMode: enum value expected";
                                case 0:
                                case 1:
                                    break;
                                }
                            if (message.entities != null && message.hasOwnProperty("entities")) {
                                if (!Array.isArray(message.entities))
                                    return "entities: array expected";
                                for (var i = 0; i < message.entities.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.EntityType.Entity.verify(message.entities[i]);
                                    if (error)
                                        return "entities." + error;
                                }
                            }
                            if (message.enableFuzzyExtraction != null && message.hasOwnProperty("enableFuzzyExtraction"))
                                if (typeof message.enableFuzzyExtraction !== "boolean")
                                    return "enableFuzzyExtraction: boolean expected";
                            return null;
                        };
    
                        /**
                         * Creates an EntityType message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.EntityType
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.EntityType} EntityType
                         */
                        EntityType.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.EntityType)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.EntityType();
                            if (object.name != null)
                                message.name = String(object.name);
                            if (object.displayName != null)
                                message.displayName = String(object.displayName);
                            switch (object.kind) {
                            default:
                                if (typeof object.kind === "number") {
                                    message.kind = object.kind;
                                    break;
                                }
                                break;
                            case "KIND_UNSPECIFIED":
                            case 0:
                                message.kind = 0;
                                break;
                            case "KIND_MAP":
                            case 1:
                                message.kind = 1;
                                break;
                            case "KIND_LIST":
                            case 2:
                                message.kind = 2;
                                break;
                            case "KIND_REGEXP":
                            case 3:
                                message.kind = 3;
                                break;
                            }
                            switch (object.autoExpansionMode) {
                            default:
                                if (typeof object.autoExpansionMode === "number") {
                                    message.autoExpansionMode = object.autoExpansionMode;
                                    break;
                                }
                                break;
                            case "AUTO_EXPANSION_MODE_UNSPECIFIED":
                            case 0:
                                message.autoExpansionMode = 0;
                                break;
                            case "AUTO_EXPANSION_MODE_DEFAULT":
                            case 1:
                                message.autoExpansionMode = 1;
                                break;
                            }
                            if (object.entities) {
                                if (!Array.isArray(object.entities))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.EntityType.entities: array expected");
                                message.entities = [];
                                for (var i = 0; i < object.entities.length; ++i) {
                                    if (typeof object.entities[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.EntityType.entities: object expected");
                                    message.entities[i] = $root.google.cloud.dialogflow.v2beta1.EntityType.Entity.fromObject(object.entities[i]);
                                }
                            }
                            if (object.enableFuzzyExtraction != null)
                                message.enableFuzzyExtraction = Boolean(object.enableFuzzyExtraction);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an EntityType message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.EntityType
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.EntityType} message EntityType
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        EntityType.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.entities = [];
                            if (options.defaults) {
                                object.name = "";
                                object.displayName = "";
                                object.kind = options.enums === String ? "KIND_UNSPECIFIED" : 0;
                                object.autoExpansionMode = options.enums === String ? "AUTO_EXPANSION_MODE_UNSPECIFIED" : 0;
                                object.enableFuzzyExtraction = false;
                            }
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            if (message.displayName != null && message.hasOwnProperty("displayName"))
                                object.displayName = message.displayName;
                            if (message.kind != null && message.hasOwnProperty("kind"))
                                object.kind = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.EntityType.Kind[message.kind] === undefined ? message.kind : $root.google.cloud.dialogflow.v2beta1.EntityType.Kind[message.kind] : message.kind;
                            if (message.autoExpansionMode != null && message.hasOwnProperty("autoExpansionMode"))
                                object.autoExpansionMode = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.EntityType.AutoExpansionMode[message.autoExpansionMode] === undefined ? message.autoExpansionMode : $root.google.cloud.dialogflow.v2beta1.EntityType.AutoExpansionMode[message.autoExpansionMode] : message.autoExpansionMode;
                            if (message.entities && message.entities.length) {
                                object.entities = [];
                                for (var j = 0; j < message.entities.length; ++j)
                                    object.entities[j] = $root.google.cloud.dialogflow.v2beta1.EntityType.Entity.toObject(message.entities[j], options);
                            }
                            if (message.enableFuzzyExtraction != null && message.hasOwnProperty("enableFuzzyExtraction"))
                                object.enableFuzzyExtraction = message.enableFuzzyExtraction;
                            return object;
                        };
    
                        /**
                         * Converts this EntityType to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.EntityType
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        EntityType.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for EntityType
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.EntityType
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        EntityType.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.EntityType";
                        };
    
                        /**
                         * Kind enum.
                         * @name google.cloud.dialogflow.v2beta1.EntityType.Kind
                         * @enum {number}
                         * @property {number} KIND_UNSPECIFIED=0 KIND_UNSPECIFIED value
                         * @property {number} KIND_MAP=1 KIND_MAP value
                         * @property {number} KIND_LIST=2 KIND_LIST value
                         * @property {number} KIND_REGEXP=3 KIND_REGEXP value
                         */
                        EntityType.Kind = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "KIND_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "KIND_MAP"] = 1;
                            values[valuesById[2] = "KIND_LIST"] = 2;
                            values[valuesById[3] = "KIND_REGEXP"] = 3;
                            return values;
                        })();
    
                        /**
                         * AutoExpansionMode enum.
                         * @name google.cloud.dialogflow.v2beta1.EntityType.AutoExpansionMode
                         * @enum {number}
                         * @property {number} AUTO_EXPANSION_MODE_UNSPECIFIED=0 AUTO_EXPANSION_MODE_UNSPECIFIED value
                         * @property {number} AUTO_EXPANSION_MODE_DEFAULT=1 AUTO_EXPANSION_MODE_DEFAULT value
                         */
                        EntityType.AutoExpansionMode = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "AUTO_EXPANSION_MODE_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "AUTO_EXPANSION_MODE_DEFAULT"] = 1;
                            return values;
                        })();
    
                        EntityType.Entity = (function() {
    
                            /**
                             * Properties of an Entity.
                             * @memberof google.cloud.dialogflow.v2beta1.EntityType
                             * @interface IEntity
                             * @property {string|null} [value] Entity value
                             * @property {Array.<string>|null} [synonyms] Entity synonyms
                             */
    
                            /**
                             * Constructs a new Entity.
                             * @memberof google.cloud.dialogflow.v2beta1.EntityType
                             * @classdesc Represents an Entity.
                             * @implements IEntity
                             * @constructor
                             * @param {google.cloud.dialogflow.v2beta1.EntityType.IEntity=} [properties] Properties to set
                             */
                            function Entity(properties) {
                                this.synonyms = [];
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * Entity value.
                             * @member {string} value
                             * @memberof google.cloud.dialogflow.v2beta1.EntityType.Entity
                             * @instance
                             */
                            Entity.prototype.value = "";
    
                            /**
                             * Entity synonyms.
                             * @member {Array.<string>} synonyms
                             * @memberof google.cloud.dialogflow.v2beta1.EntityType.Entity
                             * @instance
                             */
                            Entity.prototype.synonyms = $util.emptyArray;
    
                            /**
                             * Creates a new Entity instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2beta1.EntityType.Entity
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.EntityType.IEntity=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2beta1.EntityType.Entity} Entity instance
                             */
                            Entity.create = function create(properties) {
                                return new Entity(properties);
                            };
    
                            /**
                             * Encodes the specified Entity message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.EntityType.Entity.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2beta1.EntityType.Entity
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.EntityType.IEntity} message Entity message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            Entity.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.value != null && Object.hasOwnProperty.call(message, "value"))
                                    writer.uint32(/* id 1, wireType 2 =*/10).string(message.value);
                                if (message.synonyms != null && message.synonyms.length)
                                    for (var i = 0; i < message.synonyms.length; ++i)
                                        writer.uint32(/* id 2, wireType 2 =*/18).string(message.synonyms[i]);
                                return writer;
                            };
    
                            /**
                             * Encodes the specified Entity message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.EntityType.Entity.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.EntityType.Entity
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.EntityType.IEntity} message Entity message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            Entity.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes an Entity message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2beta1.EntityType.Entity
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2beta1.EntityType.Entity} Entity
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            Entity.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.EntityType.Entity();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.value = reader.string();
                                            break;
                                        }
                                    case 2: {
                                            if (!(message.synonyms && message.synonyms.length))
                                                message.synonyms = [];
                                            message.synonyms.push(reader.string());
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes an Entity message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.EntityType.Entity
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2beta1.EntityType.Entity} Entity
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            Entity.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies an Entity message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2beta1.EntityType.Entity
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            Entity.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.value != null && message.hasOwnProperty("value"))
                                    if (!$util.isString(message.value))
                                        return "value: string expected";
                                if (message.synonyms != null && message.hasOwnProperty("synonyms")) {
                                    if (!Array.isArray(message.synonyms))
                                        return "synonyms: array expected";
                                    for (var i = 0; i < message.synonyms.length; ++i)
                                        if (!$util.isString(message.synonyms[i]))
                                            return "synonyms: string[] expected";
                                }
                                return null;
                            };
    
                            /**
                             * Creates an Entity message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2beta1.EntityType.Entity
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2beta1.EntityType.Entity} Entity
                             */
                            Entity.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2beta1.EntityType.Entity)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2beta1.EntityType.Entity();
                                if (object.value != null)
                                    message.value = String(object.value);
                                if (object.synonyms) {
                                    if (!Array.isArray(object.synonyms))
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.EntityType.Entity.synonyms: array expected");
                                    message.synonyms = [];
                                    for (var i = 0; i < object.synonyms.length; ++i)
                                        message.synonyms[i] = String(object.synonyms[i]);
                                }
                                return message;
                            };
    
                            /**
                             * Creates a plain object from an Entity message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2beta1.EntityType.Entity
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.EntityType.Entity} message Entity
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            Entity.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.arrays || options.defaults)
                                    object.synonyms = [];
                                if (options.defaults)
                                    object.value = "";
                                if (message.value != null && message.hasOwnProperty("value"))
                                    object.value = message.value;
                                if (message.synonyms && message.synonyms.length) {
                                    object.synonyms = [];
                                    for (var j = 0; j < message.synonyms.length; ++j)
                                        object.synonyms[j] = message.synonyms[j];
                                }
                                return object;
                            };
    
                            /**
                             * Converts this Entity to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2beta1.EntityType.Entity
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            Entity.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for Entity
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2beta1.EntityType.Entity
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            Entity.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.EntityType.Entity";
                            };
    
                            return Entity;
                        })();
    
                        return EntityType;
                    })();
    
                    v2beta1.ListEntityTypesRequest = (function() {
    
                        /**
                         * Properties of a ListEntityTypesRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IListEntityTypesRequest
                         * @property {string|null} [parent] ListEntityTypesRequest parent
                         * @property {string|null} [languageCode] ListEntityTypesRequest languageCode
                         * @property {number|null} [pageSize] ListEntityTypesRequest pageSize
                         * @property {string|null} [pageToken] ListEntityTypesRequest pageToken
                         */
    
                        /**
                         * Constructs a new ListEntityTypesRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a ListEntityTypesRequest.
                         * @implements IListEntityTypesRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IListEntityTypesRequest=} [properties] Properties to set
                         */
                        function ListEntityTypesRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListEntityTypesRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.ListEntityTypesRequest
                         * @instance
                         */
                        ListEntityTypesRequest.prototype.parent = "";
    
                        /**
                         * ListEntityTypesRequest languageCode.
                         * @member {string} languageCode
                         * @memberof google.cloud.dialogflow.v2beta1.ListEntityTypesRequest
                         * @instance
                         */
                        ListEntityTypesRequest.prototype.languageCode = "";
    
                        /**
                         * ListEntityTypesRequest pageSize.
                         * @member {number} pageSize
                         * @memberof google.cloud.dialogflow.v2beta1.ListEntityTypesRequest
                         * @instance
                         */
                        ListEntityTypesRequest.prototype.pageSize = 0;
    
                        /**
                         * ListEntityTypesRequest pageToken.
                         * @member {string} pageToken
                         * @memberof google.cloud.dialogflow.v2beta1.ListEntityTypesRequest
                         * @instance
                         */
                        ListEntityTypesRequest.prototype.pageToken = "";
    
                        /**
                         * Creates a new ListEntityTypesRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.ListEntityTypesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListEntityTypesRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.ListEntityTypesRequest} ListEntityTypesRequest instance
                         */
                        ListEntityTypesRequest.create = function create(properties) {
                            return new ListEntityTypesRequest(properties);
                        };
    
                        /**
                         * Encodes the specified ListEntityTypesRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListEntityTypesRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.ListEntityTypesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListEntityTypesRequest} message ListEntityTypesRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListEntityTypesRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.languageCode != null && Object.hasOwnProperty.call(message, "languageCode"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.languageCode);
                            if (message.pageSize != null && Object.hasOwnProperty.call(message, "pageSize"))
                                writer.uint32(/* id 3, wireType 0 =*/24).int32(message.pageSize);
                            if (message.pageToken != null && Object.hasOwnProperty.call(message, "pageToken"))
                                writer.uint32(/* id 4, wireType 2 =*/34).string(message.pageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListEntityTypesRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListEntityTypesRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListEntityTypesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListEntityTypesRequest} message ListEntityTypesRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListEntityTypesRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListEntityTypesRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.ListEntityTypesRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.ListEntityTypesRequest} ListEntityTypesRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListEntityTypesRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ListEntityTypesRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.languageCode = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.pageSize = reader.int32();
                                        break;
                                    }
                                case 4: {
                                        message.pageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListEntityTypesRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListEntityTypesRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.ListEntityTypesRequest} ListEntityTypesRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListEntityTypesRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListEntityTypesRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.ListEntityTypesRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListEntityTypesRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                if (!$util.isString(message.languageCode))
                                    return "languageCode: string expected";
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                if (!$util.isInteger(message.pageSize))
                                    return "pageSize: integer expected";
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                if (!$util.isString(message.pageToken))
                                    return "pageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListEntityTypesRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListEntityTypesRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.ListEntityTypesRequest} ListEntityTypesRequest
                         */
                        ListEntityTypesRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.ListEntityTypesRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.ListEntityTypesRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.languageCode != null)
                                message.languageCode = String(object.languageCode);
                            if (object.pageSize != null)
                                message.pageSize = object.pageSize | 0;
                            if (object.pageToken != null)
                                message.pageToken = String(object.pageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListEntityTypesRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListEntityTypesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ListEntityTypesRequest} message ListEntityTypesRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListEntityTypesRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.languageCode = "";
                                object.pageSize = 0;
                                object.pageToken = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                object.languageCode = message.languageCode;
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                object.pageSize = message.pageSize;
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                object.pageToken = message.pageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListEntityTypesRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.ListEntityTypesRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListEntityTypesRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListEntityTypesRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.ListEntityTypesRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListEntityTypesRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ListEntityTypesRequest";
                        };
    
                        return ListEntityTypesRequest;
                    })();
    
                    v2beta1.ListEntityTypesResponse = (function() {
    
                        /**
                         * Properties of a ListEntityTypesResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IListEntityTypesResponse
                         * @property {Array.<google.cloud.dialogflow.v2beta1.IEntityType>|null} [entityTypes] ListEntityTypesResponse entityTypes
                         * @property {string|null} [nextPageToken] ListEntityTypesResponse nextPageToken
                         */
    
                        /**
                         * Constructs a new ListEntityTypesResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a ListEntityTypesResponse.
                         * @implements IListEntityTypesResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IListEntityTypesResponse=} [properties] Properties to set
                         */
                        function ListEntityTypesResponse(properties) {
                            this.entityTypes = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListEntityTypesResponse entityTypes.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.IEntityType>} entityTypes
                         * @memberof google.cloud.dialogflow.v2beta1.ListEntityTypesResponse
                         * @instance
                         */
                        ListEntityTypesResponse.prototype.entityTypes = $util.emptyArray;
    
                        /**
                         * ListEntityTypesResponse nextPageToken.
                         * @member {string} nextPageToken
                         * @memberof google.cloud.dialogflow.v2beta1.ListEntityTypesResponse
                         * @instance
                         */
                        ListEntityTypesResponse.prototype.nextPageToken = "";
    
                        /**
                         * Creates a new ListEntityTypesResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.ListEntityTypesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListEntityTypesResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.ListEntityTypesResponse} ListEntityTypesResponse instance
                         */
                        ListEntityTypesResponse.create = function create(properties) {
                            return new ListEntityTypesResponse(properties);
                        };
    
                        /**
                         * Encodes the specified ListEntityTypesResponse message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListEntityTypesResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.ListEntityTypesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListEntityTypesResponse} message ListEntityTypesResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListEntityTypesResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.entityTypes != null && message.entityTypes.length)
                                for (var i = 0; i < message.entityTypes.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.EntityType.encode(message.entityTypes[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.nextPageToken != null && Object.hasOwnProperty.call(message, "nextPageToken"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.nextPageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListEntityTypesResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListEntityTypesResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListEntityTypesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListEntityTypesResponse} message ListEntityTypesResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListEntityTypesResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListEntityTypesResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.ListEntityTypesResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.ListEntityTypesResponse} ListEntityTypesResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListEntityTypesResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ListEntityTypesResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.entityTypes && message.entityTypes.length))
                                            message.entityTypes = [];
                                        message.entityTypes.push($root.google.cloud.dialogflow.v2beta1.EntityType.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 2: {
                                        message.nextPageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListEntityTypesResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListEntityTypesResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.ListEntityTypesResponse} ListEntityTypesResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListEntityTypesResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListEntityTypesResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.ListEntityTypesResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListEntityTypesResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.entityTypes != null && message.hasOwnProperty("entityTypes")) {
                                if (!Array.isArray(message.entityTypes))
                                    return "entityTypes: array expected";
                                for (var i = 0; i < message.entityTypes.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.EntityType.verify(message.entityTypes[i]);
                                    if (error)
                                        return "entityTypes." + error;
                                }
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                if (!$util.isString(message.nextPageToken))
                                    return "nextPageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListEntityTypesResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListEntityTypesResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.ListEntityTypesResponse} ListEntityTypesResponse
                         */
                        ListEntityTypesResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.ListEntityTypesResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.ListEntityTypesResponse();
                            if (object.entityTypes) {
                                if (!Array.isArray(object.entityTypes))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.ListEntityTypesResponse.entityTypes: array expected");
                                message.entityTypes = [];
                                for (var i = 0; i < object.entityTypes.length; ++i) {
                                    if (typeof object.entityTypes[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.ListEntityTypesResponse.entityTypes: object expected");
                                    message.entityTypes[i] = $root.google.cloud.dialogflow.v2beta1.EntityType.fromObject(object.entityTypes[i]);
                                }
                            }
                            if (object.nextPageToken != null)
                                message.nextPageToken = String(object.nextPageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListEntityTypesResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListEntityTypesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ListEntityTypesResponse} message ListEntityTypesResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListEntityTypesResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.entityTypes = [];
                            if (options.defaults)
                                object.nextPageToken = "";
                            if (message.entityTypes && message.entityTypes.length) {
                                object.entityTypes = [];
                                for (var j = 0; j < message.entityTypes.length; ++j)
                                    object.entityTypes[j] = $root.google.cloud.dialogflow.v2beta1.EntityType.toObject(message.entityTypes[j], options);
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                object.nextPageToken = message.nextPageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListEntityTypesResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.ListEntityTypesResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListEntityTypesResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListEntityTypesResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.ListEntityTypesResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListEntityTypesResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ListEntityTypesResponse";
                        };
    
                        return ListEntityTypesResponse;
                    })();
    
                    v2beta1.GetEntityTypeRequest = (function() {
    
                        /**
                         * Properties of a GetEntityTypeRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IGetEntityTypeRequest
                         * @property {string|null} [name] GetEntityTypeRequest name
                         * @property {string|null} [languageCode] GetEntityTypeRequest languageCode
                         */
    
                        /**
                         * Constructs a new GetEntityTypeRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a GetEntityTypeRequest.
                         * @implements IGetEntityTypeRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IGetEntityTypeRequest=} [properties] Properties to set
                         */
                        function GetEntityTypeRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GetEntityTypeRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2beta1.GetEntityTypeRequest
                         * @instance
                         */
                        GetEntityTypeRequest.prototype.name = "";
    
                        /**
                         * GetEntityTypeRequest languageCode.
                         * @member {string} languageCode
                         * @memberof google.cloud.dialogflow.v2beta1.GetEntityTypeRequest
                         * @instance
                         */
                        GetEntityTypeRequest.prototype.languageCode = "";
    
                        /**
                         * Creates a new GetEntityTypeRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.GetEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetEntityTypeRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.GetEntityTypeRequest} GetEntityTypeRequest instance
                         */
                        GetEntityTypeRequest.create = function create(properties) {
                            return new GetEntityTypeRequest(properties);
                        };
    
                        /**
                         * Encodes the specified GetEntityTypeRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GetEntityTypeRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.GetEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetEntityTypeRequest} message GetEntityTypeRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetEntityTypeRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            if (message.languageCode != null && Object.hasOwnProperty.call(message, "languageCode"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.languageCode);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GetEntityTypeRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GetEntityTypeRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GetEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetEntityTypeRequest} message GetEntityTypeRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetEntityTypeRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GetEntityTypeRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.GetEntityTypeRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.GetEntityTypeRequest} GetEntityTypeRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetEntityTypeRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.GetEntityTypeRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.languageCode = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GetEntityTypeRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GetEntityTypeRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.GetEntityTypeRequest} GetEntityTypeRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetEntityTypeRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GetEntityTypeRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.GetEntityTypeRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GetEntityTypeRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                if (!$util.isString(message.languageCode))
                                    return "languageCode: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a GetEntityTypeRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.GetEntityTypeRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.GetEntityTypeRequest} GetEntityTypeRequest
                         */
                        GetEntityTypeRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.GetEntityTypeRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.GetEntityTypeRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            if (object.languageCode != null)
                                message.languageCode = String(object.languageCode);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GetEntityTypeRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.GetEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.GetEntityTypeRequest} message GetEntityTypeRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GetEntityTypeRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.name = "";
                                object.languageCode = "";
                            }
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                object.languageCode = message.languageCode;
                            return object;
                        };
    
                        /**
                         * Converts this GetEntityTypeRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.GetEntityTypeRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GetEntityTypeRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GetEntityTypeRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.GetEntityTypeRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GetEntityTypeRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.GetEntityTypeRequest";
                        };
    
                        return GetEntityTypeRequest;
                    })();
    
                    v2beta1.CreateEntityTypeRequest = (function() {
    
                        /**
                         * Properties of a CreateEntityTypeRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ICreateEntityTypeRequest
                         * @property {string|null} [parent] CreateEntityTypeRequest parent
                         * @property {google.cloud.dialogflow.v2beta1.IEntityType|null} [entityType] CreateEntityTypeRequest entityType
                         * @property {string|null} [languageCode] CreateEntityTypeRequest languageCode
                         */
    
                        /**
                         * Constructs a new CreateEntityTypeRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a CreateEntityTypeRequest.
                         * @implements ICreateEntityTypeRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ICreateEntityTypeRequest=} [properties] Properties to set
                         */
                        function CreateEntityTypeRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * CreateEntityTypeRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.CreateEntityTypeRequest
                         * @instance
                         */
                        CreateEntityTypeRequest.prototype.parent = "";
    
                        /**
                         * CreateEntityTypeRequest entityType.
                         * @member {google.cloud.dialogflow.v2beta1.IEntityType|null|undefined} entityType
                         * @memberof google.cloud.dialogflow.v2beta1.CreateEntityTypeRequest
                         * @instance
                         */
                        CreateEntityTypeRequest.prototype.entityType = null;
    
                        /**
                         * CreateEntityTypeRequest languageCode.
                         * @member {string} languageCode
                         * @memberof google.cloud.dialogflow.v2beta1.CreateEntityTypeRequest
                         * @instance
                         */
                        CreateEntityTypeRequest.prototype.languageCode = "";
    
                        /**
                         * Creates a new CreateEntityTypeRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.CreateEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ICreateEntityTypeRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.CreateEntityTypeRequest} CreateEntityTypeRequest instance
                         */
                        CreateEntityTypeRequest.create = function create(properties) {
                            return new CreateEntityTypeRequest(properties);
                        };
    
                        /**
                         * Encodes the specified CreateEntityTypeRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.CreateEntityTypeRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.CreateEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ICreateEntityTypeRequest} message CreateEntityTypeRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateEntityTypeRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.entityType != null && Object.hasOwnProperty.call(message, "entityType"))
                                $root.google.cloud.dialogflow.v2beta1.EntityType.encode(message.entityType, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.languageCode != null && Object.hasOwnProperty.call(message, "languageCode"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.languageCode);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified CreateEntityTypeRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.CreateEntityTypeRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.CreateEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ICreateEntityTypeRequest} message CreateEntityTypeRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateEntityTypeRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a CreateEntityTypeRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.CreateEntityTypeRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.CreateEntityTypeRequest} CreateEntityTypeRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateEntityTypeRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.CreateEntityTypeRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.entityType = $root.google.cloud.dialogflow.v2beta1.EntityType.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 3: {
                                        message.languageCode = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a CreateEntityTypeRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.CreateEntityTypeRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.CreateEntityTypeRequest} CreateEntityTypeRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateEntityTypeRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a CreateEntityTypeRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.CreateEntityTypeRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        CreateEntityTypeRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.entityType != null && message.hasOwnProperty("entityType")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.EntityType.verify(message.entityType);
                                if (error)
                                    return "entityType." + error;
                            }
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                if (!$util.isString(message.languageCode))
                                    return "languageCode: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a CreateEntityTypeRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.CreateEntityTypeRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.CreateEntityTypeRequest} CreateEntityTypeRequest
                         */
                        CreateEntityTypeRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.CreateEntityTypeRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.CreateEntityTypeRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.entityType != null) {
                                if (typeof object.entityType !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.CreateEntityTypeRequest.entityType: object expected");
                                message.entityType = $root.google.cloud.dialogflow.v2beta1.EntityType.fromObject(object.entityType);
                            }
                            if (object.languageCode != null)
                                message.languageCode = String(object.languageCode);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a CreateEntityTypeRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.CreateEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.CreateEntityTypeRequest} message CreateEntityTypeRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        CreateEntityTypeRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.entityType = null;
                                object.languageCode = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.entityType != null && message.hasOwnProperty("entityType"))
                                object.entityType = $root.google.cloud.dialogflow.v2beta1.EntityType.toObject(message.entityType, options);
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                object.languageCode = message.languageCode;
                            return object;
                        };
    
                        /**
                         * Converts this CreateEntityTypeRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.CreateEntityTypeRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        CreateEntityTypeRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for CreateEntityTypeRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.CreateEntityTypeRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        CreateEntityTypeRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.CreateEntityTypeRequest";
                        };
    
                        return CreateEntityTypeRequest;
                    })();
    
                    v2beta1.UpdateEntityTypeRequest = (function() {
    
                        /**
                         * Properties of an UpdateEntityTypeRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IUpdateEntityTypeRequest
                         * @property {google.cloud.dialogflow.v2beta1.IEntityType|null} [entityType] UpdateEntityTypeRequest entityType
                         * @property {string|null} [languageCode] UpdateEntityTypeRequest languageCode
                         * @property {google.protobuf.IFieldMask|null} [updateMask] UpdateEntityTypeRequest updateMask
                         */
    
                        /**
                         * Constructs a new UpdateEntityTypeRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an UpdateEntityTypeRequest.
                         * @implements IUpdateEntityTypeRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateEntityTypeRequest=} [properties] Properties to set
                         */
                        function UpdateEntityTypeRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * UpdateEntityTypeRequest entityType.
                         * @member {google.cloud.dialogflow.v2beta1.IEntityType|null|undefined} entityType
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateEntityTypeRequest
                         * @instance
                         */
                        UpdateEntityTypeRequest.prototype.entityType = null;
    
                        /**
                         * UpdateEntityTypeRequest languageCode.
                         * @member {string} languageCode
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateEntityTypeRequest
                         * @instance
                         */
                        UpdateEntityTypeRequest.prototype.languageCode = "";
    
                        /**
                         * UpdateEntityTypeRequest updateMask.
                         * @member {google.protobuf.IFieldMask|null|undefined} updateMask
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateEntityTypeRequest
                         * @instance
                         */
                        UpdateEntityTypeRequest.prototype.updateMask = null;
    
                        /**
                         * Creates a new UpdateEntityTypeRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateEntityTypeRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.UpdateEntityTypeRequest} UpdateEntityTypeRequest instance
                         */
                        UpdateEntityTypeRequest.create = function create(properties) {
                            return new UpdateEntityTypeRequest(properties);
                        };
    
                        /**
                         * Encodes the specified UpdateEntityTypeRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.UpdateEntityTypeRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateEntityTypeRequest} message UpdateEntityTypeRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UpdateEntityTypeRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.entityType != null && Object.hasOwnProperty.call(message, "entityType"))
                                $root.google.cloud.dialogflow.v2beta1.EntityType.encode(message.entityType, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.languageCode != null && Object.hasOwnProperty.call(message, "languageCode"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.languageCode);
                            if (message.updateMask != null && Object.hasOwnProperty.call(message, "updateMask"))
                                $root.google.protobuf.FieldMask.encode(message.updateMask, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified UpdateEntityTypeRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.UpdateEntityTypeRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateEntityTypeRequest} message UpdateEntityTypeRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UpdateEntityTypeRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an UpdateEntityTypeRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateEntityTypeRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.UpdateEntityTypeRequest} UpdateEntityTypeRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UpdateEntityTypeRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.UpdateEntityTypeRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.entityType = $root.google.cloud.dialogflow.v2beta1.EntityType.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.languageCode = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.updateMask = $root.google.protobuf.FieldMask.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an UpdateEntityTypeRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateEntityTypeRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.UpdateEntityTypeRequest} UpdateEntityTypeRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UpdateEntityTypeRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an UpdateEntityTypeRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateEntityTypeRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        UpdateEntityTypeRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.entityType != null && message.hasOwnProperty("entityType")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.EntityType.verify(message.entityType);
                                if (error)
                                    return "entityType." + error;
                            }
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                if (!$util.isString(message.languageCode))
                                    return "languageCode: string expected";
                            if (message.updateMask != null && message.hasOwnProperty("updateMask")) {
                                var error = $root.google.protobuf.FieldMask.verify(message.updateMask);
                                if (error)
                                    return "updateMask." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates an UpdateEntityTypeRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateEntityTypeRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.UpdateEntityTypeRequest} UpdateEntityTypeRequest
                         */
                        UpdateEntityTypeRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.UpdateEntityTypeRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.UpdateEntityTypeRequest();
                            if (object.entityType != null) {
                                if (typeof object.entityType !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.UpdateEntityTypeRequest.entityType: object expected");
                                message.entityType = $root.google.cloud.dialogflow.v2beta1.EntityType.fromObject(object.entityType);
                            }
                            if (object.languageCode != null)
                                message.languageCode = String(object.languageCode);
                            if (object.updateMask != null) {
                                if (typeof object.updateMask !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.UpdateEntityTypeRequest.updateMask: object expected");
                                message.updateMask = $root.google.protobuf.FieldMask.fromObject(object.updateMask);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an UpdateEntityTypeRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.UpdateEntityTypeRequest} message UpdateEntityTypeRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        UpdateEntityTypeRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.entityType = null;
                                object.languageCode = "";
                                object.updateMask = null;
                            }
                            if (message.entityType != null && message.hasOwnProperty("entityType"))
                                object.entityType = $root.google.cloud.dialogflow.v2beta1.EntityType.toObject(message.entityType, options);
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                object.languageCode = message.languageCode;
                            if (message.updateMask != null && message.hasOwnProperty("updateMask"))
                                object.updateMask = $root.google.protobuf.FieldMask.toObject(message.updateMask, options);
                            return object;
                        };
    
                        /**
                         * Converts this UpdateEntityTypeRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateEntityTypeRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        UpdateEntityTypeRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for UpdateEntityTypeRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateEntityTypeRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        UpdateEntityTypeRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.UpdateEntityTypeRequest";
                        };
    
                        return UpdateEntityTypeRequest;
                    })();
    
                    v2beta1.DeleteEntityTypeRequest = (function() {
    
                        /**
                         * Properties of a DeleteEntityTypeRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IDeleteEntityTypeRequest
                         * @property {string|null} [name] DeleteEntityTypeRequest name
                         */
    
                        /**
                         * Constructs a new DeleteEntityTypeRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a DeleteEntityTypeRequest.
                         * @implements IDeleteEntityTypeRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteEntityTypeRequest=} [properties] Properties to set
                         */
                        function DeleteEntityTypeRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * DeleteEntityTypeRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteEntityTypeRequest
                         * @instance
                         */
                        DeleteEntityTypeRequest.prototype.name = "";
    
                        /**
                         * Creates a new DeleteEntityTypeRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteEntityTypeRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.DeleteEntityTypeRequest} DeleteEntityTypeRequest instance
                         */
                        DeleteEntityTypeRequest.create = function create(properties) {
                            return new DeleteEntityTypeRequest(properties);
                        };
    
                        /**
                         * Encodes the specified DeleteEntityTypeRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.DeleteEntityTypeRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteEntityTypeRequest} message DeleteEntityTypeRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteEntityTypeRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified DeleteEntityTypeRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.DeleteEntityTypeRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteEntityTypeRequest} message DeleteEntityTypeRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteEntityTypeRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a DeleteEntityTypeRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteEntityTypeRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.DeleteEntityTypeRequest} DeleteEntityTypeRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteEntityTypeRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.DeleteEntityTypeRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a DeleteEntityTypeRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteEntityTypeRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.DeleteEntityTypeRequest} DeleteEntityTypeRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteEntityTypeRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a DeleteEntityTypeRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteEntityTypeRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        DeleteEntityTypeRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a DeleteEntityTypeRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteEntityTypeRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.DeleteEntityTypeRequest} DeleteEntityTypeRequest
                         */
                        DeleteEntityTypeRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.DeleteEntityTypeRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.DeleteEntityTypeRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a DeleteEntityTypeRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteEntityTypeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.DeleteEntityTypeRequest} message DeleteEntityTypeRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        DeleteEntityTypeRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.name = "";
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            return object;
                        };
    
                        /**
                         * Converts this DeleteEntityTypeRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteEntityTypeRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        DeleteEntityTypeRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for DeleteEntityTypeRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteEntityTypeRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        DeleteEntityTypeRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.DeleteEntityTypeRequest";
                        };
    
                        return DeleteEntityTypeRequest;
                    })();
    
                    v2beta1.BatchUpdateEntityTypesRequest = (function() {
    
                        /**
                         * Properties of a BatchUpdateEntityTypesRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IBatchUpdateEntityTypesRequest
                         * @property {string|null} [parent] BatchUpdateEntityTypesRequest parent
                         * @property {string|null} [entityTypeBatchUri] BatchUpdateEntityTypesRequest entityTypeBatchUri
                         * @property {google.cloud.dialogflow.v2beta1.IEntityTypeBatch|null} [entityTypeBatchInline] BatchUpdateEntityTypesRequest entityTypeBatchInline
                         * @property {string|null} [languageCode] BatchUpdateEntityTypesRequest languageCode
                         * @property {google.protobuf.IFieldMask|null} [updateMask] BatchUpdateEntityTypesRequest updateMask
                         */
    
                        /**
                         * Constructs a new BatchUpdateEntityTypesRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a BatchUpdateEntityTypesRequest.
                         * @implements IBatchUpdateEntityTypesRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IBatchUpdateEntityTypesRequest=} [properties] Properties to set
                         */
                        function BatchUpdateEntityTypesRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * BatchUpdateEntityTypesRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesRequest
                         * @instance
                         */
                        BatchUpdateEntityTypesRequest.prototype.parent = "";
    
                        /**
                         * BatchUpdateEntityTypesRequest entityTypeBatchUri.
                         * @member {string|null|undefined} entityTypeBatchUri
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesRequest
                         * @instance
                         */
                        BatchUpdateEntityTypesRequest.prototype.entityTypeBatchUri = null;
    
                        /**
                         * BatchUpdateEntityTypesRequest entityTypeBatchInline.
                         * @member {google.cloud.dialogflow.v2beta1.IEntityTypeBatch|null|undefined} entityTypeBatchInline
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesRequest
                         * @instance
                         */
                        BatchUpdateEntityTypesRequest.prototype.entityTypeBatchInline = null;
    
                        /**
                         * BatchUpdateEntityTypesRequest languageCode.
                         * @member {string} languageCode
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesRequest
                         * @instance
                         */
                        BatchUpdateEntityTypesRequest.prototype.languageCode = "";
    
                        /**
                         * BatchUpdateEntityTypesRequest updateMask.
                         * @member {google.protobuf.IFieldMask|null|undefined} updateMask
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesRequest
                         * @instance
                         */
                        BatchUpdateEntityTypesRequest.prototype.updateMask = null;
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * BatchUpdateEntityTypesRequest entityTypeBatch.
                         * @member {"entityTypeBatchUri"|"entityTypeBatchInline"|undefined} entityTypeBatch
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesRequest
                         * @instance
                         */
                        Object.defineProperty(BatchUpdateEntityTypesRequest.prototype, "entityTypeBatch", {
                            get: $util.oneOfGetter($oneOfFields = ["entityTypeBatchUri", "entityTypeBatchInline"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new BatchUpdateEntityTypesRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IBatchUpdateEntityTypesRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesRequest} BatchUpdateEntityTypesRequest instance
                         */
                        BatchUpdateEntityTypesRequest.create = function create(properties) {
                            return new BatchUpdateEntityTypesRequest(properties);
                        };
    
                        /**
                         * Encodes the specified BatchUpdateEntityTypesRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IBatchUpdateEntityTypesRequest} message BatchUpdateEntityTypesRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        BatchUpdateEntityTypesRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.entityTypeBatchUri != null && Object.hasOwnProperty.call(message, "entityTypeBatchUri"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.entityTypeBatchUri);
                            if (message.entityTypeBatchInline != null && Object.hasOwnProperty.call(message, "entityTypeBatchInline"))
                                $root.google.cloud.dialogflow.v2beta1.EntityTypeBatch.encode(message.entityTypeBatchInline, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            if (message.languageCode != null && Object.hasOwnProperty.call(message, "languageCode"))
                                writer.uint32(/* id 4, wireType 2 =*/34).string(message.languageCode);
                            if (message.updateMask != null && Object.hasOwnProperty.call(message, "updateMask"))
                                $root.google.protobuf.FieldMask.encode(message.updateMask, writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified BatchUpdateEntityTypesRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IBatchUpdateEntityTypesRequest} message BatchUpdateEntityTypesRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        BatchUpdateEntityTypesRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a BatchUpdateEntityTypesRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesRequest} BatchUpdateEntityTypesRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        BatchUpdateEntityTypesRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.entityTypeBatchUri = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.entityTypeBatchInline = $root.google.cloud.dialogflow.v2beta1.EntityTypeBatch.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 4: {
                                        message.languageCode = reader.string();
                                        break;
                                    }
                                case 5: {
                                        message.updateMask = $root.google.protobuf.FieldMask.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a BatchUpdateEntityTypesRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesRequest} BatchUpdateEntityTypesRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        BatchUpdateEntityTypesRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a BatchUpdateEntityTypesRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        BatchUpdateEntityTypesRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.entityTypeBatchUri != null && message.hasOwnProperty("entityTypeBatchUri")) {
                                properties.entityTypeBatch = 1;
                                if (!$util.isString(message.entityTypeBatchUri))
                                    return "entityTypeBatchUri: string expected";
                            }
                            if (message.entityTypeBatchInline != null && message.hasOwnProperty("entityTypeBatchInline")) {
                                if (properties.entityTypeBatch === 1)
                                    return "entityTypeBatch: multiple values";
                                properties.entityTypeBatch = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2beta1.EntityTypeBatch.verify(message.entityTypeBatchInline);
                                    if (error)
                                        return "entityTypeBatchInline." + error;
                                }
                            }
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                if (!$util.isString(message.languageCode))
                                    return "languageCode: string expected";
                            if (message.updateMask != null && message.hasOwnProperty("updateMask")) {
                                var error = $root.google.protobuf.FieldMask.verify(message.updateMask);
                                if (error)
                                    return "updateMask." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a BatchUpdateEntityTypesRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesRequest} BatchUpdateEntityTypesRequest
                         */
                        BatchUpdateEntityTypesRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.entityTypeBatchUri != null)
                                message.entityTypeBatchUri = String(object.entityTypeBatchUri);
                            if (object.entityTypeBatchInline != null) {
                                if (typeof object.entityTypeBatchInline !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesRequest.entityTypeBatchInline: object expected");
                                message.entityTypeBatchInline = $root.google.cloud.dialogflow.v2beta1.EntityTypeBatch.fromObject(object.entityTypeBatchInline);
                            }
                            if (object.languageCode != null)
                                message.languageCode = String(object.languageCode);
                            if (object.updateMask != null) {
                                if (typeof object.updateMask !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesRequest.updateMask: object expected");
                                message.updateMask = $root.google.protobuf.FieldMask.fromObject(object.updateMask);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a BatchUpdateEntityTypesRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesRequest} message BatchUpdateEntityTypesRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        BatchUpdateEntityTypesRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.languageCode = "";
                                object.updateMask = null;
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.entityTypeBatchUri != null && message.hasOwnProperty("entityTypeBatchUri")) {
                                object.entityTypeBatchUri = message.entityTypeBatchUri;
                                if (options.oneofs)
                                    object.entityTypeBatch = "entityTypeBatchUri";
                            }
                            if (message.entityTypeBatchInline != null && message.hasOwnProperty("entityTypeBatchInline")) {
                                object.entityTypeBatchInline = $root.google.cloud.dialogflow.v2beta1.EntityTypeBatch.toObject(message.entityTypeBatchInline, options);
                                if (options.oneofs)
                                    object.entityTypeBatch = "entityTypeBatchInline";
                            }
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                object.languageCode = message.languageCode;
                            if (message.updateMask != null && message.hasOwnProperty("updateMask"))
                                object.updateMask = $root.google.protobuf.FieldMask.toObject(message.updateMask, options);
                            return object;
                        };
    
                        /**
                         * Converts this BatchUpdateEntityTypesRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        BatchUpdateEntityTypesRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for BatchUpdateEntityTypesRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        BatchUpdateEntityTypesRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesRequest";
                        };
    
                        return BatchUpdateEntityTypesRequest;
                    })();
    
                    v2beta1.BatchUpdateEntityTypesResponse = (function() {
    
                        /**
                         * Properties of a BatchUpdateEntityTypesResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IBatchUpdateEntityTypesResponse
                         * @property {Array.<google.cloud.dialogflow.v2beta1.IEntityType>|null} [entityTypes] BatchUpdateEntityTypesResponse entityTypes
                         */
    
                        /**
                         * Constructs a new BatchUpdateEntityTypesResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a BatchUpdateEntityTypesResponse.
                         * @implements IBatchUpdateEntityTypesResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IBatchUpdateEntityTypesResponse=} [properties] Properties to set
                         */
                        function BatchUpdateEntityTypesResponse(properties) {
                            this.entityTypes = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * BatchUpdateEntityTypesResponse entityTypes.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.IEntityType>} entityTypes
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesResponse
                         * @instance
                         */
                        BatchUpdateEntityTypesResponse.prototype.entityTypes = $util.emptyArray;
    
                        /**
                         * Creates a new BatchUpdateEntityTypesResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IBatchUpdateEntityTypesResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesResponse} BatchUpdateEntityTypesResponse instance
                         */
                        BatchUpdateEntityTypesResponse.create = function create(properties) {
                            return new BatchUpdateEntityTypesResponse(properties);
                        };
    
                        /**
                         * Encodes the specified BatchUpdateEntityTypesResponse message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IBatchUpdateEntityTypesResponse} message BatchUpdateEntityTypesResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        BatchUpdateEntityTypesResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.entityTypes != null && message.entityTypes.length)
                                for (var i = 0; i < message.entityTypes.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.EntityType.encode(message.entityTypes[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified BatchUpdateEntityTypesResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IBatchUpdateEntityTypesResponse} message BatchUpdateEntityTypesResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        BatchUpdateEntityTypesResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a BatchUpdateEntityTypesResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesResponse} BatchUpdateEntityTypesResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        BatchUpdateEntityTypesResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.entityTypes && message.entityTypes.length))
                                            message.entityTypes = [];
                                        message.entityTypes.push($root.google.cloud.dialogflow.v2beta1.EntityType.decode(reader, reader.uint32()));
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a BatchUpdateEntityTypesResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesResponse} BatchUpdateEntityTypesResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        BatchUpdateEntityTypesResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a BatchUpdateEntityTypesResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        BatchUpdateEntityTypesResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.entityTypes != null && message.hasOwnProperty("entityTypes")) {
                                if (!Array.isArray(message.entityTypes))
                                    return "entityTypes: array expected";
                                for (var i = 0; i < message.entityTypes.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.EntityType.verify(message.entityTypes[i]);
                                    if (error)
                                        return "entityTypes." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates a BatchUpdateEntityTypesResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesResponse} BatchUpdateEntityTypesResponse
                         */
                        BatchUpdateEntityTypesResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesResponse();
                            if (object.entityTypes) {
                                if (!Array.isArray(object.entityTypes))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesResponse.entityTypes: array expected");
                                message.entityTypes = [];
                                for (var i = 0; i < object.entityTypes.length; ++i) {
                                    if (typeof object.entityTypes[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesResponse.entityTypes: object expected");
                                    message.entityTypes[i] = $root.google.cloud.dialogflow.v2beta1.EntityType.fromObject(object.entityTypes[i]);
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a BatchUpdateEntityTypesResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesResponse} message BatchUpdateEntityTypesResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        BatchUpdateEntityTypesResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.entityTypes = [];
                            if (message.entityTypes && message.entityTypes.length) {
                                object.entityTypes = [];
                                for (var j = 0; j < message.entityTypes.length; ++j)
                                    object.entityTypes[j] = $root.google.cloud.dialogflow.v2beta1.EntityType.toObject(message.entityTypes[j], options);
                            }
                            return object;
                        };
    
                        /**
                         * Converts this BatchUpdateEntityTypesResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        BatchUpdateEntityTypesResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for BatchUpdateEntityTypesResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        BatchUpdateEntityTypesResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.BatchUpdateEntityTypesResponse";
                        };
    
                        return BatchUpdateEntityTypesResponse;
                    })();
    
                    v2beta1.BatchDeleteEntityTypesRequest = (function() {
    
                        /**
                         * Properties of a BatchDeleteEntityTypesRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IBatchDeleteEntityTypesRequest
                         * @property {string|null} [parent] BatchDeleteEntityTypesRequest parent
                         * @property {Array.<string>|null} [entityTypeNames] BatchDeleteEntityTypesRequest entityTypeNames
                         */
    
                        /**
                         * Constructs a new BatchDeleteEntityTypesRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a BatchDeleteEntityTypesRequest.
                         * @implements IBatchDeleteEntityTypesRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IBatchDeleteEntityTypesRequest=} [properties] Properties to set
                         */
                        function BatchDeleteEntityTypesRequest(properties) {
                            this.entityTypeNames = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * BatchDeleteEntityTypesRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.BatchDeleteEntityTypesRequest
                         * @instance
                         */
                        BatchDeleteEntityTypesRequest.prototype.parent = "";
    
                        /**
                         * BatchDeleteEntityTypesRequest entityTypeNames.
                         * @member {Array.<string>} entityTypeNames
                         * @memberof google.cloud.dialogflow.v2beta1.BatchDeleteEntityTypesRequest
                         * @instance
                         */
                        BatchDeleteEntityTypesRequest.prototype.entityTypeNames = $util.emptyArray;
    
                        /**
                         * Creates a new BatchDeleteEntityTypesRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.BatchDeleteEntityTypesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IBatchDeleteEntityTypesRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.BatchDeleteEntityTypesRequest} BatchDeleteEntityTypesRequest instance
                         */
                        BatchDeleteEntityTypesRequest.create = function create(properties) {
                            return new BatchDeleteEntityTypesRequest(properties);
                        };
    
                        /**
                         * Encodes the specified BatchDeleteEntityTypesRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.BatchDeleteEntityTypesRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.BatchDeleteEntityTypesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IBatchDeleteEntityTypesRequest} message BatchDeleteEntityTypesRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        BatchDeleteEntityTypesRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.entityTypeNames != null && message.entityTypeNames.length)
                                for (var i = 0; i < message.entityTypeNames.length; ++i)
                                    writer.uint32(/* id 2, wireType 2 =*/18).string(message.entityTypeNames[i]);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified BatchDeleteEntityTypesRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.BatchDeleteEntityTypesRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.BatchDeleteEntityTypesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IBatchDeleteEntityTypesRequest} message BatchDeleteEntityTypesRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        BatchDeleteEntityTypesRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a BatchDeleteEntityTypesRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.BatchDeleteEntityTypesRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.BatchDeleteEntityTypesRequest} BatchDeleteEntityTypesRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        BatchDeleteEntityTypesRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.BatchDeleteEntityTypesRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        if (!(message.entityTypeNames && message.entityTypeNames.length))
                                            message.entityTypeNames = [];
                                        message.entityTypeNames.push(reader.string());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a BatchDeleteEntityTypesRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.BatchDeleteEntityTypesRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.BatchDeleteEntityTypesRequest} BatchDeleteEntityTypesRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        BatchDeleteEntityTypesRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a BatchDeleteEntityTypesRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.BatchDeleteEntityTypesRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        BatchDeleteEntityTypesRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.entityTypeNames != null && message.hasOwnProperty("entityTypeNames")) {
                                if (!Array.isArray(message.entityTypeNames))
                                    return "entityTypeNames: array expected";
                                for (var i = 0; i < message.entityTypeNames.length; ++i)
                                    if (!$util.isString(message.entityTypeNames[i]))
                                        return "entityTypeNames: string[] expected";
                            }
                            return null;
                        };
    
                        /**
                         * Creates a BatchDeleteEntityTypesRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.BatchDeleteEntityTypesRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.BatchDeleteEntityTypesRequest} BatchDeleteEntityTypesRequest
                         */
                        BatchDeleteEntityTypesRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.BatchDeleteEntityTypesRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.BatchDeleteEntityTypesRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.entityTypeNames) {
                                if (!Array.isArray(object.entityTypeNames))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.BatchDeleteEntityTypesRequest.entityTypeNames: array expected");
                                message.entityTypeNames = [];
                                for (var i = 0; i < object.entityTypeNames.length; ++i)
                                    message.entityTypeNames[i] = String(object.entityTypeNames[i]);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a BatchDeleteEntityTypesRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.BatchDeleteEntityTypesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.BatchDeleteEntityTypesRequest} message BatchDeleteEntityTypesRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        BatchDeleteEntityTypesRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.entityTypeNames = [];
                            if (options.defaults)
                                object.parent = "";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.entityTypeNames && message.entityTypeNames.length) {
                                object.entityTypeNames = [];
                                for (var j = 0; j < message.entityTypeNames.length; ++j)
                                    object.entityTypeNames[j] = message.entityTypeNames[j];
                            }
                            return object;
                        };
    
                        /**
                         * Converts this BatchDeleteEntityTypesRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.BatchDeleteEntityTypesRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        BatchDeleteEntityTypesRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for BatchDeleteEntityTypesRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.BatchDeleteEntityTypesRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        BatchDeleteEntityTypesRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.BatchDeleteEntityTypesRequest";
                        };
    
                        return BatchDeleteEntityTypesRequest;
                    })();
    
                    v2beta1.BatchCreateEntitiesRequest = (function() {
    
                        /**
                         * Properties of a BatchCreateEntitiesRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IBatchCreateEntitiesRequest
                         * @property {string|null} [parent] BatchCreateEntitiesRequest parent
                         * @property {Array.<google.cloud.dialogflow.v2beta1.EntityType.IEntity>|null} [entities] BatchCreateEntitiesRequest entities
                         * @property {string|null} [languageCode] BatchCreateEntitiesRequest languageCode
                         */
    
                        /**
                         * Constructs a new BatchCreateEntitiesRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a BatchCreateEntitiesRequest.
                         * @implements IBatchCreateEntitiesRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IBatchCreateEntitiesRequest=} [properties] Properties to set
                         */
                        function BatchCreateEntitiesRequest(properties) {
                            this.entities = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * BatchCreateEntitiesRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.BatchCreateEntitiesRequest
                         * @instance
                         */
                        BatchCreateEntitiesRequest.prototype.parent = "";
    
                        /**
                         * BatchCreateEntitiesRequest entities.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.EntityType.IEntity>} entities
                         * @memberof google.cloud.dialogflow.v2beta1.BatchCreateEntitiesRequest
                         * @instance
                         */
                        BatchCreateEntitiesRequest.prototype.entities = $util.emptyArray;
    
                        /**
                         * BatchCreateEntitiesRequest languageCode.
                         * @member {string} languageCode
                         * @memberof google.cloud.dialogflow.v2beta1.BatchCreateEntitiesRequest
                         * @instance
                         */
                        BatchCreateEntitiesRequest.prototype.languageCode = "";
    
                        /**
                         * Creates a new BatchCreateEntitiesRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.BatchCreateEntitiesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IBatchCreateEntitiesRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.BatchCreateEntitiesRequest} BatchCreateEntitiesRequest instance
                         */
                        BatchCreateEntitiesRequest.create = function create(properties) {
                            return new BatchCreateEntitiesRequest(properties);
                        };
    
                        /**
                         * Encodes the specified BatchCreateEntitiesRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.BatchCreateEntitiesRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.BatchCreateEntitiesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IBatchCreateEntitiesRequest} message BatchCreateEntitiesRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        BatchCreateEntitiesRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.entities != null && message.entities.length)
                                for (var i = 0; i < message.entities.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.EntityType.Entity.encode(message.entities[i], writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.languageCode != null && Object.hasOwnProperty.call(message, "languageCode"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.languageCode);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified BatchCreateEntitiesRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.BatchCreateEntitiesRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.BatchCreateEntitiesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IBatchCreateEntitiesRequest} message BatchCreateEntitiesRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        BatchCreateEntitiesRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a BatchCreateEntitiesRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.BatchCreateEntitiesRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.BatchCreateEntitiesRequest} BatchCreateEntitiesRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        BatchCreateEntitiesRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.BatchCreateEntitiesRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        if (!(message.entities && message.entities.length))
                                            message.entities = [];
                                        message.entities.push($root.google.cloud.dialogflow.v2beta1.EntityType.Entity.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 3: {
                                        message.languageCode = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a BatchCreateEntitiesRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.BatchCreateEntitiesRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.BatchCreateEntitiesRequest} BatchCreateEntitiesRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        BatchCreateEntitiesRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a BatchCreateEntitiesRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.BatchCreateEntitiesRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        BatchCreateEntitiesRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.entities != null && message.hasOwnProperty("entities")) {
                                if (!Array.isArray(message.entities))
                                    return "entities: array expected";
                                for (var i = 0; i < message.entities.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.EntityType.Entity.verify(message.entities[i]);
                                    if (error)
                                        return "entities." + error;
                                }
                            }
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                if (!$util.isString(message.languageCode))
                                    return "languageCode: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a BatchCreateEntitiesRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.BatchCreateEntitiesRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.BatchCreateEntitiesRequest} BatchCreateEntitiesRequest
                         */
                        BatchCreateEntitiesRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.BatchCreateEntitiesRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.BatchCreateEntitiesRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.entities) {
                                if (!Array.isArray(object.entities))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.BatchCreateEntitiesRequest.entities: array expected");
                                message.entities = [];
                                for (var i = 0; i < object.entities.length; ++i) {
                                    if (typeof object.entities[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.BatchCreateEntitiesRequest.entities: object expected");
                                    message.entities[i] = $root.google.cloud.dialogflow.v2beta1.EntityType.Entity.fromObject(object.entities[i]);
                                }
                            }
                            if (object.languageCode != null)
                                message.languageCode = String(object.languageCode);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a BatchCreateEntitiesRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.BatchCreateEntitiesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.BatchCreateEntitiesRequest} message BatchCreateEntitiesRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        BatchCreateEntitiesRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.entities = [];
                            if (options.defaults) {
                                object.parent = "";
                                object.languageCode = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.entities && message.entities.length) {
                                object.entities = [];
                                for (var j = 0; j < message.entities.length; ++j)
                                    object.entities[j] = $root.google.cloud.dialogflow.v2beta1.EntityType.Entity.toObject(message.entities[j], options);
                            }
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                object.languageCode = message.languageCode;
                            return object;
                        };
    
                        /**
                         * Converts this BatchCreateEntitiesRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.BatchCreateEntitiesRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        BatchCreateEntitiesRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for BatchCreateEntitiesRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.BatchCreateEntitiesRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        BatchCreateEntitiesRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.BatchCreateEntitiesRequest";
                        };
    
                        return BatchCreateEntitiesRequest;
                    })();
    
                    v2beta1.BatchUpdateEntitiesRequest = (function() {
    
                        /**
                         * Properties of a BatchUpdateEntitiesRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IBatchUpdateEntitiesRequest
                         * @property {string|null} [parent] BatchUpdateEntitiesRequest parent
                         * @property {Array.<google.cloud.dialogflow.v2beta1.EntityType.IEntity>|null} [entities] BatchUpdateEntitiesRequest entities
                         * @property {string|null} [languageCode] BatchUpdateEntitiesRequest languageCode
                         * @property {google.protobuf.IFieldMask|null} [updateMask] BatchUpdateEntitiesRequest updateMask
                         */
    
                        /**
                         * Constructs a new BatchUpdateEntitiesRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a BatchUpdateEntitiesRequest.
                         * @implements IBatchUpdateEntitiesRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IBatchUpdateEntitiesRequest=} [properties] Properties to set
                         */
                        function BatchUpdateEntitiesRequest(properties) {
                            this.entities = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * BatchUpdateEntitiesRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateEntitiesRequest
                         * @instance
                         */
                        BatchUpdateEntitiesRequest.prototype.parent = "";
    
                        /**
                         * BatchUpdateEntitiesRequest entities.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.EntityType.IEntity>} entities
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateEntitiesRequest
                         * @instance
                         */
                        BatchUpdateEntitiesRequest.prototype.entities = $util.emptyArray;
    
                        /**
                         * BatchUpdateEntitiesRequest languageCode.
                         * @member {string} languageCode
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateEntitiesRequest
                         * @instance
                         */
                        BatchUpdateEntitiesRequest.prototype.languageCode = "";
    
                        /**
                         * BatchUpdateEntitiesRequest updateMask.
                         * @member {google.protobuf.IFieldMask|null|undefined} updateMask
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateEntitiesRequest
                         * @instance
                         */
                        BatchUpdateEntitiesRequest.prototype.updateMask = null;
    
                        /**
                         * Creates a new BatchUpdateEntitiesRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateEntitiesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IBatchUpdateEntitiesRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.BatchUpdateEntitiesRequest} BatchUpdateEntitiesRequest instance
                         */
                        BatchUpdateEntitiesRequest.create = function create(properties) {
                            return new BatchUpdateEntitiesRequest(properties);
                        };
    
                        /**
                         * Encodes the specified BatchUpdateEntitiesRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.BatchUpdateEntitiesRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateEntitiesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IBatchUpdateEntitiesRequest} message BatchUpdateEntitiesRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        BatchUpdateEntitiesRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.entities != null && message.entities.length)
                                for (var i = 0; i < message.entities.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.EntityType.Entity.encode(message.entities[i], writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.languageCode != null && Object.hasOwnProperty.call(message, "languageCode"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.languageCode);
                            if (message.updateMask != null && Object.hasOwnProperty.call(message, "updateMask"))
                                $root.google.protobuf.FieldMask.encode(message.updateMask, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified BatchUpdateEntitiesRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.BatchUpdateEntitiesRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateEntitiesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IBatchUpdateEntitiesRequest} message BatchUpdateEntitiesRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        BatchUpdateEntitiesRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a BatchUpdateEntitiesRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateEntitiesRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.BatchUpdateEntitiesRequest} BatchUpdateEntitiesRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        BatchUpdateEntitiesRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.BatchUpdateEntitiesRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        if (!(message.entities && message.entities.length))
                                            message.entities = [];
                                        message.entities.push($root.google.cloud.dialogflow.v2beta1.EntityType.Entity.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 3: {
                                        message.languageCode = reader.string();
                                        break;
                                    }
                                case 4: {
                                        message.updateMask = $root.google.protobuf.FieldMask.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a BatchUpdateEntitiesRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateEntitiesRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.BatchUpdateEntitiesRequest} BatchUpdateEntitiesRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        BatchUpdateEntitiesRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a BatchUpdateEntitiesRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateEntitiesRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        BatchUpdateEntitiesRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.entities != null && message.hasOwnProperty("entities")) {
                                if (!Array.isArray(message.entities))
                                    return "entities: array expected";
                                for (var i = 0; i < message.entities.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.EntityType.Entity.verify(message.entities[i]);
                                    if (error)
                                        return "entities." + error;
                                }
                            }
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                if (!$util.isString(message.languageCode))
                                    return "languageCode: string expected";
                            if (message.updateMask != null && message.hasOwnProperty("updateMask")) {
                                var error = $root.google.protobuf.FieldMask.verify(message.updateMask);
                                if (error)
                                    return "updateMask." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a BatchUpdateEntitiesRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateEntitiesRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.BatchUpdateEntitiesRequest} BatchUpdateEntitiesRequest
                         */
                        BatchUpdateEntitiesRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.BatchUpdateEntitiesRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.BatchUpdateEntitiesRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.entities) {
                                if (!Array.isArray(object.entities))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.BatchUpdateEntitiesRequest.entities: array expected");
                                message.entities = [];
                                for (var i = 0; i < object.entities.length; ++i) {
                                    if (typeof object.entities[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.BatchUpdateEntitiesRequest.entities: object expected");
                                    message.entities[i] = $root.google.cloud.dialogflow.v2beta1.EntityType.Entity.fromObject(object.entities[i]);
                                }
                            }
                            if (object.languageCode != null)
                                message.languageCode = String(object.languageCode);
                            if (object.updateMask != null) {
                                if (typeof object.updateMask !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.BatchUpdateEntitiesRequest.updateMask: object expected");
                                message.updateMask = $root.google.protobuf.FieldMask.fromObject(object.updateMask);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a BatchUpdateEntitiesRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateEntitiesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.BatchUpdateEntitiesRequest} message BatchUpdateEntitiesRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        BatchUpdateEntitiesRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.entities = [];
                            if (options.defaults) {
                                object.parent = "";
                                object.languageCode = "";
                                object.updateMask = null;
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.entities && message.entities.length) {
                                object.entities = [];
                                for (var j = 0; j < message.entities.length; ++j)
                                    object.entities[j] = $root.google.cloud.dialogflow.v2beta1.EntityType.Entity.toObject(message.entities[j], options);
                            }
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                object.languageCode = message.languageCode;
                            if (message.updateMask != null && message.hasOwnProperty("updateMask"))
                                object.updateMask = $root.google.protobuf.FieldMask.toObject(message.updateMask, options);
                            return object;
                        };
    
                        /**
                         * Converts this BatchUpdateEntitiesRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateEntitiesRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        BatchUpdateEntitiesRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for BatchUpdateEntitiesRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.BatchUpdateEntitiesRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        BatchUpdateEntitiesRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.BatchUpdateEntitiesRequest";
                        };
    
                        return BatchUpdateEntitiesRequest;
                    })();
    
                    v2beta1.BatchDeleteEntitiesRequest = (function() {
    
                        /**
                         * Properties of a BatchDeleteEntitiesRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IBatchDeleteEntitiesRequest
                         * @property {string|null} [parent] BatchDeleteEntitiesRequest parent
                         * @property {Array.<string>|null} [entityValues] BatchDeleteEntitiesRequest entityValues
                         * @property {string|null} [languageCode] BatchDeleteEntitiesRequest languageCode
                         */
    
                        /**
                         * Constructs a new BatchDeleteEntitiesRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a BatchDeleteEntitiesRequest.
                         * @implements IBatchDeleteEntitiesRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IBatchDeleteEntitiesRequest=} [properties] Properties to set
                         */
                        function BatchDeleteEntitiesRequest(properties) {
                            this.entityValues = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * BatchDeleteEntitiesRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.BatchDeleteEntitiesRequest
                         * @instance
                         */
                        BatchDeleteEntitiesRequest.prototype.parent = "";
    
                        /**
                         * BatchDeleteEntitiesRequest entityValues.
                         * @member {Array.<string>} entityValues
                         * @memberof google.cloud.dialogflow.v2beta1.BatchDeleteEntitiesRequest
                         * @instance
                         */
                        BatchDeleteEntitiesRequest.prototype.entityValues = $util.emptyArray;
    
                        /**
                         * BatchDeleteEntitiesRequest languageCode.
                         * @member {string} languageCode
                         * @memberof google.cloud.dialogflow.v2beta1.BatchDeleteEntitiesRequest
                         * @instance
                         */
                        BatchDeleteEntitiesRequest.prototype.languageCode = "";
    
                        /**
                         * Creates a new BatchDeleteEntitiesRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.BatchDeleteEntitiesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IBatchDeleteEntitiesRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.BatchDeleteEntitiesRequest} BatchDeleteEntitiesRequest instance
                         */
                        BatchDeleteEntitiesRequest.create = function create(properties) {
                            return new BatchDeleteEntitiesRequest(properties);
                        };
    
                        /**
                         * Encodes the specified BatchDeleteEntitiesRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.BatchDeleteEntitiesRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.BatchDeleteEntitiesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IBatchDeleteEntitiesRequest} message BatchDeleteEntitiesRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        BatchDeleteEntitiesRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.entityValues != null && message.entityValues.length)
                                for (var i = 0; i < message.entityValues.length; ++i)
                                    writer.uint32(/* id 2, wireType 2 =*/18).string(message.entityValues[i]);
                            if (message.languageCode != null && Object.hasOwnProperty.call(message, "languageCode"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.languageCode);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified BatchDeleteEntitiesRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.BatchDeleteEntitiesRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.BatchDeleteEntitiesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IBatchDeleteEntitiesRequest} message BatchDeleteEntitiesRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        BatchDeleteEntitiesRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a BatchDeleteEntitiesRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.BatchDeleteEntitiesRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.BatchDeleteEntitiesRequest} BatchDeleteEntitiesRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        BatchDeleteEntitiesRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.BatchDeleteEntitiesRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        if (!(message.entityValues && message.entityValues.length))
                                            message.entityValues = [];
                                        message.entityValues.push(reader.string());
                                        break;
                                    }
                                case 3: {
                                        message.languageCode = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a BatchDeleteEntitiesRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.BatchDeleteEntitiesRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.BatchDeleteEntitiesRequest} BatchDeleteEntitiesRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        BatchDeleteEntitiesRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a BatchDeleteEntitiesRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.BatchDeleteEntitiesRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        BatchDeleteEntitiesRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.entityValues != null && message.hasOwnProperty("entityValues")) {
                                if (!Array.isArray(message.entityValues))
                                    return "entityValues: array expected";
                                for (var i = 0; i < message.entityValues.length; ++i)
                                    if (!$util.isString(message.entityValues[i]))
                                        return "entityValues: string[] expected";
                            }
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                if (!$util.isString(message.languageCode))
                                    return "languageCode: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a BatchDeleteEntitiesRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.BatchDeleteEntitiesRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.BatchDeleteEntitiesRequest} BatchDeleteEntitiesRequest
                         */
                        BatchDeleteEntitiesRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.BatchDeleteEntitiesRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.BatchDeleteEntitiesRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.entityValues) {
                                if (!Array.isArray(object.entityValues))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.BatchDeleteEntitiesRequest.entityValues: array expected");
                                message.entityValues = [];
                                for (var i = 0; i < object.entityValues.length; ++i)
                                    message.entityValues[i] = String(object.entityValues[i]);
                            }
                            if (object.languageCode != null)
                                message.languageCode = String(object.languageCode);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a BatchDeleteEntitiesRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.BatchDeleteEntitiesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.BatchDeleteEntitiesRequest} message BatchDeleteEntitiesRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        BatchDeleteEntitiesRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.entityValues = [];
                            if (options.defaults) {
                                object.parent = "";
                                object.languageCode = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.entityValues && message.entityValues.length) {
                                object.entityValues = [];
                                for (var j = 0; j < message.entityValues.length; ++j)
                                    object.entityValues[j] = message.entityValues[j];
                            }
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                object.languageCode = message.languageCode;
                            return object;
                        };
    
                        /**
                         * Converts this BatchDeleteEntitiesRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.BatchDeleteEntitiesRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        BatchDeleteEntitiesRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for BatchDeleteEntitiesRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.BatchDeleteEntitiesRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        BatchDeleteEntitiesRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.BatchDeleteEntitiesRequest";
                        };
    
                        return BatchDeleteEntitiesRequest;
                    })();
    
                    v2beta1.EntityTypeBatch = (function() {
    
                        /**
                         * Properties of an EntityTypeBatch.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IEntityTypeBatch
                         * @property {Array.<google.cloud.dialogflow.v2beta1.IEntityType>|null} [entityTypes] EntityTypeBatch entityTypes
                         */
    
                        /**
                         * Constructs a new EntityTypeBatch.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an EntityTypeBatch.
                         * @implements IEntityTypeBatch
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IEntityTypeBatch=} [properties] Properties to set
                         */
                        function EntityTypeBatch(properties) {
                            this.entityTypes = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * EntityTypeBatch entityTypes.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.IEntityType>} entityTypes
                         * @memberof google.cloud.dialogflow.v2beta1.EntityTypeBatch
                         * @instance
                         */
                        EntityTypeBatch.prototype.entityTypes = $util.emptyArray;
    
                        /**
                         * Creates a new EntityTypeBatch instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.EntityTypeBatch
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IEntityTypeBatch=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.EntityTypeBatch} EntityTypeBatch instance
                         */
                        EntityTypeBatch.create = function create(properties) {
                            return new EntityTypeBatch(properties);
                        };
    
                        /**
                         * Encodes the specified EntityTypeBatch message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.EntityTypeBatch.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.EntityTypeBatch
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IEntityTypeBatch} message EntityTypeBatch message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        EntityTypeBatch.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.entityTypes != null && message.entityTypes.length)
                                for (var i = 0; i < message.entityTypes.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.EntityType.encode(message.entityTypes[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified EntityTypeBatch message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.EntityTypeBatch.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.EntityTypeBatch
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IEntityTypeBatch} message EntityTypeBatch message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        EntityTypeBatch.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an EntityTypeBatch message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.EntityTypeBatch
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.EntityTypeBatch} EntityTypeBatch
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        EntityTypeBatch.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.EntityTypeBatch();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.entityTypes && message.entityTypes.length))
                                            message.entityTypes = [];
                                        message.entityTypes.push($root.google.cloud.dialogflow.v2beta1.EntityType.decode(reader, reader.uint32()));
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an EntityTypeBatch message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.EntityTypeBatch
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.EntityTypeBatch} EntityTypeBatch
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        EntityTypeBatch.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an EntityTypeBatch message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.EntityTypeBatch
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        EntityTypeBatch.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.entityTypes != null && message.hasOwnProperty("entityTypes")) {
                                if (!Array.isArray(message.entityTypes))
                                    return "entityTypes: array expected";
                                for (var i = 0; i < message.entityTypes.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.EntityType.verify(message.entityTypes[i]);
                                    if (error)
                                        return "entityTypes." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates an EntityTypeBatch message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.EntityTypeBatch
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.EntityTypeBatch} EntityTypeBatch
                         */
                        EntityTypeBatch.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.EntityTypeBatch)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.EntityTypeBatch();
                            if (object.entityTypes) {
                                if (!Array.isArray(object.entityTypes))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.EntityTypeBatch.entityTypes: array expected");
                                message.entityTypes = [];
                                for (var i = 0; i < object.entityTypes.length; ++i) {
                                    if (typeof object.entityTypes[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.EntityTypeBatch.entityTypes: object expected");
                                    message.entityTypes[i] = $root.google.cloud.dialogflow.v2beta1.EntityType.fromObject(object.entityTypes[i]);
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an EntityTypeBatch message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.EntityTypeBatch
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.EntityTypeBatch} message EntityTypeBatch
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        EntityTypeBatch.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.entityTypes = [];
                            if (message.entityTypes && message.entityTypes.length) {
                                object.entityTypes = [];
                                for (var j = 0; j < message.entityTypes.length; ++j)
                                    object.entityTypes[j] = $root.google.cloud.dialogflow.v2beta1.EntityType.toObject(message.entityTypes[j], options);
                            }
                            return object;
                        };
    
                        /**
                         * Converts this EntityTypeBatch to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.EntityTypeBatch
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        EntityTypeBatch.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for EntityTypeBatch
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.EntityTypeBatch
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        EntityTypeBatch.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.EntityTypeBatch";
                        };
    
                        return EntityTypeBatch;
                    })();
    
                    v2beta1.Conversations = (function() {
    
                        /**
                         * Constructs a new Conversations service.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a Conversations
                         * @extends $protobuf.rpc.Service
                         * @constructor
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         */
                        function Conversations(rpcImpl, requestDelimited, responseDelimited) {
                            $protobuf.rpc.Service.call(this, rpcImpl, requestDelimited, responseDelimited);
                        }
    
                        (Conversations.prototype = Object.create($protobuf.rpc.Service.prototype)).constructor = Conversations;
    
                        /**
                         * Creates new Conversations service using the specified rpc implementation.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.Conversations
                         * @static
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         * @returns {Conversations} RPC service. Useful where requests and/or responses are streamed.
                         */
                        Conversations.create = function create(rpcImpl, requestDelimited, responseDelimited) {
                            return new this(rpcImpl, requestDelimited, responseDelimited);
                        };
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Conversations|createConversation}.
                         * @memberof google.cloud.dialogflow.v2beta1.Conversations
                         * @typedef CreateConversationCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.Conversation} [response] Conversation
                         */
    
                        /**
                         * Calls CreateConversation.
                         * @function createConversation
                         * @memberof google.cloud.dialogflow.v2beta1.Conversations
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.ICreateConversationRequest} request CreateConversationRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Conversations.CreateConversationCallback} callback Node-style callback called with the error, if any, and Conversation
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Conversations.prototype.createConversation = function createConversation(request, callback) {
                            return this.rpcCall(createConversation, $root.google.cloud.dialogflow.v2beta1.CreateConversationRequest, $root.google.cloud.dialogflow.v2beta1.Conversation, request, callback);
                        }, "name", { value: "CreateConversation" });
    
                        /**
                         * Calls CreateConversation.
                         * @function createConversation
                         * @memberof google.cloud.dialogflow.v2beta1.Conversations
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.ICreateConversationRequest} request CreateConversationRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.Conversation>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Conversations|listConversations}.
                         * @memberof google.cloud.dialogflow.v2beta1.Conversations
                         * @typedef ListConversationsCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.ListConversationsResponse} [response] ListConversationsResponse
                         */
    
                        /**
                         * Calls ListConversations.
                         * @function listConversations
                         * @memberof google.cloud.dialogflow.v2beta1.Conversations
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IListConversationsRequest} request ListConversationsRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Conversations.ListConversationsCallback} callback Node-style callback called with the error, if any, and ListConversationsResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Conversations.prototype.listConversations = function listConversations(request, callback) {
                            return this.rpcCall(listConversations, $root.google.cloud.dialogflow.v2beta1.ListConversationsRequest, $root.google.cloud.dialogflow.v2beta1.ListConversationsResponse, request, callback);
                        }, "name", { value: "ListConversations" });
    
                        /**
                         * Calls ListConversations.
                         * @function listConversations
                         * @memberof google.cloud.dialogflow.v2beta1.Conversations
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IListConversationsRequest} request ListConversationsRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.ListConversationsResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Conversations|getConversation}.
                         * @memberof google.cloud.dialogflow.v2beta1.Conversations
                         * @typedef GetConversationCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.Conversation} [response] Conversation
                         */
    
                        /**
                         * Calls GetConversation.
                         * @function getConversation
                         * @memberof google.cloud.dialogflow.v2beta1.Conversations
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IGetConversationRequest} request GetConversationRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Conversations.GetConversationCallback} callback Node-style callback called with the error, if any, and Conversation
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Conversations.prototype.getConversation = function getConversation(request, callback) {
                            return this.rpcCall(getConversation, $root.google.cloud.dialogflow.v2beta1.GetConversationRequest, $root.google.cloud.dialogflow.v2beta1.Conversation, request, callback);
                        }, "name", { value: "GetConversation" });
    
                        /**
                         * Calls GetConversation.
                         * @function getConversation
                         * @memberof google.cloud.dialogflow.v2beta1.Conversations
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IGetConversationRequest} request GetConversationRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.Conversation>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Conversations|completeConversation}.
                         * @memberof google.cloud.dialogflow.v2beta1.Conversations
                         * @typedef CompleteConversationCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.Conversation} [response] Conversation
                         */
    
                        /**
                         * Calls CompleteConversation.
                         * @function completeConversation
                         * @memberof google.cloud.dialogflow.v2beta1.Conversations
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.ICompleteConversationRequest} request CompleteConversationRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Conversations.CompleteConversationCallback} callback Node-style callback called with the error, if any, and Conversation
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Conversations.prototype.completeConversation = function completeConversation(request, callback) {
                            return this.rpcCall(completeConversation, $root.google.cloud.dialogflow.v2beta1.CompleteConversationRequest, $root.google.cloud.dialogflow.v2beta1.Conversation, request, callback);
                        }, "name", { value: "CompleteConversation" });
    
                        /**
                         * Calls CompleteConversation.
                         * @function completeConversation
                         * @memberof google.cloud.dialogflow.v2beta1.Conversations
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.ICompleteConversationRequest} request CompleteConversationRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.Conversation>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Conversations|ingestContextReferences}.
                         * @memberof google.cloud.dialogflow.v2beta1.Conversations
                         * @typedef IngestContextReferencesCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.IngestContextReferencesResponse} [response] IngestContextReferencesResponse
                         */
    
                        /**
                         * Calls IngestContextReferences.
                         * @function ingestContextReferences
                         * @memberof google.cloud.dialogflow.v2beta1.Conversations
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IIngestContextReferencesRequest} request IngestContextReferencesRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Conversations.IngestContextReferencesCallback} callback Node-style callback called with the error, if any, and IngestContextReferencesResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Conversations.prototype.ingestContextReferences = function ingestContextReferences(request, callback) {
                            return this.rpcCall(ingestContextReferences, $root.google.cloud.dialogflow.v2beta1.IngestContextReferencesRequest, $root.google.cloud.dialogflow.v2beta1.IngestContextReferencesResponse, request, callback);
                        }, "name", { value: "IngestContextReferences" });
    
                        /**
                         * Calls IngestContextReferences.
                         * @function ingestContextReferences
                         * @memberof google.cloud.dialogflow.v2beta1.Conversations
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IIngestContextReferencesRequest} request IngestContextReferencesRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.IngestContextReferencesResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Conversations|batchCreateMessages}.
                         * @memberof google.cloud.dialogflow.v2beta1.Conversations
                         * @typedef BatchCreateMessagesCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.BatchCreateMessagesResponse} [response] BatchCreateMessagesResponse
                         */
    
                        /**
                         * Calls BatchCreateMessages.
                         * @function batchCreateMessages
                         * @memberof google.cloud.dialogflow.v2beta1.Conversations
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IBatchCreateMessagesRequest} request BatchCreateMessagesRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Conversations.BatchCreateMessagesCallback} callback Node-style callback called with the error, if any, and BatchCreateMessagesResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Conversations.prototype.batchCreateMessages = function batchCreateMessages(request, callback) {
                            return this.rpcCall(batchCreateMessages, $root.google.cloud.dialogflow.v2beta1.BatchCreateMessagesRequest, $root.google.cloud.dialogflow.v2beta1.BatchCreateMessagesResponse, request, callback);
                        }, "name", { value: "BatchCreateMessages" });
    
                        /**
                         * Calls BatchCreateMessages.
                         * @function batchCreateMessages
                         * @memberof google.cloud.dialogflow.v2beta1.Conversations
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IBatchCreateMessagesRequest} request BatchCreateMessagesRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.BatchCreateMessagesResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Conversations|listMessages}.
                         * @memberof google.cloud.dialogflow.v2beta1.Conversations
                         * @typedef ListMessagesCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.ListMessagesResponse} [response] ListMessagesResponse
                         */
    
                        /**
                         * Calls ListMessages.
                         * @function listMessages
                         * @memberof google.cloud.dialogflow.v2beta1.Conversations
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IListMessagesRequest} request ListMessagesRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Conversations.ListMessagesCallback} callback Node-style callback called with the error, if any, and ListMessagesResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Conversations.prototype.listMessages = function listMessages(request, callback) {
                            return this.rpcCall(listMessages, $root.google.cloud.dialogflow.v2beta1.ListMessagesRequest, $root.google.cloud.dialogflow.v2beta1.ListMessagesResponse, request, callback);
                        }, "name", { value: "ListMessages" });
    
                        /**
                         * Calls ListMessages.
                         * @function listMessages
                         * @memberof google.cloud.dialogflow.v2beta1.Conversations
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IListMessagesRequest} request ListMessagesRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.ListMessagesResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Conversations|suggestConversationSummary}.
                         * @memberof google.cloud.dialogflow.v2beta1.Conversations
                         * @typedef SuggestConversationSummaryCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse} [response] SuggestConversationSummaryResponse
                         */
    
                        /**
                         * Calls SuggestConversationSummary.
                         * @function suggestConversationSummary
                         * @memberof google.cloud.dialogflow.v2beta1.Conversations
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestConversationSummaryRequest} request SuggestConversationSummaryRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Conversations.SuggestConversationSummaryCallback} callback Node-style callback called with the error, if any, and SuggestConversationSummaryResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Conversations.prototype.suggestConversationSummary = function suggestConversationSummary(request, callback) {
                            return this.rpcCall(suggestConversationSummary, $root.google.cloud.dialogflow.v2beta1.SuggestConversationSummaryRequest, $root.google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse, request, callback);
                        }, "name", { value: "SuggestConversationSummary" });
    
                        /**
                         * Calls SuggestConversationSummary.
                         * @function suggestConversationSummary
                         * @memberof google.cloud.dialogflow.v2beta1.Conversations
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestConversationSummaryRequest} request SuggestConversationSummaryRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Conversations|generateStatelessSummary}.
                         * @memberof google.cloud.dialogflow.v2beta1.Conversations
                         * @typedef GenerateStatelessSummaryCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse} [response] GenerateStatelessSummaryResponse
                         */
    
                        /**
                         * Calls GenerateStatelessSummary.
                         * @function generateStatelessSummary
                         * @memberof google.cloud.dialogflow.v2beta1.Conversations
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IGenerateStatelessSummaryRequest} request GenerateStatelessSummaryRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Conversations.GenerateStatelessSummaryCallback} callback Node-style callback called with the error, if any, and GenerateStatelessSummaryResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Conversations.prototype.generateStatelessSummary = function generateStatelessSummary(request, callback) {
                            return this.rpcCall(generateStatelessSummary, $root.google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest, $root.google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse, request, callback);
                        }, "name", { value: "GenerateStatelessSummary" });
    
                        /**
                         * Calls GenerateStatelessSummary.
                         * @function generateStatelessSummary
                         * @memberof google.cloud.dialogflow.v2beta1.Conversations
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IGenerateStatelessSummaryRequest} request GenerateStatelessSummaryRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Conversations|generateStatelessSuggestion}.
                         * @memberof google.cloud.dialogflow.v2beta1.Conversations
                         * @typedef GenerateStatelessSuggestionCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionResponse} [response] GenerateStatelessSuggestionResponse
                         */
    
                        /**
                         * Calls GenerateStatelessSuggestion.
                         * @function generateStatelessSuggestion
                         * @memberof google.cloud.dialogflow.v2beta1.Conversations
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IGenerateStatelessSuggestionRequest} request GenerateStatelessSuggestionRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Conversations.GenerateStatelessSuggestionCallback} callback Node-style callback called with the error, if any, and GenerateStatelessSuggestionResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Conversations.prototype.generateStatelessSuggestion = function generateStatelessSuggestion(request, callback) {
                            return this.rpcCall(generateStatelessSuggestion, $root.google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionRequest, $root.google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionResponse, request, callback);
                        }, "name", { value: "GenerateStatelessSuggestion" });
    
                        /**
                         * Calls GenerateStatelessSuggestion.
                         * @function generateStatelessSuggestion
                         * @memberof google.cloud.dialogflow.v2beta1.Conversations
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IGenerateStatelessSuggestionRequest} request GenerateStatelessSuggestionRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Conversations|searchKnowledge}.
                         * @memberof google.cloud.dialogflow.v2beta1.Conversations
                         * @typedef SearchKnowledgeCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.SearchKnowledgeResponse} [response] SearchKnowledgeResponse
                         */
    
                        /**
                         * Calls SearchKnowledge.
                         * @function searchKnowledge
                         * @memberof google.cloud.dialogflow.v2beta1.Conversations
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.ISearchKnowledgeRequest} request SearchKnowledgeRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Conversations.SearchKnowledgeCallback} callback Node-style callback called with the error, if any, and SearchKnowledgeResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Conversations.prototype.searchKnowledge = function searchKnowledge(request, callback) {
                            return this.rpcCall(searchKnowledge, $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest, $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeResponse, request, callback);
                        }, "name", { value: "SearchKnowledge" });
    
                        /**
                         * Calls SearchKnowledge.
                         * @function searchKnowledge
                         * @memberof google.cloud.dialogflow.v2beta1.Conversations
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.ISearchKnowledgeRequest} request SearchKnowledgeRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.SearchKnowledgeResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Conversations|generateSuggestions}.
                         * @memberof google.cloud.dialogflow.v2beta1.Conversations
                         * @typedef GenerateSuggestionsCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse} [response] GenerateSuggestionsResponse
                         */
    
                        /**
                         * Calls GenerateSuggestions.
                         * @function generateSuggestions
                         * @memberof google.cloud.dialogflow.v2beta1.Conversations
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IGenerateSuggestionsRequest} request GenerateSuggestionsRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Conversations.GenerateSuggestionsCallback} callback Node-style callback called with the error, if any, and GenerateSuggestionsResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Conversations.prototype.generateSuggestions = function generateSuggestions(request, callback) {
                            return this.rpcCall(generateSuggestions, $root.google.cloud.dialogflow.v2beta1.GenerateSuggestionsRequest, $root.google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse, request, callback);
                        }, "name", { value: "GenerateSuggestions" });
    
                        /**
                         * Calls GenerateSuggestions.
                         * @function generateSuggestions
                         * @memberof google.cloud.dialogflow.v2beta1.Conversations
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IGenerateSuggestionsRequest} request GenerateSuggestionsRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.GenerateSuggestionsResponse>} Promise
                         * @variation 2
                         */
    
                        return Conversations;
                    })();
    
                    v2beta1.Conversation = (function() {
    
                        /**
                         * Properties of a Conversation.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IConversation
                         * @property {string|null} [name] Conversation name
                         * @property {google.cloud.dialogflow.v2beta1.Conversation.LifecycleState|null} [lifecycleState] Conversation lifecycleState
                         * @property {string|null} [conversationProfile] Conversation conversationProfile
                         * @property {google.cloud.dialogflow.v2beta1.IConversationPhoneNumber|null} [phoneNumber] Conversation phoneNumber
                         * @property {google.cloud.dialogflow.v2beta1.Conversation.ConversationStage|null} [conversationStage] Conversation conversationStage
                         * @property {google.protobuf.ITimestamp|null} [startTime] Conversation startTime
                         * @property {google.protobuf.ITimestamp|null} [endTime] Conversation endTime
                         * @property {google.cloud.dialogflow.v2beta1.Conversation.ITelephonyConnectionInfo|null} [telephonyConnectionInfo] Conversation telephonyConnectionInfo
                         * @property {Object.<string,google.cloud.dialogflow.v2beta1.Conversation.IContextReference>|null} [ingestedContextReferences] Conversation ingestedContextReferences
                         */
    
                        /**
                         * Constructs a new Conversation.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a Conversation.
                         * @implements IConversation
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IConversation=} [properties] Properties to set
                         */
                        function Conversation(properties) {
                            this.ingestedContextReferences = {};
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * Conversation name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2beta1.Conversation
                         * @instance
                         */
                        Conversation.prototype.name = "";
    
                        /**
                         * Conversation lifecycleState.
                         * @member {google.cloud.dialogflow.v2beta1.Conversation.LifecycleState} lifecycleState
                         * @memberof google.cloud.dialogflow.v2beta1.Conversation
                         * @instance
                         */
                        Conversation.prototype.lifecycleState = 0;
    
                        /**
                         * Conversation conversationProfile.
                         * @member {string} conversationProfile
                         * @memberof google.cloud.dialogflow.v2beta1.Conversation
                         * @instance
                         */
                        Conversation.prototype.conversationProfile = "";
    
                        /**
                         * Conversation phoneNumber.
                         * @member {google.cloud.dialogflow.v2beta1.IConversationPhoneNumber|null|undefined} phoneNumber
                         * @memberof google.cloud.dialogflow.v2beta1.Conversation
                         * @instance
                         */
                        Conversation.prototype.phoneNumber = null;
    
                        /**
                         * Conversation conversationStage.
                         * @member {google.cloud.dialogflow.v2beta1.Conversation.ConversationStage} conversationStage
                         * @memberof google.cloud.dialogflow.v2beta1.Conversation
                         * @instance
                         */
                        Conversation.prototype.conversationStage = 0;
    
                        /**
                         * Conversation startTime.
                         * @member {google.protobuf.ITimestamp|null|undefined} startTime
                         * @memberof google.cloud.dialogflow.v2beta1.Conversation
                         * @instance
                         */
                        Conversation.prototype.startTime = null;
    
                        /**
                         * Conversation endTime.
                         * @member {google.protobuf.ITimestamp|null|undefined} endTime
                         * @memberof google.cloud.dialogflow.v2beta1.Conversation
                         * @instance
                         */
                        Conversation.prototype.endTime = null;
    
                        /**
                         * Conversation telephonyConnectionInfo.
                         * @member {google.cloud.dialogflow.v2beta1.Conversation.ITelephonyConnectionInfo|null|undefined} telephonyConnectionInfo
                         * @memberof google.cloud.dialogflow.v2beta1.Conversation
                         * @instance
                         */
                        Conversation.prototype.telephonyConnectionInfo = null;
    
                        /**
                         * Conversation ingestedContextReferences.
                         * @member {Object.<string,google.cloud.dialogflow.v2beta1.Conversation.IContextReference>} ingestedContextReferences
                         * @memberof google.cloud.dialogflow.v2beta1.Conversation
                         * @instance
                         */
                        Conversation.prototype.ingestedContextReferences = $util.emptyObject;
    
                        /**
                         * Creates a new Conversation instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.Conversation
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IConversation=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.Conversation} Conversation instance
                         */
                        Conversation.create = function create(properties) {
                            return new Conversation(properties);
                        };
    
                        /**
                         * Encodes the specified Conversation message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Conversation.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.Conversation
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IConversation} message Conversation message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        Conversation.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            if (message.lifecycleState != null && Object.hasOwnProperty.call(message, "lifecycleState"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.lifecycleState);
                            if (message.conversationProfile != null && Object.hasOwnProperty.call(message, "conversationProfile"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.conversationProfile);
                            if (message.phoneNumber != null && Object.hasOwnProperty.call(message, "phoneNumber"))
                                $root.google.cloud.dialogflow.v2beta1.ConversationPhoneNumber.encode(message.phoneNumber, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            if (message.startTime != null && Object.hasOwnProperty.call(message, "startTime"))
                                $root.google.protobuf.Timestamp.encode(message.startTime, writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                            if (message.endTime != null && Object.hasOwnProperty.call(message, "endTime"))
                                $root.google.protobuf.Timestamp.encode(message.endTime, writer.uint32(/* id 6, wireType 2 =*/50).fork()).ldelim();
                            if (message.conversationStage != null && Object.hasOwnProperty.call(message, "conversationStage"))
                                writer.uint32(/* id 7, wireType 0 =*/56).int32(message.conversationStage);
                            if (message.telephonyConnectionInfo != null && Object.hasOwnProperty.call(message, "telephonyConnectionInfo"))
                                $root.google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.encode(message.telephonyConnectionInfo, writer.uint32(/* id 10, wireType 2 =*/82).fork()).ldelim();
                            if (message.ingestedContextReferences != null && Object.hasOwnProperty.call(message, "ingestedContextReferences"))
                                for (var keys = Object.keys(message.ingestedContextReferences), i = 0; i < keys.length; ++i) {
                                    writer.uint32(/* id 17, wireType 2 =*/138).fork().uint32(/* id 1, wireType 2 =*/10).string(keys[i]);
                                    $root.google.cloud.dialogflow.v2beta1.Conversation.ContextReference.encode(message.ingestedContextReferences[keys[i]], writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim().ldelim();
                                }
                            return writer;
                        };
    
                        /**
                         * Encodes the specified Conversation message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Conversation.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.Conversation
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IConversation} message Conversation message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        Conversation.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a Conversation message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.Conversation
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.Conversation} Conversation
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        Conversation.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Conversation(), key, value;
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.lifecycleState = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.conversationProfile = reader.string();
                                        break;
                                    }
                                case 4: {
                                        message.phoneNumber = $root.google.cloud.dialogflow.v2beta1.ConversationPhoneNumber.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 7: {
                                        message.conversationStage = reader.int32();
                                        break;
                                    }
                                case 5: {
                                        message.startTime = $root.google.protobuf.Timestamp.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 6: {
                                        message.endTime = $root.google.protobuf.Timestamp.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 10: {
                                        message.telephonyConnectionInfo = $root.google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 17: {
                                        if (message.ingestedContextReferences === $util.emptyObject)
                                            message.ingestedContextReferences = {};
                                        var end2 = reader.uint32() + reader.pos;
                                        key = "";
                                        value = null;
                                        while (reader.pos < end2) {
                                            var tag2 = reader.uint32();
                                            switch (tag2 >>> 3) {
                                            case 1:
                                                key = reader.string();
                                                break;
                                            case 2:
                                                value = $root.google.cloud.dialogflow.v2beta1.Conversation.ContextReference.decode(reader, reader.uint32());
                                                break;
                                            default:
                                                reader.skipType(tag2 & 7);
                                                break;
                                            }
                                        }
                                        message.ingestedContextReferences[key] = value;
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a Conversation message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.Conversation
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.Conversation} Conversation
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        Conversation.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a Conversation message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.Conversation
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        Conversation.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            if (message.lifecycleState != null && message.hasOwnProperty("lifecycleState"))
                                switch (message.lifecycleState) {
                                default:
                                    return "lifecycleState: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                    break;
                                }
                            if (message.conversationProfile != null && message.hasOwnProperty("conversationProfile"))
                                if (!$util.isString(message.conversationProfile))
                                    return "conversationProfile: string expected";
                            if (message.phoneNumber != null && message.hasOwnProperty("phoneNumber")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.ConversationPhoneNumber.verify(message.phoneNumber);
                                if (error)
                                    return "phoneNumber." + error;
                            }
                            if (message.conversationStage != null && message.hasOwnProperty("conversationStage"))
                                switch (message.conversationStage) {
                                default:
                                    return "conversationStage: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                    break;
                                }
                            if (message.startTime != null && message.hasOwnProperty("startTime")) {
                                var error = $root.google.protobuf.Timestamp.verify(message.startTime);
                                if (error)
                                    return "startTime." + error;
                            }
                            if (message.endTime != null && message.hasOwnProperty("endTime")) {
                                var error = $root.google.protobuf.Timestamp.verify(message.endTime);
                                if (error)
                                    return "endTime." + error;
                            }
                            if (message.telephonyConnectionInfo != null && message.hasOwnProperty("telephonyConnectionInfo")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.verify(message.telephonyConnectionInfo);
                                if (error)
                                    return "telephonyConnectionInfo." + error;
                            }
                            if (message.ingestedContextReferences != null && message.hasOwnProperty("ingestedContextReferences")) {
                                if (!$util.isObject(message.ingestedContextReferences))
                                    return "ingestedContextReferences: object expected";
                                var key = Object.keys(message.ingestedContextReferences);
                                for (var i = 0; i < key.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.Conversation.ContextReference.verify(message.ingestedContextReferences[key[i]]);
                                    if (error)
                                        return "ingestedContextReferences." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates a Conversation message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.Conversation
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.Conversation} Conversation
                         */
                        Conversation.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.Conversation)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.Conversation();
                            if (object.name != null)
                                message.name = String(object.name);
                            switch (object.lifecycleState) {
                            default:
                                if (typeof object.lifecycleState === "number") {
                                    message.lifecycleState = object.lifecycleState;
                                    break;
                                }
                                break;
                            case "LIFECYCLE_STATE_UNSPECIFIED":
                            case 0:
                                message.lifecycleState = 0;
                                break;
                            case "IN_PROGRESS":
                            case 1:
                                message.lifecycleState = 1;
                                break;
                            case "COMPLETED":
                            case 2:
                                message.lifecycleState = 2;
                                break;
                            }
                            if (object.conversationProfile != null)
                                message.conversationProfile = String(object.conversationProfile);
                            if (object.phoneNumber != null) {
                                if (typeof object.phoneNumber !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.Conversation.phoneNumber: object expected");
                                message.phoneNumber = $root.google.cloud.dialogflow.v2beta1.ConversationPhoneNumber.fromObject(object.phoneNumber);
                            }
                            switch (object.conversationStage) {
                            default:
                                if (typeof object.conversationStage === "number") {
                                    message.conversationStage = object.conversationStage;
                                    break;
                                }
                                break;
                            case "CONVERSATION_STAGE_UNSPECIFIED":
                            case 0:
                                message.conversationStage = 0;
                                break;
                            case "VIRTUAL_AGENT_STAGE":
                            case 1:
                                message.conversationStage = 1;
                                break;
                            case "HUMAN_ASSIST_STAGE":
                            case 2:
                                message.conversationStage = 2;
                                break;
                            }
                            if (object.startTime != null) {
                                if (typeof object.startTime !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.Conversation.startTime: object expected");
                                message.startTime = $root.google.protobuf.Timestamp.fromObject(object.startTime);
                            }
                            if (object.endTime != null) {
                                if (typeof object.endTime !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.Conversation.endTime: object expected");
                                message.endTime = $root.google.protobuf.Timestamp.fromObject(object.endTime);
                            }
                            if (object.telephonyConnectionInfo != null) {
                                if (typeof object.telephonyConnectionInfo !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.Conversation.telephonyConnectionInfo: object expected");
                                message.telephonyConnectionInfo = $root.google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.fromObject(object.telephonyConnectionInfo);
                            }
                            if (object.ingestedContextReferences) {
                                if (typeof object.ingestedContextReferences !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.Conversation.ingestedContextReferences: object expected");
                                message.ingestedContextReferences = {};
                                for (var keys = Object.keys(object.ingestedContextReferences), i = 0; i < keys.length; ++i) {
                                    if (typeof object.ingestedContextReferences[keys[i]] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.Conversation.ingestedContextReferences: object expected");
                                    message.ingestedContextReferences[keys[i]] = $root.google.cloud.dialogflow.v2beta1.Conversation.ContextReference.fromObject(object.ingestedContextReferences[keys[i]]);
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a Conversation message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.Conversation
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.Conversation} message Conversation
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        Conversation.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.objects || options.defaults)
                                object.ingestedContextReferences = {};
                            if (options.defaults) {
                                object.name = "";
                                object.lifecycleState = options.enums === String ? "LIFECYCLE_STATE_UNSPECIFIED" : 0;
                                object.conversationProfile = "";
                                object.phoneNumber = null;
                                object.startTime = null;
                                object.endTime = null;
                                object.conversationStage = options.enums === String ? "CONVERSATION_STAGE_UNSPECIFIED" : 0;
                                object.telephonyConnectionInfo = null;
                            }
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            if (message.lifecycleState != null && message.hasOwnProperty("lifecycleState"))
                                object.lifecycleState = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.Conversation.LifecycleState[message.lifecycleState] === undefined ? message.lifecycleState : $root.google.cloud.dialogflow.v2beta1.Conversation.LifecycleState[message.lifecycleState] : message.lifecycleState;
                            if (message.conversationProfile != null && message.hasOwnProperty("conversationProfile"))
                                object.conversationProfile = message.conversationProfile;
                            if (message.phoneNumber != null && message.hasOwnProperty("phoneNumber"))
                                object.phoneNumber = $root.google.cloud.dialogflow.v2beta1.ConversationPhoneNumber.toObject(message.phoneNumber, options);
                            if (message.startTime != null && message.hasOwnProperty("startTime"))
                                object.startTime = $root.google.protobuf.Timestamp.toObject(message.startTime, options);
                            if (message.endTime != null && message.hasOwnProperty("endTime"))
                                object.endTime = $root.google.protobuf.Timestamp.toObject(message.endTime, options);
                            if (message.conversationStage != null && message.hasOwnProperty("conversationStage"))
                                object.conversationStage = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.Conversation.ConversationStage[message.conversationStage] === undefined ? message.conversationStage : $root.google.cloud.dialogflow.v2beta1.Conversation.ConversationStage[message.conversationStage] : message.conversationStage;
                            if (message.telephonyConnectionInfo != null && message.hasOwnProperty("telephonyConnectionInfo"))
                                object.telephonyConnectionInfo = $root.google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.toObject(message.telephonyConnectionInfo, options);
                            var keys2;
                            if (message.ingestedContextReferences && (keys2 = Object.keys(message.ingestedContextReferences)).length) {
                                object.ingestedContextReferences = {};
                                for (var j = 0; j < keys2.length; ++j)
                                    object.ingestedContextReferences[keys2[j]] = $root.google.cloud.dialogflow.v2beta1.Conversation.ContextReference.toObject(message.ingestedContextReferences[keys2[j]], options);
                            }
                            return object;
                        };
    
                        /**
                         * Converts this Conversation to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.Conversation
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        Conversation.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for Conversation
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.Conversation
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        Conversation.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Conversation";
                        };
    
                        /**
                         * LifecycleState enum.
                         * @name google.cloud.dialogflow.v2beta1.Conversation.LifecycleState
                         * @enum {number}
                         * @property {number} LIFECYCLE_STATE_UNSPECIFIED=0 LIFECYCLE_STATE_UNSPECIFIED value
                         * @property {number} IN_PROGRESS=1 IN_PROGRESS value
                         * @property {number} COMPLETED=2 COMPLETED value
                         */
                        Conversation.LifecycleState = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "LIFECYCLE_STATE_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "IN_PROGRESS"] = 1;
                            values[valuesById[2] = "COMPLETED"] = 2;
                            return values;
                        })();
    
                        /**
                         * ConversationStage enum.
                         * @name google.cloud.dialogflow.v2beta1.Conversation.ConversationStage
                         * @enum {number}
                         * @property {number} CONVERSATION_STAGE_UNSPECIFIED=0 CONVERSATION_STAGE_UNSPECIFIED value
                         * @property {number} VIRTUAL_AGENT_STAGE=1 VIRTUAL_AGENT_STAGE value
                         * @property {number} HUMAN_ASSIST_STAGE=2 HUMAN_ASSIST_STAGE value
                         */
                        Conversation.ConversationStage = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "CONVERSATION_STAGE_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "VIRTUAL_AGENT_STAGE"] = 1;
                            values[valuesById[2] = "HUMAN_ASSIST_STAGE"] = 2;
                            return values;
                        })();
    
                        Conversation.TelephonyConnectionInfo = (function() {
    
                            /**
                             * Properties of a TelephonyConnectionInfo.
                             * @memberof google.cloud.dialogflow.v2beta1.Conversation
                             * @interface ITelephonyConnectionInfo
                             * @property {string|null} [dialedNumber] TelephonyConnectionInfo dialedNumber
                             * @property {string|null} [sdp] TelephonyConnectionInfo sdp
                             * @property {Array.<google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.ISipHeader>|null} [sipHeaders] TelephonyConnectionInfo sipHeaders
                             * @property {Array.<google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.IMimeContent>|null} [extraMimeContents] TelephonyConnectionInfo extraMimeContents
                             */
    
                            /**
                             * Constructs a new TelephonyConnectionInfo.
                             * @memberof google.cloud.dialogflow.v2beta1.Conversation
                             * @classdesc Represents a TelephonyConnectionInfo.
                             * @implements ITelephonyConnectionInfo
                             * @constructor
                             * @param {google.cloud.dialogflow.v2beta1.Conversation.ITelephonyConnectionInfo=} [properties] Properties to set
                             */
                            function TelephonyConnectionInfo(properties) {
                                this.sipHeaders = [];
                                this.extraMimeContents = [];
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * TelephonyConnectionInfo dialedNumber.
                             * @member {string} dialedNumber
                             * @memberof google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo
                             * @instance
                             */
                            TelephonyConnectionInfo.prototype.dialedNumber = "";
    
                            /**
                             * TelephonyConnectionInfo sdp.
                             * @member {string} sdp
                             * @memberof google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo
                             * @instance
                             */
                            TelephonyConnectionInfo.prototype.sdp = "";
    
                            /**
                             * TelephonyConnectionInfo sipHeaders.
                             * @member {Array.<google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.ISipHeader>} sipHeaders
                             * @memberof google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo
                             * @instance
                             */
                            TelephonyConnectionInfo.prototype.sipHeaders = $util.emptyArray;
    
                            /**
                             * TelephonyConnectionInfo extraMimeContents.
                             * @member {Array.<google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.IMimeContent>} extraMimeContents
                             * @memberof google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo
                             * @instance
                             */
                            TelephonyConnectionInfo.prototype.extraMimeContents = $util.emptyArray;
    
                            /**
                             * Creates a new TelephonyConnectionInfo instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.Conversation.ITelephonyConnectionInfo=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo} TelephonyConnectionInfo instance
                             */
                            TelephonyConnectionInfo.create = function create(properties) {
                                return new TelephonyConnectionInfo(properties);
                            };
    
                            /**
                             * Encodes the specified TelephonyConnectionInfo message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.Conversation.ITelephonyConnectionInfo} message TelephonyConnectionInfo message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            TelephonyConnectionInfo.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.dialedNumber != null && Object.hasOwnProperty.call(message, "dialedNumber"))
                                    writer.uint32(/* id 2, wireType 2 =*/18).string(message.dialedNumber);
                                if (message.sdp != null && Object.hasOwnProperty.call(message, "sdp"))
                                    writer.uint32(/* id 5, wireType 2 =*/42).string(message.sdp);
                                if (message.sipHeaders != null && message.sipHeaders.length)
                                    for (var i = 0; i < message.sipHeaders.length; ++i)
                                        $root.google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.SipHeader.encode(message.sipHeaders[i], writer.uint32(/* id 12, wireType 2 =*/98).fork()).ldelim();
                                if (message.extraMimeContents != null && message.extraMimeContents.length)
                                    for (var i = 0; i < message.extraMimeContents.length; ++i)
                                        $root.google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.MimeContent.encode(message.extraMimeContents[i], writer.uint32(/* id 13, wireType 2 =*/106).fork()).ldelim();
                                return writer;
                            };
    
                            /**
                             * Encodes the specified TelephonyConnectionInfo message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.Conversation.ITelephonyConnectionInfo} message TelephonyConnectionInfo message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            TelephonyConnectionInfo.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a TelephonyConnectionInfo message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo} TelephonyConnectionInfo
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            TelephonyConnectionInfo.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 2: {
                                            message.dialedNumber = reader.string();
                                            break;
                                        }
                                    case 5: {
                                            message.sdp = reader.string();
                                            break;
                                        }
                                    case 12: {
                                            if (!(message.sipHeaders && message.sipHeaders.length))
                                                message.sipHeaders = [];
                                            message.sipHeaders.push($root.google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.SipHeader.decode(reader, reader.uint32()));
                                            break;
                                        }
                                    case 13: {
                                            if (!(message.extraMimeContents && message.extraMimeContents.length))
                                                message.extraMimeContents = [];
                                            message.extraMimeContents.push($root.google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.MimeContent.decode(reader, reader.uint32()));
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a TelephonyConnectionInfo message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo} TelephonyConnectionInfo
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            TelephonyConnectionInfo.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a TelephonyConnectionInfo message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            TelephonyConnectionInfo.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.dialedNumber != null && message.hasOwnProperty("dialedNumber"))
                                    if (!$util.isString(message.dialedNumber))
                                        return "dialedNumber: string expected";
                                if (message.sdp != null && message.hasOwnProperty("sdp"))
                                    if (!$util.isString(message.sdp))
                                        return "sdp: string expected";
                                if (message.sipHeaders != null && message.hasOwnProperty("sipHeaders")) {
                                    if (!Array.isArray(message.sipHeaders))
                                        return "sipHeaders: array expected";
                                    for (var i = 0; i < message.sipHeaders.length; ++i) {
                                        var error = $root.google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.SipHeader.verify(message.sipHeaders[i]);
                                        if (error)
                                            return "sipHeaders." + error;
                                    }
                                }
                                if (message.extraMimeContents != null && message.hasOwnProperty("extraMimeContents")) {
                                    if (!Array.isArray(message.extraMimeContents))
                                        return "extraMimeContents: array expected";
                                    for (var i = 0; i < message.extraMimeContents.length; ++i) {
                                        var error = $root.google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.MimeContent.verify(message.extraMimeContents[i]);
                                        if (error)
                                            return "extraMimeContents." + error;
                                    }
                                }
                                return null;
                            };
    
                            /**
                             * Creates a TelephonyConnectionInfo message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo} TelephonyConnectionInfo
                             */
                            TelephonyConnectionInfo.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo();
                                if (object.dialedNumber != null)
                                    message.dialedNumber = String(object.dialedNumber);
                                if (object.sdp != null)
                                    message.sdp = String(object.sdp);
                                if (object.sipHeaders) {
                                    if (!Array.isArray(object.sipHeaders))
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.sipHeaders: array expected");
                                    message.sipHeaders = [];
                                    for (var i = 0; i < object.sipHeaders.length; ++i) {
                                        if (typeof object.sipHeaders[i] !== "object")
                                            throw TypeError(".google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.sipHeaders: object expected");
                                        message.sipHeaders[i] = $root.google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.SipHeader.fromObject(object.sipHeaders[i]);
                                    }
                                }
                                if (object.extraMimeContents) {
                                    if (!Array.isArray(object.extraMimeContents))
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.extraMimeContents: array expected");
                                    message.extraMimeContents = [];
                                    for (var i = 0; i < object.extraMimeContents.length; ++i) {
                                        if (typeof object.extraMimeContents[i] !== "object")
                                            throw TypeError(".google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.extraMimeContents: object expected");
                                        message.extraMimeContents[i] = $root.google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.MimeContent.fromObject(object.extraMimeContents[i]);
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a TelephonyConnectionInfo message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo} message TelephonyConnectionInfo
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            TelephonyConnectionInfo.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.arrays || options.defaults) {
                                    object.sipHeaders = [];
                                    object.extraMimeContents = [];
                                }
                                if (options.defaults) {
                                    object.dialedNumber = "";
                                    object.sdp = "";
                                }
                                if (message.dialedNumber != null && message.hasOwnProperty("dialedNumber"))
                                    object.dialedNumber = message.dialedNumber;
                                if (message.sdp != null && message.hasOwnProperty("sdp"))
                                    object.sdp = message.sdp;
                                if (message.sipHeaders && message.sipHeaders.length) {
                                    object.sipHeaders = [];
                                    for (var j = 0; j < message.sipHeaders.length; ++j)
                                        object.sipHeaders[j] = $root.google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.SipHeader.toObject(message.sipHeaders[j], options);
                                }
                                if (message.extraMimeContents && message.extraMimeContents.length) {
                                    object.extraMimeContents = [];
                                    for (var j = 0; j < message.extraMimeContents.length; ++j)
                                        object.extraMimeContents[j] = $root.google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.MimeContent.toObject(message.extraMimeContents[j], options);
                                }
                                return object;
                            };
    
                            /**
                             * Converts this TelephonyConnectionInfo to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            TelephonyConnectionInfo.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for TelephonyConnectionInfo
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            TelephonyConnectionInfo.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo";
                            };
    
                            TelephonyConnectionInfo.SipHeader = (function() {
    
                                /**
                                 * Properties of a SipHeader.
                                 * @memberof google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo
                                 * @interface ISipHeader
                                 * @property {string|null} [name] SipHeader name
                                 * @property {string|null} [value] SipHeader value
                                 */
    
                                /**
                                 * Constructs a new SipHeader.
                                 * @memberof google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo
                                 * @classdesc Represents a SipHeader.
                                 * @implements ISipHeader
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.ISipHeader=} [properties] Properties to set
                                 */
                                function SipHeader(properties) {
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * SipHeader name.
                                 * @member {string} name
                                 * @memberof google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.SipHeader
                                 * @instance
                                 */
                                SipHeader.prototype.name = "";
    
                                /**
                                 * SipHeader value.
                                 * @member {string} value
                                 * @memberof google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.SipHeader
                                 * @instance
                                 */
                                SipHeader.prototype.value = "";
    
                                /**
                                 * Creates a new SipHeader instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.SipHeader
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.ISipHeader=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.SipHeader} SipHeader instance
                                 */
                                SipHeader.create = function create(properties) {
                                    return new SipHeader(properties);
                                };
    
                                /**
                                 * Encodes the specified SipHeader message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.SipHeader.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.SipHeader
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.ISipHeader} message SipHeader message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                SipHeader.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                                    if (message.value != null && Object.hasOwnProperty.call(message, "value"))
                                        writer.uint32(/* id 2, wireType 2 =*/18).string(message.value);
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified SipHeader message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.SipHeader.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.SipHeader
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.ISipHeader} message SipHeader message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                SipHeader.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a SipHeader message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.SipHeader
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.SipHeader} SipHeader
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                SipHeader.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.SipHeader();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                message.name = reader.string();
                                                break;
                                            }
                                        case 2: {
                                                message.value = reader.string();
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a SipHeader message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.SipHeader
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.SipHeader} SipHeader
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                SipHeader.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a SipHeader message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.SipHeader
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                SipHeader.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.name != null && message.hasOwnProperty("name"))
                                        if (!$util.isString(message.name))
                                            return "name: string expected";
                                    if (message.value != null && message.hasOwnProperty("value"))
                                        if (!$util.isString(message.value))
                                            return "value: string expected";
                                    return null;
                                };
    
                                /**
                                 * Creates a SipHeader message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.SipHeader
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.SipHeader} SipHeader
                                 */
                                SipHeader.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.SipHeader)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.SipHeader();
                                    if (object.name != null)
                                        message.name = String(object.name);
                                    if (object.value != null)
                                        message.value = String(object.value);
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a SipHeader message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.SipHeader
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.SipHeader} message SipHeader
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                SipHeader.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.defaults) {
                                        object.name = "";
                                        object.value = "";
                                    }
                                    if (message.name != null && message.hasOwnProperty("name"))
                                        object.name = message.name;
                                    if (message.value != null && message.hasOwnProperty("value"))
                                        object.value = message.value;
                                    return object;
                                };
    
                                /**
                                 * Converts this SipHeader to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.SipHeader
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                SipHeader.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for SipHeader
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.SipHeader
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                SipHeader.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.SipHeader";
                                };
    
                                return SipHeader;
                            })();
    
                            TelephonyConnectionInfo.MimeContent = (function() {
    
                                /**
                                 * Properties of a MimeContent.
                                 * @memberof google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo
                                 * @interface IMimeContent
                                 * @property {string|null} [mimeType] MimeContent mimeType
                                 * @property {Uint8Array|null} [content] MimeContent content
                                 */
    
                                /**
                                 * Constructs a new MimeContent.
                                 * @memberof google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo
                                 * @classdesc Represents a MimeContent.
                                 * @implements IMimeContent
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.IMimeContent=} [properties] Properties to set
                                 */
                                function MimeContent(properties) {
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * MimeContent mimeType.
                                 * @member {string} mimeType
                                 * @memberof google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.MimeContent
                                 * @instance
                                 */
                                MimeContent.prototype.mimeType = "";
    
                                /**
                                 * MimeContent content.
                                 * @member {Uint8Array} content
                                 * @memberof google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.MimeContent
                                 * @instance
                                 */
                                MimeContent.prototype.content = $util.newBuffer([]);
    
                                /**
                                 * Creates a new MimeContent instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.MimeContent
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.IMimeContent=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.MimeContent} MimeContent instance
                                 */
                                MimeContent.create = function create(properties) {
                                    return new MimeContent(properties);
                                };
    
                                /**
                                 * Encodes the specified MimeContent message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.MimeContent.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.MimeContent
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.IMimeContent} message MimeContent message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                MimeContent.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.mimeType != null && Object.hasOwnProperty.call(message, "mimeType"))
                                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.mimeType);
                                    if (message.content != null && Object.hasOwnProperty.call(message, "content"))
                                        writer.uint32(/* id 2, wireType 2 =*/18).bytes(message.content);
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified MimeContent message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.MimeContent.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.MimeContent
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.IMimeContent} message MimeContent message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                MimeContent.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a MimeContent message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.MimeContent
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.MimeContent} MimeContent
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                MimeContent.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.MimeContent();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                message.mimeType = reader.string();
                                                break;
                                            }
                                        case 2: {
                                                message.content = reader.bytes();
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a MimeContent message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.MimeContent
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.MimeContent} MimeContent
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                MimeContent.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a MimeContent message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.MimeContent
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                MimeContent.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.mimeType != null && message.hasOwnProperty("mimeType"))
                                        if (!$util.isString(message.mimeType))
                                            return "mimeType: string expected";
                                    if (message.content != null && message.hasOwnProperty("content"))
                                        if (!(message.content && typeof message.content.length === "number" || $util.isString(message.content)))
                                            return "content: buffer expected";
                                    return null;
                                };
    
                                /**
                                 * Creates a MimeContent message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.MimeContent
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.MimeContent} MimeContent
                                 */
                                MimeContent.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.MimeContent)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.MimeContent();
                                    if (object.mimeType != null)
                                        message.mimeType = String(object.mimeType);
                                    if (object.content != null)
                                        if (typeof object.content === "string")
                                            $util.base64.decode(object.content, message.content = $util.newBuffer($util.base64.length(object.content)), 0);
                                        else if (object.content.length >= 0)
                                            message.content = object.content;
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a MimeContent message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.MimeContent
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.MimeContent} message MimeContent
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                MimeContent.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.defaults) {
                                        object.mimeType = "";
                                        if (options.bytes === String)
                                            object.content = "";
                                        else {
                                            object.content = [];
                                            if (options.bytes !== Array)
                                                object.content = $util.newBuffer(object.content);
                                        }
                                    }
                                    if (message.mimeType != null && message.hasOwnProperty("mimeType"))
                                        object.mimeType = message.mimeType;
                                    if (message.content != null && message.hasOwnProperty("content"))
                                        object.content = options.bytes === String ? $util.base64.encode(message.content, 0, message.content.length) : options.bytes === Array ? Array.prototype.slice.call(message.content) : message.content;
                                    return object;
                                };
    
                                /**
                                 * Converts this MimeContent to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.MimeContent
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                MimeContent.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for MimeContent
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.MimeContent
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                MimeContent.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Conversation.TelephonyConnectionInfo.MimeContent";
                                };
    
                                return MimeContent;
                            })();
    
                            return TelephonyConnectionInfo;
                        })();
    
                        Conversation.ContextReference = (function() {
    
                            /**
                             * Properties of a ContextReference.
                             * @memberof google.cloud.dialogflow.v2beta1.Conversation
                             * @interface IContextReference
                             * @property {Array.<google.cloud.dialogflow.v2beta1.Conversation.ContextReference.IContextContent>|null} [contextContents] ContextReference contextContents
                             * @property {google.cloud.dialogflow.v2beta1.Conversation.ContextReference.UpdateMode|null} [updateMode] ContextReference updateMode
                             * @property {string|null} [languageCode] ContextReference languageCode
                             * @property {google.protobuf.ITimestamp|null} [createTime] ContextReference createTime
                             */
    
                            /**
                             * Constructs a new ContextReference.
                             * @memberof google.cloud.dialogflow.v2beta1.Conversation
                             * @classdesc Represents a ContextReference.
                             * @implements IContextReference
                             * @constructor
                             * @param {google.cloud.dialogflow.v2beta1.Conversation.IContextReference=} [properties] Properties to set
                             */
                            function ContextReference(properties) {
                                this.contextContents = [];
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * ContextReference contextContents.
                             * @member {Array.<google.cloud.dialogflow.v2beta1.Conversation.ContextReference.IContextContent>} contextContents
                             * @memberof google.cloud.dialogflow.v2beta1.Conversation.ContextReference
                             * @instance
                             */
                            ContextReference.prototype.contextContents = $util.emptyArray;
    
                            /**
                             * ContextReference updateMode.
                             * @member {google.cloud.dialogflow.v2beta1.Conversation.ContextReference.UpdateMode} updateMode
                             * @memberof google.cloud.dialogflow.v2beta1.Conversation.ContextReference
                             * @instance
                             */
                            ContextReference.prototype.updateMode = 0;
    
                            /**
                             * ContextReference languageCode.
                             * @member {string} languageCode
                             * @memberof google.cloud.dialogflow.v2beta1.Conversation.ContextReference
                             * @instance
                             */
                            ContextReference.prototype.languageCode = "";
    
                            /**
                             * ContextReference createTime.
                             * @member {google.protobuf.ITimestamp|null|undefined} createTime
                             * @memberof google.cloud.dialogflow.v2beta1.Conversation.ContextReference
                             * @instance
                             */
                            ContextReference.prototype.createTime = null;
    
                            /**
                             * Creates a new ContextReference instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2beta1.Conversation.ContextReference
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.Conversation.IContextReference=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2beta1.Conversation.ContextReference} ContextReference instance
                             */
                            ContextReference.create = function create(properties) {
                                return new ContextReference(properties);
                            };
    
                            /**
                             * Encodes the specified ContextReference message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Conversation.ContextReference.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2beta1.Conversation.ContextReference
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.Conversation.IContextReference} message ContextReference message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            ContextReference.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.contextContents != null && message.contextContents.length)
                                    for (var i = 0; i < message.contextContents.length; ++i)
                                        $root.google.cloud.dialogflow.v2beta1.Conversation.ContextReference.ContextContent.encode(message.contextContents[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                                if (message.updateMode != null && Object.hasOwnProperty.call(message, "updateMode"))
                                    writer.uint32(/* id 2, wireType 0 =*/16).int32(message.updateMode);
                                if (message.languageCode != null && Object.hasOwnProperty.call(message, "languageCode"))
                                    writer.uint32(/* id 3, wireType 2 =*/26).string(message.languageCode);
                                if (message.createTime != null && Object.hasOwnProperty.call(message, "createTime"))
                                    $root.google.protobuf.Timestamp.encode(message.createTime, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                                return writer;
                            };
    
                            /**
                             * Encodes the specified ContextReference message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Conversation.ContextReference.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.Conversation.ContextReference
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.Conversation.IContextReference} message ContextReference message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            ContextReference.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a ContextReference message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2beta1.Conversation.ContextReference
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2beta1.Conversation.ContextReference} ContextReference
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            ContextReference.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Conversation.ContextReference();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            if (!(message.contextContents && message.contextContents.length))
                                                message.contextContents = [];
                                            message.contextContents.push($root.google.cloud.dialogflow.v2beta1.Conversation.ContextReference.ContextContent.decode(reader, reader.uint32()));
                                            break;
                                        }
                                    case 2: {
                                            message.updateMode = reader.int32();
                                            break;
                                        }
                                    case 3: {
                                            message.languageCode = reader.string();
                                            break;
                                        }
                                    case 4: {
                                            message.createTime = $root.google.protobuf.Timestamp.decode(reader, reader.uint32());
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a ContextReference message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.Conversation.ContextReference
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2beta1.Conversation.ContextReference} ContextReference
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            ContextReference.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a ContextReference message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2beta1.Conversation.ContextReference
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            ContextReference.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.contextContents != null && message.hasOwnProperty("contextContents")) {
                                    if (!Array.isArray(message.contextContents))
                                        return "contextContents: array expected";
                                    for (var i = 0; i < message.contextContents.length; ++i) {
                                        var error = $root.google.cloud.dialogflow.v2beta1.Conversation.ContextReference.ContextContent.verify(message.contextContents[i]);
                                        if (error)
                                            return "contextContents." + error;
                                    }
                                }
                                if (message.updateMode != null && message.hasOwnProperty("updateMode"))
                                    switch (message.updateMode) {
                                    default:
                                        return "updateMode: enum value expected";
                                    case 0:
                                    case 1:
                                    case 2:
                                        break;
                                    }
                                if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                    if (!$util.isString(message.languageCode))
                                        return "languageCode: string expected";
                                if (message.createTime != null && message.hasOwnProperty("createTime")) {
                                    var error = $root.google.protobuf.Timestamp.verify(message.createTime);
                                    if (error)
                                        return "createTime." + error;
                                }
                                return null;
                            };
    
                            /**
                             * Creates a ContextReference message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2beta1.Conversation.ContextReference
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2beta1.Conversation.ContextReference} ContextReference
                             */
                            ContextReference.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2beta1.Conversation.ContextReference)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2beta1.Conversation.ContextReference();
                                if (object.contextContents) {
                                    if (!Array.isArray(object.contextContents))
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.Conversation.ContextReference.contextContents: array expected");
                                    message.contextContents = [];
                                    for (var i = 0; i < object.contextContents.length; ++i) {
                                        if (typeof object.contextContents[i] !== "object")
                                            throw TypeError(".google.cloud.dialogflow.v2beta1.Conversation.ContextReference.contextContents: object expected");
                                        message.contextContents[i] = $root.google.cloud.dialogflow.v2beta1.Conversation.ContextReference.ContextContent.fromObject(object.contextContents[i]);
                                    }
                                }
                                switch (object.updateMode) {
                                default:
                                    if (typeof object.updateMode === "number") {
                                        message.updateMode = object.updateMode;
                                        break;
                                    }
                                    break;
                                case "UPDATE_MODE_UNSPECIFIED":
                                case 0:
                                    message.updateMode = 0;
                                    break;
                                case "APPEND":
                                case 1:
                                    message.updateMode = 1;
                                    break;
                                case "OVERWRITE":
                                case 2:
                                    message.updateMode = 2;
                                    break;
                                }
                                if (object.languageCode != null)
                                    message.languageCode = String(object.languageCode);
                                if (object.createTime != null) {
                                    if (typeof object.createTime !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.Conversation.ContextReference.createTime: object expected");
                                    message.createTime = $root.google.protobuf.Timestamp.fromObject(object.createTime);
                                }
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a ContextReference message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2beta1.Conversation.ContextReference
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.Conversation.ContextReference} message ContextReference
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            ContextReference.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.arrays || options.defaults)
                                    object.contextContents = [];
                                if (options.defaults) {
                                    object.updateMode = options.enums === String ? "UPDATE_MODE_UNSPECIFIED" : 0;
                                    object.languageCode = "";
                                    object.createTime = null;
                                }
                                if (message.contextContents && message.contextContents.length) {
                                    object.contextContents = [];
                                    for (var j = 0; j < message.contextContents.length; ++j)
                                        object.contextContents[j] = $root.google.cloud.dialogflow.v2beta1.Conversation.ContextReference.ContextContent.toObject(message.contextContents[j], options);
                                }
                                if (message.updateMode != null && message.hasOwnProperty("updateMode"))
                                    object.updateMode = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.Conversation.ContextReference.UpdateMode[message.updateMode] === undefined ? message.updateMode : $root.google.cloud.dialogflow.v2beta1.Conversation.ContextReference.UpdateMode[message.updateMode] : message.updateMode;
                                if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                    object.languageCode = message.languageCode;
                                if (message.createTime != null && message.hasOwnProperty("createTime"))
                                    object.createTime = $root.google.protobuf.Timestamp.toObject(message.createTime, options);
                                return object;
                            };
    
                            /**
                             * Converts this ContextReference to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2beta1.Conversation.ContextReference
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            ContextReference.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for ContextReference
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2beta1.Conversation.ContextReference
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            ContextReference.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Conversation.ContextReference";
                            };
    
                            ContextReference.ContextContent = (function() {
    
                                /**
                                 * Properties of a ContextContent.
                                 * @memberof google.cloud.dialogflow.v2beta1.Conversation.ContextReference
                                 * @interface IContextContent
                                 * @property {string|null} [content] ContextContent content
                                 * @property {google.cloud.dialogflow.v2beta1.Conversation.ContextReference.ContextContent.ContentFormat|null} [contentFormat] ContextContent contentFormat
                                 * @property {google.protobuf.ITimestamp|null} [ingestionTime] ContextContent ingestionTime
                                 */
    
                                /**
                                 * Constructs a new ContextContent.
                                 * @memberof google.cloud.dialogflow.v2beta1.Conversation.ContextReference
                                 * @classdesc Represents a ContextContent.
                                 * @implements IContextContent
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2beta1.Conversation.ContextReference.IContextContent=} [properties] Properties to set
                                 */
                                function ContextContent(properties) {
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * ContextContent content.
                                 * @member {string} content
                                 * @memberof google.cloud.dialogflow.v2beta1.Conversation.ContextReference.ContextContent
                                 * @instance
                                 */
                                ContextContent.prototype.content = "";
    
                                /**
                                 * ContextContent contentFormat.
                                 * @member {google.cloud.dialogflow.v2beta1.Conversation.ContextReference.ContextContent.ContentFormat} contentFormat
                                 * @memberof google.cloud.dialogflow.v2beta1.Conversation.ContextReference.ContextContent
                                 * @instance
                                 */
                                ContextContent.prototype.contentFormat = 0;
    
                                /**
                                 * ContextContent ingestionTime.
                                 * @member {google.protobuf.ITimestamp|null|undefined} ingestionTime
                                 * @memberof google.cloud.dialogflow.v2beta1.Conversation.ContextReference.ContextContent
                                 * @instance
                                 */
                                ContextContent.prototype.ingestionTime = null;
    
                                /**
                                 * Creates a new ContextContent instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2beta1.Conversation.ContextReference.ContextContent
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Conversation.ContextReference.IContextContent=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2beta1.Conversation.ContextReference.ContextContent} ContextContent instance
                                 */
                                ContextContent.create = function create(properties) {
                                    return new ContextContent(properties);
                                };
    
                                /**
                                 * Encodes the specified ContextContent message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Conversation.ContextReference.ContextContent.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2beta1.Conversation.ContextReference.ContextContent
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Conversation.ContextReference.IContextContent} message ContextContent message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                ContextContent.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.content != null && Object.hasOwnProperty.call(message, "content"))
                                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.content);
                                    if (message.contentFormat != null && Object.hasOwnProperty.call(message, "contentFormat"))
                                        writer.uint32(/* id 2, wireType 0 =*/16).int32(message.contentFormat);
                                    if (message.ingestionTime != null && Object.hasOwnProperty.call(message, "ingestionTime"))
                                        $root.google.protobuf.Timestamp.encode(message.ingestionTime, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified ContextContent message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Conversation.ContextReference.ContextContent.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Conversation.ContextReference.ContextContent
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Conversation.ContextReference.IContextContent} message ContextContent message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                ContextContent.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a ContextContent message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2beta1.Conversation.ContextReference.ContextContent
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2beta1.Conversation.ContextReference.ContextContent} ContextContent
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                ContextContent.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Conversation.ContextReference.ContextContent();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                message.content = reader.string();
                                                break;
                                            }
                                        case 2: {
                                                message.contentFormat = reader.int32();
                                                break;
                                            }
                                        case 3: {
                                                message.ingestionTime = $root.google.protobuf.Timestamp.decode(reader, reader.uint32());
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a ContextContent message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.Conversation.ContextReference.ContextContent
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2beta1.Conversation.ContextReference.ContextContent} ContextContent
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                ContextContent.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a ContextContent message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2beta1.Conversation.ContextReference.ContextContent
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                ContextContent.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.content != null && message.hasOwnProperty("content"))
                                        if (!$util.isString(message.content))
                                            return "content: string expected";
                                    if (message.contentFormat != null && message.hasOwnProperty("contentFormat"))
                                        switch (message.contentFormat) {
                                        default:
                                            return "contentFormat: enum value expected";
                                        case 0:
                                        case 1:
                                        case 2:
                                            break;
                                        }
                                    if (message.ingestionTime != null && message.hasOwnProperty("ingestionTime")) {
                                        var error = $root.google.protobuf.Timestamp.verify(message.ingestionTime);
                                        if (error)
                                            return "ingestionTime." + error;
                                    }
                                    return null;
                                };
    
                                /**
                                 * Creates a ContextContent message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Conversation.ContextReference.ContextContent
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2beta1.Conversation.ContextReference.ContextContent} ContextContent
                                 */
                                ContextContent.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2beta1.Conversation.ContextReference.ContextContent)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2beta1.Conversation.ContextReference.ContextContent();
                                    if (object.content != null)
                                        message.content = String(object.content);
                                    switch (object.contentFormat) {
                                    default:
                                        if (typeof object.contentFormat === "number") {
                                            message.contentFormat = object.contentFormat;
                                            break;
                                        }
                                        break;
                                    case "CONTENT_FORMAT_UNSPECIFIED":
                                    case 0:
                                        message.contentFormat = 0;
                                        break;
                                    case "JSON":
                                    case 1:
                                        message.contentFormat = 1;
                                        break;
                                    case "PLAIN_TEXT":
                                    case 2:
                                        message.contentFormat = 2;
                                        break;
                                    }
                                    if (object.ingestionTime != null) {
                                        if (typeof object.ingestionTime !== "object")
                                            throw TypeError(".google.cloud.dialogflow.v2beta1.Conversation.ContextReference.ContextContent.ingestionTime: object expected");
                                        message.ingestionTime = $root.google.protobuf.Timestamp.fromObject(object.ingestionTime);
                                    }
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a ContextContent message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2beta1.Conversation.ContextReference.ContextContent
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.Conversation.ContextReference.ContextContent} message ContextContent
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                ContextContent.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.defaults) {
                                        object.content = "";
                                        object.contentFormat = options.enums === String ? "CONTENT_FORMAT_UNSPECIFIED" : 0;
                                        object.ingestionTime = null;
                                    }
                                    if (message.content != null && message.hasOwnProperty("content"))
                                        object.content = message.content;
                                    if (message.contentFormat != null && message.hasOwnProperty("contentFormat"))
                                        object.contentFormat = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.Conversation.ContextReference.ContextContent.ContentFormat[message.contentFormat] === undefined ? message.contentFormat : $root.google.cloud.dialogflow.v2beta1.Conversation.ContextReference.ContextContent.ContentFormat[message.contentFormat] : message.contentFormat;
                                    if (message.ingestionTime != null && message.hasOwnProperty("ingestionTime"))
                                        object.ingestionTime = $root.google.protobuf.Timestamp.toObject(message.ingestionTime, options);
                                    return object;
                                };
    
                                /**
                                 * Converts this ContextContent to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2beta1.Conversation.ContextReference.ContextContent
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                ContextContent.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for ContextContent
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2beta1.Conversation.ContextReference.ContextContent
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                ContextContent.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Conversation.ContextReference.ContextContent";
                                };
    
                                /**
                                 * ContentFormat enum.
                                 * @name google.cloud.dialogflow.v2beta1.Conversation.ContextReference.ContextContent.ContentFormat
                                 * @enum {number}
                                 * @property {number} CONTENT_FORMAT_UNSPECIFIED=0 CONTENT_FORMAT_UNSPECIFIED value
                                 * @property {number} JSON=1 JSON value
                                 * @property {number} PLAIN_TEXT=2 PLAIN_TEXT value
                                 */
                                ContextContent.ContentFormat = (function() {
                                    var valuesById = {}, values = Object.create(valuesById);
                                    values[valuesById[0] = "CONTENT_FORMAT_UNSPECIFIED"] = 0;
                                    values[valuesById[1] = "JSON"] = 1;
                                    values[valuesById[2] = "PLAIN_TEXT"] = 2;
                                    return values;
                                })();
    
                                return ContextContent;
                            })();
    
                            /**
                             * UpdateMode enum.
                             * @name google.cloud.dialogflow.v2beta1.Conversation.ContextReference.UpdateMode
                             * @enum {number}
                             * @property {number} UPDATE_MODE_UNSPECIFIED=0 UPDATE_MODE_UNSPECIFIED value
                             * @property {number} APPEND=1 APPEND value
                             * @property {number} OVERWRITE=2 OVERWRITE value
                             */
                            ContextReference.UpdateMode = (function() {
                                var valuesById = {}, values = Object.create(valuesById);
                                values[valuesById[0] = "UPDATE_MODE_UNSPECIFIED"] = 0;
                                values[valuesById[1] = "APPEND"] = 1;
                                values[valuesById[2] = "OVERWRITE"] = 2;
                                return values;
                            })();
    
                            return ContextReference;
                        })();
    
                        return Conversation;
                    })();
    
                    v2beta1.ConversationPhoneNumber = (function() {
    
                        /**
                         * Properties of a ConversationPhoneNumber.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IConversationPhoneNumber
                         * @property {number|null} [countryCode] ConversationPhoneNumber countryCode
                         * @property {string|null} [phoneNumber] ConversationPhoneNumber phoneNumber
                         */
    
                        /**
                         * Constructs a new ConversationPhoneNumber.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a ConversationPhoneNumber.
                         * @implements IConversationPhoneNumber
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IConversationPhoneNumber=} [properties] Properties to set
                         */
                        function ConversationPhoneNumber(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ConversationPhoneNumber countryCode.
                         * @member {number} countryCode
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationPhoneNumber
                         * @instance
                         */
                        ConversationPhoneNumber.prototype.countryCode = 0;
    
                        /**
                         * ConversationPhoneNumber phoneNumber.
                         * @member {string} phoneNumber
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationPhoneNumber
                         * @instance
                         */
                        ConversationPhoneNumber.prototype.phoneNumber = "";
    
                        /**
                         * Creates a new ConversationPhoneNumber instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationPhoneNumber
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IConversationPhoneNumber=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.ConversationPhoneNumber} ConversationPhoneNumber instance
                         */
                        ConversationPhoneNumber.create = function create(properties) {
                            return new ConversationPhoneNumber(properties);
                        };
    
                        /**
                         * Encodes the specified ConversationPhoneNumber message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ConversationPhoneNumber.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationPhoneNumber
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IConversationPhoneNumber} message ConversationPhoneNumber message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ConversationPhoneNumber.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.countryCode != null && Object.hasOwnProperty.call(message, "countryCode"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.countryCode);
                            if (message.phoneNumber != null && Object.hasOwnProperty.call(message, "phoneNumber"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.phoneNumber);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ConversationPhoneNumber message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ConversationPhoneNumber.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationPhoneNumber
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IConversationPhoneNumber} message ConversationPhoneNumber message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ConversationPhoneNumber.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ConversationPhoneNumber message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationPhoneNumber
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.ConversationPhoneNumber} ConversationPhoneNumber
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ConversationPhoneNumber.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ConversationPhoneNumber();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 2: {
                                        message.countryCode = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.phoneNumber = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ConversationPhoneNumber message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationPhoneNumber
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.ConversationPhoneNumber} ConversationPhoneNumber
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ConversationPhoneNumber.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ConversationPhoneNumber message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationPhoneNumber
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ConversationPhoneNumber.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.countryCode != null && message.hasOwnProperty("countryCode"))
                                if (!$util.isInteger(message.countryCode))
                                    return "countryCode: integer expected";
                            if (message.phoneNumber != null && message.hasOwnProperty("phoneNumber"))
                                if (!$util.isString(message.phoneNumber))
                                    return "phoneNumber: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ConversationPhoneNumber message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationPhoneNumber
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.ConversationPhoneNumber} ConversationPhoneNumber
                         */
                        ConversationPhoneNumber.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.ConversationPhoneNumber)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.ConversationPhoneNumber();
                            if (object.countryCode != null)
                                message.countryCode = object.countryCode | 0;
                            if (object.phoneNumber != null)
                                message.phoneNumber = String(object.phoneNumber);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ConversationPhoneNumber message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationPhoneNumber
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ConversationPhoneNumber} message ConversationPhoneNumber
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ConversationPhoneNumber.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.countryCode = 0;
                                object.phoneNumber = "";
                            }
                            if (message.countryCode != null && message.hasOwnProperty("countryCode"))
                                object.countryCode = message.countryCode;
                            if (message.phoneNumber != null && message.hasOwnProperty("phoneNumber"))
                                object.phoneNumber = message.phoneNumber;
                            return object;
                        };
    
                        /**
                         * Converts this ConversationPhoneNumber to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationPhoneNumber
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ConversationPhoneNumber.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ConversationPhoneNumber
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationPhoneNumber
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ConversationPhoneNumber.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ConversationPhoneNumber";
                        };
    
                        return ConversationPhoneNumber;
                    })();
    
                    v2beta1.CreateConversationRequest = (function() {
    
                        /**
                         * Properties of a CreateConversationRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ICreateConversationRequest
                         * @property {string|null} [parent] CreateConversationRequest parent
                         * @property {google.cloud.dialogflow.v2beta1.IConversation|null} [conversation] CreateConversationRequest conversation
                         * @property {string|null} [conversationId] CreateConversationRequest conversationId
                         */
    
                        /**
                         * Constructs a new CreateConversationRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a CreateConversationRequest.
                         * @implements ICreateConversationRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ICreateConversationRequest=} [properties] Properties to set
                         */
                        function CreateConversationRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * CreateConversationRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.CreateConversationRequest
                         * @instance
                         */
                        CreateConversationRequest.prototype.parent = "";
    
                        /**
                         * CreateConversationRequest conversation.
                         * @member {google.cloud.dialogflow.v2beta1.IConversation|null|undefined} conversation
                         * @memberof google.cloud.dialogflow.v2beta1.CreateConversationRequest
                         * @instance
                         */
                        CreateConversationRequest.prototype.conversation = null;
    
                        /**
                         * CreateConversationRequest conversationId.
                         * @member {string} conversationId
                         * @memberof google.cloud.dialogflow.v2beta1.CreateConversationRequest
                         * @instance
                         */
                        CreateConversationRequest.prototype.conversationId = "";
    
                        /**
                         * Creates a new CreateConversationRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.CreateConversationRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ICreateConversationRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.CreateConversationRequest} CreateConversationRequest instance
                         */
                        CreateConversationRequest.create = function create(properties) {
                            return new CreateConversationRequest(properties);
                        };
    
                        /**
                         * Encodes the specified CreateConversationRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.CreateConversationRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.CreateConversationRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ICreateConversationRequest} message CreateConversationRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateConversationRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.conversation != null && Object.hasOwnProperty.call(message, "conversation"))
                                $root.google.cloud.dialogflow.v2beta1.Conversation.encode(message.conversation, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.conversationId != null && Object.hasOwnProperty.call(message, "conversationId"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.conversationId);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified CreateConversationRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.CreateConversationRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.CreateConversationRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ICreateConversationRequest} message CreateConversationRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateConversationRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a CreateConversationRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.CreateConversationRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.CreateConversationRequest} CreateConversationRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateConversationRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.CreateConversationRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.conversation = $root.google.cloud.dialogflow.v2beta1.Conversation.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 3: {
                                        message.conversationId = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a CreateConversationRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.CreateConversationRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.CreateConversationRequest} CreateConversationRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateConversationRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a CreateConversationRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.CreateConversationRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        CreateConversationRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.conversation != null && message.hasOwnProperty("conversation")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.Conversation.verify(message.conversation);
                                if (error)
                                    return "conversation." + error;
                            }
                            if (message.conversationId != null && message.hasOwnProperty("conversationId"))
                                if (!$util.isString(message.conversationId))
                                    return "conversationId: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a CreateConversationRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.CreateConversationRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.CreateConversationRequest} CreateConversationRequest
                         */
                        CreateConversationRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.CreateConversationRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.CreateConversationRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.conversation != null) {
                                if (typeof object.conversation !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.CreateConversationRequest.conversation: object expected");
                                message.conversation = $root.google.cloud.dialogflow.v2beta1.Conversation.fromObject(object.conversation);
                            }
                            if (object.conversationId != null)
                                message.conversationId = String(object.conversationId);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a CreateConversationRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.CreateConversationRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.CreateConversationRequest} message CreateConversationRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        CreateConversationRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.conversation = null;
                                object.conversationId = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.conversation != null && message.hasOwnProperty("conversation"))
                                object.conversation = $root.google.cloud.dialogflow.v2beta1.Conversation.toObject(message.conversation, options);
                            if (message.conversationId != null && message.hasOwnProperty("conversationId"))
                                object.conversationId = message.conversationId;
                            return object;
                        };
    
                        /**
                         * Converts this CreateConversationRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.CreateConversationRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        CreateConversationRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for CreateConversationRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.CreateConversationRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        CreateConversationRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.CreateConversationRequest";
                        };
    
                        return CreateConversationRequest;
                    })();
    
                    v2beta1.ListConversationsRequest = (function() {
    
                        /**
                         * Properties of a ListConversationsRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IListConversationsRequest
                         * @property {string|null} [parent] ListConversationsRequest parent
                         * @property {number|null} [pageSize] ListConversationsRequest pageSize
                         * @property {string|null} [pageToken] ListConversationsRequest pageToken
                         * @property {string|null} [filter] ListConversationsRequest filter
                         */
    
                        /**
                         * Constructs a new ListConversationsRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a ListConversationsRequest.
                         * @implements IListConversationsRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IListConversationsRequest=} [properties] Properties to set
                         */
                        function ListConversationsRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListConversationsRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.ListConversationsRequest
                         * @instance
                         */
                        ListConversationsRequest.prototype.parent = "";
    
                        /**
                         * ListConversationsRequest pageSize.
                         * @member {number} pageSize
                         * @memberof google.cloud.dialogflow.v2beta1.ListConversationsRequest
                         * @instance
                         */
                        ListConversationsRequest.prototype.pageSize = 0;
    
                        /**
                         * ListConversationsRequest pageToken.
                         * @member {string} pageToken
                         * @memberof google.cloud.dialogflow.v2beta1.ListConversationsRequest
                         * @instance
                         */
                        ListConversationsRequest.prototype.pageToken = "";
    
                        /**
                         * ListConversationsRequest filter.
                         * @member {string} filter
                         * @memberof google.cloud.dialogflow.v2beta1.ListConversationsRequest
                         * @instance
                         */
                        ListConversationsRequest.prototype.filter = "";
    
                        /**
                         * Creates a new ListConversationsRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.ListConversationsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListConversationsRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.ListConversationsRequest} ListConversationsRequest instance
                         */
                        ListConversationsRequest.create = function create(properties) {
                            return new ListConversationsRequest(properties);
                        };
    
                        /**
                         * Encodes the specified ListConversationsRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListConversationsRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.ListConversationsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListConversationsRequest} message ListConversationsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListConversationsRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.pageSize != null && Object.hasOwnProperty.call(message, "pageSize"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.pageSize);
                            if (message.pageToken != null && Object.hasOwnProperty.call(message, "pageToken"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.pageToken);
                            if (message.filter != null && Object.hasOwnProperty.call(message, "filter"))
                                writer.uint32(/* id 4, wireType 2 =*/34).string(message.filter);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListConversationsRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListConversationsRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListConversationsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListConversationsRequest} message ListConversationsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListConversationsRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListConversationsRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.ListConversationsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.ListConversationsRequest} ListConversationsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListConversationsRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ListConversationsRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.pageSize = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.pageToken = reader.string();
                                        break;
                                    }
                                case 4: {
                                        message.filter = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListConversationsRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListConversationsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.ListConversationsRequest} ListConversationsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListConversationsRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListConversationsRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.ListConversationsRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListConversationsRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                if (!$util.isInteger(message.pageSize))
                                    return "pageSize: integer expected";
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                if (!$util.isString(message.pageToken))
                                    return "pageToken: string expected";
                            if (message.filter != null && message.hasOwnProperty("filter"))
                                if (!$util.isString(message.filter))
                                    return "filter: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListConversationsRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListConversationsRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.ListConversationsRequest} ListConversationsRequest
                         */
                        ListConversationsRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.ListConversationsRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.ListConversationsRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.pageSize != null)
                                message.pageSize = object.pageSize | 0;
                            if (object.pageToken != null)
                                message.pageToken = String(object.pageToken);
                            if (object.filter != null)
                                message.filter = String(object.filter);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListConversationsRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListConversationsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ListConversationsRequest} message ListConversationsRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListConversationsRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.pageSize = 0;
                                object.pageToken = "";
                                object.filter = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                object.pageSize = message.pageSize;
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                object.pageToken = message.pageToken;
                            if (message.filter != null && message.hasOwnProperty("filter"))
                                object.filter = message.filter;
                            return object;
                        };
    
                        /**
                         * Converts this ListConversationsRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.ListConversationsRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListConversationsRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListConversationsRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.ListConversationsRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListConversationsRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ListConversationsRequest";
                        };
    
                        return ListConversationsRequest;
                    })();
    
                    v2beta1.ListConversationsResponse = (function() {
    
                        /**
                         * Properties of a ListConversationsResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IListConversationsResponse
                         * @property {Array.<google.cloud.dialogflow.v2beta1.IConversation>|null} [conversations] ListConversationsResponse conversations
                         * @property {string|null} [nextPageToken] ListConversationsResponse nextPageToken
                         */
    
                        /**
                         * Constructs a new ListConversationsResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a ListConversationsResponse.
                         * @implements IListConversationsResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IListConversationsResponse=} [properties] Properties to set
                         */
                        function ListConversationsResponse(properties) {
                            this.conversations = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListConversationsResponse conversations.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.IConversation>} conversations
                         * @memberof google.cloud.dialogflow.v2beta1.ListConversationsResponse
                         * @instance
                         */
                        ListConversationsResponse.prototype.conversations = $util.emptyArray;
    
                        /**
                         * ListConversationsResponse nextPageToken.
                         * @member {string} nextPageToken
                         * @memberof google.cloud.dialogflow.v2beta1.ListConversationsResponse
                         * @instance
                         */
                        ListConversationsResponse.prototype.nextPageToken = "";
    
                        /**
                         * Creates a new ListConversationsResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.ListConversationsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListConversationsResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.ListConversationsResponse} ListConversationsResponse instance
                         */
                        ListConversationsResponse.create = function create(properties) {
                            return new ListConversationsResponse(properties);
                        };
    
                        /**
                         * Encodes the specified ListConversationsResponse message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListConversationsResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.ListConversationsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListConversationsResponse} message ListConversationsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListConversationsResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.conversations != null && message.conversations.length)
                                for (var i = 0; i < message.conversations.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.Conversation.encode(message.conversations[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.nextPageToken != null && Object.hasOwnProperty.call(message, "nextPageToken"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.nextPageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListConversationsResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListConversationsResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListConversationsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListConversationsResponse} message ListConversationsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListConversationsResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListConversationsResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.ListConversationsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.ListConversationsResponse} ListConversationsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListConversationsResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ListConversationsResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.conversations && message.conversations.length))
                                            message.conversations = [];
                                        message.conversations.push($root.google.cloud.dialogflow.v2beta1.Conversation.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 2: {
                                        message.nextPageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListConversationsResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListConversationsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.ListConversationsResponse} ListConversationsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListConversationsResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListConversationsResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.ListConversationsResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListConversationsResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.conversations != null && message.hasOwnProperty("conversations")) {
                                if (!Array.isArray(message.conversations))
                                    return "conversations: array expected";
                                for (var i = 0; i < message.conversations.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.Conversation.verify(message.conversations[i]);
                                    if (error)
                                        return "conversations." + error;
                                }
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                if (!$util.isString(message.nextPageToken))
                                    return "nextPageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListConversationsResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListConversationsResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.ListConversationsResponse} ListConversationsResponse
                         */
                        ListConversationsResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.ListConversationsResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.ListConversationsResponse();
                            if (object.conversations) {
                                if (!Array.isArray(object.conversations))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.ListConversationsResponse.conversations: array expected");
                                message.conversations = [];
                                for (var i = 0; i < object.conversations.length; ++i) {
                                    if (typeof object.conversations[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.ListConversationsResponse.conversations: object expected");
                                    message.conversations[i] = $root.google.cloud.dialogflow.v2beta1.Conversation.fromObject(object.conversations[i]);
                                }
                            }
                            if (object.nextPageToken != null)
                                message.nextPageToken = String(object.nextPageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListConversationsResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListConversationsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ListConversationsResponse} message ListConversationsResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListConversationsResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.conversations = [];
                            if (options.defaults)
                                object.nextPageToken = "";
                            if (message.conversations && message.conversations.length) {
                                object.conversations = [];
                                for (var j = 0; j < message.conversations.length; ++j)
                                    object.conversations[j] = $root.google.cloud.dialogflow.v2beta1.Conversation.toObject(message.conversations[j], options);
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                object.nextPageToken = message.nextPageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListConversationsResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.ListConversationsResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListConversationsResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListConversationsResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.ListConversationsResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListConversationsResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ListConversationsResponse";
                        };
    
                        return ListConversationsResponse;
                    })();
    
                    v2beta1.GetConversationRequest = (function() {
    
                        /**
                         * Properties of a GetConversationRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IGetConversationRequest
                         * @property {string|null} [name] GetConversationRequest name
                         */
    
                        /**
                         * Constructs a new GetConversationRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a GetConversationRequest.
                         * @implements IGetConversationRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IGetConversationRequest=} [properties] Properties to set
                         */
                        function GetConversationRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GetConversationRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2beta1.GetConversationRequest
                         * @instance
                         */
                        GetConversationRequest.prototype.name = "";
    
                        /**
                         * Creates a new GetConversationRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.GetConversationRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetConversationRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.GetConversationRequest} GetConversationRequest instance
                         */
                        GetConversationRequest.create = function create(properties) {
                            return new GetConversationRequest(properties);
                        };
    
                        /**
                         * Encodes the specified GetConversationRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GetConversationRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.GetConversationRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetConversationRequest} message GetConversationRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetConversationRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GetConversationRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GetConversationRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GetConversationRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetConversationRequest} message GetConversationRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetConversationRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GetConversationRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.GetConversationRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.GetConversationRequest} GetConversationRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetConversationRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.GetConversationRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GetConversationRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GetConversationRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.GetConversationRequest} GetConversationRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetConversationRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GetConversationRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.GetConversationRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GetConversationRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a GetConversationRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.GetConversationRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.GetConversationRequest} GetConversationRequest
                         */
                        GetConversationRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.GetConversationRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.GetConversationRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GetConversationRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.GetConversationRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.GetConversationRequest} message GetConversationRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GetConversationRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.name = "";
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            return object;
                        };
    
                        /**
                         * Converts this GetConversationRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.GetConversationRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GetConversationRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GetConversationRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.GetConversationRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GetConversationRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.GetConversationRequest";
                        };
    
                        return GetConversationRequest;
                    })();
    
                    v2beta1.CompleteConversationRequest = (function() {
    
                        /**
                         * Properties of a CompleteConversationRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ICompleteConversationRequest
                         * @property {string|null} [name] CompleteConversationRequest name
                         */
    
                        /**
                         * Constructs a new CompleteConversationRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a CompleteConversationRequest.
                         * @implements ICompleteConversationRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ICompleteConversationRequest=} [properties] Properties to set
                         */
                        function CompleteConversationRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * CompleteConversationRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2beta1.CompleteConversationRequest
                         * @instance
                         */
                        CompleteConversationRequest.prototype.name = "";
    
                        /**
                         * Creates a new CompleteConversationRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.CompleteConversationRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ICompleteConversationRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.CompleteConversationRequest} CompleteConversationRequest instance
                         */
                        CompleteConversationRequest.create = function create(properties) {
                            return new CompleteConversationRequest(properties);
                        };
    
                        /**
                         * Encodes the specified CompleteConversationRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.CompleteConversationRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.CompleteConversationRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ICompleteConversationRequest} message CompleteConversationRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CompleteConversationRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified CompleteConversationRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.CompleteConversationRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.CompleteConversationRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ICompleteConversationRequest} message CompleteConversationRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CompleteConversationRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a CompleteConversationRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.CompleteConversationRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.CompleteConversationRequest} CompleteConversationRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CompleteConversationRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.CompleteConversationRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a CompleteConversationRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.CompleteConversationRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.CompleteConversationRequest} CompleteConversationRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CompleteConversationRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a CompleteConversationRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.CompleteConversationRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        CompleteConversationRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a CompleteConversationRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.CompleteConversationRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.CompleteConversationRequest} CompleteConversationRequest
                         */
                        CompleteConversationRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.CompleteConversationRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.CompleteConversationRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a CompleteConversationRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.CompleteConversationRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.CompleteConversationRequest} message CompleteConversationRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        CompleteConversationRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.name = "";
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            return object;
                        };
    
                        /**
                         * Converts this CompleteConversationRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.CompleteConversationRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        CompleteConversationRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for CompleteConversationRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.CompleteConversationRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        CompleteConversationRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.CompleteConversationRequest";
                        };
    
                        return CompleteConversationRequest;
                    })();
    
                    v2beta1.CreateMessageRequest = (function() {
    
                        /**
                         * Properties of a CreateMessageRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ICreateMessageRequest
                         * @property {string|null} [parent] CreateMessageRequest parent
                         * @property {google.cloud.dialogflow.v2beta1.IMessage|null} [message] CreateMessageRequest message
                         */
    
                        /**
                         * Constructs a new CreateMessageRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a CreateMessageRequest.
                         * @implements ICreateMessageRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ICreateMessageRequest=} [properties] Properties to set
                         */
                        function CreateMessageRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * CreateMessageRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.CreateMessageRequest
                         * @instance
                         */
                        CreateMessageRequest.prototype.parent = "";
    
                        /**
                         * CreateMessageRequest message.
                         * @member {google.cloud.dialogflow.v2beta1.IMessage|null|undefined} message
                         * @memberof google.cloud.dialogflow.v2beta1.CreateMessageRequest
                         * @instance
                         */
                        CreateMessageRequest.prototype.message = null;
    
                        /**
                         * Creates a new CreateMessageRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.CreateMessageRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ICreateMessageRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.CreateMessageRequest} CreateMessageRequest instance
                         */
                        CreateMessageRequest.create = function create(properties) {
                            return new CreateMessageRequest(properties);
                        };
    
                        /**
                         * Encodes the specified CreateMessageRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.CreateMessageRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.CreateMessageRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ICreateMessageRequest} message CreateMessageRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateMessageRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.message != null && Object.hasOwnProperty.call(message, "message"))
                                $root.google.cloud.dialogflow.v2beta1.Message.encode(message.message, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified CreateMessageRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.CreateMessageRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.CreateMessageRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ICreateMessageRequest} message CreateMessageRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateMessageRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a CreateMessageRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.CreateMessageRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.CreateMessageRequest} CreateMessageRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateMessageRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.CreateMessageRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.message = $root.google.cloud.dialogflow.v2beta1.Message.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a CreateMessageRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.CreateMessageRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.CreateMessageRequest} CreateMessageRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateMessageRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a CreateMessageRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.CreateMessageRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        CreateMessageRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.message != null && message.hasOwnProperty("message")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.Message.verify(message.message);
                                if (error)
                                    return "message." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a CreateMessageRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.CreateMessageRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.CreateMessageRequest} CreateMessageRequest
                         */
                        CreateMessageRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.CreateMessageRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.CreateMessageRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.message != null) {
                                if (typeof object.message !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.CreateMessageRequest.message: object expected");
                                message.message = $root.google.cloud.dialogflow.v2beta1.Message.fromObject(object.message);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a CreateMessageRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.CreateMessageRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.CreateMessageRequest} message CreateMessageRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        CreateMessageRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.message = null;
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.message != null && message.hasOwnProperty("message"))
                                object.message = $root.google.cloud.dialogflow.v2beta1.Message.toObject(message.message, options);
                            return object;
                        };
    
                        /**
                         * Converts this CreateMessageRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.CreateMessageRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        CreateMessageRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for CreateMessageRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.CreateMessageRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        CreateMessageRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.CreateMessageRequest";
                        };
    
                        return CreateMessageRequest;
                    })();
    
                    v2beta1.BatchCreateMessagesRequest = (function() {
    
                        /**
                         * Properties of a BatchCreateMessagesRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IBatchCreateMessagesRequest
                         * @property {string|null} [parent] BatchCreateMessagesRequest parent
                         * @property {Array.<google.cloud.dialogflow.v2beta1.ICreateMessageRequest>|null} [requests] BatchCreateMessagesRequest requests
                         */
    
                        /**
                         * Constructs a new BatchCreateMessagesRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a BatchCreateMessagesRequest.
                         * @implements IBatchCreateMessagesRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IBatchCreateMessagesRequest=} [properties] Properties to set
                         */
                        function BatchCreateMessagesRequest(properties) {
                            this.requests = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * BatchCreateMessagesRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.BatchCreateMessagesRequest
                         * @instance
                         */
                        BatchCreateMessagesRequest.prototype.parent = "";
    
                        /**
                         * BatchCreateMessagesRequest requests.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.ICreateMessageRequest>} requests
                         * @memberof google.cloud.dialogflow.v2beta1.BatchCreateMessagesRequest
                         * @instance
                         */
                        BatchCreateMessagesRequest.prototype.requests = $util.emptyArray;
    
                        /**
                         * Creates a new BatchCreateMessagesRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.BatchCreateMessagesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IBatchCreateMessagesRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.BatchCreateMessagesRequest} BatchCreateMessagesRequest instance
                         */
                        BatchCreateMessagesRequest.create = function create(properties) {
                            return new BatchCreateMessagesRequest(properties);
                        };
    
                        /**
                         * Encodes the specified BatchCreateMessagesRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.BatchCreateMessagesRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.BatchCreateMessagesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IBatchCreateMessagesRequest} message BatchCreateMessagesRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        BatchCreateMessagesRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.requests != null && message.requests.length)
                                for (var i = 0; i < message.requests.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.CreateMessageRequest.encode(message.requests[i], writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified BatchCreateMessagesRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.BatchCreateMessagesRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.BatchCreateMessagesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IBatchCreateMessagesRequest} message BatchCreateMessagesRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        BatchCreateMessagesRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a BatchCreateMessagesRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.BatchCreateMessagesRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.BatchCreateMessagesRequest} BatchCreateMessagesRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        BatchCreateMessagesRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.BatchCreateMessagesRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        if (!(message.requests && message.requests.length))
                                            message.requests = [];
                                        message.requests.push($root.google.cloud.dialogflow.v2beta1.CreateMessageRequest.decode(reader, reader.uint32()));
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a BatchCreateMessagesRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.BatchCreateMessagesRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.BatchCreateMessagesRequest} BatchCreateMessagesRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        BatchCreateMessagesRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a BatchCreateMessagesRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.BatchCreateMessagesRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        BatchCreateMessagesRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.requests != null && message.hasOwnProperty("requests")) {
                                if (!Array.isArray(message.requests))
                                    return "requests: array expected";
                                for (var i = 0; i < message.requests.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.CreateMessageRequest.verify(message.requests[i]);
                                    if (error)
                                        return "requests." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates a BatchCreateMessagesRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.BatchCreateMessagesRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.BatchCreateMessagesRequest} BatchCreateMessagesRequest
                         */
                        BatchCreateMessagesRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.BatchCreateMessagesRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.BatchCreateMessagesRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.requests) {
                                if (!Array.isArray(object.requests))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.BatchCreateMessagesRequest.requests: array expected");
                                message.requests = [];
                                for (var i = 0; i < object.requests.length; ++i) {
                                    if (typeof object.requests[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.BatchCreateMessagesRequest.requests: object expected");
                                    message.requests[i] = $root.google.cloud.dialogflow.v2beta1.CreateMessageRequest.fromObject(object.requests[i]);
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a BatchCreateMessagesRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.BatchCreateMessagesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.BatchCreateMessagesRequest} message BatchCreateMessagesRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        BatchCreateMessagesRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.requests = [];
                            if (options.defaults)
                                object.parent = "";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.requests && message.requests.length) {
                                object.requests = [];
                                for (var j = 0; j < message.requests.length; ++j)
                                    object.requests[j] = $root.google.cloud.dialogflow.v2beta1.CreateMessageRequest.toObject(message.requests[j], options);
                            }
                            return object;
                        };
    
                        /**
                         * Converts this BatchCreateMessagesRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.BatchCreateMessagesRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        BatchCreateMessagesRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for BatchCreateMessagesRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.BatchCreateMessagesRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        BatchCreateMessagesRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.BatchCreateMessagesRequest";
                        };
    
                        return BatchCreateMessagesRequest;
                    })();
    
                    v2beta1.BatchCreateMessagesResponse = (function() {
    
                        /**
                         * Properties of a BatchCreateMessagesResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IBatchCreateMessagesResponse
                         * @property {Array.<google.cloud.dialogflow.v2beta1.IMessage>|null} [messages] BatchCreateMessagesResponse messages
                         */
    
                        /**
                         * Constructs a new BatchCreateMessagesResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a BatchCreateMessagesResponse.
                         * @implements IBatchCreateMessagesResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IBatchCreateMessagesResponse=} [properties] Properties to set
                         */
                        function BatchCreateMessagesResponse(properties) {
                            this.messages = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * BatchCreateMessagesResponse messages.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.IMessage>} messages
                         * @memberof google.cloud.dialogflow.v2beta1.BatchCreateMessagesResponse
                         * @instance
                         */
                        BatchCreateMessagesResponse.prototype.messages = $util.emptyArray;
    
                        /**
                         * Creates a new BatchCreateMessagesResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.BatchCreateMessagesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IBatchCreateMessagesResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.BatchCreateMessagesResponse} BatchCreateMessagesResponse instance
                         */
                        BatchCreateMessagesResponse.create = function create(properties) {
                            return new BatchCreateMessagesResponse(properties);
                        };
    
                        /**
                         * Encodes the specified BatchCreateMessagesResponse message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.BatchCreateMessagesResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.BatchCreateMessagesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IBatchCreateMessagesResponse} message BatchCreateMessagesResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        BatchCreateMessagesResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.messages != null && message.messages.length)
                                for (var i = 0; i < message.messages.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.Message.encode(message.messages[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified BatchCreateMessagesResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.BatchCreateMessagesResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.BatchCreateMessagesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IBatchCreateMessagesResponse} message BatchCreateMessagesResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        BatchCreateMessagesResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a BatchCreateMessagesResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.BatchCreateMessagesResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.BatchCreateMessagesResponse} BatchCreateMessagesResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        BatchCreateMessagesResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.BatchCreateMessagesResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.messages && message.messages.length))
                                            message.messages = [];
                                        message.messages.push($root.google.cloud.dialogflow.v2beta1.Message.decode(reader, reader.uint32()));
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a BatchCreateMessagesResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.BatchCreateMessagesResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.BatchCreateMessagesResponse} BatchCreateMessagesResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        BatchCreateMessagesResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a BatchCreateMessagesResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.BatchCreateMessagesResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        BatchCreateMessagesResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.messages != null && message.hasOwnProperty("messages")) {
                                if (!Array.isArray(message.messages))
                                    return "messages: array expected";
                                for (var i = 0; i < message.messages.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.Message.verify(message.messages[i]);
                                    if (error)
                                        return "messages." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates a BatchCreateMessagesResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.BatchCreateMessagesResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.BatchCreateMessagesResponse} BatchCreateMessagesResponse
                         */
                        BatchCreateMessagesResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.BatchCreateMessagesResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.BatchCreateMessagesResponse();
                            if (object.messages) {
                                if (!Array.isArray(object.messages))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.BatchCreateMessagesResponse.messages: array expected");
                                message.messages = [];
                                for (var i = 0; i < object.messages.length; ++i) {
                                    if (typeof object.messages[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.BatchCreateMessagesResponse.messages: object expected");
                                    message.messages[i] = $root.google.cloud.dialogflow.v2beta1.Message.fromObject(object.messages[i]);
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a BatchCreateMessagesResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.BatchCreateMessagesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.BatchCreateMessagesResponse} message BatchCreateMessagesResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        BatchCreateMessagesResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.messages = [];
                            if (message.messages && message.messages.length) {
                                object.messages = [];
                                for (var j = 0; j < message.messages.length; ++j)
                                    object.messages[j] = $root.google.cloud.dialogflow.v2beta1.Message.toObject(message.messages[j], options);
                            }
                            return object;
                        };
    
                        /**
                         * Converts this BatchCreateMessagesResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.BatchCreateMessagesResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        BatchCreateMessagesResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for BatchCreateMessagesResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.BatchCreateMessagesResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        BatchCreateMessagesResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.BatchCreateMessagesResponse";
                        };
    
                        return BatchCreateMessagesResponse;
                    })();
    
                    v2beta1.ListMessagesRequest = (function() {
    
                        /**
                         * Properties of a ListMessagesRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IListMessagesRequest
                         * @property {string|null} [parent] ListMessagesRequest parent
                         * @property {string|null} [filter] ListMessagesRequest filter
                         * @property {number|null} [pageSize] ListMessagesRequest pageSize
                         * @property {string|null} [pageToken] ListMessagesRequest pageToken
                         */
    
                        /**
                         * Constructs a new ListMessagesRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a ListMessagesRequest.
                         * @implements IListMessagesRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IListMessagesRequest=} [properties] Properties to set
                         */
                        function ListMessagesRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListMessagesRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.ListMessagesRequest
                         * @instance
                         */
                        ListMessagesRequest.prototype.parent = "";
    
                        /**
                         * ListMessagesRequest filter.
                         * @member {string} filter
                         * @memberof google.cloud.dialogflow.v2beta1.ListMessagesRequest
                         * @instance
                         */
                        ListMessagesRequest.prototype.filter = "";
    
                        /**
                         * ListMessagesRequest pageSize.
                         * @member {number} pageSize
                         * @memberof google.cloud.dialogflow.v2beta1.ListMessagesRequest
                         * @instance
                         */
                        ListMessagesRequest.prototype.pageSize = 0;
    
                        /**
                         * ListMessagesRequest pageToken.
                         * @member {string} pageToken
                         * @memberof google.cloud.dialogflow.v2beta1.ListMessagesRequest
                         * @instance
                         */
                        ListMessagesRequest.prototype.pageToken = "";
    
                        /**
                         * Creates a new ListMessagesRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.ListMessagesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListMessagesRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.ListMessagesRequest} ListMessagesRequest instance
                         */
                        ListMessagesRequest.create = function create(properties) {
                            return new ListMessagesRequest(properties);
                        };
    
                        /**
                         * Encodes the specified ListMessagesRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListMessagesRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.ListMessagesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListMessagesRequest} message ListMessagesRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListMessagesRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.pageSize != null && Object.hasOwnProperty.call(message, "pageSize"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.pageSize);
                            if (message.pageToken != null && Object.hasOwnProperty.call(message, "pageToken"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.pageToken);
                            if (message.filter != null && Object.hasOwnProperty.call(message, "filter"))
                                writer.uint32(/* id 4, wireType 2 =*/34).string(message.filter);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListMessagesRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListMessagesRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListMessagesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListMessagesRequest} message ListMessagesRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListMessagesRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListMessagesRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.ListMessagesRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.ListMessagesRequest} ListMessagesRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListMessagesRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ListMessagesRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 4: {
                                        message.filter = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.pageSize = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.pageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListMessagesRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListMessagesRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.ListMessagesRequest} ListMessagesRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListMessagesRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListMessagesRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.ListMessagesRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListMessagesRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.filter != null && message.hasOwnProperty("filter"))
                                if (!$util.isString(message.filter))
                                    return "filter: string expected";
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                if (!$util.isInteger(message.pageSize))
                                    return "pageSize: integer expected";
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                if (!$util.isString(message.pageToken))
                                    return "pageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListMessagesRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListMessagesRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.ListMessagesRequest} ListMessagesRequest
                         */
                        ListMessagesRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.ListMessagesRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.ListMessagesRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.filter != null)
                                message.filter = String(object.filter);
                            if (object.pageSize != null)
                                message.pageSize = object.pageSize | 0;
                            if (object.pageToken != null)
                                message.pageToken = String(object.pageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListMessagesRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListMessagesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ListMessagesRequest} message ListMessagesRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListMessagesRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.pageSize = 0;
                                object.pageToken = "";
                                object.filter = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                object.pageSize = message.pageSize;
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                object.pageToken = message.pageToken;
                            if (message.filter != null && message.hasOwnProperty("filter"))
                                object.filter = message.filter;
                            return object;
                        };
    
                        /**
                         * Converts this ListMessagesRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.ListMessagesRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListMessagesRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListMessagesRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.ListMessagesRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListMessagesRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ListMessagesRequest";
                        };
    
                        return ListMessagesRequest;
                    })();
    
                    v2beta1.ListMessagesResponse = (function() {
    
                        /**
                         * Properties of a ListMessagesResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IListMessagesResponse
                         * @property {Array.<google.cloud.dialogflow.v2beta1.IMessage>|null} [messages] ListMessagesResponse messages
                         * @property {string|null} [nextPageToken] ListMessagesResponse nextPageToken
                         */
    
                        /**
                         * Constructs a new ListMessagesResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a ListMessagesResponse.
                         * @implements IListMessagesResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IListMessagesResponse=} [properties] Properties to set
                         */
                        function ListMessagesResponse(properties) {
                            this.messages = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListMessagesResponse messages.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.IMessage>} messages
                         * @memberof google.cloud.dialogflow.v2beta1.ListMessagesResponse
                         * @instance
                         */
                        ListMessagesResponse.prototype.messages = $util.emptyArray;
    
                        /**
                         * ListMessagesResponse nextPageToken.
                         * @member {string} nextPageToken
                         * @memberof google.cloud.dialogflow.v2beta1.ListMessagesResponse
                         * @instance
                         */
                        ListMessagesResponse.prototype.nextPageToken = "";
    
                        /**
                         * Creates a new ListMessagesResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.ListMessagesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListMessagesResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.ListMessagesResponse} ListMessagesResponse instance
                         */
                        ListMessagesResponse.create = function create(properties) {
                            return new ListMessagesResponse(properties);
                        };
    
                        /**
                         * Encodes the specified ListMessagesResponse message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListMessagesResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.ListMessagesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListMessagesResponse} message ListMessagesResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListMessagesResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.messages != null && message.messages.length)
                                for (var i = 0; i < message.messages.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.Message.encode(message.messages[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.nextPageToken != null && Object.hasOwnProperty.call(message, "nextPageToken"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.nextPageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListMessagesResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListMessagesResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListMessagesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListMessagesResponse} message ListMessagesResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListMessagesResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListMessagesResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.ListMessagesResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.ListMessagesResponse} ListMessagesResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListMessagesResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ListMessagesResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.messages && message.messages.length))
                                            message.messages = [];
                                        message.messages.push($root.google.cloud.dialogflow.v2beta1.Message.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 2: {
                                        message.nextPageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListMessagesResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListMessagesResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.ListMessagesResponse} ListMessagesResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListMessagesResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListMessagesResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.ListMessagesResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListMessagesResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.messages != null && message.hasOwnProperty("messages")) {
                                if (!Array.isArray(message.messages))
                                    return "messages: array expected";
                                for (var i = 0; i < message.messages.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.Message.verify(message.messages[i]);
                                    if (error)
                                        return "messages." + error;
                                }
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                if (!$util.isString(message.nextPageToken))
                                    return "nextPageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListMessagesResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListMessagesResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.ListMessagesResponse} ListMessagesResponse
                         */
                        ListMessagesResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.ListMessagesResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.ListMessagesResponse();
                            if (object.messages) {
                                if (!Array.isArray(object.messages))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.ListMessagesResponse.messages: array expected");
                                message.messages = [];
                                for (var i = 0; i < object.messages.length; ++i) {
                                    if (typeof object.messages[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.ListMessagesResponse.messages: object expected");
                                    message.messages[i] = $root.google.cloud.dialogflow.v2beta1.Message.fromObject(object.messages[i]);
                                }
                            }
                            if (object.nextPageToken != null)
                                message.nextPageToken = String(object.nextPageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListMessagesResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListMessagesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ListMessagesResponse} message ListMessagesResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListMessagesResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.messages = [];
                            if (options.defaults)
                                object.nextPageToken = "";
                            if (message.messages && message.messages.length) {
                                object.messages = [];
                                for (var j = 0; j < message.messages.length; ++j)
                                    object.messages[j] = $root.google.cloud.dialogflow.v2beta1.Message.toObject(message.messages[j], options);
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                object.nextPageToken = message.nextPageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListMessagesResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.ListMessagesResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListMessagesResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListMessagesResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.ListMessagesResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListMessagesResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ListMessagesResponse";
                        };
    
                        return ListMessagesResponse;
                    })();
    
                    v2beta1.IngestContextReferencesRequest = (function() {
    
                        /**
                         * Properties of an IngestContextReferencesRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IIngestContextReferencesRequest
                         * @property {string|null} [conversation] IngestContextReferencesRequest conversation
                         * @property {Object.<string,google.cloud.dialogflow.v2beta1.Conversation.IContextReference>|null} [contextReferences] IngestContextReferencesRequest contextReferences
                         */
    
                        /**
                         * Constructs a new IngestContextReferencesRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an IngestContextReferencesRequest.
                         * @implements IIngestContextReferencesRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IIngestContextReferencesRequest=} [properties] Properties to set
                         */
                        function IngestContextReferencesRequest(properties) {
                            this.contextReferences = {};
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * IngestContextReferencesRequest conversation.
                         * @member {string} conversation
                         * @memberof google.cloud.dialogflow.v2beta1.IngestContextReferencesRequest
                         * @instance
                         */
                        IngestContextReferencesRequest.prototype.conversation = "";
    
                        /**
                         * IngestContextReferencesRequest contextReferences.
                         * @member {Object.<string,google.cloud.dialogflow.v2beta1.Conversation.IContextReference>} contextReferences
                         * @memberof google.cloud.dialogflow.v2beta1.IngestContextReferencesRequest
                         * @instance
                         */
                        IngestContextReferencesRequest.prototype.contextReferences = $util.emptyObject;
    
                        /**
                         * Creates a new IngestContextReferencesRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.IngestContextReferencesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IIngestContextReferencesRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.IngestContextReferencesRequest} IngestContextReferencesRequest instance
                         */
                        IngestContextReferencesRequest.create = function create(properties) {
                            return new IngestContextReferencesRequest(properties);
                        };
    
                        /**
                         * Encodes the specified IngestContextReferencesRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.IngestContextReferencesRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.IngestContextReferencesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IIngestContextReferencesRequest} message IngestContextReferencesRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        IngestContextReferencesRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.conversation != null && Object.hasOwnProperty.call(message, "conversation"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.conversation);
                            if (message.contextReferences != null && Object.hasOwnProperty.call(message, "contextReferences"))
                                for (var keys = Object.keys(message.contextReferences), i = 0; i < keys.length; ++i) {
                                    writer.uint32(/* id 2, wireType 2 =*/18).fork().uint32(/* id 1, wireType 2 =*/10).string(keys[i]);
                                    $root.google.cloud.dialogflow.v2beta1.Conversation.ContextReference.encode(message.contextReferences[keys[i]], writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim().ldelim();
                                }
                            return writer;
                        };
    
                        /**
                         * Encodes the specified IngestContextReferencesRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.IngestContextReferencesRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.IngestContextReferencesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IIngestContextReferencesRequest} message IngestContextReferencesRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        IngestContextReferencesRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an IngestContextReferencesRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.IngestContextReferencesRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.IngestContextReferencesRequest} IngestContextReferencesRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        IngestContextReferencesRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.IngestContextReferencesRequest(), key, value;
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.conversation = reader.string();
                                        break;
                                    }
                                case 2: {
                                        if (message.contextReferences === $util.emptyObject)
                                            message.contextReferences = {};
                                        var end2 = reader.uint32() + reader.pos;
                                        key = "";
                                        value = null;
                                        while (reader.pos < end2) {
                                            var tag2 = reader.uint32();
                                            switch (tag2 >>> 3) {
                                            case 1:
                                                key = reader.string();
                                                break;
                                            case 2:
                                                value = $root.google.cloud.dialogflow.v2beta1.Conversation.ContextReference.decode(reader, reader.uint32());
                                                break;
                                            default:
                                                reader.skipType(tag2 & 7);
                                                break;
                                            }
                                        }
                                        message.contextReferences[key] = value;
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an IngestContextReferencesRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.IngestContextReferencesRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.IngestContextReferencesRequest} IngestContextReferencesRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        IngestContextReferencesRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an IngestContextReferencesRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.IngestContextReferencesRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        IngestContextReferencesRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.conversation != null && message.hasOwnProperty("conversation"))
                                if (!$util.isString(message.conversation))
                                    return "conversation: string expected";
                            if (message.contextReferences != null && message.hasOwnProperty("contextReferences")) {
                                if (!$util.isObject(message.contextReferences))
                                    return "contextReferences: object expected";
                                var key = Object.keys(message.contextReferences);
                                for (var i = 0; i < key.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.Conversation.ContextReference.verify(message.contextReferences[key[i]]);
                                    if (error)
                                        return "contextReferences." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates an IngestContextReferencesRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.IngestContextReferencesRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.IngestContextReferencesRequest} IngestContextReferencesRequest
                         */
                        IngestContextReferencesRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.IngestContextReferencesRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.IngestContextReferencesRequest();
                            if (object.conversation != null)
                                message.conversation = String(object.conversation);
                            if (object.contextReferences) {
                                if (typeof object.contextReferences !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.IngestContextReferencesRequest.contextReferences: object expected");
                                message.contextReferences = {};
                                for (var keys = Object.keys(object.contextReferences), i = 0; i < keys.length; ++i) {
                                    if (typeof object.contextReferences[keys[i]] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.IngestContextReferencesRequest.contextReferences: object expected");
                                    message.contextReferences[keys[i]] = $root.google.cloud.dialogflow.v2beta1.Conversation.ContextReference.fromObject(object.contextReferences[keys[i]]);
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an IngestContextReferencesRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.IngestContextReferencesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IngestContextReferencesRequest} message IngestContextReferencesRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        IngestContextReferencesRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.objects || options.defaults)
                                object.contextReferences = {};
                            if (options.defaults)
                                object.conversation = "";
                            if (message.conversation != null && message.hasOwnProperty("conversation"))
                                object.conversation = message.conversation;
                            var keys2;
                            if (message.contextReferences && (keys2 = Object.keys(message.contextReferences)).length) {
                                object.contextReferences = {};
                                for (var j = 0; j < keys2.length; ++j)
                                    object.contextReferences[keys2[j]] = $root.google.cloud.dialogflow.v2beta1.Conversation.ContextReference.toObject(message.contextReferences[keys2[j]], options);
                            }
                            return object;
                        };
    
                        /**
                         * Converts this IngestContextReferencesRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.IngestContextReferencesRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        IngestContextReferencesRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for IngestContextReferencesRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.IngestContextReferencesRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        IngestContextReferencesRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.IngestContextReferencesRequest";
                        };
    
                        return IngestContextReferencesRequest;
                    })();
    
                    v2beta1.IngestContextReferencesResponse = (function() {
    
                        /**
                         * Properties of an IngestContextReferencesResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IIngestContextReferencesResponse
                         * @property {Object.<string,google.cloud.dialogflow.v2beta1.Conversation.IContextReference>|null} [ingestedContextReferences] IngestContextReferencesResponse ingestedContextReferences
                         */
    
                        /**
                         * Constructs a new IngestContextReferencesResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an IngestContextReferencesResponse.
                         * @implements IIngestContextReferencesResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IIngestContextReferencesResponse=} [properties] Properties to set
                         */
                        function IngestContextReferencesResponse(properties) {
                            this.ingestedContextReferences = {};
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * IngestContextReferencesResponse ingestedContextReferences.
                         * @member {Object.<string,google.cloud.dialogflow.v2beta1.Conversation.IContextReference>} ingestedContextReferences
                         * @memberof google.cloud.dialogflow.v2beta1.IngestContextReferencesResponse
                         * @instance
                         */
                        IngestContextReferencesResponse.prototype.ingestedContextReferences = $util.emptyObject;
    
                        /**
                         * Creates a new IngestContextReferencesResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.IngestContextReferencesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IIngestContextReferencesResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.IngestContextReferencesResponse} IngestContextReferencesResponse instance
                         */
                        IngestContextReferencesResponse.create = function create(properties) {
                            return new IngestContextReferencesResponse(properties);
                        };
    
                        /**
                         * Encodes the specified IngestContextReferencesResponse message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.IngestContextReferencesResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.IngestContextReferencesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IIngestContextReferencesResponse} message IngestContextReferencesResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        IngestContextReferencesResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.ingestedContextReferences != null && Object.hasOwnProperty.call(message, "ingestedContextReferences"))
                                for (var keys = Object.keys(message.ingestedContextReferences), i = 0; i < keys.length; ++i) {
                                    writer.uint32(/* id 1, wireType 2 =*/10).fork().uint32(/* id 1, wireType 2 =*/10).string(keys[i]);
                                    $root.google.cloud.dialogflow.v2beta1.Conversation.ContextReference.encode(message.ingestedContextReferences[keys[i]], writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim().ldelim();
                                }
                            return writer;
                        };
    
                        /**
                         * Encodes the specified IngestContextReferencesResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.IngestContextReferencesResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.IngestContextReferencesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IIngestContextReferencesResponse} message IngestContextReferencesResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        IngestContextReferencesResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an IngestContextReferencesResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.IngestContextReferencesResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.IngestContextReferencesResponse} IngestContextReferencesResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        IngestContextReferencesResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.IngestContextReferencesResponse(), key, value;
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (message.ingestedContextReferences === $util.emptyObject)
                                            message.ingestedContextReferences = {};
                                        var end2 = reader.uint32() + reader.pos;
                                        key = "";
                                        value = null;
                                        while (reader.pos < end2) {
                                            var tag2 = reader.uint32();
                                            switch (tag2 >>> 3) {
                                            case 1:
                                                key = reader.string();
                                                break;
                                            case 2:
                                                value = $root.google.cloud.dialogflow.v2beta1.Conversation.ContextReference.decode(reader, reader.uint32());
                                                break;
                                            default:
                                                reader.skipType(tag2 & 7);
                                                break;
                                            }
                                        }
                                        message.ingestedContextReferences[key] = value;
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an IngestContextReferencesResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.IngestContextReferencesResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.IngestContextReferencesResponse} IngestContextReferencesResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        IngestContextReferencesResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an IngestContextReferencesResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.IngestContextReferencesResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        IngestContextReferencesResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.ingestedContextReferences != null && message.hasOwnProperty("ingestedContextReferences")) {
                                if (!$util.isObject(message.ingestedContextReferences))
                                    return "ingestedContextReferences: object expected";
                                var key = Object.keys(message.ingestedContextReferences);
                                for (var i = 0; i < key.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.Conversation.ContextReference.verify(message.ingestedContextReferences[key[i]]);
                                    if (error)
                                        return "ingestedContextReferences." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates an IngestContextReferencesResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.IngestContextReferencesResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.IngestContextReferencesResponse} IngestContextReferencesResponse
                         */
                        IngestContextReferencesResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.IngestContextReferencesResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.IngestContextReferencesResponse();
                            if (object.ingestedContextReferences) {
                                if (typeof object.ingestedContextReferences !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.IngestContextReferencesResponse.ingestedContextReferences: object expected");
                                message.ingestedContextReferences = {};
                                for (var keys = Object.keys(object.ingestedContextReferences), i = 0; i < keys.length; ++i) {
                                    if (typeof object.ingestedContextReferences[keys[i]] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.IngestContextReferencesResponse.ingestedContextReferences: object expected");
                                    message.ingestedContextReferences[keys[i]] = $root.google.cloud.dialogflow.v2beta1.Conversation.ContextReference.fromObject(object.ingestedContextReferences[keys[i]]);
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an IngestContextReferencesResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.IngestContextReferencesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IngestContextReferencesResponse} message IngestContextReferencesResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        IngestContextReferencesResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.objects || options.defaults)
                                object.ingestedContextReferences = {};
                            var keys2;
                            if (message.ingestedContextReferences && (keys2 = Object.keys(message.ingestedContextReferences)).length) {
                                object.ingestedContextReferences = {};
                                for (var j = 0; j < keys2.length; ++j)
                                    object.ingestedContextReferences[keys2[j]] = $root.google.cloud.dialogflow.v2beta1.Conversation.ContextReference.toObject(message.ingestedContextReferences[keys2[j]], options);
                            }
                            return object;
                        };
    
                        /**
                         * Converts this IngestContextReferencesResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.IngestContextReferencesResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        IngestContextReferencesResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for IngestContextReferencesResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.IngestContextReferencesResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        IngestContextReferencesResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.IngestContextReferencesResponse";
                        };
    
                        return IngestContextReferencesResponse;
                    })();
    
                    v2beta1.SuggestConversationSummaryRequest = (function() {
    
                        /**
                         * Properties of a SuggestConversationSummaryRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ISuggestConversationSummaryRequest
                         * @property {string|null} [conversation] SuggestConversationSummaryRequest conversation
                         * @property {string|null} [latestMessage] SuggestConversationSummaryRequest latestMessage
                         * @property {number|null} [contextSize] SuggestConversationSummaryRequest contextSize
                         * @property {google.cloud.dialogflow.v2beta1.IAssistQueryParameters|null} [assistQueryParams] SuggestConversationSummaryRequest assistQueryParams
                         */
    
                        /**
                         * Constructs a new SuggestConversationSummaryRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a SuggestConversationSummaryRequest.
                         * @implements ISuggestConversationSummaryRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestConversationSummaryRequest=} [properties] Properties to set
                         */
                        function SuggestConversationSummaryRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SuggestConversationSummaryRequest conversation.
                         * @member {string} conversation
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestConversationSummaryRequest
                         * @instance
                         */
                        SuggestConversationSummaryRequest.prototype.conversation = "";
    
                        /**
                         * SuggestConversationSummaryRequest latestMessage.
                         * @member {string} latestMessage
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestConversationSummaryRequest
                         * @instance
                         */
                        SuggestConversationSummaryRequest.prototype.latestMessage = "";
    
                        /**
                         * SuggestConversationSummaryRequest contextSize.
                         * @member {number} contextSize
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestConversationSummaryRequest
                         * @instance
                         */
                        SuggestConversationSummaryRequest.prototype.contextSize = 0;
    
                        /**
                         * SuggestConversationSummaryRequest assistQueryParams.
                         * @member {google.cloud.dialogflow.v2beta1.IAssistQueryParameters|null|undefined} assistQueryParams
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestConversationSummaryRequest
                         * @instance
                         */
                        SuggestConversationSummaryRequest.prototype.assistQueryParams = null;
    
                        /**
                         * Creates a new SuggestConversationSummaryRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestConversationSummaryRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestConversationSummaryRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.SuggestConversationSummaryRequest} SuggestConversationSummaryRequest instance
                         */
                        SuggestConversationSummaryRequest.create = function create(properties) {
                            return new SuggestConversationSummaryRequest(properties);
                        };
    
                        /**
                         * Encodes the specified SuggestConversationSummaryRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SuggestConversationSummaryRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestConversationSummaryRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestConversationSummaryRequest} message SuggestConversationSummaryRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SuggestConversationSummaryRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.conversation != null && Object.hasOwnProperty.call(message, "conversation"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.conversation);
                            if (message.latestMessage != null && Object.hasOwnProperty.call(message, "latestMessage"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.latestMessage);
                            if (message.contextSize != null && Object.hasOwnProperty.call(message, "contextSize"))
                                writer.uint32(/* id 4, wireType 0 =*/32).int32(message.contextSize);
                            if (message.assistQueryParams != null && Object.hasOwnProperty.call(message, "assistQueryParams"))
                                $root.google.cloud.dialogflow.v2beta1.AssistQueryParameters.encode(message.assistQueryParams, writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SuggestConversationSummaryRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SuggestConversationSummaryRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestConversationSummaryRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestConversationSummaryRequest} message SuggestConversationSummaryRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SuggestConversationSummaryRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SuggestConversationSummaryRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestConversationSummaryRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.SuggestConversationSummaryRequest} SuggestConversationSummaryRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SuggestConversationSummaryRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.SuggestConversationSummaryRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.conversation = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.latestMessage = reader.string();
                                        break;
                                    }
                                case 4: {
                                        message.contextSize = reader.int32();
                                        break;
                                    }
                                case 5: {
                                        message.assistQueryParams = $root.google.cloud.dialogflow.v2beta1.AssistQueryParameters.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SuggestConversationSummaryRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestConversationSummaryRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.SuggestConversationSummaryRequest} SuggestConversationSummaryRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SuggestConversationSummaryRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SuggestConversationSummaryRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestConversationSummaryRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SuggestConversationSummaryRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.conversation != null && message.hasOwnProperty("conversation"))
                                if (!$util.isString(message.conversation))
                                    return "conversation: string expected";
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                if (!$util.isString(message.latestMessage))
                                    return "latestMessage: string expected";
                            if (message.contextSize != null && message.hasOwnProperty("contextSize"))
                                if (!$util.isInteger(message.contextSize))
                                    return "contextSize: integer expected";
                            if (message.assistQueryParams != null && message.hasOwnProperty("assistQueryParams")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.AssistQueryParameters.verify(message.assistQueryParams);
                                if (error)
                                    return "assistQueryParams." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a SuggestConversationSummaryRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestConversationSummaryRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.SuggestConversationSummaryRequest} SuggestConversationSummaryRequest
                         */
                        SuggestConversationSummaryRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.SuggestConversationSummaryRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.SuggestConversationSummaryRequest();
                            if (object.conversation != null)
                                message.conversation = String(object.conversation);
                            if (object.latestMessage != null)
                                message.latestMessage = String(object.latestMessage);
                            if (object.contextSize != null)
                                message.contextSize = object.contextSize | 0;
                            if (object.assistQueryParams != null) {
                                if (typeof object.assistQueryParams !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.SuggestConversationSummaryRequest.assistQueryParams: object expected");
                                message.assistQueryParams = $root.google.cloud.dialogflow.v2beta1.AssistQueryParameters.fromObject(object.assistQueryParams);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SuggestConversationSummaryRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestConversationSummaryRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.SuggestConversationSummaryRequest} message SuggestConversationSummaryRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SuggestConversationSummaryRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.conversation = "";
                                object.latestMessage = "";
                                object.contextSize = 0;
                                object.assistQueryParams = null;
                            }
                            if (message.conversation != null && message.hasOwnProperty("conversation"))
                                object.conversation = message.conversation;
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                object.latestMessage = message.latestMessage;
                            if (message.contextSize != null && message.hasOwnProperty("contextSize"))
                                object.contextSize = message.contextSize;
                            if (message.assistQueryParams != null && message.hasOwnProperty("assistQueryParams"))
                                object.assistQueryParams = $root.google.cloud.dialogflow.v2beta1.AssistQueryParameters.toObject(message.assistQueryParams, options);
                            return object;
                        };
    
                        /**
                         * Converts this SuggestConversationSummaryRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestConversationSummaryRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SuggestConversationSummaryRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SuggestConversationSummaryRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestConversationSummaryRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SuggestConversationSummaryRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.SuggestConversationSummaryRequest";
                        };
    
                        return SuggestConversationSummaryRequest;
                    })();
    
                    v2beta1.SuggestConversationSummaryResponse = (function() {
    
                        /**
                         * Properties of a SuggestConversationSummaryResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ISuggestConversationSummaryResponse
                         * @property {google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse.ISummary|null} [summary] SuggestConversationSummaryResponse summary
                         * @property {string|null} [latestMessage] SuggestConversationSummaryResponse latestMessage
                         * @property {number|null} [contextSize] SuggestConversationSummaryResponse contextSize
                         */
    
                        /**
                         * Constructs a new SuggestConversationSummaryResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a SuggestConversationSummaryResponse.
                         * @implements ISuggestConversationSummaryResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestConversationSummaryResponse=} [properties] Properties to set
                         */
                        function SuggestConversationSummaryResponse(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SuggestConversationSummaryResponse summary.
                         * @member {google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse.ISummary|null|undefined} summary
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse
                         * @instance
                         */
                        SuggestConversationSummaryResponse.prototype.summary = null;
    
                        /**
                         * SuggestConversationSummaryResponse latestMessage.
                         * @member {string} latestMessage
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse
                         * @instance
                         */
                        SuggestConversationSummaryResponse.prototype.latestMessage = "";
    
                        /**
                         * SuggestConversationSummaryResponse contextSize.
                         * @member {number} contextSize
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse
                         * @instance
                         */
                        SuggestConversationSummaryResponse.prototype.contextSize = 0;
    
                        /**
                         * Creates a new SuggestConversationSummaryResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestConversationSummaryResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse} SuggestConversationSummaryResponse instance
                         */
                        SuggestConversationSummaryResponse.create = function create(properties) {
                            return new SuggestConversationSummaryResponse(properties);
                        };
    
                        /**
                         * Encodes the specified SuggestConversationSummaryResponse message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestConversationSummaryResponse} message SuggestConversationSummaryResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SuggestConversationSummaryResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.summary != null && Object.hasOwnProperty.call(message, "summary"))
                                $root.google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse.Summary.encode(message.summary, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.latestMessage != null && Object.hasOwnProperty.call(message, "latestMessage"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.latestMessage);
                            if (message.contextSize != null && Object.hasOwnProperty.call(message, "contextSize"))
                                writer.uint32(/* id 3, wireType 0 =*/24).int32(message.contextSize);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SuggestConversationSummaryResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISuggestConversationSummaryResponse} message SuggestConversationSummaryResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SuggestConversationSummaryResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SuggestConversationSummaryResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse} SuggestConversationSummaryResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SuggestConversationSummaryResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.summary = $root.google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse.Summary.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.latestMessage = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.contextSize = reader.int32();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SuggestConversationSummaryResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse} SuggestConversationSummaryResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SuggestConversationSummaryResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SuggestConversationSummaryResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SuggestConversationSummaryResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.summary != null && message.hasOwnProperty("summary")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse.Summary.verify(message.summary);
                                if (error)
                                    return "summary." + error;
                            }
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                if (!$util.isString(message.latestMessage))
                                    return "latestMessage: string expected";
                            if (message.contextSize != null && message.hasOwnProperty("contextSize"))
                                if (!$util.isInteger(message.contextSize))
                                    return "contextSize: integer expected";
                            return null;
                        };
    
                        /**
                         * Creates a SuggestConversationSummaryResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse} SuggestConversationSummaryResponse
                         */
                        SuggestConversationSummaryResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse();
                            if (object.summary != null) {
                                if (typeof object.summary !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse.summary: object expected");
                                message.summary = $root.google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse.Summary.fromObject(object.summary);
                            }
                            if (object.latestMessage != null)
                                message.latestMessage = String(object.latestMessage);
                            if (object.contextSize != null)
                                message.contextSize = object.contextSize | 0;
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SuggestConversationSummaryResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse} message SuggestConversationSummaryResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SuggestConversationSummaryResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.summary = null;
                                object.latestMessage = "";
                                object.contextSize = 0;
                            }
                            if (message.summary != null && message.hasOwnProperty("summary"))
                                object.summary = $root.google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse.Summary.toObject(message.summary, options);
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                object.latestMessage = message.latestMessage;
                            if (message.contextSize != null && message.hasOwnProperty("contextSize"))
                                object.contextSize = message.contextSize;
                            return object;
                        };
    
                        /**
                         * Converts this SuggestConversationSummaryResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SuggestConversationSummaryResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SuggestConversationSummaryResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SuggestConversationSummaryResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse";
                        };
    
                        SuggestConversationSummaryResponse.Summary = (function() {
    
                            /**
                             * Properties of a Summary.
                             * @memberof google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse
                             * @interface ISummary
                             * @property {string|null} [text] Summary text
                             * @property {Object.<string,string>|null} [textSections] Summary textSections
                             * @property {string|null} [answerRecord] Summary answerRecord
                             * @property {string|null} [baselineModelVersion] Summary baselineModelVersion
                             */
    
                            /**
                             * Constructs a new Summary.
                             * @memberof google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse
                             * @classdesc Represents a Summary.
                             * @implements ISummary
                             * @constructor
                             * @param {google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse.ISummary=} [properties] Properties to set
                             */
                            function Summary(properties) {
                                this.textSections = {};
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * Summary text.
                             * @member {string} text
                             * @memberof google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse.Summary
                             * @instance
                             */
                            Summary.prototype.text = "";
    
                            /**
                             * Summary textSections.
                             * @member {Object.<string,string>} textSections
                             * @memberof google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse.Summary
                             * @instance
                             */
                            Summary.prototype.textSections = $util.emptyObject;
    
                            /**
                             * Summary answerRecord.
                             * @member {string} answerRecord
                             * @memberof google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse.Summary
                             * @instance
                             */
                            Summary.prototype.answerRecord = "";
    
                            /**
                             * Summary baselineModelVersion.
                             * @member {string} baselineModelVersion
                             * @memberof google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse.Summary
                             * @instance
                             */
                            Summary.prototype.baselineModelVersion = "";
    
                            /**
                             * Creates a new Summary instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse.Summary
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse.ISummary=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse.Summary} Summary instance
                             */
                            Summary.create = function create(properties) {
                                return new Summary(properties);
                            };
    
                            /**
                             * Encodes the specified Summary message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse.Summary.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse.Summary
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse.ISummary} message Summary message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            Summary.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.text != null && Object.hasOwnProperty.call(message, "text"))
                                    writer.uint32(/* id 1, wireType 2 =*/10).string(message.text);
                                if (message.answerRecord != null && Object.hasOwnProperty.call(message, "answerRecord"))
                                    writer.uint32(/* id 3, wireType 2 =*/26).string(message.answerRecord);
                                if (message.textSections != null && Object.hasOwnProperty.call(message, "textSections"))
                                    for (var keys = Object.keys(message.textSections), i = 0; i < keys.length; ++i)
                                        writer.uint32(/* id 4, wireType 2 =*/34).fork().uint32(/* id 1, wireType 2 =*/10).string(keys[i]).uint32(/* id 2, wireType 2 =*/18).string(message.textSections[keys[i]]).ldelim();
                                if (message.baselineModelVersion != null && Object.hasOwnProperty.call(message, "baselineModelVersion"))
                                    writer.uint32(/* id 5, wireType 2 =*/42).string(message.baselineModelVersion);
                                return writer;
                            };
    
                            /**
                             * Encodes the specified Summary message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse.Summary.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse.Summary
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse.ISummary} message Summary message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            Summary.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a Summary message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse.Summary
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse.Summary} Summary
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            Summary.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse.Summary(), key, value;
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.text = reader.string();
                                            break;
                                        }
                                    case 4: {
                                            if (message.textSections === $util.emptyObject)
                                                message.textSections = {};
                                            var end2 = reader.uint32() + reader.pos;
                                            key = "";
                                            value = "";
                                            while (reader.pos < end2) {
                                                var tag2 = reader.uint32();
                                                switch (tag2 >>> 3) {
                                                case 1:
                                                    key = reader.string();
                                                    break;
                                                case 2:
                                                    value = reader.string();
                                                    break;
                                                default:
                                                    reader.skipType(tag2 & 7);
                                                    break;
                                                }
                                            }
                                            message.textSections[key] = value;
                                            break;
                                        }
                                    case 3: {
                                            message.answerRecord = reader.string();
                                            break;
                                        }
                                    case 5: {
                                            message.baselineModelVersion = reader.string();
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a Summary message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse.Summary
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse.Summary} Summary
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            Summary.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a Summary message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse.Summary
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            Summary.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.text != null && message.hasOwnProperty("text"))
                                    if (!$util.isString(message.text))
                                        return "text: string expected";
                                if (message.textSections != null && message.hasOwnProperty("textSections")) {
                                    if (!$util.isObject(message.textSections))
                                        return "textSections: object expected";
                                    var key = Object.keys(message.textSections);
                                    for (var i = 0; i < key.length; ++i)
                                        if (!$util.isString(message.textSections[key[i]]))
                                            return "textSections: string{k:string} expected";
                                }
                                if (message.answerRecord != null && message.hasOwnProperty("answerRecord"))
                                    if (!$util.isString(message.answerRecord))
                                        return "answerRecord: string expected";
                                if (message.baselineModelVersion != null && message.hasOwnProperty("baselineModelVersion"))
                                    if (!$util.isString(message.baselineModelVersion))
                                        return "baselineModelVersion: string expected";
                                return null;
                            };
    
                            /**
                             * Creates a Summary message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse.Summary
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse.Summary} Summary
                             */
                            Summary.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse.Summary)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse.Summary();
                                if (object.text != null)
                                    message.text = String(object.text);
                                if (object.textSections) {
                                    if (typeof object.textSections !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse.Summary.textSections: object expected");
                                    message.textSections = {};
                                    for (var keys = Object.keys(object.textSections), i = 0; i < keys.length; ++i)
                                        message.textSections[keys[i]] = String(object.textSections[keys[i]]);
                                }
                                if (object.answerRecord != null)
                                    message.answerRecord = String(object.answerRecord);
                                if (object.baselineModelVersion != null)
                                    message.baselineModelVersion = String(object.baselineModelVersion);
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a Summary message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse.Summary
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse.Summary} message Summary
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            Summary.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.objects || options.defaults)
                                    object.textSections = {};
                                if (options.defaults) {
                                    object.text = "";
                                    object.answerRecord = "";
                                    object.baselineModelVersion = "";
                                }
                                if (message.text != null && message.hasOwnProperty("text"))
                                    object.text = message.text;
                                if (message.answerRecord != null && message.hasOwnProperty("answerRecord"))
                                    object.answerRecord = message.answerRecord;
                                var keys2;
                                if (message.textSections && (keys2 = Object.keys(message.textSections)).length) {
                                    object.textSections = {};
                                    for (var j = 0; j < keys2.length; ++j)
                                        object.textSections[keys2[j]] = message.textSections[keys2[j]];
                                }
                                if (message.baselineModelVersion != null && message.hasOwnProperty("baselineModelVersion"))
                                    object.baselineModelVersion = message.baselineModelVersion;
                                return object;
                            };
    
                            /**
                             * Converts this Summary to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse.Summary
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            Summary.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for Summary
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse.Summary
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            Summary.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.SuggestConversationSummaryResponse.Summary";
                            };
    
                            return Summary;
                        })();
    
                        return SuggestConversationSummaryResponse;
                    })();
    
                    v2beta1.GenerateStatelessSummaryRequest = (function() {
    
                        /**
                         * Properties of a GenerateStatelessSummaryRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IGenerateStatelessSummaryRequest
                         * @property {google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest.IMinimalConversation|null} [statelessConversation] GenerateStatelessSummaryRequest statelessConversation
                         * @property {google.cloud.dialogflow.v2beta1.IConversationProfile|null} [conversationProfile] GenerateStatelessSummaryRequest conversationProfile
                         * @property {string|null} [latestMessage] GenerateStatelessSummaryRequest latestMessage
                         * @property {number|null} [maxContextSize] GenerateStatelessSummaryRequest maxContextSize
                         */
    
                        /**
                         * Constructs a new GenerateStatelessSummaryRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a GenerateStatelessSummaryRequest.
                         * @implements IGenerateStatelessSummaryRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IGenerateStatelessSummaryRequest=} [properties] Properties to set
                         */
                        function GenerateStatelessSummaryRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GenerateStatelessSummaryRequest statelessConversation.
                         * @member {google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest.IMinimalConversation|null|undefined} statelessConversation
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest
                         * @instance
                         */
                        GenerateStatelessSummaryRequest.prototype.statelessConversation = null;
    
                        /**
                         * GenerateStatelessSummaryRequest conversationProfile.
                         * @member {google.cloud.dialogflow.v2beta1.IConversationProfile|null|undefined} conversationProfile
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest
                         * @instance
                         */
                        GenerateStatelessSummaryRequest.prototype.conversationProfile = null;
    
                        /**
                         * GenerateStatelessSummaryRequest latestMessage.
                         * @member {string} latestMessage
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest
                         * @instance
                         */
                        GenerateStatelessSummaryRequest.prototype.latestMessage = "";
    
                        /**
                         * GenerateStatelessSummaryRequest maxContextSize.
                         * @member {number} maxContextSize
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest
                         * @instance
                         */
                        GenerateStatelessSummaryRequest.prototype.maxContextSize = 0;
    
                        /**
                         * Creates a new GenerateStatelessSummaryRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGenerateStatelessSummaryRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest} GenerateStatelessSummaryRequest instance
                         */
                        GenerateStatelessSummaryRequest.create = function create(properties) {
                            return new GenerateStatelessSummaryRequest(properties);
                        };
    
                        /**
                         * Encodes the specified GenerateStatelessSummaryRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGenerateStatelessSummaryRequest} message GenerateStatelessSummaryRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GenerateStatelessSummaryRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.statelessConversation != null && Object.hasOwnProperty.call(message, "statelessConversation"))
                                $root.google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest.MinimalConversation.encode(message.statelessConversation, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.conversationProfile != null && Object.hasOwnProperty.call(message, "conversationProfile"))
                                $root.google.cloud.dialogflow.v2beta1.ConversationProfile.encode(message.conversationProfile, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.latestMessage != null && Object.hasOwnProperty.call(message, "latestMessage"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.latestMessage);
                            if (message.maxContextSize != null && Object.hasOwnProperty.call(message, "maxContextSize"))
                                writer.uint32(/* id 4, wireType 0 =*/32).int32(message.maxContextSize);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GenerateStatelessSummaryRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGenerateStatelessSummaryRequest} message GenerateStatelessSummaryRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GenerateStatelessSummaryRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GenerateStatelessSummaryRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest} GenerateStatelessSummaryRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GenerateStatelessSummaryRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.statelessConversation = $root.google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest.MinimalConversation.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.conversationProfile = $root.google.cloud.dialogflow.v2beta1.ConversationProfile.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 3: {
                                        message.latestMessage = reader.string();
                                        break;
                                    }
                                case 4: {
                                        message.maxContextSize = reader.int32();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GenerateStatelessSummaryRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest} GenerateStatelessSummaryRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GenerateStatelessSummaryRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GenerateStatelessSummaryRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GenerateStatelessSummaryRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.statelessConversation != null && message.hasOwnProperty("statelessConversation")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest.MinimalConversation.verify(message.statelessConversation);
                                if (error)
                                    return "statelessConversation." + error;
                            }
                            if (message.conversationProfile != null && message.hasOwnProperty("conversationProfile")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.ConversationProfile.verify(message.conversationProfile);
                                if (error)
                                    return "conversationProfile." + error;
                            }
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                if (!$util.isString(message.latestMessage))
                                    return "latestMessage: string expected";
                            if (message.maxContextSize != null && message.hasOwnProperty("maxContextSize"))
                                if (!$util.isInteger(message.maxContextSize))
                                    return "maxContextSize: integer expected";
                            return null;
                        };
    
                        /**
                         * Creates a GenerateStatelessSummaryRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest} GenerateStatelessSummaryRequest
                         */
                        GenerateStatelessSummaryRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest();
                            if (object.statelessConversation != null) {
                                if (typeof object.statelessConversation !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest.statelessConversation: object expected");
                                message.statelessConversation = $root.google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest.MinimalConversation.fromObject(object.statelessConversation);
                            }
                            if (object.conversationProfile != null) {
                                if (typeof object.conversationProfile !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest.conversationProfile: object expected");
                                message.conversationProfile = $root.google.cloud.dialogflow.v2beta1.ConversationProfile.fromObject(object.conversationProfile);
                            }
                            if (object.latestMessage != null)
                                message.latestMessage = String(object.latestMessage);
                            if (object.maxContextSize != null)
                                message.maxContextSize = object.maxContextSize | 0;
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GenerateStatelessSummaryRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest} message GenerateStatelessSummaryRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GenerateStatelessSummaryRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.statelessConversation = null;
                                object.conversationProfile = null;
                                object.latestMessage = "";
                                object.maxContextSize = 0;
                            }
                            if (message.statelessConversation != null && message.hasOwnProperty("statelessConversation"))
                                object.statelessConversation = $root.google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest.MinimalConversation.toObject(message.statelessConversation, options);
                            if (message.conversationProfile != null && message.hasOwnProperty("conversationProfile"))
                                object.conversationProfile = $root.google.cloud.dialogflow.v2beta1.ConversationProfile.toObject(message.conversationProfile, options);
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                object.latestMessage = message.latestMessage;
                            if (message.maxContextSize != null && message.hasOwnProperty("maxContextSize"))
                                object.maxContextSize = message.maxContextSize;
                            return object;
                        };
    
                        /**
                         * Converts this GenerateStatelessSummaryRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GenerateStatelessSummaryRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GenerateStatelessSummaryRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GenerateStatelessSummaryRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest";
                        };
    
                        GenerateStatelessSummaryRequest.MinimalConversation = (function() {
    
                            /**
                             * Properties of a MinimalConversation.
                             * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest
                             * @interface IMinimalConversation
                             * @property {Array.<google.cloud.dialogflow.v2beta1.IMessage>|null} [messages] MinimalConversation messages
                             * @property {string|null} [parent] MinimalConversation parent
                             */
    
                            /**
                             * Constructs a new MinimalConversation.
                             * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest
                             * @classdesc Represents a MinimalConversation.
                             * @implements IMinimalConversation
                             * @constructor
                             * @param {google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest.IMinimalConversation=} [properties] Properties to set
                             */
                            function MinimalConversation(properties) {
                                this.messages = [];
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * MinimalConversation messages.
                             * @member {Array.<google.cloud.dialogflow.v2beta1.IMessage>} messages
                             * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest.MinimalConversation
                             * @instance
                             */
                            MinimalConversation.prototype.messages = $util.emptyArray;
    
                            /**
                             * MinimalConversation parent.
                             * @member {string} parent
                             * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest.MinimalConversation
                             * @instance
                             */
                            MinimalConversation.prototype.parent = "";
    
                            /**
                             * Creates a new MinimalConversation instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest.MinimalConversation
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest.IMinimalConversation=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest.MinimalConversation} MinimalConversation instance
                             */
                            MinimalConversation.create = function create(properties) {
                                return new MinimalConversation(properties);
                            };
    
                            /**
                             * Encodes the specified MinimalConversation message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest.MinimalConversation.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest.MinimalConversation
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest.IMinimalConversation} message MinimalConversation message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            MinimalConversation.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.messages != null && message.messages.length)
                                    for (var i = 0; i < message.messages.length; ++i)
                                        $root.google.cloud.dialogflow.v2beta1.Message.encode(message.messages[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                                if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                    writer.uint32(/* id 2, wireType 2 =*/18).string(message.parent);
                                return writer;
                            };
    
                            /**
                             * Encodes the specified MinimalConversation message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest.MinimalConversation.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest.MinimalConversation
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest.IMinimalConversation} message MinimalConversation message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            MinimalConversation.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a MinimalConversation message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest.MinimalConversation
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest.MinimalConversation} MinimalConversation
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            MinimalConversation.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest.MinimalConversation();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            if (!(message.messages && message.messages.length))
                                                message.messages = [];
                                            message.messages.push($root.google.cloud.dialogflow.v2beta1.Message.decode(reader, reader.uint32()));
                                            break;
                                        }
                                    case 2: {
                                            message.parent = reader.string();
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a MinimalConversation message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest.MinimalConversation
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest.MinimalConversation} MinimalConversation
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            MinimalConversation.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a MinimalConversation message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest.MinimalConversation
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            MinimalConversation.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.messages != null && message.hasOwnProperty("messages")) {
                                    if (!Array.isArray(message.messages))
                                        return "messages: array expected";
                                    for (var i = 0; i < message.messages.length; ++i) {
                                        var error = $root.google.cloud.dialogflow.v2beta1.Message.verify(message.messages[i]);
                                        if (error)
                                            return "messages." + error;
                                    }
                                }
                                if (message.parent != null && message.hasOwnProperty("parent"))
                                    if (!$util.isString(message.parent))
                                        return "parent: string expected";
                                return null;
                            };
    
                            /**
                             * Creates a MinimalConversation message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest.MinimalConversation
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest.MinimalConversation} MinimalConversation
                             */
                            MinimalConversation.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest.MinimalConversation)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest.MinimalConversation();
                                if (object.messages) {
                                    if (!Array.isArray(object.messages))
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest.MinimalConversation.messages: array expected");
                                    message.messages = [];
                                    for (var i = 0; i < object.messages.length; ++i) {
                                        if (typeof object.messages[i] !== "object")
                                            throw TypeError(".google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest.MinimalConversation.messages: object expected");
                                        message.messages[i] = $root.google.cloud.dialogflow.v2beta1.Message.fromObject(object.messages[i]);
                                    }
                                }
                                if (object.parent != null)
                                    message.parent = String(object.parent);
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a MinimalConversation message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest.MinimalConversation
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest.MinimalConversation} message MinimalConversation
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            MinimalConversation.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.arrays || options.defaults)
                                    object.messages = [];
                                if (options.defaults)
                                    object.parent = "";
                                if (message.messages && message.messages.length) {
                                    object.messages = [];
                                    for (var j = 0; j < message.messages.length; ++j)
                                        object.messages[j] = $root.google.cloud.dialogflow.v2beta1.Message.toObject(message.messages[j], options);
                                }
                                if (message.parent != null && message.hasOwnProperty("parent"))
                                    object.parent = message.parent;
                                return object;
                            };
    
                            /**
                             * Converts this MinimalConversation to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest.MinimalConversation
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            MinimalConversation.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for MinimalConversation
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest.MinimalConversation
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            MinimalConversation.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryRequest.MinimalConversation";
                            };
    
                            return MinimalConversation;
                        })();
    
                        return GenerateStatelessSummaryRequest;
                    })();
    
                    v2beta1.GenerateStatelessSummaryResponse = (function() {
    
                        /**
                         * Properties of a GenerateStatelessSummaryResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IGenerateStatelessSummaryResponse
                         * @property {google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse.ISummary|null} [summary] GenerateStatelessSummaryResponse summary
                         * @property {string|null} [latestMessage] GenerateStatelessSummaryResponse latestMessage
                         * @property {number|null} [contextSize] GenerateStatelessSummaryResponse contextSize
                         */
    
                        /**
                         * Constructs a new GenerateStatelessSummaryResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a GenerateStatelessSummaryResponse.
                         * @implements IGenerateStatelessSummaryResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IGenerateStatelessSummaryResponse=} [properties] Properties to set
                         */
                        function GenerateStatelessSummaryResponse(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GenerateStatelessSummaryResponse summary.
                         * @member {google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse.ISummary|null|undefined} summary
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse
                         * @instance
                         */
                        GenerateStatelessSummaryResponse.prototype.summary = null;
    
                        /**
                         * GenerateStatelessSummaryResponse latestMessage.
                         * @member {string} latestMessage
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse
                         * @instance
                         */
                        GenerateStatelessSummaryResponse.prototype.latestMessage = "";
    
                        /**
                         * GenerateStatelessSummaryResponse contextSize.
                         * @member {number} contextSize
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse
                         * @instance
                         */
                        GenerateStatelessSummaryResponse.prototype.contextSize = 0;
    
                        /**
                         * Creates a new GenerateStatelessSummaryResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGenerateStatelessSummaryResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse} GenerateStatelessSummaryResponse instance
                         */
                        GenerateStatelessSummaryResponse.create = function create(properties) {
                            return new GenerateStatelessSummaryResponse(properties);
                        };
    
                        /**
                         * Encodes the specified GenerateStatelessSummaryResponse message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGenerateStatelessSummaryResponse} message GenerateStatelessSummaryResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GenerateStatelessSummaryResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.summary != null && Object.hasOwnProperty.call(message, "summary"))
                                $root.google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse.Summary.encode(message.summary, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.latestMessage != null && Object.hasOwnProperty.call(message, "latestMessage"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.latestMessage);
                            if (message.contextSize != null && Object.hasOwnProperty.call(message, "contextSize"))
                                writer.uint32(/* id 3, wireType 0 =*/24).int32(message.contextSize);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GenerateStatelessSummaryResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGenerateStatelessSummaryResponse} message GenerateStatelessSummaryResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GenerateStatelessSummaryResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GenerateStatelessSummaryResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse} GenerateStatelessSummaryResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GenerateStatelessSummaryResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.summary = $root.google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse.Summary.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.latestMessage = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.contextSize = reader.int32();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GenerateStatelessSummaryResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse} GenerateStatelessSummaryResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GenerateStatelessSummaryResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GenerateStatelessSummaryResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GenerateStatelessSummaryResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.summary != null && message.hasOwnProperty("summary")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse.Summary.verify(message.summary);
                                if (error)
                                    return "summary." + error;
                            }
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                if (!$util.isString(message.latestMessage))
                                    return "latestMessage: string expected";
                            if (message.contextSize != null && message.hasOwnProperty("contextSize"))
                                if (!$util.isInteger(message.contextSize))
                                    return "contextSize: integer expected";
                            return null;
                        };
    
                        /**
                         * Creates a GenerateStatelessSummaryResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse} GenerateStatelessSummaryResponse
                         */
                        GenerateStatelessSummaryResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse();
                            if (object.summary != null) {
                                if (typeof object.summary !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse.summary: object expected");
                                message.summary = $root.google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse.Summary.fromObject(object.summary);
                            }
                            if (object.latestMessage != null)
                                message.latestMessage = String(object.latestMessage);
                            if (object.contextSize != null)
                                message.contextSize = object.contextSize | 0;
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GenerateStatelessSummaryResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse} message GenerateStatelessSummaryResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GenerateStatelessSummaryResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.summary = null;
                                object.latestMessage = "";
                                object.contextSize = 0;
                            }
                            if (message.summary != null && message.hasOwnProperty("summary"))
                                object.summary = $root.google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse.Summary.toObject(message.summary, options);
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                object.latestMessage = message.latestMessage;
                            if (message.contextSize != null && message.hasOwnProperty("contextSize"))
                                object.contextSize = message.contextSize;
                            return object;
                        };
    
                        /**
                         * Converts this GenerateStatelessSummaryResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GenerateStatelessSummaryResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GenerateStatelessSummaryResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GenerateStatelessSummaryResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse";
                        };
    
                        GenerateStatelessSummaryResponse.Summary = (function() {
    
                            /**
                             * Properties of a Summary.
                             * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse
                             * @interface ISummary
                             * @property {string|null} [text] Summary text
                             * @property {Object.<string,string>|null} [textSections] Summary textSections
                             * @property {string|null} [baselineModelVersion] Summary baselineModelVersion
                             */
    
                            /**
                             * Constructs a new Summary.
                             * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse
                             * @classdesc Represents a Summary.
                             * @implements ISummary
                             * @constructor
                             * @param {google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse.ISummary=} [properties] Properties to set
                             */
                            function Summary(properties) {
                                this.textSections = {};
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * Summary text.
                             * @member {string} text
                             * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse.Summary
                             * @instance
                             */
                            Summary.prototype.text = "";
    
                            /**
                             * Summary textSections.
                             * @member {Object.<string,string>} textSections
                             * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse.Summary
                             * @instance
                             */
                            Summary.prototype.textSections = $util.emptyObject;
    
                            /**
                             * Summary baselineModelVersion.
                             * @member {string} baselineModelVersion
                             * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse.Summary
                             * @instance
                             */
                            Summary.prototype.baselineModelVersion = "";
    
                            /**
                             * Creates a new Summary instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse.Summary
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse.ISummary=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse.Summary} Summary instance
                             */
                            Summary.create = function create(properties) {
                                return new Summary(properties);
                            };
    
                            /**
                             * Encodes the specified Summary message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse.Summary.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse.Summary
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse.ISummary} message Summary message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            Summary.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.text != null && Object.hasOwnProperty.call(message, "text"))
                                    writer.uint32(/* id 1, wireType 2 =*/10).string(message.text);
                                if (message.textSections != null && Object.hasOwnProperty.call(message, "textSections"))
                                    for (var keys = Object.keys(message.textSections), i = 0; i < keys.length; ++i)
                                        writer.uint32(/* id 2, wireType 2 =*/18).fork().uint32(/* id 1, wireType 2 =*/10).string(keys[i]).uint32(/* id 2, wireType 2 =*/18).string(message.textSections[keys[i]]).ldelim();
                                if (message.baselineModelVersion != null && Object.hasOwnProperty.call(message, "baselineModelVersion"))
                                    writer.uint32(/* id 4, wireType 2 =*/34).string(message.baselineModelVersion);
                                return writer;
                            };
    
                            /**
                             * Encodes the specified Summary message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse.Summary.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse.Summary
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse.ISummary} message Summary message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            Summary.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a Summary message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse.Summary
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse.Summary} Summary
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            Summary.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse.Summary(), key, value;
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.text = reader.string();
                                            break;
                                        }
                                    case 2: {
                                            if (message.textSections === $util.emptyObject)
                                                message.textSections = {};
                                            var end2 = reader.uint32() + reader.pos;
                                            key = "";
                                            value = "";
                                            while (reader.pos < end2) {
                                                var tag2 = reader.uint32();
                                                switch (tag2 >>> 3) {
                                                case 1:
                                                    key = reader.string();
                                                    break;
                                                case 2:
                                                    value = reader.string();
                                                    break;
                                                default:
                                                    reader.skipType(tag2 & 7);
                                                    break;
                                                }
                                            }
                                            message.textSections[key] = value;
                                            break;
                                        }
                                    case 4: {
                                            message.baselineModelVersion = reader.string();
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a Summary message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse.Summary
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse.Summary} Summary
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            Summary.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a Summary message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse.Summary
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            Summary.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.text != null && message.hasOwnProperty("text"))
                                    if (!$util.isString(message.text))
                                        return "text: string expected";
                                if (message.textSections != null && message.hasOwnProperty("textSections")) {
                                    if (!$util.isObject(message.textSections))
                                        return "textSections: object expected";
                                    var key = Object.keys(message.textSections);
                                    for (var i = 0; i < key.length; ++i)
                                        if (!$util.isString(message.textSections[key[i]]))
                                            return "textSections: string{k:string} expected";
                                }
                                if (message.baselineModelVersion != null && message.hasOwnProperty("baselineModelVersion"))
                                    if (!$util.isString(message.baselineModelVersion))
                                        return "baselineModelVersion: string expected";
                                return null;
                            };
    
                            /**
                             * Creates a Summary message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse.Summary
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse.Summary} Summary
                             */
                            Summary.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse.Summary)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse.Summary();
                                if (object.text != null)
                                    message.text = String(object.text);
                                if (object.textSections) {
                                    if (typeof object.textSections !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse.Summary.textSections: object expected");
                                    message.textSections = {};
                                    for (var keys = Object.keys(object.textSections), i = 0; i < keys.length; ++i)
                                        message.textSections[keys[i]] = String(object.textSections[keys[i]]);
                                }
                                if (object.baselineModelVersion != null)
                                    message.baselineModelVersion = String(object.baselineModelVersion);
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a Summary message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse.Summary
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse.Summary} message Summary
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            Summary.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.objects || options.defaults)
                                    object.textSections = {};
                                if (options.defaults) {
                                    object.text = "";
                                    object.baselineModelVersion = "";
                                }
                                if (message.text != null && message.hasOwnProperty("text"))
                                    object.text = message.text;
                                var keys2;
                                if (message.textSections && (keys2 = Object.keys(message.textSections)).length) {
                                    object.textSections = {};
                                    for (var j = 0; j < keys2.length; ++j)
                                        object.textSections[keys2[j]] = message.textSections[keys2[j]];
                                }
                                if (message.baselineModelVersion != null && message.hasOwnProperty("baselineModelVersion"))
                                    object.baselineModelVersion = message.baselineModelVersion;
                                return object;
                            };
    
                            /**
                             * Converts this Summary to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse.Summary
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            Summary.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for Summary
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse.Summary
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            Summary.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.GenerateStatelessSummaryResponse.Summary";
                            };
    
                            return Summary;
                        })();
    
                        return GenerateStatelessSummaryResponse;
                    })();
    
                    v2beta1.GenerateStatelessSuggestionRequest = (function() {
    
                        /**
                         * Properties of a GenerateStatelessSuggestionRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IGenerateStatelessSuggestionRequest
                         * @property {string|null} [parent] GenerateStatelessSuggestionRequest parent
                         * @property {google.cloud.dialogflow.v2beta1.IGenerator|null} [generator] GenerateStatelessSuggestionRequest generator
                         * @property {string|null} [generatorName] GenerateStatelessSuggestionRequest generatorName
                         * @property {Object.<string,google.cloud.dialogflow.v2beta1.Conversation.IContextReference>|null} [contextReferences] GenerateStatelessSuggestionRequest contextReferences
                         * @property {google.cloud.dialogflow.v2beta1.IConversationContext|null} [conversationContext] GenerateStatelessSuggestionRequest conversationContext
                         * @property {Array.<google.cloud.dialogflow.v2beta1.TriggerEvent>|null} [triggerEvents] GenerateStatelessSuggestionRequest triggerEvents
                         */
    
                        /**
                         * Constructs a new GenerateStatelessSuggestionRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a GenerateStatelessSuggestionRequest.
                         * @implements IGenerateStatelessSuggestionRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IGenerateStatelessSuggestionRequest=} [properties] Properties to set
                         */
                        function GenerateStatelessSuggestionRequest(properties) {
                            this.contextReferences = {};
                            this.triggerEvents = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GenerateStatelessSuggestionRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionRequest
                         * @instance
                         */
                        GenerateStatelessSuggestionRequest.prototype.parent = "";
    
                        /**
                         * GenerateStatelessSuggestionRequest generator.
                         * @member {google.cloud.dialogflow.v2beta1.IGenerator|null|undefined} generator
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionRequest
                         * @instance
                         */
                        GenerateStatelessSuggestionRequest.prototype.generator = null;
    
                        /**
                         * GenerateStatelessSuggestionRequest generatorName.
                         * @member {string|null|undefined} generatorName
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionRequest
                         * @instance
                         */
                        GenerateStatelessSuggestionRequest.prototype.generatorName = null;
    
                        /**
                         * GenerateStatelessSuggestionRequest contextReferences.
                         * @member {Object.<string,google.cloud.dialogflow.v2beta1.Conversation.IContextReference>} contextReferences
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionRequest
                         * @instance
                         */
                        GenerateStatelessSuggestionRequest.prototype.contextReferences = $util.emptyObject;
    
                        /**
                         * GenerateStatelessSuggestionRequest conversationContext.
                         * @member {google.cloud.dialogflow.v2beta1.IConversationContext|null|undefined} conversationContext
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionRequest
                         * @instance
                         */
                        GenerateStatelessSuggestionRequest.prototype.conversationContext = null;
    
                        /**
                         * GenerateStatelessSuggestionRequest triggerEvents.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.TriggerEvent>} triggerEvents
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionRequest
                         * @instance
                         */
                        GenerateStatelessSuggestionRequest.prototype.triggerEvents = $util.emptyArray;
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * GenerateStatelessSuggestionRequest generatorResource.
                         * @member {"generator"|"generatorName"|undefined} generatorResource
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionRequest
                         * @instance
                         */
                        Object.defineProperty(GenerateStatelessSuggestionRequest.prototype, "generatorResource", {
                            get: $util.oneOfGetter($oneOfFields = ["generator", "generatorName"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new GenerateStatelessSuggestionRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGenerateStatelessSuggestionRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionRequest} GenerateStatelessSuggestionRequest instance
                         */
                        GenerateStatelessSuggestionRequest.create = function create(properties) {
                            return new GenerateStatelessSuggestionRequest(properties);
                        };
    
                        /**
                         * Encodes the specified GenerateStatelessSuggestionRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGenerateStatelessSuggestionRequest} message GenerateStatelessSuggestionRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GenerateStatelessSuggestionRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.generator != null && Object.hasOwnProperty.call(message, "generator"))
                                $root.google.cloud.dialogflow.v2beta1.Generator.encode(message.generator, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.generatorName != null && Object.hasOwnProperty.call(message, "generatorName"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.generatorName);
                            if (message.contextReferences != null && Object.hasOwnProperty.call(message, "contextReferences"))
                                for (var keys = Object.keys(message.contextReferences), i = 0; i < keys.length; ++i) {
                                    writer.uint32(/* id 4, wireType 2 =*/34).fork().uint32(/* id 1, wireType 2 =*/10).string(keys[i]);
                                    $root.google.cloud.dialogflow.v2beta1.Conversation.ContextReference.encode(message.contextReferences[keys[i]], writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim().ldelim();
                                }
                            if (message.conversationContext != null && Object.hasOwnProperty.call(message, "conversationContext"))
                                $root.google.cloud.dialogflow.v2beta1.ConversationContext.encode(message.conversationContext, writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                            if (message.triggerEvents != null && message.triggerEvents.length) {
                                writer.uint32(/* id 6, wireType 2 =*/50).fork();
                                for (var i = 0; i < message.triggerEvents.length; ++i)
                                    writer.int32(message.triggerEvents[i]);
                                writer.ldelim();
                            }
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GenerateStatelessSuggestionRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGenerateStatelessSuggestionRequest} message GenerateStatelessSuggestionRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GenerateStatelessSuggestionRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GenerateStatelessSuggestionRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionRequest} GenerateStatelessSuggestionRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GenerateStatelessSuggestionRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionRequest(), key, value;
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.generator = $root.google.cloud.dialogflow.v2beta1.Generator.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 3: {
                                        message.generatorName = reader.string();
                                        break;
                                    }
                                case 4: {
                                        if (message.contextReferences === $util.emptyObject)
                                            message.contextReferences = {};
                                        var end2 = reader.uint32() + reader.pos;
                                        key = "";
                                        value = null;
                                        while (reader.pos < end2) {
                                            var tag2 = reader.uint32();
                                            switch (tag2 >>> 3) {
                                            case 1:
                                                key = reader.string();
                                                break;
                                            case 2:
                                                value = $root.google.cloud.dialogflow.v2beta1.Conversation.ContextReference.decode(reader, reader.uint32());
                                                break;
                                            default:
                                                reader.skipType(tag2 & 7);
                                                break;
                                            }
                                        }
                                        message.contextReferences[key] = value;
                                        break;
                                    }
                                case 5: {
                                        message.conversationContext = $root.google.cloud.dialogflow.v2beta1.ConversationContext.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 6: {
                                        if (!(message.triggerEvents && message.triggerEvents.length))
                                            message.triggerEvents = [];
                                        if ((tag & 7) === 2) {
                                            var end2 = reader.uint32() + reader.pos;
                                            while (reader.pos < end2)
                                                message.triggerEvents.push(reader.int32());
                                        } else
                                            message.triggerEvents.push(reader.int32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GenerateStatelessSuggestionRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionRequest} GenerateStatelessSuggestionRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GenerateStatelessSuggestionRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GenerateStatelessSuggestionRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GenerateStatelessSuggestionRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.generator != null && message.hasOwnProperty("generator")) {
                                properties.generatorResource = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2beta1.Generator.verify(message.generator);
                                    if (error)
                                        return "generator." + error;
                                }
                            }
                            if (message.generatorName != null && message.hasOwnProperty("generatorName")) {
                                if (properties.generatorResource === 1)
                                    return "generatorResource: multiple values";
                                properties.generatorResource = 1;
                                if (!$util.isString(message.generatorName))
                                    return "generatorName: string expected";
                            }
                            if (message.contextReferences != null && message.hasOwnProperty("contextReferences")) {
                                if (!$util.isObject(message.contextReferences))
                                    return "contextReferences: object expected";
                                var key = Object.keys(message.contextReferences);
                                for (var i = 0; i < key.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.Conversation.ContextReference.verify(message.contextReferences[key[i]]);
                                    if (error)
                                        return "contextReferences." + error;
                                }
                            }
                            if (message.conversationContext != null && message.hasOwnProperty("conversationContext")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.ConversationContext.verify(message.conversationContext);
                                if (error)
                                    return "conversationContext." + error;
                            }
                            if (message.triggerEvents != null && message.hasOwnProperty("triggerEvents")) {
                                if (!Array.isArray(message.triggerEvents))
                                    return "triggerEvents: array expected";
                                for (var i = 0; i < message.triggerEvents.length; ++i)
                                    switch (message.triggerEvents[i]) {
                                    default:
                                        return "triggerEvents: enum value[] expected";
                                    case 0:
                                    case 1:
                                    case 2:
                                    case 3:
                                    case 4:
                                        break;
                                    }
                            }
                            return null;
                        };
    
                        /**
                         * Creates a GenerateStatelessSuggestionRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionRequest} GenerateStatelessSuggestionRequest
                         */
                        GenerateStatelessSuggestionRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.generator != null) {
                                if (typeof object.generator !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionRequest.generator: object expected");
                                message.generator = $root.google.cloud.dialogflow.v2beta1.Generator.fromObject(object.generator);
                            }
                            if (object.generatorName != null)
                                message.generatorName = String(object.generatorName);
                            if (object.contextReferences) {
                                if (typeof object.contextReferences !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionRequest.contextReferences: object expected");
                                message.contextReferences = {};
                                for (var keys = Object.keys(object.contextReferences), i = 0; i < keys.length; ++i) {
                                    if (typeof object.contextReferences[keys[i]] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionRequest.contextReferences: object expected");
                                    message.contextReferences[keys[i]] = $root.google.cloud.dialogflow.v2beta1.Conversation.ContextReference.fromObject(object.contextReferences[keys[i]]);
                                }
                            }
                            if (object.conversationContext != null) {
                                if (typeof object.conversationContext !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionRequest.conversationContext: object expected");
                                message.conversationContext = $root.google.cloud.dialogflow.v2beta1.ConversationContext.fromObject(object.conversationContext);
                            }
                            if (object.triggerEvents) {
                                if (!Array.isArray(object.triggerEvents))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionRequest.triggerEvents: array expected");
                                message.triggerEvents = [];
                                for (var i = 0; i < object.triggerEvents.length; ++i)
                                    switch (object.triggerEvents[i]) {
                                    default:
                                        if (typeof object.triggerEvents[i] === "number") {
                                            message.triggerEvents[i] = object.triggerEvents[i];
                                            break;
                                        }
                                    case "TRIGGER_EVENT_UNSPECIFIED":
                                    case 0:
                                        message.triggerEvents[i] = 0;
                                        break;
                                    case "END_OF_UTTERANCE":
                                    case 1:
                                        message.triggerEvents[i] = 1;
                                        break;
                                    case "MANUAL_CALL":
                                    case 2:
                                        message.triggerEvents[i] = 2;
                                        break;
                                    case "CUSTOMER_MESSAGE":
                                    case 3:
                                        message.triggerEvents[i] = 3;
                                        break;
                                    case "AGENT_MESSAGE":
                                    case 4:
                                        message.triggerEvents[i] = 4;
                                        break;
                                    }
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GenerateStatelessSuggestionRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionRequest} message GenerateStatelessSuggestionRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GenerateStatelessSuggestionRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.triggerEvents = [];
                            if (options.objects || options.defaults)
                                object.contextReferences = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.conversationContext = null;
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.generator != null && message.hasOwnProperty("generator")) {
                                object.generator = $root.google.cloud.dialogflow.v2beta1.Generator.toObject(message.generator, options);
                                if (options.oneofs)
                                    object.generatorResource = "generator";
                            }
                            if (message.generatorName != null && message.hasOwnProperty("generatorName")) {
                                object.generatorName = message.generatorName;
                                if (options.oneofs)
                                    object.generatorResource = "generatorName";
                            }
                            var keys2;
                            if (message.contextReferences && (keys2 = Object.keys(message.contextReferences)).length) {
                                object.contextReferences = {};
                                for (var j = 0; j < keys2.length; ++j)
                                    object.contextReferences[keys2[j]] = $root.google.cloud.dialogflow.v2beta1.Conversation.ContextReference.toObject(message.contextReferences[keys2[j]], options);
                            }
                            if (message.conversationContext != null && message.hasOwnProperty("conversationContext"))
                                object.conversationContext = $root.google.cloud.dialogflow.v2beta1.ConversationContext.toObject(message.conversationContext, options);
                            if (message.triggerEvents && message.triggerEvents.length) {
                                object.triggerEvents = [];
                                for (var j = 0; j < message.triggerEvents.length; ++j)
                                    object.triggerEvents[j] = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.TriggerEvent[message.triggerEvents[j]] === undefined ? message.triggerEvents[j] : $root.google.cloud.dialogflow.v2beta1.TriggerEvent[message.triggerEvents[j]] : message.triggerEvents[j];
                            }
                            return object;
                        };
    
                        /**
                         * Converts this GenerateStatelessSuggestionRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GenerateStatelessSuggestionRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GenerateStatelessSuggestionRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GenerateStatelessSuggestionRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionRequest";
                        };
    
                        return GenerateStatelessSuggestionRequest;
                    })();
    
                    v2beta1.GenerateStatelessSuggestionResponse = (function() {
    
                        /**
                         * Properties of a GenerateStatelessSuggestionResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IGenerateStatelessSuggestionResponse
                         * @property {google.cloud.dialogflow.v2beta1.IGeneratorSuggestion|null} [generatorSuggestion] GenerateStatelessSuggestionResponse generatorSuggestion
                         */
    
                        /**
                         * Constructs a new GenerateStatelessSuggestionResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a GenerateStatelessSuggestionResponse.
                         * @implements IGenerateStatelessSuggestionResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IGenerateStatelessSuggestionResponse=} [properties] Properties to set
                         */
                        function GenerateStatelessSuggestionResponse(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GenerateStatelessSuggestionResponse generatorSuggestion.
                         * @member {google.cloud.dialogflow.v2beta1.IGeneratorSuggestion|null|undefined} generatorSuggestion
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionResponse
                         * @instance
                         */
                        GenerateStatelessSuggestionResponse.prototype.generatorSuggestion = null;
    
                        /**
                         * Creates a new GenerateStatelessSuggestionResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGenerateStatelessSuggestionResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionResponse} GenerateStatelessSuggestionResponse instance
                         */
                        GenerateStatelessSuggestionResponse.create = function create(properties) {
                            return new GenerateStatelessSuggestionResponse(properties);
                        };
    
                        /**
                         * Encodes the specified GenerateStatelessSuggestionResponse message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGenerateStatelessSuggestionResponse} message GenerateStatelessSuggestionResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GenerateStatelessSuggestionResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.generatorSuggestion != null && Object.hasOwnProperty.call(message, "generatorSuggestion"))
                                $root.google.cloud.dialogflow.v2beta1.GeneratorSuggestion.encode(message.generatorSuggestion, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GenerateStatelessSuggestionResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGenerateStatelessSuggestionResponse} message GenerateStatelessSuggestionResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GenerateStatelessSuggestionResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GenerateStatelessSuggestionResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionResponse} GenerateStatelessSuggestionResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GenerateStatelessSuggestionResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.generatorSuggestion = $root.google.cloud.dialogflow.v2beta1.GeneratorSuggestion.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GenerateStatelessSuggestionResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionResponse} GenerateStatelessSuggestionResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GenerateStatelessSuggestionResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GenerateStatelessSuggestionResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GenerateStatelessSuggestionResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.generatorSuggestion != null && message.hasOwnProperty("generatorSuggestion")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.GeneratorSuggestion.verify(message.generatorSuggestion);
                                if (error)
                                    return "generatorSuggestion." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a GenerateStatelessSuggestionResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionResponse} GenerateStatelessSuggestionResponse
                         */
                        GenerateStatelessSuggestionResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionResponse();
                            if (object.generatorSuggestion != null) {
                                if (typeof object.generatorSuggestion !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionResponse.generatorSuggestion: object expected");
                                message.generatorSuggestion = $root.google.cloud.dialogflow.v2beta1.GeneratorSuggestion.fromObject(object.generatorSuggestion);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GenerateStatelessSuggestionResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionResponse} message GenerateStatelessSuggestionResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GenerateStatelessSuggestionResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.generatorSuggestion = null;
                            if (message.generatorSuggestion != null && message.hasOwnProperty("generatorSuggestion"))
                                object.generatorSuggestion = $root.google.cloud.dialogflow.v2beta1.GeneratorSuggestion.toObject(message.generatorSuggestion, options);
                            return object;
                        };
    
                        /**
                         * Converts this GenerateStatelessSuggestionResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GenerateStatelessSuggestionResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GenerateStatelessSuggestionResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GenerateStatelessSuggestionResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.GenerateStatelessSuggestionResponse";
                        };
    
                        return GenerateStatelessSuggestionResponse;
                    })();
    
                    v2beta1.SearchKnowledgeRequest = (function() {
    
                        /**
                         * Properties of a SearchKnowledgeRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ISearchKnowledgeRequest
                         * @property {string|null} [parent] SearchKnowledgeRequest parent
                         * @property {google.cloud.dialogflow.v2beta1.ITextInput|null} [query] SearchKnowledgeRequest query
                         * @property {string|null} [conversationProfile] SearchKnowledgeRequest conversationProfile
                         * @property {string|null} [sessionId] SearchKnowledgeRequest sessionId
                         * @property {string|null} [conversation] SearchKnowledgeRequest conversation
                         * @property {string|null} [latestMessage] SearchKnowledgeRequest latestMessage
                         * @property {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.QuerySource|null} [querySource] SearchKnowledgeRequest querySource
                         * @property {google.protobuf.IStruct|null} [endUserMetadata] SearchKnowledgeRequest endUserMetadata
                         * @property {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.ISearchConfig|null} [searchConfig] SearchKnowledgeRequest searchConfig
                         * @property {boolean|null} [exactSearch] SearchKnowledgeRequest exactSearch
                         */
    
                        /**
                         * Constructs a new SearchKnowledgeRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a SearchKnowledgeRequest.
                         * @implements ISearchKnowledgeRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ISearchKnowledgeRequest=} [properties] Properties to set
                         */
                        function SearchKnowledgeRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SearchKnowledgeRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest
                         * @instance
                         */
                        SearchKnowledgeRequest.prototype.parent = "";
    
                        /**
                         * SearchKnowledgeRequest query.
                         * @member {google.cloud.dialogflow.v2beta1.ITextInput|null|undefined} query
                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest
                         * @instance
                         */
                        SearchKnowledgeRequest.prototype.query = null;
    
                        /**
                         * SearchKnowledgeRequest conversationProfile.
                         * @member {string} conversationProfile
                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest
                         * @instance
                         */
                        SearchKnowledgeRequest.prototype.conversationProfile = "";
    
                        /**
                         * SearchKnowledgeRequest sessionId.
                         * @member {string} sessionId
                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest
                         * @instance
                         */
                        SearchKnowledgeRequest.prototype.sessionId = "";
    
                        /**
                         * SearchKnowledgeRequest conversation.
                         * @member {string} conversation
                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest
                         * @instance
                         */
                        SearchKnowledgeRequest.prototype.conversation = "";
    
                        /**
                         * SearchKnowledgeRequest latestMessage.
                         * @member {string} latestMessage
                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest
                         * @instance
                         */
                        SearchKnowledgeRequest.prototype.latestMessage = "";
    
                        /**
                         * SearchKnowledgeRequest querySource.
                         * @member {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.QuerySource} querySource
                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest
                         * @instance
                         */
                        SearchKnowledgeRequest.prototype.querySource = 0;
    
                        /**
                         * SearchKnowledgeRequest endUserMetadata.
                         * @member {google.protobuf.IStruct|null|undefined} endUserMetadata
                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest
                         * @instance
                         */
                        SearchKnowledgeRequest.prototype.endUserMetadata = null;
    
                        /**
                         * SearchKnowledgeRequest searchConfig.
                         * @member {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.ISearchConfig|null|undefined} searchConfig
                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest
                         * @instance
                         */
                        SearchKnowledgeRequest.prototype.searchConfig = null;
    
                        /**
                         * SearchKnowledgeRequest exactSearch.
                         * @member {boolean} exactSearch
                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest
                         * @instance
                         */
                        SearchKnowledgeRequest.prototype.exactSearch = false;
    
                        /**
                         * Creates a new SearchKnowledgeRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISearchKnowledgeRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest} SearchKnowledgeRequest instance
                         */
                        SearchKnowledgeRequest.create = function create(properties) {
                            return new SearchKnowledgeRequest(properties);
                        };
    
                        /**
                         * Encodes the specified SearchKnowledgeRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISearchKnowledgeRequest} message SearchKnowledgeRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SearchKnowledgeRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.query != null && Object.hasOwnProperty.call(message, "query"))
                                $root.google.cloud.dialogflow.v2beta1.TextInput.encode(message.query, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.conversationProfile != null && Object.hasOwnProperty.call(message, "conversationProfile"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.conversationProfile);
                            if (message.sessionId != null && Object.hasOwnProperty.call(message, "sessionId"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.sessionId);
                            if (message.conversation != null && Object.hasOwnProperty.call(message, "conversation"))
                                writer.uint32(/* id 4, wireType 2 =*/34).string(message.conversation);
                            if (message.latestMessage != null && Object.hasOwnProperty.call(message, "latestMessage"))
                                writer.uint32(/* id 5, wireType 2 =*/42).string(message.latestMessage);
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 6, wireType 2 =*/50).string(message.parent);
                            if (message.querySource != null && Object.hasOwnProperty.call(message, "querySource"))
                                writer.uint32(/* id 7, wireType 0 =*/56).int32(message.querySource);
                            if (message.endUserMetadata != null && Object.hasOwnProperty.call(message, "endUserMetadata"))
                                $root.google.protobuf.Struct.encode(message.endUserMetadata, writer.uint32(/* id 9, wireType 2 =*/74).fork()).ldelim();
                            if (message.searchConfig != null && Object.hasOwnProperty.call(message, "searchConfig"))
                                $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.encode(message.searchConfig, writer.uint32(/* id 11, wireType 2 =*/90).fork()).ldelim();
                            if (message.exactSearch != null && Object.hasOwnProperty.call(message, "exactSearch"))
                                writer.uint32(/* id 14, wireType 0 =*/112).bool(message.exactSearch);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SearchKnowledgeRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISearchKnowledgeRequest} message SearchKnowledgeRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SearchKnowledgeRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SearchKnowledgeRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest} SearchKnowledgeRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SearchKnowledgeRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 6: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 1: {
                                        message.query = $root.google.cloud.dialogflow.v2beta1.TextInput.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.conversationProfile = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.sessionId = reader.string();
                                        break;
                                    }
                                case 4: {
                                        message.conversation = reader.string();
                                        break;
                                    }
                                case 5: {
                                        message.latestMessage = reader.string();
                                        break;
                                    }
                                case 7: {
                                        message.querySource = reader.int32();
                                        break;
                                    }
                                case 9: {
                                        message.endUserMetadata = $root.google.protobuf.Struct.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 11: {
                                        message.searchConfig = $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 14: {
                                        message.exactSearch = reader.bool();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SearchKnowledgeRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest} SearchKnowledgeRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SearchKnowledgeRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SearchKnowledgeRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SearchKnowledgeRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.query != null && message.hasOwnProperty("query")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.TextInput.verify(message.query);
                                if (error)
                                    return "query." + error;
                            }
                            if (message.conversationProfile != null && message.hasOwnProperty("conversationProfile"))
                                if (!$util.isString(message.conversationProfile))
                                    return "conversationProfile: string expected";
                            if (message.sessionId != null && message.hasOwnProperty("sessionId"))
                                if (!$util.isString(message.sessionId))
                                    return "sessionId: string expected";
                            if (message.conversation != null && message.hasOwnProperty("conversation"))
                                if (!$util.isString(message.conversation))
                                    return "conversation: string expected";
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                if (!$util.isString(message.latestMessage))
                                    return "latestMessage: string expected";
                            if (message.querySource != null && message.hasOwnProperty("querySource"))
                                switch (message.querySource) {
                                default:
                                    return "querySource: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                    break;
                                }
                            if (message.endUserMetadata != null && message.hasOwnProperty("endUserMetadata")) {
                                var error = $root.google.protobuf.Struct.verify(message.endUserMetadata);
                                if (error)
                                    return "endUserMetadata." + error;
                            }
                            if (message.searchConfig != null && message.hasOwnProperty("searchConfig")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.verify(message.searchConfig);
                                if (error)
                                    return "searchConfig." + error;
                            }
                            if (message.exactSearch != null && message.hasOwnProperty("exactSearch"))
                                if (typeof message.exactSearch !== "boolean")
                                    return "exactSearch: boolean expected";
                            return null;
                        };
    
                        /**
                         * Creates a SearchKnowledgeRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest} SearchKnowledgeRequest
                         */
                        SearchKnowledgeRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.query != null) {
                                if (typeof object.query !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.query: object expected");
                                message.query = $root.google.cloud.dialogflow.v2beta1.TextInput.fromObject(object.query);
                            }
                            if (object.conversationProfile != null)
                                message.conversationProfile = String(object.conversationProfile);
                            if (object.sessionId != null)
                                message.sessionId = String(object.sessionId);
                            if (object.conversation != null)
                                message.conversation = String(object.conversation);
                            if (object.latestMessage != null)
                                message.latestMessage = String(object.latestMessage);
                            switch (object.querySource) {
                            default:
                                if (typeof object.querySource === "number") {
                                    message.querySource = object.querySource;
                                    break;
                                }
                                break;
                            case "QUERY_SOURCE_UNSPECIFIED":
                            case 0:
                                message.querySource = 0;
                                break;
                            case "AGENT_QUERY":
                            case 1:
                                message.querySource = 1;
                                break;
                            case "SUGGESTED_QUERY":
                            case 2:
                                message.querySource = 2;
                                break;
                            }
                            if (object.endUserMetadata != null) {
                                if (typeof object.endUserMetadata !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.endUserMetadata: object expected");
                                message.endUserMetadata = $root.google.protobuf.Struct.fromObject(object.endUserMetadata);
                            }
                            if (object.searchConfig != null) {
                                if (typeof object.searchConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.searchConfig: object expected");
                                message.searchConfig = $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.fromObject(object.searchConfig);
                            }
                            if (object.exactSearch != null)
                                message.exactSearch = Boolean(object.exactSearch);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SearchKnowledgeRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest} message SearchKnowledgeRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SearchKnowledgeRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.query = null;
                                object.conversationProfile = "";
                                object.sessionId = "";
                                object.conversation = "";
                                object.latestMessage = "";
                                object.parent = "";
                                object.querySource = options.enums === String ? "QUERY_SOURCE_UNSPECIFIED" : 0;
                                object.endUserMetadata = null;
                                object.searchConfig = null;
                                object.exactSearch = false;
                            }
                            if (message.query != null && message.hasOwnProperty("query"))
                                object.query = $root.google.cloud.dialogflow.v2beta1.TextInput.toObject(message.query, options);
                            if (message.conversationProfile != null && message.hasOwnProperty("conversationProfile"))
                                object.conversationProfile = message.conversationProfile;
                            if (message.sessionId != null && message.hasOwnProperty("sessionId"))
                                object.sessionId = message.sessionId;
                            if (message.conversation != null && message.hasOwnProperty("conversation"))
                                object.conversation = message.conversation;
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                object.latestMessage = message.latestMessage;
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.querySource != null && message.hasOwnProperty("querySource"))
                                object.querySource = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.QuerySource[message.querySource] === undefined ? message.querySource : $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.QuerySource[message.querySource] : message.querySource;
                            if (message.endUserMetadata != null && message.hasOwnProperty("endUserMetadata"))
                                object.endUserMetadata = $root.google.protobuf.Struct.toObject(message.endUserMetadata, options);
                            if (message.searchConfig != null && message.hasOwnProperty("searchConfig"))
                                object.searchConfig = $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.toObject(message.searchConfig, options);
                            if (message.exactSearch != null && message.hasOwnProperty("exactSearch"))
                                object.exactSearch = message.exactSearch;
                            return object;
                        };
    
                        /**
                         * Converts this SearchKnowledgeRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SearchKnowledgeRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SearchKnowledgeRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SearchKnowledgeRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest";
                        };
    
                        /**
                         * QuerySource enum.
                         * @name google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.QuerySource
                         * @enum {number}
                         * @property {number} QUERY_SOURCE_UNSPECIFIED=0 QUERY_SOURCE_UNSPECIFIED value
                         * @property {number} AGENT_QUERY=1 AGENT_QUERY value
                         * @property {number} SUGGESTED_QUERY=2 SUGGESTED_QUERY value
                         */
                        SearchKnowledgeRequest.QuerySource = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "QUERY_SOURCE_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "AGENT_QUERY"] = 1;
                            values[valuesById[2] = "SUGGESTED_QUERY"] = 2;
                            return values;
                        })();
    
                        SearchKnowledgeRequest.SearchConfig = (function() {
    
                            /**
                             * Properties of a SearchConfig.
                             * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest
                             * @interface ISearchConfig
                             * @property {Array.<google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.IBoostSpecs>|null} [boostSpecs] SearchConfig boostSpecs
                             * @property {Array.<google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.IFilterSpecs>|null} [filterSpecs] SearchConfig filterSpecs
                             */
    
                            /**
                             * Constructs a new SearchConfig.
                             * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest
                             * @classdesc Represents a SearchConfig.
                             * @implements ISearchConfig
                             * @constructor
                             * @param {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.ISearchConfig=} [properties] Properties to set
                             */
                            function SearchConfig(properties) {
                                this.boostSpecs = [];
                                this.filterSpecs = [];
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * SearchConfig boostSpecs.
                             * @member {Array.<google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.IBoostSpecs>} boostSpecs
                             * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig
                             * @instance
                             */
                            SearchConfig.prototype.boostSpecs = $util.emptyArray;
    
                            /**
                             * SearchConfig filterSpecs.
                             * @member {Array.<google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.IFilterSpecs>} filterSpecs
                             * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig
                             * @instance
                             */
                            SearchConfig.prototype.filterSpecs = $util.emptyArray;
    
                            /**
                             * Creates a new SearchConfig instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.ISearchConfig=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig} SearchConfig instance
                             */
                            SearchConfig.create = function create(properties) {
                                return new SearchConfig(properties);
                            };
    
                            /**
                             * Encodes the specified SearchConfig message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.ISearchConfig} message SearchConfig message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            SearchConfig.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.boostSpecs != null && message.boostSpecs.length)
                                    for (var i = 0; i < message.boostSpecs.length; ++i)
                                        $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.encode(message.boostSpecs[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                                if (message.filterSpecs != null && message.filterSpecs.length)
                                    for (var i = 0; i < message.filterSpecs.length; ++i)
                                        $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.FilterSpecs.encode(message.filterSpecs[i], writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                                return writer;
                            };
    
                            /**
                             * Encodes the specified SearchConfig message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.ISearchConfig} message SearchConfig message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            SearchConfig.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a SearchConfig message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig} SearchConfig
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            SearchConfig.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            if (!(message.boostSpecs && message.boostSpecs.length))
                                                message.boostSpecs = [];
                                            message.boostSpecs.push($root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.decode(reader, reader.uint32()));
                                            break;
                                        }
                                    case 2: {
                                            if (!(message.filterSpecs && message.filterSpecs.length))
                                                message.filterSpecs = [];
                                            message.filterSpecs.push($root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.FilterSpecs.decode(reader, reader.uint32()));
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a SearchConfig message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig} SearchConfig
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            SearchConfig.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a SearchConfig message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            SearchConfig.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.boostSpecs != null && message.hasOwnProperty("boostSpecs")) {
                                    if (!Array.isArray(message.boostSpecs))
                                        return "boostSpecs: array expected";
                                    for (var i = 0; i < message.boostSpecs.length; ++i) {
                                        var error = $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.verify(message.boostSpecs[i]);
                                        if (error)
                                            return "boostSpecs." + error;
                                    }
                                }
                                if (message.filterSpecs != null && message.hasOwnProperty("filterSpecs")) {
                                    if (!Array.isArray(message.filterSpecs))
                                        return "filterSpecs: array expected";
                                    for (var i = 0; i < message.filterSpecs.length; ++i) {
                                        var error = $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.FilterSpecs.verify(message.filterSpecs[i]);
                                        if (error)
                                            return "filterSpecs." + error;
                                    }
                                }
                                return null;
                            };
    
                            /**
                             * Creates a SearchConfig message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig} SearchConfig
                             */
                            SearchConfig.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig();
                                if (object.boostSpecs) {
                                    if (!Array.isArray(object.boostSpecs))
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.boostSpecs: array expected");
                                    message.boostSpecs = [];
                                    for (var i = 0; i < object.boostSpecs.length; ++i) {
                                        if (typeof object.boostSpecs[i] !== "object")
                                            throw TypeError(".google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.boostSpecs: object expected");
                                        message.boostSpecs[i] = $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.fromObject(object.boostSpecs[i]);
                                    }
                                }
                                if (object.filterSpecs) {
                                    if (!Array.isArray(object.filterSpecs))
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.filterSpecs: array expected");
                                    message.filterSpecs = [];
                                    for (var i = 0; i < object.filterSpecs.length; ++i) {
                                        if (typeof object.filterSpecs[i] !== "object")
                                            throw TypeError(".google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.filterSpecs: object expected");
                                        message.filterSpecs[i] = $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.FilterSpecs.fromObject(object.filterSpecs[i]);
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a SearchConfig message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig} message SearchConfig
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            SearchConfig.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.arrays || options.defaults) {
                                    object.boostSpecs = [];
                                    object.filterSpecs = [];
                                }
                                if (message.boostSpecs && message.boostSpecs.length) {
                                    object.boostSpecs = [];
                                    for (var j = 0; j < message.boostSpecs.length; ++j)
                                        object.boostSpecs[j] = $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.toObject(message.boostSpecs[j], options);
                                }
                                if (message.filterSpecs && message.filterSpecs.length) {
                                    object.filterSpecs = [];
                                    for (var j = 0; j < message.filterSpecs.length; ++j)
                                        object.filterSpecs[j] = $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.FilterSpecs.toObject(message.filterSpecs[j], options);
                                }
                                return object;
                            };
    
                            /**
                             * Converts this SearchConfig to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            SearchConfig.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for SearchConfig
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            SearchConfig.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig";
                            };
    
                            SearchConfig.BoostSpecs = (function() {
    
                                /**
                                 * Properties of a BoostSpecs.
                                 * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig
                                 * @interface IBoostSpecs
                                 * @property {Array.<string>|null} [dataStores] BoostSpecs dataStores
                                 * @property {Array.<google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.IBoostSpec>|null} [spec] BoostSpecs spec
                                 */
    
                                /**
                                 * Constructs a new BoostSpecs.
                                 * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig
                                 * @classdesc Represents a BoostSpecs.
                                 * @implements IBoostSpecs
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.IBoostSpecs=} [properties] Properties to set
                                 */
                                function BoostSpecs(properties) {
                                    this.dataStores = [];
                                    this.spec = [];
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * BoostSpecs dataStores.
                                 * @member {Array.<string>} dataStores
                                 * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs
                                 * @instance
                                 */
                                BoostSpecs.prototype.dataStores = $util.emptyArray;
    
                                /**
                                 * BoostSpecs spec.
                                 * @member {Array.<google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.IBoostSpec>} spec
                                 * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs
                                 * @instance
                                 */
                                BoostSpecs.prototype.spec = $util.emptyArray;
    
                                /**
                                 * Creates a new BoostSpecs instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.IBoostSpecs=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs} BoostSpecs instance
                                 */
                                BoostSpecs.create = function create(properties) {
                                    return new BoostSpecs(properties);
                                };
    
                                /**
                                 * Encodes the specified BoostSpecs message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.IBoostSpecs} message BoostSpecs message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                BoostSpecs.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.dataStores != null && message.dataStores.length)
                                        for (var i = 0; i < message.dataStores.length; ++i)
                                            writer.uint32(/* id 1, wireType 2 =*/10).string(message.dataStores[i]);
                                    if (message.spec != null && message.spec.length)
                                        for (var i = 0; i < message.spec.length; ++i)
                                            $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.encode(message.spec[i], writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified BoostSpecs message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.IBoostSpecs} message BoostSpecs message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                BoostSpecs.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a BoostSpecs message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs} BoostSpecs
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                BoostSpecs.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                if (!(message.dataStores && message.dataStores.length))
                                                    message.dataStores = [];
                                                message.dataStores.push(reader.string());
                                                break;
                                            }
                                        case 2: {
                                                if (!(message.spec && message.spec.length))
                                                    message.spec = [];
                                                message.spec.push($root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.decode(reader, reader.uint32()));
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a BoostSpecs message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs} BoostSpecs
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                BoostSpecs.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a BoostSpecs message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                BoostSpecs.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.dataStores != null && message.hasOwnProperty("dataStores")) {
                                        if (!Array.isArray(message.dataStores))
                                            return "dataStores: array expected";
                                        for (var i = 0; i < message.dataStores.length; ++i)
                                            if (!$util.isString(message.dataStores[i]))
                                                return "dataStores: string[] expected";
                                    }
                                    if (message.spec != null && message.hasOwnProperty("spec")) {
                                        if (!Array.isArray(message.spec))
                                            return "spec: array expected";
                                        for (var i = 0; i < message.spec.length; ++i) {
                                            var error = $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.verify(message.spec[i]);
                                            if (error)
                                                return "spec." + error;
                                        }
                                    }
                                    return null;
                                };
    
                                /**
                                 * Creates a BoostSpecs message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs} BoostSpecs
                                 */
                                BoostSpecs.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs();
                                    if (object.dataStores) {
                                        if (!Array.isArray(object.dataStores))
                                            throw TypeError(".google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.dataStores: array expected");
                                        message.dataStores = [];
                                        for (var i = 0; i < object.dataStores.length; ++i)
                                            message.dataStores[i] = String(object.dataStores[i]);
                                    }
                                    if (object.spec) {
                                        if (!Array.isArray(object.spec))
                                            throw TypeError(".google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.spec: array expected");
                                        message.spec = [];
                                        for (var i = 0; i < object.spec.length; ++i) {
                                            if (typeof object.spec[i] !== "object")
                                                throw TypeError(".google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.spec: object expected");
                                            message.spec[i] = $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.fromObject(object.spec[i]);
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a BoostSpecs message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs} message BoostSpecs
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                BoostSpecs.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.arrays || options.defaults) {
                                        object.dataStores = [];
                                        object.spec = [];
                                    }
                                    if (message.dataStores && message.dataStores.length) {
                                        object.dataStores = [];
                                        for (var j = 0; j < message.dataStores.length; ++j)
                                            object.dataStores[j] = message.dataStores[j];
                                    }
                                    if (message.spec && message.spec.length) {
                                        object.spec = [];
                                        for (var j = 0; j < message.spec.length; ++j)
                                            object.spec[j] = $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.toObject(message.spec[j], options);
                                    }
                                    return object;
                                };
    
                                /**
                                 * Converts this BoostSpecs to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                BoostSpecs.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for BoostSpecs
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                BoostSpecs.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs";
                                };
    
                                BoostSpecs.BoostSpec = (function() {
    
                                    /**
                                     * Properties of a BoostSpec.
                                     * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs
                                     * @interface IBoostSpec
                                     * @property {Array.<google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.IConditionBoostSpec>|null} [conditionBoostSpecs] BoostSpec conditionBoostSpecs
                                     */
    
                                    /**
                                     * Constructs a new BoostSpec.
                                     * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs
                                     * @classdesc Represents a BoostSpec.
                                     * @implements IBoostSpec
                                     * @constructor
                                     * @param {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.IBoostSpec=} [properties] Properties to set
                                     */
                                    function BoostSpec(properties) {
                                        this.conditionBoostSpecs = [];
                                        if (properties)
                                            for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                                if (properties[keys[i]] != null)
                                                    this[keys[i]] = properties[keys[i]];
                                    }
    
                                    /**
                                     * BoostSpec conditionBoostSpecs.
                                     * @member {Array.<google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.IConditionBoostSpec>} conditionBoostSpecs
                                     * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec
                                     * @instance
                                     */
                                    BoostSpec.prototype.conditionBoostSpecs = $util.emptyArray;
    
                                    /**
                                     * Creates a new BoostSpec instance using the specified properties.
                                     * @function create
                                     * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec
                                     * @static
                                     * @param {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.IBoostSpec=} [properties] Properties to set
                                     * @returns {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec} BoostSpec instance
                                     */
                                    BoostSpec.create = function create(properties) {
                                        return new BoostSpec(properties);
                                    };
    
                                    /**
                                     * Encodes the specified BoostSpec message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.verify|verify} messages.
                                     * @function encode
                                     * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec
                                     * @static
                                     * @param {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.IBoostSpec} message BoostSpec message or plain object to encode
                                     * @param {$protobuf.Writer} [writer] Writer to encode to
                                     * @returns {$protobuf.Writer} Writer
                                     */
                                    BoostSpec.encode = function encode(message, writer) {
                                        if (!writer)
                                            writer = $Writer.create();
                                        if (message.conditionBoostSpecs != null && message.conditionBoostSpecs.length)
                                            for (var i = 0; i < message.conditionBoostSpecs.length; ++i)
                                                $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.encode(message.conditionBoostSpecs[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                                        return writer;
                                    };
    
                                    /**
                                     * Encodes the specified BoostSpec message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.verify|verify} messages.
                                     * @function encodeDelimited
                                     * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec
                                     * @static
                                     * @param {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.IBoostSpec} message BoostSpec message or plain object to encode
                                     * @param {$protobuf.Writer} [writer] Writer to encode to
                                     * @returns {$protobuf.Writer} Writer
                                     */
                                    BoostSpec.encodeDelimited = function encodeDelimited(message, writer) {
                                        return this.encode(message, writer).ldelim();
                                    };
    
                                    /**
                                     * Decodes a BoostSpec message from the specified reader or buffer.
                                     * @function decode
                                     * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec
                                     * @static
                                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                     * @param {number} [length] Message length if known beforehand
                                     * @returns {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec} BoostSpec
                                     * @throws {Error} If the payload is not a reader or valid buffer
                                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                     */
                                    BoostSpec.decode = function decode(reader, length) {
                                        if (!(reader instanceof $Reader))
                                            reader = $Reader.create(reader);
                                        var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec();
                                        while (reader.pos < end) {
                                            var tag = reader.uint32();
                                            switch (tag >>> 3) {
                                            case 1: {
                                                    if (!(message.conditionBoostSpecs && message.conditionBoostSpecs.length))
                                                        message.conditionBoostSpecs = [];
                                                    message.conditionBoostSpecs.push($root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.decode(reader, reader.uint32()));
                                                    break;
                                                }
                                            default:
                                                reader.skipType(tag & 7);
                                                break;
                                            }
                                        }
                                        return message;
                                    };
    
                                    /**
                                     * Decodes a BoostSpec message from the specified reader or buffer, length delimited.
                                     * @function decodeDelimited
                                     * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec
                                     * @static
                                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                     * @returns {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec} BoostSpec
                                     * @throws {Error} If the payload is not a reader or valid buffer
                                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                     */
                                    BoostSpec.decodeDelimited = function decodeDelimited(reader) {
                                        if (!(reader instanceof $Reader))
                                            reader = new $Reader(reader);
                                        return this.decode(reader, reader.uint32());
                                    };
    
                                    /**
                                     * Verifies a BoostSpec message.
                                     * @function verify
                                     * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec
                                     * @static
                                     * @param {Object.<string,*>} message Plain object to verify
                                     * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                     */
                                    BoostSpec.verify = function verify(message) {
                                        if (typeof message !== "object" || message === null)
                                            return "object expected";
                                        if (message.conditionBoostSpecs != null && message.hasOwnProperty("conditionBoostSpecs")) {
                                            if (!Array.isArray(message.conditionBoostSpecs))
                                                return "conditionBoostSpecs: array expected";
                                            for (var i = 0; i < message.conditionBoostSpecs.length; ++i) {
                                                var error = $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.verify(message.conditionBoostSpecs[i]);
                                                if (error)
                                                    return "conditionBoostSpecs." + error;
                                            }
                                        }
                                        return null;
                                    };
    
                                    /**
                                     * Creates a BoostSpec message from a plain object. Also converts values to their respective internal types.
                                     * @function fromObject
                                     * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec
                                     * @static
                                     * @param {Object.<string,*>} object Plain object
                                     * @returns {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec} BoostSpec
                                     */
                                    BoostSpec.fromObject = function fromObject(object) {
                                        if (object instanceof $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec)
                                            return object;
                                        var message = new $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec();
                                        if (object.conditionBoostSpecs) {
                                            if (!Array.isArray(object.conditionBoostSpecs))
                                                throw TypeError(".google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.conditionBoostSpecs: array expected");
                                            message.conditionBoostSpecs = [];
                                            for (var i = 0; i < object.conditionBoostSpecs.length; ++i) {
                                                if (typeof object.conditionBoostSpecs[i] !== "object")
                                                    throw TypeError(".google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.conditionBoostSpecs: object expected");
                                                message.conditionBoostSpecs[i] = $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.fromObject(object.conditionBoostSpecs[i]);
                                            }
                                        }
                                        return message;
                                    };
    
                                    /**
                                     * Creates a plain object from a BoostSpec message. Also converts values to other types if specified.
                                     * @function toObject
                                     * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec
                                     * @static
                                     * @param {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec} message BoostSpec
                                     * @param {$protobuf.IConversionOptions} [options] Conversion options
                                     * @returns {Object.<string,*>} Plain object
                                     */
                                    BoostSpec.toObject = function toObject(message, options) {
                                        if (!options)
                                            options = {};
                                        var object = {};
                                        if (options.arrays || options.defaults)
                                            object.conditionBoostSpecs = [];
                                        if (message.conditionBoostSpecs && message.conditionBoostSpecs.length) {
                                            object.conditionBoostSpecs = [];
                                            for (var j = 0; j < message.conditionBoostSpecs.length; ++j)
                                                object.conditionBoostSpecs[j] = $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.toObject(message.conditionBoostSpecs[j], options);
                                        }
                                        return object;
                                    };
    
                                    /**
                                     * Converts this BoostSpec to JSON.
                                     * @function toJSON
                                     * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec
                                     * @instance
                                     * @returns {Object.<string,*>} JSON object
                                     */
                                    BoostSpec.prototype.toJSON = function toJSON() {
                                        return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                    };
    
                                    /**
                                     * Gets the default type url for BoostSpec
                                     * @function getTypeUrl
                                     * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec
                                     * @static
                                     * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                     * @returns {string} The default type url
                                     */
                                    BoostSpec.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                        if (typeUrlPrefix === undefined) {
                                            typeUrlPrefix = "type.googleapis.com";
                                        }
                                        return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec";
                                    };
    
                                    BoostSpec.ConditionBoostSpec = (function() {
    
                                        /**
                                         * Properties of a ConditionBoostSpec.
                                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec
                                         * @interface IConditionBoostSpec
                                         * @property {string|null} [condition] ConditionBoostSpec condition
                                         * @property {number|null} [boost] ConditionBoostSpec boost
                                         * @property {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.IBoostControlSpec|null} [boostControlSpec] ConditionBoostSpec boostControlSpec
                                         */
    
                                        /**
                                         * Constructs a new ConditionBoostSpec.
                                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec
                                         * @classdesc Represents a ConditionBoostSpec.
                                         * @implements IConditionBoostSpec
                                         * @constructor
                                         * @param {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.IConditionBoostSpec=} [properties] Properties to set
                                         */
                                        function ConditionBoostSpec(properties) {
                                            if (properties)
                                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                                    if (properties[keys[i]] != null)
                                                        this[keys[i]] = properties[keys[i]];
                                        }
    
                                        /**
                                         * ConditionBoostSpec condition.
                                         * @member {string} condition
                                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec
                                         * @instance
                                         */
                                        ConditionBoostSpec.prototype.condition = "";
    
                                        /**
                                         * ConditionBoostSpec boost.
                                         * @member {number} boost
                                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec
                                         * @instance
                                         */
                                        ConditionBoostSpec.prototype.boost = 0;
    
                                        /**
                                         * ConditionBoostSpec boostControlSpec.
                                         * @member {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.IBoostControlSpec|null|undefined} boostControlSpec
                                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec
                                         * @instance
                                         */
                                        ConditionBoostSpec.prototype.boostControlSpec = null;
    
                                        /**
                                         * Creates a new ConditionBoostSpec instance using the specified properties.
                                         * @function create
                                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec
                                         * @static
                                         * @param {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.IConditionBoostSpec=} [properties] Properties to set
                                         * @returns {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec} ConditionBoostSpec instance
                                         */
                                        ConditionBoostSpec.create = function create(properties) {
                                            return new ConditionBoostSpec(properties);
                                        };
    
                                        /**
                                         * Encodes the specified ConditionBoostSpec message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.verify|verify} messages.
                                         * @function encode
                                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec
                                         * @static
                                         * @param {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.IConditionBoostSpec} message ConditionBoostSpec message or plain object to encode
                                         * @param {$protobuf.Writer} [writer] Writer to encode to
                                         * @returns {$protobuf.Writer} Writer
                                         */
                                        ConditionBoostSpec.encode = function encode(message, writer) {
                                            if (!writer)
                                                writer = $Writer.create();
                                            if (message.condition != null && Object.hasOwnProperty.call(message, "condition"))
                                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.condition);
                                            if (message.boost != null && Object.hasOwnProperty.call(message, "boost"))
                                                writer.uint32(/* id 2, wireType 5 =*/21).float(message.boost);
                                            if (message.boostControlSpec != null && Object.hasOwnProperty.call(message, "boostControlSpec"))
                                                $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.encode(message.boostControlSpec, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                                            return writer;
                                        };
    
                                        /**
                                         * Encodes the specified ConditionBoostSpec message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.verify|verify} messages.
                                         * @function encodeDelimited
                                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec
                                         * @static
                                         * @param {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.IConditionBoostSpec} message ConditionBoostSpec message or plain object to encode
                                         * @param {$protobuf.Writer} [writer] Writer to encode to
                                         * @returns {$protobuf.Writer} Writer
                                         */
                                        ConditionBoostSpec.encodeDelimited = function encodeDelimited(message, writer) {
                                            return this.encode(message, writer).ldelim();
                                        };
    
                                        /**
                                         * Decodes a ConditionBoostSpec message from the specified reader or buffer.
                                         * @function decode
                                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec
                                         * @static
                                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                         * @param {number} [length] Message length if known beforehand
                                         * @returns {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec} ConditionBoostSpec
                                         * @throws {Error} If the payload is not a reader or valid buffer
                                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                         */
                                        ConditionBoostSpec.decode = function decode(reader, length) {
                                            if (!(reader instanceof $Reader))
                                                reader = $Reader.create(reader);
                                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec();
                                            while (reader.pos < end) {
                                                var tag = reader.uint32();
                                                switch (tag >>> 3) {
                                                case 1: {
                                                        message.condition = reader.string();
                                                        break;
                                                    }
                                                case 2: {
                                                        message.boost = reader.float();
                                                        break;
                                                    }
                                                case 4: {
                                                        message.boostControlSpec = $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.decode(reader, reader.uint32());
                                                        break;
                                                    }
                                                default:
                                                    reader.skipType(tag & 7);
                                                    break;
                                                }
                                            }
                                            return message;
                                        };
    
                                        /**
                                         * Decodes a ConditionBoostSpec message from the specified reader or buffer, length delimited.
                                         * @function decodeDelimited
                                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec
                                         * @static
                                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                         * @returns {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec} ConditionBoostSpec
                                         * @throws {Error} If the payload is not a reader or valid buffer
                                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                         */
                                        ConditionBoostSpec.decodeDelimited = function decodeDelimited(reader) {
                                            if (!(reader instanceof $Reader))
                                                reader = new $Reader(reader);
                                            return this.decode(reader, reader.uint32());
                                        };
    
                                        /**
                                         * Verifies a ConditionBoostSpec message.
                                         * @function verify
                                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec
                                         * @static
                                         * @param {Object.<string,*>} message Plain object to verify
                                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                         */
                                        ConditionBoostSpec.verify = function verify(message) {
                                            if (typeof message !== "object" || message === null)
                                                return "object expected";
                                            if (message.condition != null && message.hasOwnProperty("condition"))
                                                if (!$util.isString(message.condition))
                                                    return "condition: string expected";
                                            if (message.boost != null && message.hasOwnProperty("boost"))
                                                if (typeof message.boost !== "number")
                                                    return "boost: number expected";
                                            if (message.boostControlSpec != null && message.hasOwnProperty("boostControlSpec")) {
                                                var error = $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.verify(message.boostControlSpec);
                                                if (error)
                                                    return "boostControlSpec." + error;
                                            }
                                            return null;
                                        };
    
                                        /**
                                         * Creates a ConditionBoostSpec message from a plain object. Also converts values to their respective internal types.
                                         * @function fromObject
                                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec
                                         * @static
                                         * @param {Object.<string,*>} object Plain object
                                         * @returns {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec} ConditionBoostSpec
                                         */
                                        ConditionBoostSpec.fromObject = function fromObject(object) {
                                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec)
                                                return object;
                                            var message = new $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec();
                                            if (object.condition != null)
                                                message.condition = String(object.condition);
                                            if (object.boost != null)
                                                message.boost = Number(object.boost);
                                            if (object.boostControlSpec != null) {
                                                if (typeof object.boostControlSpec !== "object")
                                                    throw TypeError(".google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.boostControlSpec: object expected");
                                                message.boostControlSpec = $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.fromObject(object.boostControlSpec);
                                            }
                                            return message;
                                        };
    
                                        /**
                                         * Creates a plain object from a ConditionBoostSpec message. Also converts values to other types if specified.
                                         * @function toObject
                                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec
                                         * @static
                                         * @param {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec} message ConditionBoostSpec
                                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                                         * @returns {Object.<string,*>} Plain object
                                         */
                                        ConditionBoostSpec.toObject = function toObject(message, options) {
                                            if (!options)
                                                options = {};
                                            var object = {};
                                            if (options.defaults) {
                                                object.condition = "";
                                                object.boost = 0;
                                                object.boostControlSpec = null;
                                            }
                                            if (message.condition != null && message.hasOwnProperty("condition"))
                                                object.condition = message.condition;
                                            if (message.boost != null && message.hasOwnProperty("boost"))
                                                object.boost = options.json && !isFinite(message.boost) ? String(message.boost) : message.boost;
                                            if (message.boostControlSpec != null && message.hasOwnProperty("boostControlSpec"))
                                                object.boostControlSpec = $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.toObject(message.boostControlSpec, options);
                                            return object;
                                        };
    
                                        /**
                                         * Converts this ConditionBoostSpec to JSON.
                                         * @function toJSON
                                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec
                                         * @instance
                                         * @returns {Object.<string,*>} JSON object
                                         */
                                        ConditionBoostSpec.prototype.toJSON = function toJSON() {
                                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                        };
    
                                        /**
                                         * Gets the default type url for ConditionBoostSpec
                                         * @function getTypeUrl
                                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec
                                         * @static
                                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                         * @returns {string} The default type url
                                         */
                                        ConditionBoostSpec.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                            if (typeUrlPrefix === undefined) {
                                                typeUrlPrefix = "type.googleapis.com";
                                            }
                                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec";
                                        };
    
                                        ConditionBoostSpec.BoostControlSpec = (function() {
    
                                            /**
                                             * Properties of a BoostControlSpec.
                                             * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec
                                             * @interface IBoostControlSpec
                                             * @property {string|null} [fieldName] BoostControlSpec fieldName
                                             * @property {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.AttributeType|null} [attributeType] BoostControlSpec attributeType
                                             * @property {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.InterpolationType|null} [interpolationType] BoostControlSpec interpolationType
                                             * @property {Array.<google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.IControlPoint>|null} [controlPoints] BoostControlSpec controlPoints
                                             */
    
                                            /**
                                             * Constructs a new BoostControlSpec.
                                             * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec
                                             * @classdesc Represents a BoostControlSpec.
                                             * @implements IBoostControlSpec
                                             * @constructor
                                             * @param {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.IBoostControlSpec=} [properties] Properties to set
                                             */
                                            function BoostControlSpec(properties) {
                                                this.controlPoints = [];
                                                if (properties)
                                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                                        if (properties[keys[i]] != null)
                                                            this[keys[i]] = properties[keys[i]];
                                            }
    
                                            /**
                                             * BoostControlSpec fieldName.
                                             * @member {string} fieldName
                                             * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec
                                             * @instance
                                             */
                                            BoostControlSpec.prototype.fieldName = "";
    
                                            /**
                                             * BoostControlSpec attributeType.
                                             * @member {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.AttributeType} attributeType
                                             * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec
                                             * @instance
                                             */
                                            BoostControlSpec.prototype.attributeType = 0;
    
                                            /**
                                             * BoostControlSpec interpolationType.
                                             * @member {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.InterpolationType} interpolationType
                                             * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec
                                             * @instance
                                             */
                                            BoostControlSpec.prototype.interpolationType = 0;
    
                                            /**
                                             * BoostControlSpec controlPoints.
                                             * @member {Array.<google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.IControlPoint>} controlPoints
                                             * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec
                                             * @instance
                                             */
                                            BoostControlSpec.prototype.controlPoints = $util.emptyArray;
    
                                            /**
                                             * Creates a new BoostControlSpec instance using the specified properties.
                                             * @function create
                                             * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec
                                             * @static
                                             * @param {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.IBoostControlSpec=} [properties] Properties to set
                                             * @returns {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec} BoostControlSpec instance
                                             */
                                            BoostControlSpec.create = function create(properties) {
                                                return new BoostControlSpec(properties);
                                            };
    
                                            /**
                                             * Encodes the specified BoostControlSpec message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.verify|verify} messages.
                                             * @function encode
                                             * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec
                                             * @static
                                             * @param {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.IBoostControlSpec} message BoostControlSpec message or plain object to encode
                                             * @param {$protobuf.Writer} [writer] Writer to encode to
                                             * @returns {$protobuf.Writer} Writer
                                             */
                                            BoostControlSpec.encode = function encode(message, writer) {
                                                if (!writer)
                                                    writer = $Writer.create();
                                                if (message.fieldName != null && Object.hasOwnProperty.call(message, "fieldName"))
                                                    writer.uint32(/* id 1, wireType 2 =*/10).string(message.fieldName);
                                                if (message.attributeType != null && Object.hasOwnProperty.call(message, "attributeType"))
                                                    writer.uint32(/* id 2, wireType 0 =*/16).int32(message.attributeType);
                                                if (message.interpolationType != null && Object.hasOwnProperty.call(message, "interpolationType"))
                                                    writer.uint32(/* id 3, wireType 0 =*/24).int32(message.interpolationType);
                                                if (message.controlPoints != null && message.controlPoints.length)
                                                    for (var i = 0; i < message.controlPoints.length; ++i)
                                                        $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.ControlPoint.encode(message.controlPoints[i], writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                                                return writer;
                                            };
    
                                            /**
                                             * Encodes the specified BoostControlSpec message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.verify|verify} messages.
                                             * @function encodeDelimited
                                             * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec
                                             * @static
                                             * @param {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.IBoostControlSpec} message BoostControlSpec message or plain object to encode
                                             * @param {$protobuf.Writer} [writer] Writer to encode to
                                             * @returns {$protobuf.Writer} Writer
                                             */
                                            BoostControlSpec.encodeDelimited = function encodeDelimited(message, writer) {
                                                return this.encode(message, writer).ldelim();
                                            };
    
                                            /**
                                             * Decodes a BoostControlSpec message from the specified reader or buffer.
                                             * @function decode
                                             * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec
                                             * @static
                                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                             * @param {number} [length] Message length if known beforehand
                                             * @returns {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec} BoostControlSpec
                                             * @throws {Error} If the payload is not a reader or valid buffer
                                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                             */
                                            BoostControlSpec.decode = function decode(reader, length) {
                                                if (!(reader instanceof $Reader))
                                                    reader = $Reader.create(reader);
                                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec();
                                                while (reader.pos < end) {
                                                    var tag = reader.uint32();
                                                    switch (tag >>> 3) {
                                                    case 1: {
                                                            message.fieldName = reader.string();
                                                            break;
                                                        }
                                                    case 2: {
                                                            message.attributeType = reader.int32();
                                                            break;
                                                        }
                                                    case 3: {
                                                            message.interpolationType = reader.int32();
                                                            break;
                                                        }
                                                    case 4: {
                                                            if (!(message.controlPoints && message.controlPoints.length))
                                                                message.controlPoints = [];
                                                            message.controlPoints.push($root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.ControlPoint.decode(reader, reader.uint32()));
                                                            break;
                                                        }
                                                    default:
                                                        reader.skipType(tag & 7);
                                                        break;
                                                    }
                                                }
                                                return message;
                                            };
    
                                            /**
                                             * Decodes a BoostControlSpec message from the specified reader or buffer, length delimited.
                                             * @function decodeDelimited
                                             * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec
                                             * @static
                                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                             * @returns {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec} BoostControlSpec
                                             * @throws {Error} If the payload is not a reader or valid buffer
                                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                             */
                                            BoostControlSpec.decodeDelimited = function decodeDelimited(reader) {
                                                if (!(reader instanceof $Reader))
                                                    reader = new $Reader(reader);
                                                return this.decode(reader, reader.uint32());
                                            };
    
                                            /**
                                             * Verifies a BoostControlSpec message.
                                             * @function verify
                                             * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec
                                             * @static
                                             * @param {Object.<string,*>} message Plain object to verify
                                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                             */
                                            BoostControlSpec.verify = function verify(message) {
                                                if (typeof message !== "object" || message === null)
                                                    return "object expected";
                                                if (message.fieldName != null && message.hasOwnProperty("fieldName"))
                                                    if (!$util.isString(message.fieldName))
                                                        return "fieldName: string expected";
                                                if (message.attributeType != null && message.hasOwnProperty("attributeType"))
                                                    switch (message.attributeType) {
                                                    default:
                                                        return "attributeType: enum value expected";
                                                    case 0:
                                                    case 1:
                                                    case 2:
                                                        break;
                                                    }
                                                if (message.interpolationType != null && message.hasOwnProperty("interpolationType"))
                                                    switch (message.interpolationType) {
                                                    default:
                                                        return "interpolationType: enum value expected";
                                                    case 0:
                                                    case 1:
                                                        break;
                                                    }
                                                if (message.controlPoints != null && message.hasOwnProperty("controlPoints")) {
                                                    if (!Array.isArray(message.controlPoints))
                                                        return "controlPoints: array expected";
                                                    for (var i = 0; i < message.controlPoints.length; ++i) {
                                                        var error = $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.ControlPoint.verify(message.controlPoints[i]);
                                                        if (error)
                                                            return "controlPoints." + error;
                                                    }
                                                }
                                                return null;
                                            };
    
                                            /**
                                             * Creates a BoostControlSpec message from a plain object. Also converts values to their respective internal types.
                                             * @function fromObject
                                             * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec
                                             * @static
                                             * @param {Object.<string,*>} object Plain object
                                             * @returns {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec} BoostControlSpec
                                             */
                                            BoostControlSpec.fromObject = function fromObject(object) {
                                                if (object instanceof $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec)
                                                    return object;
                                                var message = new $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec();
                                                if (object.fieldName != null)
                                                    message.fieldName = String(object.fieldName);
                                                switch (object.attributeType) {
                                                default:
                                                    if (typeof object.attributeType === "number") {
                                                        message.attributeType = object.attributeType;
                                                        break;
                                                    }
                                                    break;
                                                case "ATTRIBUTE_TYPE_UNSPECIFIED":
                                                case 0:
                                                    message.attributeType = 0;
                                                    break;
                                                case "NUMERICAL":
                                                case 1:
                                                    message.attributeType = 1;
                                                    break;
                                                case "FRESHNESS":
                                                case 2:
                                                    message.attributeType = 2;
                                                    break;
                                                }
                                                switch (object.interpolationType) {
                                                default:
                                                    if (typeof object.interpolationType === "number") {
                                                        message.interpolationType = object.interpolationType;
                                                        break;
                                                    }
                                                    break;
                                                case "INTERPOLATION_TYPE_UNSPECIFIED":
                                                case 0:
                                                    message.interpolationType = 0;
                                                    break;
                                                case "LINEAR":
                                                case 1:
                                                    message.interpolationType = 1;
                                                    break;
                                                }
                                                if (object.controlPoints) {
                                                    if (!Array.isArray(object.controlPoints))
                                                        throw TypeError(".google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.controlPoints: array expected");
                                                    message.controlPoints = [];
                                                    for (var i = 0; i < object.controlPoints.length; ++i) {
                                                        if (typeof object.controlPoints[i] !== "object")
                                                            throw TypeError(".google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.controlPoints: object expected");
                                                        message.controlPoints[i] = $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.ControlPoint.fromObject(object.controlPoints[i]);
                                                    }
                                                }
                                                return message;
                                            };
    
                                            /**
                                             * Creates a plain object from a BoostControlSpec message. Also converts values to other types if specified.
                                             * @function toObject
                                             * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec
                                             * @static
                                             * @param {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec} message BoostControlSpec
                                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                                             * @returns {Object.<string,*>} Plain object
                                             */
                                            BoostControlSpec.toObject = function toObject(message, options) {
                                                if (!options)
                                                    options = {};
                                                var object = {};
                                                if (options.arrays || options.defaults)
                                                    object.controlPoints = [];
                                                if (options.defaults) {
                                                    object.fieldName = "";
                                                    object.attributeType = options.enums === String ? "ATTRIBUTE_TYPE_UNSPECIFIED" : 0;
                                                    object.interpolationType = options.enums === String ? "INTERPOLATION_TYPE_UNSPECIFIED" : 0;
                                                }
                                                if (message.fieldName != null && message.hasOwnProperty("fieldName"))
                                                    object.fieldName = message.fieldName;
                                                if (message.attributeType != null && message.hasOwnProperty("attributeType"))
                                                    object.attributeType = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.AttributeType[message.attributeType] === undefined ? message.attributeType : $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.AttributeType[message.attributeType] : message.attributeType;
                                                if (message.interpolationType != null && message.hasOwnProperty("interpolationType"))
                                                    object.interpolationType = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.InterpolationType[message.interpolationType] === undefined ? message.interpolationType : $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.InterpolationType[message.interpolationType] : message.interpolationType;
                                                if (message.controlPoints && message.controlPoints.length) {
                                                    object.controlPoints = [];
                                                    for (var j = 0; j < message.controlPoints.length; ++j)
                                                        object.controlPoints[j] = $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.ControlPoint.toObject(message.controlPoints[j], options);
                                                }
                                                return object;
                                            };
    
                                            /**
                                             * Converts this BoostControlSpec to JSON.
                                             * @function toJSON
                                             * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec
                                             * @instance
                                             * @returns {Object.<string,*>} JSON object
                                             */
                                            BoostControlSpec.prototype.toJSON = function toJSON() {
                                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                            };
    
                                            /**
                                             * Gets the default type url for BoostControlSpec
                                             * @function getTypeUrl
                                             * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec
                                             * @static
                                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                             * @returns {string} The default type url
                                             */
                                            BoostControlSpec.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                                if (typeUrlPrefix === undefined) {
                                                    typeUrlPrefix = "type.googleapis.com";
                                                }
                                                return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec";
                                            };
    
                                            /**
                                             * AttributeType enum.
                                             * @name google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.AttributeType
                                             * @enum {number}
                                             * @property {number} ATTRIBUTE_TYPE_UNSPECIFIED=0 ATTRIBUTE_TYPE_UNSPECIFIED value
                                             * @property {number} NUMERICAL=1 NUMERICAL value
                                             * @property {number} FRESHNESS=2 FRESHNESS value
                                             */
                                            BoostControlSpec.AttributeType = (function() {
                                                var valuesById = {}, values = Object.create(valuesById);
                                                values[valuesById[0] = "ATTRIBUTE_TYPE_UNSPECIFIED"] = 0;
                                                values[valuesById[1] = "NUMERICAL"] = 1;
                                                values[valuesById[2] = "FRESHNESS"] = 2;
                                                return values;
                                            })();
    
                                            /**
                                             * InterpolationType enum.
                                             * @name google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.InterpolationType
                                             * @enum {number}
                                             * @property {number} INTERPOLATION_TYPE_UNSPECIFIED=0 INTERPOLATION_TYPE_UNSPECIFIED value
                                             * @property {number} LINEAR=1 LINEAR value
                                             */
                                            BoostControlSpec.InterpolationType = (function() {
                                                var valuesById = {}, values = Object.create(valuesById);
                                                values[valuesById[0] = "INTERPOLATION_TYPE_UNSPECIFIED"] = 0;
                                                values[valuesById[1] = "LINEAR"] = 1;
                                                return values;
                                            })();
    
                                            BoostControlSpec.ControlPoint = (function() {
    
                                                /**
                                                 * Properties of a ControlPoint.
                                                 * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec
                                                 * @interface IControlPoint
                                                 * @property {string|null} [attributeValue] ControlPoint attributeValue
                                                 * @property {number|null} [boostAmount] ControlPoint boostAmount
                                                 */
    
                                                /**
                                                 * Constructs a new ControlPoint.
                                                 * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec
                                                 * @classdesc Represents a ControlPoint.
                                                 * @implements IControlPoint
                                                 * @constructor
                                                 * @param {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.IControlPoint=} [properties] Properties to set
                                                 */
                                                function ControlPoint(properties) {
                                                    if (properties)
                                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                                            if (properties[keys[i]] != null)
                                                                this[keys[i]] = properties[keys[i]];
                                                }
    
                                                /**
                                                 * ControlPoint attributeValue.
                                                 * @member {string} attributeValue
                                                 * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.ControlPoint
                                                 * @instance
                                                 */
                                                ControlPoint.prototype.attributeValue = "";
    
                                                /**
                                                 * ControlPoint boostAmount.
                                                 * @member {number} boostAmount
                                                 * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.ControlPoint
                                                 * @instance
                                                 */
                                                ControlPoint.prototype.boostAmount = 0;
    
                                                /**
                                                 * Creates a new ControlPoint instance using the specified properties.
                                                 * @function create
                                                 * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.ControlPoint
                                                 * @static
                                                 * @param {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.IControlPoint=} [properties] Properties to set
                                                 * @returns {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.ControlPoint} ControlPoint instance
                                                 */
                                                ControlPoint.create = function create(properties) {
                                                    return new ControlPoint(properties);
                                                };
    
                                                /**
                                                 * Encodes the specified ControlPoint message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.ControlPoint.verify|verify} messages.
                                                 * @function encode
                                                 * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.ControlPoint
                                                 * @static
                                                 * @param {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.IControlPoint} message ControlPoint message or plain object to encode
                                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                                 * @returns {$protobuf.Writer} Writer
                                                 */
                                                ControlPoint.encode = function encode(message, writer) {
                                                    if (!writer)
                                                        writer = $Writer.create();
                                                    if (message.attributeValue != null && Object.hasOwnProperty.call(message, "attributeValue"))
                                                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.attributeValue);
                                                    if (message.boostAmount != null && Object.hasOwnProperty.call(message, "boostAmount"))
                                                        writer.uint32(/* id 2, wireType 5 =*/21).float(message.boostAmount);
                                                    return writer;
                                                };
    
                                                /**
                                                 * Encodes the specified ControlPoint message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.ControlPoint.verify|verify} messages.
                                                 * @function encodeDelimited
                                                 * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.ControlPoint
                                                 * @static
                                                 * @param {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.IControlPoint} message ControlPoint message or plain object to encode
                                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                                 * @returns {$protobuf.Writer} Writer
                                                 */
                                                ControlPoint.encodeDelimited = function encodeDelimited(message, writer) {
                                                    return this.encode(message, writer).ldelim();
                                                };
    
                                                /**
                                                 * Decodes a ControlPoint message from the specified reader or buffer.
                                                 * @function decode
                                                 * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.ControlPoint
                                                 * @static
                                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                                 * @param {number} [length] Message length if known beforehand
                                                 * @returns {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.ControlPoint} ControlPoint
                                                 * @throws {Error} If the payload is not a reader or valid buffer
                                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                                 */
                                                ControlPoint.decode = function decode(reader, length) {
                                                    if (!(reader instanceof $Reader))
                                                        reader = $Reader.create(reader);
                                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.ControlPoint();
                                                    while (reader.pos < end) {
                                                        var tag = reader.uint32();
                                                        switch (tag >>> 3) {
                                                        case 1: {
                                                                message.attributeValue = reader.string();
                                                                break;
                                                            }
                                                        case 2: {
                                                                message.boostAmount = reader.float();
                                                                break;
                                                            }
                                                        default:
                                                            reader.skipType(tag & 7);
                                                            break;
                                                        }
                                                    }
                                                    return message;
                                                };
    
                                                /**
                                                 * Decodes a ControlPoint message from the specified reader or buffer, length delimited.
                                                 * @function decodeDelimited
                                                 * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.ControlPoint
                                                 * @static
                                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                                 * @returns {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.ControlPoint} ControlPoint
                                                 * @throws {Error} If the payload is not a reader or valid buffer
                                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                                 */
                                                ControlPoint.decodeDelimited = function decodeDelimited(reader) {
                                                    if (!(reader instanceof $Reader))
                                                        reader = new $Reader(reader);
                                                    return this.decode(reader, reader.uint32());
                                                };
    
                                                /**
                                                 * Verifies a ControlPoint message.
                                                 * @function verify
                                                 * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.ControlPoint
                                                 * @static
                                                 * @param {Object.<string,*>} message Plain object to verify
                                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                                 */
                                                ControlPoint.verify = function verify(message) {
                                                    if (typeof message !== "object" || message === null)
                                                        return "object expected";
                                                    if (message.attributeValue != null && message.hasOwnProperty("attributeValue"))
                                                        if (!$util.isString(message.attributeValue))
                                                            return "attributeValue: string expected";
                                                    if (message.boostAmount != null && message.hasOwnProperty("boostAmount"))
                                                        if (typeof message.boostAmount !== "number")
                                                            return "boostAmount: number expected";
                                                    return null;
                                                };
    
                                                /**
                                                 * Creates a ControlPoint message from a plain object. Also converts values to their respective internal types.
                                                 * @function fromObject
                                                 * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.ControlPoint
                                                 * @static
                                                 * @param {Object.<string,*>} object Plain object
                                                 * @returns {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.ControlPoint} ControlPoint
                                                 */
                                                ControlPoint.fromObject = function fromObject(object) {
                                                    if (object instanceof $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.ControlPoint)
                                                        return object;
                                                    var message = new $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.ControlPoint();
                                                    if (object.attributeValue != null)
                                                        message.attributeValue = String(object.attributeValue);
                                                    if (object.boostAmount != null)
                                                        message.boostAmount = Number(object.boostAmount);
                                                    return message;
                                                };
    
                                                /**
                                                 * Creates a plain object from a ControlPoint message. Also converts values to other types if specified.
                                                 * @function toObject
                                                 * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.ControlPoint
                                                 * @static
                                                 * @param {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.ControlPoint} message ControlPoint
                                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                                 * @returns {Object.<string,*>} Plain object
                                                 */
                                                ControlPoint.toObject = function toObject(message, options) {
                                                    if (!options)
                                                        options = {};
                                                    var object = {};
                                                    if (options.defaults) {
                                                        object.attributeValue = "";
                                                        object.boostAmount = 0;
                                                    }
                                                    if (message.attributeValue != null && message.hasOwnProperty("attributeValue"))
                                                        object.attributeValue = message.attributeValue;
                                                    if (message.boostAmount != null && message.hasOwnProperty("boostAmount"))
                                                        object.boostAmount = options.json && !isFinite(message.boostAmount) ? String(message.boostAmount) : message.boostAmount;
                                                    return object;
                                                };
    
                                                /**
                                                 * Converts this ControlPoint to JSON.
                                                 * @function toJSON
                                                 * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.ControlPoint
                                                 * @instance
                                                 * @returns {Object.<string,*>} JSON object
                                                 */
                                                ControlPoint.prototype.toJSON = function toJSON() {
                                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                                };
    
                                                /**
                                                 * Gets the default type url for ControlPoint
                                                 * @function getTypeUrl
                                                 * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.ControlPoint
                                                 * @static
                                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                                 * @returns {string} The default type url
                                                 */
                                                ControlPoint.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                                    if (typeUrlPrefix === undefined) {
                                                        typeUrlPrefix = "type.googleapis.com";
                                                    }
                                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.BoostSpecs.BoostSpec.ConditionBoostSpec.BoostControlSpec.ControlPoint";
                                                };
    
                                                return ControlPoint;
                                            })();
    
                                            return BoostControlSpec;
                                        })();
    
                                        return ConditionBoostSpec;
                                    })();
    
                                    return BoostSpec;
                                })();
    
                                return BoostSpecs;
                            })();
    
                            SearchConfig.FilterSpecs = (function() {
    
                                /**
                                 * Properties of a FilterSpecs.
                                 * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig
                                 * @interface IFilterSpecs
                                 * @property {Array.<string>|null} [dataStores] FilterSpecs dataStores
                                 * @property {string|null} [filter] FilterSpecs filter
                                 */
    
                                /**
                                 * Constructs a new FilterSpecs.
                                 * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig
                                 * @classdesc Represents a FilterSpecs.
                                 * @implements IFilterSpecs
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.IFilterSpecs=} [properties] Properties to set
                                 */
                                function FilterSpecs(properties) {
                                    this.dataStores = [];
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * FilterSpecs dataStores.
                                 * @member {Array.<string>} dataStores
                                 * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.FilterSpecs
                                 * @instance
                                 */
                                FilterSpecs.prototype.dataStores = $util.emptyArray;
    
                                /**
                                 * FilterSpecs filter.
                                 * @member {string} filter
                                 * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.FilterSpecs
                                 * @instance
                                 */
                                FilterSpecs.prototype.filter = "";
    
                                /**
                                 * Creates a new FilterSpecs instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.FilterSpecs
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.IFilterSpecs=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.FilterSpecs} FilterSpecs instance
                                 */
                                FilterSpecs.create = function create(properties) {
                                    return new FilterSpecs(properties);
                                };
    
                                /**
                                 * Encodes the specified FilterSpecs message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.FilterSpecs.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.FilterSpecs
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.IFilterSpecs} message FilterSpecs message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                FilterSpecs.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.dataStores != null && message.dataStores.length)
                                        for (var i = 0; i < message.dataStores.length; ++i)
                                            writer.uint32(/* id 1, wireType 2 =*/10).string(message.dataStores[i]);
                                    if (message.filter != null && Object.hasOwnProperty.call(message, "filter"))
                                        writer.uint32(/* id 2, wireType 2 =*/18).string(message.filter);
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified FilterSpecs message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.FilterSpecs.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.FilterSpecs
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.IFilterSpecs} message FilterSpecs message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                FilterSpecs.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a FilterSpecs message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.FilterSpecs
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.FilterSpecs} FilterSpecs
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                FilterSpecs.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.FilterSpecs();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                if (!(message.dataStores && message.dataStores.length))
                                                    message.dataStores = [];
                                                message.dataStores.push(reader.string());
                                                break;
                                            }
                                        case 2: {
                                                message.filter = reader.string();
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a FilterSpecs message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.FilterSpecs
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.FilterSpecs} FilterSpecs
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                FilterSpecs.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a FilterSpecs message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.FilterSpecs
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                FilterSpecs.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.dataStores != null && message.hasOwnProperty("dataStores")) {
                                        if (!Array.isArray(message.dataStores))
                                            return "dataStores: array expected";
                                        for (var i = 0; i < message.dataStores.length; ++i)
                                            if (!$util.isString(message.dataStores[i]))
                                                return "dataStores: string[] expected";
                                    }
                                    if (message.filter != null && message.hasOwnProperty("filter"))
                                        if (!$util.isString(message.filter))
                                            return "filter: string expected";
                                    return null;
                                };
    
                                /**
                                 * Creates a FilterSpecs message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.FilterSpecs
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.FilterSpecs} FilterSpecs
                                 */
                                FilterSpecs.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.FilterSpecs)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.FilterSpecs();
                                    if (object.dataStores) {
                                        if (!Array.isArray(object.dataStores))
                                            throw TypeError(".google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.FilterSpecs.dataStores: array expected");
                                        message.dataStores = [];
                                        for (var i = 0; i < object.dataStores.length; ++i)
                                            message.dataStores[i] = String(object.dataStores[i]);
                                    }
                                    if (object.filter != null)
                                        message.filter = String(object.filter);
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a FilterSpecs message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.FilterSpecs
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.FilterSpecs} message FilterSpecs
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                FilterSpecs.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.arrays || options.defaults)
                                        object.dataStores = [];
                                    if (options.defaults)
                                        object.filter = "";
                                    if (message.dataStores && message.dataStores.length) {
                                        object.dataStores = [];
                                        for (var j = 0; j < message.dataStores.length; ++j)
                                            object.dataStores[j] = message.dataStores[j];
                                    }
                                    if (message.filter != null && message.hasOwnProperty("filter"))
                                        object.filter = message.filter;
                                    return object;
                                };
    
                                /**
                                 * Converts this FilterSpecs to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.FilterSpecs
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                FilterSpecs.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for FilterSpecs
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.FilterSpecs
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                FilterSpecs.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.SearchKnowledgeRequest.SearchConfig.FilterSpecs";
                                };
    
                                return FilterSpecs;
                            })();
    
                            return SearchConfig;
                        })();
    
                        return SearchKnowledgeRequest;
                    })();
    
                    v2beta1.SearchKnowledgeResponse = (function() {
    
                        /**
                         * Properties of a SearchKnowledgeResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ISearchKnowledgeResponse
                         * @property {Array.<google.cloud.dialogflow.v2beta1.ISearchKnowledgeAnswer>|null} [answers] SearchKnowledgeResponse answers
                         * @property {string|null} [rewrittenQuery] SearchKnowledgeResponse rewrittenQuery
                         */
    
                        /**
                         * Constructs a new SearchKnowledgeResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a SearchKnowledgeResponse.
                         * @implements ISearchKnowledgeResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ISearchKnowledgeResponse=} [properties] Properties to set
                         */
                        function SearchKnowledgeResponse(properties) {
                            this.answers = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SearchKnowledgeResponse answers.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.ISearchKnowledgeAnswer>} answers
                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeResponse
                         * @instance
                         */
                        SearchKnowledgeResponse.prototype.answers = $util.emptyArray;
    
                        /**
                         * SearchKnowledgeResponse rewrittenQuery.
                         * @member {string} rewrittenQuery
                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeResponse
                         * @instance
                         */
                        SearchKnowledgeResponse.prototype.rewrittenQuery = "";
    
                        /**
                         * Creates a new SearchKnowledgeResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISearchKnowledgeResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.SearchKnowledgeResponse} SearchKnowledgeResponse instance
                         */
                        SearchKnowledgeResponse.create = function create(properties) {
                            return new SearchKnowledgeResponse(properties);
                        };
    
                        /**
                         * Encodes the specified SearchKnowledgeResponse message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SearchKnowledgeResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISearchKnowledgeResponse} message SearchKnowledgeResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SearchKnowledgeResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.answers != null && message.answers.length)
                                for (var i = 0; i < message.answers.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer.encode(message.answers[i], writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.rewrittenQuery != null && Object.hasOwnProperty.call(message, "rewrittenQuery"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.rewrittenQuery);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SearchKnowledgeResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SearchKnowledgeResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISearchKnowledgeResponse} message SearchKnowledgeResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SearchKnowledgeResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SearchKnowledgeResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.SearchKnowledgeResponse} SearchKnowledgeResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SearchKnowledgeResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 2: {
                                        if (!(message.answers && message.answers.length))
                                            message.answers = [];
                                        message.answers.push($root.google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 3: {
                                        message.rewrittenQuery = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SearchKnowledgeResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.SearchKnowledgeResponse} SearchKnowledgeResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SearchKnowledgeResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SearchKnowledgeResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SearchKnowledgeResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.answers != null && message.hasOwnProperty("answers")) {
                                if (!Array.isArray(message.answers))
                                    return "answers: array expected";
                                for (var i = 0; i < message.answers.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer.verify(message.answers[i]);
                                    if (error)
                                        return "answers." + error;
                                }
                            }
                            if (message.rewrittenQuery != null && message.hasOwnProperty("rewrittenQuery"))
                                if (!$util.isString(message.rewrittenQuery))
                                    return "rewrittenQuery: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a SearchKnowledgeResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.SearchKnowledgeResponse} SearchKnowledgeResponse
                         */
                        SearchKnowledgeResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeResponse();
                            if (object.answers) {
                                if (!Array.isArray(object.answers))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.SearchKnowledgeResponse.answers: array expected");
                                message.answers = [];
                                for (var i = 0; i < object.answers.length; ++i) {
                                    if (typeof object.answers[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.SearchKnowledgeResponse.answers: object expected");
                                    message.answers[i] = $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer.fromObject(object.answers[i]);
                                }
                            }
                            if (object.rewrittenQuery != null)
                                message.rewrittenQuery = String(object.rewrittenQuery);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SearchKnowledgeResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.SearchKnowledgeResponse} message SearchKnowledgeResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SearchKnowledgeResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.answers = [];
                            if (options.defaults)
                                object.rewrittenQuery = "";
                            if (message.answers && message.answers.length) {
                                object.answers = [];
                                for (var j = 0; j < message.answers.length; ++j)
                                    object.answers[j] = $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer.toObject(message.answers[j], options);
                            }
                            if (message.rewrittenQuery != null && message.hasOwnProperty("rewrittenQuery"))
                                object.rewrittenQuery = message.rewrittenQuery;
                            return object;
                        };
    
                        /**
                         * Converts this SearchKnowledgeResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SearchKnowledgeResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SearchKnowledgeResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SearchKnowledgeResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.SearchKnowledgeResponse";
                        };
    
                        return SearchKnowledgeResponse;
                    })();
    
                    v2beta1.SearchKnowledgeAnswer = (function() {
    
                        /**
                         * Properties of a SearchKnowledgeAnswer.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ISearchKnowledgeAnswer
                         * @property {string|null} [answer] SearchKnowledgeAnswer answer
                         * @property {google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer.AnswerType|null} [answerType] SearchKnowledgeAnswer answerType
                         * @property {Array.<google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer.IAnswerSource>|null} [answerSources] SearchKnowledgeAnswer answerSources
                         * @property {string|null} [answerRecord] SearchKnowledgeAnswer answerRecord
                         */
    
                        /**
                         * Constructs a new SearchKnowledgeAnswer.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a SearchKnowledgeAnswer.
                         * @implements ISearchKnowledgeAnswer
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ISearchKnowledgeAnswer=} [properties] Properties to set
                         */
                        function SearchKnowledgeAnswer(properties) {
                            this.answerSources = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SearchKnowledgeAnswer answer.
                         * @member {string} answer
                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer
                         * @instance
                         */
                        SearchKnowledgeAnswer.prototype.answer = "";
    
                        /**
                         * SearchKnowledgeAnswer answerType.
                         * @member {google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer.AnswerType} answerType
                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer
                         * @instance
                         */
                        SearchKnowledgeAnswer.prototype.answerType = 0;
    
                        /**
                         * SearchKnowledgeAnswer answerSources.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer.IAnswerSource>} answerSources
                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer
                         * @instance
                         */
                        SearchKnowledgeAnswer.prototype.answerSources = $util.emptyArray;
    
                        /**
                         * SearchKnowledgeAnswer answerRecord.
                         * @member {string} answerRecord
                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer
                         * @instance
                         */
                        SearchKnowledgeAnswer.prototype.answerRecord = "";
    
                        /**
                         * Creates a new SearchKnowledgeAnswer instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISearchKnowledgeAnswer=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer} SearchKnowledgeAnswer instance
                         */
                        SearchKnowledgeAnswer.create = function create(properties) {
                            return new SearchKnowledgeAnswer(properties);
                        };
    
                        /**
                         * Encodes the specified SearchKnowledgeAnswer message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISearchKnowledgeAnswer} message SearchKnowledgeAnswer message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SearchKnowledgeAnswer.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.answer != null && Object.hasOwnProperty.call(message, "answer"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.answer);
                            if (message.answerType != null && Object.hasOwnProperty.call(message, "answerType"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.answerType);
                            if (message.answerSources != null && message.answerSources.length)
                                for (var i = 0; i < message.answerSources.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer.AnswerSource.encode(message.answerSources[i], writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            if (message.answerRecord != null && Object.hasOwnProperty.call(message, "answerRecord"))
                                writer.uint32(/* id 5, wireType 2 =*/42).string(message.answerRecord);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SearchKnowledgeAnswer message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISearchKnowledgeAnswer} message SearchKnowledgeAnswer message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SearchKnowledgeAnswer.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SearchKnowledgeAnswer message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer} SearchKnowledgeAnswer
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SearchKnowledgeAnswer.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.answer = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.answerType = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        if (!(message.answerSources && message.answerSources.length))
                                            message.answerSources = [];
                                        message.answerSources.push($root.google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer.AnswerSource.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 5: {
                                        message.answerRecord = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SearchKnowledgeAnswer message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer} SearchKnowledgeAnswer
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SearchKnowledgeAnswer.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SearchKnowledgeAnswer message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SearchKnowledgeAnswer.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.answer != null && message.hasOwnProperty("answer"))
                                if (!$util.isString(message.answer))
                                    return "answer: string expected";
                            if (message.answerType != null && message.hasOwnProperty("answerType"))
                                switch (message.answerType) {
                                default:
                                    return "answerType: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                    break;
                                }
                            if (message.answerSources != null && message.hasOwnProperty("answerSources")) {
                                if (!Array.isArray(message.answerSources))
                                    return "answerSources: array expected";
                                for (var i = 0; i < message.answerSources.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer.AnswerSource.verify(message.answerSources[i]);
                                    if (error)
                                        return "answerSources." + error;
                                }
                            }
                            if (message.answerRecord != null && message.hasOwnProperty("answerRecord"))
                                if (!$util.isString(message.answerRecord))
                                    return "answerRecord: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a SearchKnowledgeAnswer message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer} SearchKnowledgeAnswer
                         */
                        SearchKnowledgeAnswer.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer();
                            if (object.answer != null)
                                message.answer = String(object.answer);
                            switch (object.answerType) {
                            default:
                                if (typeof object.answerType === "number") {
                                    message.answerType = object.answerType;
                                    break;
                                }
                                break;
                            case "ANSWER_TYPE_UNSPECIFIED":
                            case 0:
                                message.answerType = 0;
                                break;
                            case "FAQ":
                            case 1:
                                message.answerType = 1;
                                break;
                            case "GENERATIVE":
                            case 2:
                                message.answerType = 2;
                                break;
                            case "INTENT":
                            case 3:
                                message.answerType = 3;
                                break;
                            }
                            if (object.answerSources) {
                                if (!Array.isArray(object.answerSources))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer.answerSources: array expected");
                                message.answerSources = [];
                                for (var i = 0; i < object.answerSources.length; ++i) {
                                    if (typeof object.answerSources[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer.answerSources: object expected");
                                    message.answerSources[i] = $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer.AnswerSource.fromObject(object.answerSources[i]);
                                }
                            }
                            if (object.answerRecord != null)
                                message.answerRecord = String(object.answerRecord);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SearchKnowledgeAnswer message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer} message SearchKnowledgeAnswer
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SearchKnowledgeAnswer.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.answerSources = [];
                            if (options.defaults) {
                                object.answer = "";
                                object.answerType = options.enums === String ? "ANSWER_TYPE_UNSPECIFIED" : 0;
                                object.answerRecord = "";
                            }
                            if (message.answer != null && message.hasOwnProperty("answer"))
                                object.answer = message.answer;
                            if (message.answerType != null && message.hasOwnProperty("answerType"))
                                object.answerType = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer.AnswerType[message.answerType] === undefined ? message.answerType : $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer.AnswerType[message.answerType] : message.answerType;
                            if (message.answerSources && message.answerSources.length) {
                                object.answerSources = [];
                                for (var j = 0; j < message.answerSources.length; ++j)
                                    object.answerSources[j] = $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer.AnswerSource.toObject(message.answerSources[j], options);
                            }
                            if (message.answerRecord != null && message.hasOwnProperty("answerRecord"))
                                object.answerRecord = message.answerRecord;
                            return object;
                        };
    
                        /**
                         * Converts this SearchKnowledgeAnswer to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SearchKnowledgeAnswer.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SearchKnowledgeAnswer
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SearchKnowledgeAnswer.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer";
                        };
    
                        /**
                         * AnswerType enum.
                         * @name google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer.AnswerType
                         * @enum {number}
                         * @property {number} ANSWER_TYPE_UNSPECIFIED=0 ANSWER_TYPE_UNSPECIFIED value
                         * @property {number} FAQ=1 FAQ value
                         * @property {number} GENERATIVE=2 GENERATIVE value
                         * @property {number} INTENT=3 INTENT value
                         */
                        SearchKnowledgeAnswer.AnswerType = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "ANSWER_TYPE_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "FAQ"] = 1;
                            values[valuesById[2] = "GENERATIVE"] = 2;
                            values[valuesById[3] = "INTENT"] = 3;
                            return values;
                        })();
    
                        SearchKnowledgeAnswer.AnswerSource = (function() {
    
                            /**
                             * Properties of an AnswerSource.
                             * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer
                             * @interface IAnswerSource
                             * @property {string|null} [title] AnswerSource title
                             * @property {string|null} [uri] AnswerSource uri
                             * @property {string|null} [snippet] AnswerSource snippet
                             * @property {google.protobuf.IStruct|null} [metadata] AnswerSource metadata
                             */
    
                            /**
                             * Constructs a new AnswerSource.
                             * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer
                             * @classdesc Represents an AnswerSource.
                             * @implements IAnswerSource
                             * @constructor
                             * @param {google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer.IAnswerSource=} [properties] Properties to set
                             */
                            function AnswerSource(properties) {
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * AnswerSource title.
                             * @member {string} title
                             * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer.AnswerSource
                             * @instance
                             */
                            AnswerSource.prototype.title = "";
    
                            /**
                             * AnswerSource uri.
                             * @member {string} uri
                             * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer.AnswerSource
                             * @instance
                             */
                            AnswerSource.prototype.uri = "";
    
                            /**
                             * AnswerSource snippet.
                             * @member {string} snippet
                             * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer.AnswerSource
                             * @instance
                             */
                            AnswerSource.prototype.snippet = "";
    
                            /**
                             * AnswerSource metadata.
                             * @member {google.protobuf.IStruct|null|undefined} metadata
                             * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer.AnswerSource
                             * @instance
                             */
                            AnswerSource.prototype.metadata = null;
    
                            /**
                             * Creates a new AnswerSource instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer.AnswerSource
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer.IAnswerSource=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer.AnswerSource} AnswerSource instance
                             */
                            AnswerSource.create = function create(properties) {
                                return new AnswerSource(properties);
                            };
    
                            /**
                             * Encodes the specified AnswerSource message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer.AnswerSource.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer.AnswerSource
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer.IAnswerSource} message AnswerSource message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            AnswerSource.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.title != null && Object.hasOwnProperty.call(message, "title"))
                                    writer.uint32(/* id 1, wireType 2 =*/10).string(message.title);
                                if (message.uri != null && Object.hasOwnProperty.call(message, "uri"))
                                    writer.uint32(/* id 2, wireType 2 =*/18).string(message.uri);
                                if (message.snippet != null && Object.hasOwnProperty.call(message, "snippet"))
                                    writer.uint32(/* id 3, wireType 2 =*/26).string(message.snippet);
                                if (message.metadata != null && Object.hasOwnProperty.call(message, "metadata"))
                                    $root.google.protobuf.Struct.encode(message.metadata, writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                                return writer;
                            };
    
                            /**
                             * Encodes the specified AnswerSource message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer.AnswerSource.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer.AnswerSource
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer.IAnswerSource} message AnswerSource message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            AnswerSource.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes an AnswerSource message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer.AnswerSource
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer.AnswerSource} AnswerSource
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            AnswerSource.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer.AnswerSource();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.title = reader.string();
                                            break;
                                        }
                                    case 2: {
                                            message.uri = reader.string();
                                            break;
                                        }
                                    case 3: {
                                            message.snippet = reader.string();
                                            break;
                                        }
                                    case 5: {
                                            message.metadata = $root.google.protobuf.Struct.decode(reader, reader.uint32());
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes an AnswerSource message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer.AnswerSource
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer.AnswerSource} AnswerSource
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            AnswerSource.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies an AnswerSource message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer.AnswerSource
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            AnswerSource.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.title != null && message.hasOwnProperty("title"))
                                    if (!$util.isString(message.title))
                                        return "title: string expected";
                                if (message.uri != null && message.hasOwnProperty("uri"))
                                    if (!$util.isString(message.uri))
                                        return "uri: string expected";
                                if (message.snippet != null && message.hasOwnProperty("snippet"))
                                    if (!$util.isString(message.snippet))
                                        return "snippet: string expected";
                                if (message.metadata != null && message.hasOwnProperty("metadata")) {
                                    var error = $root.google.protobuf.Struct.verify(message.metadata);
                                    if (error)
                                        return "metadata." + error;
                                }
                                return null;
                            };
    
                            /**
                             * Creates an AnswerSource message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer.AnswerSource
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer.AnswerSource} AnswerSource
                             */
                            AnswerSource.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer.AnswerSource)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer.AnswerSource();
                                if (object.title != null)
                                    message.title = String(object.title);
                                if (object.uri != null)
                                    message.uri = String(object.uri);
                                if (object.snippet != null)
                                    message.snippet = String(object.snippet);
                                if (object.metadata != null) {
                                    if (typeof object.metadata !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer.AnswerSource.metadata: object expected");
                                    message.metadata = $root.google.protobuf.Struct.fromObject(object.metadata);
                                }
                                return message;
                            };
    
                            /**
                             * Creates a plain object from an AnswerSource message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer.AnswerSource
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer.AnswerSource} message AnswerSource
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            AnswerSource.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.defaults) {
                                    object.title = "";
                                    object.uri = "";
                                    object.snippet = "";
                                    object.metadata = null;
                                }
                                if (message.title != null && message.hasOwnProperty("title"))
                                    object.title = message.title;
                                if (message.uri != null && message.hasOwnProperty("uri"))
                                    object.uri = message.uri;
                                if (message.snippet != null && message.hasOwnProperty("snippet"))
                                    object.snippet = message.snippet;
                                if (message.metadata != null && message.hasOwnProperty("metadata"))
                                    object.metadata = $root.google.protobuf.Struct.toObject(message.metadata, options);
                                return object;
                            };
    
                            /**
                             * Converts this AnswerSource to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer.AnswerSource
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            AnswerSource.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for AnswerSource
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer.AnswerSource
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            AnswerSource.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.SearchKnowledgeAnswer.AnswerSource";
                            };
    
                            return AnswerSource;
                        })();
    
                        return SearchKnowledgeAnswer;
                    })();
    
                    v2beta1.GenerateSuggestionsRequest = (function() {
    
                        /**
                         * Properties of a GenerateSuggestionsRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IGenerateSuggestionsRequest
                         * @property {string|null} [conversation] GenerateSuggestionsRequest conversation
                         * @property {string|null} [latestMessage] GenerateSuggestionsRequest latestMessage
                         * @property {Array.<google.cloud.dialogflow.v2beta1.TriggerEvent>|null} [triggerEvents] GenerateSuggestionsRequest triggerEvents
                         */
    
                        /**
                         * Constructs a new GenerateSuggestionsRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a GenerateSuggestionsRequest.
                         * @implements IGenerateSuggestionsRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IGenerateSuggestionsRequest=} [properties] Properties to set
                         */
                        function GenerateSuggestionsRequest(properties) {
                            this.triggerEvents = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GenerateSuggestionsRequest conversation.
                         * @member {string} conversation
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateSuggestionsRequest
                         * @instance
                         */
                        GenerateSuggestionsRequest.prototype.conversation = "";
    
                        /**
                         * GenerateSuggestionsRequest latestMessage.
                         * @member {string} latestMessage
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateSuggestionsRequest
                         * @instance
                         */
                        GenerateSuggestionsRequest.prototype.latestMessage = "";
    
                        /**
                         * GenerateSuggestionsRequest triggerEvents.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.TriggerEvent>} triggerEvents
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateSuggestionsRequest
                         * @instance
                         */
                        GenerateSuggestionsRequest.prototype.triggerEvents = $util.emptyArray;
    
                        /**
                         * Creates a new GenerateSuggestionsRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateSuggestionsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGenerateSuggestionsRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.GenerateSuggestionsRequest} GenerateSuggestionsRequest instance
                         */
                        GenerateSuggestionsRequest.create = function create(properties) {
                            return new GenerateSuggestionsRequest(properties);
                        };
    
                        /**
                         * Encodes the specified GenerateSuggestionsRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GenerateSuggestionsRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateSuggestionsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGenerateSuggestionsRequest} message GenerateSuggestionsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GenerateSuggestionsRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.conversation != null && Object.hasOwnProperty.call(message, "conversation"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.conversation);
                            if (message.latestMessage != null && Object.hasOwnProperty.call(message, "latestMessage"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.latestMessage);
                            if (message.triggerEvents != null && message.triggerEvents.length) {
                                writer.uint32(/* id 3, wireType 2 =*/26).fork();
                                for (var i = 0; i < message.triggerEvents.length; ++i)
                                    writer.int32(message.triggerEvents[i]);
                                writer.ldelim();
                            }
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GenerateSuggestionsRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GenerateSuggestionsRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateSuggestionsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGenerateSuggestionsRequest} message GenerateSuggestionsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GenerateSuggestionsRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GenerateSuggestionsRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateSuggestionsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.GenerateSuggestionsRequest} GenerateSuggestionsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GenerateSuggestionsRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.GenerateSuggestionsRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.conversation = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.latestMessage = reader.string();
                                        break;
                                    }
                                case 3: {
                                        if (!(message.triggerEvents && message.triggerEvents.length))
                                            message.triggerEvents = [];
                                        if ((tag & 7) === 2) {
                                            var end2 = reader.uint32() + reader.pos;
                                            while (reader.pos < end2)
                                                message.triggerEvents.push(reader.int32());
                                        } else
                                            message.triggerEvents.push(reader.int32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GenerateSuggestionsRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateSuggestionsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.GenerateSuggestionsRequest} GenerateSuggestionsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GenerateSuggestionsRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GenerateSuggestionsRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateSuggestionsRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GenerateSuggestionsRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.conversation != null && message.hasOwnProperty("conversation"))
                                if (!$util.isString(message.conversation))
                                    return "conversation: string expected";
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                if (!$util.isString(message.latestMessage))
                                    return "latestMessage: string expected";
                            if (message.triggerEvents != null && message.hasOwnProperty("triggerEvents")) {
                                if (!Array.isArray(message.triggerEvents))
                                    return "triggerEvents: array expected";
                                for (var i = 0; i < message.triggerEvents.length; ++i)
                                    switch (message.triggerEvents[i]) {
                                    default:
                                        return "triggerEvents: enum value[] expected";
                                    case 0:
                                    case 1:
                                    case 2:
                                    case 3:
                                    case 4:
                                        break;
                                    }
                            }
                            return null;
                        };
    
                        /**
                         * Creates a GenerateSuggestionsRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateSuggestionsRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.GenerateSuggestionsRequest} GenerateSuggestionsRequest
                         */
                        GenerateSuggestionsRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.GenerateSuggestionsRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.GenerateSuggestionsRequest();
                            if (object.conversation != null)
                                message.conversation = String(object.conversation);
                            if (object.latestMessage != null)
                                message.latestMessage = String(object.latestMessage);
                            if (object.triggerEvents) {
                                if (!Array.isArray(object.triggerEvents))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.GenerateSuggestionsRequest.triggerEvents: array expected");
                                message.triggerEvents = [];
                                for (var i = 0; i < object.triggerEvents.length; ++i)
                                    switch (object.triggerEvents[i]) {
                                    default:
                                        if (typeof object.triggerEvents[i] === "number") {
                                            message.triggerEvents[i] = object.triggerEvents[i];
                                            break;
                                        }
                                    case "TRIGGER_EVENT_UNSPECIFIED":
                                    case 0:
                                        message.triggerEvents[i] = 0;
                                        break;
                                    case "END_OF_UTTERANCE":
                                    case 1:
                                        message.triggerEvents[i] = 1;
                                        break;
                                    case "MANUAL_CALL":
                                    case 2:
                                        message.triggerEvents[i] = 2;
                                        break;
                                    case "CUSTOMER_MESSAGE":
                                    case 3:
                                        message.triggerEvents[i] = 3;
                                        break;
                                    case "AGENT_MESSAGE":
                                    case 4:
                                        message.triggerEvents[i] = 4;
                                        break;
                                    }
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GenerateSuggestionsRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateSuggestionsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.GenerateSuggestionsRequest} message GenerateSuggestionsRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GenerateSuggestionsRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.triggerEvents = [];
                            if (options.defaults) {
                                object.conversation = "";
                                object.latestMessage = "";
                            }
                            if (message.conversation != null && message.hasOwnProperty("conversation"))
                                object.conversation = message.conversation;
                            if (message.latestMessage != null && message.hasOwnProperty("latestMessage"))
                                object.latestMessage = message.latestMessage;
                            if (message.triggerEvents && message.triggerEvents.length) {
                                object.triggerEvents = [];
                                for (var j = 0; j < message.triggerEvents.length; ++j)
                                    object.triggerEvents[j] = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.TriggerEvent[message.triggerEvents[j]] === undefined ? message.triggerEvents[j] : $root.google.cloud.dialogflow.v2beta1.TriggerEvent[message.triggerEvents[j]] : message.triggerEvents[j];
                            }
                            return object;
                        };
    
                        /**
                         * Converts this GenerateSuggestionsRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateSuggestionsRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GenerateSuggestionsRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GenerateSuggestionsRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.GenerateSuggestionsRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GenerateSuggestionsRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.GenerateSuggestionsRequest";
                        };
    
                        return GenerateSuggestionsRequest;
                    })();
    
                    v2beta1.ConversationProfiles = (function() {
    
                        /**
                         * Constructs a new ConversationProfiles service.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a ConversationProfiles
                         * @extends $protobuf.rpc.Service
                         * @constructor
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         */
                        function ConversationProfiles(rpcImpl, requestDelimited, responseDelimited) {
                            $protobuf.rpc.Service.call(this, rpcImpl, requestDelimited, responseDelimited);
                        }
    
                        (ConversationProfiles.prototype = Object.create($protobuf.rpc.Service.prototype)).constructor = ConversationProfiles;
    
                        /**
                         * Creates new ConversationProfiles service using the specified rpc implementation.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationProfiles
                         * @static
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         * @returns {ConversationProfiles} RPC service. Useful where requests and/or responses are streamed.
                         */
                        ConversationProfiles.create = function create(rpcImpl, requestDelimited, responseDelimited) {
                            return new this(rpcImpl, requestDelimited, responseDelimited);
                        };
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.ConversationProfiles|listConversationProfiles}.
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationProfiles
                         * @typedef ListConversationProfilesCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.ListConversationProfilesResponse} [response] ListConversationProfilesResponse
                         */
    
                        /**
                         * Calls ListConversationProfiles.
                         * @function listConversationProfiles
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationProfiles
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IListConversationProfilesRequest} request ListConversationProfilesRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.ConversationProfiles.ListConversationProfilesCallback} callback Node-style callback called with the error, if any, and ListConversationProfilesResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(ConversationProfiles.prototype.listConversationProfiles = function listConversationProfiles(request, callback) {
                            return this.rpcCall(listConversationProfiles, $root.google.cloud.dialogflow.v2beta1.ListConversationProfilesRequest, $root.google.cloud.dialogflow.v2beta1.ListConversationProfilesResponse, request, callback);
                        }, "name", { value: "ListConversationProfiles" });
    
                        /**
                         * Calls ListConversationProfiles.
                         * @function listConversationProfiles
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationProfiles
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IListConversationProfilesRequest} request ListConversationProfilesRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.ListConversationProfilesResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.ConversationProfiles|getConversationProfile}.
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationProfiles
                         * @typedef GetConversationProfileCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.ConversationProfile} [response] ConversationProfile
                         */
    
                        /**
                         * Calls GetConversationProfile.
                         * @function getConversationProfile
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationProfiles
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IGetConversationProfileRequest} request GetConversationProfileRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.ConversationProfiles.GetConversationProfileCallback} callback Node-style callback called with the error, if any, and ConversationProfile
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(ConversationProfiles.prototype.getConversationProfile = function getConversationProfile(request, callback) {
                            return this.rpcCall(getConversationProfile, $root.google.cloud.dialogflow.v2beta1.GetConversationProfileRequest, $root.google.cloud.dialogflow.v2beta1.ConversationProfile, request, callback);
                        }, "name", { value: "GetConversationProfile" });
    
                        /**
                         * Calls GetConversationProfile.
                         * @function getConversationProfile
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationProfiles
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IGetConversationProfileRequest} request GetConversationProfileRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.ConversationProfile>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.ConversationProfiles|createConversationProfile}.
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationProfiles
                         * @typedef CreateConversationProfileCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.ConversationProfile} [response] ConversationProfile
                         */
    
                        /**
                         * Calls CreateConversationProfile.
                         * @function createConversationProfile
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationProfiles
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.ICreateConversationProfileRequest} request CreateConversationProfileRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.ConversationProfiles.CreateConversationProfileCallback} callback Node-style callback called with the error, if any, and ConversationProfile
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(ConversationProfiles.prototype.createConversationProfile = function createConversationProfile(request, callback) {
                            return this.rpcCall(createConversationProfile, $root.google.cloud.dialogflow.v2beta1.CreateConversationProfileRequest, $root.google.cloud.dialogflow.v2beta1.ConversationProfile, request, callback);
                        }, "name", { value: "CreateConversationProfile" });
    
                        /**
                         * Calls CreateConversationProfile.
                         * @function createConversationProfile
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationProfiles
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.ICreateConversationProfileRequest} request CreateConversationProfileRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.ConversationProfile>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.ConversationProfiles|updateConversationProfile}.
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationProfiles
                         * @typedef UpdateConversationProfileCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.ConversationProfile} [response] ConversationProfile
                         */
    
                        /**
                         * Calls UpdateConversationProfile.
                         * @function updateConversationProfile
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationProfiles
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateConversationProfileRequest} request UpdateConversationProfileRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.ConversationProfiles.UpdateConversationProfileCallback} callback Node-style callback called with the error, if any, and ConversationProfile
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(ConversationProfiles.prototype.updateConversationProfile = function updateConversationProfile(request, callback) {
                            return this.rpcCall(updateConversationProfile, $root.google.cloud.dialogflow.v2beta1.UpdateConversationProfileRequest, $root.google.cloud.dialogflow.v2beta1.ConversationProfile, request, callback);
                        }, "name", { value: "UpdateConversationProfile" });
    
                        /**
                         * Calls UpdateConversationProfile.
                         * @function updateConversationProfile
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationProfiles
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateConversationProfileRequest} request UpdateConversationProfileRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.ConversationProfile>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.ConversationProfiles|deleteConversationProfile}.
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationProfiles
                         * @typedef DeleteConversationProfileCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.protobuf.Empty} [response] Empty
                         */
    
                        /**
                         * Calls DeleteConversationProfile.
                         * @function deleteConversationProfile
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationProfiles
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteConversationProfileRequest} request DeleteConversationProfileRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.ConversationProfiles.DeleteConversationProfileCallback} callback Node-style callback called with the error, if any, and Empty
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(ConversationProfiles.prototype.deleteConversationProfile = function deleteConversationProfile(request, callback) {
                            return this.rpcCall(deleteConversationProfile, $root.google.cloud.dialogflow.v2beta1.DeleteConversationProfileRequest, $root.google.protobuf.Empty, request, callback);
                        }, "name", { value: "DeleteConversationProfile" });
    
                        /**
                         * Calls DeleteConversationProfile.
                         * @function deleteConversationProfile
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationProfiles
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteConversationProfileRequest} request DeleteConversationProfileRequest message or plain object
                         * @returns {Promise<google.protobuf.Empty>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.ConversationProfiles|setSuggestionFeatureConfig}.
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationProfiles
                         * @typedef SetSuggestionFeatureConfigCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.longrunning.Operation} [response] Operation
                         */
    
                        /**
                         * Calls SetSuggestionFeatureConfig.
                         * @function setSuggestionFeatureConfig
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationProfiles
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.ISetSuggestionFeatureConfigRequest} request SetSuggestionFeatureConfigRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.ConversationProfiles.SetSuggestionFeatureConfigCallback} callback Node-style callback called with the error, if any, and Operation
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(ConversationProfiles.prototype.setSuggestionFeatureConfig = function setSuggestionFeatureConfig(request, callback) {
                            return this.rpcCall(setSuggestionFeatureConfig, $root.google.cloud.dialogflow.v2beta1.SetSuggestionFeatureConfigRequest, $root.google.longrunning.Operation, request, callback);
                        }, "name", { value: "SetSuggestionFeatureConfig" });
    
                        /**
                         * Calls SetSuggestionFeatureConfig.
                         * @function setSuggestionFeatureConfig
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationProfiles
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.ISetSuggestionFeatureConfigRequest} request SetSuggestionFeatureConfigRequest message or plain object
                         * @returns {Promise<google.longrunning.Operation>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.ConversationProfiles|clearSuggestionFeatureConfig}.
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationProfiles
                         * @typedef ClearSuggestionFeatureConfigCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.longrunning.Operation} [response] Operation
                         */
    
                        /**
                         * Calls ClearSuggestionFeatureConfig.
                         * @function clearSuggestionFeatureConfig
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationProfiles
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IClearSuggestionFeatureConfigRequest} request ClearSuggestionFeatureConfigRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.ConversationProfiles.ClearSuggestionFeatureConfigCallback} callback Node-style callback called with the error, if any, and Operation
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(ConversationProfiles.prototype.clearSuggestionFeatureConfig = function clearSuggestionFeatureConfig(request, callback) {
                            return this.rpcCall(clearSuggestionFeatureConfig, $root.google.cloud.dialogflow.v2beta1.ClearSuggestionFeatureConfigRequest, $root.google.longrunning.Operation, request, callback);
                        }, "name", { value: "ClearSuggestionFeatureConfig" });
    
                        /**
                         * Calls ClearSuggestionFeatureConfig.
                         * @function clearSuggestionFeatureConfig
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationProfiles
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IClearSuggestionFeatureConfigRequest} request ClearSuggestionFeatureConfigRequest message or plain object
                         * @returns {Promise<google.longrunning.Operation>} Promise
                         * @variation 2
                         */
    
                        return ConversationProfiles;
                    })();
    
                    v2beta1.ConversationProfile = (function() {
    
                        /**
                         * Properties of a ConversationProfile.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IConversationProfile
                         * @property {string|null} [name] ConversationProfile name
                         * @property {string|null} [displayName] ConversationProfile displayName
                         * @property {google.protobuf.ITimestamp|null} [createTime] ConversationProfile createTime
                         * @property {google.protobuf.ITimestamp|null} [updateTime] ConversationProfile updateTime
                         * @property {google.cloud.dialogflow.v2beta1.IAutomatedAgentConfig|null} [automatedAgentConfig] ConversationProfile automatedAgentConfig
                         * @property {google.cloud.dialogflow.v2beta1.IHumanAgentAssistantConfig|null} [humanAgentAssistantConfig] ConversationProfile humanAgentAssistantConfig
                         * @property {google.cloud.dialogflow.v2beta1.IHumanAgentHandoffConfig|null} [humanAgentHandoffConfig] ConversationProfile humanAgentHandoffConfig
                         * @property {google.cloud.dialogflow.v2beta1.INotificationConfig|null} [notificationConfig] ConversationProfile notificationConfig
                         * @property {google.cloud.dialogflow.v2beta1.ILoggingConfig|null} [loggingConfig] ConversationProfile loggingConfig
                         * @property {google.cloud.dialogflow.v2beta1.INotificationConfig|null} [newMessageEventNotificationConfig] ConversationProfile newMessageEventNotificationConfig
                         * @property {google.cloud.dialogflow.v2beta1.INotificationConfig|null} [newRecognitionResultNotificationConfig] ConversationProfile newRecognitionResultNotificationConfig
                         * @property {google.cloud.dialogflow.v2beta1.ISpeechToTextConfig|null} [sttConfig] ConversationProfile sttConfig
                         * @property {string|null} [languageCode] ConversationProfile languageCode
                         * @property {string|null} [timeZone] ConversationProfile timeZone
                         * @property {string|null} [securitySettings] ConversationProfile securitySettings
                         * @property {google.cloud.dialogflow.v2beta1.ISynthesizeSpeechConfig|null} [ttsConfig] ConversationProfile ttsConfig
                         */
    
                        /**
                         * Constructs a new ConversationProfile.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a ConversationProfile.
                         * @implements IConversationProfile
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IConversationProfile=} [properties] Properties to set
                         */
                        function ConversationProfile(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ConversationProfile name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationProfile
                         * @instance
                         */
                        ConversationProfile.prototype.name = "";
    
                        /**
                         * ConversationProfile displayName.
                         * @member {string} displayName
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationProfile
                         * @instance
                         */
                        ConversationProfile.prototype.displayName = "";
    
                        /**
                         * ConversationProfile createTime.
                         * @member {google.protobuf.ITimestamp|null|undefined} createTime
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationProfile
                         * @instance
                         */
                        ConversationProfile.prototype.createTime = null;
    
                        /**
                         * ConversationProfile updateTime.
                         * @member {google.protobuf.ITimestamp|null|undefined} updateTime
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationProfile
                         * @instance
                         */
                        ConversationProfile.prototype.updateTime = null;
    
                        /**
                         * ConversationProfile automatedAgentConfig.
                         * @member {google.cloud.dialogflow.v2beta1.IAutomatedAgentConfig|null|undefined} automatedAgentConfig
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationProfile
                         * @instance
                         */
                        ConversationProfile.prototype.automatedAgentConfig = null;
    
                        /**
                         * ConversationProfile humanAgentAssistantConfig.
                         * @member {google.cloud.dialogflow.v2beta1.IHumanAgentAssistantConfig|null|undefined} humanAgentAssistantConfig
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationProfile
                         * @instance
                         */
                        ConversationProfile.prototype.humanAgentAssistantConfig = null;
    
                        /**
                         * ConversationProfile humanAgentHandoffConfig.
                         * @member {google.cloud.dialogflow.v2beta1.IHumanAgentHandoffConfig|null|undefined} humanAgentHandoffConfig
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationProfile
                         * @instance
                         */
                        ConversationProfile.prototype.humanAgentHandoffConfig = null;
    
                        /**
                         * ConversationProfile notificationConfig.
                         * @member {google.cloud.dialogflow.v2beta1.INotificationConfig|null|undefined} notificationConfig
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationProfile
                         * @instance
                         */
                        ConversationProfile.prototype.notificationConfig = null;
    
                        /**
                         * ConversationProfile loggingConfig.
                         * @member {google.cloud.dialogflow.v2beta1.ILoggingConfig|null|undefined} loggingConfig
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationProfile
                         * @instance
                         */
                        ConversationProfile.prototype.loggingConfig = null;
    
                        /**
                         * ConversationProfile newMessageEventNotificationConfig.
                         * @member {google.cloud.dialogflow.v2beta1.INotificationConfig|null|undefined} newMessageEventNotificationConfig
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationProfile
                         * @instance
                         */
                        ConversationProfile.prototype.newMessageEventNotificationConfig = null;
    
                        /**
                         * ConversationProfile newRecognitionResultNotificationConfig.
                         * @member {google.cloud.dialogflow.v2beta1.INotificationConfig|null|undefined} newRecognitionResultNotificationConfig
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationProfile
                         * @instance
                         */
                        ConversationProfile.prototype.newRecognitionResultNotificationConfig = null;
    
                        /**
                         * ConversationProfile sttConfig.
                         * @member {google.cloud.dialogflow.v2beta1.ISpeechToTextConfig|null|undefined} sttConfig
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationProfile
                         * @instance
                         */
                        ConversationProfile.prototype.sttConfig = null;
    
                        /**
                         * ConversationProfile languageCode.
                         * @member {string} languageCode
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationProfile
                         * @instance
                         */
                        ConversationProfile.prototype.languageCode = "";
    
                        /**
                         * ConversationProfile timeZone.
                         * @member {string} timeZone
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationProfile
                         * @instance
                         */
                        ConversationProfile.prototype.timeZone = "";
    
                        /**
                         * ConversationProfile securitySettings.
                         * @member {string} securitySettings
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationProfile
                         * @instance
                         */
                        ConversationProfile.prototype.securitySettings = "";
    
                        /**
                         * ConversationProfile ttsConfig.
                         * @member {google.cloud.dialogflow.v2beta1.ISynthesizeSpeechConfig|null|undefined} ttsConfig
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationProfile
                         * @instance
                         */
                        ConversationProfile.prototype.ttsConfig = null;
    
                        /**
                         * Creates a new ConversationProfile instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationProfile
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IConversationProfile=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.ConversationProfile} ConversationProfile instance
                         */
                        ConversationProfile.create = function create(properties) {
                            return new ConversationProfile(properties);
                        };
    
                        /**
                         * Encodes the specified ConversationProfile message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ConversationProfile.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationProfile
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IConversationProfile} message ConversationProfile message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ConversationProfile.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            if (message.displayName != null && Object.hasOwnProperty.call(message, "displayName"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.displayName);
                            if (message.automatedAgentConfig != null && Object.hasOwnProperty.call(message, "automatedAgentConfig"))
                                $root.google.cloud.dialogflow.v2beta1.AutomatedAgentConfig.encode(message.automatedAgentConfig, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            if (message.humanAgentAssistantConfig != null && Object.hasOwnProperty.call(message, "humanAgentAssistantConfig"))
                                $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.encode(message.humanAgentAssistantConfig, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            if (message.humanAgentHandoffConfig != null && Object.hasOwnProperty.call(message, "humanAgentHandoffConfig"))
                                $root.google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.encode(message.humanAgentHandoffConfig, writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                            if (message.notificationConfig != null && Object.hasOwnProperty.call(message, "notificationConfig"))
                                $root.google.cloud.dialogflow.v2beta1.NotificationConfig.encode(message.notificationConfig, writer.uint32(/* id 6, wireType 2 =*/50).fork()).ldelim();
                            if (message.loggingConfig != null && Object.hasOwnProperty.call(message, "loggingConfig"))
                                $root.google.cloud.dialogflow.v2beta1.LoggingConfig.encode(message.loggingConfig, writer.uint32(/* id 7, wireType 2 =*/58).fork()).ldelim();
                            if (message.newMessageEventNotificationConfig != null && Object.hasOwnProperty.call(message, "newMessageEventNotificationConfig"))
                                $root.google.cloud.dialogflow.v2beta1.NotificationConfig.encode(message.newMessageEventNotificationConfig, writer.uint32(/* id 8, wireType 2 =*/66).fork()).ldelim();
                            if (message.sttConfig != null && Object.hasOwnProperty.call(message, "sttConfig"))
                                $root.google.cloud.dialogflow.v2beta1.SpeechToTextConfig.encode(message.sttConfig, writer.uint32(/* id 9, wireType 2 =*/74).fork()).ldelim();
                            if (message.languageCode != null && Object.hasOwnProperty.call(message, "languageCode"))
                                writer.uint32(/* id 10, wireType 2 =*/82).string(message.languageCode);
                            if (message.createTime != null && Object.hasOwnProperty.call(message, "createTime"))
                                $root.google.protobuf.Timestamp.encode(message.createTime, writer.uint32(/* id 11, wireType 2 =*/90).fork()).ldelim();
                            if (message.updateTime != null && Object.hasOwnProperty.call(message, "updateTime"))
                                $root.google.protobuf.Timestamp.encode(message.updateTime, writer.uint32(/* id 12, wireType 2 =*/98).fork()).ldelim();
                            if (message.securitySettings != null && Object.hasOwnProperty.call(message, "securitySettings"))
                                writer.uint32(/* id 13, wireType 2 =*/106).string(message.securitySettings);
                            if (message.timeZone != null && Object.hasOwnProperty.call(message, "timeZone"))
                                writer.uint32(/* id 14, wireType 2 =*/114).string(message.timeZone);
                            if (message.ttsConfig != null && Object.hasOwnProperty.call(message, "ttsConfig"))
                                $root.google.cloud.dialogflow.v2beta1.SynthesizeSpeechConfig.encode(message.ttsConfig, writer.uint32(/* id 18, wireType 2 =*/146).fork()).ldelim();
                            if (message.newRecognitionResultNotificationConfig != null && Object.hasOwnProperty.call(message, "newRecognitionResultNotificationConfig"))
                                $root.google.cloud.dialogflow.v2beta1.NotificationConfig.encode(message.newRecognitionResultNotificationConfig, writer.uint32(/* id 21, wireType 2 =*/170).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ConversationProfile message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ConversationProfile.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationProfile
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IConversationProfile} message ConversationProfile message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ConversationProfile.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ConversationProfile message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationProfile
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.ConversationProfile} ConversationProfile
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ConversationProfile.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ConversationProfile();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.displayName = reader.string();
                                        break;
                                    }
                                case 11: {
                                        message.createTime = $root.google.protobuf.Timestamp.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 12: {
                                        message.updateTime = $root.google.protobuf.Timestamp.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 3: {
                                        message.automatedAgentConfig = $root.google.cloud.dialogflow.v2beta1.AutomatedAgentConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 4: {
                                        message.humanAgentAssistantConfig = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 5: {
                                        message.humanAgentHandoffConfig = $root.google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 6: {
                                        message.notificationConfig = $root.google.cloud.dialogflow.v2beta1.NotificationConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 7: {
                                        message.loggingConfig = $root.google.cloud.dialogflow.v2beta1.LoggingConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 8: {
                                        message.newMessageEventNotificationConfig = $root.google.cloud.dialogflow.v2beta1.NotificationConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 21: {
                                        message.newRecognitionResultNotificationConfig = $root.google.cloud.dialogflow.v2beta1.NotificationConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 9: {
                                        message.sttConfig = $root.google.cloud.dialogflow.v2beta1.SpeechToTextConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 10: {
                                        message.languageCode = reader.string();
                                        break;
                                    }
                                case 14: {
                                        message.timeZone = reader.string();
                                        break;
                                    }
                                case 13: {
                                        message.securitySettings = reader.string();
                                        break;
                                    }
                                case 18: {
                                        message.ttsConfig = $root.google.cloud.dialogflow.v2beta1.SynthesizeSpeechConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ConversationProfile message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationProfile
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.ConversationProfile} ConversationProfile
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ConversationProfile.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ConversationProfile message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationProfile
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ConversationProfile.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            if (message.displayName != null && message.hasOwnProperty("displayName"))
                                if (!$util.isString(message.displayName))
                                    return "displayName: string expected";
                            if (message.createTime != null && message.hasOwnProperty("createTime")) {
                                var error = $root.google.protobuf.Timestamp.verify(message.createTime);
                                if (error)
                                    return "createTime." + error;
                            }
                            if (message.updateTime != null && message.hasOwnProperty("updateTime")) {
                                var error = $root.google.protobuf.Timestamp.verify(message.updateTime);
                                if (error)
                                    return "updateTime." + error;
                            }
                            if (message.automatedAgentConfig != null && message.hasOwnProperty("automatedAgentConfig")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.AutomatedAgentConfig.verify(message.automatedAgentConfig);
                                if (error)
                                    return "automatedAgentConfig." + error;
                            }
                            if (message.humanAgentAssistantConfig != null && message.hasOwnProperty("humanAgentAssistantConfig")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.verify(message.humanAgentAssistantConfig);
                                if (error)
                                    return "humanAgentAssistantConfig." + error;
                            }
                            if (message.humanAgentHandoffConfig != null && message.hasOwnProperty("humanAgentHandoffConfig")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.verify(message.humanAgentHandoffConfig);
                                if (error)
                                    return "humanAgentHandoffConfig." + error;
                            }
                            if (message.notificationConfig != null && message.hasOwnProperty("notificationConfig")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.NotificationConfig.verify(message.notificationConfig);
                                if (error)
                                    return "notificationConfig." + error;
                            }
                            if (message.loggingConfig != null && message.hasOwnProperty("loggingConfig")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.LoggingConfig.verify(message.loggingConfig);
                                if (error)
                                    return "loggingConfig." + error;
                            }
                            if (message.newMessageEventNotificationConfig != null && message.hasOwnProperty("newMessageEventNotificationConfig")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.NotificationConfig.verify(message.newMessageEventNotificationConfig);
                                if (error)
                                    return "newMessageEventNotificationConfig." + error;
                            }
                            if (message.newRecognitionResultNotificationConfig != null && message.hasOwnProperty("newRecognitionResultNotificationConfig")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.NotificationConfig.verify(message.newRecognitionResultNotificationConfig);
                                if (error)
                                    return "newRecognitionResultNotificationConfig." + error;
                            }
                            if (message.sttConfig != null && message.hasOwnProperty("sttConfig")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.SpeechToTextConfig.verify(message.sttConfig);
                                if (error)
                                    return "sttConfig." + error;
                            }
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                if (!$util.isString(message.languageCode))
                                    return "languageCode: string expected";
                            if (message.timeZone != null && message.hasOwnProperty("timeZone"))
                                if (!$util.isString(message.timeZone))
                                    return "timeZone: string expected";
                            if (message.securitySettings != null && message.hasOwnProperty("securitySettings"))
                                if (!$util.isString(message.securitySettings))
                                    return "securitySettings: string expected";
                            if (message.ttsConfig != null && message.hasOwnProperty("ttsConfig")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.SynthesizeSpeechConfig.verify(message.ttsConfig);
                                if (error)
                                    return "ttsConfig." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a ConversationProfile message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationProfile
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.ConversationProfile} ConversationProfile
                         */
                        ConversationProfile.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.ConversationProfile)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.ConversationProfile();
                            if (object.name != null)
                                message.name = String(object.name);
                            if (object.displayName != null)
                                message.displayName = String(object.displayName);
                            if (object.createTime != null) {
                                if (typeof object.createTime !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.ConversationProfile.createTime: object expected");
                                message.createTime = $root.google.protobuf.Timestamp.fromObject(object.createTime);
                            }
                            if (object.updateTime != null) {
                                if (typeof object.updateTime !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.ConversationProfile.updateTime: object expected");
                                message.updateTime = $root.google.protobuf.Timestamp.fromObject(object.updateTime);
                            }
                            if (object.automatedAgentConfig != null) {
                                if (typeof object.automatedAgentConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.ConversationProfile.automatedAgentConfig: object expected");
                                message.automatedAgentConfig = $root.google.cloud.dialogflow.v2beta1.AutomatedAgentConfig.fromObject(object.automatedAgentConfig);
                            }
                            if (object.humanAgentAssistantConfig != null) {
                                if (typeof object.humanAgentAssistantConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.ConversationProfile.humanAgentAssistantConfig: object expected");
                                message.humanAgentAssistantConfig = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.fromObject(object.humanAgentAssistantConfig);
                            }
                            if (object.humanAgentHandoffConfig != null) {
                                if (typeof object.humanAgentHandoffConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.ConversationProfile.humanAgentHandoffConfig: object expected");
                                message.humanAgentHandoffConfig = $root.google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.fromObject(object.humanAgentHandoffConfig);
                            }
                            if (object.notificationConfig != null) {
                                if (typeof object.notificationConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.ConversationProfile.notificationConfig: object expected");
                                message.notificationConfig = $root.google.cloud.dialogflow.v2beta1.NotificationConfig.fromObject(object.notificationConfig);
                            }
                            if (object.loggingConfig != null) {
                                if (typeof object.loggingConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.ConversationProfile.loggingConfig: object expected");
                                message.loggingConfig = $root.google.cloud.dialogflow.v2beta1.LoggingConfig.fromObject(object.loggingConfig);
                            }
                            if (object.newMessageEventNotificationConfig != null) {
                                if (typeof object.newMessageEventNotificationConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.ConversationProfile.newMessageEventNotificationConfig: object expected");
                                message.newMessageEventNotificationConfig = $root.google.cloud.dialogflow.v2beta1.NotificationConfig.fromObject(object.newMessageEventNotificationConfig);
                            }
                            if (object.newRecognitionResultNotificationConfig != null) {
                                if (typeof object.newRecognitionResultNotificationConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.ConversationProfile.newRecognitionResultNotificationConfig: object expected");
                                message.newRecognitionResultNotificationConfig = $root.google.cloud.dialogflow.v2beta1.NotificationConfig.fromObject(object.newRecognitionResultNotificationConfig);
                            }
                            if (object.sttConfig != null) {
                                if (typeof object.sttConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.ConversationProfile.sttConfig: object expected");
                                message.sttConfig = $root.google.cloud.dialogflow.v2beta1.SpeechToTextConfig.fromObject(object.sttConfig);
                            }
                            if (object.languageCode != null)
                                message.languageCode = String(object.languageCode);
                            if (object.timeZone != null)
                                message.timeZone = String(object.timeZone);
                            if (object.securitySettings != null)
                                message.securitySettings = String(object.securitySettings);
                            if (object.ttsConfig != null) {
                                if (typeof object.ttsConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.ConversationProfile.ttsConfig: object expected");
                                message.ttsConfig = $root.google.cloud.dialogflow.v2beta1.SynthesizeSpeechConfig.fromObject(object.ttsConfig);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ConversationProfile message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationProfile
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ConversationProfile} message ConversationProfile
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ConversationProfile.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.name = "";
                                object.displayName = "";
                                object.automatedAgentConfig = null;
                                object.humanAgentAssistantConfig = null;
                                object.humanAgentHandoffConfig = null;
                                object.notificationConfig = null;
                                object.loggingConfig = null;
                                object.newMessageEventNotificationConfig = null;
                                object.sttConfig = null;
                                object.languageCode = "";
                                object.createTime = null;
                                object.updateTime = null;
                                object.securitySettings = "";
                                object.timeZone = "";
                                object.ttsConfig = null;
                                object.newRecognitionResultNotificationConfig = null;
                            }
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            if (message.displayName != null && message.hasOwnProperty("displayName"))
                                object.displayName = message.displayName;
                            if (message.automatedAgentConfig != null && message.hasOwnProperty("automatedAgentConfig"))
                                object.automatedAgentConfig = $root.google.cloud.dialogflow.v2beta1.AutomatedAgentConfig.toObject(message.automatedAgentConfig, options);
                            if (message.humanAgentAssistantConfig != null && message.hasOwnProperty("humanAgentAssistantConfig"))
                                object.humanAgentAssistantConfig = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.toObject(message.humanAgentAssistantConfig, options);
                            if (message.humanAgentHandoffConfig != null && message.hasOwnProperty("humanAgentHandoffConfig"))
                                object.humanAgentHandoffConfig = $root.google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.toObject(message.humanAgentHandoffConfig, options);
                            if (message.notificationConfig != null && message.hasOwnProperty("notificationConfig"))
                                object.notificationConfig = $root.google.cloud.dialogflow.v2beta1.NotificationConfig.toObject(message.notificationConfig, options);
                            if (message.loggingConfig != null && message.hasOwnProperty("loggingConfig"))
                                object.loggingConfig = $root.google.cloud.dialogflow.v2beta1.LoggingConfig.toObject(message.loggingConfig, options);
                            if (message.newMessageEventNotificationConfig != null && message.hasOwnProperty("newMessageEventNotificationConfig"))
                                object.newMessageEventNotificationConfig = $root.google.cloud.dialogflow.v2beta1.NotificationConfig.toObject(message.newMessageEventNotificationConfig, options);
                            if (message.sttConfig != null && message.hasOwnProperty("sttConfig"))
                                object.sttConfig = $root.google.cloud.dialogflow.v2beta1.SpeechToTextConfig.toObject(message.sttConfig, options);
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                object.languageCode = message.languageCode;
                            if (message.createTime != null && message.hasOwnProperty("createTime"))
                                object.createTime = $root.google.protobuf.Timestamp.toObject(message.createTime, options);
                            if (message.updateTime != null && message.hasOwnProperty("updateTime"))
                                object.updateTime = $root.google.protobuf.Timestamp.toObject(message.updateTime, options);
                            if (message.securitySettings != null && message.hasOwnProperty("securitySettings"))
                                object.securitySettings = message.securitySettings;
                            if (message.timeZone != null && message.hasOwnProperty("timeZone"))
                                object.timeZone = message.timeZone;
                            if (message.ttsConfig != null && message.hasOwnProperty("ttsConfig"))
                                object.ttsConfig = $root.google.cloud.dialogflow.v2beta1.SynthesizeSpeechConfig.toObject(message.ttsConfig, options);
                            if (message.newRecognitionResultNotificationConfig != null && message.hasOwnProperty("newRecognitionResultNotificationConfig"))
                                object.newRecognitionResultNotificationConfig = $root.google.cloud.dialogflow.v2beta1.NotificationConfig.toObject(message.newRecognitionResultNotificationConfig, options);
                            return object;
                        };
    
                        /**
                         * Converts this ConversationProfile to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationProfile
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ConversationProfile.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ConversationProfile
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationProfile
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ConversationProfile.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ConversationProfile";
                        };
    
                        return ConversationProfile;
                    })();
    
                    v2beta1.AutomatedAgentConfig = (function() {
    
                        /**
                         * Properties of an AutomatedAgentConfig.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IAutomatedAgentConfig
                         * @property {string|null} [agent] AutomatedAgentConfig agent
                         * @property {google.protobuf.IDuration|null} [sessionTtl] AutomatedAgentConfig sessionTtl
                         */
    
                        /**
                         * Constructs a new AutomatedAgentConfig.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an AutomatedAgentConfig.
                         * @implements IAutomatedAgentConfig
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IAutomatedAgentConfig=} [properties] Properties to set
                         */
                        function AutomatedAgentConfig(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * AutomatedAgentConfig agent.
                         * @member {string} agent
                         * @memberof google.cloud.dialogflow.v2beta1.AutomatedAgentConfig
                         * @instance
                         */
                        AutomatedAgentConfig.prototype.agent = "";
    
                        /**
                         * AutomatedAgentConfig sessionTtl.
                         * @member {google.protobuf.IDuration|null|undefined} sessionTtl
                         * @memberof google.cloud.dialogflow.v2beta1.AutomatedAgentConfig
                         * @instance
                         */
                        AutomatedAgentConfig.prototype.sessionTtl = null;
    
                        /**
                         * Creates a new AutomatedAgentConfig instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.AutomatedAgentConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IAutomatedAgentConfig=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.AutomatedAgentConfig} AutomatedAgentConfig instance
                         */
                        AutomatedAgentConfig.create = function create(properties) {
                            return new AutomatedAgentConfig(properties);
                        };
    
                        /**
                         * Encodes the specified AutomatedAgentConfig message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.AutomatedAgentConfig.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.AutomatedAgentConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IAutomatedAgentConfig} message AutomatedAgentConfig message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        AutomatedAgentConfig.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.agent != null && Object.hasOwnProperty.call(message, "agent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.agent);
                            if (message.sessionTtl != null && Object.hasOwnProperty.call(message, "sessionTtl"))
                                $root.google.protobuf.Duration.encode(message.sessionTtl, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified AutomatedAgentConfig message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.AutomatedAgentConfig.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.AutomatedAgentConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IAutomatedAgentConfig} message AutomatedAgentConfig message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        AutomatedAgentConfig.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an AutomatedAgentConfig message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.AutomatedAgentConfig
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.AutomatedAgentConfig} AutomatedAgentConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        AutomatedAgentConfig.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.AutomatedAgentConfig();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.agent = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.sessionTtl = $root.google.protobuf.Duration.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an AutomatedAgentConfig message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.AutomatedAgentConfig
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.AutomatedAgentConfig} AutomatedAgentConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        AutomatedAgentConfig.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an AutomatedAgentConfig message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.AutomatedAgentConfig
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        AutomatedAgentConfig.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.agent != null && message.hasOwnProperty("agent"))
                                if (!$util.isString(message.agent))
                                    return "agent: string expected";
                            if (message.sessionTtl != null && message.hasOwnProperty("sessionTtl")) {
                                var error = $root.google.protobuf.Duration.verify(message.sessionTtl);
                                if (error)
                                    return "sessionTtl." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates an AutomatedAgentConfig message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.AutomatedAgentConfig
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.AutomatedAgentConfig} AutomatedAgentConfig
                         */
                        AutomatedAgentConfig.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.AutomatedAgentConfig)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.AutomatedAgentConfig();
                            if (object.agent != null)
                                message.agent = String(object.agent);
                            if (object.sessionTtl != null) {
                                if (typeof object.sessionTtl !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.AutomatedAgentConfig.sessionTtl: object expected");
                                message.sessionTtl = $root.google.protobuf.Duration.fromObject(object.sessionTtl);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an AutomatedAgentConfig message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.AutomatedAgentConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.AutomatedAgentConfig} message AutomatedAgentConfig
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        AutomatedAgentConfig.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.agent = "";
                                object.sessionTtl = null;
                            }
                            if (message.agent != null && message.hasOwnProperty("agent"))
                                object.agent = message.agent;
                            if (message.sessionTtl != null && message.hasOwnProperty("sessionTtl"))
                                object.sessionTtl = $root.google.protobuf.Duration.toObject(message.sessionTtl, options);
                            return object;
                        };
    
                        /**
                         * Converts this AutomatedAgentConfig to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.AutomatedAgentConfig
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        AutomatedAgentConfig.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for AutomatedAgentConfig
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.AutomatedAgentConfig
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        AutomatedAgentConfig.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.AutomatedAgentConfig";
                        };
    
                        return AutomatedAgentConfig;
                    })();
    
                    v2beta1.HumanAgentAssistantConfig = (function() {
    
                        /**
                         * Properties of a HumanAgentAssistantConfig.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IHumanAgentAssistantConfig
                         * @property {google.cloud.dialogflow.v2beta1.INotificationConfig|null} [notificationConfig] HumanAgentAssistantConfig notificationConfig
                         * @property {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ISuggestionConfig|null} [humanAgentSuggestionConfig] HumanAgentAssistantConfig humanAgentSuggestionConfig
                         * @property {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ISuggestionConfig|null} [endUserSuggestionConfig] HumanAgentAssistantConfig endUserSuggestionConfig
                         * @property {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.IMessageAnalysisConfig|null} [messageAnalysisConfig] HumanAgentAssistantConfig messageAnalysisConfig
                         */
    
                        /**
                         * Constructs a new HumanAgentAssistantConfig.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a HumanAgentAssistantConfig.
                         * @implements IHumanAgentAssistantConfig
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IHumanAgentAssistantConfig=} [properties] Properties to set
                         */
                        function HumanAgentAssistantConfig(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * HumanAgentAssistantConfig notificationConfig.
                         * @member {google.cloud.dialogflow.v2beta1.INotificationConfig|null|undefined} notificationConfig
                         * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig
                         * @instance
                         */
                        HumanAgentAssistantConfig.prototype.notificationConfig = null;
    
                        /**
                         * HumanAgentAssistantConfig humanAgentSuggestionConfig.
                         * @member {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ISuggestionConfig|null|undefined} humanAgentSuggestionConfig
                         * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig
                         * @instance
                         */
                        HumanAgentAssistantConfig.prototype.humanAgentSuggestionConfig = null;
    
                        /**
                         * HumanAgentAssistantConfig endUserSuggestionConfig.
                         * @member {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ISuggestionConfig|null|undefined} endUserSuggestionConfig
                         * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig
                         * @instance
                         */
                        HumanAgentAssistantConfig.prototype.endUserSuggestionConfig = null;
    
                        /**
                         * HumanAgentAssistantConfig messageAnalysisConfig.
                         * @member {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.IMessageAnalysisConfig|null|undefined} messageAnalysisConfig
                         * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig
                         * @instance
                         */
                        HumanAgentAssistantConfig.prototype.messageAnalysisConfig = null;
    
                        /**
                         * Creates a new HumanAgentAssistantConfig instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IHumanAgentAssistantConfig=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig} HumanAgentAssistantConfig instance
                         */
                        HumanAgentAssistantConfig.create = function create(properties) {
                            return new HumanAgentAssistantConfig(properties);
                        };
    
                        /**
                         * Encodes the specified HumanAgentAssistantConfig message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IHumanAgentAssistantConfig} message HumanAgentAssistantConfig message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        HumanAgentAssistantConfig.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.notificationConfig != null && Object.hasOwnProperty.call(message, "notificationConfig"))
                                $root.google.cloud.dialogflow.v2beta1.NotificationConfig.encode(message.notificationConfig, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.humanAgentSuggestionConfig != null && Object.hasOwnProperty.call(message, "humanAgentSuggestionConfig"))
                                $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionConfig.encode(message.humanAgentSuggestionConfig, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            if (message.endUserSuggestionConfig != null && Object.hasOwnProperty.call(message, "endUserSuggestionConfig"))
                                $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionConfig.encode(message.endUserSuggestionConfig, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            if (message.messageAnalysisConfig != null && Object.hasOwnProperty.call(message, "messageAnalysisConfig"))
                                $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.MessageAnalysisConfig.encode(message.messageAnalysisConfig, writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified HumanAgentAssistantConfig message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IHumanAgentAssistantConfig} message HumanAgentAssistantConfig message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        HumanAgentAssistantConfig.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a HumanAgentAssistantConfig message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig} HumanAgentAssistantConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        HumanAgentAssistantConfig.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 2: {
                                        message.notificationConfig = $root.google.cloud.dialogflow.v2beta1.NotificationConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 3: {
                                        message.humanAgentSuggestionConfig = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 4: {
                                        message.endUserSuggestionConfig = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 5: {
                                        message.messageAnalysisConfig = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.MessageAnalysisConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a HumanAgentAssistantConfig message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig} HumanAgentAssistantConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        HumanAgentAssistantConfig.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a HumanAgentAssistantConfig message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        HumanAgentAssistantConfig.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.notificationConfig != null && message.hasOwnProperty("notificationConfig")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.NotificationConfig.verify(message.notificationConfig);
                                if (error)
                                    return "notificationConfig." + error;
                            }
                            if (message.humanAgentSuggestionConfig != null && message.hasOwnProperty("humanAgentSuggestionConfig")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionConfig.verify(message.humanAgentSuggestionConfig);
                                if (error)
                                    return "humanAgentSuggestionConfig." + error;
                            }
                            if (message.endUserSuggestionConfig != null && message.hasOwnProperty("endUserSuggestionConfig")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionConfig.verify(message.endUserSuggestionConfig);
                                if (error)
                                    return "endUserSuggestionConfig." + error;
                            }
                            if (message.messageAnalysisConfig != null && message.hasOwnProperty("messageAnalysisConfig")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.MessageAnalysisConfig.verify(message.messageAnalysisConfig);
                                if (error)
                                    return "messageAnalysisConfig." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a HumanAgentAssistantConfig message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig} HumanAgentAssistantConfig
                         */
                        HumanAgentAssistantConfig.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig();
                            if (object.notificationConfig != null) {
                                if (typeof object.notificationConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.notificationConfig: object expected");
                                message.notificationConfig = $root.google.cloud.dialogflow.v2beta1.NotificationConfig.fromObject(object.notificationConfig);
                            }
                            if (object.humanAgentSuggestionConfig != null) {
                                if (typeof object.humanAgentSuggestionConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.humanAgentSuggestionConfig: object expected");
                                message.humanAgentSuggestionConfig = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionConfig.fromObject(object.humanAgentSuggestionConfig);
                            }
                            if (object.endUserSuggestionConfig != null) {
                                if (typeof object.endUserSuggestionConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.endUserSuggestionConfig: object expected");
                                message.endUserSuggestionConfig = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionConfig.fromObject(object.endUserSuggestionConfig);
                            }
                            if (object.messageAnalysisConfig != null) {
                                if (typeof object.messageAnalysisConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.messageAnalysisConfig: object expected");
                                message.messageAnalysisConfig = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.MessageAnalysisConfig.fromObject(object.messageAnalysisConfig);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a HumanAgentAssistantConfig message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig} message HumanAgentAssistantConfig
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        HumanAgentAssistantConfig.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.notificationConfig = null;
                                object.humanAgentSuggestionConfig = null;
                                object.endUserSuggestionConfig = null;
                                object.messageAnalysisConfig = null;
                            }
                            if (message.notificationConfig != null && message.hasOwnProperty("notificationConfig"))
                                object.notificationConfig = $root.google.cloud.dialogflow.v2beta1.NotificationConfig.toObject(message.notificationConfig, options);
                            if (message.humanAgentSuggestionConfig != null && message.hasOwnProperty("humanAgentSuggestionConfig"))
                                object.humanAgentSuggestionConfig = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionConfig.toObject(message.humanAgentSuggestionConfig, options);
                            if (message.endUserSuggestionConfig != null && message.hasOwnProperty("endUserSuggestionConfig"))
                                object.endUserSuggestionConfig = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionConfig.toObject(message.endUserSuggestionConfig, options);
                            if (message.messageAnalysisConfig != null && message.hasOwnProperty("messageAnalysisConfig"))
                                object.messageAnalysisConfig = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.MessageAnalysisConfig.toObject(message.messageAnalysisConfig, options);
                            return object;
                        };
    
                        /**
                         * Converts this HumanAgentAssistantConfig to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        HumanAgentAssistantConfig.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for HumanAgentAssistantConfig
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        HumanAgentAssistantConfig.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig";
                        };
    
                        HumanAgentAssistantConfig.SuggestionTriggerSettings = (function() {
    
                            /**
                             * Properties of a SuggestionTriggerSettings.
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig
                             * @interface ISuggestionTriggerSettings
                             * @property {boolean|null} [noSmallTalk] SuggestionTriggerSettings noSmallTalk
                             * @property {boolean|null} [onlyEndUser] SuggestionTriggerSettings onlyEndUser
                             */
    
                            /**
                             * Constructs a new SuggestionTriggerSettings.
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig
                             * @classdesc Represents a SuggestionTriggerSettings.
                             * @implements ISuggestionTriggerSettings
                             * @constructor
                             * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ISuggestionTriggerSettings=} [properties] Properties to set
                             */
                            function SuggestionTriggerSettings(properties) {
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * SuggestionTriggerSettings noSmallTalk.
                             * @member {boolean} noSmallTalk
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionTriggerSettings
                             * @instance
                             */
                            SuggestionTriggerSettings.prototype.noSmallTalk = false;
    
                            /**
                             * SuggestionTriggerSettings onlyEndUser.
                             * @member {boolean} onlyEndUser
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionTriggerSettings
                             * @instance
                             */
                            SuggestionTriggerSettings.prototype.onlyEndUser = false;
    
                            /**
                             * Creates a new SuggestionTriggerSettings instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionTriggerSettings
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ISuggestionTriggerSettings=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionTriggerSettings} SuggestionTriggerSettings instance
                             */
                            SuggestionTriggerSettings.create = function create(properties) {
                                return new SuggestionTriggerSettings(properties);
                            };
    
                            /**
                             * Encodes the specified SuggestionTriggerSettings message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionTriggerSettings.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionTriggerSettings
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ISuggestionTriggerSettings} message SuggestionTriggerSettings message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            SuggestionTriggerSettings.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.noSmallTalk != null && Object.hasOwnProperty.call(message, "noSmallTalk"))
                                    writer.uint32(/* id 1, wireType 0 =*/8).bool(message.noSmallTalk);
                                if (message.onlyEndUser != null && Object.hasOwnProperty.call(message, "onlyEndUser"))
                                    writer.uint32(/* id 2, wireType 0 =*/16).bool(message.onlyEndUser);
                                return writer;
                            };
    
                            /**
                             * Encodes the specified SuggestionTriggerSettings message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionTriggerSettings.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionTriggerSettings
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ISuggestionTriggerSettings} message SuggestionTriggerSettings message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            SuggestionTriggerSettings.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a SuggestionTriggerSettings message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionTriggerSettings
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionTriggerSettings} SuggestionTriggerSettings
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            SuggestionTriggerSettings.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionTriggerSettings();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.noSmallTalk = reader.bool();
                                            break;
                                        }
                                    case 2: {
                                            message.onlyEndUser = reader.bool();
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a SuggestionTriggerSettings message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionTriggerSettings
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionTriggerSettings} SuggestionTriggerSettings
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            SuggestionTriggerSettings.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a SuggestionTriggerSettings message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionTriggerSettings
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            SuggestionTriggerSettings.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.noSmallTalk != null && message.hasOwnProperty("noSmallTalk"))
                                    if (typeof message.noSmallTalk !== "boolean")
                                        return "noSmallTalk: boolean expected";
                                if (message.onlyEndUser != null && message.hasOwnProperty("onlyEndUser"))
                                    if (typeof message.onlyEndUser !== "boolean")
                                        return "onlyEndUser: boolean expected";
                                return null;
                            };
    
                            /**
                             * Creates a SuggestionTriggerSettings message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionTriggerSettings
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionTriggerSettings} SuggestionTriggerSettings
                             */
                            SuggestionTriggerSettings.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionTriggerSettings)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionTriggerSettings();
                                if (object.noSmallTalk != null)
                                    message.noSmallTalk = Boolean(object.noSmallTalk);
                                if (object.onlyEndUser != null)
                                    message.onlyEndUser = Boolean(object.onlyEndUser);
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a SuggestionTriggerSettings message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionTriggerSettings
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionTriggerSettings} message SuggestionTriggerSettings
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            SuggestionTriggerSettings.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.defaults) {
                                    object.noSmallTalk = false;
                                    object.onlyEndUser = false;
                                }
                                if (message.noSmallTalk != null && message.hasOwnProperty("noSmallTalk"))
                                    object.noSmallTalk = message.noSmallTalk;
                                if (message.onlyEndUser != null && message.hasOwnProperty("onlyEndUser"))
                                    object.onlyEndUser = message.onlyEndUser;
                                return object;
                            };
    
                            /**
                             * Converts this SuggestionTriggerSettings to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionTriggerSettings
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            SuggestionTriggerSettings.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for SuggestionTriggerSettings
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionTriggerSettings
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            SuggestionTriggerSettings.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionTriggerSettings";
                            };
    
                            return SuggestionTriggerSettings;
                        })();
    
                        HumanAgentAssistantConfig.SuggestionFeatureConfig = (function() {
    
                            /**
                             * Properties of a SuggestionFeatureConfig.
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig
                             * @interface ISuggestionFeatureConfig
                             * @property {google.cloud.dialogflow.v2beta1.ISuggestionFeature|null} [suggestionFeature] SuggestionFeatureConfig suggestionFeature
                             * @property {boolean|null} [enableEventBasedSuggestion] SuggestionFeatureConfig enableEventBasedSuggestion
                             * @property {boolean|null} [disableAgentQueryLogging] SuggestionFeatureConfig disableAgentQueryLogging
                             * @property {boolean|null} [enableQuerySuggestionWhenNoAnswer] SuggestionFeatureConfig enableQuerySuggestionWhenNoAnswer
                             * @property {boolean|null} [enableConversationAugmentedQuery] SuggestionFeatureConfig enableConversationAugmentedQuery
                             * @property {boolean|null} [enableQuerySuggestionOnly] SuggestionFeatureConfig enableQuerySuggestionOnly
                             * @property {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ISuggestionTriggerSettings|null} [suggestionTriggerSettings] SuggestionFeatureConfig suggestionTriggerSettings
                             * @property {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ISuggestionQueryConfig|null} [queryConfig] SuggestionFeatureConfig queryConfig
                             * @property {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.IConversationModelConfig|null} [conversationModelConfig] SuggestionFeatureConfig conversationModelConfig
                             * @property {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.IConversationProcessConfig|null} [conversationProcessConfig] SuggestionFeatureConfig conversationProcessConfig
                             */
    
                            /**
                             * Constructs a new SuggestionFeatureConfig.
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig
                             * @classdesc Represents a SuggestionFeatureConfig.
                             * @implements ISuggestionFeatureConfig
                             * @constructor
                             * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ISuggestionFeatureConfig=} [properties] Properties to set
                             */
                            function SuggestionFeatureConfig(properties) {
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * SuggestionFeatureConfig suggestionFeature.
                             * @member {google.cloud.dialogflow.v2beta1.ISuggestionFeature|null|undefined} suggestionFeature
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionFeatureConfig
                             * @instance
                             */
                            SuggestionFeatureConfig.prototype.suggestionFeature = null;
    
                            /**
                             * SuggestionFeatureConfig enableEventBasedSuggestion.
                             * @member {boolean} enableEventBasedSuggestion
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionFeatureConfig
                             * @instance
                             */
                            SuggestionFeatureConfig.prototype.enableEventBasedSuggestion = false;
    
                            /**
                             * SuggestionFeatureConfig disableAgentQueryLogging.
                             * @member {boolean} disableAgentQueryLogging
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionFeatureConfig
                             * @instance
                             */
                            SuggestionFeatureConfig.prototype.disableAgentQueryLogging = false;
    
                            /**
                             * SuggestionFeatureConfig enableQuerySuggestionWhenNoAnswer.
                             * @member {boolean} enableQuerySuggestionWhenNoAnswer
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionFeatureConfig
                             * @instance
                             */
                            SuggestionFeatureConfig.prototype.enableQuerySuggestionWhenNoAnswer = false;
    
                            /**
                             * SuggestionFeatureConfig enableConversationAugmentedQuery.
                             * @member {boolean} enableConversationAugmentedQuery
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionFeatureConfig
                             * @instance
                             */
                            SuggestionFeatureConfig.prototype.enableConversationAugmentedQuery = false;
    
                            /**
                             * SuggestionFeatureConfig enableQuerySuggestionOnly.
                             * @member {boolean} enableQuerySuggestionOnly
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionFeatureConfig
                             * @instance
                             */
                            SuggestionFeatureConfig.prototype.enableQuerySuggestionOnly = false;
    
                            /**
                             * SuggestionFeatureConfig suggestionTriggerSettings.
                             * @member {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ISuggestionTriggerSettings|null|undefined} suggestionTriggerSettings
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionFeatureConfig
                             * @instance
                             */
                            SuggestionFeatureConfig.prototype.suggestionTriggerSettings = null;
    
                            /**
                             * SuggestionFeatureConfig queryConfig.
                             * @member {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ISuggestionQueryConfig|null|undefined} queryConfig
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionFeatureConfig
                             * @instance
                             */
                            SuggestionFeatureConfig.prototype.queryConfig = null;
    
                            /**
                             * SuggestionFeatureConfig conversationModelConfig.
                             * @member {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.IConversationModelConfig|null|undefined} conversationModelConfig
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionFeatureConfig
                             * @instance
                             */
                            SuggestionFeatureConfig.prototype.conversationModelConfig = null;
    
                            /**
                             * SuggestionFeatureConfig conversationProcessConfig.
                             * @member {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.IConversationProcessConfig|null|undefined} conversationProcessConfig
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionFeatureConfig
                             * @instance
                             */
                            SuggestionFeatureConfig.prototype.conversationProcessConfig = null;
    
                            /**
                             * Creates a new SuggestionFeatureConfig instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionFeatureConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ISuggestionFeatureConfig=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionFeatureConfig} SuggestionFeatureConfig instance
                             */
                            SuggestionFeatureConfig.create = function create(properties) {
                                return new SuggestionFeatureConfig(properties);
                            };
    
                            /**
                             * Encodes the specified SuggestionFeatureConfig message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionFeatureConfig.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionFeatureConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ISuggestionFeatureConfig} message SuggestionFeatureConfig message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            SuggestionFeatureConfig.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.enableEventBasedSuggestion != null && Object.hasOwnProperty.call(message, "enableEventBasedSuggestion"))
                                    writer.uint32(/* id 3, wireType 0 =*/24).bool(message.enableEventBasedSuggestion);
                                if (message.suggestionFeature != null && Object.hasOwnProperty.call(message, "suggestionFeature"))
                                    $root.google.cloud.dialogflow.v2beta1.SuggestionFeature.encode(message.suggestionFeature, writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                                if (message.queryConfig != null && Object.hasOwnProperty.call(message, "queryConfig"))
                                    $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.encode(message.queryConfig, writer.uint32(/* id 6, wireType 2 =*/50).fork()).ldelim();
                                if (message.conversationModelConfig != null && Object.hasOwnProperty.call(message, "conversationModelConfig"))
                                    $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ConversationModelConfig.encode(message.conversationModelConfig, writer.uint32(/* id 7, wireType 2 =*/58).fork()).ldelim();
                                if (message.conversationProcessConfig != null && Object.hasOwnProperty.call(message, "conversationProcessConfig"))
                                    $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ConversationProcessConfig.encode(message.conversationProcessConfig, writer.uint32(/* id 8, wireType 2 =*/66).fork()).ldelim();
                                if (message.suggestionTriggerSettings != null && Object.hasOwnProperty.call(message, "suggestionTriggerSettings"))
                                    $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionTriggerSettings.encode(message.suggestionTriggerSettings, writer.uint32(/* id 10, wireType 2 =*/82).fork()).ldelim();
                                if (message.disableAgentQueryLogging != null && Object.hasOwnProperty.call(message, "disableAgentQueryLogging"))
                                    writer.uint32(/* id 14, wireType 0 =*/112).bool(message.disableAgentQueryLogging);
                                if (message.enableQuerySuggestionWhenNoAnswer != null && Object.hasOwnProperty.call(message, "enableQuerySuggestionWhenNoAnswer"))
                                    writer.uint32(/* id 15, wireType 0 =*/120).bool(message.enableQuerySuggestionWhenNoAnswer);
                                if (message.enableConversationAugmentedQuery != null && Object.hasOwnProperty.call(message, "enableConversationAugmentedQuery"))
                                    writer.uint32(/* id 16, wireType 0 =*/128).bool(message.enableConversationAugmentedQuery);
                                if (message.enableQuerySuggestionOnly != null && Object.hasOwnProperty.call(message, "enableQuerySuggestionOnly"))
                                    writer.uint32(/* id 17, wireType 0 =*/136).bool(message.enableQuerySuggestionOnly);
                                return writer;
                            };
    
                            /**
                             * Encodes the specified SuggestionFeatureConfig message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionFeatureConfig.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionFeatureConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ISuggestionFeatureConfig} message SuggestionFeatureConfig message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            SuggestionFeatureConfig.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a SuggestionFeatureConfig message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionFeatureConfig
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionFeatureConfig} SuggestionFeatureConfig
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            SuggestionFeatureConfig.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionFeatureConfig();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 5: {
                                            message.suggestionFeature = $root.google.cloud.dialogflow.v2beta1.SuggestionFeature.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 3: {
                                            message.enableEventBasedSuggestion = reader.bool();
                                            break;
                                        }
                                    case 14: {
                                            message.disableAgentQueryLogging = reader.bool();
                                            break;
                                        }
                                    case 15: {
                                            message.enableQuerySuggestionWhenNoAnswer = reader.bool();
                                            break;
                                        }
                                    case 16: {
                                            message.enableConversationAugmentedQuery = reader.bool();
                                            break;
                                        }
                                    case 17: {
                                            message.enableQuerySuggestionOnly = reader.bool();
                                            break;
                                        }
                                    case 10: {
                                            message.suggestionTriggerSettings = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionTriggerSettings.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 6: {
                                            message.queryConfig = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 7: {
                                            message.conversationModelConfig = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ConversationModelConfig.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 8: {
                                            message.conversationProcessConfig = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ConversationProcessConfig.decode(reader, reader.uint32());
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a SuggestionFeatureConfig message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionFeatureConfig
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionFeatureConfig} SuggestionFeatureConfig
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            SuggestionFeatureConfig.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a SuggestionFeatureConfig message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionFeatureConfig
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            SuggestionFeatureConfig.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.suggestionFeature != null && message.hasOwnProperty("suggestionFeature")) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.SuggestionFeature.verify(message.suggestionFeature);
                                    if (error)
                                        return "suggestionFeature." + error;
                                }
                                if (message.enableEventBasedSuggestion != null && message.hasOwnProperty("enableEventBasedSuggestion"))
                                    if (typeof message.enableEventBasedSuggestion !== "boolean")
                                        return "enableEventBasedSuggestion: boolean expected";
                                if (message.disableAgentQueryLogging != null && message.hasOwnProperty("disableAgentQueryLogging"))
                                    if (typeof message.disableAgentQueryLogging !== "boolean")
                                        return "disableAgentQueryLogging: boolean expected";
                                if (message.enableQuerySuggestionWhenNoAnswer != null && message.hasOwnProperty("enableQuerySuggestionWhenNoAnswer"))
                                    if (typeof message.enableQuerySuggestionWhenNoAnswer !== "boolean")
                                        return "enableQuerySuggestionWhenNoAnswer: boolean expected";
                                if (message.enableConversationAugmentedQuery != null && message.hasOwnProperty("enableConversationAugmentedQuery"))
                                    if (typeof message.enableConversationAugmentedQuery !== "boolean")
                                        return "enableConversationAugmentedQuery: boolean expected";
                                if (message.enableQuerySuggestionOnly != null && message.hasOwnProperty("enableQuerySuggestionOnly"))
                                    if (typeof message.enableQuerySuggestionOnly !== "boolean")
                                        return "enableQuerySuggestionOnly: boolean expected";
                                if (message.suggestionTriggerSettings != null && message.hasOwnProperty("suggestionTriggerSettings")) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionTriggerSettings.verify(message.suggestionTriggerSettings);
                                    if (error)
                                        return "suggestionTriggerSettings." + error;
                                }
                                if (message.queryConfig != null && message.hasOwnProperty("queryConfig")) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.verify(message.queryConfig);
                                    if (error)
                                        return "queryConfig." + error;
                                }
                                if (message.conversationModelConfig != null && message.hasOwnProperty("conversationModelConfig")) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ConversationModelConfig.verify(message.conversationModelConfig);
                                    if (error)
                                        return "conversationModelConfig." + error;
                                }
                                if (message.conversationProcessConfig != null && message.hasOwnProperty("conversationProcessConfig")) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ConversationProcessConfig.verify(message.conversationProcessConfig);
                                    if (error)
                                        return "conversationProcessConfig." + error;
                                }
                                return null;
                            };
    
                            /**
                             * Creates a SuggestionFeatureConfig message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionFeatureConfig
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionFeatureConfig} SuggestionFeatureConfig
                             */
                            SuggestionFeatureConfig.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionFeatureConfig)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionFeatureConfig();
                                if (object.suggestionFeature != null) {
                                    if (typeof object.suggestionFeature !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionFeatureConfig.suggestionFeature: object expected");
                                    message.suggestionFeature = $root.google.cloud.dialogflow.v2beta1.SuggestionFeature.fromObject(object.suggestionFeature);
                                }
                                if (object.enableEventBasedSuggestion != null)
                                    message.enableEventBasedSuggestion = Boolean(object.enableEventBasedSuggestion);
                                if (object.disableAgentQueryLogging != null)
                                    message.disableAgentQueryLogging = Boolean(object.disableAgentQueryLogging);
                                if (object.enableQuerySuggestionWhenNoAnswer != null)
                                    message.enableQuerySuggestionWhenNoAnswer = Boolean(object.enableQuerySuggestionWhenNoAnswer);
                                if (object.enableConversationAugmentedQuery != null)
                                    message.enableConversationAugmentedQuery = Boolean(object.enableConversationAugmentedQuery);
                                if (object.enableQuerySuggestionOnly != null)
                                    message.enableQuerySuggestionOnly = Boolean(object.enableQuerySuggestionOnly);
                                if (object.suggestionTriggerSettings != null) {
                                    if (typeof object.suggestionTriggerSettings !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionFeatureConfig.suggestionTriggerSettings: object expected");
                                    message.suggestionTriggerSettings = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionTriggerSettings.fromObject(object.suggestionTriggerSettings);
                                }
                                if (object.queryConfig != null) {
                                    if (typeof object.queryConfig !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionFeatureConfig.queryConfig: object expected");
                                    message.queryConfig = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.fromObject(object.queryConfig);
                                }
                                if (object.conversationModelConfig != null) {
                                    if (typeof object.conversationModelConfig !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionFeatureConfig.conversationModelConfig: object expected");
                                    message.conversationModelConfig = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ConversationModelConfig.fromObject(object.conversationModelConfig);
                                }
                                if (object.conversationProcessConfig != null) {
                                    if (typeof object.conversationProcessConfig !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionFeatureConfig.conversationProcessConfig: object expected");
                                    message.conversationProcessConfig = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ConversationProcessConfig.fromObject(object.conversationProcessConfig);
                                }
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a SuggestionFeatureConfig message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionFeatureConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionFeatureConfig} message SuggestionFeatureConfig
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            SuggestionFeatureConfig.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.defaults) {
                                    object.enableEventBasedSuggestion = false;
                                    object.suggestionFeature = null;
                                    object.queryConfig = null;
                                    object.conversationModelConfig = null;
                                    object.conversationProcessConfig = null;
                                    object.suggestionTriggerSettings = null;
                                    object.disableAgentQueryLogging = false;
                                    object.enableQuerySuggestionWhenNoAnswer = false;
                                    object.enableConversationAugmentedQuery = false;
                                    object.enableQuerySuggestionOnly = false;
                                }
                                if (message.enableEventBasedSuggestion != null && message.hasOwnProperty("enableEventBasedSuggestion"))
                                    object.enableEventBasedSuggestion = message.enableEventBasedSuggestion;
                                if (message.suggestionFeature != null && message.hasOwnProperty("suggestionFeature"))
                                    object.suggestionFeature = $root.google.cloud.dialogflow.v2beta1.SuggestionFeature.toObject(message.suggestionFeature, options);
                                if (message.queryConfig != null && message.hasOwnProperty("queryConfig"))
                                    object.queryConfig = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.toObject(message.queryConfig, options);
                                if (message.conversationModelConfig != null && message.hasOwnProperty("conversationModelConfig"))
                                    object.conversationModelConfig = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ConversationModelConfig.toObject(message.conversationModelConfig, options);
                                if (message.conversationProcessConfig != null && message.hasOwnProperty("conversationProcessConfig"))
                                    object.conversationProcessConfig = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ConversationProcessConfig.toObject(message.conversationProcessConfig, options);
                                if (message.suggestionTriggerSettings != null && message.hasOwnProperty("suggestionTriggerSettings"))
                                    object.suggestionTriggerSettings = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionTriggerSettings.toObject(message.suggestionTriggerSettings, options);
                                if (message.disableAgentQueryLogging != null && message.hasOwnProperty("disableAgentQueryLogging"))
                                    object.disableAgentQueryLogging = message.disableAgentQueryLogging;
                                if (message.enableQuerySuggestionWhenNoAnswer != null && message.hasOwnProperty("enableQuerySuggestionWhenNoAnswer"))
                                    object.enableQuerySuggestionWhenNoAnswer = message.enableQuerySuggestionWhenNoAnswer;
                                if (message.enableConversationAugmentedQuery != null && message.hasOwnProperty("enableConversationAugmentedQuery"))
                                    object.enableConversationAugmentedQuery = message.enableConversationAugmentedQuery;
                                if (message.enableQuerySuggestionOnly != null && message.hasOwnProperty("enableQuerySuggestionOnly"))
                                    object.enableQuerySuggestionOnly = message.enableQuerySuggestionOnly;
                                return object;
                            };
    
                            /**
                             * Converts this SuggestionFeatureConfig to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionFeatureConfig
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            SuggestionFeatureConfig.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for SuggestionFeatureConfig
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionFeatureConfig
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            SuggestionFeatureConfig.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionFeatureConfig";
                            };
    
                            return SuggestionFeatureConfig;
                        })();
    
                        HumanAgentAssistantConfig.SuggestionConfig = (function() {
    
                            /**
                             * Properties of a SuggestionConfig.
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig
                             * @interface ISuggestionConfig
                             * @property {Array.<google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ISuggestionFeatureConfig>|null} [featureConfigs] SuggestionConfig featureConfigs
                             * @property {boolean|null} [groupSuggestionResponses] SuggestionConfig groupSuggestionResponses
                             * @property {Array.<string>|null} [generators] SuggestionConfig generators
                             * @property {boolean|null} [disableHighLatencyFeaturesSyncDelivery] SuggestionConfig disableHighLatencyFeaturesSyncDelivery
                             */
    
                            /**
                             * Constructs a new SuggestionConfig.
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig
                             * @classdesc Represents a SuggestionConfig.
                             * @implements ISuggestionConfig
                             * @constructor
                             * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ISuggestionConfig=} [properties] Properties to set
                             */
                            function SuggestionConfig(properties) {
                                this.featureConfigs = [];
                                this.generators = [];
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * SuggestionConfig featureConfigs.
                             * @member {Array.<google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ISuggestionFeatureConfig>} featureConfigs
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionConfig
                             * @instance
                             */
                            SuggestionConfig.prototype.featureConfigs = $util.emptyArray;
    
                            /**
                             * SuggestionConfig groupSuggestionResponses.
                             * @member {boolean} groupSuggestionResponses
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionConfig
                             * @instance
                             */
                            SuggestionConfig.prototype.groupSuggestionResponses = false;
    
                            /**
                             * SuggestionConfig generators.
                             * @member {Array.<string>} generators
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionConfig
                             * @instance
                             */
                            SuggestionConfig.prototype.generators = $util.emptyArray;
    
                            /**
                             * SuggestionConfig disableHighLatencyFeaturesSyncDelivery.
                             * @member {boolean} disableHighLatencyFeaturesSyncDelivery
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionConfig
                             * @instance
                             */
                            SuggestionConfig.prototype.disableHighLatencyFeaturesSyncDelivery = false;
    
                            /**
                             * Creates a new SuggestionConfig instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ISuggestionConfig=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionConfig} SuggestionConfig instance
                             */
                            SuggestionConfig.create = function create(properties) {
                                return new SuggestionConfig(properties);
                            };
    
                            /**
                             * Encodes the specified SuggestionConfig message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionConfig.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ISuggestionConfig} message SuggestionConfig message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            SuggestionConfig.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.featureConfigs != null && message.featureConfigs.length)
                                    for (var i = 0; i < message.featureConfigs.length; ++i)
                                        $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionFeatureConfig.encode(message.featureConfigs[i], writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                                if (message.groupSuggestionResponses != null && Object.hasOwnProperty.call(message, "groupSuggestionResponses"))
                                    writer.uint32(/* id 3, wireType 0 =*/24).bool(message.groupSuggestionResponses);
                                if (message.generators != null && message.generators.length)
                                    for (var i = 0; i < message.generators.length; ++i)
                                        writer.uint32(/* id 4, wireType 2 =*/34).string(message.generators[i]);
                                if (message.disableHighLatencyFeaturesSyncDelivery != null && Object.hasOwnProperty.call(message, "disableHighLatencyFeaturesSyncDelivery"))
                                    writer.uint32(/* id 5, wireType 0 =*/40).bool(message.disableHighLatencyFeaturesSyncDelivery);
                                return writer;
                            };
    
                            /**
                             * Encodes the specified SuggestionConfig message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionConfig.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ISuggestionConfig} message SuggestionConfig message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            SuggestionConfig.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a SuggestionConfig message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionConfig
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionConfig} SuggestionConfig
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            SuggestionConfig.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionConfig();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 2: {
                                            if (!(message.featureConfigs && message.featureConfigs.length))
                                                message.featureConfigs = [];
                                            message.featureConfigs.push($root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionFeatureConfig.decode(reader, reader.uint32()));
                                            break;
                                        }
                                    case 3: {
                                            message.groupSuggestionResponses = reader.bool();
                                            break;
                                        }
                                    case 4: {
                                            if (!(message.generators && message.generators.length))
                                                message.generators = [];
                                            message.generators.push(reader.string());
                                            break;
                                        }
                                    case 5: {
                                            message.disableHighLatencyFeaturesSyncDelivery = reader.bool();
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a SuggestionConfig message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionConfig
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionConfig} SuggestionConfig
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            SuggestionConfig.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a SuggestionConfig message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionConfig
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            SuggestionConfig.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.featureConfigs != null && message.hasOwnProperty("featureConfigs")) {
                                    if (!Array.isArray(message.featureConfigs))
                                        return "featureConfigs: array expected";
                                    for (var i = 0; i < message.featureConfigs.length; ++i) {
                                        var error = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionFeatureConfig.verify(message.featureConfigs[i]);
                                        if (error)
                                            return "featureConfigs." + error;
                                    }
                                }
                                if (message.groupSuggestionResponses != null && message.hasOwnProperty("groupSuggestionResponses"))
                                    if (typeof message.groupSuggestionResponses !== "boolean")
                                        return "groupSuggestionResponses: boolean expected";
                                if (message.generators != null && message.hasOwnProperty("generators")) {
                                    if (!Array.isArray(message.generators))
                                        return "generators: array expected";
                                    for (var i = 0; i < message.generators.length; ++i)
                                        if (!$util.isString(message.generators[i]))
                                            return "generators: string[] expected";
                                }
                                if (message.disableHighLatencyFeaturesSyncDelivery != null && message.hasOwnProperty("disableHighLatencyFeaturesSyncDelivery"))
                                    if (typeof message.disableHighLatencyFeaturesSyncDelivery !== "boolean")
                                        return "disableHighLatencyFeaturesSyncDelivery: boolean expected";
                                return null;
                            };
    
                            /**
                             * Creates a SuggestionConfig message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionConfig
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionConfig} SuggestionConfig
                             */
                            SuggestionConfig.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionConfig)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionConfig();
                                if (object.featureConfigs) {
                                    if (!Array.isArray(object.featureConfigs))
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionConfig.featureConfigs: array expected");
                                    message.featureConfigs = [];
                                    for (var i = 0; i < object.featureConfigs.length; ++i) {
                                        if (typeof object.featureConfigs[i] !== "object")
                                            throw TypeError(".google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionConfig.featureConfigs: object expected");
                                        message.featureConfigs[i] = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionFeatureConfig.fromObject(object.featureConfigs[i]);
                                    }
                                }
                                if (object.groupSuggestionResponses != null)
                                    message.groupSuggestionResponses = Boolean(object.groupSuggestionResponses);
                                if (object.generators) {
                                    if (!Array.isArray(object.generators))
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionConfig.generators: array expected");
                                    message.generators = [];
                                    for (var i = 0; i < object.generators.length; ++i)
                                        message.generators[i] = String(object.generators[i]);
                                }
                                if (object.disableHighLatencyFeaturesSyncDelivery != null)
                                    message.disableHighLatencyFeaturesSyncDelivery = Boolean(object.disableHighLatencyFeaturesSyncDelivery);
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a SuggestionConfig message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionConfig} message SuggestionConfig
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            SuggestionConfig.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.arrays || options.defaults) {
                                    object.featureConfigs = [];
                                    object.generators = [];
                                }
                                if (options.defaults) {
                                    object.groupSuggestionResponses = false;
                                    object.disableHighLatencyFeaturesSyncDelivery = false;
                                }
                                if (message.featureConfigs && message.featureConfigs.length) {
                                    object.featureConfigs = [];
                                    for (var j = 0; j < message.featureConfigs.length; ++j)
                                        object.featureConfigs[j] = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionFeatureConfig.toObject(message.featureConfigs[j], options);
                                }
                                if (message.groupSuggestionResponses != null && message.hasOwnProperty("groupSuggestionResponses"))
                                    object.groupSuggestionResponses = message.groupSuggestionResponses;
                                if (message.generators && message.generators.length) {
                                    object.generators = [];
                                    for (var j = 0; j < message.generators.length; ++j)
                                        object.generators[j] = message.generators[j];
                                }
                                if (message.disableHighLatencyFeaturesSyncDelivery != null && message.hasOwnProperty("disableHighLatencyFeaturesSyncDelivery"))
                                    object.disableHighLatencyFeaturesSyncDelivery = message.disableHighLatencyFeaturesSyncDelivery;
                                return object;
                            };
    
                            /**
                             * Converts this SuggestionConfig to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionConfig
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            SuggestionConfig.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for SuggestionConfig
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionConfig
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            SuggestionConfig.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionConfig";
                            };
    
                            return SuggestionConfig;
                        })();
    
                        HumanAgentAssistantConfig.SuggestionQueryConfig = (function() {
    
                            /**
                             * Properties of a SuggestionQueryConfig.
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig
                             * @interface ISuggestionQueryConfig
                             * @property {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.IKnowledgeBaseQuerySource|null} [knowledgeBaseQuerySource] SuggestionQueryConfig knowledgeBaseQuerySource
                             * @property {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.IDocumentQuerySource|null} [documentQuerySource] SuggestionQueryConfig documentQuerySource
                             * @property {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.IDialogflowQuerySource|null} [dialogflowQuerySource] SuggestionQueryConfig dialogflowQuerySource
                             * @property {number|null} [maxResults] SuggestionQueryConfig maxResults
                             * @property {number|null} [confidenceThreshold] SuggestionQueryConfig confidenceThreshold
                             * @property {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.IContextFilterSettings|null} [contextFilterSettings] SuggestionQueryConfig contextFilterSettings
                             * @property {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.ISections|null} [sections] SuggestionQueryConfig sections
                             * @property {number|null} [contextSize] SuggestionQueryConfig contextSize
                             */
    
                            /**
                             * Constructs a new SuggestionQueryConfig.
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig
                             * @classdesc Represents a SuggestionQueryConfig.
                             * @implements ISuggestionQueryConfig
                             * @constructor
                             * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ISuggestionQueryConfig=} [properties] Properties to set
                             */
                            function SuggestionQueryConfig(properties) {
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * SuggestionQueryConfig knowledgeBaseQuerySource.
                             * @member {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.IKnowledgeBaseQuerySource|null|undefined} knowledgeBaseQuerySource
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig
                             * @instance
                             */
                            SuggestionQueryConfig.prototype.knowledgeBaseQuerySource = null;
    
                            /**
                             * SuggestionQueryConfig documentQuerySource.
                             * @member {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.IDocumentQuerySource|null|undefined} documentQuerySource
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig
                             * @instance
                             */
                            SuggestionQueryConfig.prototype.documentQuerySource = null;
    
                            /**
                             * SuggestionQueryConfig dialogflowQuerySource.
                             * @member {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.IDialogflowQuerySource|null|undefined} dialogflowQuerySource
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig
                             * @instance
                             */
                            SuggestionQueryConfig.prototype.dialogflowQuerySource = null;
    
                            /**
                             * SuggestionQueryConfig maxResults.
                             * @member {number} maxResults
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig
                             * @instance
                             */
                            SuggestionQueryConfig.prototype.maxResults = 0;
    
                            /**
                             * SuggestionQueryConfig confidenceThreshold.
                             * @member {number} confidenceThreshold
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig
                             * @instance
                             */
                            SuggestionQueryConfig.prototype.confidenceThreshold = 0;
    
                            /**
                             * SuggestionQueryConfig contextFilterSettings.
                             * @member {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.IContextFilterSettings|null|undefined} contextFilterSettings
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig
                             * @instance
                             */
                            SuggestionQueryConfig.prototype.contextFilterSettings = null;
    
                            /**
                             * SuggestionQueryConfig sections.
                             * @member {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.ISections|null|undefined} sections
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig
                             * @instance
                             */
                            SuggestionQueryConfig.prototype.sections = null;
    
                            /**
                             * SuggestionQueryConfig contextSize.
                             * @member {number} contextSize
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig
                             * @instance
                             */
                            SuggestionQueryConfig.prototype.contextSize = 0;
    
                            // OneOf field names bound to virtual getters and setters
                            var $oneOfFields;
    
                            /**
                             * SuggestionQueryConfig querySource.
                             * @member {"knowledgeBaseQuerySource"|"documentQuerySource"|"dialogflowQuerySource"|undefined} querySource
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig
                             * @instance
                             */
                            Object.defineProperty(SuggestionQueryConfig.prototype, "querySource", {
                                get: $util.oneOfGetter($oneOfFields = ["knowledgeBaseQuerySource", "documentQuerySource", "dialogflowQuerySource"]),
                                set: $util.oneOfSetter($oneOfFields)
                            });
    
                            /**
                             * Creates a new SuggestionQueryConfig instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ISuggestionQueryConfig=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig} SuggestionQueryConfig instance
                             */
                            SuggestionQueryConfig.create = function create(properties) {
                                return new SuggestionQueryConfig(properties);
                            };
    
                            /**
                             * Encodes the specified SuggestionQueryConfig message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ISuggestionQueryConfig} message SuggestionQueryConfig message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            SuggestionQueryConfig.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.knowledgeBaseQuerySource != null && Object.hasOwnProperty.call(message, "knowledgeBaseQuerySource"))
                                    $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.KnowledgeBaseQuerySource.encode(message.knowledgeBaseQuerySource, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                                if (message.documentQuerySource != null && Object.hasOwnProperty.call(message, "documentQuerySource"))
                                    $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DocumentQuerySource.encode(message.documentQuerySource, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                                if (message.dialogflowQuerySource != null && Object.hasOwnProperty.call(message, "dialogflowQuerySource"))
                                    $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.encode(message.dialogflowQuerySource, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                                if (message.maxResults != null && Object.hasOwnProperty.call(message, "maxResults"))
                                    writer.uint32(/* id 4, wireType 0 =*/32).int32(message.maxResults);
                                if (message.confidenceThreshold != null && Object.hasOwnProperty.call(message, "confidenceThreshold"))
                                    writer.uint32(/* id 5, wireType 5 =*/45).float(message.confidenceThreshold);
                                if (message.contextFilterSettings != null && Object.hasOwnProperty.call(message, "contextFilterSettings"))
                                    $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings.encode(message.contextFilterSettings, writer.uint32(/* id 7, wireType 2 =*/58).fork()).ldelim();
                                if (message.sections != null && Object.hasOwnProperty.call(message, "sections"))
                                    $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections.encode(message.sections, writer.uint32(/* id 8, wireType 2 =*/66).fork()).ldelim();
                                if (message.contextSize != null && Object.hasOwnProperty.call(message, "contextSize"))
                                    writer.uint32(/* id 9, wireType 0 =*/72).int32(message.contextSize);
                                return writer;
                            };
    
                            /**
                             * Encodes the specified SuggestionQueryConfig message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ISuggestionQueryConfig} message SuggestionQueryConfig message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            SuggestionQueryConfig.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a SuggestionQueryConfig message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig} SuggestionQueryConfig
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            SuggestionQueryConfig.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.knowledgeBaseQuerySource = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.KnowledgeBaseQuerySource.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 2: {
                                            message.documentQuerySource = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DocumentQuerySource.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 3: {
                                            message.dialogflowQuerySource = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 4: {
                                            message.maxResults = reader.int32();
                                            break;
                                        }
                                    case 5: {
                                            message.confidenceThreshold = reader.float();
                                            break;
                                        }
                                    case 7: {
                                            message.contextFilterSettings = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 8: {
                                            message.sections = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 9: {
                                            message.contextSize = reader.int32();
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a SuggestionQueryConfig message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig} SuggestionQueryConfig
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            SuggestionQueryConfig.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a SuggestionQueryConfig message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            SuggestionQueryConfig.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                var properties = {};
                                if (message.knowledgeBaseQuerySource != null && message.hasOwnProperty("knowledgeBaseQuerySource")) {
                                    properties.querySource = 1;
                                    {
                                        var error = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.KnowledgeBaseQuerySource.verify(message.knowledgeBaseQuerySource);
                                        if (error)
                                            return "knowledgeBaseQuerySource." + error;
                                    }
                                }
                                if (message.documentQuerySource != null && message.hasOwnProperty("documentQuerySource")) {
                                    if (properties.querySource === 1)
                                        return "querySource: multiple values";
                                    properties.querySource = 1;
                                    {
                                        var error = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DocumentQuerySource.verify(message.documentQuerySource);
                                        if (error)
                                            return "documentQuerySource." + error;
                                    }
                                }
                                if (message.dialogflowQuerySource != null && message.hasOwnProperty("dialogflowQuerySource")) {
                                    if (properties.querySource === 1)
                                        return "querySource: multiple values";
                                    properties.querySource = 1;
                                    {
                                        var error = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.verify(message.dialogflowQuerySource);
                                        if (error)
                                            return "dialogflowQuerySource." + error;
                                    }
                                }
                                if (message.maxResults != null && message.hasOwnProperty("maxResults"))
                                    if (!$util.isInteger(message.maxResults))
                                        return "maxResults: integer expected";
                                if (message.confidenceThreshold != null && message.hasOwnProperty("confidenceThreshold"))
                                    if (typeof message.confidenceThreshold !== "number")
                                        return "confidenceThreshold: number expected";
                                if (message.contextFilterSettings != null && message.hasOwnProperty("contextFilterSettings")) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings.verify(message.contextFilterSettings);
                                    if (error)
                                        return "contextFilterSettings." + error;
                                }
                                if (message.sections != null && message.hasOwnProperty("sections")) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections.verify(message.sections);
                                    if (error)
                                        return "sections." + error;
                                }
                                if (message.contextSize != null && message.hasOwnProperty("contextSize"))
                                    if (!$util.isInteger(message.contextSize))
                                        return "contextSize: integer expected";
                                return null;
                            };
    
                            /**
                             * Creates a SuggestionQueryConfig message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig} SuggestionQueryConfig
                             */
                            SuggestionQueryConfig.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig();
                                if (object.knowledgeBaseQuerySource != null) {
                                    if (typeof object.knowledgeBaseQuerySource !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.knowledgeBaseQuerySource: object expected");
                                    message.knowledgeBaseQuerySource = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.KnowledgeBaseQuerySource.fromObject(object.knowledgeBaseQuerySource);
                                }
                                if (object.documentQuerySource != null) {
                                    if (typeof object.documentQuerySource !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.documentQuerySource: object expected");
                                    message.documentQuerySource = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DocumentQuerySource.fromObject(object.documentQuerySource);
                                }
                                if (object.dialogflowQuerySource != null) {
                                    if (typeof object.dialogflowQuerySource !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.dialogflowQuerySource: object expected");
                                    message.dialogflowQuerySource = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.fromObject(object.dialogflowQuerySource);
                                }
                                if (object.maxResults != null)
                                    message.maxResults = object.maxResults | 0;
                                if (object.confidenceThreshold != null)
                                    message.confidenceThreshold = Number(object.confidenceThreshold);
                                if (object.contextFilterSettings != null) {
                                    if (typeof object.contextFilterSettings !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.contextFilterSettings: object expected");
                                    message.contextFilterSettings = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings.fromObject(object.contextFilterSettings);
                                }
                                if (object.sections != null) {
                                    if (typeof object.sections !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.sections: object expected");
                                    message.sections = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections.fromObject(object.sections);
                                }
                                if (object.contextSize != null)
                                    message.contextSize = object.contextSize | 0;
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a SuggestionQueryConfig message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig} message SuggestionQueryConfig
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            SuggestionQueryConfig.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.defaults) {
                                    object.maxResults = 0;
                                    object.confidenceThreshold = 0;
                                    object.contextFilterSettings = null;
                                    object.sections = null;
                                    object.contextSize = 0;
                                }
                                if (message.knowledgeBaseQuerySource != null && message.hasOwnProperty("knowledgeBaseQuerySource")) {
                                    object.knowledgeBaseQuerySource = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.KnowledgeBaseQuerySource.toObject(message.knowledgeBaseQuerySource, options);
                                    if (options.oneofs)
                                        object.querySource = "knowledgeBaseQuerySource";
                                }
                                if (message.documentQuerySource != null && message.hasOwnProperty("documentQuerySource")) {
                                    object.documentQuerySource = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DocumentQuerySource.toObject(message.documentQuerySource, options);
                                    if (options.oneofs)
                                        object.querySource = "documentQuerySource";
                                }
                                if (message.dialogflowQuerySource != null && message.hasOwnProperty("dialogflowQuerySource")) {
                                    object.dialogflowQuerySource = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.toObject(message.dialogflowQuerySource, options);
                                    if (options.oneofs)
                                        object.querySource = "dialogflowQuerySource";
                                }
                                if (message.maxResults != null && message.hasOwnProperty("maxResults"))
                                    object.maxResults = message.maxResults;
                                if (message.confidenceThreshold != null && message.hasOwnProperty("confidenceThreshold"))
                                    object.confidenceThreshold = options.json && !isFinite(message.confidenceThreshold) ? String(message.confidenceThreshold) : message.confidenceThreshold;
                                if (message.contextFilterSettings != null && message.hasOwnProperty("contextFilterSettings"))
                                    object.contextFilterSettings = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings.toObject(message.contextFilterSettings, options);
                                if (message.sections != null && message.hasOwnProperty("sections"))
                                    object.sections = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections.toObject(message.sections, options);
                                if (message.contextSize != null && message.hasOwnProperty("contextSize"))
                                    object.contextSize = message.contextSize;
                                return object;
                            };
    
                            /**
                             * Converts this SuggestionQueryConfig to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            SuggestionQueryConfig.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for SuggestionQueryConfig
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            SuggestionQueryConfig.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig";
                            };
    
                            SuggestionQueryConfig.KnowledgeBaseQuerySource = (function() {
    
                                /**
                                 * Properties of a KnowledgeBaseQuerySource.
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig
                                 * @interface IKnowledgeBaseQuerySource
                                 * @property {Array.<string>|null} [knowledgeBases] KnowledgeBaseQuerySource knowledgeBases
                                 */
    
                                /**
                                 * Constructs a new KnowledgeBaseQuerySource.
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig
                                 * @classdesc Represents a KnowledgeBaseQuerySource.
                                 * @implements IKnowledgeBaseQuerySource
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.IKnowledgeBaseQuerySource=} [properties] Properties to set
                                 */
                                function KnowledgeBaseQuerySource(properties) {
                                    this.knowledgeBases = [];
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * KnowledgeBaseQuerySource knowledgeBases.
                                 * @member {Array.<string>} knowledgeBases
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.KnowledgeBaseQuerySource
                                 * @instance
                                 */
                                KnowledgeBaseQuerySource.prototype.knowledgeBases = $util.emptyArray;
    
                                /**
                                 * Creates a new KnowledgeBaseQuerySource instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.KnowledgeBaseQuerySource
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.IKnowledgeBaseQuerySource=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.KnowledgeBaseQuerySource} KnowledgeBaseQuerySource instance
                                 */
                                KnowledgeBaseQuerySource.create = function create(properties) {
                                    return new KnowledgeBaseQuerySource(properties);
                                };
    
                                /**
                                 * Encodes the specified KnowledgeBaseQuerySource message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.KnowledgeBaseQuerySource.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.KnowledgeBaseQuerySource
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.IKnowledgeBaseQuerySource} message KnowledgeBaseQuerySource message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                KnowledgeBaseQuerySource.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.knowledgeBases != null && message.knowledgeBases.length)
                                        for (var i = 0; i < message.knowledgeBases.length; ++i)
                                            writer.uint32(/* id 1, wireType 2 =*/10).string(message.knowledgeBases[i]);
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified KnowledgeBaseQuerySource message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.KnowledgeBaseQuerySource.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.KnowledgeBaseQuerySource
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.IKnowledgeBaseQuerySource} message KnowledgeBaseQuerySource message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                KnowledgeBaseQuerySource.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a KnowledgeBaseQuerySource message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.KnowledgeBaseQuerySource
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.KnowledgeBaseQuerySource} KnowledgeBaseQuerySource
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                KnowledgeBaseQuerySource.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.KnowledgeBaseQuerySource();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                if (!(message.knowledgeBases && message.knowledgeBases.length))
                                                    message.knowledgeBases = [];
                                                message.knowledgeBases.push(reader.string());
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a KnowledgeBaseQuerySource message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.KnowledgeBaseQuerySource
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.KnowledgeBaseQuerySource} KnowledgeBaseQuerySource
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                KnowledgeBaseQuerySource.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a KnowledgeBaseQuerySource message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.KnowledgeBaseQuerySource
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                KnowledgeBaseQuerySource.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.knowledgeBases != null && message.hasOwnProperty("knowledgeBases")) {
                                        if (!Array.isArray(message.knowledgeBases))
                                            return "knowledgeBases: array expected";
                                        for (var i = 0; i < message.knowledgeBases.length; ++i)
                                            if (!$util.isString(message.knowledgeBases[i]))
                                                return "knowledgeBases: string[] expected";
                                    }
                                    return null;
                                };
    
                                /**
                                 * Creates a KnowledgeBaseQuerySource message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.KnowledgeBaseQuerySource
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.KnowledgeBaseQuerySource} KnowledgeBaseQuerySource
                                 */
                                KnowledgeBaseQuerySource.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.KnowledgeBaseQuerySource)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.KnowledgeBaseQuerySource();
                                    if (object.knowledgeBases) {
                                        if (!Array.isArray(object.knowledgeBases))
                                            throw TypeError(".google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.KnowledgeBaseQuerySource.knowledgeBases: array expected");
                                        message.knowledgeBases = [];
                                        for (var i = 0; i < object.knowledgeBases.length; ++i)
                                            message.knowledgeBases[i] = String(object.knowledgeBases[i]);
                                    }
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a KnowledgeBaseQuerySource message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.KnowledgeBaseQuerySource
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.KnowledgeBaseQuerySource} message KnowledgeBaseQuerySource
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                KnowledgeBaseQuerySource.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.arrays || options.defaults)
                                        object.knowledgeBases = [];
                                    if (message.knowledgeBases && message.knowledgeBases.length) {
                                        object.knowledgeBases = [];
                                        for (var j = 0; j < message.knowledgeBases.length; ++j)
                                            object.knowledgeBases[j] = message.knowledgeBases[j];
                                    }
                                    return object;
                                };
    
                                /**
                                 * Converts this KnowledgeBaseQuerySource to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.KnowledgeBaseQuerySource
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                KnowledgeBaseQuerySource.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for KnowledgeBaseQuerySource
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.KnowledgeBaseQuerySource
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                KnowledgeBaseQuerySource.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.KnowledgeBaseQuerySource";
                                };
    
                                return KnowledgeBaseQuerySource;
                            })();
    
                            SuggestionQueryConfig.DocumentQuerySource = (function() {
    
                                /**
                                 * Properties of a DocumentQuerySource.
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig
                                 * @interface IDocumentQuerySource
                                 * @property {Array.<string>|null} [documents] DocumentQuerySource documents
                                 */
    
                                /**
                                 * Constructs a new DocumentQuerySource.
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig
                                 * @classdesc Represents a DocumentQuerySource.
                                 * @implements IDocumentQuerySource
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.IDocumentQuerySource=} [properties] Properties to set
                                 */
                                function DocumentQuerySource(properties) {
                                    this.documents = [];
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * DocumentQuerySource documents.
                                 * @member {Array.<string>} documents
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DocumentQuerySource
                                 * @instance
                                 */
                                DocumentQuerySource.prototype.documents = $util.emptyArray;
    
                                /**
                                 * Creates a new DocumentQuerySource instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DocumentQuerySource
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.IDocumentQuerySource=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DocumentQuerySource} DocumentQuerySource instance
                                 */
                                DocumentQuerySource.create = function create(properties) {
                                    return new DocumentQuerySource(properties);
                                };
    
                                /**
                                 * Encodes the specified DocumentQuerySource message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DocumentQuerySource.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DocumentQuerySource
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.IDocumentQuerySource} message DocumentQuerySource message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                DocumentQuerySource.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.documents != null && message.documents.length)
                                        for (var i = 0; i < message.documents.length; ++i)
                                            writer.uint32(/* id 1, wireType 2 =*/10).string(message.documents[i]);
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified DocumentQuerySource message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DocumentQuerySource.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DocumentQuerySource
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.IDocumentQuerySource} message DocumentQuerySource message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                DocumentQuerySource.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a DocumentQuerySource message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DocumentQuerySource
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DocumentQuerySource} DocumentQuerySource
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                DocumentQuerySource.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DocumentQuerySource();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                if (!(message.documents && message.documents.length))
                                                    message.documents = [];
                                                message.documents.push(reader.string());
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a DocumentQuerySource message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DocumentQuerySource
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DocumentQuerySource} DocumentQuerySource
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                DocumentQuerySource.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a DocumentQuerySource message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DocumentQuerySource
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                DocumentQuerySource.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.documents != null && message.hasOwnProperty("documents")) {
                                        if (!Array.isArray(message.documents))
                                            return "documents: array expected";
                                        for (var i = 0; i < message.documents.length; ++i)
                                            if (!$util.isString(message.documents[i]))
                                                return "documents: string[] expected";
                                    }
                                    return null;
                                };
    
                                /**
                                 * Creates a DocumentQuerySource message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DocumentQuerySource
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DocumentQuerySource} DocumentQuerySource
                                 */
                                DocumentQuerySource.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DocumentQuerySource)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DocumentQuerySource();
                                    if (object.documents) {
                                        if (!Array.isArray(object.documents))
                                            throw TypeError(".google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DocumentQuerySource.documents: array expected");
                                        message.documents = [];
                                        for (var i = 0; i < object.documents.length; ++i)
                                            message.documents[i] = String(object.documents[i]);
                                    }
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a DocumentQuerySource message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DocumentQuerySource
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DocumentQuerySource} message DocumentQuerySource
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                DocumentQuerySource.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.arrays || options.defaults)
                                        object.documents = [];
                                    if (message.documents && message.documents.length) {
                                        object.documents = [];
                                        for (var j = 0; j < message.documents.length; ++j)
                                            object.documents[j] = message.documents[j];
                                    }
                                    return object;
                                };
    
                                /**
                                 * Converts this DocumentQuerySource to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DocumentQuerySource
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                DocumentQuerySource.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for DocumentQuerySource
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DocumentQuerySource
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                DocumentQuerySource.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DocumentQuerySource";
                                };
    
                                return DocumentQuerySource;
                            })();
    
                            SuggestionQueryConfig.DialogflowQuerySource = (function() {
    
                                /**
                                 * Properties of a DialogflowQuerySource.
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig
                                 * @interface IDialogflowQuerySource
                                 * @property {string|null} [agent] DialogflowQuerySource agent
                                 * @property {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.IHumanAgentSideConfig|null} [humanAgentSideConfig] DialogflowQuerySource humanAgentSideConfig
                                 */
    
                                /**
                                 * Constructs a new DialogflowQuerySource.
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig
                                 * @classdesc Represents a DialogflowQuerySource.
                                 * @implements IDialogflowQuerySource
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.IDialogflowQuerySource=} [properties] Properties to set
                                 */
                                function DialogflowQuerySource(properties) {
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * DialogflowQuerySource agent.
                                 * @member {string} agent
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource
                                 * @instance
                                 */
                                DialogflowQuerySource.prototype.agent = "";
    
                                /**
                                 * DialogflowQuerySource humanAgentSideConfig.
                                 * @member {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.IHumanAgentSideConfig|null|undefined} humanAgentSideConfig
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource
                                 * @instance
                                 */
                                DialogflowQuerySource.prototype.humanAgentSideConfig = null;
    
                                /**
                                 * Creates a new DialogflowQuerySource instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.IDialogflowQuerySource=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource} DialogflowQuerySource instance
                                 */
                                DialogflowQuerySource.create = function create(properties) {
                                    return new DialogflowQuerySource(properties);
                                };
    
                                /**
                                 * Encodes the specified DialogflowQuerySource message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.IDialogflowQuerySource} message DialogflowQuerySource message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                DialogflowQuerySource.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.agent != null && Object.hasOwnProperty.call(message, "agent"))
                                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.agent);
                                    if (message.humanAgentSideConfig != null && Object.hasOwnProperty.call(message, "humanAgentSideConfig"))
                                        $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.HumanAgentSideConfig.encode(message.humanAgentSideConfig, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified DialogflowQuerySource message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.IDialogflowQuerySource} message DialogflowQuerySource message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                DialogflowQuerySource.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a DialogflowQuerySource message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource} DialogflowQuerySource
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                DialogflowQuerySource.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                message.agent = reader.string();
                                                break;
                                            }
                                        case 3: {
                                                message.humanAgentSideConfig = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.HumanAgentSideConfig.decode(reader, reader.uint32());
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a DialogflowQuerySource message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource} DialogflowQuerySource
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                DialogflowQuerySource.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a DialogflowQuerySource message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                DialogflowQuerySource.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.agent != null && message.hasOwnProperty("agent"))
                                        if (!$util.isString(message.agent))
                                            return "agent: string expected";
                                    if (message.humanAgentSideConfig != null && message.hasOwnProperty("humanAgentSideConfig")) {
                                        var error = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.HumanAgentSideConfig.verify(message.humanAgentSideConfig);
                                        if (error)
                                            return "humanAgentSideConfig." + error;
                                    }
                                    return null;
                                };
    
                                /**
                                 * Creates a DialogflowQuerySource message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource} DialogflowQuerySource
                                 */
                                DialogflowQuerySource.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource();
                                    if (object.agent != null)
                                        message.agent = String(object.agent);
                                    if (object.humanAgentSideConfig != null) {
                                        if (typeof object.humanAgentSideConfig !== "object")
                                            throw TypeError(".google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.humanAgentSideConfig: object expected");
                                        message.humanAgentSideConfig = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.HumanAgentSideConfig.fromObject(object.humanAgentSideConfig);
                                    }
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a DialogflowQuerySource message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource} message DialogflowQuerySource
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                DialogflowQuerySource.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.defaults) {
                                        object.agent = "";
                                        object.humanAgentSideConfig = null;
                                    }
                                    if (message.agent != null && message.hasOwnProperty("agent"))
                                        object.agent = message.agent;
                                    if (message.humanAgentSideConfig != null && message.hasOwnProperty("humanAgentSideConfig"))
                                        object.humanAgentSideConfig = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.HumanAgentSideConfig.toObject(message.humanAgentSideConfig, options);
                                    return object;
                                };
    
                                /**
                                 * Converts this DialogflowQuerySource to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                DialogflowQuerySource.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for DialogflowQuerySource
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                DialogflowQuerySource.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource";
                                };
    
                                DialogflowQuerySource.HumanAgentSideConfig = (function() {
    
                                    /**
                                     * Properties of a HumanAgentSideConfig.
                                     * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource
                                     * @interface IHumanAgentSideConfig
                                     * @property {string|null} [agent] HumanAgentSideConfig agent
                                     */
    
                                    /**
                                     * Constructs a new HumanAgentSideConfig.
                                     * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource
                                     * @classdesc Represents a HumanAgentSideConfig.
                                     * @implements IHumanAgentSideConfig
                                     * @constructor
                                     * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.IHumanAgentSideConfig=} [properties] Properties to set
                                     */
                                    function HumanAgentSideConfig(properties) {
                                        if (properties)
                                            for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                                if (properties[keys[i]] != null)
                                                    this[keys[i]] = properties[keys[i]];
                                    }
    
                                    /**
                                     * HumanAgentSideConfig agent.
                                     * @member {string} agent
                                     * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.HumanAgentSideConfig
                                     * @instance
                                     */
                                    HumanAgentSideConfig.prototype.agent = "";
    
                                    /**
                                     * Creates a new HumanAgentSideConfig instance using the specified properties.
                                     * @function create
                                     * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.HumanAgentSideConfig
                                     * @static
                                     * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.IHumanAgentSideConfig=} [properties] Properties to set
                                     * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.HumanAgentSideConfig} HumanAgentSideConfig instance
                                     */
                                    HumanAgentSideConfig.create = function create(properties) {
                                        return new HumanAgentSideConfig(properties);
                                    };
    
                                    /**
                                     * Encodes the specified HumanAgentSideConfig message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.HumanAgentSideConfig.verify|verify} messages.
                                     * @function encode
                                     * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.HumanAgentSideConfig
                                     * @static
                                     * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.IHumanAgentSideConfig} message HumanAgentSideConfig message or plain object to encode
                                     * @param {$protobuf.Writer} [writer] Writer to encode to
                                     * @returns {$protobuf.Writer} Writer
                                     */
                                    HumanAgentSideConfig.encode = function encode(message, writer) {
                                        if (!writer)
                                            writer = $Writer.create();
                                        if (message.agent != null && Object.hasOwnProperty.call(message, "agent"))
                                            writer.uint32(/* id 1, wireType 2 =*/10).string(message.agent);
                                        return writer;
                                    };
    
                                    /**
                                     * Encodes the specified HumanAgentSideConfig message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.HumanAgentSideConfig.verify|verify} messages.
                                     * @function encodeDelimited
                                     * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.HumanAgentSideConfig
                                     * @static
                                     * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.IHumanAgentSideConfig} message HumanAgentSideConfig message or plain object to encode
                                     * @param {$protobuf.Writer} [writer] Writer to encode to
                                     * @returns {$protobuf.Writer} Writer
                                     */
                                    HumanAgentSideConfig.encodeDelimited = function encodeDelimited(message, writer) {
                                        return this.encode(message, writer).ldelim();
                                    };
    
                                    /**
                                     * Decodes a HumanAgentSideConfig message from the specified reader or buffer.
                                     * @function decode
                                     * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.HumanAgentSideConfig
                                     * @static
                                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                     * @param {number} [length] Message length if known beforehand
                                     * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.HumanAgentSideConfig} HumanAgentSideConfig
                                     * @throws {Error} If the payload is not a reader or valid buffer
                                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                     */
                                    HumanAgentSideConfig.decode = function decode(reader, length) {
                                        if (!(reader instanceof $Reader))
                                            reader = $Reader.create(reader);
                                        var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.HumanAgentSideConfig();
                                        while (reader.pos < end) {
                                            var tag = reader.uint32();
                                            switch (tag >>> 3) {
                                            case 1: {
                                                    message.agent = reader.string();
                                                    break;
                                                }
                                            default:
                                                reader.skipType(tag & 7);
                                                break;
                                            }
                                        }
                                        return message;
                                    };
    
                                    /**
                                     * Decodes a HumanAgentSideConfig message from the specified reader or buffer, length delimited.
                                     * @function decodeDelimited
                                     * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.HumanAgentSideConfig
                                     * @static
                                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                     * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.HumanAgentSideConfig} HumanAgentSideConfig
                                     * @throws {Error} If the payload is not a reader or valid buffer
                                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                     */
                                    HumanAgentSideConfig.decodeDelimited = function decodeDelimited(reader) {
                                        if (!(reader instanceof $Reader))
                                            reader = new $Reader(reader);
                                        return this.decode(reader, reader.uint32());
                                    };
    
                                    /**
                                     * Verifies a HumanAgentSideConfig message.
                                     * @function verify
                                     * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.HumanAgentSideConfig
                                     * @static
                                     * @param {Object.<string,*>} message Plain object to verify
                                     * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                     */
                                    HumanAgentSideConfig.verify = function verify(message) {
                                        if (typeof message !== "object" || message === null)
                                            return "object expected";
                                        if (message.agent != null && message.hasOwnProperty("agent"))
                                            if (!$util.isString(message.agent))
                                                return "agent: string expected";
                                        return null;
                                    };
    
                                    /**
                                     * Creates a HumanAgentSideConfig message from a plain object. Also converts values to their respective internal types.
                                     * @function fromObject
                                     * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.HumanAgentSideConfig
                                     * @static
                                     * @param {Object.<string,*>} object Plain object
                                     * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.HumanAgentSideConfig} HumanAgentSideConfig
                                     */
                                    HumanAgentSideConfig.fromObject = function fromObject(object) {
                                        if (object instanceof $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.HumanAgentSideConfig)
                                            return object;
                                        var message = new $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.HumanAgentSideConfig();
                                        if (object.agent != null)
                                            message.agent = String(object.agent);
                                        return message;
                                    };
    
                                    /**
                                     * Creates a plain object from a HumanAgentSideConfig message. Also converts values to other types if specified.
                                     * @function toObject
                                     * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.HumanAgentSideConfig
                                     * @static
                                     * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.HumanAgentSideConfig} message HumanAgentSideConfig
                                     * @param {$protobuf.IConversionOptions} [options] Conversion options
                                     * @returns {Object.<string,*>} Plain object
                                     */
                                    HumanAgentSideConfig.toObject = function toObject(message, options) {
                                        if (!options)
                                            options = {};
                                        var object = {};
                                        if (options.defaults)
                                            object.agent = "";
                                        if (message.agent != null && message.hasOwnProperty("agent"))
                                            object.agent = message.agent;
                                        return object;
                                    };
    
                                    /**
                                     * Converts this HumanAgentSideConfig to JSON.
                                     * @function toJSON
                                     * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.HumanAgentSideConfig
                                     * @instance
                                     * @returns {Object.<string,*>} JSON object
                                     */
                                    HumanAgentSideConfig.prototype.toJSON = function toJSON() {
                                        return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                    };
    
                                    /**
                                     * Gets the default type url for HumanAgentSideConfig
                                     * @function getTypeUrl
                                     * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.HumanAgentSideConfig
                                     * @static
                                     * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                     * @returns {string} The default type url
                                     */
                                    HumanAgentSideConfig.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                        if (typeUrlPrefix === undefined) {
                                            typeUrlPrefix = "type.googleapis.com";
                                        }
                                        return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.DialogflowQuerySource.HumanAgentSideConfig";
                                    };
    
                                    return HumanAgentSideConfig;
                                })();
    
                                return DialogflowQuerySource;
                            })();
    
                            SuggestionQueryConfig.ContextFilterSettings = (function() {
    
                                /**
                                 * Properties of a ContextFilterSettings.
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig
                                 * @interface IContextFilterSettings
                                 * @property {boolean|null} [dropHandoffMessages] ContextFilterSettings dropHandoffMessages
                                 * @property {boolean|null} [dropVirtualAgentMessages] ContextFilterSettings dropVirtualAgentMessages
                                 * @property {boolean|null} [dropIvrMessages] ContextFilterSettings dropIvrMessages
                                 */
    
                                /**
                                 * Constructs a new ContextFilterSettings.
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig
                                 * @classdesc Represents a ContextFilterSettings.
                                 * @implements IContextFilterSettings
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.IContextFilterSettings=} [properties] Properties to set
                                 */
                                function ContextFilterSettings(properties) {
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * ContextFilterSettings dropHandoffMessages.
                                 * @member {boolean} dropHandoffMessages
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings
                                 * @instance
                                 */
                                ContextFilterSettings.prototype.dropHandoffMessages = false;
    
                                /**
                                 * ContextFilterSettings dropVirtualAgentMessages.
                                 * @member {boolean} dropVirtualAgentMessages
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings
                                 * @instance
                                 */
                                ContextFilterSettings.prototype.dropVirtualAgentMessages = false;
    
                                /**
                                 * ContextFilterSettings dropIvrMessages.
                                 * @member {boolean} dropIvrMessages
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings
                                 * @instance
                                 */
                                ContextFilterSettings.prototype.dropIvrMessages = false;
    
                                /**
                                 * Creates a new ContextFilterSettings instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.IContextFilterSettings=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings} ContextFilterSettings instance
                                 */
                                ContextFilterSettings.create = function create(properties) {
                                    return new ContextFilterSettings(properties);
                                };
    
                                /**
                                 * Encodes the specified ContextFilterSettings message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.IContextFilterSettings} message ContextFilterSettings message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                ContextFilterSettings.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.dropHandoffMessages != null && Object.hasOwnProperty.call(message, "dropHandoffMessages"))
                                        writer.uint32(/* id 1, wireType 0 =*/8).bool(message.dropHandoffMessages);
                                    if (message.dropVirtualAgentMessages != null && Object.hasOwnProperty.call(message, "dropVirtualAgentMessages"))
                                        writer.uint32(/* id 2, wireType 0 =*/16).bool(message.dropVirtualAgentMessages);
                                    if (message.dropIvrMessages != null && Object.hasOwnProperty.call(message, "dropIvrMessages"))
                                        writer.uint32(/* id 3, wireType 0 =*/24).bool(message.dropIvrMessages);
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified ContextFilterSettings message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.IContextFilterSettings} message ContextFilterSettings message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                ContextFilterSettings.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a ContextFilterSettings message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings} ContextFilterSettings
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                ContextFilterSettings.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                message.dropHandoffMessages = reader.bool();
                                                break;
                                            }
                                        case 2: {
                                                message.dropVirtualAgentMessages = reader.bool();
                                                break;
                                            }
                                        case 3: {
                                                message.dropIvrMessages = reader.bool();
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a ContextFilterSettings message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings} ContextFilterSettings
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                ContextFilterSettings.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a ContextFilterSettings message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                ContextFilterSettings.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.dropHandoffMessages != null && message.hasOwnProperty("dropHandoffMessages"))
                                        if (typeof message.dropHandoffMessages !== "boolean")
                                            return "dropHandoffMessages: boolean expected";
                                    if (message.dropVirtualAgentMessages != null && message.hasOwnProperty("dropVirtualAgentMessages"))
                                        if (typeof message.dropVirtualAgentMessages !== "boolean")
                                            return "dropVirtualAgentMessages: boolean expected";
                                    if (message.dropIvrMessages != null && message.hasOwnProperty("dropIvrMessages"))
                                        if (typeof message.dropIvrMessages !== "boolean")
                                            return "dropIvrMessages: boolean expected";
                                    return null;
                                };
    
                                /**
                                 * Creates a ContextFilterSettings message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings} ContextFilterSettings
                                 */
                                ContextFilterSettings.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings();
                                    if (object.dropHandoffMessages != null)
                                        message.dropHandoffMessages = Boolean(object.dropHandoffMessages);
                                    if (object.dropVirtualAgentMessages != null)
                                        message.dropVirtualAgentMessages = Boolean(object.dropVirtualAgentMessages);
                                    if (object.dropIvrMessages != null)
                                        message.dropIvrMessages = Boolean(object.dropIvrMessages);
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a ContextFilterSettings message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings} message ContextFilterSettings
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                ContextFilterSettings.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.defaults) {
                                        object.dropHandoffMessages = false;
                                        object.dropVirtualAgentMessages = false;
                                        object.dropIvrMessages = false;
                                    }
                                    if (message.dropHandoffMessages != null && message.hasOwnProperty("dropHandoffMessages"))
                                        object.dropHandoffMessages = message.dropHandoffMessages;
                                    if (message.dropVirtualAgentMessages != null && message.hasOwnProperty("dropVirtualAgentMessages"))
                                        object.dropVirtualAgentMessages = message.dropVirtualAgentMessages;
                                    if (message.dropIvrMessages != null && message.hasOwnProperty("dropIvrMessages"))
                                        object.dropIvrMessages = message.dropIvrMessages;
                                    return object;
                                };
    
                                /**
                                 * Converts this ContextFilterSettings to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                ContextFilterSettings.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for ContextFilterSettings
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                ContextFilterSettings.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.ContextFilterSettings";
                                };
    
                                return ContextFilterSettings;
                            })();
    
                            SuggestionQueryConfig.Sections = (function() {
    
                                /**
                                 * Properties of a Sections.
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig
                                 * @interface ISections
                                 * @property {Array.<google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections.SectionType>|null} [sectionTypes] Sections sectionTypes
                                 */
    
                                /**
                                 * Constructs a new Sections.
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig
                                 * @classdesc Represents a Sections.
                                 * @implements ISections
                                 * @constructor
                                 * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.ISections=} [properties] Properties to set
                                 */
                                function Sections(properties) {
                                    this.sectionTypes = [];
                                    if (properties)
                                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                            if (properties[keys[i]] != null)
                                                this[keys[i]] = properties[keys[i]];
                                }
    
                                /**
                                 * Sections sectionTypes.
                                 * @member {Array.<google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections.SectionType>} sectionTypes
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections
                                 * @instance
                                 */
                                Sections.prototype.sectionTypes = $util.emptyArray;
    
                                /**
                                 * Creates a new Sections instance using the specified properties.
                                 * @function create
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.ISections=} [properties] Properties to set
                                 * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections} Sections instance
                                 */
                                Sections.create = function create(properties) {
                                    return new Sections(properties);
                                };
    
                                /**
                                 * Encodes the specified Sections message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections.verify|verify} messages.
                                 * @function encode
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.ISections} message Sections message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                Sections.encode = function encode(message, writer) {
                                    if (!writer)
                                        writer = $Writer.create();
                                    if (message.sectionTypes != null && message.sectionTypes.length) {
                                        writer.uint32(/* id 1, wireType 2 =*/10).fork();
                                        for (var i = 0; i < message.sectionTypes.length; ++i)
                                            writer.int32(message.sectionTypes[i]);
                                        writer.ldelim();
                                    }
                                    return writer;
                                };
    
                                /**
                                 * Encodes the specified Sections message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections.verify|verify} messages.
                                 * @function encodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.ISections} message Sections message or plain object to encode
                                 * @param {$protobuf.Writer} [writer] Writer to encode to
                                 * @returns {$protobuf.Writer} Writer
                                 */
                                Sections.encodeDelimited = function encodeDelimited(message, writer) {
                                    return this.encode(message, writer).ldelim();
                                };
    
                                /**
                                 * Decodes a Sections message from the specified reader or buffer.
                                 * @function decode
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @param {number} [length] Message length if known beforehand
                                 * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections} Sections
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                Sections.decode = function decode(reader, length) {
                                    if (!(reader instanceof $Reader))
                                        reader = $Reader.create(reader);
                                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections();
                                    while (reader.pos < end) {
                                        var tag = reader.uint32();
                                        switch (tag >>> 3) {
                                        case 1: {
                                                if (!(message.sectionTypes && message.sectionTypes.length))
                                                    message.sectionTypes = [];
                                                if ((tag & 7) === 2) {
                                                    var end2 = reader.uint32() + reader.pos;
                                                    while (reader.pos < end2)
                                                        message.sectionTypes.push(reader.int32());
                                                } else
                                                    message.sectionTypes.push(reader.int32());
                                                break;
                                            }
                                        default:
                                            reader.skipType(tag & 7);
                                            break;
                                        }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Decodes a Sections message from the specified reader or buffer, length delimited.
                                 * @function decodeDelimited
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections
                                 * @static
                                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                                 * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections} Sections
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                Sections.decodeDelimited = function decodeDelimited(reader) {
                                    if (!(reader instanceof $Reader))
                                        reader = new $Reader(reader);
                                    return this.decode(reader, reader.uint32());
                                };
    
                                /**
                                 * Verifies a Sections message.
                                 * @function verify
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections
                                 * @static
                                 * @param {Object.<string,*>} message Plain object to verify
                                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                                 */
                                Sections.verify = function verify(message) {
                                    if (typeof message !== "object" || message === null)
                                        return "object expected";
                                    if (message.sectionTypes != null && message.hasOwnProperty("sectionTypes")) {
                                        if (!Array.isArray(message.sectionTypes))
                                            return "sectionTypes: array expected";
                                        for (var i = 0; i < message.sectionTypes.length; ++i)
                                            switch (message.sectionTypes[i]) {
                                            default:
                                                return "sectionTypes: enum value[] expected";
                                            case 0:
                                            case 1:
                                            case 2:
                                            case 3:
                                            case 4:
                                            case 5:
                                            case 6:
                                                break;
                                            }
                                    }
                                    return null;
                                };
    
                                /**
                                 * Creates a Sections message from a plain object. Also converts values to their respective internal types.
                                 * @function fromObject
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections
                                 * @static
                                 * @param {Object.<string,*>} object Plain object
                                 * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections} Sections
                                 */
                                Sections.fromObject = function fromObject(object) {
                                    if (object instanceof $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections)
                                        return object;
                                    var message = new $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections();
                                    if (object.sectionTypes) {
                                        if (!Array.isArray(object.sectionTypes))
                                            throw TypeError(".google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections.sectionTypes: array expected");
                                        message.sectionTypes = [];
                                        for (var i = 0; i < object.sectionTypes.length; ++i)
                                            switch (object.sectionTypes[i]) {
                                            default:
                                                if (typeof object.sectionTypes[i] === "number") {
                                                    message.sectionTypes[i] = object.sectionTypes[i];
                                                    break;
                                                }
                                            case "SECTION_TYPE_UNSPECIFIED":
                                            case 0:
                                                message.sectionTypes[i] = 0;
                                                break;
                                            case "SITUATION":
                                            case 1:
                                                message.sectionTypes[i] = 1;
                                                break;
                                            case "ACTION":
                                            case 2:
                                                message.sectionTypes[i] = 2;
                                                break;
                                            case "RESOLUTION":
                                            case 3:
                                                message.sectionTypes[i] = 3;
                                                break;
                                            case "REASON_FOR_CANCELLATION":
                                            case 4:
                                                message.sectionTypes[i] = 4;
                                                break;
                                            case "CUSTOMER_SATISFACTION":
                                            case 5:
                                                message.sectionTypes[i] = 5;
                                                break;
                                            case "ENTITIES":
                                            case 6:
                                                message.sectionTypes[i] = 6;
                                                break;
                                            }
                                    }
                                    return message;
                                };
    
                                /**
                                 * Creates a plain object from a Sections message. Also converts values to other types if specified.
                                 * @function toObject
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections
                                 * @static
                                 * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections} message Sections
                                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                                 * @returns {Object.<string,*>} Plain object
                                 */
                                Sections.toObject = function toObject(message, options) {
                                    if (!options)
                                        options = {};
                                    var object = {};
                                    if (options.arrays || options.defaults)
                                        object.sectionTypes = [];
                                    if (message.sectionTypes && message.sectionTypes.length) {
                                        object.sectionTypes = [];
                                        for (var j = 0; j < message.sectionTypes.length; ++j)
                                            object.sectionTypes[j] = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections.SectionType[message.sectionTypes[j]] === undefined ? message.sectionTypes[j] : $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections.SectionType[message.sectionTypes[j]] : message.sectionTypes[j];
                                    }
                                    return object;
                                };
    
                                /**
                                 * Converts this Sections to JSON.
                                 * @function toJSON
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections
                                 * @instance
                                 * @returns {Object.<string,*>} JSON object
                                 */
                                Sections.prototype.toJSON = function toJSON() {
                                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                                };
    
                                /**
                                 * Gets the default type url for Sections
                                 * @function getTypeUrl
                                 * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections
                                 * @static
                                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns {string} The default type url
                                 */
                                Sections.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                    if (typeUrlPrefix === undefined) {
                                        typeUrlPrefix = "type.googleapis.com";
                                    }
                                    return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections";
                                };
    
                                /**
                                 * SectionType enum.
                                 * @name google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionQueryConfig.Sections.SectionType
                                 * @enum {number}
                                 * @property {number} SECTION_TYPE_UNSPECIFIED=0 SECTION_TYPE_UNSPECIFIED value
                                 * @property {number} SITUATION=1 SITUATION value
                                 * @property {number} ACTION=2 ACTION value
                                 * @property {number} RESOLUTION=3 RESOLUTION value
                                 * @property {number} REASON_FOR_CANCELLATION=4 REASON_FOR_CANCELLATION value
                                 * @property {number} CUSTOMER_SATISFACTION=5 CUSTOMER_SATISFACTION value
                                 * @property {number} ENTITIES=6 ENTITIES value
                                 */
                                Sections.SectionType = (function() {
                                    var valuesById = {}, values = Object.create(valuesById);
                                    values[valuesById[0] = "SECTION_TYPE_UNSPECIFIED"] = 0;
                                    values[valuesById[1] = "SITUATION"] = 1;
                                    values[valuesById[2] = "ACTION"] = 2;
                                    values[valuesById[3] = "RESOLUTION"] = 3;
                                    values[valuesById[4] = "REASON_FOR_CANCELLATION"] = 4;
                                    values[valuesById[5] = "CUSTOMER_SATISFACTION"] = 5;
                                    values[valuesById[6] = "ENTITIES"] = 6;
                                    return values;
                                })();
    
                                return Sections;
                            })();
    
                            return SuggestionQueryConfig;
                        })();
    
                        HumanAgentAssistantConfig.ConversationModelConfig = (function() {
    
                            /**
                             * Properties of a ConversationModelConfig.
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig
                             * @interface IConversationModelConfig
                             * @property {string|null} [model] ConversationModelConfig model
                             * @property {string|null} [baselineModelVersion] ConversationModelConfig baselineModelVersion
                             */
    
                            /**
                             * Constructs a new ConversationModelConfig.
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig
                             * @classdesc Represents a ConversationModelConfig.
                             * @implements IConversationModelConfig
                             * @constructor
                             * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.IConversationModelConfig=} [properties] Properties to set
                             */
                            function ConversationModelConfig(properties) {
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * ConversationModelConfig model.
                             * @member {string} model
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ConversationModelConfig
                             * @instance
                             */
                            ConversationModelConfig.prototype.model = "";
    
                            /**
                             * ConversationModelConfig baselineModelVersion.
                             * @member {string} baselineModelVersion
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ConversationModelConfig
                             * @instance
                             */
                            ConversationModelConfig.prototype.baselineModelVersion = "";
    
                            /**
                             * Creates a new ConversationModelConfig instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ConversationModelConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.IConversationModelConfig=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ConversationModelConfig} ConversationModelConfig instance
                             */
                            ConversationModelConfig.create = function create(properties) {
                                return new ConversationModelConfig(properties);
                            };
    
                            /**
                             * Encodes the specified ConversationModelConfig message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ConversationModelConfig.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ConversationModelConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.IConversationModelConfig} message ConversationModelConfig message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            ConversationModelConfig.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.model != null && Object.hasOwnProperty.call(message, "model"))
                                    writer.uint32(/* id 1, wireType 2 =*/10).string(message.model);
                                if (message.baselineModelVersion != null && Object.hasOwnProperty.call(message, "baselineModelVersion"))
                                    writer.uint32(/* id 8, wireType 2 =*/66).string(message.baselineModelVersion);
                                return writer;
                            };
    
                            /**
                             * Encodes the specified ConversationModelConfig message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ConversationModelConfig.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ConversationModelConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.IConversationModelConfig} message ConversationModelConfig message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            ConversationModelConfig.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a ConversationModelConfig message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ConversationModelConfig
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ConversationModelConfig} ConversationModelConfig
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            ConversationModelConfig.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ConversationModelConfig();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.model = reader.string();
                                            break;
                                        }
                                    case 8: {
                                            message.baselineModelVersion = reader.string();
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a ConversationModelConfig message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ConversationModelConfig
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ConversationModelConfig} ConversationModelConfig
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            ConversationModelConfig.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a ConversationModelConfig message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ConversationModelConfig
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            ConversationModelConfig.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.model != null && message.hasOwnProperty("model"))
                                    if (!$util.isString(message.model))
                                        return "model: string expected";
                                if (message.baselineModelVersion != null && message.hasOwnProperty("baselineModelVersion"))
                                    if (!$util.isString(message.baselineModelVersion))
                                        return "baselineModelVersion: string expected";
                                return null;
                            };
    
                            /**
                             * Creates a ConversationModelConfig message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ConversationModelConfig
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ConversationModelConfig} ConversationModelConfig
                             */
                            ConversationModelConfig.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ConversationModelConfig)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ConversationModelConfig();
                                if (object.model != null)
                                    message.model = String(object.model);
                                if (object.baselineModelVersion != null)
                                    message.baselineModelVersion = String(object.baselineModelVersion);
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a ConversationModelConfig message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ConversationModelConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ConversationModelConfig} message ConversationModelConfig
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            ConversationModelConfig.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.defaults) {
                                    object.model = "";
                                    object.baselineModelVersion = "";
                                }
                                if (message.model != null && message.hasOwnProperty("model"))
                                    object.model = message.model;
                                if (message.baselineModelVersion != null && message.hasOwnProperty("baselineModelVersion"))
                                    object.baselineModelVersion = message.baselineModelVersion;
                                return object;
                            };
    
                            /**
                             * Converts this ConversationModelConfig to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ConversationModelConfig
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            ConversationModelConfig.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for ConversationModelConfig
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ConversationModelConfig
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            ConversationModelConfig.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ConversationModelConfig";
                            };
    
                            return ConversationModelConfig;
                        })();
    
                        HumanAgentAssistantConfig.ConversationProcessConfig = (function() {
    
                            /**
                             * Properties of a ConversationProcessConfig.
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig
                             * @interface IConversationProcessConfig
                             * @property {number|null} [recentSentencesCount] ConversationProcessConfig recentSentencesCount
                             */
    
                            /**
                             * Constructs a new ConversationProcessConfig.
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig
                             * @classdesc Represents a ConversationProcessConfig.
                             * @implements IConversationProcessConfig
                             * @constructor
                             * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.IConversationProcessConfig=} [properties] Properties to set
                             */
                            function ConversationProcessConfig(properties) {
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * ConversationProcessConfig recentSentencesCount.
                             * @member {number} recentSentencesCount
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ConversationProcessConfig
                             * @instance
                             */
                            ConversationProcessConfig.prototype.recentSentencesCount = 0;
    
                            /**
                             * Creates a new ConversationProcessConfig instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ConversationProcessConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.IConversationProcessConfig=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ConversationProcessConfig} ConversationProcessConfig instance
                             */
                            ConversationProcessConfig.create = function create(properties) {
                                return new ConversationProcessConfig(properties);
                            };
    
                            /**
                             * Encodes the specified ConversationProcessConfig message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ConversationProcessConfig.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ConversationProcessConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.IConversationProcessConfig} message ConversationProcessConfig message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            ConversationProcessConfig.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.recentSentencesCount != null && Object.hasOwnProperty.call(message, "recentSentencesCount"))
                                    writer.uint32(/* id 2, wireType 0 =*/16).int32(message.recentSentencesCount);
                                return writer;
                            };
    
                            /**
                             * Encodes the specified ConversationProcessConfig message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ConversationProcessConfig.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ConversationProcessConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.IConversationProcessConfig} message ConversationProcessConfig message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            ConversationProcessConfig.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a ConversationProcessConfig message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ConversationProcessConfig
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ConversationProcessConfig} ConversationProcessConfig
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            ConversationProcessConfig.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ConversationProcessConfig();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 2: {
                                            message.recentSentencesCount = reader.int32();
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a ConversationProcessConfig message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ConversationProcessConfig
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ConversationProcessConfig} ConversationProcessConfig
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            ConversationProcessConfig.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a ConversationProcessConfig message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ConversationProcessConfig
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            ConversationProcessConfig.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.recentSentencesCount != null && message.hasOwnProperty("recentSentencesCount"))
                                    if (!$util.isInteger(message.recentSentencesCount))
                                        return "recentSentencesCount: integer expected";
                                return null;
                            };
    
                            /**
                             * Creates a ConversationProcessConfig message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ConversationProcessConfig
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ConversationProcessConfig} ConversationProcessConfig
                             */
                            ConversationProcessConfig.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ConversationProcessConfig)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ConversationProcessConfig();
                                if (object.recentSentencesCount != null)
                                    message.recentSentencesCount = object.recentSentencesCount | 0;
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a ConversationProcessConfig message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ConversationProcessConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ConversationProcessConfig} message ConversationProcessConfig
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            ConversationProcessConfig.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.defaults)
                                    object.recentSentencesCount = 0;
                                if (message.recentSentencesCount != null && message.hasOwnProperty("recentSentencesCount"))
                                    object.recentSentencesCount = message.recentSentencesCount;
                                return object;
                            };
    
                            /**
                             * Converts this ConversationProcessConfig to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ConversationProcessConfig
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            ConversationProcessConfig.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for ConversationProcessConfig
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ConversationProcessConfig
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            ConversationProcessConfig.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ConversationProcessConfig";
                            };
    
                            return ConversationProcessConfig;
                        })();
    
                        HumanAgentAssistantConfig.MessageAnalysisConfig = (function() {
    
                            /**
                             * Properties of a MessageAnalysisConfig.
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig
                             * @interface IMessageAnalysisConfig
                             * @property {boolean|null} [enableEntityExtraction] MessageAnalysisConfig enableEntityExtraction
                             * @property {boolean|null} [enableSentimentAnalysis] MessageAnalysisConfig enableSentimentAnalysis
                             */
    
                            /**
                             * Constructs a new MessageAnalysisConfig.
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig
                             * @classdesc Represents a MessageAnalysisConfig.
                             * @implements IMessageAnalysisConfig
                             * @constructor
                             * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.IMessageAnalysisConfig=} [properties] Properties to set
                             */
                            function MessageAnalysisConfig(properties) {
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * MessageAnalysisConfig enableEntityExtraction.
                             * @member {boolean} enableEntityExtraction
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.MessageAnalysisConfig
                             * @instance
                             */
                            MessageAnalysisConfig.prototype.enableEntityExtraction = false;
    
                            /**
                             * MessageAnalysisConfig enableSentimentAnalysis.
                             * @member {boolean} enableSentimentAnalysis
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.MessageAnalysisConfig
                             * @instance
                             */
                            MessageAnalysisConfig.prototype.enableSentimentAnalysis = false;
    
                            /**
                             * Creates a new MessageAnalysisConfig instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.MessageAnalysisConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.IMessageAnalysisConfig=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.MessageAnalysisConfig} MessageAnalysisConfig instance
                             */
                            MessageAnalysisConfig.create = function create(properties) {
                                return new MessageAnalysisConfig(properties);
                            };
    
                            /**
                             * Encodes the specified MessageAnalysisConfig message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.MessageAnalysisConfig.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.MessageAnalysisConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.IMessageAnalysisConfig} message MessageAnalysisConfig message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            MessageAnalysisConfig.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.enableEntityExtraction != null && Object.hasOwnProperty.call(message, "enableEntityExtraction"))
                                    writer.uint32(/* id 2, wireType 0 =*/16).bool(message.enableEntityExtraction);
                                if (message.enableSentimentAnalysis != null && Object.hasOwnProperty.call(message, "enableSentimentAnalysis"))
                                    writer.uint32(/* id 3, wireType 0 =*/24).bool(message.enableSentimentAnalysis);
                                return writer;
                            };
    
                            /**
                             * Encodes the specified MessageAnalysisConfig message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.MessageAnalysisConfig.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.MessageAnalysisConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.IMessageAnalysisConfig} message MessageAnalysisConfig message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            MessageAnalysisConfig.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a MessageAnalysisConfig message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.MessageAnalysisConfig
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.MessageAnalysisConfig} MessageAnalysisConfig
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            MessageAnalysisConfig.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.MessageAnalysisConfig();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 2: {
                                            message.enableEntityExtraction = reader.bool();
                                            break;
                                        }
                                    case 3: {
                                            message.enableSentimentAnalysis = reader.bool();
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a MessageAnalysisConfig message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.MessageAnalysisConfig
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.MessageAnalysisConfig} MessageAnalysisConfig
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            MessageAnalysisConfig.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a MessageAnalysisConfig message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.MessageAnalysisConfig
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            MessageAnalysisConfig.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.enableEntityExtraction != null && message.hasOwnProperty("enableEntityExtraction"))
                                    if (typeof message.enableEntityExtraction !== "boolean")
                                        return "enableEntityExtraction: boolean expected";
                                if (message.enableSentimentAnalysis != null && message.hasOwnProperty("enableSentimentAnalysis"))
                                    if (typeof message.enableSentimentAnalysis !== "boolean")
                                        return "enableSentimentAnalysis: boolean expected";
                                return null;
                            };
    
                            /**
                             * Creates a MessageAnalysisConfig message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.MessageAnalysisConfig
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.MessageAnalysisConfig} MessageAnalysisConfig
                             */
                            MessageAnalysisConfig.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.MessageAnalysisConfig)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.MessageAnalysisConfig();
                                if (object.enableEntityExtraction != null)
                                    message.enableEntityExtraction = Boolean(object.enableEntityExtraction);
                                if (object.enableSentimentAnalysis != null)
                                    message.enableSentimentAnalysis = Boolean(object.enableSentimentAnalysis);
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a MessageAnalysisConfig message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.MessageAnalysisConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.MessageAnalysisConfig} message MessageAnalysisConfig
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            MessageAnalysisConfig.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.defaults) {
                                    object.enableEntityExtraction = false;
                                    object.enableSentimentAnalysis = false;
                                }
                                if (message.enableEntityExtraction != null && message.hasOwnProperty("enableEntityExtraction"))
                                    object.enableEntityExtraction = message.enableEntityExtraction;
                                if (message.enableSentimentAnalysis != null && message.hasOwnProperty("enableSentimentAnalysis"))
                                    object.enableSentimentAnalysis = message.enableSentimentAnalysis;
                                return object;
                            };
    
                            /**
                             * Converts this MessageAnalysisConfig to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.MessageAnalysisConfig
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            MessageAnalysisConfig.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for MessageAnalysisConfig
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.MessageAnalysisConfig
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            MessageAnalysisConfig.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.MessageAnalysisConfig";
                            };
    
                            return MessageAnalysisConfig;
                        })();
    
                        return HumanAgentAssistantConfig;
                    })();
    
                    v2beta1.HumanAgentHandoffConfig = (function() {
    
                        /**
                         * Properties of a HumanAgentHandoffConfig.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IHumanAgentHandoffConfig
                         * @property {google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.ILivePersonConfig|null} [livePersonConfig] HumanAgentHandoffConfig livePersonConfig
                         * @property {google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.ISalesforceLiveAgentConfig|null} [salesforceLiveAgentConfig] HumanAgentHandoffConfig salesforceLiveAgentConfig
                         */
    
                        /**
                         * Constructs a new HumanAgentHandoffConfig.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a HumanAgentHandoffConfig.
                         * @implements IHumanAgentHandoffConfig
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IHumanAgentHandoffConfig=} [properties] Properties to set
                         */
                        function HumanAgentHandoffConfig(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * HumanAgentHandoffConfig livePersonConfig.
                         * @member {google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.ILivePersonConfig|null|undefined} livePersonConfig
                         * @memberof google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig
                         * @instance
                         */
                        HumanAgentHandoffConfig.prototype.livePersonConfig = null;
    
                        /**
                         * HumanAgentHandoffConfig salesforceLiveAgentConfig.
                         * @member {google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.ISalesforceLiveAgentConfig|null|undefined} salesforceLiveAgentConfig
                         * @memberof google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig
                         * @instance
                         */
                        HumanAgentHandoffConfig.prototype.salesforceLiveAgentConfig = null;
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * HumanAgentHandoffConfig agentService.
                         * @member {"livePersonConfig"|"salesforceLiveAgentConfig"|undefined} agentService
                         * @memberof google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig
                         * @instance
                         */
                        Object.defineProperty(HumanAgentHandoffConfig.prototype, "agentService", {
                            get: $util.oneOfGetter($oneOfFields = ["livePersonConfig", "salesforceLiveAgentConfig"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new HumanAgentHandoffConfig instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IHumanAgentHandoffConfig=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig} HumanAgentHandoffConfig instance
                         */
                        HumanAgentHandoffConfig.create = function create(properties) {
                            return new HumanAgentHandoffConfig(properties);
                        };
    
                        /**
                         * Encodes the specified HumanAgentHandoffConfig message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IHumanAgentHandoffConfig} message HumanAgentHandoffConfig message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        HumanAgentHandoffConfig.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.livePersonConfig != null && Object.hasOwnProperty.call(message, "livePersonConfig"))
                                $root.google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.LivePersonConfig.encode(message.livePersonConfig, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.salesforceLiveAgentConfig != null && Object.hasOwnProperty.call(message, "salesforceLiveAgentConfig"))
                                $root.google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.SalesforceLiveAgentConfig.encode(message.salesforceLiveAgentConfig, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified HumanAgentHandoffConfig message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IHumanAgentHandoffConfig} message HumanAgentHandoffConfig message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        HumanAgentHandoffConfig.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a HumanAgentHandoffConfig message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig} HumanAgentHandoffConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        HumanAgentHandoffConfig.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.livePersonConfig = $root.google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.LivePersonConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.salesforceLiveAgentConfig = $root.google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.SalesforceLiveAgentConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a HumanAgentHandoffConfig message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig} HumanAgentHandoffConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        HumanAgentHandoffConfig.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a HumanAgentHandoffConfig message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        HumanAgentHandoffConfig.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.livePersonConfig != null && message.hasOwnProperty("livePersonConfig")) {
                                properties.agentService = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.LivePersonConfig.verify(message.livePersonConfig);
                                    if (error)
                                        return "livePersonConfig." + error;
                                }
                            }
                            if (message.salesforceLiveAgentConfig != null && message.hasOwnProperty("salesforceLiveAgentConfig")) {
                                if (properties.agentService === 1)
                                    return "agentService: multiple values";
                                properties.agentService = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.SalesforceLiveAgentConfig.verify(message.salesforceLiveAgentConfig);
                                    if (error)
                                        return "salesforceLiveAgentConfig." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates a HumanAgentHandoffConfig message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig} HumanAgentHandoffConfig
                         */
                        HumanAgentHandoffConfig.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig();
                            if (object.livePersonConfig != null) {
                                if (typeof object.livePersonConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.livePersonConfig: object expected");
                                message.livePersonConfig = $root.google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.LivePersonConfig.fromObject(object.livePersonConfig);
                            }
                            if (object.salesforceLiveAgentConfig != null) {
                                if (typeof object.salesforceLiveAgentConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.salesforceLiveAgentConfig: object expected");
                                message.salesforceLiveAgentConfig = $root.google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.SalesforceLiveAgentConfig.fromObject(object.salesforceLiveAgentConfig);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a HumanAgentHandoffConfig message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig} message HumanAgentHandoffConfig
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        HumanAgentHandoffConfig.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (message.livePersonConfig != null && message.hasOwnProperty("livePersonConfig")) {
                                object.livePersonConfig = $root.google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.LivePersonConfig.toObject(message.livePersonConfig, options);
                                if (options.oneofs)
                                    object.agentService = "livePersonConfig";
                            }
                            if (message.salesforceLiveAgentConfig != null && message.hasOwnProperty("salesforceLiveAgentConfig")) {
                                object.salesforceLiveAgentConfig = $root.google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.SalesforceLiveAgentConfig.toObject(message.salesforceLiveAgentConfig, options);
                                if (options.oneofs)
                                    object.agentService = "salesforceLiveAgentConfig";
                            }
                            return object;
                        };
    
                        /**
                         * Converts this HumanAgentHandoffConfig to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        HumanAgentHandoffConfig.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for HumanAgentHandoffConfig
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        HumanAgentHandoffConfig.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig";
                        };
    
                        HumanAgentHandoffConfig.LivePersonConfig = (function() {
    
                            /**
                             * Properties of a LivePersonConfig.
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig
                             * @interface ILivePersonConfig
                             * @property {string|null} [accountNumber] LivePersonConfig accountNumber
                             */
    
                            /**
                             * Constructs a new LivePersonConfig.
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig
                             * @classdesc Represents a LivePersonConfig.
                             * @implements ILivePersonConfig
                             * @constructor
                             * @param {google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.ILivePersonConfig=} [properties] Properties to set
                             */
                            function LivePersonConfig(properties) {
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * LivePersonConfig accountNumber.
                             * @member {string} accountNumber
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.LivePersonConfig
                             * @instance
                             */
                            LivePersonConfig.prototype.accountNumber = "";
    
                            /**
                             * Creates a new LivePersonConfig instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.LivePersonConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.ILivePersonConfig=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.LivePersonConfig} LivePersonConfig instance
                             */
                            LivePersonConfig.create = function create(properties) {
                                return new LivePersonConfig(properties);
                            };
    
                            /**
                             * Encodes the specified LivePersonConfig message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.LivePersonConfig.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.LivePersonConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.ILivePersonConfig} message LivePersonConfig message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            LivePersonConfig.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.accountNumber != null && Object.hasOwnProperty.call(message, "accountNumber"))
                                    writer.uint32(/* id 1, wireType 2 =*/10).string(message.accountNumber);
                                return writer;
                            };
    
                            /**
                             * Encodes the specified LivePersonConfig message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.LivePersonConfig.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.LivePersonConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.ILivePersonConfig} message LivePersonConfig message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            LivePersonConfig.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a LivePersonConfig message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.LivePersonConfig
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.LivePersonConfig} LivePersonConfig
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            LivePersonConfig.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.LivePersonConfig();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.accountNumber = reader.string();
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a LivePersonConfig message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.LivePersonConfig
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.LivePersonConfig} LivePersonConfig
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            LivePersonConfig.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a LivePersonConfig message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.LivePersonConfig
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            LivePersonConfig.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.accountNumber != null && message.hasOwnProperty("accountNumber"))
                                    if (!$util.isString(message.accountNumber))
                                        return "accountNumber: string expected";
                                return null;
                            };
    
                            /**
                             * Creates a LivePersonConfig message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.LivePersonConfig
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.LivePersonConfig} LivePersonConfig
                             */
                            LivePersonConfig.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.LivePersonConfig)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.LivePersonConfig();
                                if (object.accountNumber != null)
                                    message.accountNumber = String(object.accountNumber);
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a LivePersonConfig message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.LivePersonConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.LivePersonConfig} message LivePersonConfig
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            LivePersonConfig.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.defaults)
                                    object.accountNumber = "";
                                if (message.accountNumber != null && message.hasOwnProperty("accountNumber"))
                                    object.accountNumber = message.accountNumber;
                                return object;
                            };
    
                            /**
                             * Converts this LivePersonConfig to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.LivePersonConfig
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            LivePersonConfig.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for LivePersonConfig
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.LivePersonConfig
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            LivePersonConfig.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.LivePersonConfig";
                            };
    
                            return LivePersonConfig;
                        })();
    
                        HumanAgentHandoffConfig.SalesforceLiveAgentConfig = (function() {
    
                            /**
                             * Properties of a SalesforceLiveAgentConfig.
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig
                             * @interface ISalesforceLiveAgentConfig
                             * @property {string|null} [organizationId] SalesforceLiveAgentConfig organizationId
                             * @property {string|null} [deploymentId] SalesforceLiveAgentConfig deploymentId
                             * @property {string|null} [buttonId] SalesforceLiveAgentConfig buttonId
                             * @property {string|null} [endpointDomain] SalesforceLiveAgentConfig endpointDomain
                             */
    
                            /**
                             * Constructs a new SalesforceLiveAgentConfig.
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig
                             * @classdesc Represents a SalesforceLiveAgentConfig.
                             * @implements ISalesforceLiveAgentConfig
                             * @constructor
                             * @param {google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.ISalesforceLiveAgentConfig=} [properties] Properties to set
                             */
                            function SalesforceLiveAgentConfig(properties) {
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * SalesforceLiveAgentConfig organizationId.
                             * @member {string} organizationId
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.SalesforceLiveAgentConfig
                             * @instance
                             */
                            SalesforceLiveAgentConfig.prototype.organizationId = "";
    
                            /**
                             * SalesforceLiveAgentConfig deploymentId.
                             * @member {string} deploymentId
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.SalesforceLiveAgentConfig
                             * @instance
                             */
                            SalesforceLiveAgentConfig.prototype.deploymentId = "";
    
                            /**
                             * SalesforceLiveAgentConfig buttonId.
                             * @member {string} buttonId
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.SalesforceLiveAgentConfig
                             * @instance
                             */
                            SalesforceLiveAgentConfig.prototype.buttonId = "";
    
                            /**
                             * SalesforceLiveAgentConfig endpointDomain.
                             * @member {string} endpointDomain
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.SalesforceLiveAgentConfig
                             * @instance
                             */
                            SalesforceLiveAgentConfig.prototype.endpointDomain = "";
    
                            /**
                             * Creates a new SalesforceLiveAgentConfig instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.SalesforceLiveAgentConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.ISalesforceLiveAgentConfig=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.SalesforceLiveAgentConfig} SalesforceLiveAgentConfig instance
                             */
                            SalesforceLiveAgentConfig.create = function create(properties) {
                                return new SalesforceLiveAgentConfig(properties);
                            };
    
                            /**
                             * Encodes the specified SalesforceLiveAgentConfig message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.SalesforceLiveAgentConfig.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.SalesforceLiveAgentConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.ISalesforceLiveAgentConfig} message SalesforceLiveAgentConfig message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            SalesforceLiveAgentConfig.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.organizationId != null && Object.hasOwnProperty.call(message, "organizationId"))
                                    writer.uint32(/* id 1, wireType 2 =*/10).string(message.organizationId);
                                if (message.deploymentId != null && Object.hasOwnProperty.call(message, "deploymentId"))
                                    writer.uint32(/* id 2, wireType 2 =*/18).string(message.deploymentId);
                                if (message.buttonId != null && Object.hasOwnProperty.call(message, "buttonId"))
                                    writer.uint32(/* id 3, wireType 2 =*/26).string(message.buttonId);
                                if (message.endpointDomain != null && Object.hasOwnProperty.call(message, "endpointDomain"))
                                    writer.uint32(/* id 4, wireType 2 =*/34).string(message.endpointDomain);
                                return writer;
                            };
    
                            /**
                             * Encodes the specified SalesforceLiveAgentConfig message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.SalesforceLiveAgentConfig.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.SalesforceLiveAgentConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.ISalesforceLiveAgentConfig} message SalesforceLiveAgentConfig message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            SalesforceLiveAgentConfig.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a SalesforceLiveAgentConfig message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.SalesforceLiveAgentConfig
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.SalesforceLiveAgentConfig} SalesforceLiveAgentConfig
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            SalesforceLiveAgentConfig.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.SalesforceLiveAgentConfig();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.organizationId = reader.string();
                                            break;
                                        }
                                    case 2: {
                                            message.deploymentId = reader.string();
                                            break;
                                        }
                                    case 3: {
                                            message.buttonId = reader.string();
                                            break;
                                        }
                                    case 4: {
                                            message.endpointDomain = reader.string();
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a SalesforceLiveAgentConfig message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.SalesforceLiveAgentConfig
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.SalesforceLiveAgentConfig} SalesforceLiveAgentConfig
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            SalesforceLiveAgentConfig.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a SalesforceLiveAgentConfig message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.SalesforceLiveAgentConfig
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            SalesforceLiveAgentConfig.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.organizationId != null && message.hasOwnProperty("organizationId"))
                                    if (!$util.isString(message.organizationId))
                                        return "organizationId: string expected";
                                if (message.deploymentId != null && message.hasOwnProperty("deploymentId"))
                                    if (!$util.isString(message.deploymentId))
                                        return "deploymentId: string expected";
                                if (message.buttonId != null && message.hasOwnProperty("buttonId"))
                                    if (!$util.isString(message.buttonId))
                                        return "buttonId: string expected";
                                if (message.endpointDomain != null && message.hasOwnProperty("endpointDomain"))
                                    if (!$util.isString(message.endpointDomain))
                                        return "endpointDomain: string expected";
                                return null;
                            };
    
                            /**
                             * Creates a SalesforceLiveAgentConfig message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.SalesforceLiveAgentConfig
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.SalesforceLiveAgentConfig} SalesforceLiveAgentConfig
                             */
                            SalesforceLiveAgentConfig.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.SalesforceLiveAgentConfig)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.SalesforceLiveAgentConfig();
                                if (object.organizationId != null)
                                    message.organizationId = String(object.organizationId);
                                if (object.deploymentId != null)
                                    message.deploymentId = String(object.deploymentId);
                                if (object.buttonId != null)
                                    message.buttonId = String(object.buttonId);
                                if (object.endpointDomain != null)
                                    message.endpointDomain = String(object.endpointDomain);
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a SalesforceLiveAgentConfig message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.SalesforceLiveAgentConfig
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.SalesforceLiveAgentConfig} message SalesforceLiveAgentConfig
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            SalesforceLiveAgentConfig.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.defaults) {
                                    object.organizationId = "";
                                    object.deploymentId = "";
                                    object.buttonId = "";
                                    object.endpointDomain = "";
                                }
                                if (message.organizationId != null && message.hasOwnProperty("organizationId"))
                                    object.organizationId = message.organizationId;
                                if (message.deploymentId != null && message.hasOwnProperty("deploymentId"))
                                    object.deploymentId = message.deploymentId;
                                if (message.buttonId != null && message.hasOwnProperty("buttonId"))
                                    object.buttonId = message.buttonId;
                                if (message.endpointDomain != null && message.hasOwnProperty("endpointDomain"))
                                    object.endpointDomain = message.endpointDomain;
                                return object;
                            };
    
                            /**
                             * Converts this SalesforceLiveAgentConfig to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.SalesforceLiveAgentConfig
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            SalesforceLiveAgentConfig.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for SalesforceLiveAgentConfig
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.SalesforceLiveAgentConfig
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            SalesforceLiveAgentConfig.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.HumanAgentHandoffConfig.SalesforceLiveAgentConfig";
                            };
    
                            return SalesforceLiveAgentConfig;
                        })();
    
                        return HumanAgentHandoffConfig;
                    })();
    
                    v2beta1.NotificationConfig = (function() {
    
                        /**
                         * Properties of a NotificationConfig.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface INotificationConfig
                         * @property {string|null} [topic] NotificationConfig topic
                         * @property {google.cloud.dialogflow.v2beta1.NotificationConfig.MessageFormat|null} [messageFormat] NotificationConfig messageFormat
                         */
    
                        /**
                         * Constructs a new NotificationConfig.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a NotificationConfig.
                         * @implements INotificationConfig
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.INotificationConfig=} [properties] Properties to set
                         */
                        function NotificationConfig(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * NotificationConfig topic.
                         * @member {string} topic
                         * @memberof google.cloud.dialogflow.v2beta1.NotificationConfig
                         * @instance
                         */
                        NotificationConfig.prototype.topic = "";
    
                        /**
                         * NotificationConfig messageFormat.
                         * @member {google.cloud.dialogflow.v2beta1.NotificationConfig.MessageFormat} messageFormat
                         * @memberof google.cloud.dialogflow.v2beta1.NotificationConfig
                         * @instance
                         */
                        NotificationConfig.prototype.messageFormat = 0;
    
                        /**
                         * Creates a new NotificationConfig instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.NotificationConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.INotificationConfig=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.NotificationConfig} NotificationConfig instance
                         */
                        NotificationConfig.create = function create(properties) {
                            return new NotificationConfig(properties);
                        };
    
                        /**
                         * Encodes the specified NotificationConfig message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.NotificationConfig.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.NotificationConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.INotificationConfig} message NotificationConfig message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        NotificationConfig.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.topic != null && Object.hasOwnProperty.call(message, "topic"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.topic);
                            if (message.messageFormat != null && Object.hasOwnProperty.call(message, "messageFormat"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.messageFormat);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified NotificationConfig message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.NotificationConfig.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.NotificationConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.INotificationConfig} message NotificationConfig message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        NotificationConfig.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a NotificationConfig message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.NotificationConfig
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.NotificationConfig} NotificationConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        NotificationConfig.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.NotificationConfig();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.topic = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.messageFormat = reader.int32();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a NotificationConfig message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.NotificationConfig
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.NotificationConfig} NotificationConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        NotificationConfig.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a NotificationConfig message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.NotificationConfig
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        NotificationConfig.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.topic != null && message.hasOwnProperty("topic"))
                                if (!$util.isString(message.topic))
                                    return "topic: string expected";
                            if (message.messageFormat != null && message.hasOwnProperty("messageFormat"))
                                switch (message.messageFormat) {
                                default:
                                    return "messageFormat: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                    break;
                                }
                            return null;
                        };
    
                        /**
                         * Creates a NotificationConfig message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.NotificationConfig
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.NotificationConfig} NotificationConfig
                         */
                        NotificationConfig.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.NotificationConfig)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.NotificationConfig();
                            if (object.topic != null)
                                message.topic = String(object.topic);
                            switch (object.messageFormat) {
                            default:
                                if (typeof object.messageFormat === "number") {
                                    message.messageFormat = object.messageFormat;
                                    break;
                                }
                                break;
                            case "MESSAGE_FORMAT_UNSPECIFIED":
                            case 0:
                                message.messageFormat = 0;
                                break;
                            case "PROTO":
                            case 1:
                                message.messageFormat = 1;
                                break;
                            case "JSON":
                            case 2:
                                message.messageFormat = 2;
                                break;
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a NotificationConfig message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.NotificationConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.NotificationConfig} message NotificationConfig
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        NotificationConfig.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.topic = "";
                                object.messageFormat = options.enums === String ? "MESSAGE_FORMAT_UNSPECIFIED" : 0;
                            }
                            if (message.topic != null && message.hasOwnProperty("topic"))
                                object.topic = message.topic;
                            if (message.messageFormat != null && message.hasOwnProperty("messageFormat"))
                                object.messageFormat = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.NotificationConfig.MessageFormat[message.messageFormat] === undefined ? message.messageFormat : $root.google.cloud.dialogflow.v2beta1.NotificationConfig.MessageFormat[message.messageFormat] : message.messageFormat;
                            return object;
                        };
    
                        /**
                         * Converts this NotificationConfig to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.NotificationConfig
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        NotificationConfig.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for NotificationConfig
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.NotificationConfig
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        NotificationConfig.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.NotificationConfig";
                        };
    
                        /**
                         * MessageFormat enum.
                         * @name google.cloud.dialogflow.v2beta1.NotificationConfig.MessageFormat
                         * @enum {number}
                         * @property {number} MESSAGE_FORMAT_UNSPECIFIED=0 MESSAGE_FORMAT_UNSPECIFIED value
                         * @property {number} PROTO=1 PROTO value
                         * @property {number} JSON=2 JSON value
                         */
                        NotificationConfig.MessageFormat = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "MESSAGE_FORMAT_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "PROTO"] = 1;
                            values[valuesById[2] = "JSON"] = 2;
                            return values;
                        })();
    
                        return NotificationConfig;
                    })();
    
                    v2beta1.LoggingConfig = (function() {
    
                        /**
                         * Properties of a LoggingConfig.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ILoggingConfig
                         * @property {boolean|null} [enableStackdriverLogging] LoggingConfig enableStackdriverLogging
                         */
    
                        /**
                         * Constructs a new LoggingConfig.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a LoggingConfig.
                         * @implements ILoggingConfig
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ILoggingConfig=} [properties] Properties to set
                         */
                        function LoggingConfig(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * LoggingConfig enableStackdriverLogging.
                         * @member {boolean} enableStackdriverLogging
                         * @memberof google.cloud.dialogflow.v2beta1.LoggingConfig
                         * @instance
                         */
                        LoggingConfig.prototype.enableStackdriverLogging = false;
    
                        /**
                         * Creates a new LoggingConfig instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.LoggingConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ILoggingConfig=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.LoggingConfig} LoggingConfig instance
                         */
                        LoggingConfig.create = function create(properties) {
                            return new LoggingConfig(properties);
                        };
    
                        /**
                         * Encodes the specified LoggingConfig message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.LoggingConfig.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.LoggingConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ILoggingConfig} message LoggingConfig message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        LoggingConfig.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.enableStackdriverLogging != null && Object.hasOwnProperty.call(message, "enableStackdriverLogging"))
                                writer.uint32(/* id 3, wireType 0 =*/24).bool(message.enableStackdriverLogging);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified LoggingConfig message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.LoggingConfig.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.LoggingConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ILoggingConfig} message LoggingConfig message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        LoggingConfig.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a LoggingConfig message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.LoggingConfig
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.LoggingConfig} LoggingConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        LoggingConfig.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.LoggingConfig();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 3: {
                                        message.enableStackdriverLogging = reader.bool();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a LoggingConfig message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.LoggingConfig
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.LoggingConfig} LoggingConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        LoggingConfig.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a LoggingConfig message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.LoggingConfig
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        LoggingConfig.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.enableStackdriverLogging != null && message.hasOwnProperty("enableStackdriverLogging"))
                                if (typeof message.enableStackdriverLogging !== "boolean")
                                    return "enableStackdriverLogging: boolean expected";
                            return null;
                        };
    
                        /**
                         * Creates a LoggingConfig message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.LoggingConfig
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.LoggingConfig} LoggingConfig
                         */
                        LoggingConfig.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.LoggingConfig)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.LoggingConfig();
                            if (object.enableStackdriverLogging != null)
                                message.enableStackdriverLogging = Boolean(object.enableStackdriverLogging);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a LoggingConfig message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.LoggingConfig
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.LoggingConfig} message LoggingConfig
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        LoggingConfig.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.enableStackdriverLogging = false;
                            if (message.enableStackdriverLogging != null && message.hasOwnProperty("enableStackdriverLogging"))
                                object.enableStackdriverLogging = message.enableStackdriverLogging;
                            return object;
                        };
    
                        /**
                         * Converts this LoggingConfig to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.LoggingConfig
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        LoggingConfig.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for LoggingConfig
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.LoggingConfig
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        LoggingConfig.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.LoggingConfig";
                        };
    
                        return LoggingConfig;
                    })();
    
                    v2beta1.ListConversationProfilesRequest = (function() {
    
                        /**
                         * Properties of a ListConversationProfilesRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IListConversationProfilesRequest
                         * @property {string|null} [parent] ListConversationProfilesRequest parent
                         * @property {number|null} [pageSize] ListConversationProfilesRequest pageSize
                         * @property {string|null} [pageToken] ListConversationProfilesRequest pageToken
                         */
    
                        /**
                         * Constructs a new ListConversationProfilesRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a ListConversationProfilesRequest.
                         * @implements IListConversationProfilesRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IListConversationProfilesRequest=} [properties] Properties to set
                         */
                        function ListConversationProfilesRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListConversationProfilesRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.ListConversationProfilesRequest
                         * @instance
                         */
                        ListConversationProfilesRequest.prototype.parent = "";
    
                        /**
                         * ListConversationProfilesRequest pageSize.
                         * @member {number} pageSize
                         * @memberof google.cloud.dialogflow.v2beta1.ListConversationProfilesRequest
                         * @instance
                         */
                        ListConversationProfilesRequest.prototype.pageSize = 0;
    
                        /**
                         * ListConversationProfilesRequest pageToken.
                         * @member {string} pageToken
                         * @memberof google.cloud.dialogflow.v2beta1.ListConversationProfilesRequest
                         * @instance
                         */
                        ListConversationProfilesRequest.prototype.pageToken = "";
    
                        /**
                         * Creates a new ListConversationProfilesRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.ListConversationProfilesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListConversationProfilesRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.ListConversationProfilesRequest} ListConversationProfilesRequest instance
                         */
                        ListConversationProfilesRequest.create = function create(properties) {
                            return new ListConversationProfilesRequest(properties);
                        };
    
                        /**
                         * Encodes the specified ListConversationProfilesRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListConversationProfilesRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.ListConversationProfilesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListConversationProfilesRequest} message ListConversationProfilesRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListConversationProfilesRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.pageSize != null && Object.hasOwnProperty.call(message, "pageSize"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.pageSize);
                            if (message.pageToken != null && Object.hasOwnProperty.call(message, "pageToken"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.pageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListConversationProfilesRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListConversationProfilesRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListConversationProfilesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListConversationProfilesRequest} message ListConversationProfilesRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListConversationProfilesRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListConversationProfilesRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.ListConversationProfilesRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.ListConversationProfilesRequest} ListConversationProfilesRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListConversationProfilesRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ListConversationProfilesRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.pageSize = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.pageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListConversationProfilesRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListConversationProfilesRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.ListConversationProfilesRequest} ListConversationProfilesRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListConversationProfilesRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListConversationProfilesRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.ListConversationProfilesRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListConversationProfilesRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                if (!$util.isInteger(message.pageSize))
                                    return "pageSize: integer expected";
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                if (!$util.isString(message.pageToken))
                                    return "pageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListConversationProfilesRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListConversationProfilesRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.ListConversationProfilesRequest} ListConversationProfilesRequest
                         */
                        ListConversationProfilesRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.ListConversationProfilesRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.ListConversationProfilesRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.pageSize != null)
                                message.pageSize = object.pageSize | 0;
                            if (object.pageToken != null)
                                message.pageToken = String(object.pageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListConversationProfilesRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListConversationProfilesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ListConversationProfilesRequest} message ListConversationProfilesRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListConversationProfilesRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.pageSize = 0;
                                object.pageToken = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                object.pageSize = message.pageSize;
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                object.pageToken = message.pageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListConversationProfilesRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.ListConversationProfilesRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListConversationProfilesRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListConversationProfilesRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.ListConversationProfilesRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListConversationProfilesRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ListConversationProfilesRequest";
                        };
    
                        return ListConversationProfilesRequest;
                    })();
    
                    v2beta1.ListConversationProfilesResponse = (function() {
    
                        /**
                         * Properties of a ListConversationProfilesResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IListConversationProfilesResponse
                         * @property {Array.<google.cloud.dialogflow.v2beta1.IConversationProfile>|null} [conversationProfiles] ListConversationProfilesResponse conversationProfiles
                         * @property {string|null} [nextPageToken] ListConversationProfilesResponse nextPageToken
                         */
    
                        /**
                         * Constructs a new ListConversationProfilesResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a ListConversationProfilesResponse.
                         * @implements IListConversationProfilesResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IListConversationProfilesResponse=} [properties] Properties to set
                         */
                        function ListConversationProfilesResponse(properties) {
                            this.conversationProfiles = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListConversationProfilesResponse conversationProfiles.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.IConversationProfile>} conversationProfiles
                         * @memberof google.cloud.dialogflow.v2beta1.ListConversationProfilesResponse
                         * @instance
                         */
                        ListConversationProfilesResponse.prototype.conversationProfiles = $util.emptyArray;
    
                        /**
                         * ListConversationProfilesResponse nextPageToken.
                         * @member {string} nextPageToken
                         * @memberof google.cloud.dialogflow.v2beta1.ListConversationProfilesResponse
                         * @instance
                         */
                        ListConversationProfilesResponse.prototype.nextPageToken = "";
    
                        /**
                         * Creates a new ListConversationProfilesResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.ListConversationProfilesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListConversationProfilesResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.ListConversationProfilesResponse} ListConversationProfilesResponse instance
                         */
                        ListConversationProfilesResponse.create = function create(properties) {
                            return new ListConversationProfilesResponse(properties);
                        };
    
                        /**
                         * Encodes the specified ListConversationProfilesResponse message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListConversationProfilesResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.ListConversationProfilesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListConversationProfilesResponse} message ListConversationProfilesResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListConversationProfilesResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.conversationProfiles != null && message.conversationProfiles.length)
                                for (var i = 0; i < message.conversationProfiles.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.ConversationProfile.encode(message.conversationProfiles[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.nextPageToken != null && Object.hasOwnProperty.call(message, "nextPageToken"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.nextPageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListConversationProfilesResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListConversationProfilesResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListConversationProfilesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListConversationProfilesResponse} message ListConversationProfilesResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListConversationProfilesResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListConversationProfilesResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.ListConversationProfilesResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.ListConversationProfilesResponse} ListConversationProfilesResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListConversationProfilesResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ListConversationProfilesResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.conversationProfiles && message.conversationProfiles.length))
                                            message.conversationProfiles = [];
                                        message.conversationProfiles.push($root.google.cloud.dialogflow.v2beta1.ConversationProfile.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 2: {
                                        message.nextPageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListConversationProfilesResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListConversationProfilesResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.ListConversationProfilesResponse} ListConversationProfilesResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListConversationProfilesResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListConversationProfilesResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.ListConversationProfilesResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListConversationProfilesResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.conversationProfiles != null && message.hasOwnProperty("conversationProfiles")) {
                                if (!Array.isArray(message.conversationProfiles))
                                    return "conversationProfiles: array expected";
                                for (var i = 0; i < message.conversationProfiles.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.ConversationProfile.verify(message.conversationProfiles[i]);
                                    if (error)
                                        return "conversationProfiles." + error;
                                }
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                if (!$util.isString(message.nextPageToken))
                                    return "nextPageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListConversationProfilesResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListConversationProfilesResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.ListConversationProfilesResponse} ListConversationProfilesResponse
                         */
                        ListConversationProfilesResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.ListConversationProfilesResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.ListConversationProfilesResponse();
                            if (object.conversationProfiles) {
                                if (!Array.isArray(object.conversationProfiles))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.ListConversationProfilesResponse.conversationProfiles: array expected");
                                message.conversationProfiles = [];
                                for (var i = 0; i < object.conversationProfiles.length; ++i) {
                                    if (typeof object.conversationProfiles[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.ListConversationProfilesResponse.conversationProfiles: object expected");
                                    message.conversationProfiles[i] = $root.google.cloud.dialogflow.v2beta1.ConversationProfile.fromObject(object.conversationProfiles[i]);
                                }
                            }
                            if (object.nextPageToken != null)
                                message.nextPageToken = String(object.nextPageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListConversationProfilesResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListConversationProfilesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ListConversationProfilesResponse} message ListConversationProfilesResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListConversationProfilesResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.conversationProfiles = [];
                            if (options.defaults)
                                object.nextPageToken = "";
                            if (message.conversationProfiles && message.conversationProfiles.length) {
                                object.conversationProfiles = [];
                                for (var j = 0; j < message.conversationProfiles.length; ++j)
                                    object.conversationProfiles[j] = $root.google.cloud.dialogflow.v2beta1.ConversationProfile.toObject(message.conversationProfiles[j], options);
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                object.nextPageToken = message.nextPageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListConversationProfilesResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.ListConversationProfilesResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListConversationProfilesResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListConversationProfilesResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.ListConversationProfilesResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListConversationProfilesResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ListConversationProfilesResponse";
                        };
    
                        return ListConversationProfilesResponse;
                    })();
    
                    v2beta1.GetConversationProfileRequest = (function() {
    
                        /**
                         * Properties of a GetConversationProfileRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IGetConversationProfileRequest
                         * @property {string|null} [name] GetConversationProfileRequest name
                         */
    
                        /**
                         * Constructs a new GetConversationProfileRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a GetConversationProfileRequest.
                         * @implements IGetConversationProfileRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IGetConversationProfileRequest=} [properties] Properties to set
                         */
                        function GetConversationProfileRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GetConversationProfileRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2beta1.GetConversationProfileRequest
                         * @instance
                         */
                        GetConversationProfileRequest.prototype.name = "";
    
                        /**
                         * Creates a new GetConversationProfileRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.GetConversationProfileRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetConversationProfileRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.GetConversationProfileRequest} GetConversationProfileRequest instance
                         */
                        GetConversationProfileRequest.create = function create(properties) {
                            return new GetConversationProfileRequest(properties);
                        };
    
                        /**
                         * Encodes the specified GetConversationProfileRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GetConversationProfileRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.GetConversationProfileRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetConversationProfileRequest} message GetConversationProfileRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetConversationProfileRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GetConversationProfileRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GetConversationProfileRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GetConversationProfileRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetConversationProfileRequest} message GetConversationProfileRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetConversationProfileRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GetConversationProfileRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.GetConversationProfileRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.GetConversationProfileRequest} GetConversationProfileRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetConversationProfileRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.GetConversationProfileRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GetConversationProfileRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GetConversationProfileRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.GetConversationProfileRequest} GetConversationProfileRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetConversationProfileRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GetConversationProfileRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.GetConversationProfileRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GetConversationProfileRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a GetConversationProfileRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.GetConversationProfileRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.GetConversationProfileRequest} GetConversationProfileRequest
                         */
                        GetConversationProfileRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.GetConversationProfileRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.GetConversationProfileRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GetConversationProfileRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.GetConversationProfileRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.GetConversationProfileRequest} message GetConversationProfileRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GetConversationProfileRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.name = "";
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            return object;
                        };
    
                        /**
                         * Converts this GetConversationProfileRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.GetConversationProfileRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GetConversationProfileRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GetConversationProfileRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.GetConversationProfileRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GetConversationProfileRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.GetConversationProfileRequest";
                        };
    
                        return GetConversationProfileRequest;
                    })();
    
                    v2beta1.CreateConversationProfileRequest = (function() {
    
                        /**
                         * Properties of a CreateConversationProfileRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ICreateConversationProfileRequest
                         * @property {string|null} [parent] CreateConversationProfileRequest parent
                         * @property {google.cloud.dialogflow.v2beta1.IConversationProfile|null} [conversationProfile] CreateConversationProfileRequest conversationProfile
                         */
    
                        /**
                         * Constructs a new CreateConversationProfileRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a CreateConversationProfileRequest.
                         * @implements ICreateConversationProfileRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ICreateConversationProfileRequest=} [properties] Properties to set
                         */
                        function CreateConversationProfileRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * CreateConversationProfileRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.CreateConversationProfileRequest
                         * @instance
                         */
                        CreateConversationProfileRequest.prototype.parent = "";
    
                        /**
                         * CreateConversationProfileRequest conversationProfile.
                         * @member {google.cloud.dialogflow.v2beta1.IConversationProfile|null|undefined} conversationProfile
                         * @memberof google.cloud.dialogflow.v2beta1.CreateConversationProfileRequest
                         * @instance
                         */
                        CreateConversationProfileRequest.prototype.conversationProfile = null;
    
                        /**
                         * Creates a new CreateConversationProfileRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.CreateConversationProfileRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ICreateConversationProfileRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.CreateConversationProfileRequest} CreateConversationProfileRequest instance
                         */
                        CreateConversationProfileRequest.create = function create(properties) {
                            return new CreateConversationProfileRequest(properties);
                        };
    
                        /**
                         * Encodes the specified CreateConversationProfileRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.CreateConversationProfileRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.CreateConversationProfileRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ICreateConversationProfileRequest} message CreateConversationProfileRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateConversationProfileRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.conversationProfile != null && Object.hasOwnProperty.call(message, "conversationProfile"))
                                $root.google.cloud.dialogflow.v2beta1.ConversationProfile.encode(message.conversationProfile, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified CreateConversationProfileRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.CreateConversationProfileRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.CreateConversationProfileRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ICreateConversationProfileRequest} message CreateConversationProfileRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateConversationProfileRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a CreateConversationProfileRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.CreateConversationProfileRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.CreateConversationProfileRequest} CreateConversationProfileRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateConversationProfileRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.CreateConversationProfileRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.conversationProfile = $root.google.cloud.dialogflow.v2beta1.ConversationProfile.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a CreateConversationProfileRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.CreateConversationProfileRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.CreateConversationProfileRequest} CreateConversationProfileRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateConversationProfileRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a CreateConversationProfileRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.CreateConversationProfileRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        CreateConversationProfileRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.conversationProfile != null && message.hasOwnProperty("conversationProfile")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.ConversationProfile.verify(message.conversationProfile);
                                if (error)
                                    return "conversationProfile." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a CreateConversationProfileRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.CreateConversationProfileRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.CreateConversationProfileRequest} CreateConversationProfileRequest
                         */
                        CreateConversationProfileRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.CreateConversationProfileRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.CreateConversationProfileRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.conversationProfile != null) {
                                if (typeof object.conversationProfile !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.CreateConversationProfileRequest.conversationProfile: object expected");
                                message.conversationProfile = $root.google.cloud.dialogflow.v2beta1.ConversationProfile.fromObject(object.conversationProfile);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a CreateConversationProfileRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.CreateConversationProfileRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.CreateConversationProfileRequest} message CreateConversationProfileRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        CreateConversationProfileRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.conversationProfile = null;
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.conversationProfile != null && message.hasOwnProperty("conversationProfile"))
                                object.conversationProfile = $root.google.cloud.dialogflow.v2beta1.ConversationProfile.toObject(message.conversationProfile, options);
                            return object;
                        };
    
                        /**
                         * Converts this CreateConversationProfileRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.CreateConversationProfileRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        CreateConversationProfileRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for CreateConversationProfileRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.CreateConversationProfileRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        CreateConversationProfileRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.CreateConversationProfileRequest";
                        };
    
                        return CreateConversationProfileRequest;
                    })();
    
                    v2beta1.UpdateConversationProfileRequest = (function() {
    
                        /**
                         * Properties of an UpdateConversationProfileRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IUpdateConversationProfileRequest
                         * @property {google.cloud.dialogflow.v2beta1.IConversationProfile|null} [conversationProfile] UpdateConversationProfileRequest conversationProfile
                         * @property {google.protobuf.IFieldMask|null} [updateMask] UpdateConversationProfileRequest updateMask
                         */
    
                        /**
                         * Constructs a new UpdateConversationProfileRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an UpdateConversationProfileRequest.
                         * @implements IUpdateConversationProfileRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateConversationProfileRequest=} [properties] Properties to set
                         */
                        function UpdateConversationProfileRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * UpdateConversationProfileRequest conversationProfile.
                         * @member {google.cloud.dialogflow.v2beta1.IConversationProfile|null|undefined} conversationProfile
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateConversationProfileRequest
                         * @instance
                         */
                        UpdateConversationProfileRequest.prototype.conversationProfile = null;
    
                        /**
                         * UpdateConversationProfileRequest updateMask.
                         * @member {google.protobuf.IFieldMask|null|undefined} updateMask
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateConversationProfileRequest
                         * @instance
                         */
                        UpdateConversationProfileRequest.prototype.updateMask = null;
    
                        /**
                         * Creates a new UpdateConversationProfileRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateConversationProfileRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateConversationProfileRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.UpdateConversationProfileRequest} UpdateConversationProfileRequest instance
                         */
                        UpdateConversationProfileRequest.create = function create(properties) {
                            return new UpdateConversationProfileRequest(properties);
                        };
    
                        /**
                         * Encodes the specified UpdateConversationProfileRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.UpdateConversationProfileRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateConversationProfileRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateConversationProfileRequest} message UpdateConversationProfileRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UpdateConversationProfileRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.conversationProfile != null && Object.hasOwnProperty.call(message, "conversationProfile"))
                                $root.google.cloud.dialogflow.v2beta1.ConversationProfile.encode(message.conversationProfile, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.updateMask != null && Object.hasOwnProperty.call(message, "updateMask"))
                                $root.google.protobuf.FieldMask.encode(message.updateMask, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified UpdateConversationProfileRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.UpdateConversationProfileRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateConversationProfileRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateConversationProfileRequest} message UpdateConversationProfileRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UpdateConversationProfileRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an UpdateConversationProfileRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateConversationProfileRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.UpdateConversationProfileRequest} UpdateConversationProfileRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UpdateConversationProfileRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.UpdateConversationProfileRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.conversationProfile = $root.google.cloud.dialogflow.v2beta1.ConversationProfile.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.updateMask = $root.google.protobuf.FieldMask.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an UpdateConversationProfileRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateConversationProfileRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.UpdateConversationProfileRequest} UpdateConversationProfileRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UpdateConversationProfileRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an UpdateConversationProfileRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateConversationProfileRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        UpdateConversationProfileRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.conversationProfile != null && message.hasOwnProperty("conversationProfile")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.ConversationProfile.verify(message.conversationProfile);
                                if (error)
                                    return "conversationProfile." + error;
                            }
                            if (message.updateMask != null && message.hasOwnProperty("updateMask")) {
                                var error = $root.google.protobuf.FieldMask.verify(message.updateMask);
                                if (error)
                                    return "updateMask." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates an UpdateConversationProfileRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateConversationProfileRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.UpdateConversationProfileRequest} UpdateConversationProfileRequest
                         */
                        UpdateConversationProfileRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.UpdateConversationProfileRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.UpdateConversationProfileRequest();
                            if (object.conversationProfile != null) {
                                if (typeof object.conversationProfile !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.UpdateConversationProfileRequest.conversationProfile: object expected");
                                message.conversationProfile = $root.google.cloud.dialogflow.v2beta1.ConversationProfile.fromObject(object.conversationProfile);
                            }
                            if (object.updateMask != null) {
                                if (typeof object.updateMask !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.UpdateConversationProfileRequest.updateMask: object expected");
                                message.updateMask = $root.google.protobuf.FieldMask.fromObject(object.updateMask);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an UpdateConversationProfileRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateConversationProfileRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.UpdateConversationProfileRequest} message UpdateConversationProfileRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        UpdateConversationProfileRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.conversationProfile = null;
                                object.updateMask = null;
                            }
                            if (message.conversationProfile != null && message.hasOwnProperty("conversationProfile"))
                                object.conversationProfile = $root.google.cloud.dialogflow.v2beta1.ConversationProfile.toObject(message.conversationProfile, options);
                            if (message.updateMask != null && message.hasOwnProperty("updateMask"))
                                object.updateMask = $root.google.protobuf.FieldMask.toObject(message.updateMask, options);
                            return object;
                        };
    
                        /**
                         * Converts this UpdateConversationProfileRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateConversationProfileRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        UpdateConversationProfileRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for UpdateConversationProfileRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateConversationProfileRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        UpdateConversationProfileRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.UpdateConversationProfileRequest";
                        };
    
                        return UpdateConversationProfileRequest;
                    })();
    
                    v2beta1.DeleteConversationProfileRequest = (function() {
    
                        /**
                         * Properties of a DeleteConversationProfileRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IDeleteConversationProfileRequest
                         * @property {string|null} [name] DeleteConversationProfileRequest name
                         */
    
                        /**
                         * Constructs a new DeleteConversationProfileRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a DeleteConversationProfileRequest.
                         * @implements IDeleteConversationProfileRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteConversationProfileRequest=} [properties] Properties to set
                         */
                        function DeleteConversationProfileRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * DeleteConversationProfileRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteConversationProfileRequest
                         * @instance
                         */
                        DeleteConversationProfileRequest.prototype.name = "";
    
                        /**
                         * Creates a new DeleteConversationProfileRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteConversationProfileRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteConversationProfileRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.DeleteConversationProfileRequest} DeleteConversationProfileRequest instance
                         */
                        DeleteConversationProfileRequest.create = function create(properties) {
                            return new DeleteConversationProfileRequest(properties);
                        };
    
                        /**
                         * Encodes the specified DeleteConversationProfileRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.DeleteConversationProfileRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteConversationProfileRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteConversationProfileRequest} message DeleteConversationProfileRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteConversationProfileRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified DeleteConversationProfileRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.DeleteConversationProfileRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteConversationProfileRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteConversationProfileRequest} message DeleteConversationProfileRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteConversationProfileRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a DeleteConversationProfileRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteConversationProfileRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.DeleteConversationProfileRequest} DeleteConversationProfileRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteConversationProfileRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.DeleteConversationProfileRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a DeleteConversationProfileRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteConversationProfileRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.DeleteConversationProfileRequest} DeleteConversationProfileRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteConversationProfileRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a DeleteConversationProfileRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteConversationProfileRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        DeleteConversationProfileRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a DeleteConversationProfileRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteConversationProfileRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.DeleteConversationProfileRequest} DeleteConversationProfileRequest
                         */
                        DeleteConversationProfileRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.DeleteConversationProfileRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.DeleteConversationProfileRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a DeleteConversationProfileRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteConversationProfileRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.DeleteConversationProfileRequest} message DeleteConversationProfileRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        DeleteConversationProfileRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.name = "";
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            return object;
                        };
    
                        /**
                         * Converts this DeleteConversationProfileRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteConversationProfileRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        DeleteConversationProfileRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for DeleteConversationProfileRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteConversationProfileRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        DeleteConversationProfileRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.DeleteConversationProfileRequest";
                        };
    
                        return DeleteConversationProfileRequest;
                    })();
    
                    v2beta1.SetSuggestionFeatureConfigRequest = (function() {
    
                        /**
                         * Properties of a SetSuggestionFeatureConfigRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ISetSuggestionFeatureConfigRequest
                         * @property {string|null} [conversationProfile] SetSuggestionFeatureConfigRequest conversationProfile
                         * @property {google.cloud.dialogflow.v2beta1.Participant.Role|null} [participantRole] SetSuggestionFeatureConfigRequest participantRole
                         * @property {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ISuggestionFeatureConfig|null} [suggestionFeatureConfig] SetSuggestionFeatureConfigRequest suggestionFeatureConfig
                         */
    
                        /**
                         * Constructs a new SetSuggestionFeatureConfigRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a SetSuggestionFeatureConfigRequest.
                         * @implements ISetSuggestionFeatureConfigRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ISetSuggestionFeatureConfigRequest=} [properties] Properties to set
                         */
                        function SetSuggestionFeatureConfigRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SetSuggestionFeatureConfigRequest conversationProfile.
                         * @member {string} conversationProfile
                         * @memberof google.cloud.dialogflow.v2beta1.SetSuggestionFeatureConfigRequest
                         * @instance
                         */
                        SetSuggestionFeatureConfigRequest.prototype.conversationProfile = "";
    
                        /**
                         * SetSuggestionFeatureConfigRequest participantRole.
                         * @member {google.cloud.dialogflow.v2beta1.Participant.Role} participantRole
                         * @memberof google.cloud.dialogflow.v2beta1.SetSuggestionFeatureConfigRequest
                         * @instance
                         */
                        SetSuggestionFeatureConfigRequest.prototype.participantRole = 0;
    
                        /**
                         * SetSuggestionFeatureConfigRequest suggestionFeatureConfig.
                         * @member {google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.ISuggestionFeatureConfig|null|undefined} suggestionFeatureConfig
                         * @memberof google.cloud.dialogflow.v2beta1.SetSuggestionFeatureConfigRequest
                         * @instance
                         */
                        SetSuggestionFeatureConfigRequest.prototype.suggestionFeatureConfig = null;
    
                        /**
                         * Creates a new SetSuggestionFeatureConfigRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.SetSuggestionFeatureConfigRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISetSuggestionFeatureConfigRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.SetSuggestionFeatureConfigRequest} SetSuggestionFeatureConfigRequest instance
                         */
                        SetSuggestionFeatureConfigRequest.create = function create(properties) {
                            return new SetSuggestionFeatureConfigRequest(properties);
                        };
    
                        /**
                         * Encodes the specified SetSuggestionFeatureConfigRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SetSuggestionFeatureConfigRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.SetSuggestionFeatureConfigRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISetSuggestionFeatureConfigRequest} message SetSuggestionFeatureConfigRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SetSuggestionFeatureConfigRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.conversationProfile != null && Object.hasOwnProperty.call(message, "conversationProfile"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.conversationProfile);
                            if (message.participantRole != null && Object.hasOwnProperty.call(message, "participantRole"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.participantRole);
                            if (message.suggestionFeatureConfig != null && Object.hasOwnProperty.call(message, "suggestionFeatureConfig"))
                                $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionFeatureConfig.encode(message.suggestionFeatureConfig, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SetSuggestionFeatureConfigRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SetSuggestionFeatureConfigRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SetSuggestionFeatureConfigRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISetSuggestionFeatureConfigRequest} message SetSuggestionFeatureConfigRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SetSuggestionFeatureConfigRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SetSuggestionFeatureConfigRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.SetSuggestionFeatureConfigRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.SetSuggestionFeatureConfigRequest} SetSuggestionFeatureConfigRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SetSuggestionFeatureConfigRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.SetSuggestionFeatureConfigRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.conversationProfile = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.participantRole = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.suggestionFeatureConfig = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionFeatureConfig.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SetSuggestionFeatureConfigRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SetSuggestionFeatureConfigRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.SetSuggestionFeatureConfigRequest} SetSuggestionFeatureConfigRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SetSuggestionFeatureConfigRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SetSuggestionFeatureConfigRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.SetSuggestionFeatureConfigRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SetSuggestionFeatureConfigRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.conversationProfile != null && message.hasOwnProperty("conversationProfile"))
                                if (!$util.isString(message.conversationProfile))
                                    return "conversationProfile: string expected";
                            if (message.participantRole != null && message.hasOwnProperty("participantRole"))
                                switch (message.participantRole) {
                                default:
                                    return "participantRole: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                    break;
                                }
                            if (message.suggestionFeatureConfig != null && message.hasOwnProperty("suggestionFeatureConfig")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionFeatureConfig.verify(message.suggestionFeatureConfig);
                                if (error)
                                    return "suggestionFeatureConfig." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a SetSuggestionFeatureConfigRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.SetSuggestionFeatureConfigRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.SetSuggestionFeatureConfigRequest} SetSuggestionFeatureConfigRequest
                         */
                        SetSuggestionFeatureConfigRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.SetSuggestionFeatureConfigRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.SetSuggestionFeatureConfigRequest();
                            if (object.conversationProfile != null)
                                message.conversationProfile = String(object.conversationProfile);
                            switch (object.participantRole) {
                            default:
                                if (typeof object.participantRole === "number") {
                                    message.participantRole = object.participantRole;
                                    break;
                                }
                                break;
                            case "ROLE_UNSPECIFIED":
                            case 0:
                                message.participantRole = 0;
                                break;
                            case "HUMAN_AGENT":
                            case 1:
                                message.participantRole = 1;
                                break;
                            case "AUTOMATED_AGENT":
                            case 2:
                                message.participantRole = 2;
                                break;
                            case "END_USER":
                            case 3:
                                message.participantRole = 3;
                                break;
                            }
                            if (object.suggestionFeatureConfig != null) {
                                if (typeof object.suggestionFeatureConfig !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.SetSuggestionFeatureConfigRequest.suggestionFeatureConfig: object expected");
                                message.suggestionFeatureConfig = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionFeatureConfig.fromObject(object.suggestionFeatureConfig);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SetSuggestionFeatureConfigRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.SetSuggestionFeatureConfigRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.SetSuggestionFeatureConfigRequest} message SetSuggestionFeatureConfigRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SetSuggestionFeatureConfigRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.conversationProfile = "";
                                object.participantRole = options.enums === String ? "ROLE_UNSPECIFIED" : 0;
                                object.suggestionFeatureConfig = null;
                            }
                            if (message.conversationProfile != null && message.hasOwnProperty("conversationProfile"))
                                object.conversationProfile = message.conversationProfile;
                            if (message.participantRole != null && message.hasOwnProperty("participantRole"))
                                object.participantRole = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.Participant.Role[message.participantRole] === undefined ? message.participantRole : $root.google.cloud.dialogflow.v2beta1.Participant.Role[message.participantRole] : message.participantRole;
                            if (message.suggestionFeatureConfig != null && message.hasOwnProperty("suggestionFeatureConfig"))
                                object.suggestionFeatureConfig = $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantConfig.SuggestionFeatureConfig.toObject(message.suggestionFeatureConfig, options);
                            return object;
                        };
    
                        /**
                         * Converts this SetSuggestionFeatureConfigRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.SetSuggestionFeatureConfigRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SetSuggestionFeatureConfigRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SetSuggestionFeatureConfigRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.SetSuggestionFeatureConfigRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SetSuggestionFeatureConfigRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.SetSuggestionFeatureConfigRequest";
                        };
    
                        return SetSuggestionFeatureConfigRequest;
                    })();
    
                    v2beta1.ClearSuggestionFeatureConfigRequest = (function() {
    
                        /**
                         * Properties of a ClearSuggestionFeatureConfigRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IClearSuggestionFeatureConfigRequest
                         * @property {string|null} [conversationProfile] ClearSuggestionFeatureConfigRequest conversationProfile
                         * @property {google.cloud.dialogflow.v2beta1.Participant.Role|null} [participantRole] ClearSuggestionFeatureConfigRequest participantRole
                         * @property {google.cloud.dialogflow.v2beta1.SuggestionFeature.Type|null} [suggestionFeatureType] ClearSuggestionFeatureConfigRequest suggestionFeatureType
                         */
    
                        /**
                         * Constructs a new ClearSuggestionFeatureConfigRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a ClearSuggestionFeatureConfigRequest.
                         * @implements IClearSuggestionFeatureConfigRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IClearSuggestionFeatureConfigRequest=} [properties] Properties to set
                         */
                        function ClearSuggestionFeatureConfigRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ClearSuggestionFeatureConfigRequest conversationProfile.
                         * @member {string} conversationProfile
                         * @memberof google.cloud.dialogflow.v2beta1.ClearSuggestionFeatureConfigRequest
                         * @instance
                         */
                        ClearSuggestionFeatureConfigRequest.prototype.conversationProfile = "";
    
                        /**
                         * ClearSuggestionFeatureConfigRequest participantRole.
                         * @member {google.cloud.dialogflow.v2beta1.Participant.Role} participantRole
                         * @memberof google.cloud.dialogflow.v2beta1.ClearSuggestionFeatureConfigRequest
                         * @instance
                         */
                        ClearSuggestionFeatureConfigRequest.prototype.participantRole = 0;
    
                        /**
                         * ClearSuggestionFeatureConfigRequest suggestionFeatureType.
                         * @member {google.cloud.dialogflow.v2beta1.SuggestionFeature.Type} suggestionFeatureType
                         * @memberof google.cloud.dialogflow.v2beta1.ClearSuggestionFeatureConfigRequest
                         * @instance
                         */
                        ClearSuggestionFeatureConfigRequest.prototype.suggestionFeatureType = 0;
    
                        /**
                         * Creates a new ClearSuggestionFeatureConfigRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.ClearSuggestionFeatureConfigRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IClearSuggestionFeatureConfigRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.ClearSuggestionFeatureConfigRequest} ClearSuggestionFeatureConfigRequest instance
                         */
                        ClearSuggestionFeatureConfigRequest.create = function create(properties) {
                            return new ClearSuggestionFeatureConfigRequest(properties);
                        };
    
                        /**
                         * Encodes the specified ClearSuggestionFeatureConfigRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ClearSuggestionFeatureConfigRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.ClearSuggestionFeatureConfigRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IClearSuggestionFeatureConfigRequest} message ClearSuggestionFeatureConfigRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ClearSuggestionFeatureConfigRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.conversationProfile != null && Object.hasOwnProperty.call(message, "conversationProfile"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.conversationProfile);
                            if (message.participantRole != null && Object.hasOwnProperty.call(message, "participantRole"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.participantRole);
                            if (message.suggestionFeatureType != null && Object.hasOwnProperty.call(message, "suggestionFeatureType"))
                                writer.uint32(/* id 3, wireType 0 =*/24).int32(message.suggestionFeatureType);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ClearSuggestionFeatureConfigRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ClearSuggestionFeatureConfigRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ClearSuggestionFeatureConfigRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IClearSuggestionFeatureConfigRequest} message ClearSuggestionFeatureConfigRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ClearSuggestionFeatureConfigRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ClearSuggestionFeatureConfigRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.ClearSuggestionFeatureConfigRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.ClearSuggestionFeatureConfigRequest} ClearSuggestionFeatureConfigRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ClearSuggestionFeatureConfigRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ClearSuggestionFeatureConfigRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.conversationProfile = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.participantRole = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.suggestionFeatureType = reader.int32();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ClearSuggestionFeatureConfigRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ClearSuggestionFeatureConfigRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.ClearSuggestionFeatureConfigRequest} ClearSuggestionFeatureConfigRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ClearSuggestionFeatureConfigRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ClearSuggestionFeatureConfigRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.ClearSuggestionFeatureConfigRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ClearSuggestionFeatureConfigRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.conversationProfile != null && message.hasOwnProperty("conversationProfile"))
                                if (!$util.isString(message.conversationProfile))
                                    return "conversationProfile: string expected";
                            if (message.participantRole != null && message.hasOwnProperty("participantRole"))
                                switch (message.participantRole) {
                                default:
                                    return "participantRole: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                    break;
                                }
                            if (message.suggestionFeatureType != null && message.hasOwnProperty("suggestionFeatureType"))
                                switch (message.suggestionFeatureType) {
                                default:
                                    return "suggestionFeatureType: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                case 4:
                                case 8:
                                case 14:
                                case 15:
                                    break;
                                }
                            return null;
                        };
    
                        /**
                         * Creates a ClearSuggestionFeatureConfigRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.ClearSuggestionFeatureConfigRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.ClearSuggestionFeatureConfigRequest} ClearSuggestionFeatureConfigRequest
                         */
                        ClearSuggestionFeatureConfigRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.ClearSuggestionFeatureConfigRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.ClearSuggestionFeatureConfigRequest();
                            if (object.conversationProfile != null)
                                message.conversationProfile = String(object.conversationProfile);
                            switch (object.participantRole) {
                            default:
                                if (typeof object.participantRole === "number") {
                                    message.participantRole = object.participantRole;
                                    break;
                                }
                                break;
                            case "ROLE_UNSPECIFIED":
                            case 0:
                                message.participantRole = 0;
                                break;
                            case "HUMAN_AGENT":
                            case 1:
                                message.participantRole = 1;
                                break;
                            case "AUTOMATED_AGENT":
                            case 2:
                                message.participantRole = 2;
                                break;
                            case "END_USER":
                            case 3:
                                message.participantRole = 3;
                                break;
                            }
                            switch (object.suggestionFeatureType) {
                            default:
                                if (typeof object.suggestionFeatureType === "number") {
                                    message.suggestionFeatureType = object.suggestionFeatureType;
                                    break;
                                }
                                break;
                            case "TYPE_UNSPECIFIED":
                            case 0:
                                message.suggestionFeatureType = 0;
                                break;
                            case "ARTICLE_SUGGESTION":
                            case 1:
                                message.suggestionFeatureType = 1;
                                break;
                            case "FAQ":
                            case 2:
                                message.suggestionFeatureType = 2;
                                break;
                            case "SMART_REPLY":
                            case 3:
                                message.suggestionFeatureType = 3;
                                break;
                            case "DIALOGFLOW_ASSIST":
                            case 4:
                                message.suggestionFeatureType = 4;
                                break;
                            case "CONVERSATION_SUMMARIZATION":
                            case 8:
                                message.suggestionFeatureType = 8;
                                break;
                            case "KNOWLEDGE_SEARCH":
                            case 14:
                                message.suggestionFeatureType = 14;
                                break;
                            case "KNOWLEDGE_ASSIST":
                            case 15:
                                message.suggestionFeatureType = 15;
                                break;
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ClearSuggestionFeatureConfigRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.ClearSuggestionFeatureConfigRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ClearSuggestionFeatureConfigRequest} message ClearSuggestionFeatureConfigRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ClearSuggestionFeatureConfigRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.conversationProfile = "";
                                object.participantRole = options.enums === String ? "ROLE_UNSPECIFIED" : 0;
                                object.suggestionFeatureType = options.enums === String ? "TYPE_UNSPECIFIED" : 0;
                            }
                            if (message.conversationProfile != null && message.hasOwnProperty("conversationProfile"))
                                object.conversationProfile = message.conversationProfile;
                            if (message.participantRole != null && message.hasOwnProperty("participantRole"))
                                object.participantRole = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.Participant.Role[message.participantRole] === undefined ? message.participantRole : $root.google.cloud.dialogflow.v2beta1.Participant.Role[message.participantRole] : message.participantRole;
                            if (message.suggestionFeatureType != null && message.hasOwnProperty("suggestionFeatureType"))
                                object.suggestionFeatureType = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.SuggestionFeature.Type[message.suggestionFeatureType] === undefined ? message.suggestionFeatureType : $root.google.cloud.dialogflow.v2beta1.SuggestionFeature.Type[message.suggestionFeatureType] : message.suggestionFeatureType;
                            return object;
                        };
    
                        /**
                         * Converts this ClearSuggestionFeatureConfigRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.ClearSuggestionFeatureConfigRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ClearSuggestionFeatureConfigRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ClearSuggestionFeatureConfigRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.ClearSuggestionFeatureConfigRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ClearSuggestionFeatureConfigRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ClearSuggestionFeatureConfigRequest";
                        };
    
                        return ClearSuggestionFeatureConfigRequest;
                    })();
    
                    v2beta1.SetSuggestionFeatureConfigOperationMetadata = (function() {
    
                        /**
                         * Properties of a SetSuggestionFeatureConfigOperationMetadata.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ISetSuggestionFeatureConfigOperationMetadata
                         * @property {string|null} [conversationProfile] SetSuggestionFeatureConfigOperationMetadata conversationProfile
                         * @property {google.cloud.dialogflow.v2beta1.Participant.Role|null} [participantRole] SetSuggestionFeatureConfigOperationMetadata participantRole
                         * @property {google.cloud.dialogflow.v2beta1.SuggestionFeature.Type|null} [suggestionFeatureType] SetSuggestionFeatureConfigOperationMetadata suggestionFeatureType
                         * @property {google.protobuf.ITimestamp|null} [createTime] SetSuggestionFeatureConfigOperationMetadata createTime
                         */
    
                        /**
                         * Constructs a new SetSuggestionFeatureConfigOperationMetadata.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a SetSuggestionFeatureConfigOperationMetadata.
                         * @implements ISetSuggestionFeatureConfigOperationMetadata
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ISetSuggestionFeatureConfigOperationMetadata=} [properties] Properties to set
                         */
                        function SetSuggestionFeatureConfigOperationMetadata(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SetSuggestionFeatureConfigOperationMetadata conversationProfile.
                         * @member {string} conversationProfile
                         * @memberof google.cloud.dialogflow.v2beta1.SetSuggestionFeatureConfigOperationMetadata
                         * @instance
                         */
                        SetSuggestionFeatureConfigOperationMetadata.prototype.conversationProfile = "";
    
                        /**
                         * SetSuggestionFeatureConfigOperationMetadata participantRole.
                         * @member {google.cloud.dialogflow.v2beta1.Participant.Role} participantRole
                         * @memberof google.cloud.dialogflow.v2beta1.SetSuggestionFeatureConfigOperationMetadata
                         * @instance
                         */
                        SetSuggestionFeatureConfigOperationMetadata.prototype.participantRole = 0;
    
                        /**
                         * SetSuggestionFeatureConfigOperationMetadata suggestionFeatureType.
                         * @member {google.cloud.dialogflow.v2beta1.SuggestionFeature.Type} suggestionFeatureType
                         * @memberof google.cloud.dialogflow.v2beta1.SetSuggestionFeatureConfigOperationMetadata
                         * @instance
                         */
                        SetSuggestionFeatureConfigOperationMetadata.prototype.suggestionFeatureType = 0;
    
                        /**
                         * SetSuggestionFeatureConfigOperationMetadata createTime.
                         * @member {google.protobuf.ITimestamp|null|undefined} createTime
                         * @memberof google.cloud.dialogflow.v2beta1.SetSuggestionFeatureConfigOperationMetadata
                         * @instance
                         */
                        SetSuggestionFeatureConfigOperationMetadata.prototype.createTime = null;
    
                        /**
                         * Creates a new SetSuggestionFeatureConfigOperationMetadata instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.SetSuggestionFeatureConfigOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISetSuggestionFeatureConfigOperationMetadata=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.SetSuggestionFeatureConfigOperationMetadata} SetSuggestionFeatureConfigOperationMetadata instance
                         */
                        SetSuggestionFeatureConfigOperationMetadata.create = function create(properties) {
                            return new SetSuggestionFeatureConfigOperationMetadata(properties);
                        };
    
                        /**
                         * Encodes the specified SetSuggestionFeatureConfigOperationMetadata message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SetSuggestionFeatureConfigOperationMetadata.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.SetSuggestionFeatureConfigOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISetSuggestionFeatureConfigOperationMetadata} message SetSuggestionFeatureConfigOperationMetadata message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SetSuggestionFeatureConfigOperationMetadata.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.conversationProfile != null && Object.hasOwnProperty.call(message, "conversationProfile"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.conversationProfile);
                            if (message.participantRole != null && Object.hasOwnProperty.call(message, "participantRole"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.participantRole);
                            if (message.suggestionFeatureType != null && Object.hasOwnProperty.call(message, "suggestionFeatureType"))
                                writer.uint32(/* id 3, wireType 0 =*/24).int32(message.suggestionFeatureType);
                            if (message.createTime != null && Object.hasOwnProperty.call(message, "createTime"))
                                $root.google.protobuf.Timestamp.encode(message.createTime, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SetSuggestionFeatureConfigOperationMetadata message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SetSuggestionFeatureConfigOperationMetadata.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SetSuggestionFeatureConfigOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISetSuggestionFeatureConfigOperationMetadata} message SetSuggestionFeatureConfigOperationMetadata message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SetSuggestionFeatureConfigOperationMetadata.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SetSuggestionFeatureConfigOperationMetadata message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.SetSuggestionFeatureConfigOperationMetadata
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.SetSuggestionFeatureConfigOperationMetadata} SetSuggestionFeatureConfigOperationMetadata
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SetSuggestionFeatureConfigOperationMetadata.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.SetSuggestionFeatureConfigOperationMetadata();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.conversationProfile = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.participantRole = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.suggestionFeatureType = reader.int32();
                                        break;
                                    }
                                case 4: {
                                        message.createTime = $root.google.protobuf.Timestamp.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SetSuggestionFeatureConfigOperationMetadata message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SetSuggestionFeatureConfigOperationMetadata
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.SetSuggestionFeatureConfigOperationMetadata} SetSuggestionFeatureConfigOperationMetadata
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SetSuggestionFeatureConfigOperationMetadata.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SetSuggestionFeatureConfigOperationMetadata message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.SetSuggestionFeatureConfigOperationMetadata
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SetSuggestionFeatureConfigOperationMetadata.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.conversationProfile != null && message.hasOwnProperty("conversationProfile"))
                                if (!$util.isString(message.conversationProfile))
                                    return "conversationProfile: string expected";
                            if (message.participantRole != null && message.hasOwnProperty("participantRole"))
                                switch (message.participantRole) {
                                default:
                                    return "participantRole: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                    break;
                                }
                            if (message.suggestionFeatureType != null && message.hasOwnProperty("suggestionFeatureType"))
                                switch (message.suggestionFeatureType) {
                                default:
                                    return "suggestionFeatureType: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                case 4:
                                case 8:
                                case 14:
                                case 15:
                                    break;
                                }
                            if (message.createTime != null && message.hasOwnProperty("createTime")) {
                                var error = $root.google.protobuf.Timestamp.verify(message.createTime);
                                if (error)
                                    return "createTime." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a SetSuggestionFeatureConfigOperationMetadata message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.SetSuggestionFeatureConfigOperationMetadata
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.SetSuggestionFeatureConfigOperationMetadata} SetSuggestionFeatureConfigOperationMetadata
                         */
                        SetSuggestionFeatureConfigOperationMetadata.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.SetSuggestionFeatureConfigOperationMetadata)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.SetSuggestionFeatureConfigOperationMetadata();
                            if (object.conversationProfile != null)
                                message.conversationProfile = String(object.conversationProfile);
                            switch (object.participantRole) {
                            default:
                                if (typeof object.participantRole === "number") {
                                    message.participantRole = object.participantRole;
                                    break;
                                }
                                break;
                            case "ROLE_UNSPECIFIED":
                            case 0:
                                message.participantRole = 0;
                                break;
                            case "HUMAN_AGENT":
                            case 1:
                                message.participantRole = 1;
                                break;
                            case "AUTOMATED_AGENT":
                            case 2:
                                message.participantRole = 2;
                                break;
                            case "END_USER":
                            case 3:
                                message.participantRole = 3;
                                break;
                            }
                            switch (object.suggestionFeatureType) {
                            default:
                                if (typeof object.suggestionFeatureType === "number") {
                                    message.suggestionFeatureType = object.suggestionFeatureType;
                                    break;
                                }
                                break;
                            case "TYPE_UNSPECIFIED":
                            case 0:
                                message.suggestionFeatureType = 0;
                                break;
                            case "ARTICLE_SUGGESTION":
                            case 1:
                                message.suggestionFeatureType = 1;
                                break;
                            case "FAQ":
                            case 2:
                                message.suggestionFeatureType = 2;
                                break;
                            case "SMART_REPLY":
                            case 3:
                                message.suggestionFeatureType = 3;
                                break;
                            case "DIALOGFLOW_ASSIST":
                            case 4:
                                message.suggestionFeatureType = 4;
                                break;
                            case "CONVERSATION_SUMMARIZATION":
                            case 8:
                                message.suggestionFeatureType = 8;
                                break;
                            case "KNOWLEDGE_SEARCH":
                            case 14:
                                message.suggestionFeatureType = 14;
                                break;
                            case "KNOWLEDGE_ASSIST":
                            case 15:
                                message.suggestionFeatureType = 15;
                                break;
                            }
                            if (object.createTime != null) {
                                if (typeof object.createTime !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.SetSuggestionFeatureConfigOperationMetadata.createTime: object expected");
                                message.createTime = $root.google.protobuf.Timestamp.fromObject(object.createTime);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SetSuggestionFeatureConfigOperationMetadata message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.SetSuggestionFeatureConfigOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.SetSuggestionFeatureConfigOperationMetadata} message SetSuggestionFeatureConfigOperationMetadata
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SetSuggestionFeatureConfigOperationMetadata.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.conversationProfile = "";
                                object.participantRole = options.enums === String ? "ROLE_UNSPECIFIED" : 0;
                                object.suggestionFeatureType = options.enums === String ? "TYPE_UNSPECIFIED" : 0;
                                object.createTime = null;
                            }
                            if (message.conversationProfile != null && message.hasOwnProperty("conversationProfile"))
                                object.conversationProfile = message.conversationProfile;
                            if (message.participantRole != null && message.hasOwnProperty("participantRole"))
                                object.participantRole = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.Participant.Role[message.participantRole] === undefined ? message.participantRole : $root.google.cloud.dialogflow.v2beta1.Participant.Role[message.participantRole] : message.participantRole;
                            if (message.suggestionFeatureType != null && message.hasOwnProperty("suggestionFeatureType"))
                                object.suggestionFeatureType = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.SuggestionFeature.Type[message.suggestionFeatureType] === undefined ? message.suggestionFeatureType : $root.google.cloud.dialogflow.v2beta1.SuggestionFeature.Type[message.suggestionFeatureType] : message.suggestionFeatureType;
                            if (message.createTime != null && message.hasOwnProperty("createTime"))
                                object.createTime = $root.google.protobuf.Timestamp.toObject(message.createTime, options);
                            return object;
                        };
    
                        /**
                         * Converts this SetSuggestionFeatureConfigOperationMetadata to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.SetSuggestionFeatureConfigOperationMetadata
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SetSuggestionFeatureConfigOperationMetadata.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SetSuggestionFeatureConfigOperationMetadata
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.SetSuggestionFeatureConfigOperationMetadata
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SetSuggestionFeatureConfigOperationMetadata.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.SetSuggestionFeatureConfigOperationMetadata";
                        };
    
                        return SetSuggestionFeatureConfigOperationMetadata;
                    })();
    
                    v2beta1.ClearSuggestionFeatureConfigOperationMetadata = (function() {
    
                        /**
                         * Properties of a ClearSuggestionFeatureConfigOperationMetadata.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IClearSuggestionFeatureConfigOperationMetadata
                         * @property {string|null} [conversationProfile] ClearSuggestionFeatureConfigOperationMetadata conversationProfile
                         * @property {google.cloud.dialogflow.v2beta1.Participant.Role|null} [participantRole] ClearSuggestionFeatureConfigOperationMetadata participantRole
                         * @property {google.cloud.dialogflow.v2beta1.SuggestionFeature.Type|null} [suggestionFeatureType] ClearSuggestionFeatureConfigOperationMetadata suggestionFeatureType
                         * @property {google.protobuf.ITimestamp|null} [createTime] ClearSuggestionFeatureConfigOperationMetadata createTime
                         */
    
                        /**
                         * Constructs a new ClearSuggestionFeatureConfigOperationMetadata.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a ClearSuggestionFeatureConfigOperationMetadata.
                         * @implements IClearSuggestionFeatureConfigOperationMetadata
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IClearSuggestionFeatureConfigOperationMetadata=} [properties] Properties to set
                         */
                        function ClearSuggestionFeatureConfigOperationMetadata(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ClearSuggestionFeatureConfigOperationMetadata conversationProfile.
                         * @member {string} conversationProfile
                         * @memberof google.cloud.dialogflow.v2beta1.ClearSuggestionFeatureConfigOperationMetadata
                         * @instance
                         */
                        ClearSuggestionFeatureConfigOperationMetadata.prototype.conversationProfile = "";
    
                        /**
                         * ClearSuggestionFeatureConfigOperationMetadata participantRole.
                         * @member {google.cloud.dialogflow.v2beta1.Participant.Role} participantRole
                         * @memberof google.cloud.dialogflow.v2beta1.ClearSuggestionFeatureConfigOperationMetadata
                         * @instance
                         */
                        ClearSuggestionFeatureConfigOperationMetadata.prototype.participantRole = 0;
    
                        /**
                         * ClearSuggestionFeatureConfigOperationMetadata suggestionFeatureType.
                         * @member {google.cloud.dialogflow.v2beta1.SuggestionFeature.Type} suggestionFeatureType
                         * @memberof google.cloud.dialogflow.v2beta1.ClearSuggestionFeatureConfigOperationMetadata
                         * @instance
                         */
                        ClearSuggestionFeatureConfigOperationMetadata.prototype.suggestionFeatureType = 0;
    
                        /**
                         * ClearSuggestionFeatureConfigOperationMetadata createTime.
                         * @member {google.protobuf.ITimestamp|null|undefined} createTime
                         * @memberof google.cloud.dialogflow.v2beta1.ClearSuggestionFeatureConfigOperationMetadata
                         * @instance
                         */
                        ClearSuggestionFeatureConfigOperationMetadata.prototype.createTime = null;
    
                        /**
                         * Creates a new ClearSuggestionFeatureConfigOperationMetadata instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.ClearSuggestionFeatureConfigOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IClearSuggestionFeatureConfigOperationMetadata=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.ClearSuggestionFeatureConfigOperationMetadata} ClearSuggestionFeatureConfigOperationMetadata instance
                         */
                        ClearSuggestionFeatureConfigOperationMetadata.create = function create(properties) {
                            return new ClearSuggestionFeatureConfigOperationMetadata(properties);
                        };
    
                        /**
                         * Encodes the specified ClearSuggestionFeatureConfigOperationMetadata message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ClearSuggestionFeatureConfigOperationMetadata.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.ClearSuggestionFeatureConfigOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IClearSuggestionFeatureConfigOperationMetadata} message ClearSuggestionFeatureConfigOperationMetadata message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ClearSuggestionFeatureConfigOperationMetadata.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.conversationProfile != null && Object.hasOwnProperty.call(message, "conversationProfile"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.conversationProfile);
                            if (message.participantRole != null && Object.hasOwnProperty.call(message, "participantRole"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.participantRole);
                            if (message.suggestionFeatureType != null && Object.hasOwnProperty.call(message, "suggestionFeatureType"))
                                writer.uint32(/* id 3, wireType 0 =*/24).int32(message.suggestionFeatureType);
                            if (message.createTime != null && Object.hasOwnProperty.call(message, "createTime"))
                                $root.google.protobuf.Timestamp.encode(message.createTime, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ClearSuggestionFeatureConfigOperationMetadata message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ClearSuggestionFeatureConfigOperationMetadata.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ClearSuggestionFeatureConfigOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IClearSuggestionFeatureConfigOperationMetadata} message ClearSuggestionFeatureConfigOperationMetadata message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ClearSuggestionFeatureConfigOperationMetadata.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ClearSuggestionFeatureConfigOperationMetadata message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.ClearSuggestionFeatureConfigOperationMetadata
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.ClearSuggestionFeatureConfigOperationMetadata} ClearSuggestionFeatureConfigOperationMetadata
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ClearSuggestionFeatureConfigOperationMetadata.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ClearSuggestionFeatureConfigOperationMetadata();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.conversationProfile = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.participantRole = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.suggestionFeatureType = reader.int32();
                                        break;
                                    }
                                case 4: {
                                        message.createTime = $root.google.protobuf.Timestamp.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ClearSuggestionFeatureConfigOperationMetadata message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ClearSuggestionFeatureConfigOperationMetadata
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.ClearSuggestionFeatureConfigOperationMetadata} ClearSuggestionFeatureConfigOperationMetadata
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ClearSuggestionFeatureConfigOperationMetadata.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ClearSuggestionFeatureConfigOperationMetadata message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.ClearSuggestionFeatureConfigOperationMetadata
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ClearSuggestionFeatureConfigOperationMetadata.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.conversationProfile != null && message.hasOwnProperty("conversationProfile"))
                                if (!$util.isString(message.conversationProfile))
                                    return "conversationProfile: string expected";
                            if (message.participantRole != null && message.hasOwnProperty("participantRole"))
                                switch (message.participantRole) {
                                default:
                                    return "participantRole: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                    break;
                                }
                            if (message.suggestionFeatureType != null && message.hasOwnProperty("suggestionFeatureType"))
                                switch (message.suggestionFeatureType) {
                                default:
                                    return "suggestionFeatureType: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                case 4:
                                case 8:
                                case 14:
                                case 15:
                                    break;
                                }
                            if (message.createTime != null && message.hasOwnProperty("createTime")) {
                                var error = $root.google.protobuf.Timestamp.verify(message.createTime);
                                if (error)
                                    return "createTime." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a ClearSuggestionFeatureConfigOperationMetadata message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.ClearSuggestionFeatureConfigOperationMetadata
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.ClearSuggestionFeatureConfigOperationMetadata} ClearSuggestionFeatureConfigOperationMetadata
                         */
                        ClearSuggestionFeatureConfigOperationMetadata.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.ClearSuggestionFeatureConfigOperationMetadata)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.ClearSuggestionFeatureConfigOperationMetadata();
                            if (object.conversationProfile != null)
                                message.conversationProfile = String(object.conversationProfile);
                            switch (object.participantRole) {
                            default:
                                if (typeof object.participantRole === "number") {
                                    message.participantRole = object.participantRole;
                                    break;
                                }
                                break;
                            case "ROLE_UNSPECIFIED":
                            case 0:
                                message.participantRole = 0;
                                break;
                            case "HUMAN_AGENT":
                            case 1:
                                message.participantRole = 1;
                                break;
                            case "AUTOMATED_AGENT":
                            case 2:
                                message.participantRole = 2;
                                break;
                            case "END_USER":
                            case 3:
                                message.participantRole = 3;
                                break;
                            }
                            switch (object.suggestionFeatureType) {
                            default:
                                if (typeof object.suggestionFeatureType === "number") {
                                    message.suggestionFeatureType = object.suggestionFeatureType;
                                    break;
                                }
                                break;
                            case "TYPE_UNSPECIFIED":
                            case 0:
                                message.suggestionFeatureType = 0;
                                break;
                            case "ARTICLE_SUGGESTION":
                            case 1:
                                message.suggestionFeatureType = 1;
                                break;
                            case "FAQ":
                            case 2:
                                message.suggestionFeatureType = 2;
                                break;
                            case "SMART_REPLY":
                            case 3:
                                message.suggestionFeatureType = 3;
                                break;
                            case "DIALOGFLOW_ASSIST":
                            case 4:
                                message.suggestionFeatureType = 4;
                                break;
                            case "CONVERSATION_SUMMARIZATION":
                            case 8:
                                message.suggestionFeatureType = 8;
                                break;
                            case "KNOWLEDGE_SEARCH":
                            case 14:
                                message.suggestionFeatureType = 14;
                                break;
                            case "KNOWLEDGE_ASSIST":
                            case 15:
                                message.suggestionFeatureType = 15;
                                break;
                            }
                            if (object.createTime != null) {
                                if (typeof object.createTime !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.ClearSuggestionFeatureConfigOperationMetadata.createTime: object expected");
                                message.createTime = $root.google.protobuf.Timestamp.fromObject(object.createTime);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ClearSuggestionFeatureConfigOperationMetadata message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.ClearSuggestionFeatureConfigOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ClearSuggestionFeatureConfigOperationMetadata} message ClearSuggestionFeatureConfigOperationMetadata
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ClearSuggestionFeatureConfigOperationMetadata.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.conversationProfile = "";
                                object.participantRole = options.enums === String ? "ROLE_UNSPECIFIED" : 0;
                                object.suggestionFeatureType = options.enums === String ? "TYPE_UNSPECIFIED" : 0;
                                object.createTime = null;
                            }
                            if (message.conversationProfile != null && message.hasOwnProperty("conversationProfile"))
                                object.conversationProfile = message.conversationProfile;
                            if (message.participantRole != null && message.hasOwnProperty("participantRole"))
                                object.participantRole = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.Participant.Role[message.participantRole] === undefined ? message.participantRole : $root.google.cloud.dialogflow.v2beta1.Participant.Role[message.participantRole] : message.participantRole;
                            if (message.suggestionFeatureType != null && message.hasOwnProperty("suggestionFeatureType"))
                                object.suggestionFeatureType = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.SuggestionFeature.Type[message.suggestionFeatureType] === undefined ? message.suggestionFeatureType : $root.google.cloud.dialogflow.v2beta1.SuggestionFeature.Type[message.suggestionFeatureType] : message.suggestionFeatureType;
                            if (message.createTime != null && message.hasOwnProperty("createTime"))
                                object.createTime = $root.google.protobuf.Timestamp.toObject(message.createTime, options);
                            return object;
                        };
    
                        /**
                         * Converts this ClearSuggestionFeatureConfigOperationMetadata to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.ClearSuggestionFeatureConfigOperationMetadata
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ClearSuggestionFeatureConfigOperationMetadata.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ClearSuggestionFeatureConfigOperationMetadata
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.ClearSuggestionFeatureConfigOperationMetadata
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ClearSuggestionFeatureConfigOperationMetadata.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ClearSuggestionFeatureConfigOperationMetadata";
                        };
    
                        return ClearSuggestionFeatureConfigOperationMetadata;
                    })();
    
                    v2beta1.ConversationEvent = (function() {
    
                        /**
                         * Properties of a ConversationEvent.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IConversationEvent
                         * @property {string|null} [conversation] ConversationEvent conversation
                         * @property {google.cloud.dialogflow.v2beta1.ConversationEvent.Type|null} [type] ConversationEvent type
                         * @property {google.rpc.IStatus|null} [errorStatus] ConversationEvent errorStatus
                         * @property {google.cloud.dialogflow.v2beta1.IMessage|null} [newMessagePayload] ConversationEvent newMessagePayload
                         * @property {google.cloud.dialogflow.v2beta1.IStreamingRecognitionResult|null} [newRecognitionResultPayload] ConversationEvent newRecognitionResultPayload
                         */
    
                        /**
                         * Constructs a new ConversationEvent.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a ConversationEvent.
                         * @implements IConversationEvent
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IConversationEvent=} [properties] Properties to set
                         */
                        function ConversationEvent(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ConversationEvent conversation.
                         * @member {string} conversation
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationEvent
                         * @instance
                         */
                        ConversationEvent.prototype.conversation = "";
    
                        /**
                         * ConversationEvent type.
                         * @member {google.cloud.dialogflow.v2beta1.ConversationEvent.Type} type
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationEvent
                         * @instance
                         */
                        ConversationEvent.prototype.type = 0;
    
                        /**
                         * ConversationEvent errorStatus.
                         * @member {google.rpc.IStatus|null|undefined} errorStatus
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationEvent
                         * @instance
                         */
                        ConversationEvent.prototype.errorStatus = null;
    
                        /**
                         * ConversationEvent newMessagePayload.
                         * @member {google.cloud.dialogflow.v2beta1.IMessage|null|undefined} newMessagePayload
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationEvent
                         * @instance
                         */
                        ConversationEvent.prototype.newMessagePayload = null;
    
                        /**
                         * ConversationEvent newRecognitionResultPayload.
                         * @member {google.cloud.dialogflow.v2beta1.IStreamingRecognitionResult|null|undefined} newRecognitionResultPayload
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationEvent
                         * @instance
                         */
                        ConversationEvent.prototype.newRecognitionResultPayload = null;
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * ConversationEvent payload.
                         * @member {"newMessagePayload"|"newRecognitionResultPayload"|undefined} payload
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationEvent
                         * @instance
                         */
                        Object.defineProperty(ConversationEvent.prototype, "payload", {
                            get: $util.oneOfGetter($oneOfFields = ["newMessagePayload", "newRecognitionResultPayload"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new ConversationEvent instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationEvent
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IConversationEvent=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.ConversationEvent} ConversationEvent instance
                         */
                        ConversationEvent.create = function create(properties) {
                            return new ConversationEvent(properties);
                        };
    
                        /**
                         * Encodes the specified ConversationEvent message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ConversationEvent.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationEvent
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IConversationEvent} message ConversationEvent message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ConversationEvent.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.conversation != null && Object.hasOwnProperty.call(message, "conversation"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.conversation);
                            if (message.type != null && Object.hasOwnProperty.call(message, "type"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.type);
                            if (message.errorStatus != null && Object.hasOwnProperty.call(message, "errorStatus"))
                                $root.google.rpc.Status.encode(message.errorStatus, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            if (message.newMessagePayload != null && Object.hasOwnProperty.call(message, "newMessagePayload"))
                                $root.google.cloud.dialogflow.v2beta1.Message.encode(message.newMessagePayload, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            if (message.newRecognitionResultPayload != null && Object.hasOwnProperty.call(message, "newRecognitionResultPayload"))
                                $root.google.cloud.dialogflow.v2beta1.StreamingRecognitionResult.encode(message.newRecognitionResultPayload, writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ConversationEvent message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ConversationEvent.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationEvent
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IConversationEvent} message ConversationEvent message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ConversationEvent.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ConversationEvent message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationEvent
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.ConversationEvent} ConversationEvent
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ConversationEvent.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ConversationEvent();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.conversation = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.type = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.errorStatus = $root.google.rpc.Status.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 4: {
                                        message.newMessagePayload = $root.google.cloud.dialogflow.v2beta1.Message.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 5: {
                                        message.newRecognitionResultPayload = $root.google.cloud.dialogflow.v2beta1.StreamingRecognitionResult.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ConversationEvent message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationEvent
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.ConversationEvent} ConversationEvent
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ConversationEvent.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ConversationEvent message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationEvent
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ConversationEvent.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.conversation != null && message.hasOwnProperty("conversation"))
                                if (!$util.isString(message.conversation))
                                    return "conversation: string expected";
                            if (message.type != null && message.hasOwnProperty("type"))
                                switch (message.type) {
                                default:
                                    return "type: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                case 5:
                                case 7:
                                case 4:
                                    break;
                                }
                            if (message.errorStatus != null && message.hasOwnProperty("errorStatus")) {
                                var error = $root.google.rpc.Status.verify(message.errorStatus);
                                if (error)
                                    return "errorStatus." + error;
                            }
                            if (message.newMessagePayload != null && message.hasOwnProperty("newMessagePayload")) {
                                properties.payload = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2beta1.Message.verify(message.newMessagePayload);
                                    if (error)
                                        return "newMessagePayload." + error;
                                }
                            }
                            if (message.newRecognitionResultPayload != null && message.hasOwnProperty("newRecognitionResultPayload")) {
                                if (properties.payload === 1)
                                    return "payload: multiple values";
                                properties.payload = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2beta1.StreamingRecognitionResult.verify(message.newRecognitionResultPayload);
                                    if (error)
                                        return "newRecognitionResultPayload." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates a ConversationEvent message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationEvent
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.ConversationEvent} ConversationEvent
                         */
                        ConversationEvent.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.ConversationEvent)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.ConversationEvent();
                            if (object.conversation != null)
                                message.conversation = String(object.conversation);
                            switch (object.type) {
                            default:
                                if (typeof object.type === "number") {
                                    message.type = object.type;
                                    break;
                                }
                                break;
                            case "TYPE_UNSPECIFIED":
                            case 0:
                                message.type = 0;
                                break;
                            case "CONVERSATION_STARTED":
                            case 1:
                                message.type = 1;
                                break;
                            case "CONVERSATION_FINISHED":
                            case 2:
                                message.type = 2;
                                break;
                            case "HUMAN_INTERVENTION_NEEDED":
                            case 3:
                                message.type = 3;
                                break;
                            case "NEW_MESSAGE":
                            case 5:
                                message.type = 5;
                                break;
                            case "NEW_RECOGNITION_RESULT":
                            case 7:
                                message.type = 7;
                                break;
                            case "UNRECOVERABLE_ERROR":
                            case 4:
                                message.type = 4;
                                break;
                            }
                            if (object.errorStatus != null) {
                                if (typeof object.errorStatus !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.ConversationEvent.errorStatus: object expected");
                                message.errorStatus = $root.google.rpc.Status.fromObject(object.errorStatus);
                            }
                            if (object.newMessagePayload != null) {
                                if (typeof object.newMessagePayload !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.ConversationEvent.newMessagePayload: object expected");
                                message.newMessagePayload = $root.google.cloud.dialogflow.v2beta1.Message.fromObject(object.newMessagePayload);
                            }
                            if (object.newRecognitionResultPayload != null) {
                                if (typeof object.newRecognitionResultPayload !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.ConversationEvent.newRecognitionResultPayload: object expected");
                                message.newRecognitionResultPayload = $root.google.cloud.dialogflow.v2beta1.StreamingRecognitionResult.fromObject(object.newRecognitionResultPayload);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ConversationEvent message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationEvent
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ConversationEvent} message ConversationEvent
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ConversationEvent.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.conversation = "";
                                object.type = options.enums === String ? "TYPE_UNSPECIFIED" : 0;
                                object.errorStatus = null;
                            }
                            if (message.conversation != null && message.hasOwnProperty("conversation"))
                                object.conversation = message.conversation;
                            if (message.type != null && message.hasOwnProperty("type"))
                                object.type = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.ConversationEvent.Type[message.type] === undefined ? message.type : $root.google.cloud.dialogflow.v2beta1.ConversationEvent.Type[message.type] : message.type;
                            if (message.errorStatus != null && message.hasOwnProperty("errorStatus"))
                                object.errorStatus = $root.google.rpc.Status.toObject(message.errorStatus, options);
                            if (message.newMessagePayload != null && message.hasOwnProperty("newMessagePayload")) {
                                object.newMessagePayload = $root.google.cloud.dialogflow.v2beta1.Message.toObject(message.newMessagePayload, options);
                                if (options.oneofs)
                                    object.payload = "newMessagePayload";
                            }
                            if (message.newRecognitionResultPayload != null && message.hasOwnProperty("newRecognitionResultPayload")) {
                                object.newRecognitionResultPayload = $root.google.cloud.dialogflow.v2beta1.StreamingRecognitionResult.toObject(message.newRecognitionResultPayload, options);
                                if (options.oneofs)
                                    object.payload = "newRecognitionResultPayload";
                            }
                            return object;
                        };
    
                        /**
                         * Converts this ConversationEvent to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationEvent
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ConversationEvent.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ConversationEvent
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.ConversationEvent
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ConversationEvent.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ConversationEvent";
                        };
    
                        /**
                         * Type enum.
                         * @name google.cloud.dialogflow.v2beta1.ConversationEvent.Type
                         * @enum {number}
                         * @property {number} TYPE_UNSPECIFIED=0 TYPE_UNSPECIFIED value
                         * @property {number} CONVERSATION_STARTED=1 CONVERSATION_STARTED value
                         * @property {number} CONVERSATION_FINISHED=2 CONVERSATION_FINISHED value
                         * @property {number} HUMAN_INTERVENTION_NEEDED=3 HUMAN_INTERVENTION_NEEDED value
                         * @property {number} NEW_MESSAGE=5 NEW_MESSAGE value
                         * @property {number} NEW_RECOGNITION_RESULT=7 NEW_RECOGNITION_RESULT value
                         * @property {number} UNRECOVERABLE_ERROR=4 UNRECOVERABLE_ERROR value
                         */
                        ConversationEvent.Type = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "TYPE_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "CONVERSATION_STARTED"] = 1;
                            values[valuesById[2] = "CONVERSATION_FINISHED"] = 2;
                            values[valuesById[3] = "HUMAN_INTERVENTION_NEEDED"] = 3;
                            values[valuesById[5] = "NEW_MESSAGE"] = 5;
                            values[valuesById[7] = "NEW_RECOGNITION_RESULT"] = 7;
                            values[valuesById[4] = "UNRECOVERABLE_ERROR"] = 4;
                            return values;
                        })();
    
                        return ConversationEvent;
                    })();
    
                    v2beta1.Documents = (function() {
    
                        /**
                         * Constructs a new Documents service.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a Documents
                         * @extends $protobuf.rpc.Service
                         * @constructor
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         */
                        function Documents(rpcImpl, requestDelimited, responseDelimited) {
                            $protobuf.rpc.Service.call(this, rpcImpl, requestDelimited, responseDelimited);
                        }
    
                        (Documents.prototype = Object.create($protobuf.rpc.Service.prototype)).constructor = Documents;
    
                        /**
                         * Creates new Documents service using the specified rpc implementation.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.Documents
                         * @static
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         * @returns {Documents} RPC service. Useful where requests and/or responses are streamed.
                         */
                        Documents.create = function create(rpcImpl, requestDelimited, responseDelimited) {
                            return new this(rpcImpl, requestDelimited, responseDelimited);
                        };
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Documents|listDocuments}.
                         * @memberof google.cloud.dialogflow.v2beta1.Documents
                         * @typedef ListDocumentsCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.ListDocumentsResponse} [response] ListDocumentsResponse
                         */
    
                        /**
                         * Calls ListDocuments.
                         * @function listDocuments
                         * @memberof google.cloud.dialogflow.v2beta1.Documents
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IListDocumentsRequest} request ListDocumentsRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Documents.ListDocumentsCallback} callback Node-style callback called with the error, if any, and ListDocumentsResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Documents.prototype.listDocuments = function listDocuments(request, callback) {
                            return this.rpcCall(listDocuments, $root.google.cloud.dialogflow.v2beta1.ListDocumentsRequest, $root.google.cloud.dialogflow.v2beta1.ListDocumentsResponse, request, callback);
                        }, "name", { value: "ListDocuments" });
    
                        /**
                         * Calls ListDocuments.
                         * @function listDocuments
                         * @memberof google.cloud.dialogflow.v2beta1.Documents
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IListDocumentsRequest} request ListDocumentsRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.ListDocumentsResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Documents|getDocument}.
                         * @memberof google.cloud.dialogflow.v2beta1.Documents
                         * @typedef GetDocumentCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.Document} [response] Document
                         */
    
                        /**
                         * Calls GetDocument.
                         * @function getDocument
                         * @memberof google.cloud.dialogflow.v2beta1.Documents
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IGetDocumentRequest} request GetDocumentRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Documents.GetDocumentCallback} callback Node-style callback called with the error, if any, and Document
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Documents.prototype.getDocument = function getDocument(request, callback) {
                            return this.rpcCall(getDocument, $root.google.cloud.dialogflow.v2beta1.GetDocumentRequest, $root.google.cloud.dialogflow.v2beta1.Document, request, callback);
                        }, "name", { value: "GetDocument" });
    
                        /**
                         * Calls GetDocument.
                         * @function getDocument
                         * @memberof google.cloud.dialogflow.v2beta1.Documents
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IGetDocumentRequest} request GetDocumentRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.Document>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Documents|createDocument}.
                         * @memberof google.cloud.dialogflow.v2beta1.Documents
                         * @typedef CreateDocumentCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.longrunning.Operation} [response] Operation
                         */
    
                        /**
                         * Calls CreateDocument.
                         * @function createDocument
                         * @memberof google.cloud.dialogflow.v2beta1.Documents
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.ICreateDocumentRequest} request CreateDocumentRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Documents.CreateDocumentCallback} callback Node-style callback called with the error, if any, and Operation
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Documents.prototype.createDocument = function createDocument(request, callback) {
                            return this.rpcCall(createDocument, $root.google.cloud.dialogflow.v2beta1.CreateDocumentRequest, $root.google.longrunning.Operation, request, callback);
                        }, "name", { value: "CreateDocument" });
    
                        /**
                         * Calls CreateDocument.
                         * @function createDocument
                         * @memberof google.cloud.dialogflow.v2beta1.Documents
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.ICreateDocumentRequest} request CreateDocumentRequest message or plain object
                         * @returns {Promise<google.longrunning.Operation>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Documents|importDocuments}.
                         * @memberof google.cloud.dialogflow.v2beta1.Documents
                         * @typedef ImportDocumentsCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.longrunning.Operation} [response] Operation
                         */
    
                        /**
                         * Calls ImportDocuments.
                         * @function importDocuments
                         * @memberof google.cloud.dialogflow.v2beta1.Documents
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IImportDocumentsRequest} request ImportDocumentsRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Documents.ImportDocumentsCallback} callback Node-style callback called with the error, if any, and Operation
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Documents.prototype.importDocuments = function importDocuments(request, callback) {
                            return this.rpcCall(importDocuments, $root.google.cloud.dialogflow.v2beta1.ImportDocumentsRequest, $root.google.longrunning.Operation, request, callback);
                        }, "name", { value: "ImportDocuments" });
    
                        /**
                         * Calls ImportDocuments.
                         * @function importDocuments
                         * @memberof google.cloud.dialogflow.v2beta1.Documents
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IImportDocumentsRequest} request ImportDocumentsRequest message or plain object
                         * @returns {Promise<google.longrunning.Operation>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Documents|deleteDocument}.
                         * @memberof google.cloud.dialogflow.v2beta1.Documents
                         * @typedef DeleteDocumentCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.longrunning.Operation} [response] Operation
                         */
    
                        /**
                         * Calls DeleteDocument.
                         * @function deleteDocument
                         * @memberof google.cloud.dialogflow.v2beta1.Documents
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteDocumentRequest} request DeleteDocumentRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Documents.DeleteDocumentCallback} callback Node-style callback called with the error, if any, and Operation
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Documents.prototype.deleteDocument = function deleteDocument(request, callback) {
                            return this.rpcCall(deleteDocument, $root.google.cloud.dialogflow.v2beta1.DeleteDocumentRequest, $root.google.longrunning.Operation, request, callback);
                        }, "name", { value: "DeleteDocument" });
    
                        /**
                         * Calls DeleteDocument.
                         * @function deleteDocument
                         * @memberof google.cloud.dialogflow.v2beta1.Documents
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteDocumentRequest} request DeleteDocumentRequest message or plain object
                         * @returns {Promise<google.longrunning.Operation>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Documents|updateDocument}.
                         * @memberof google.cloud.dialogflow.v2beta1.Documents
                         * @typedef UpdateDocumentCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.longrunning.Operation} [response] Operation
                         */
    
                        /**
                         * Calls UpdateDocument.
                         * @function updateDocument
                         * @memberof google.cloud.dialogflow.v2beta1.Documents
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateDocumentRequest} request UpdateDocumentRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Documents.UpdateDocumentCallback} callback Node-style callback called with the error, if any, and Operation
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Documents.prototype.updateDocument = function updateDocument(request, callback) {
                            return this.rpcCall(updateDocument, $root.google.cloud.dialogflow.v2beta1.UpdateDocumentRequest, $root.google.longrunning.Operation, request, callback);
                        }, "name", { value: "UpdateDocument" });
    
                        /**
                         * Calls UpdateDocument.
                         * @function updateDocument
                         * @memberof google.cloud.dialogflow.v2beta1.Documents
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateDocumentRequest} request UpdateDocumentRequest message or plain object
                         * @returns {Promise<google.longrunning.Operation>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Documents|reloadDocument}.
                         * @memberof google.cloud.dialogflow.v2beta1.Documents
                         * @typedef ReloadDocumentCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.longrunning.Operation} [response] Operation
                         */
    
                        /**
                         * Calls ReloadDocument.
                         * @function reloadDocument
                         * @memberof google.cloud.dialogflow.v2beta1.Documents
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IReloadDocumentRequest} request ReloadDocumentRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Documents.ReloadDocumentCallback} callback Node-style callback called with the error, if any, and Operation
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Documents.prototype.reloadDocument = function reloadDocument(request, callback) {
                            return this.rpcCall(reloadDocument, $root.google.cloud.dialogflow.v2beta1.ReloadDocumentRequest, $root.google.longrunning.Operation, request, callback);
                        }, "name", { value: "ReloadDocument" });
    
                        /**
                         * Calls ReloadDocument.
                         * @function reloadDocument
                         * @memberof google.cloud.dialogflow.v2beta1.Documents
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IReloadDocumentRequest} request ReloadDocumentRequest message or plain object
                         * @returns {Promise<google.longrunning.Operation>} Promise
                         * @variation 2
                         */
    
                        return Documents;
                    })();
    
                    v2beta1.Document = (function() {
    
                        /**
                         * Properties of a Document.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IDocument
                         * @property {string|null} [name] Document name
                         * @property {string|null} [displayName] Document displayName
                         * @property {string|null} [mimeType] Document mimeType
                         * @property {Array.<google.cloud.dialogflow.v2beta1.Document.KnowledgeType>|null} [knowledgeTypes] Document knowledgeTypes
                         * @property {string|null} [contentUri] Document contentUri
                         * @property {string|null} [content] Document content
                         * @property {Uint8Array|null} [rawContent] Document rawContent
                         * @property {boolean|null} [enableAutoReload] Document enableAutoReload
                         * @property {google.cloud.dialogflow.v2beta1.Document.IReloadStatus|null} [latestReloadStatus] Document latestReloadStatus
                         * @property {Object.<string,string>|null} [metadata] Document metadata
                         * @property {google.cloud.dialogflow.v2beta1.Document.State|null} [state] Document state
                         */
    
                        /**
                         * Constructs a new Document.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a Document.
                         * @implements IDocument
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IDocument=} [properties] Properties to set
                         */
                        function Document(properties) {
                            this.knowledgeTypes = [];
                            this.metadata = {};
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * Document name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2beta1.Document
                         * @instance
                         */
                        Document.prototype.name = "";
    
                        /**
                         * Document displayName.
                         * @member {string} displayName
                         * @memberof google.cloud.dialogflow.v2beta1.Document
                         * @instance
                         */
                        Document.prototype.displayName = "";
    
                        /**
                         * Document mimeType.
                         * @member {string} mimeType
                         * @memberof google.cloud.dialogflow.v2beta1.Document
                         * @instance
                         */
                        Document.prototype.mimeType = "";
    
                        /**
                         * Document knowledgeTypes.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.Document.KnowledgeType>} knowledgeTypes
                         * @memberof google.cloud.dialogflow.v2beta1.Document
                         * @instance
                         */
                        Document.prototype.knowledgeTypes = $util.emptyArray;
    
                        /**
                         * Document contentUri.
                         * @member {string|null|undefined} contentUri
                         * @memberof google.cloud.dialogflow.v2beta1.Document
                         * @instance
                         */
                        Document.prototype.contentUri = null;
    
                        /**
                         * Document content.
                         * @member {string|null|undefined} content
                         * @memberof google.cloud.dialogflow.v2beta1.Document
                         * @instance
                         */
                        Document.prototype.content = null;
    
                        /**
                         * Document rawContent.
                         * @member {Uint8Array|null|undefined} rawContent
                         * @memberof google.cloud.dialogflow.v2beta1.Document
                         * @instance
                         */
                        Document.prototype.rawContent = null;
    
                        /**
                         * Document enableAutoReload.
                         * @member {boolean} enableAutoReload
                         * @memberof google.cloud.dialogflow.v2beta1.Document
                         * @instance
                         */
                        Document.prototype.enableAutoReload = false;
    
                        /**
                         * Document latestReloadStatus.
                         * @member {google.cloud.dialogflow.v2beta1.Document.IReloadStatus|null|undefined} latestReloadStatus
                         * @memberof google.cloud.dialogflow.v2beta1.Document
                         * @instance
                         */
                        Document.prototype.latestReloadStatus = null;
    
                        /**
                         * Document metadata.
                         * @member {Object.<string,string>} metadata
                         * @memberof google.cloud.dialogflow.v2beta1.Document
                         * @instance
                         */
                        Document.prototype.metadata = $util.emptyObject;
    
                        /**
                         * Document state.
                         * @member {google.cloud.dialogflow.v2beta1.Document.State} state
                         * @memberof google.cloud.dialogflow.v2beta1.Document
                         * @instance
                         */
                        Document.prototype.state = 0;
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * Document source.
                         * @member {"contentUri"|"content"|"rawContent"|undefined} source
                         * @memberof google.cloud.dialogflow.v2beta1.Document
                         * @instance
                         */
                        Object.defineProperty(Document.prototype, "source", {
                            get: $util.oneOfGetter($oneOfFields = ["contentUri", "content", "rawContent"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new Document instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.Document
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDocument=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.Document} Document instance
                         */
                        Document.create = function create(properties) {
                            return new Document(properties);
                        };
    
                        /**
                         * Encodes the specified Document message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Document.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.Document
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDocument} message Document message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        Document.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            if (message.displayName != null && Object.hasOwnProperty.call(message, "displayName"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.displayName);
                            if (message.mimeType != null && Object.hasOwnProperty.call(message, "mimeType"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.mimeType);
                            if (message.knowledgeTypes != null && message.knowledgeTypes.length) {
                                writer.uint32(/* id 4, wireType 2 =*/34).fork();
                                for (var i = 0; i < message.knowledgeTypes.length; ++i)
                                    writer.int32(message.knowledgeTypes[i]);
                                writer.ldelim();
                            }
                            if (message.contentUri != null && Object.hasOwnProperty.call(message, "contentUri"))
                                writer.uint32(/* id 5, wireType 2 =*/42).string(message.contentUri);
                            if (message.content != null && Object.hasOwnProperty.call(message, "content"))
                                writer.uint32(/* id 6, wireType 2 =*/50).string(message.content);
                            if (message.metadata != null && Object.hasOwnProperty.call(message, "metadata"))
                                for (var keys = Object.keys(message.metadata), i = 0; i < keys.length; ++i)
                                    writer.uint32(/* id 7, wireType 2 =*/58).fork().uint32(/* id 1, wireType 2 =*/10).string(keys[i]).uint32(/* id 2, wireType 2 =*/18).string(message.metadata[keys[i]]).ldelim();
                            if (message.rawContent != null && Object.hasOwnProperty.call(message, "rawContent"))
                                writer.uint32(/* id 9, wireType 2 =*/74).bytes(message.rawContent);
                            if (message.enableAutoReload != null && Object.hasOwnProperty.call(message, "enableAutoReload"))
                                writer.uint32(/* id 11, wireType 0 =*/88).bool(message.enableAutoReload);
                            if (message.latestReloadStatus != null && Object.hasOwnProperty.call(message, "latestReloadStatus"))
                                $root.google.cloud.dialogflow.v2beta1.Document.ReloadStatus.encode(message.latestReloadStatus, writer.uint32(/* id 12, wireType 2 =*/98).fork()).ldelim();
                            if (message.state != null && Object.hasOwnProperty.call(message, "state"))
                                writer.uint32(/* id 13, wireType 0 =*/104).int32(message.state);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified Document message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Document.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.Document
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDocument} message Document message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        Document.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a Document message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.Document
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.Document} Document
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        Document.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Document(), key, value;
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.displayName = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.mimeType = reader.string();
                                        break;
                                    }
                                case 4: {
                                        if (!(message.knowledgeTypes && message.knowledgeTypes.length))
                                            message.knowledgeTypes = [];
                                        if ((tag & 7) === 2) {
                                            var end2 = reader.uint32() + reader.pos;
                                            while (reader.pos < end2)
                                                message.knowledgeTypes.push(reader.int32());
                                        } else
                                            message.knowledgeTypes.push(reader.int32());
                                        break;
                                    }
                                case 5: {
                                        message.contentUri = reader.string();
                                        break;
                                    }
                                case 6: {
                                        message.content = reader.string();
                                        break;
                                    }
                                case 9: {
                                        message.rawContent = reader.bytes();
                                        break;
                                    }
                                case 11: {
                                        message.enableAutoReload = reader.bool();
                                        break;
                                    }
                                case 12: {
                                        message.latestReloadStatus = $root.google.cloud.dialogflow.v2beta1.Document.ReloadStatus.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 7: {
                                        if (message.metadata === $util.emptyObject)
                                            message.metadata = {};
                                        var end2 = reader.uint32() + reader.pos;
                                        key = "";
                                        value = "";
                                        while (reader.pos < end2) {
                                            var tag2 = reader.uint32();
                                            switch (tag2 >>> 3) {
                                            case 1:
                                                key = reader.string();
                                                break;
                                            case 2:
                                                value = reader.string();
                                                break;
                                            default:
                                                reader.skipType(tag2 & 7);
                                                break;
                                            }
                                        }
                                        message.metadata[key] = value;
                                        break;
                                    }
                                case 13: {
                                        message.state = reader.int32();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a Document message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.Document
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.Document} Document
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        Document.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a Document message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.Document
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        Document.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            if (message.displayName != null && message.hasOwnProperty("displayName"))
                                if (!$util.isString(message.displayName))
                                    return "displayName: string expected";
                            if (message.mimeType != null && message.hasOwnProperty("mimeType"))
                                if (!$util.isString(message.mimeType))
                                    return "mimeType: string expected";
                            if (message.knowledgeTypes != null && message.hasOwnProperty("knowledgeTypes")) {
                                if (!Array.isArray(message.knowledgeTypes))
                                    return "knowledgeTypes: array expected";
                                for (var i = 0; i < message.knowledgeTypes.length; ++i)
                                    switch (message.knowledgeTypes[i]) {
                                    default:
                                        return "knowledgeTypes: enum value[] expected";
                                    case 0:
                                    case 1:
                                    case 2:
                                    case 3:
                                    case 4:
                                    case 4:
                                        break;
                                    }
                            }
                            if (message.contentUri != null && message.hasOwnProperty("contentUri")) {
                                properties.source = 1;
                                if (!$util.isString(message.contentUri))
                                    return "contentUri: string expected";
                            }
                            if (message.content != null && message.hasOwnProperty("content")) {
                                if (properties.source === 1)
                                    return "source: multiple values";
                                properties.source = 1;
                                if (!$util.isString(message.content))
                                    return "content: string expected";
                            }
                            if (message.rawContent != null && message.hasOwnProperty("rawContent")) {
                                if (properties.source === 1)
                                    return "source: multiple values";
                                properties.source = 1;
                                if (!(message.rawContent && typeof message.rawContent.length === "number" || $util.isString(message.rawContent)))
                                    return "rawContent: buffer expected";
                            }
                            if (message.enableAutoReload != null && message.hasOwnProperty("enableAutoReload"))
                                if (typeof message.enableAutoReload !== "boolean")
                                    return "enableAutoReload: boolean expected";
                            if (message.latestReloadStatus != null && message.hasOwnProperty("latestReloadStatus")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.Document.ReloadStatus.verify(message.latestReloadStatus);
                                if (error)
                                    return "latestReloadStatus." + error;
                            }
                            if (message.metadata != null && message.hasOwnProperty("metadata")) {
                                if (!$util.isObject(message.metadata))
                                    return "metadata: object expected";
                                var key = Object.keys(message.metadata);
                                for (var i = 0; i < key.length; ++i)
                                    if (!$util.isString(message.metadata[key[i]]))
                                        return "metadata: string{k:string} expected";
                            }
                            if (message.state != null && message.hasOwnProperty("state"))
                                switch (message.state) {
                                default:
                                    return "state: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                case 4:
                                case 5:
                                    break;
                                }
                            return null;
                        };
    
                        /**
                         * Creates a Document message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.Document
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.Document} Document
                         */
                        Document.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.Document)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.Document();
                            if (object.name != null)
                                message.name = String(object.name);
                            if (object.displayName != null)
                                message.displayName = String(object.displayName);
                            if (object.mimeType != null)
                                message.mimeType = String(object.mimeType);
                            if (object.knowledgeTypes) {
                                if (!Array.isArray(object.knowledgeTypes))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.Document.knowledgeTypes: array expected");
                                message.knowledgeTypes = [];
                                for (var i = 0; i < object.knowledgeTypes.length; ++i)
                                    switch (object.knowledgeTypes[i]) {
                                    default:
                                        if (typeof object.knowledgeTypes[i] === "number") {
                                            message.knowledgeTypes[i] = object.knowledgeTypes[i];
                                            break;
                                        }
                                    case "KNOWLEDGE_TYPE_UNSPECIFIED":
                                    case 0:
                                        message.knowledgeTypes[i] = 0;
                                        break;
                                    case "FAQ":
                                    case 1:
                                        message.knowledgeTypes[i] = 1;
                                        break;
                                    case "EXTRACTIVE_QA":
                                    case 2:
                                        message.knowledgeTypes[i] = 2;
                                        break;
                                    case "ARTICLE_SUGGESTION":
                                    case 3:
                                        message.knowledgeTypes[i] = 3;
                                        break;
                                    case "AGENT_FACING_SMART_REPLY":
                                    case 4:
                                        message.knowledgeTypes[i] = 4;
                                        break;
                                    case "SMART_REPLY":
                                    case 4:
                                        message.knowledgeTypes[i] = 4;
                                        break;
                                    }
                            }
                            if (object.contentUri != null)
                                message.contentUri = String(object.contentUri);
                            if (object.content != null)
                                message.content = String(object.content);
                            if (object.rawContent != null)
                                if (typeof object.rawContent === "string")
                                    $util.base64.decode(object.rawContent, message.rawContent = $util.newBuffer($util.base64.length(object.rawContent)), 0);
                                else if (object.rawContent.length >= 0)
                                    message.rawContent = object.rawContent;
                            if (object.enableAutoReload != null)
                                message.enableAutoReload = Boolean(object.enableAutoReload);
                            if (object.latestReloadStatus != null) {
                                if (typeof object.latestReloadStatus !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.Document.latestReloadStatus: object expected");
                                message.latestReloadStatus = $root.google.cloud.dialogflow.v2beta1.Document.ReloadStatus.fromObject(object.latestReloadStatus);
                            }
                            if (object.metadata) {
                                if (typeof object.metadata !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.Document.metadata: object expected");
                                message.metadata = {};
                                for (var keys = Object.keys(object.metadata), i = 0; i < keys.length; ++i)
                                    message.metadata[keys[i]] = String(object.metadata[keys[i]]);
                            }
                            switch (object.state) {
                            default:
                                if (typeof object.state === "number") {
                                    message.state = object.state;
                                    break;
                                }
                                break;
                            case "STATE_UNSPECIFIED":
                            case 0:
                                message.state = 0;
                                break;
                            case "CREATING":
                            case 1:
                                message.state = 1;
                                break;
                            case "ACTIVE":
                            case 2:
                                message.state = 2;
                                break;
                            case "UPDATING":
                            case 3:
                                message.state = 3;
                                break;
                            case "RELOADING":
                            case 4:
                                message.state = 4;
                                break;
                            case "DELETING":
                            case 5:
                                message.state = 5;
                                break;
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a Document message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.Document
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.Document} message Document
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        Document.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.knowledgeTypes = [];
                            if (options.objects || options.defaults)
                                object.metadata = {};
                            if (options.defaults) {
                                object.name = "";
                                object.displayName = "";
                                object.mimeType = "";
                                object.enableAutoReload = false;
                                object.latestReloadStatus = null;
                                object.state = options.enums === String ? "STATE_UNSPECIFIED" : 0;
                            }
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            if (message.displayName != null && message.hasOwnProperty("displayName"))
                                object.displayName = message.displayName;
                            if (message.mimeType != null && message.hasOwnProperty("mimeType"))
                                object.mimeType = message.mimeType;
                            if (message.knowledgeTypes && message.knowledgeTypes.length) {
                                object.knowledgeTypes = [];
                                for (var j = 0; j < message.knowledgeTypes.length; ++j)
                                    object.knowledgeTypes[j] = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.Document.KnowledgeType[message.knowledgeTypes[j]] === undefined ? message.knowledgeTypes[j] : $root.google.cloud.dialogflow.v2beta1.Document.KnowledgeType[message.knowledgeTypes[j]] : message.knowledgeTypes[j];
                            }
                            if (message.contentUri != null && message.hasOwnProperty("contentUri")) {
                                object.contentUri = message.contentUri;
                                if (options.oneofs)
                                    object.source = "contentUri";
                            }
                            if (message.content != null && message.hasOwnProperty("content")) {
                                object.content = message.content;
                                if (options.oneofs)
                                    object.source = "content";
                            }
                            var keys2;
                            if (message.metadata && (keys2 = Object.keys(message.metadata)).length) {
                                object.metadata = {};
                                for (var j = 0; j < keys2.length; ++j)
                                    object.metadata[keys2[j]] = message.metadata[keys2[j]];
                            }
                            if (message.rawContent != null && message.hasOwnProperty("rawContent")) {
                                object.rawContent = options.bytes === String ? $util.base64.encode(message.rawContent, 0, message.rawContent.length) : options.bytes === Array ? Array.prototype.slice.call(message.rawContent) : message.rawContent;
                                if (options.oneofs)
                                    object.source = "rawContent";
                            }
                            if (message.enableAutoReload != null && message.hasOwnProperty("enableAutoReload"))
                                object.enableAutoReload = message.enableAutoReload;
                            if (message.latestReloadStatus != null && message.hasOwnProperty("latestReloadStatus"))
                                object.latestReloadStatus = $root.google.cloud.dialogflow.v2beta1.Document.ReloadStatus.toObject(message.latestReloadStatus, options);
                            if (message.state != null && message.hasOwnProperty("state"))
                                object.state = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.Document.State[message.state] === undefined ? message.state : $root.google.cloud.dialogflow.v2beta1.Document.State[message.state] : message.state;
                            return object;
                        };
    
                        /**
                         * Converts this Document to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.Document
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        Document.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for Document
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.Document
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        Document.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Document";
                        };
    
                        /**
                         * KnowledgeType enum.
                         * @name google.cloud.dialogflow.v2beta1.Document.KnowledgeType
                         * @enum {number}
                         * @property {number} KNOWLEDGE_TYPE_UNSPECIFIED=0 KNOWLEDGE_TYPE_UNSPECIFIED value
                         * @property {number} FAQ=1 FAQ value
                         * @property {number} EXTRACTIVE_QA=2 EXTRACTIVE_QA value
                         * @property {number} ARTICLE_SUGGESTION=3 ARTICLE_SUGGESTION value
                         * @property {number} AGENT_FACING_SMART_REPLY=4 AGENT_FACING_SMART_REPLY value
                         * @property {number} SMART_REPLY=4 SMART_REPLY value
                         */
                        Document.KnowledgeType = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "KNOWLEDGE_TYPE_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "FAQ"] = 1;
                            values[valuesById[2] = "EXTRACTIVE_QA"] = 2;
                            values[valuesById[3] = "ARTICLE_SUGGESTION"] = 3;
                            values[valuesById[4] = "AGENT_FACING_SMART_REPLY"] = 4;
                            values["SMART_REPLY"] = 4;
                            return values;
                        })();
    
                        Document.ReloadStatus = (function() {
    
                            /**
                             * Properties of a ReloadStatus.
                             * @memberof google.cloud.dialogflow.v2beta1.Document
                             * @interface IReloadStatus
                             * @property {google.protobuf.ITimestamp|null} [time] ReloadStatus time
                             * @property {google.rpc.IStatus|null} [status] ReloadStatus status
                             */
    
                            /**
                             * Constructs a new ReloadStatus.
                             * @memberof google.cloud.dialogflow.v2beta1.Document
                             * @classdesc Represents a ReloadStatus.
                             * @implements IReloadStatus
                             * @constructor
                             * @param {google.cloud.dialogflow.v2beta1.Document.IReloadStatus=} [properties] Properties to set
                             */
                            function ReloadStatus(properties) {
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * ReloadStatus time.
                             * @member {google.protobuf.ITimestamp|null|undefined} time
                             * @memberof google.cloud.dialogflow.v2beta1.Document.ReloadStatus
                             * @instance
                             */
                            ReloadStatus.prototype.time = null;
    
                            /**
                             * ReloadStatus status.
                             * @member {google.rpc.IStatus|null|undefined} status
                             * @memberof google.cloud.dialogflow.v2beta1.Document.ReloadStatus
                             * @instance
                             */
                            ReloadStatus.prototype.status = null;
    
                            /**
                             * Creates a new ReloadStatus instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2beta1.Document.ReloadStatus
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.Document.IReloadStatus=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2beta1.Document.ReloadStatus} ReloadStatus instance
                             */
                            ReloadStatus.create = function create(properties) {
                                return new ReloadStatus(properties);
                            };
    
                            /**
                             * Encodes the specified ReloadStatus message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Document.ReloadStatus.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2beta1.Document.ReloadStatus
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.Document.IReloadStatus} message ReloadStatus message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            ReloadStatus.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.time != null && Object.hasOwnProperty.call(message, "time"))
                                    $root.google.protobuf.Timestamp.encode(message.time, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                                if (message.status != null && Object.hasOwnProperty.call(message, "status"))
                                    $root.google.rpc.Status.encode(message.status, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                                return writer;
                            };
    
                            /**
                             * Encodes the specified ReloadStatus message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Document.ReloadStatus.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.Document.ReloadStatus
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.Document.IReloadStatus} message ReloadStatus message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            ReloadStatus.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a ReloadStatus message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2beta1.Document.ReloadStatus
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2beta1.Document.ReloadStatus} ReloadStatus
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            ReloadStatus.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Document.ReloadStatus();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.time = $root.google.protobuf.Timestamp.decode(reader, reader.uint32());
                                            break;
                                        }
                                    case 2: {
                                            message.status = $root.google.rpc.Status.decode(reader, reader.uint32());
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a ReloadStatus message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.Document.ReloadStatus
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2beta1.Document.ReloadStatus} ReloadStatus
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            ReloadStatus.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a ReloadStatus message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2beta1.Document.ReloadStatus
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            ReloadStatus.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.time != null && message.hasOwnProperty("time")) {
                                    var error = $root.google.protobuf.Timestamp.verify(message.time);
                                    if (error)
                                        return "time." + error;
                                }
                                if (message.status != null && message.hasOwnProperty("status")) {
                                    var error = $root.google.rpc.Status.verify(message.status);
                                    if (error)
                                        return "status." + error;
                                }
                                return null;
                            };
    
                            /**
                             * Creates a ReloadStatus message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2beta1.Document.ReloadStatus
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2beta1.Document.ReloadStatus} ReloadStatus
                             */
                            ReloadStatus.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2beta1.Document.ReloadStatus)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2beta1.Document.ReloadStatus();
                                if (object.time != null) {
                                    if (typeof object.time !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.Document.ReloadStatus.time: object expected");
                                    message.time = $root.google.protobuf.Timestamp.fromObject(object.time);
                                }
                                if (object.status != null) {
                                    if (typeof object.status !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.Document.ReloadStatus.status: object expected");
                                    message.status = $root.google.rpc.Status.fromObject(object.status);
                                }
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a ReloadStatus message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2beta1.Document.ReloadStatus
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.Document.ReloadStatus} message ReloadStatus
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            ReloadStatus.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.defaults) {
                                    object.time = null;
                                    object.status = null;
                                }
                                if (message.time != null && message.hasOwnProperty("time"))
                                    object.time = $root.google.protobuf.Timestamp.toObject(message.time, options);
                                if (message.status != null && message.hasOwnProperty("status"))
                                    object.status = $root.google.rpc.Status.toObject(message.status, options);
                                return object;
                            };
    
                            /**
                             * Converts this ReloadStatus to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2beta1.Document.ReloadStatus
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            ReloadStatus.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for ReloadStatus
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2beta1.Document.ReloadStatus
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            ReloadStatus.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Document.ReloadStatus";
                            };
    
                            return ReloadStatus;
                        })();
    
                        /**
                         * State enum.
                         * @name google.cloud.dialogflow.v2beta1.Document.State
                         * @enum {number}
                         * @property {number} STATE_UNSPECIFIED=0 STATE_UNSPECIFIED value
                         * @property {number} CREATING=1 CREATING value
                         * @property {number} ACTIVE=2 ACTIVE value
                         * @property {number} UPDATING=3 UPDATING value
                         * @property {number} RELOADING=4 RELOADING value
                         * @property {number} DELETING=5 DELETING value
                         */
                        Document.State = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "STATE_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "CREATING"] = 1;
                            values[valuesById[2] = "ACTIVE"] = 2;
                            values[valuesById[3] = "UPDATING"] = 3;
                            values[valuesById[4] = "RELOADING"] = 4;
                            values[valuesById[5] = "DELETING"] = 5;
                            return values;
                        })();
    
                        return Document;
                    })();
    
                    v2beta1.GetDocumentRequest = (function() {
    
                        /**
                         * Properties of a GetDocumentRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IGetDocumentRequest
                         * @property {string|null} [name] GetDocumentRequest name
                         */
    
                        /**
                         * Constructs a new GetDocumentRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a GetDocumentRequest.
                         * @implements IGetDocumentRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IGetDocumentRequest=} [properties] Properties to set
                         */
                        function GetDocumentRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GetDocumentRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2beta1.GetDocumentRequest
                         * @instance
                         */
                        GetDocumentRequest.prototype.name = "";
    
                        /**
                         * Creates a new GetDocumentRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.GetDocumentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetDocumentRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.GetDocumentRequest} GetDocumentRequest instance
                         */
                        GetDocumentRequest.create = function create(properties) {
                            return new GetDocumentRequest(properties);
                        };
    
                        /**
                         * Encodes the specified GetDocumentRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GetDocumentRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.GetDocumentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetDocumentRequest} message GetDocumentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetDocumentRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GetDocumentRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GetDocumentRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GetDocumentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetDocumentRequest} message GetDocumentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetDocumentRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GetDocumentRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.GetDocumentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.GetDocumentRequest} GetDocumentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetDocumentRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.GetDocumentRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GetDocumentRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GetDocumentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.GetDocumentRequest} GetDocumentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetDocumentRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GetDocumentRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.GetDocumentRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GetDocumentRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a GetDocumentRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.GetDocumentRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.GetDocumentRequest} GetDocumentRequest
                         */
                        GetDocumentRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.GetDocumentRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.GetDocumentRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GetDocumentRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.GetDocumentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.GetDocumentRequest} message GetDocumentRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GetDocumentRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.name = "";
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            return object;
                        };
    
                        /**
                         * Converts this GetDocumentRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.GetDocumentRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GetDocumentRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GetDocumentRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.GetDocumentRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GetDocumentRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.GetDocumentRequest";
                        };
    
                        return GetDocumentRequest;
                    })();
    
                    v2beta1.ListDocumentsRequest = (function() {
    
                        /**
                         * Properties of a ListDocumentsRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IListDocumentsRequest
                         * @property {string|null} [parent] ListDocumentsRequest parent
                         * @property {number|null} [pageSize] ListDocumentsRequest pageSize
                         * @property {string|null} [pageToken] ListDocumentsRequest pageToken
                         * @property {string|null} [filter] ListDocumentsRequest filter
                         */
    
                        /**
                         * Constructs a new ListDocumentsRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a ListDocumentsRequest.
                         * @implements IListDocumentsRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IListDocumentsRequest=} [properties] Properties to set
                         */
                        function ListDocumentsRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListDocumentsRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.ListDocumentsRequest
                         * @instance
                         */
                        ListDocumentsRequest.prototype.parent = "";
    
                        /**
                         * ListDocumentsRequest pageSize.
                         * @member {number} pageSize
                         * @memberof google.cloud.dialogflow.v2beta1.ListDocumentsRequest
                         * @instance
                         */
                        ListDocumentsRequest.prototype.pageSize = 0;
    
                        /**
                         * ListDocumentsRequest pageToken.
                         * @member {string} pageToken
                         * @memberof google.cloud.dialogflow.v2beta1.ListDocumentsRequest
                         * @instance
                         */
                        ListDocumentsRequest.prototype.pageToken = "";
    
                        /**
                         * ListDocumentsRequest filter.
                         * @member {string} filter
                         * @memberof google.cloud.dialogflow.v2beta1.ListDocumentsRequest
                         * @instance
                         */
                        ListDocumentsRequest.prototype.filter = "";
    
                        /**
                         * Creates a new ListDocumentsRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.ListDocumentsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListDocumentsRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.ListDocumentsRequest} ListDocumentsRequest instance
                         */
                        ListDocumentsRequest.create = function create(properties) {
                            return new ListDocumentsRequest(properties);
                        };
    
                        /**
                         * Encodes the specified ListDocumentsRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListDocumentsRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.ListDocumentsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListDocumentsRequest} message ListDocumentsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListDocumentsRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.pageSize != null && Object.hasOwnProperty.call(message, "pageSize"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.pageSize);
                            if (message.pageToken != null && Object.hasOwnProperty.call(message, "pageToken"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.pageToken);
                            if (message.filter != null && Object.hasOwnProperty.call(message, "filter"))
                                writer.uint32(/* id 4, wireType 2 =*/34).string(message.filter);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListDocumentsRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListDocumentsRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListDocumentsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListDocumentsRequest} message ListDocumentsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListDocumentsRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListDocumentsRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.ListDocumentsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.ListDocumentsRequest} ListDocumentsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListDocumentsRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ListDocumentsRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.pageSize = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.pageToken = reader.string();
                                        break;
                                    }
                                case 4: {
                                        message.filter = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListDocumentsRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListDocumentsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.ListDocumentsRequest} ListDocumentsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListDocumentsRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListDocumentsRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.ListDocumentsRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListDocumentsRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                if (!$util.isInteger(message.pageSize))
                                    return "pageSize: integer expected";
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                if (!$util.isString(message.pageToken))
                                    return "pageToken: string expected";
                            if (message.filter != null && message.hasOwnProperty("filter"))
                                if (!$util.isString(message.filter))
                                    return "filter: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListDocumentsRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListDocumentsRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.ListDocumentsRequest} ListDocumentsRequest
                         */
                        ListDocumentsRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.ListDocumentsRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.ListDocumentsRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.pageSize != null)
                                message.pageSize = object.pageSize | 0;
                            if (object.pageToken != null)
                                message.pageToken = String(object.pageToken);
                            if (object.filter != null)
                                message.filter = String(object.filter);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListDocumentsRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListDocumentsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ListDocumentsRequest} message ListDocumentsRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListDocumentsRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.pageSize = 0;
                                object.pageToken = "";
                                object.filter = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                object.pageSize = message.pageSize;
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                object.pageToken = message.pageToken;
                            if (message.filter != null && message.hasOwnProperty("filter"))
                                object.filter = message.filter;
                            return object;
                        };
    
                        /**
                         * Converts this ListDocumentsRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.ListDocumentsRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListDocumentsRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListDocumentsRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.ListDocumentsRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListDocumentsRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ListDocumentsRequest";
                        };
    
                        return ListDocumentsRequest;
                    })();
    
                    v2beta1.ListDocumentsResponse = (function() {
    
                        /**
                         * Properties of a ListDocumentsResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IListDocumentsResponse
                         * @property {Array.<google.cloud.dialogflow.v2beta1.IDocument>|null} [documents] ListDocumentsResponse documents
                         * @property {string|null} [nextPageToken] ListDocumentsResponse nextPageToken
                         */
    
                        /**
                         * Constructs a new ListDocumentsResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a ListDocumentsResponse.
                         * @implements IListDocumentsResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IListDocumentsResponse=} [properties] Properties to set
                         */
                        function ListDocumentsResponse(properties) {
                            this.documents = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListDocumentsResponse documents.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.IDocument>} documents
                         * @memberof google.cloud.dialogflow.v2beta1.ListDocumentsResponse
                         * @instance
                         */
                        ListDocumentsResponse.prototype.documents = $util.emptyArray;
    
                        /**
                         * ListDocumentsResponse nextPageToken.
                         * @member {string} nextPageToken
                         * @memberof google.cloud.dialogflow.v2beta1.ListDocumentsResponse
                         * @instance
                         */
                        ListDocumentsResponse.prototype.nextPageToken = "";
    
                        /**
                         * Creates a new ListDocumentsResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.ListDocumentsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListDocumentsResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.ListDocumentsResponse} ListDocumentsResponse instance
                         */
                        ListDocumentsResponse.create = function create(properties) {
                            return new ListDocumentsResponse(properties);
                        };
    
                        /**
                         * Encodes the specified ListDocumentsResponse message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListDocumentsResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.ListDocumentsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListDocumentsResponse} message ListDocumentsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListDocumentsResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.documents != null && message.documents.length)
                                for (var i = 0; i < message.documents.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.Document.encode(message.documents[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.nextPageToken != null && Object.hasOwnProperty.call(message, "nextPageToken"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.nextPageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListDocumentsResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListDocumentsResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListDocumentsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListDocumentsResponse} message ListDocumentsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListDocumentsResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListDocumentsResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.ListDocumentsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.ListDocumentsResponse} ListDocumentsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListDocumentsResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ListDocumentsResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.documents && message.documents.length))
                                            message.documents = [];
                                        message.documents.push($root.google.cloud.dialogflow.v2beta1.Document.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 2: {
                                        message.nextPageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListDocumentsResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListDocumentsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.ListDocumentsResponse} ListDocumentsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListDocumentsResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListDocumentsResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.ListDocumentsResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListDocumentsResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.documents != null && message.hasOwnProperty("documents")) {
                                if (!Array.isArray(message.documents))
                                    return "documents: array expected";
                                for (var i = 0; i < message.documents.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.Document.verify(message.documents[i]);
                                    if (error)
                                        return "documents." + error;
                                }
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                if (!$util.isString(message.nextPageToken))
                                    return "nextPageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListDocumentsResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListDocumentsResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.ListDocumentsResponse} ListDocumentsResponse
                         */
                        ListDocumentsResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.ListDocumentsResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.ListDocumentsResponse();
                            if (object.documents) {
                                if (!Array.isArray(object.documents))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.ListDocumentsResponse.documents: array expected");
                                message.documents = [];
                                for (var i = 0; i < object.documents.length; ++i) {
                                    if (typeof object.documents[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.ListDocumentsResponse.documents: object expected");
                                    message.documents[i] = $root.google.cloud.dialogflow.v2beta1.Document.fromObject(object.documents[i]);
                                }
                            }
                            if (object.nextPageToken != null)
                                message.nextPageToken = String(object.nextPageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListDocumentsResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListDocumentsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ListDocumentsResponse} message ListDocumentsResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListDocumentsResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.documents = [];
                            if (options.defaults)
                                object.nextPageToken = "";
                            if (message.documents && message.documents.length) {
                                object.documents = [];
                                for (var j = 0; j < message.documents.length; ++j)
                                    object.documents[j] = $root.google.cloud.dialogflow.v2beta1.Document.toObject(message.documents[j], options);
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                object.nextPageToken = message.nextPageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListDocumentsResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.ListDocumentsResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListDocumentsResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListDocumentsResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.ListDocumentsResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListDocumentsResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ListDocumentsResponse";
                        };
    
                        return ListDocumentsResponse;
                    })();
    
                    v2beta1.CreateDocumentRequest = (function() {
    
                        /**
                         * Properties of a CreateDocumentRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ICreateDocumentRequest
                         * @property {string|null} [parent] CreateDocumentRequest parent
                         * @property {google.cloud.dialogflow.v2beta1.IDocument|null} [document] CreateDocumentRequest document
                         * @property {boolean|null} [importGcsCustomMetadata] CreateDocumentRequest importGcsCustomMetadata
                         */
    
                        /**
                         * Constructs a new CreateDocumentRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a CreateDocumentRequest.
                         * @implements ICreateDocumentRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ICreateDocumentRequest=} [properties] Properties to set
                         */
                        function CreateDocumentRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * CreateDocumentRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.CreateDocumentRequest
                         * @instance
                         */
                        CreateDocumentRequest.prototype.parent = "";
    
                        /**
                         * CreateDocumentRequest document.
                         * @member {google.cloud.dialogflow.v2beta1.IDocument|null|undefined} document
                         * @memberof google.cloud.dialogflow.v2beta1.CreateDocumentRequest
                         * @instance
                         */
                        CreateDocumentRequest.prototype.document = null;
    
                        /**
                         * CreateDocumentRequest importGcsCustomMetadata.
                         * @member {boolean} importGcsCustomMetadata
                         * @memberof google.cloud.dialogflow.v2beta1.CreateDocumentRequest
                         * @instance
                         */
                        CreateDocumentRequest.prototype.importGcsCustomMetadata = false;
    
                        /**
                         * Creates a new CreateDocumentRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.CreateDocumentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ICreateDocumentRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.CreateDocumentRequest} CreateDocumentRequest instance
                         */
                        CreateDocumentRequest.create = function create(properties) {
                            return new CreateDocumentRequest(properties);
                        };
    
                        /**
                         * Encodes the specified CreateDocumentRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.CreateDocumentRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.CreateDocumentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ICreateDocumentRequest} message CreateDocumentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateDocumentRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.document != null && Object.hasOwnProperty.call(message, "document"))
                                $root.google.cloud.dialogflow.v2beta1.Document.encode(message.document, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.importGcsCustomMetadata != null && Object.hasOwnProperty.call(message, "importGcsCustomMetadata"))
                                writer.uint32(/* id 3, wireType 0 =*/24).bool(message.importGcsCustomMetadata);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified CreateDocumentRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.CreateDocumentRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.CreateDocumentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ICreateDocumentRequest} message CreateDocumentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateDocumentRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a CreateDocumentRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.CreateDocumentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.CreateDocumentRequest} CreateDocumentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateDocumentRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.CreateDocumentRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.document = $root.google.cloud.dialogflow.v2beta1.Document.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 3: {
                                        message.importGcsCustomMetadata = reader.bool();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a CreateDocumentRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.CreateDocumentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.CreateDocumentRequest} CreateDocumentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateDocumentRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a CreateDocumentRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.CreateDocumentRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        CreateDocumentRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.document != null && message.hasOwnProperty("document")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.Document.verify(message.document);
                                if (error)
                                    return "document." + error;
                            }
                            if (message.importGcsCustomMetadata != null && message.hasOwnProperty("importGcsCustomMetadata"))
                                if (typeof message.importGcsCustomMetadata !== "boolean")
                                    return "importGcsCustomMetadata: boolean expected";
                            return null;
                        };
    
                        /**
                         * Creates a CreateDocumentRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.CreateDocumentRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.CreateDocumentRequest} CreateDocumentRequest
                         */
                        CreateDocumentRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.CreateDocumentRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.CreateDocumentRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.document != null) {
                                if (typeof object.document !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.CreateDocumentRequest.document: object expected");
                                message.document = $root.google.cloud.dialogflow.v2beta1.Document.fromObject(object.document);
                            }
                            if (object.importGcsCustomMetadata != null)
                                message.importGcsCustomMetadata = Boolean(object.importGcsCustomMetadata);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a CreateDocumentRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.CreateDocumentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.CreateDocumentRequest} message CreateDocumentRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        CreateDocumentRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.document = null;
                                object.importGcsCustomMetadata = false;
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.document != null && message.hasOwnProperty("document"))
                                object.document = $root.google.cloud.dialogflow.v2beta1.Document.toObject(message.document, options);
                            if (message.importGcsCustomMetadata != null && message.hasOwnProperty("importGcsCustomMetadata"))
                                object.importGcsCustomMetadata = message.importGcsCustomMetadata;
                            return object;
                        };
    
                        /**
                         * Converts this CreateDocumentRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.CreateDocumentRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        CreateDocumentRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for CreateDocumentRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.CreateDocumentRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        CreateDocumentRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.CreateDocumentRequest";
                        };
    
                        return CreateDocumentRequest;
                    })();
    
                    v2beta1.ImportDocumentsRequest = (function() {
    
                        /**
                         * Properties of an ImportDocumentsRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IImportDocumentsRequest
                         * @property {string|null} [parent] ImportDocumentsRequest parent
                         * @property {google.cloud.dialogflow.v2beta1.IGcsSources|null} [gcsSource] ImportDocumentsRequest gcsSource
                         * @property {google.cloud.dialogflow.v2beta1.IImportDocumentTemplate|null} [documentTemplate] ImportDocumentsRequest documentTemplate
                         * @property {boolean|null} [importGcsCustomMetadata] ImportDocumentsRequest importGcsCustomMetadata
                         */
    
                        /**
                         * Constructs a new ImportDocumentsRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an ImportDocumentsRequest.
                         * @implements IImportDocumentsRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IImportDocumentsRequest=} [properties] Properties to set
                         */
                        function ImportDocumentsRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ImportDocumentsRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.ImportDocumentsRequest
                         * @instance
                         */
                        ImportDocumentsRequest.prototype.parent = "";
    
                        /**
                         * ImportDocumentsRequest gcsSource.
                         * @member {google.cloud.dialogflow.v2beta1.IGcsSources|null|undefined} gcsSource
                         * @memberof google.cloud.dialogflow.v2beta1.ImportDocumentsRequest
                         * @instance
                         */
                        ImportDocumentsRequest.prototype.gcsSource = null;
    
                        /**
                         * ImportDocumentsRequest documentTemplate.
                         * @member {google.cloud.dialogflow.v2beta1.IImportDocumentTemplate|null|undefined} documentTemplate
                         * @memberof google.cloud.dialogflow.v2beta1.ImportDocumentsRequest
                         * @instance
                         */
                        ImportDocumentsRequest.prototype.documentTemplate = null;
    
                        /**
                         * ImportDocumentsRequest importGcsCustomMetadata.
                         * @member {boolean} importGcsCustomMetadata
                         * @memberof google.cloud.dialogflow.v2beta1.ImportDocumentsRequest
                         * @instance
                         */
                        ImportDocumentsRequest.prototype.importGcsCustomMetadata = false;
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * ImportDocumentsRequest source.
                         * @member {"gcsSource"|undefined} source
                         * @memberof google.cloud.dialogflow.v2beta1.ImportDocumentsRequest
                         * @instance
                         */
                        Object.defineProperty(ImportDocumentsRequest.prototype, "source", {
                            get: $util.oneOfGetter($oneOfFields = ["gcsSource"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new ImportDocumentsRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.ImportDocumentsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IImportDocumentsRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.ImportDocumentsRequest} ImportDocumentsRequest instance
                         */
                        ImportDocumentsRequest.create = function create(properties) {
                            return new ImportDocumentsRequest(properties);
                        };
    
                        /**
                         * Encodes the specified ImportDocumentsRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ImportDocumentsRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.ImportDocumentsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IImportDocumentsRequest} message ImportDocumentsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ImportDocumentsRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.gcsSource != null && Object.hasOwnProperty.call(message, "gcsSource"))
                                $root.google.cloud.dialogflow.v2beta1.GcsSources.encode(message.gcsSource, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.documentTemplate != null && Object.hasOwnProperty.call(message, "documentTemplate"))
                                $root.google.cloud.dialogflow.v2beta1.ImportDocumentTemplate.encode(message.documentTemplate, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            if (message.importGcsCustomMetadata != null && Object.hasOwnProperty.call(message, "importGcsCustomMetadata"))
                                writer.uint32(/* id 4, wireType 0 =*/32).bool(message.importGcsCustomMetadata);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ImportDocumentsRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ImportDocumentsRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ImportDocumentsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IImportDocumentsRequest} message ImportDocumentsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ImportDocumentsRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an ImportDocumentsRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.ImportDocumentsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.ImportDocumentsRequest} ImportDocumentsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ImportDocumentsRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ImportDocumentsRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.gcsSource = $root.google.cloud.dialogflow.v2beta1.GcsSources.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 3: {
                                        message.documentTemplate = $root.google.cloud.dialogflow.v2beta1.ImportDocumentTemplate.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 4: {
                                        message.importGcsCustomMetadata = reader.bool();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an ImportDocumentsRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ImportDocumentsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.ImportDocumentsRequest} ImportDocumentsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ImportDocumentsRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an ImportDocumentsRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.ImportDocumentsRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ImportDocumentsRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.gcsSource != null && message.hasOwnProperty("gcsSource")) {
                                properties.source = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2beta1.GcsSources.verify(message.gcsSource);
                                    if (error)
                                        return "gcsSource." + error;
                                }
                            }
                            if (message.documentTemplate != null && message.hasOwnProperty("documentTemplate")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.ImportDocumentTemplate.verify(message.documentTemplate);
                                if (error)
                                    return "documentTemplate." + error;
                            }
                            if (message.importGcsCustomMetadata != null && message.hasOwnProperty("importGcsCustomMetadata"))
                                if (typeof message.importGcsCustomMetadata !== "boolean")
                                    return "importGcsCustomMetadata: boolean expected";
                            return null;
                        };
    
                        /**
                         * Creates an ImportDocumentsRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.ImportDocumentsRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.ImportDocumentsRequest} ImportDocumentsRequest
                         */
                        ImportDocumentsRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.ImportDocumentsRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.ImportDocumentsRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.gcsSource != null) {
                                if (typeof object.gcsSource !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.ImportDocumentsRequest.gcsSource: object expected");
                                message.gcsSource = $root.google.cloud.dialogflow.v2beta1.GcsSources.fromObject(object.gcsSource);
                            }
                            if (object.documentTemplate != null) {
                                if (typeof object.documentTemplate !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.ImportDocumentsRequest.documentTemplate: object expected");
                                message.documentTemplate = $root.google.cloud.dialogflow.v2beta1.ImportDocumentTemplate.fromObject(object.documentTemplate);
                            }
                            if (object.importGcsCustomMetadata != null)
                                message.importGcsCustomMetadata = Boolean(object.importGcsCustomMetadata);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an ImportDocumentsRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.ImportDocumentsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ImportDocumentsRequest} message ImportDocumentsRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ImportDocumentsRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.documentTemplate = null;
                                object.importGcsCustomMetadata = false;
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.gcsSource != null && message.hasOwnProperty("gcsSource")) {
                                object.gcsSource = $root.google.cloud.dialogflow.v2beta1.GcsSources.toObject(message.gcsSource, options);
                                if (options.oneofs)
                                    object.source = "gcsSource";
                            }
                            if (message.documentTemplate != null && message.hasOwnProperty("documentTemplate"))
                                object.documentTemplate = $root.google.cloud.dialogflow.v2beta1.ImportDocumentTemplate.toObject(message.documentTemplate, options);
                            if (message.importGcsCustomMetadata != null && message.hasOwnProperty("importGcsCustomMetadata"))
                                object.importGcsCustomMetadata = message.importGcsCustomMetadata;
                            return object;
                        };
    
                        /**
                         * Converts this ImportDocumentsRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.ImportDocumentsRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ImportDocumentsRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ImportDocumentsRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.ImportDocumentsRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ImportDocumentsRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ImportDocumentsRequest";
                        };
    
                        return ImportDocumentsRequest;
                    })();
    
                    v2beta1.ImportDocumentTemplate = (function() {
    
                        /**
                         * Properties of an ImportDocumentTemplate.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IImportDocumentTemplate
                         * @property {string|null} [mimeType] ImportDocumentTemplate mimeType
                         * @property {Array.<google.cloud.dialogflow.v2beta1.Document.KnowledgeType>|null} [knowledgeTypes] ImportDocumentTemplate knowledgeTypes
                         * @property {Object.<string,string>|null} [metadata] ImportDocumentTemplate metadata
                         */
    
                        /**
                         * Constructs a new ImportDocumentTemplate.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an ImportDocumentTemplate.
                         * @implements IImportDocumentTemplate
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IImportDocumentTemplate=} [properties] Properties to set
                         */
                        function ImportDocumentTemplate(properties) {
                            this.knowledgeTypes = [];
                            this.metadata = {};
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ImportDocumentTemplate mimeType.
                         * @member {string} mimeType
                         * @memberof google.cloud.dialogflow.v2beta1.ImportDocumentTemplate
                         * @instance
                         */
                        ImportDocumentTemplate.prototype.mimeType = "";
    
                        /**
                         * ImportDocumentTemplate knowledgeTypes.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.Document.KnowledgeType>} knowledgeTypes
                         * @memberof google.cloud.dialogflow.v2beta1.ImportDocumentTemplate
                         * @instance
                         */
                        ImportDocumentTemplate.prototype.knowledgeTypes = $util.emptyArray;
    
                        /**
                         * ImportDocumentTemplate metadata.
                         * @member {Object.<string,string>} metadata
                         * @memberof google.cloud.dialogflow.v2beta1.ImportDocumentTemplate
                         * @instance
                         */
                        ImportDocumentTemplate.prototype.metadata = $util.emptyObject;
    
                        /**
                         * Creates a new ImportDocumentTemplate instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.ImportDocumentTemplate
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IImportDocumentTemplate=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.ImportDocumentTemplate} ImportDocumentTemplate instance
                         */
                        ImportDocumentTemplate.create = function create(properties) {
                            return new ImportDocumentTemplate(properties);
                        };
    
                        /**
                         * Encodes the specified ImportDocumentTemplate message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ImportDocumentTemplate.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.ImportDocumentTemplate
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IImportDocumentTemplate} message ImportDocumentTemplate message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ImportDocumentTemplate.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.mimeType != null && Object.hasOwnProperty.call(message, "mimeType"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.mimeType);
                            if (message.knowledgeTypes != null && message.knowledgeTypes.length) {
                                writer.uint32(/* id 2, wireType 2 =*/18).fork();
                                for (var i = 0; i < message.knowledgeTypes.length; ++i)
                                    writer.int32(message.knowledgeTypes[i]);
                                writer.ldelim();
                            }
                            if (message.metadata != null && Object.hasOwnProperty.call(message, "metadata"))
                                for (var keys = Object.keys(message.metadata), i = 0; i < keys.length; ++i)
                                    writer.uint32(/* id 3, wireType 2 =*/26).fork().uint32(/* id 1, wireType 2 =*/10).string(keys[i]).uint32(/* id 2, wireType 2 =*/18).string(message.metadata[keys[i]]).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ImportDocumentTemplate message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ImportDocumentTemplate.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ImportDocumentTemplate
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IImportDocumentTemplate} message ImportDocumentTemplate message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ImportDocumentTemplate.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an ImportDocumentTemplate message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.ImportDocumentTemplate
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.ImportDocumentTemplate} ImportDocumentTemplate
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ImportDocumentTemplate.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ImportDocumentTemplate(), key, value;
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.mimeType = reader.string();
                                        break;
                                    }
                                case 2: {
                                        if (!(message.knowledgeTypes && message.knowledgeTypes.length))
                                            message.knowledgeTypes = [];
                                        if ((tag & 7) === 2) {
                                            var end2 = reader.uint32() + reader.pos;
                                            while (reader.pos < end2)
                                                message.knowledgeTypes.push(reader.int32());
                                        } else
                                            message.knowledgeTypes.push(reader.int32());
                                        break;
                                    }
                                case 3: {
                                        if (message.metadata === $util.emptyObject)
                                            message.metadata = {};
                                        var end2 = reader.uint32() + reader.pos;
                                        key = "";
                                        value = "";
                                        while (reader.pos < end2) {
                                            var tag2 = reader.uint32();
                                            switch (tag2 >>> 3) {
                                            case 1:
                                                key = reader.string();
                                                break;
                                            case 2:
                                                value = reader.string();
                                                break;
                                            default:
                                                reader.skipType(tag2 & 7);
                                                break;
                                            }
                                        }
                                        message.metadata[key] = value;
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an ImportDocumentTemplate message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ImportDocumentTemplate
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.ImportDocumentTemplate} ImportDocumentTemplate
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ImportDocumentTemplate.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an ImportDocumentTemplate message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.ImportDocumentTemplate
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ImportDocumentTemplate.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.mimeType != null && message.hasOwnProperty("mimeType"))
                                if (!$util.isString(message.mimeType))
                                    return "mimeType: string expected";
                            if (message.knowledgeTypes != null && message.hasOwnProperty("knowledgeTypes")) {
                                if (!Array.isArray(message.knowledgeTypes))
                                    return "knowledgeTypes: array expected";
                                for (var i = 0; i < message.knowledgeTypes.length; ++i)
                                    switch (message.knowledgeTypes[i]) {
                                    default:
                                        return "knowledgeTypes: enum value[] expected";
                                    case 0:
                                    case 1:
                                    case 2:
                                    case 3:
                                    case 4:
                                    case 4:
                                        break;
                                    }
                            }
                            if (message.metadata != null && message.hasOwnProperty("metadata")) {
                                if (!$util.isObject(message.metadata))
                                    return "metadata: object expected";
                                var key = Object.keys(message.metadata);
                                for (var i = 0; i < key.length; ++i)
                                    if (!$util.isString(message.metadata[key[i]]))
                                        return "metadata: string{k:string} expected";
                            }
                            return null;
                        };
    
                        /**
                         * Creates an ImportDocumentTemplate message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.ImportDocumentTemplate
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.ImportDocumentTemplate} ImportDocumentTemplate
                         */
                        ImportDocumentTemplate.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.ImportDocumentTemplate)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.ImportDocumentTemplate();
                            if (object.mimeType != null)
                                message.mimeType = String(object.mimeType);
                            if (object.knowledgeTypes) {
                                if (!Array.isArray(object.knowledgeTypes))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.ImportDocumentTemplate.knowledgeTypes: array expected");
                                message.knowledgeTypes = [];
                                for (var i = 0; i < object.knowledgeTypes.length; ++i)
                                    switch (object.knowledgeTypes[i]) {
                                    default:
                                        if (typeof object.knowledgeTypes[i] === "number") {
                                            message.knowledgeTypes[i] = object.knowledgeTypes[i];
                                            break;
                                        }
                                    case "KNOWLEDGE_TYPE_UNSPECIFIED":
                                    case 0:
                                        message.knowledgeTypes[i] = 0;
                                        break;
                                    case "FAQ":
                                    case 1:
                                        message.knowledgeTypes[i] = 1;
                                        break;
                                    case "EXTRACTIVE_QA":
                                    case 2:
                                        message.knowledgeTypes[i] = 2;
                                        break;
                                    case "ARTICLE_SUGGESTION":
                                    case 3:
                                        message.knowledgeTypes[i] = 3;
                                        break;
                                    case "AGENT_FACING_SMART_REPLY":
                                    case 4:
                                        message.knowledgeTypes[i] = 4;
                                        break;
                                    case "SMART_REPLY":
                                    case 4:
                                        message.knowledgeTypes[i] = 4;
                                        break;
                                    }
                            }
                            if (object.metadata) {
                                if (typeof object.metadata !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.ImportDocumentTemplate.metadata: object expected");
                                message.metadata = {};
                                for (var keys = Object.keys(object.metadata), i = 0; i < keys.length; ++i)
                                    message.metadata[keys[i]] = String(object.metadata[keys[i]]);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an ImportDocumentTemplate message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.ImportDocumentTemplate
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ImportDocumentTemplate} message ImportDocumentTemplate
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ImportDocumentTemplate.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.knowledgeTypes = [];
                            if (options.objects || options.defaults)
                                object.metadata = {};
                            if (options.defaults)
                                object.mimeType = "";
                            if (message.mimeType != null && message.hasOwnProperty("mimeType"))
                                object.mimeType = message.mimeType;
                            if (message.knowledgeTypes && message.knowledgeTypes.length) {
                                object.knowledgeTypes = [];
                                for (var j = 0; j < message.knowledgeTypes.length; ++j)
                                    object.knowledgeTypes[j] = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.Document.KnowledgeType[message.knowledgeTypes[j]] === undefined ? message.knowledgeTypes[j] : $root.google.cloud.dialogflow.v2beta1.Document.KnowledgeType[message.knowledgeTypes[j]] : message.knowledgeTypes[j];
                            }
                            var keys2;
                            if (message.metadata && (keys2 = Object.keys(message.metadata)).length) {
                                object.metadata = {};
                                for (var j = 0; j < keys2.length; ++j)
                                    object.metadata[keys2[j]] = message.metadata[keys2[j]];
                            }
                            return object;
                        };
    
                        /**
                         * Converts this ImportDocumentTemplate to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.ImportDocumentTemplate
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ImportDocumentTemplate.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ImportDocumentTemplate
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.ImportDocumentTemplate
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ImportDocumentTemplate.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ImportDocumentTemplate";
                        };
    
                        return ImportDocumentTemplate;
                    })();
    
                    v2beta1.ImportDocumentsResponse = (function() {
    
                        /**
                         * Properties of an ImportDocumentsResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IImportDocumentsResponse
                         * @property {Array.<google.rpc.IStatus>|null} [warnings] ImportDocumentsResponse warnings
                         */
    
                        /**
                         * Constructs a new ImportDocumentsResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an ImportDocumentsResponse.
                         * @implements IImportDocumentsResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IImportDocumentsResponse=} [properties] Properties to set
                         */
                        function ImportDocumentsResponse(properties) {
                            this.warnings = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ImportDocumentsResponse warnings.
                         * @member {Array.<google.rpc.IStatus>} warnings
                         * @memberof google.cloud.dialogflow.v2beta1.ImportDocumentsResponse
                         * @instance
                         */
                        ImportDocumentsResponse.prototype.warnings = $util.emptyArray;
    
                        /**
                         * Creates a new ImportDocumentsResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.ImportDocumentsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IImportDocumentsResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.ImportDocumentsResponse} ImportDocumentsResponse instance
                         */
                        ImportDocumentsResponse.create = function create(properties) {
                            return new ImportDocumentsResponse(properties);
                        };
    
                        /**
                         * Encodes the specified ImportDocumentsResponse message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ImportDocumentsResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.ImportDocumentsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IImportDocumentsResponse} message ImportDocumentsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ImportDocumentsResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.warnings != null && message.warnings.length)
                                for (var i = 0; i < message.warnings.length; ++i)
                                    $root.google.rpc.Status.encode(message.warnings[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ImportDocumentsResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ImportDocumentsResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ImportDocumentsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IImportDocumentsResponse} message ImportDocumentsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ImportDocumentsResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an ImportDocumentsResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.ImportDocumentsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.ImportDocumentsResponse} ImportDocumentsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ImportDocumentsResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ImportDocumentsResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.warnings && message.warnings.length))
                                            message.warnings = [];
                                        message.warnings.push($root.google.rpc.Status.decode(reader, reader.uint32()));
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an ImportDocumentsResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ImportDocumentsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.ImportDocumentsResponse} ImportDocumentsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ImportDocumentsResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an ImportDocumentsResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.ImportDocumentsResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ImportDocumentsResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.warnings != null && message.hasOwnProperty("warnings")) {
                                if (!Array.isArray(message.warnings))
                                    return "warnings: array expected";
                                for (var i = 0; i < message.warnings.length; ++i) {
                                    var error = $root.google.rpc.Status.verify(message.warnings[i]);
                                    if (error)
                                        return "warnings." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates an ImportDocumentsResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.ImportDocumentsResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.ImportDocumentsResponse} ImportDocumentsResponse
                         */
                        ImportDocumentsResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.ImportDocumentsResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.ImportDocumentsResponse();
                            if (object.warnings) {
                                if (!Array.isArray(object.warnings))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.ImportDocumentsResponse.warnings: array expected");
                                message.warnings = [];
                                for (var i = 0; i < object.warnings.length; ++i) {
                                    if (typeof object.warnings[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.ImportDocumentsResponse.warnings: object expected");
                                    message.warnings[i] = $root.google.rpc.Status.fromObject(object.warnings[i]);
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an ImportDocumentsResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.ImportDocumentsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ImportDocumentsResponse} message ImportDocumentsResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ImportDocumentsResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.warnings = [];
                            if (message.warnings && message.warnings.length) {
                                object.warnings = [];
                                for (var j = 0; j < message.warnings.length; ++j)
                                    object.warnings[j] = $root.google.rpc.Status.toObject(message.warnings[j], options);
                            }
                            return object;
                        };
    
                        /**
                         * Converts this ImportDocumentsResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.ImportDocumentsResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ImportDocumentsResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ImportDocumentsResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.ImportDocumentsResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ImportDocumentsResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ImportDocumentsResponse";
                        };
    
                        return ImportDocumentsResponse;
                    })();
    
                    v2beta1.DeleteDocumentRequest = (function() {
    
                        /**
                         * Properties of a DeleteDocumentRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IDeleteDocumentRequest
                         * @property {string|null} [name] DeleteDocumentRequest name
                         */
    
                        /**
                         * Constructs a new DeleteDocumentRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a DeleteDocumentRequest.
                         * @implements IDeleteDocumentRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteDocumentRequest=} [properties] Properties to set
                         */
                        function DeleteDocumentRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * DeleteDocumentRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteDocumentRequest
                         * @instance
                         */
                        DeleteDocumentRequest.prototype.name = "";
    
                        /**
                         * Creates a new DeleteDocumentRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteDocumentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteDocumentRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.DeleteDocumentRequest} DeleteDocumentRequest instance
                         */
                        DeleteDocumentRequest.create = function create(properties) {
                            return new DeleteDocumentRequest(properties);
                        };
    
                        /**
                         * Encodes the specified DeleteDocumentRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.DeleteDocumentRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteDocumentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteDocumentRequest} message DeleteDocumentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteDocumentRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified DeleteDocumentRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.DeleteDocumentRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteDocumentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteDocumentRequest} message DeleteDocumentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteDocumentRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a DeleteDocumentRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteDocumentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.DeleteDocumentRequest} DeleteDocumentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteDocumentRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.DeleteDocumentRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a DeleteDocumentRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteDocumentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.DeleteDocumentRequest} DeleteDocumentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteDocumentRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a DeleteDocumentRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteDocumentRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        DeleteDocumentRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a DeleteDocumentRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteDocumentRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.DeleteDocumentRequest} DeleteDocumentRequest
                         */
                        DeleteDocumentRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.DeleteDocumentRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.DeleteDocumentRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a DeleteDocumentRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteDocumentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.DeleteDocumentRequest} message DeleteDocumentRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        DeleteDocumentRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.name = "";
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            return object;
                        };
    
                        /**
                         * Converts this DeleteDocumentRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteDocumentRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        DeleteDocumentRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for DeleteDocumentRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteDocumentRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        DeleteDocumentRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.DeleteDocumentRequest";
                        };
    
                        return DeleteDocumentRequest;
                    })();
    
                    v2beta1.UpdateDocumentRequest = (function() {
    
                        /**
                         * Properties of an UpdateDocumentRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IUpdateDocumentRequest
                         * @property {google.cloud.dialogflow.v2beta1.IDocument|null} [document] UpdateDocumentRequest document
                         * @property {google.protobuf.IFieldMask|null} [updateMask] UpdateDocumentRequest updateMask
                         */
    
                        /**
                         * Constructs a new UpdateDocumentRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an UpdateDocumentRequest.
                         * @implements IUpdateDocumentRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateDocumentRequest=} [properties] Properties to set
                         */
                        function UpdateDocumentRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * UpdateDocumentRequest document.
                         * @member {google.cloud.dialogflow.v2beta1.IDocument|null|undefined} document
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateDocumentRequest
                         * @instance
                         */
                        UpdateDocumentRequest.prototype.document = null;
    
                        /**
                         * UpdateDocumentRequest updateMask.
                         * @member {google.protobuf.IFieldMask|null|undefined} updateMask
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateDocumentRequest
                         * @instance
                         */
                        UpdateDocumentRequest.prototype.updateMask = null;
    
                        /**
                         * Creates a new UpdateDocumentRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateDocumentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateDocumentRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.UpdateDocumentRequest} UpdateDocumentRequest instance
                         */
                        UpdateDocumentRequest.create = function create(properties) {
                            return new UpdateDocumentRequest(properties);
                        };
    
                        /**
                         * Encodes the specified UpdateDocumentRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.UpdateDocumentRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateDocumentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateDocumentRequest} message UpdateDocumentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UpdateDocumentRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.document != null && Object.hasOwnProperty.call(message, "document"))
                                $root.google.cloud.dialogflow.v2beta1.Document.encode(message.document, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.updateMask != null && Object.hasOwnProperty.call(message, "updateMask"))
                                $root.google.protobuf.FieldMask.encode(message.updateMask, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified UpdateDocumentRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.UpdateDocumentRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateDocumentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateDocumentRequest} message UpdateDocumentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UpdateDocumentRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an UpdateDocumentRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateDocumentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.UpdateDocumentRequest} UpdateDocumentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UpdateDocumentRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.UpdateDocumentRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.document = $root.google.cloud.dialogflow.v2beta1.Document.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.updateMask = $root.google.protobuf.FieldMask.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an UpdateDocumentRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateDocumentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.UpdateDocumentRequest} UpdateDocumentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UpdateDocumentRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an UpdateDocumentRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateDocumentRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        UpdateDocumentRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.document != null && message.hasOwnProperty("document")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.Document.verify(message.document);
                                if (error)
                                    return "document." + error;
                            }
                            if (message.updateMask != null && message.hasOwnProperty("updateMask")) {
                                var error = $root.google.protobuf.FieldMask.verify(message.updateMask);
                                if (error)
                                    return "updateMask." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates an UpdateDocumentRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateDocumentRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.UpdateDocumentRequest} UpdateDocumentRequest
                         */
                        UpdateDocumentRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.UpdateDocumentRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.UpdateDocumentRequest();
                            if (object.document != null) {
                                if (typeof object.document !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.UpdateDocumentRequest.document: object expected");
                                message.document = $root.google.cloud.dialogflow.v2beta1.Document.fromObject(object.document);
                            }
                            if (object.updateMask != null) {
                                if (typeof object.updateMask !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.UpdateDocumentRequest.updateMask: object expected");
                                message.updateMask = $root.google.protobuf.FieldMask.fromObject(object.updateMask);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an UpdateDocumentRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateDocumentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.UpdateDocumentRequest} message UpdateDocumentRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        UpdateDocumentRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.document = null;
                                object.updateMask = null;
                            }
                            if (message.document != null && message.hasOwnProperty("document"))
                                object.document = $root.google.cloud.dialogflow.v2beta1.Document.toObject(message.document, options);
                            if (message.updateMask != null && message.hasOwnProperty("updateMask"))
                                object.updateMask = $root.google.protobuf.FieldMask.toObject(message.updateMask, options);
                            return object;
                        };
    
                        /**
                         * Converts this UpdateDocumentRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateDocumentRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        UpdateDocumentRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for UpdateDocumentRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateDocumentRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        UpdateDocumentRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.UpdateDocumentRequest";
                        };
    
                        return UpdateDocumentRequest;
                    })();
    
                    v2beta1.ExportOperationMetadata = (function() {
    
                        /**
                         * Properties of an ExportOperationMetadata.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IExportOperationMetadata
                         * @property {google.cloud.dialogflow.v2beta1.IGcsDestination|null} [exportedGcsDestination] ExportOperationMetadata exportedGcsDestination
                         */
    
                        /**
                         * Constructs a new ExportOperationMetadata.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an ExportOperationMetadata.
                         * @implements IExportOperationMetadata
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IExportOperationMetadata=} [properties] Properties to set
                         */
                        function ExportOperationMetadata(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ExportOperationMetadata exportedGcsDestination.
                         * @member {google.cloud.dialogflow.v2beta1.IGcsDestination|null|undefined} exportedGcsDestination
                         * @memberof google.cloud.dialogflow.v2beta1.ExportOperationMetadata
                         * @instance
                         */
                        ExportOperationMetadata.prototype.exportedGcsDestination = null;
    
                        /**
                         * Creates a new ExportOperationMetadata instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.ExportOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IExportOperationMetadata=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.ExportOperationMetadata} ExportOperationMetadata instance
                         */
                        ExportOperationMetadata.create = function create(properties) {
                            return new ExportOperationMetadata(properties);
                        };
    
                        /**
                         * Encodes the specified ExportOperationMetadata message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ExportOperationMetadata.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.ExportOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IExportOperationMetadata} message ExportOperationMetadata message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ExportOperationMetadata.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.exportedGcsDestination != null && Object.hasOwnProperty.call(message, "exportedGcsDestination"))
                                $root.google.cloud.dialogflow.v2beta1.GcsDestination.encode(message.exportedGcsDestination, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ExportOperationMetadata message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ExportOperationMetadata.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ExportOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IExportOperationMetadata} message ExportOperationMetadata message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ExportOperationMetadata.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an ExportOperationMetadata message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.ExportOperationMetadata
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.ExportOperationMetadata} ExportOperationMetadata
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ExportOperationMetadata.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ExportOperationMetadata();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.exportedGcsDestination = $root.google.cloud.dialogflow.v2beta1.GcsDestination.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an ExportOperationMetadata message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ExportOperationMetadata
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.ExportOperationMetadata} ExportOperationMetadata
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ExportOperationMetadata.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an ExportOperationMetadata message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.ExportOperationMetadata
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ExportOperationMetadata.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.exportedGcsDestination != null && message.hasOwnProperty("exportedGcsDestination")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.GcsDestination.verify(message.exportedGcsDestination);
                                if (error)
                                    return "exportedGcsDestination." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates an ExportOperationMetadata message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.ExportOperationMetadata
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.ExportOperationMetadata} ExportOperationMetadata
                         */
                        ExportOperationMetadata.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.ExportOperationMetadata)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.ExportOperationMetadata();
                            if (object.exportedGcsDestination != null) {
                                if (typeof object.exportedGcsDestination !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.ExportOperationMetadata.exportedGcsDestination: object expected");
                                message.exportedGcsDestination = $root.google.cloud.dialogflow.v2beta1.GcsDestination.fromObject(object.exportedGcsDestination);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an ExportOperationMetadata message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.ExportOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ExportOperationMetadata} message ExportOperationMetadata
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ExportOperationMetadata.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.exportedGcsDestination = null;
                            if (message.exportedGcsDestination != null && message.hasOwnProperty("exportedGcsDestination"))
                                object.exportedGcsDestination = $root.google.cloud.dialogflow.v2beta1.GcsDestination.toObject(message.exportedGcsDestination, options);
                            return object;
                        };
    
                        /**
                         * Converts this ExportOperationMetadata to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.ExportOperationMetadata
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ExportOperationMetadata.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ExportOperationMetadata
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.ExportOperationMetadata
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ExportOperationMetadata.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ExportOperationMetadata";
                        };
    
                        return ExportOperationMetadata;
                    })();
    
                    v2beta1.KnowledgeOperationMetadata = (function() {
    
                        /**
                         * Properties of a KnowledgeOperationMetadata.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IKnowledgeOperationMetadata
                         * @property {google.cloud.dialogflow.v2beta1.KnowledgeOperationMetadata.State|null} [state] KnowledgeOperationMetadata state
                         * @property {string|null} [knowledgeBase] KnowledgeOperationMetadata knowledgeBase
                         * @property {google.cloud.dialogflow.v2beta1.IExportOperationMetadata|null} [exportOperationMetadata] KnowledgeOperationMetadata exportOperationMetadata
                         */
    
                        /**
                         * Constructs a new KnowledgeOperationMetadata.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a KnowledgeOperationMetadata.
                         * @implements IKnowledgeOperationMetadata
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IKnowledgeOperationMetadata=} [properties] Properties to set
                         */
                        function KnowledgeOperationMetadata(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * KnowledgeOperationMetadata state.
                         * @member {google.cloud.dialogflow.v2beta1.KnowledgeOperationMetadata.State} state
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeOperationMetadata
                         * @instance
                         */
                        KnowledgeOperationMetadata.prototype.state = 0;
    
                        /**
                         * KnowledgeOperationMetadata knowledgeBase.
                         * @member {string} knowledgeBase
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeOperationMetadata
                         * @instance
                         */
                        KnowledgeOperationMetadata.prototype.knowledgeBase = "";
    
                        /**
                         * KnowledgeOperationMetadata exportOperationMetadata.
                         * @member {google.cloud.dialogflow.v2beta1.IExportOperationMetadata|null|undefined} exportOperationMetadata
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeOperationMetadata
                         * @instance
                         */
                        KnowledgeOperationMetadata.prototype.exportOperationMetadata = null;
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * KnowledgeOperationMetadata operationMetadata.
                         * @member {"exportOperationMetadata"|undefined} operationMetadata
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeOperationMetadata
                         * @instance
                         */
                        Object.defineProperty(KnowledgeOperationMetadata.prototype, "operationMetadata", {
                            get: $util.oneOfGetter($oneOfFields = ["exportOperationMetadata"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new KnowledgeOperationMetadata instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IKnowledgeOperationMetadata=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.KnowledgeOperationMetadata} KnowledgeOperationMetadata instance
                         */
                        KnowledgeOperationMetadata.create = function create(properties) {
                            return new KnowledgeOperationMetadata(properties);
                        };
    
                        /**
                         * Encodes the specified KnowledgeOperationMetadata message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.KnowledgeOperationMetadata.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IKnowledgeOperationMetadata} message KnowledgeOperationMetadata message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        KnowledgeOperationMetadata.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.state != null && Object.hasOwnProperty.call(message, "state"))
                                writer.uint32(/* id 1, wireType 0 =*/8).int32(message.state);
                            if (message.knowledgeBase != null && Object.hasOwnProperty.call(message, "knowledgeBase"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.knowledgeBase);
                            if (message.exportOperationMetadata != null && Object.hasOwnProperty.call(message, "exportOperationMetadata"))
                                $root.google.cloud.dialogflow.v2beta1.ExportOperationMetadata.encode(message.exportOperationMetadata, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified KnowledgeOperationMetadata message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.KnowledgeOperationMetadata.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IKnowledgeOperationMetadata} message KnowledgeOperationMetadata message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        KnowledgeOperationMetadata.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a KnowledgeOperationMetadata message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeOperationMetadata
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.KnowledgeOperationMetadata} KnowledgeOperationMetadata
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        KnowledgeOperationMetadata.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.KnowledgeOperationMetadata();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.state = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.knowledgeBase = reader.string();
                                        break;
                                    }
                                case 4: {
                                        message.exportOperationMetadata = $root.google.cloud.dialogflow.v2beta1.ExportOperationMetadata.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a KnowledgeOperationMetadata message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeOperationMetadata
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.KnowledgeOperationMetadata} KnowledgeOperationMetadata
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        KnowledgeOperationMetadata.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a KnowledgeOperationMetadata message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeOperationMetadata
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        KnowledgeOperationMetadata.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.state != null && message.hasOwnProperty("state"))
                                switch (message.state) {
                                default:
                                    return "state: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                    break;
                                }
                            if (message.knowledgeBase != null && message.hasOwnProperty("knowledgeBase"))
                                if (!$util.isString(message.knowledgeBase))
                                    return "knowledgeBase: string expected";
                            if (message.exportOperationMetadata != null && message.hasOwnProperty("exportOperationMetadata")) {
                                properties.operationMetadata = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2beta1.ExportOperationMetadata.verify(message.exportOperationMetadata);
                                    if (error)
                                        return "exportOperationMetadata." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates a KnowledgeOperationMetadata message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeOperationMetadata
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.KnowledgeOperationMetadata} KnowledgeOperationMetadata
                         */
                        KnowledgeOperationMetadata.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.KnowledgeOperationMetadata)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.KnowledgeOperationMetadata();
                            switch (object.state) {
                            default:
                                if (typeof object.state === "number") {
                                    message.state = object.state;
                                    break;
                                }
                                break;
                            case "STATE_UNSPECIFIED":
                            case 0:
                                message.state = 0;
                                break;
                            case "PENDING":
                            case 1:
                                message.state = 1;
                                break;
                            case "RUNNING":
                            case 2:
                                message.state = 2;
                                break;
                            case "DONE":
                            case 3:
                                message.state = 3;
                                break;
                            }
                            if (object.knowledgeBase != null)
                                message.knowledgeBase = String(object.knowledgeBase);
                            if (object.exportOperationMetadata != null) {
                                if (typeof object.exportOperationMetadata !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.KnowledgeOperationMetadata.exportOperationMetadata: object expected");
                                message.exportOperationMetadata = $root.google.cloud.dialogflow.v2beta1.ExportOperationMetadata.fromObject(object.exportOperationMetadata);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a KnowledgeOperationMetadata message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeOperationMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.KnowledgeOperationMetadata} message KnowledgeOperationMetadata
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        KnowledgeOperationMetadata.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.state = options.enums === String ? "STATE_UNSPECIFIED" : 0;
                                object.knowledgeBase = "";
                            }
                            if (message.state != null && message.hasOwnProperty("state"))
                                object.state = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.KnowledgeOperationMetadata.State[message.state] === undefined ? message.state : $root.google.cloud.dialogflow.v2beta1.KnowledgeOperationMetadata.State[message.state] : message.state;
                            if (message.knowledgeBase != null && message.hasOwnProperty("knowledgeBase"))
                                object.knowledgeBase = message.knowledgeBase;
                            if (message.exportOperationMetadata != null && message.hasOwnProperty("exportOperationMetadata")) {
                                object.exportOperationMetadata = $root.google.cloud.dialogflow.v2beta1.ExportOperationMetadata.toObject(message.exportOperationMetadata, options);
                                if (options.oneofs)
                                    object.operationMetadata = "exportOperationMetadata";
                            }
                            return object;
                        };
    
                        /**
                         * Converts this KnowledgeOperationMetadata to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeOperationMetadata
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        KnowledgeOperationMetadata.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for KnowledgeOperationMetadata
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeOperationMetadata
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        KnowledgeOperationMetadata.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.KnowledgeOperationMetadata";
                        };
    
                        /**
                         * State enum.
                         * @name google.cloud.dialogflow.v2beta1.KnowledgeOperationMetadata.State
                         * @enum {number}
                         * @property {number} STATE_UNSPECIFIED=0 STATE_UNSPECIFIED value
                         * @property {number} PENDING=1 PENDING value
                         * @property {number} RUNNING=2 RUNNING value
                         * @property {number} DONE=3 DONE value
                         */
                        KnowledgeOperationMetadata.State = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "STATE_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "PENDING"] = 1;
                            values[valuesById[2] = "RUNNING"] = 2;
                            values[valuesById[3] = "DONE"] = 3;
                            return values;
                        })();
    
                        return KnowledgeOperationMetadata;
                    })();
    
                    v2beta1.ReloadDocumentRequest = (function() {
    
                        /**
                         * Properties of a ReloadDocumentRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IReloadDocumentRequest
                         * @property {string|null} [name] ReloadDocumentRequest name
                         * @property {google.cloud.dialogflow.v2beta1.IGcsSource|null} [gcsSource] ReloadDocumentRequest gcsSource
                         * @property {boolean|null} [importGcsCustomMetadata] ReloadDocumentRequest importGcsCustomMetadata
                         */
    
                        /**
                         * Constructs a new ReloadDocumentRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a ReloadDocumentRequest.
                         * @implements IReloadDocumentRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IReloadDocumentRequest=} [properties] Properties to set
                         */
                        function ReloadDocumentRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ReloadDocumentRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2beta1.ReloadDocumentRequest
                         * @instance
                         */
                        ReloadDocumentRequest.prototype.name = "";
    
                        /**
                         * ReloadDocumentRequest gcsSource.
                         * @member {google.cloud.dialogflow.v2beta1.IGcsSource|null|undefined} gcsSource
                         * @memberof google.cloud.dialogflow.v2beta1.ReloadDocumentRequest
                         * @instance
                         */
                        ReloadDocumentRequest.prototype.gcsSource = null;
    
                        /**
                         * ReloadDocumentRequest importGcsCustomMetadata.
                         * @member {boolean} importGcsCustomMetadata
                         * @memberof google.cloud.dialogflow.v2beta1.ReloadDocumentRequest
                         * @instance
                         */
                        ReloadDocumentRequest.prototype.importGcsCustomMetadata = false;
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * ReloadDocumentRequest source.
                         * @member {"gcsSource"|undefined} source
                         * @memberof google.cloud.dialogflow.v2beta1.ReloadDocumentRequest
                         * @instance
                         */
                        Object.defineProperty(ReloadDocumentRequest.prototype, "source", {
                            get: $util.oneOfGetter($oneOfFields = ["gcsSource"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new ReloadDocumentRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.ReloadDocumentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IReloadDocumentRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.ReloadDocumentRequest} ReloadDocumentRequest instance
                         */
                        ReloadDocumentRequest.create = function create(properties) {
                            return new ReloadDocumentRequest(properties);
                        };
    
                        /**
                         * Encodes the specified ReloadDocumentRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ReloadDocumentRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.ReloadDocumentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IReloadDocumentRequest} message ReloadDocumentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ReloadDocumentRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            if (message.gcsSource != null && Object.hasOwnProperty.call(message, "gcsSource"))
                                $root.google.cloud.dialogflow.v2beta1.GcsSource.encode(message.gcsSource, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            if (message.importGcsCustomMetadata != null && Object.hasOwnProperty.call(message, "importGcsCustomMetadata"))
                                writer.uint32(/* id 4, wireType 0 =*/32).bool(message.importGcsCustomMetadata);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ReloadDocumentRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ReloadDocumentRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ReloadDocumentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IReloadDocumentRequest} message ReloadDocumentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ReloadDocumentRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ReloadDocumentRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.ReloadDocumentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.ReloadDocumentRequest} ReloadDocumentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ReloadDocumentRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ReloadDocumentRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.gcsSource = $root.google.cloud.dialogflow.v2beta1.GcsSource.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 4: {
                                        message.importGcsCustomMetadata = reader.bool();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ReloadDocumentRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ReloadDocumentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.ReloadDocumentRequest} ReloadDocumentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ReloadDocumentRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ReloadDocumentRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.ReloadDocumentRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ReloadDocumentRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            if (message.gcsSource != null && message.hasOwnProperty("gcsSource")) {
                                properties.source = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2beta1.GcsSource.verify(message.gcsSource);
                                    if (error)
                                        return "gcsSource." + error;
                                }
                            }
                            if (message.importGcsCustomMetadata != null && message.hasOwnProperty("importGcsCustomMetadata"))
                                if (typeof message.importGcsCustomMetadata !== "boolean")
                                    return "importGcsCustomMetadata: boolean expected";
                            return null;
                        };
    
                        /**
                         * Creates a ReloadDocumentRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.ReloadDocumentRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.ReloadDocumentRequest} ReloadDocumentRequest
                         */
                        ReloadDocumentRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.ReloadDocumentRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.ReloadDocumentRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            if (object.gcsSource != null) {
                                if (typeof object.gcsSource !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.ReloadDocumentRequest.gcsSource: object expected");
                                message.gcsSource = $root.google.cloud.dialogflow.v2beta1.GcsSource.fromObject(object.gcsSource);
                            }
                            if (object.importGcsCustomMetadata != null)
                                message.importGcsCustomMetadata = Boolean(object.importGcsCustomMetadata);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ReloadDocumentRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.ReloadDocumentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ReloadDocumentRequest} message ReloadDocumentRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ReloadDocumentRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.name = "";
                                object.importGcsCustomMetadata = false;
                            }
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            if (message.gcsSource != null && message.hasOwnProperty("gcsSource")) {
                                object.gcsSource = $root.google.cloud.dialogflow.v2beta1.GcsSource.toObject(message.gcsSource, options);
                                if (options.oneofs)
                                    object.source = "gcsSource";
                            }
                            if (message.importGcsCustomMetadata != null && message.hasOwnProperty("importGcsCustomMetadata"))
                                object.importGcsCustomMetadata = message.importGcsCustomMetadata;
                            return object;
                        };
    
                        /**
                         * Converts this ReloadDocumentRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.ReloadDocumentRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ReloadDocumentRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ReloadDocumentRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.ReloadDocumentRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ReloadDocumentRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ReloadDocumentRequest";
                        };
    
                        return ReloadDocumentRequest;
                    })();
    
                    v2beta1.GcsSources = (function() {
    
                        /**
                         * Properties of a GcsSources.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IGcsSources
                         * @property {Array.<string>|null} [uris] GcsSources uris
                         */
    
                        /**
                         * Constructs a new GcsSources.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a GcsSources.
                         * @implements IGcsSources
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IGcsSources=} [properties] Properties to set
                         */
                        function GcsSources(properties) {
                            this.uris = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GcsSources uris.
                         * @member {Array.<string>} uris
                         * @memberof google.cloud.dialogflow.v2beta1.GcsSources
                         * @instance
                         */
                        GcsSources.prototype.uris = $util.emptyArray;
    
                        /**
                         * Creates a new GcsSources instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.GcsSources
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGcsSources=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.GcsSources} GcsSources instance
                         */
                        GcsSources.create = function create(properties) {
                            return new GcsSources(properties);
                        };
    
                        /**
                         * Encodes the specified GcsSources message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GcsSources.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.GcsSources
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGcsSources} message GcsSources message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GcsSources.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.uris != null && message.uris.length)
                                for (var i = 0; i < message.uris.length; ++i)
                                    writer.uint32(/* id 2, wireType 2 =*/18).string(message.uris[i]);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GcsSources message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GcsSources.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GcsSources
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGcsSources} message GcsSources message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GcsSources.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GcsSources message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.GcsSources
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.GcsSources} GcsSources
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GcsSources.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.GcsSources();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 2: {
                                        if (!(message.uris && message.uris.length))
                                            message.uris = [];
                                        message.uris.push(reader.string());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GcsSources message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GcsSources
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.GcsSources} GcsSources
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GcsSources.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GcsSources message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.GcsSources
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GcsSources.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.uris != null && message.hasOwnProperty("uris")) {
                                if (!Array.isArray(message.uris))
                                    return "uris: array expected";
                                for (var i = 0; i < message.uris.length; ++i)
                                    if (!$util.isString(message.uris[i]))
                                        return "uris: string[] expected";
                            }
                            return null;
                        };
    
                        /**
                         * Creates a GcsSources message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.GcsSources
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.GcsSources} GcsSources
                         */
                        GcsSources.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.GcsSources)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.GcsSources();
                            if (object.uris) {
                                if (!Array.isArray(object.uris))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.GcsSources.uris: array expected");
                                message.uris = [];
                                for (var i = 0; i < object.uris.length; ++i)
                                    message.uris[i] = String(object.uris[i]);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GcsSources message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.GcsSources
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.GcsSources} message GcsSources
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GcsSources.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.uris = [];
                            if (message.uris && message.uris.length) {
                                object.uris = [];
                                for (var j = 0; j < message.uris.length; ++j)
                                    object.uris[j] = message.uris[j];
                            }
                            return object;
                        };
    
                        /**
                         * Converts this GcsSources to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.GcsSources
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GcsSources.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GcsSources
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.GcsSources
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GcsSources.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.GcsSources";
                        };
    
                        return GcsSources;
                    })();
    
                    v2beta1.GcsSource = (function() {
    
                        /**
                         * Properties of a GcsSource.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IGcsSource
                         * @property {string|null} [uri] GcsSource uri
                         */
    
                        /**
                         * Constructs a new GcsSource.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a GcsSource.
                         * @implements IGcsSource
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IGcsSource=} [properties] Properties to set
                         */
                        function GcsSource(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GcsSource uri.
                         * @member {string} uri
                         * @memberof google.cloud.dialogflow.v2beta1.GcsSource
                         * @instance
                         */
                        GcsSource.prototype.uri = "";
    
                        /**
                         * Creates a new GcsSource instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.GcsSource
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGcsSource=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.GcsSource} GcsSource instance
                         */
                        GcsSource.create = function create(properties) {
                            return new GcsSource(properties);
                        };
    
                        /**
                         * Encodes the specified GcsSource message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GcsSource.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.GcsSource
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGcsSource} message GcsSource message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GcsSource.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.uri != null && Object.hasOwnProperty.call(message, "uri"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.uri);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GcsSource message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GcsSource.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GcsSource
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGcsSource} message GcsSource message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GcsSource.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GcsSource message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.GcsSource
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.GcsSource} GcsSource
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GcsSource.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.GcsSource();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.uri = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GcsSource message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GcsSource
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.GcsSource} GcsSource
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GcsSource.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GcsSource message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.GcsSource
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GcsSource.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.uri != null && message.hasOwnProperty("uri"))
                                if (!$util.isString(message.uri))
                                    return "uri: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a GcsSource message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.GcsSource
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.GcsSource} GcsSource
                         */
                        GcsSource.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.GcsSource)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.GcsSource();
                            if (object.uri != null)
                                message.uri = String(object.uri);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GcsSource message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.GcsSource
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.GcsSource} message GcsSource
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GcsSource.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.uri = "";
                            if (message.uri != null && message.hasOwnProperty("uri"))
                                object.uri = message.uri;
                            return object;
                        };
    
                        /**
                         * Converts this GcsSource to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.GcsSource
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GcsSource.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GcsSource
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.GcsSource
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GcsSource.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.GcsSource";
                        };
    
                        return GcsSource;
                    })();
    
                    v2beta1.GcsDestination = (function() {
    
                        /**
                         * Properties of a GcsDestination.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IGcsDestination
                         * @property {string|null} [uri] GcsDestination uri
                         */
    
                        /**
                         * Constructs a new GcsDestination.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a GcsDestination.
                         * @implements IGcsDestination
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IGcsDestination=} [properties] Properties to set
                         */
                        function GcsDestination(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GcsDestination uri.
                         * @member {string} uri
                         * @memberof google.cloud.dialogflow.v2beta1.GcsDestination
                         * @instance
                         */
                        GcsDestination.prototype.uri = "";
    
                        /**
                         * Creates a new GcsDestination instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.GcsDestination
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGcsDestination=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.GcsDestination} GcsDestination instance
                         */
                        GcsDestination.create = function create(properties) {
                            return new GcsDestination(properties);
                        };
    
                        /**
                         * Encodes the specified GcsDestination message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GcsDestination.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.GcsDestination
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGcsDestination} message GcsDestination message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GcsDestination.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.uri != null && Object.hasOwnProperty.call(message, "uri"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.uri);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GcsDestination message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GcsDestination.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GcsDestination
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGcsDestination} message GcsDestination message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GcsDestination.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GcsDestination message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.GcsDestination
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.GcsDestination} GcsDestination
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GcsDestination.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.GcsDestination();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.uri = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GcsDestination message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GcsDestination
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.GcsDestination} GcsDestination
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GcsDestination.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GcsDestination message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.GcsDestination
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GcsDestination.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.uri != null && message.hasOwnProperty("uri"))
                                if (!$util.isString(message.uri))
                                    return "uri: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a GcsDestination message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.GcsDestination
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.GcsDestination} GcsDestination
                         */
                        GcsDestination.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.GcsDestination)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.GcsDestination();
                            if (object.uri != null)
                                message.uri = String(object.uri);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GcsDestination message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.GcsDestination
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.GcsDestination} message GcsDestination
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GcsDestination.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.uri = "";
                            if (message.uri != null && message.hasOwnProperty("uri"))
                                object.uri = message.uri;
                            return object;
                        };
    
                        /**
                         * Converts this GcsDestination to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.GcsDestination
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GcsDestination.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GcsDestination
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.GcsDestination
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GcsDestination.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.GcsDestination";
                        };
    
                        return GcsDestination;
                    })();
    
                    v2beta1.EncryptionSpecService = (function() {
    
                        /**
                         * Constructs a new EncryptionSpecService service.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an EncryptionSpecService
                         * @extends $protobuf.rpc.Service
                         * @constructor
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         */
                        function EncryptionSpecService(rpcImpl, requestDelimited, responseDelimited) {
                            $protobuf.rpc.Service.call(this, rpcImpl, requestDelimited, responseDelimited);
                        }
    
                        (EncryptionSpecService.prototype = Object.create($protobuf.rpc.Service.prototype)).constructor = EncryptionSpecService;
    
                        /**
                         * Creates new EncryptionSpecService service using the specified rpc implementation.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.EncryptionSpecService
                         * @static
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         * @returns {EncryptionSpecService} RPC service. Useful where requests and/or responses are streamed.
                         */
                        EncryptionSpecService.create = function create(rpcImpl, requestDelimited, responseDelimited) {
                            return new this(rpcImpl, requestDelimited, responseDelimited);
                        };
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.EncryptionSpecService|getEncryptionSpec}.
                         * @memberof google.cloud.dialogflow.v2beta1.EncryptionSpecService
                         * @typedef GetEncryptionSpecCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.EncryptionSpec} [response] EncryptionSpec
                         */
    
                        /**
                         * Calls GetEncryptionSpec.
                         * @function getEncryptionSpec
                         * @memberof google.cloud.dialogflow.v2beta1.EncryptionSpecService
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IGetEncryptionSpecRequest} request GetEncryptionSpecRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.EncryptionSpecService.GetEncryptionSpecCallback} callback Node-style callback called with the error, if any, and EncryptionSpec
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(EncryptionSpecService.prototype.getEncryptionSpec = function getEncryptionSpec(request, callback) {
                            return this.rpcCall(getEncryptionSpec, $root.google.cloud.dialogflow.v2beta1.GetEncryptionSpecRequest, $root.google.cloud.dialogflow.v2beta1.EncryptionSpec, request, callback);
                        }, "name", { value: "GetEncryptionSpec" });
    
                        /**
                         * Calls GetEncryptionSpec.
                         * @function getEncryptionSpec
                         * @memberof google.cloud.dialogflow.v2beta1.EncryptionSpecService
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IGetEncryptionSpecRequest} request GetEncryptionSpecRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.EncryptionSpec>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.EncryptionSpecService|initializeEncryptionSpec}.
                         * @memberof google.cloud.dialogflow.v2beta1.EncryptionSpecService
                         * @typedef InitializeEncryptionSpecCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.longrunning.Operation} [response] Operation
                         */
    
                        /**
                         * Calls InitializeEncryptionSpec.
                         * @function initializeEncryptionSpec
                         * @memberof google.cloud.dialogflow.v2beta1.EncryptionSpecService
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IInitializeEncryptionSpecRequest} request InitializeEncryptionSpecRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.EncryptionSpecService.InitializeEncryptionSpecCallback} callback Node-style callback called with the error, if any, and Operation
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(EncryptionSpecService.prototype.initializeEncryptionSpec = function initializeEncryptionSpec(request, callback) {
                            return this.rpcCall(initializeEncryptionSpec, $root.google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecRequest, $root.google.longrunning.Operation, request, callback);
                        }, "name", { value: "InitializeEncryptionSpec" });
    
                        /**
                         * Calls InitializeEncryptionSpec.
                         * @function initializeEncryptionSpec
                         * @memberof google.cloud.dialogflow.v2beta1.EncryptionSpecService
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IInitializeEncryptionSpecRequest} request InitializeEncryptionSpecRequest message or plain object
                         * @returns {Promise<google.longrunning.Operation>} Promise
                         * @variation 2
                         */
    
                        return EncryptionSpecService;
                    })();
    
                    v2beta1.GetEncryptionSpecRequest = (function() {
    
                        /**
                         * Properties of a GetEncryptionSpecRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IGetEncryptionSpecRequest
                         * @property {string|null} [name] GetEncryptionSpecRequest name
                         */
    
                        /**
                         * Constructs a new GetEncryptionSpecRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a GetEncryptionSpecRequest.
                         * @implements IGetEncryptionSpecRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IGetEncryptionSpecRequest=} [properties] Properties to set
                         */
                        function GetEncryptionSpecRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GetEncryptionSpecRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2beta1.GetEncryptionSpecRequest
                         * @instance
                         */
                        GetEncryptionSpecRequest.prototype.name = "";
    
                        /**
                         * Creates a new GetEncryptionSpecRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.GetEncryptionSpecRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetEncryptionSpecRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.GetEncryptionSpecRequest} GetEncryptionSpecRequest instance
                         */
                        GetEncryptionSpecRequest.create = function create(properties) {
                            return new GetEncryptionSpecRequest(properties);
                        };
    
                        /**
                         * Encodes the specified GetEncryptionSpecRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GetEncryptionSpecRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.GetEncryptionSpecRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetEncryptionSpecRequest} message GetEncryptionSpecRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetEncryptionSpecRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GetEncryptionSpecRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GetEncryptionSpecRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GetEncryptionSpecRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetEncryptionSpecRequest} message GetEncryptionSpecRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetEncryptionSpecRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GetEncryptionSpecRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.GetEncryptionSpecRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.GetEncryptionSpecRequest} GetEncryptionSpecRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetEncryptionSpecRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.GetEncryptionSpecRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GetEncryptionSpecRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GetEncryptionSpecRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.GetEncryptionSpecRequest} GetEncryptionSpecRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetEncryptionSpecRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GetEncryptionSpecRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.GetEncryptionSpecRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GetEncryptionSpecRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a GetEncryptionSpecRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.GetEncryptionSpecRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.GetEncryptionSpecRequest} GetEncryptionSpecRequest
                         */
                        GetEncryptionSpecRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.GetEncryptionSpecRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.GetEncryptionSpecRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GetEncryptionSpecRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.GetEncryptionSpecRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.GetEncryptionSpecRequest} message GetEncryptionSpecRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GetEncryptionSpecRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.name = "";
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            return object;
                        };
    
                        /**
                         * Converts this GetEncryptionSpecRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.GetEncryptionSpecRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GetEncryptionSpecRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GetEncryptionSpecRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.GetEncryptionSpecRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GetEncryptionSpecRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.GetEncryptionSpecRequest";
                        };
    
                        return GetEncryptionSpecRequest;
                    })();
    
                    v2beta1.EncryptionSpec = (function() {
    
                        /**
                         * Properties of an EncryptionSpec.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IEncryptionSpec
                         * @property {string|null} [name] EncryptionSpec name
                         * @property {string|null} [kmsKey] EncryptionSpec kmsKey
                         */
    
                        /**
                         * Constructs a new EncryptionSpec.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an EncryptionSpec.
                         * @implements IEncryptionSpec
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IEncryptionSpec=} [properties] Properties to set
                         */
                        function EncryptionSpec(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * EncryptionSpec name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2beta1.EncryptionSpec
                         * @instance
                         */
                        EncryptionSpec.prototype.name = "";
    
                        /**
                         * EncryptionSpec kmsKey.
                         * @member {string} kmsKey
                         * @memberof google.cloud.dialogflow.v2beta1.EncryptionSpec
                         * @instance
                         */
                        EncryptionSpec.prototype.kmsKey = "";
    
                        /**
                         * Creates a new EncryptionSpec instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.EncryptionSpec
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IEncryptionSpec=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.EncryptionSpec} EncryptionSpec instance
                         */
                        EncryptionSpec.create = function create(properties) {
                            return new EncryptionSpec(properties);
                        };
    
                        /**
                         * Encodes the specified EncryptionSpec message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.EncryptionSpec.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.EncryptionSpec
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IEncryptionSpec} message EncryptionSpec message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        EncryptionSpec.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            if (message.kmsKey != null && Object.hasOwnProperty.call(message, "kmsKey"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.kmsKey);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified EncryptionSpec message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.EncryptionSpec.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.EncryptionSpec
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IEncryptionSpec} message EncryptionSpec message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        EncryptionSpec.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an EncryptionSpec message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.EncryptionSpec
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.EncryptionSpec} EncryptionSpec
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        EncryptionSpec.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.EncryptionSpec();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.kmsKey = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an EncryptionSpec message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.EncryptionSpec
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.EncryptionSpec} EncryptionSpec
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        EncryptionSpec.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an EncryptionSpec message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.EncryptionSpec
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        EncryptionSpec.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            if (message.kmsKey != null && message.hasOwnProperty("kmsKey"))
                                if (!$util.isString(message.kmsKey))
                                    return "kmsKey: string expected";
                            return null;
                        };
    
                        /**
                         * Creates an EncryptionSpec message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.EncryptionSpec
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.EncryptionSpec} EncryptionSpec
                         */
                        EncryptionSpec.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.EncryptionSpec)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.EncryptionSpec();
                            if (object.name != null)
                                message.name = String(object.name);
                            if (object.kmsKey != null)
                                message.kmsKey = String(object.kmsKey);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an EncryptionSpec message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.EncryptionSpec
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.EncryptionSpec} message EncryptionSpec
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        EncryptionSpec.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.name = "";
                                object.kmsKey = "";
                            }
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            if (message.kmsKey != null && message.hasOwnProperty("kmsKey"))
                                object.kmsKey = message.kmsKey;
                            return object;
                        };
    
                        /**
                         * Converts this EncryptionSpec to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.EncryptionSpec
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        EncryptionSpec.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for EncryptionSpec
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.EncryptionSpec
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        EncryptionSpec.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.EncryptionSpec";
                        };
    
                        return EncryptionSpec;
                    })();
    
                    v2beta1.InitializeEncryptionSpecRequest = (function() {
    
                        /**
                         * Properties of an InitializeEncryptionSpecRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IInitializeEncryptionSpecRequest
                         * @property {google.cloud.dialogflow.v2beta1.IEncryptionSpec|null} [encryptionSpec] InitializeEncryptionSpecRequest encryptionSpec
                         */
    
                        /**
                         * Constructs a new InitializeEncryptionSpecRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an InitializeEncryptionSpecRequest.
                         * @implements IInitializeEncryptionSpecRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IInitializeEncryptionSpecRequest=} [properties] Properties to set
                         */
                        function InitializeEncryptionSpecRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * InitializeEncryptionSpecRequest encryptionSpec.
                         * @member {google.cloud.dialogflow.v2beta1.IEncryptionSpec|null|undefined} encryptionSpec
                         * @memberof google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecRequest
                         * @instance
                         */
                        InitializeEncryptionSpecRequest.prototype.encryptionSpec = null;
    
                        /**
                         * Creates a new InitializeEncryptionSpecRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IInitializeEncryptionSpecRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecRequest} InitializeEncryptionSpecRequest instance
                         */
                        InitializeEncryptionSpecRequest.create = function create(properties) {
                            return new InitializeEncryptionSpecRequest(properties);
                        };
    
                        /**
                         * Encodes the specified InitializeEncryptionSpecRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IInitializeEncryptionSpecRequest} message InitializeEncryptionSpecRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        InitializeEncryptionSpecRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.encryptionSpec != null && Object.hasOwnProperty.call(message, "encryptionSpec"))
                                $root.google.cloud.dialogflow.v2beta1.EncryptionSpec.encode(message.encryptionSpec, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified InitializeEncryptionSpecRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IInitializeEncryptionSpecRequest} message InitializeEncryptionSpecRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        InitializeEncryptionSpecRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an InitializeEncryptionSpecRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecRequest} InitializeEncryptionSpecRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        InitializeEncryptionSpecRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.encryptionSpec = $root.google.cloud.dialogflow.v2beta1.EncryptionSpec.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an InitializeEncryptionSpecRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecRequest} InitializeEncryptionSpecRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        InitializeEncryptionSpecRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an InitializeEncryptionSpecRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        InitializeEncryptionSpecRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.encryptionSpec != null && message.hasOwnProperty("encryptionSpec")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.EncryptionSpec.verify(message.encryptionSpec);
                                if (error)
                                    return "encryptionSpec." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates an InitializeEncryptionSpecRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecRequest} InitializeEncryptionSpecRequest
                         */
                        InitializeEncryptionSpecRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecRequest();
                            if (object.encryptionSpec != null) {
                                if (typeof object.encryptionSpec !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecRequest.encryptionSpec: object expected");
                                message.encryptionSpec = $root.google.cloud.dialogflow.v2beta1.EncryptionSpec.fromObject(object.encryptionSpec);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an InitializeEncryptionSpecRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecRequest} message InitializeEncryptionSpecRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        InitializeEncryptionSpecRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.encryptionSpec = null;
                            if (message.encryptionSpec != null && message.hasOwnProperty("encryptionSpec"))
                                object.encryptionSpec = $root.google.cloud.dialogflow.v2beta1.EncryptionSpec.toObject(message.encryptionSpec, options);
                            return object;
                        };
    
                        /**
                         * Converts this InitializeEncryptionSpecRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        InitializeEncryptionSpecRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for InitializeEncryptionSpecRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        InitializeEncryptionSpecRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecRequest";
                        };
    
                        return InitializeEncryptionSpecRequest;
                    })();
    
                    v2beta1.InitializeEncryptionSpecResponse = (function() {
    
                        /**
                         * Properties of an InitializeEncryptionSpecResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IInitializeEncryptionSpecResponse
                         */
    
                        /**
                         * Constructs a new InitializeEncryptionSpecResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an InitializeEncryptionSpecResponse.
                         * @implements IInitializeEncryptionSpecResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IInitializeEncryptionSpecResponse=} [properties] Properties to set
                         */
                        function InitializeEncryptionSpecResponse(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * Creates a new InitializeEncryptionSpecResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IInitializeEncryptionSpecResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecResponse} InitializeEncryptionSpecResponse instance
                         */
                        InitializeEncryptionSpecResponse.create = function create(properties) {
                            return new InitializeEncryptionSpecResponse(properties);
                        };
    
                        /**
                         * Encodes the specified InitializeEncryptionSpecResponse message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IInitializeEncryptionSpecResponse} message InitializeEncryptionSpecResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        InitializeEncryptionSpecResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified InitializeEncryptionSpecResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IInitializeEncryptionSpecResponse} message InitializeEncryptionSpecResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        InitializeEncryptionSpecResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an InitializeEncryptionSpecResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecResponse} InitializeEncryptionSpecResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        InitializeEncryptionSpecResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an InitializeEncryptionSpecResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecResponse} InitializeEncryptionSpecResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        InitializeEncryptionSpecResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an InitializeEncryptionSpecResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        InitializeEncryptionSpecResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            return null;
                        };
    
                        /**
                         * Creates an InitializeEncryptionSpecResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecResponse} InitializeEncryptionSpecResponse
                         */
                        InitializeEncryptionSpecResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecResponse)
                                return object;
                            return new $root.google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecResponse();
                        };
    
                        /**
                         * Creates a plain object from an InitializeEncryptionSpecResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecResponse} message InitializeEncryptionSpecResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        InitializeEncryptionSpecResponse.toObject = function toObject() {
                            return {};
                        };
    
                        /**
                         * Converts this InitializeEncryptionSpecResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        InitializeEncryptionSpecResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for InitializeEncryptionSpecResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        InitializeEncryptionSpecResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecResponse";
                        };
    
                        return InitializeEncryptionSpecResponse;
                    })();
    
                    v2beta1.InitializeEncryptionSpecMetadata = (function() {
    
                        /**
                         * Properties of an InitializeEncryptionSpecMetadata.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IInitializeEncryptionSpecMetadata
                         * @property {google.cloud.dialogflow.v2beta1.IInitializeEncryptionSpecRequest|null} [request] InitializeEncryptionSpecMetadata request
                         */
    
                        /**
                         * Constructs a new InitializeEncryptionSpecMetadata.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an InitializeEncryptionSpecMetadata.
                         * @implements IInitializeEncryptionSpecMetadata
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IInitializeEncryptionSpecMetadata=} [properties] Properties to set
                         */
                        function InitializeEncryptionSpecMetadata(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * InitializeEncryptionSpecMetadata request.
                         * @member {google.cloud.dialogflow.v2beta1.IInitializeEncryptionSpecRequest|null|undefined} request
                         * @memberof google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecMetadata
                         * @instance
                         */
                        InitializeEncryptionSpecMetadata.prototype.request = null;
    
                        /**
                         * Creates a new InitializeEncryptionSpecMetadata instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IInitializeEncryptionSpecMetadata=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecMetadata} InitializeEncryptionSpecMetadata instance
                         */
                        InitializeEncryptionSpecMetadata.create = function create(properties) {
                            return new InitializeEncryptionSpecMetadata(properties);
                        };
    
                        /**
                         * Encodes the specified InitializeEncryptionSpecMetadata message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecMetadata.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IInitializeEncryptionSpecMetadata} message InitializeEncryptionSpecMetadata message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        InitializeEncryptionSpecMetadata.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.request != null && Object.hasOwnProperty.call(message, "request"))
                                $root.google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecRequest.encode(message.request, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified InitializeEncryptionSpecMetadata message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecMetadata.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IInitializeEncryptionSpecMetadata} message InitializeEncryptionSpecMetadata message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        InitializeEncryptionSpecMetadata.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an InitializeEncryptionSpecMetadata message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecMetadata
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecMetadata} InitializeEncryptionSpecMetadata
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        InitializeEncryptionSpecMetadata.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecMetadata();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 4: {
                                        message.request = $root.google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecRequest.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an InitializeEncryptionSpecMetadata message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecMetadata
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecMetadata} InitializeEncryptionSpecMetadata
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        InitializeEncryptionSpecMetadata.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an InitializeEncryptionSpecMetadata message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecMetadata
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        InitializeEncryptionSpecMetadata.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.request != null && message.hasOwnProperty("request")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecRequest.verify(message.request);
                                if (error)
                                    return "request." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates an InitializeEncryptionSpecMetadata message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecMetadata
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecMetadata} InitializeEncryptionSpecMetadata
                         */
                        InitializeEncryptionSpecMetadata.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecMetadata)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecMetadata();
                            if (object.request != null) {
                                if (typeof object.request !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecMetadata.request: object expected");
                                message.request = $root.google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecRequest.fromObject(object.request);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an InitializeEncryptionSpecMetadata message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecMetadata
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecMetadata} message InitializeEncryptionSpecMetadata
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        InitializeEncryptionSpecMetadata.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.request = null;
                            if (message.request != null && message.hasOwnProperty("request"))
                                object.request = $root.google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecRequest.toObject(message.request, options);
                            return object;
                        };
    
                        /**
                         * Converts this InitializeEncryptionSpecMetadata to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecMetadata
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        InitializeEncryptionSpecMetadata.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for InitializeEncryptionSpecMetadata
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecMetadata
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        InitializeEncryptionSpecMetadata.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.InitializeEncryptionSpecMetadata";
                        };
    
                        return InitializeEncryptionSpecMetadata;
                    })();
    
                    v2beta1.Environments = (function() {
    
                        /**
                         * Constructs a new Environments service.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an Environments
                         * @extends $protobuf.rpc.Service
                         * @constructor
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         */
                        function Environments(rpcImpl, requestDelimited, responseDelimited) {
                            $protobuf.rpc.Service.call(this, rpcImpl, requestDelimited, responseDelimited);
                        }
    
                        (Environments.prototype = Object.create($protobuf.rpc.Service.prototype)).constructor = Environments;
    
                        /**
                         * Creates new Environments service using the specified rpc implementation.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.Environments
                         * @static
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         * @returns {Environments} RPC service. Useful where requests and/or responses are streamed.
                         */
                        Environments.create = function create(rpcImpl, requestDelimited, responseDelimited) {
                            return new this(rpcImpl, requestDelimited, responseDelimited);
                        };
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Environments|listEnvironments}.
                         * @memberof google.cloud.dialogflow.v2beta1.Environments
                         * @typedef ListEnvironmentsCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.ListEnvironmentsResponse} [response] ListEnvironmentsResponse
                         */
    
                        /**
                         * Calls ListEnvironments.
                         * @function listEnvironments
                         * @memberof google.cloud.dialogflow.v2beta1.Environments
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IListEnvironmentsRequest} request ListEnvironmentsRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Environments.ListEnvironmentsCallback} callback Node-style callback called with the error, if any, and ListEnvironmentsResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Environments.prototype.listEnvironments = function listEnvironments(request, callback) {
                            return this.rpcCall(listEnvironments, $root.google.cloud.dialogflow.v2beta1.ListEnvironmentsRequest, $root.google.cloud.dialogflow.v2beta1.ListEnvironmentsResponse, request, callback);
                        }, "name", { value: "ListEnvironments" });
    
                        /**
                         * Calls ListEnvironments.
                         * @function listEnvironments
                         * @memberof google.cloud.dialogflow.v2beta1.Environments
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IListEnvironmentsRequest} request ListEnvironmentsRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.ListEnvironmentsResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Environments|getEnvironment}.
                         * @memberof google.cloud.dialogflow.v2beta1.Environments
                         * @typedef GetEnvironmentCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.Environment} [response] Environment
                         */
    
                        /**
                         * Calls GetEnvironment.
                         * @function getEnvironment
                         * @memberof google.cloud.dialogflow.v2beta1.Environments
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IGetEnvironmentRequest} request GetEnvironmentRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Environments.GetEnvironmentCallback} callback Node-style callback called with the error, if any, and Environment
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Environments.prototype.getEnvironment = function getEnvironment(request, callback) {
                            return this.rpcCall(getEnvironment, $root.google.cloud.dialogflow.v2beta1.GetEnvironmentRequest, $root.google.cloud.dialogflow.v2beta1.Environment, request, callback);
                        }, "name", { value: "GetEnvironment" });
    
                        /**
                         * Calls GetEnvironment.
                         * @function getEnvironment
                         * @memberof google.cloud.dialogflow.v2beta1.Environments
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IGetEnvironmentRequest} request GetEnvironmentRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.Environment>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Environments|createEnvironment}.
                         * @memberof google.cloud.dialogflow.v2beta1.Environments
                         * @typedef CreateEnvironmentCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.Environment} [response] Environment
                         */
    
                        /**
                         * Calls CreateEnvironment.
                         * @function createEnvironment
                         * @memberof google.cloud.dialogflow.v2beta1.Environments
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.ICreateEnvironmentRequest} request CreateEnvironmentRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Environments.CreateEnvironmentCallback} callback Node-style callback called with the error, if any, and Environment
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Environments.prototype.createEnvironment = function createEnvironment(request, callback) {
                            return this.rpcCall(createEnvironment, $root.google.cloud.dialogflow.v2beta1.CreateEnvironmentRequest, $root.google.cloud.dialogflow.v2beta1.Environment, request, callback);
                        }, "name", { value: "CreateEnvironment" });
    
                        /**
                         * Calls CreateEnvironment.
                         * @function createEnvironment
                         * @memberof google.cloud.dialogflow.v2beta1.Environments
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.ICreateEnvironmentRequest} request CreateEnvironmentRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.Environment>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Environments|updateEnvironment}.
                         * @memberof google.cloud.dialogflow.v2beta1.Environments
                         * @typedef UpdateEnvironmentCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.Environment} [response] Environment
                         */
    
                        /**
                         * Calls UpdateEnvironment.
                         * @function updateEnvironment
                         * @memberof google.cloud.dialogflow.v2beta1.Environments
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateEnvironmentRequest} request UpdateEnvironmentRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Environments.UpdateEnvironmentCallback} callback Node-style callback called with the error, if any, and Environment
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Environments.prototype.updateEnvironment = function updateEnvironment(request, callback) {
                            return this.rpcCall(updateEnvironment, $root.google.cloud.dialogflow.v2beta1.UpdateEnvironmentRequest, $root.google.cloud.dialogflow.v2beta1.Environment, request, callback);
                        }, "name", { value: "UpdateEnvironment" });
    
                        /**
                         * Calls UpdateEnvironment.
                         * @function updateEnvironment
                         * @memberof google.cloud.dialogflow.v2beta1.Environments
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateEnvironmentRequest} request UpdateEnvironmentRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.Environment>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Environments|deleteEnvironment}.
                         * @memberof google.cloud.dialogflow.v2beta1.Environments
                         * @typedef DeleteEnvironmentCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.protobuf.Empty} [response] Empty
                         */
    
                        /**
                         * Calls DeleteEnvironment.
                         * @function deleteEnvironment
                         * @memberof google.cloud.dialogflow.v2beta1.Environments
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteEnvironmentRequest} request DeleteEnvironmentRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Environments.DeleteEnvironmentCallback} callback Node-style callback called with the error, if any, and Empty
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Environments.prototype.deleteEnvironment = function deleteEnvironment(request, callback) {
                            return this.rpcCall(deleteEnvironment, $root.google.cloud.dialogflow.v2beta1.DeleteEnvironmentRequest, $root.google.protobuf.Empty, request, callback);
                        }, "name", { value: "DeleteEnvironment" });
    
                        /**
                         * Calls DeleteEnvironment.
                         * @function deleteEnvironment
                         * @memberof google.cloud.dialogflow.v2beta1.Environments
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteEnvironmentRequest} request DeleteEnvironmentRequest message or plain object
                         * @returns {Promise<google.protobuf.Empty>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Environments|getEnvironmentHistory}.
                         * @memberof google.cloud.dialogflow.v2beta1.Environments
                         * @typedef GetEnvironmentHistoryCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.EnvironmentHistory} [response] EnvironmentHistory
                         */
    
                        /**
                         * Calls GetEnvironmentHistory.
                         * @function getEnvironmentHistory
                         * @memberof google.cloud.dialogflow.v2beta1.Environments
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IGetEnvironmentHistoryRequest} request GetEnvironmentHistoryRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Environments.GetEnvironmentHistoryCallback} callback Node-style callback called with the error, if any, and EnvironmentHistory
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Environments.prototype.getEnvironmentHistory = function getEnvironmentHistory(request, callback) {
                            return this.rpcCall(getEnvironmentHistory, $root.google.cloud.dialogflow.v2beta1.GetEnvironmentHistoryRequest, $root.google.cloud.dialogflow.v2beta1.EnvironmentHistory, request, callback);
                        }, "name", { value: "GetEnvironmentHistory" });
    
                        /**
                         * Calls GetEnvironmentHistory.
                         * @function getEnvironmentHistory
                         * @memberof google.cloud.dialogflow.v2beta1.Environments
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IGetEnvironmentHistoryRequest} request GetEnvironmentHistoryRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.EnvironmentHistory>} Promise
                         * @variation 2
                         */
    
                        return Environments;
                    })();
    
                    v2beta1.Environment = (function() {
    
                        /**
                         * Properties of an Environment.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IEnvironment
                         * @property {string|null} [name] Environment name
                         * @property {string|null} [description] Environment description
                         * @property {string|null} [agentVersion] Environment agentVersion
                         * @property {google.cloud.dialogflow.v2beta1.Environment.State|null} [state] Environment state
                         * @property {google.protobuf.ITimestamp|null} [updateTime] Environment updateTime
                         * @property {google.cloud.dialogflow.v2beta1.ITextToSpeechSettings|null} [textToSpeechSettings] Environment textToSpeechSettings
                         * @property {google.cloud.dialogflow.v2beta1.IFulfillment|null} [fulfillment] Environment fulfillment
                         */
    
                        /**
                         * Constructs a new Environment.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an Environment.
                         * @implements IEnvironment
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IEnvironment=} [properties] Properties to set
                         */
                        function Environment(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * Environment name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2beta1.Environment
                         * @instance
                         */
                        Environment.prototype.name = "";
    
                        /**
                         * Environment description.
                         * @member {string} description
                         * @memberof google.cloud.dialogflow.v2beta1.Environment
                         * @instance
                         */
                        Environment.prototype.description = "";
    
                        /**
                         * Environment agentVersion.
                         * @member {string} agentVersion
                         * @memberof google.cloud.dialogflow.v2beta1.Environment
                         * @instance
                         */
                        Environment.prototype.agentVersion = "";
    
                        /**
                         * Environment state.
                         * @member {google.cloud.dialogflow.v2beta1.Environment.State} state
                         * @memberof google.cloud.dialogflow.v2beta1.Environment
                         * @instance
                         */
                        Environment.prototype.state = 0;
    
                        /**
                         * Environment updateTime.
                         * @member {google.protobuf.ITimestamp|null|undefined} updateTime
                         * @memberof google.cloud.dialogflow.v2beta1.Environment
                         * @instance
                         */
                        Environment.prototype.updateTime = null;
    
                        /**
                         * Environment textToSpeechSettings.
                         * @member {google.cloud.dialogflow.v2beta1.ITextToSpeechSettings|null|undefined} textToSpeechSettings
                         * @memberof google.cloud.dialogflow.v2beta1.Environment
                         * @instance
                         */
                        Environment.prototype.textToSpeechSettings = null;
    
                        /**
                         * Environment fulfillment.
                         * @member {google.cloud.dialogflow.v2beta1.IFulfillment|null|undefined} fulfillment
                         * @memberof google.cloud.dialogflow.v2beta1.Environment
                         * @instance
                         */
                        Environment.prototype.fulfillment = null;
    
                        /**
                         * Creates a new Environment instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.Environment
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IEnvironment=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.Environment} Environment instance
                         */
                        Environment.create = function create(properties) {
                            return new Environment(properties);
                        };
    
                        /**
                         * Encodes the specified Environment message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Environment.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.Environment
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IEnvironment} message Environment message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        Environment.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            if (message.description != null && Object.hasOwnProperty.call(message, "description"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.description);
                            if (message.agentVersion != null && Object.hasOwnProperty.call(message, "agentVersion"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.agentVersion);
                            if (message.state != null && Object.hasOwnProperty.call(message, "state"))
                                writer.uint32(/* id 4, wireType 0 =*/32).int32(message.state);
                            if (message.updateTime != null && Object.hasOwnProperty.call(message, "updateTime"))
                                $root.google.protobuf.Timestamp.encode(message.updateTime, writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                            if (message.textToSpeechSettings != null && Object.hasOwnProperty.call(message, "textToSpeechSettings"))
                                $root.google.cloud.dialogflow.v2beta1.TextToSpeechSettings.encode(message.textToSpeechSettings, writer.uint32(/* id 7, wireType 2 =*/58).fork()).ldelim();
                            if (message.fulfillment != null && Object.hasOwnProperty.call(message, "fulfillment"))
                                $root.google.cloud.dialogflow.v2beta1.Fulfillment.encode(message.fulfillment, writer.uint32(/* id 8, wireType 2 =*/66).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified Environment message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Environment.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.Environment
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IEnvironment} message Environment message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        Environment.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an Environment message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.Environment
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.Environment} Environment
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        Environment.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Environment();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.description = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.agentVersion = reader.string();
                                        break;
                                    }
                                case 4: {
                                        message.state = reader.int32();
                                        break;
                                    }
                                case 5: {
                                        message.updateTime = $root.google.protobuf.Timestamp.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 7: {
                                        message.textToSpeechSettings = $root.google.cloud.dialogflow.v2beta1.TextToSpeechSettings.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 8: {
                                        message.fulfillment = $root.google.cloud.dialogflow.v2beta1.Fulfillment.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an Environment message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.Environment
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.Environment} Environment
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        Environment.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an Environment message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.Environment
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        Environment.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            if (message.description != null && message.hasOwnProperty("description"))
                                if (!$util.isString(message.description))
                                    return "description: string expected";
                            if (message.agentVersion != null && message.hasOwnProperty("agentVersion"))
                                if (!$util.isString(message.agentVersion))
                                    return "agentVersion: string expected";
                            if (message.state != null && message.hasOwnProperty("state"))
                                switch (message.state) {
                                default:
                                    return "state: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                    break;
                                }
                            if (message.updateTime != null && message.hasOwnProperty("updateTime")) {
                                var error = $root.google.protobuf.Timestamp.verify(message.updateTime);
                                if (error)
                                    return "updateTime." + error;
                            }
                            if (message.textToSpeechSettings != null && message.hasOwnProperty("textToSpeechSettings")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.TextToSpeechSettings.verify(message.textToSpeechSettings);
                                if (error)
                                    return "textToSpeechSettings." + error;
                            }
                            if (message.fulfillment != null && message.hasOwnProperty("fulfillment")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.Fulfillment.verify(message.fulfillment);
                                if (error)
                                    return "fulfillment." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates an Environment message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.Environment
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.Environment} Environment
                         */
                        Environment.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.Environment)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.Environment();
                            if (object.name != null)
                                message.name = String(object.name);
                            if (object.description != null)
                                message.description = String(object.description);
                            if (object.agentVersion != null)
                                message.agentVersion = String(object.agentVersion);
                            switch (object.state) {
                            default:
                                if (typeof object.state === "number") {
                                    message.state = object.state;
                                    break;
                                }
                                break;
                            case "STATE_UNSPECIFIED":
                            case 0:
                                message.state = 0;
                                break;
                            case "STOPPED":
                            case 1:
                                message.state = 1;
                                break;
                            case "LOADING":
                            case 2:
                                message.state = 2;
                                break;
                            case "RUNNING":
                            case 3:
                                message.state = 3;
                                break;
                            }
                            if (object.updateTime != null) {
                                if (typeof object.updateTime !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.Environment.updateTime: object expected");
                                message.updateTime = $root.google.protobuf.Timestamp.fromObject(object.updateTime);
                            }
                            if (object.textToSpeechSettings != null) {
                                if (typeof object.textToSpeechSettings !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.Environment.textToSpeechSettings: object expected");
                                message.textToSpeechSettings = $root.google.cloud.dialogflow.v2beta1.TextToSpeechSettings.fromObject(object.textToSpeechSettings);
                            }
                            if (object.fulfillment != null) {
                                if (typeof object.fulfillment !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.Environment.fulfillment: object expected");
                                message.fulfillment = $root.google.cloud.dialogflow.v2beta1.Fulfillment.fromObject(object.fulfillment);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an Environment message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.Environment
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.Environment} message Environment
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        Environment.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.name = "";
                                object.description = "";
                                object.agentVersion = "";
                                object.state = options.enums === String ? "STATE_UNSPECIFIED" : 0;
                                object.updateTime = null;
                                object.textToSpeechSettings = null;
                                object.fulfillment = null;
                            }
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            if (message.description != null && message.hasOwnProperty("description"))
                                object.description = message.description;
                            if (message.agentVersion != null && message.hasOwnProperty("agentVersion"))
                                object.agentVersion = message.agentVersion;
                            if (message.state != null && message.hasOwnProperty("state"))
                                object.state = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.Environment.State[message.state] === undefined ? message.state : $root.google.cloud.dialogflow.v2beta1.Environment.State[message.state] : message.state;
                            if (message.updateTime != null && message.hasOwnProperty("updateTime"))
                                object.updateTime = $root.google.protobuf.Timestamp.toObject(message.updateTime, options);
                            if (message.textToSpeechSettings != null && message.hasOwnProperty("textToSpeechSettings"))
                                object.textToSpeechSettings = $root.google.cloud.dialogflow.v2beta1.TextToSpeechSettings.toObject(message.textToSpeechSettings, options);
                            if (message.fulfillment != null && message.hasOwnProperty("fulfillment"))
                                object.fulfillment = $root.google.cloud.dialogflow.v2beta1.Fulfillment.toObject(message.fulfillment, options);
                            return object;
                        };
    
                        /**
                         * Converts this Environment to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.Environment
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        Environment.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for Environment
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.Environment
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        Environment.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Environment";
                        };
    
                        /**
                         * State enum.
                         * @name google.cloud.dialogflow.v2beta1.Environment.State
                         * @enum {number}
                         * @property {number} STATE_UNSPECIFIED=0 STATE_UNSPECIFIED value
                         * @property {number} STOPPED=1 STOPPED value
                         * @property {number} LOADING=2 LOADING value
                         * @property {number} RUNNING=3 RUNNING value
                         */
                        Environment.State = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "STATE_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "STOPPED"] = 1;
                            values[valuesById[2] = "LOADING"] = 2;
                            values[valuesById[3] = "RUNNING"] = 3;
                            return values;
                        })();
    
                        return Environment;
                    })();
    
                    v2beta1.TextToSpeechSettings = (function() {
    
                        /**
                         * Properties of a TextToSpeechSettings.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ITextToSpeechSettings
                         * @property {boolean|null} [enableTextToSpeech] TextToSpeechSettings enableTextToSpeech
                         * @property {google.cloud.dialogflow.v2beta1.OutputAudioEncoding|null} [outputAudioEncoding] TextToSpeechSettings outputAudioEncoding
                         * @property {number|null} [sampleRateHertz] TextToSpeechSettings sampleRateHertz
                         * @property {Object.<string,google.cloud.dialogflow.v2beta1.ISynthesizeSpeechConfig>|null} [synthesizeSpeechConfigs] TextToSpeechSettings synthesizeSpeechConfigs
                         */
    
                        /**
                         * Constructs a new TextToSpeechSettings.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a TextToSpeechSettings.
                         * @implements ITextToSpeechSettings
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ITextToSpeechSettings=} [properties] Properties to set
                         */
                        function TextToSpeechSettings(properties) {
                            this.synthesizeSpeechConfigs = {};
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * TextToSpeechSettings enableTextToSpeech.
                         * @member {boolean} enableTextToSpeech
                         * @memberof google.cloud.dialogflow.v2beta1.TextToSpeechSettings
                         * @instance
                         */
                        TextToSpeechSettings.prototype.enableTextToSpeech = false;
    
                        /**
                         * TextToSpeechSettings outputAudioEncoding.
                         * @member {google.cloud.dialogflow.v2beta1.OutputAudioEncoding} outputAudioEncoding
                         * @memberof google.cloud.dialogflow.v2beta1.TextToSpeechSettings
                         * @instance
                         */
                        TextToSpeechSettings.prototype.outputAudioEncoding = 0;
    
                        /**
                         * TextToSpeechSettings sampleRateHertz.
                         * @member {number} sampleRateHertz
                         * @memberof google.cloud.dialogflow.v2beta1.TextToSpeechSettings
                         * @instance
                         */
                        TextToSpeechSettings.prototype.sampleRateHertz = 0;
    
                        /**
                         * TextToSpeechSettings synthesizeSpeechConfigs.
                         * @member {Object.<string,google.cloud.dialogflow.v2beta1.ISynthesizeSpeechConfig>} synthesizeSpeechConfigs
                         * @memberof google.cloud.dialogflow.v2beta1.TextToSpeechSettings
                         * @instance
                         */
                        TextToSpeechSettings.prototype.synthesizeSpeechConfigs = $util.emptyObject;
    
                        /**
                         * Creates a new TextToSpeechSettings instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.TextToSpeechSettings
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ITextToSpeechSettings=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.TextToSpeechSettings} TextToSpeechSettings instance
                         */
                        TextToSpeechSettings.create = function create(properties) {
                            return new TextToSpeechSettings(properties);
                        };
    
                        /**
                         * Encodes the specified TextToSpeechSettings message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.TextToSpeechSettings.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.TextToSpeechSettings
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ITextToSpeechSettings} message TextToSpeechSettings message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        TextToSpeechSettings.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.enableTextToSpeech != null && Object.hasOwnProperty.call(message, "enableTextToSpeech"))
                                writer.uint32(/* id 1, wireType 0 =*/8).bool(message.enableTextToSpeech);
                            if (message.outputAudioEncoding != null && Object.hasOwnProperty.call(message, "outputAudioEncoding"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.outputAudioEncoding);
                            if (message.sampleRateHertz != null && Object.hasOwnProperty.call(message, "sampleRateHertz"))
                                writer.uint32(/* id 3, wireType 0 =*/24).int32(message.sampleRateHertz);
                            if (message.synthesizeSpeechConfigs != null && Object.hasOwnProperty.call(message, "synthesizeSpeechConfigs"))
                                for (var keys = Object.keys(message.synthesizeSpeechConfigs), i = 0; i < keys.length; ++i) {
                                    writer.uint32(/* id 4, wireType 2 =*/34).fork().uint32(/* id 1, wireType 2 =*/10).string(keys[i]);
                                    $root.google.cloud.dialogflow.v2beta1.SynthesizeSpeechConfig.encode(message.synthesizeSpeechConfigs[keys[i]], writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim().ldelim();
                                }
                            return writer;
                        };
    
                        /**
                         * Encodes the specified TextToSpeechSettings message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.TextToSpeechSettings.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.TextToSpeechSettings
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ITextToSpeechSettings} message TextToSpeechSettings message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        TextToSpeechSettings.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a TextToSpeechSettings message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.TextToSpeechSettings
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.TextToSpeechSettings} TextToSpeechSettings
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        TextToSpeechSettings.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.TextToSpeechSettings(), key, value;
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.enableTextToSpeech = reader.bool();
                                        break;
                                    }
                                case 2: {
                                        message.outputAudioEncoding = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.sampleRateHertz = reader.int32();
                                        break;
                                    }
                                case 4: {
                                        if (message.synthesizeSpeechConfigs === $util.emptyObject)
                                            message.synthesizeSpeechConfigs = {};
                                        var end2 = reader.uint32() + reader.pos;
                                        key = "";
                                        value = null;
                                        while (reader.pos < end2) {
                                            var tag2 = reader.uint32();
                                            switch (tag2 >>> 3) {
                                            case 1:
                                                key = reader.string();
                                                break;
                                            case 2:
                                                value = $root.google.cloud.dialogflow.v2beta1.SynthesizeSpeechConfig.decode(reader, reader.uint32());
                                                break;
                                            default:
                                                reader.skipType(tag2 & 7);
                                                break;
                                            }
                                        }
                                        message.synthesizeSpeechConfigs[key] = value;
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a TextToSpeechSettings message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.TextToSpeechSettings
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.TextToSpeechSettings} TextToSpeechSettings
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        TextToSpeechSettings.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a TextToSpeechSettings message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.TextToSpeechSettings
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        TextToSpeechSettings.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.enableTextToSpeech != null && message.hasOwnProperty("enableTextToSpeech"))
                                if (typeof message.enableTextToSpeech !== "boolean")
                                    return "enableTextToSpeech: boolean expected";
                            if (message.outputAudioEncoding != null && message.hasOwnProperty("outputAudioEncoding"))
                                switch (message.outputAudioEncoding) {
                                default:
                                    return "outputAudioEncoding: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 4:
                                case 3:
                                case 5:
                                case 6:
                                    break;
                                }
                            if (message.sampleRateHertz != null && message.hasOwnProperty("sampleRateHertz"))
                                if (!$util.isInteger(message.sampleRateHertz))
                                    return "sampleRateHertz: integer expected";
                            if (message.synthesizeSpeechConfigs != null && message.hasOwnProperty("synthesizeSpeechConfigs")) {
                                if (!$util.isObject(message.synthesizeSpeechConfigs))
                                    return "synthesizeSpeechConfigs: object expected";
                                var key = Object.keys(message.synthesizeSpeechConfigs);
                                for (var i = 0; i < key.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.SynthesizeSpeechConfig.verify(message.synthesizeSpeechConfigs[key[i]]);
                                    if (error)
                                        return "synthesizeSpeechConfigs." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates a TextToSpeechSettings message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.TextToSpeechSettings
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.TextToSpeechSettings} TextToSpeechSettings
                         */
                        TextToSpeechSettings.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.TextToSpeechSettings)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.TextToSpeechSettings();
                            if (object.enableTextToSpeech != null)
                                message.enableTextToSpeech = Boolean(object.enableTextToSpeech);
                            switch (object.outputAudioEncoding) {
                            default:
                                if (typeof object.outputAudioEncoding === "number") {
                                    message.outputAudioEncoding = object.outputAudioEncoding;
                                    break;
                                }
                                break;
                            case "OUTPUT_AUDIO_ENCODING_UNSPECIFIED":
                            case 0:
                                message.outputAudioEncoding = 0;
                                break;
                            case "OUTPUT_AUDIO_ENCODING_LINEAR_16":
                            case 1:
                                message.outputAudioEncoding = 1;
                                break;
                            case "OUTPUT_AUDIO_ENCODING_MP3":
                            case 2:
                                message.outputAudioEncoding = 2;
                                break;
                            case "OUTPUT_AUDIO_ENCODING_MP3_64_KBPS":
                            case 4:
                                message.outputAudioEncoding = 4;
                                break;
                            case "OUTPUT_AUDIO_ENCODING_OGG_OPUS":
                            case 3:
                                message.outputAudioEncoding = 3;
                                break;
                            case "OUTPUT_AUDIO_ENCODING_MULAW":
                            case 5:
                                message.outputAudioEncoding = 5;
                                break;
                            case "OUTPUT_AUDIO_ENCODING_ALAW":
                            case 6:
                                message.outputAudioEncoding = 6;
                                break;
                            }
                            if (object.sampleRateHertz != null)
                                message.sampleRateHertz = object.sampleRateHertz | 0;
                            if (object.synthesizeSpeechConfigs) {
                                if (typeof object.synthesizeSpeechConfigs !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.TextToSpeechSettings.synthesizeSpeechConfigs: object expected");
                                message.synthesizeSpeechConfigs = {};
                                for (var keys = Object.keys(object.synthesizeSpeechConfigs), i = 0; i < keys.length; ++i) {
                                    if (typeof object.synthesizeSpeechConfigs[keys[i]] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.TextToSpeechSettings.synthesizeSpeechConfigs: object expected");
                                    message.synthesizeSpeechConfigs[keys[i]] = $root.google.cloud.dialogflow.v2beta1.SynthesizeSpeechConfig.fromObject(object.synthesizeSpeechConfigs[keys[i]]);
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a TextToSpeechSettings message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.TextToSpeechSettings
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.TextToSpeechSettings} message TextToSpeechSettings
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        TextToSpeechSettings.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.objects || options.defaults)
                                object.synthesizeSpeechConfigs = {};
                            if (options.defaults) {
                                object.enableTextToSpeech = false;
                                object.outputAudioEncoding = options.enums === String ? "OUTPUT_AUDIO_ENCODING_UNSPECIFIED" : 0;
                                object.sampleRateHertz = 0;
                            }
                            if (message.enableTextToSpeech != null && message.hasOwnProperty("enableTextToSpeech"))
                                object.enableTextToSpeech = message.enableTextToSpeech;
                            if (message.outputAudioEncoding != null && message.hasOwnProperty("outputAudioEncoding"))
                                object.outputAudioEncoding = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.OutputAudioEncoding[message.outputAudioEncoding] === undefined ? message.outputAudioEncoding : $root.google.cloud.dialogflow.v2beta1.OutputAudioEncoding[message.outputAudioEncoding] : message.outputAudioEncoding;
                            if (message.sampleRateHertz != null && message.hasOwnProperty("sampleRateHertz"))
                                object.sampleRateHertz = message.sampleRateHertz;
                            var keys2;
                            if (message.synthesizeSpeechConfigs && (keys2 = Object.keys(message.synthesizeSpeechConfigs)).length) {
                                object.synthesizeSpeechConfigs = {};
                                for (var j = 0; j < keys2.length; ++j)
                                    object.synthesizeSpeechConfigs[keys2[j]] = $root.google.cloud.dialogflow.v2beta1.SynthesizeSpeechConfig.toObject(message.synthesizeSpeechConfigs[keys2[j]], options);
                            }
                            return object;
                        };
    
                        /**
                         * Converts this TextToSpeechSettings to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.TextToSpeechSettings
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        TextToSpeechSettings.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for TextToSpeechSettings
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.TextToSpeechSettings
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        TextToSpeechSettings.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.TextToSpeechSettings";
                        };
    
                        return TextToSpeechSettings;
                    })();
    
                    v2beta1.ListEnvironmentsRequest = (function() {
    
                        /**
                         * Properties of a ListEnvironmentsRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IListEnvironmentsRequest
                         * @property {string|null} [parent] ListEnvironmentsRequest parent
                         * @property {number|null} [pageSize] ListEnvironmentsRequest pageSize
                         * @property {string|null} [pageToken] ListEnvironmentsRequest pageToken
                         */
    
                        /**
                         * Constructs a new ListEnvironmentsRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a ListEnvironmentsRequest.
                         * @implements IListEnvironmentsRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IListEnvironmentsRequest=} [properties] Properties to set
                         */
                        function ListEnvironmentsRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListEnvironmentsRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.ListEnvironmentsRequest
                         * @instance
                         */
                        ListEnvironmentsRequest.prototype.parent = "";
    
                        /**
                         * ListEnvironmentsRequest pageSize.
                         * @member {number} pageSize
                         * @memberof google.cloud.dialogflow.v2beta1.ListEnvironmentsRequest
                         * @instance
                         */
                        ListEnvironmentsRequest.prototype.pageSize = 0;
    
                        /**
                         * ListEnvironmentsRequest pageToken.
                         * @member {string} pageToken
                         * @memberof google.cloud.dialogflow.v2beta1.ListEnvironmentsRequest
                         * @instance
                         */
                        ListEnvironmentsRequest.prototype.pageToken = "";
    
                        /**
                         * Creates a new ListEnvironmentsRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.ListEnvironmentsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListEnvironmentsRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.ListEnvironmentsRequest} ListEnvironmentsRequest instance
                         */
                        ListEnvironmentsRequest.create = function create(properties) {
                            return new ListEnvironmentsRequest(properties);
                        };
    
                        /**
                         * Encodes the specified ListEnvironmentsRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListEnvironmentsRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.ListEnvironmentsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListEnvironmentsRequest} message ListEnvironmentsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListEnvironmentsRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.pageSize != null && Object.hasOwnProperty.call(message, "pageSize"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.pageSize);
                            if (message.pageToken != null && Object.hasOwnProperty.call(message, "pageToken"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.pageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListEnvironmentsRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListEnvironmentsRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListEnvironmentsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListEnvironmentsRequest} message ListEnvironmentsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListEnvironmentsRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListEnvironmentsRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.ListEnvironmentsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.ListEnvironmentsRequest} ListEnvironmentsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListEnvironmentsRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ListEnvironmentsRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.pageSize = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.pageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListEnvironmentsRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListEnvironmentsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.ListEnvironmentsRequest} ListEnvironmentsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListEnvironmentsRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListEnvironmentsRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.ListEnvironmentsRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListEnvironmentsRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                if (!$util.isInteger(message.pageSize))
                                    return "pageSize: integer expected";
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                if (!$util.isString(message.pageToken))
                                    return "pageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListEnvironmentsRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListEnvironmentsRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.ListEnvironmentsRequest} ListEnvironmentsRequest
                         */
                        ListEnvironmentsRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.ListEnvironmentsRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.ListEnvironmentsRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.pageSize != null)
                                message.pageSize = object.pageSize | 0;
                            if (object.pageToken != null)
                                message.pageToken = String(object.pageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListEnvironmentsRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListEnvironmentsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ListEnvironmentsRequest} message ListEnvironmentsRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListEnvironmentsRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.pageSize = 0;
                                object.pageToken = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                object.pageSize = message.pageSize;
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                object.pageToken = message.pageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListEnvironmentsRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.ListEnvironmentsRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListEnvironmentsRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListEnvironmentsRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.ListEnvironmentsRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListEnvironmentsRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ListEnvironmentsRequest";
                        };
    
                        return ListEnvironmentsRequest;
                    })();
    
                    v2beta1.ListEnvironmentsResponse = (function() {
    
                        /**
                         * Properties of a ListEnvironmentsResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IListEnvironmentsResponse
                         * @property {Array.<google.cloud.dialogflow.v2beta1.IEnvironment>|null} [environments] ListEnvironmentsResponse environments
                         * @property {string|null} [nextPageToken] ListEnvironmentsResponse nextPageToken
                         */
    
                        /**
                         * Constructs a new ListEnvironmentsResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a ListEnvironmentsResponse.
                         * @implements IListEnvironmentsResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IListEnvironmentsResponse=} [properties] Properties to set
                         */
                        function ListEnvironmentsResponse(properties) {
                            this.environments = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListEnvironmentsResponse environments.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.IEnvironment>} environments
                         * @memberof google.cloud.dialogflow.v2beta1.ListEnvironmentsResponse
                         * @instance
                         */
                        ListEnvironmentsResponse.prototype.environments = $util.emptyArray;
    
                        /**
                         * ListEnvironmentsResponse nextPageToken.
                         * @member {string} nextPageToken
                         * @memberof google.cloud.dialogflow.v2beta1.ListEnvironmentsResponse
                         * @instance
                         */
                        ListEnvironmentsResponse.prototype.nextPageToken = "";
    
                        /**
                         * Creates a new ListEnvironmentsResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.ListEnvironmentsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListEnvironmentsResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.ListEnvironmentsResponse} ListEnvironmentsResponse instance
                         */
                        ListEnvironmentsResponse.create = function create(properties) {
                            return new ListEnvironmentsResponse(properties);
                        };
    
                        /**
                         * Encodes the specified ListEnvironmentsResponse message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListEnvironmentsResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.ListEnvironmentsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListEnvironmentsResponse} message ListEnvironmentsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListEnvironmentsResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.environments != null && message.environments.length)
                                for (var i = 0; i < message.environments.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.Environment.encode(message.environments[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.nextPageToken != null && Object.hasOwnProperty.call(message, "nextPageToken"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.nextPageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListEnvironmentsResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListEnvironmentsResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListEnvironmentsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListEnvironmentsResponse} message ListEnvironmentsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListEnvironmentsResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListEnvironmentsResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.ListEnvironmentsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.ListEnvironmentsResponse} ListEnvironmentsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListEnvironmentsResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ListEnvironmentsResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.environments && message.environments.length))
                                            message.environments = [];
                                        message.environments.push($root.google.cloud.dialogflow.v2beta1.Environment.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 2: {
                                        message.nextPageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListEnvironmentsResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListEnvironmentsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.ListEnvironmentsResponse} ListEnvironmentsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListEnvironmentsResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListEnvironmentsResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.ListEnvironmentsResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListEnvironmentsResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.environments != null && message.hasOwnProperty("environments")) {
                                if (!Array.isArray(message.environments))
                                    return "environments: array expected";
                                for (var i = 0; i < message.environments.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.Environment.verify(message.environments[i]);
                                    if (error)
                                        return "environments." + error;
                                }
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                if (!$util.isString(message.nextPageToken))
                                    return "nextPageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListEnvironmentsResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListEnvironmentsResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.ListEnvironmentsResponse} ListEnvironmentsResponse
                         */
                        ListEnvironmentsResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.ListEnvironmentsResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.ListEnvironmentsResponse();
                            if (object.environments) {
                                if (!Array.isArray(object.environments))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.ListEnvironmentsResponse.environments: array expected");
                                message.environments = [];
                                for (var i = 0; i < object.environments.length; ++i) {
                                    if (typeof object.environments[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.ListEnvironmentsResponse.environments: object expected");
                                    message.environments[i] = $root.google.cloud.dialogflow.v2beta1.Environment.fromObject(object.environments[i]);
                                }
                            }
                            if (object.nextPageToken != null)
                                message.nextPageToken = String(object.nextPageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListEnvironmentsResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListEnvironmentsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ListEnvironmentsResponse} message ListEnvironmentsResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListEnvironmentsResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.environments = [];
                            if (options.defaults)
                                object.nextPageToken = "";
                            if (message.environments && message.environments.length) {
                                object.environments = [];
                                for (var j = 0; j < message.environments.length; ++j)
                                    object.environments[j] = $root.google.cloud.dialogflow.v2beta1.Environment.toObject(message.environments[j], options);
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                object.nextPageToken = message.nextPageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListEnvironmentsResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.ListEnvironmentsResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListEnvironmentsResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListEnvironmentsResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.ListEnvironmentsResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListEnvironmentsResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ListEnvironmentsResponse";
                        };
    
                        return ListEnvironmentsResponse;
                    })();
    
                    v2beta1.GetEnvironmentRequest = (function() {
    
                        /**
                         * Properties of a GetEnvironmentRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IGetEnvironmentRequest
                         * @property {string|null} [name] GetEnvironmentRequest name
                         */
    
                        /**
                         * Constructs a new GetEnvironmentRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a GetEnvironmentRequest.
                         * @implements IGetEnvironmentRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IGetEnvironmentRequest=} [properties] Properties to set
                         */
                        function GetEnvironmentRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GetEnvironmentRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2beta1.GetEnvironmentRequest
                         * @instance
                         */
                        GetEnvironmentRequest.prototype.name = "";
    
                        /**
                         * Creates a new GetEnvironmentRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.GetEnvironmentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetEnvironmentRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.GetEnvironmentRequest} GetEnvironmentRequest instance
                         */
                        GetEnvironmentRequest.create = function create(properties) {
                            return new GetEnvironmentRequest(properties);
                        };
    
                        /**
                         * Encodes the specified GetEnvironmentRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GetEnvironmentRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.GetEnvironmentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetEnvironmentRequest} message GetEnvironmentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetEnvironmentRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GetEnvironmentRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GetEnvironmentRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GetEnvironmentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetEnvironmentRequest} message GetEnvironmentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetEnvironmentRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GetEnvironmentRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.GetEnvironmentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.GetEnvironmentRequest} GetEnvironmentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetEnvironmentRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.GetEnvironmentRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GetEnvironmentRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GetEnvironmentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.GetEnvironmentRequest} GetEnvironmentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetEnvironmentRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GetEnvironmentRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.GetEnvironmentRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GetEnvironmentRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a GetEnvironmentRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.GetEnvironmentRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.GetEnvironmentRequest} GetEnvironmentRequest
                         */
                        GetEnvironmentRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.GetEnvironmentRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.GetEnvironmentRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GetEnvironmentRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.GetEnvironmentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.GetEnvironmentRequest} message GetEnvironmentRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GetEnvironmentRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.name = "";
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            return object;
                        };
    
                        /**
                         * Converts this GetEnvironmentRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.GetEnvironmentRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GetEnvironmentRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GetEnvironmentRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.GetEnvironmentRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GetEnvironmentRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.GetEnvironmentRequest";
                        };
    
                        return GetEnvironmentRequest;
                    })();
    
                    v2beta1.CreateEnvironmentRequest = (function() {
    
                        /**
                         * Properties of a CreateEnvironmentRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ICreateEnvironmentRequest
                         * @property {string|null} [parent] CreateEnvironmentRequest parent
                         * @property {google.cloud.dialogflow.v2beta1.IEnvironment|null} [environment] CreateEnvironmentRequest environment
                         * @property {string|null} [environmentId] CreateEnvironmentRequest environmentId
                         */
    
                        /**
                         * Constructs a new CreateEnvironmentRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a CreateEnvironmentRequest.
                         * @implements ICreateEnvironmentRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ICreateEnvironmentRequest=} [properties] Properties to set
                         */
                        function CreateEnvironmentRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * CreateEnvironmentRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.CreateEnvironmentRequest
                         * @instance
                         */
                        CreateEnvironmentRequest.prototype.parent = "";
    
                        /**
                         * CreateEnvironmentRequest environment.
                         * @member {google.cloud.dialogflow.v2beta1.IEnvironment|null|undefined} environment
                         * @memberof google.cloud.dialogflow.v2beta1.CreateEnvironmentRequest
                         * @instance
                         */
                        CreateEnvironmentRequest.prototype.environment = null;
    
                        /**
                         * CreateEnvironmentRequest environmentId.
                         * @member {string} environmentId
                         * @memberof google.cloud.dialogflow.v2beta1.CreateEnvironmentRequest
                         * @instance
                         */
                        CreateEnvironmentRequest.prototype.environmentId = "";
    
                        /**
                         * Creates a new CreateEnvironmentRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.CreateEnvironmentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ICreateEnvironmentRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.CreateEnvironmentRequest} CreateEnvironmentRequest instance
                         */
                        CreateEnvironmentRequest.create = function create(properties) {
                            return new CreateEnvironmentRequest(properties);
                        };
    
                        /**
                         * Encodes the specified CreateEnvironmentRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.CreateEnvironmentRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.CreateEnvironmentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ICreateEnvironmentRequest} message CreateEnvironmentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateEnvironmentRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.environment != null && Object.hasOwnProperty.call(message, "environment"))
                                $root.google.cloud.dialogflow.v2beta1.Environment.encode(message.environment, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.environmentId != null && Object.hasOwnProperty.call(message, "environmentId"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.environmentId);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified CreateEnvironmentRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.CreateEnvironmentRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.CreateEnvironmentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ICreateEnvironmentRequest} message CreateEnvironmentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateEnvironmentRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a CreateEnvironmentRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.CreateEnvironmentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.CreateEnvironmentRequest} CreateEnvironmentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateEnvironmentRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.CreateEnvironmentRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.environment = $root.google.cloud.dialogflow.v2beta1.Environment.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 3: {
                                        message.environmentId = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a CreateEnvironmentRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.CreateEnvironmentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.CreateEnvironmentRequest} CreateEnvironmentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateEnvironmentRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a CreateEnvironmentRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.CreateEnvironmentRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        CreateEnvironmentRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.environment != null && message.hasOwnProperty("environment")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.Environment.verify(message.environment);
                                if (error)
                                    return "environment." + error;
                            }
                            if (message.environmentId != null && message.hasOwnProperty("environmentId"))
                                if (!$util.isString(message.environmentId))
                                    return "environmentId: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a CreateEnvironmentRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.CreateEnvironmentRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.CreateEnvironmentRequest} CreateEnvironmentRequest
                         */
                        CreateEnvironmentRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.CreateEnvironmentRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.CreateEnvironmentRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.environment != null) {
                                if (typeof object.environment !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.CreateEnvironmentRequest.environment: object expected");
                                message.environment = $root.google.cloud.dialogflow.v2beta1.Environment.fromObject(object.environment);
                            }
                            if (object.environmentId != null)
                                message.environmentId = String(object.environmentId);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a CreateEnvironmentRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.CreateEnvironmentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.CreateEnvironmentRequest} message CreateEnvironmentRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        CreateEnvironmentRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.environment = null;
                                object.environmentId = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.environment != null && message.hasOwnProperty("environment"))
                                object.environment = $root.google.cloud.dialogflow.v2beta1.Environment.toObject(message.environment, options);
                            if (message.environmentId != null && message.hasOwnProperty("environmentId"))
                                object.environmentId = message.environmentId;
                            return object;
                        };
    
                        /**
                         * Converts this CreateEnvironmentRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.CreateEnvironmentRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        CreateEnvironmentRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for CreateEnvironmentRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.CreateEnvironmentRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        CreateEnvironmentRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.CreateEnvironmentRequest";
                        };
    
                        return CreateEnvironmentRequest;
                    })();
    
                    v2beta1.UpdateEnvironmentRequest = (function() {
    
                        /**
                         * Properties of an UpdateEnvironmentRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IUpdateEnvironmentRequest
                         * @property {google.cloud.dialogflow.v2beta1.IEnvironment|null} [environment] UpdateEnvironmentRequest environment
                         * @property {google.protobuf.IFieldMask|null} [updateMask] UpdateEnvironmentRequest updateMask
                         * @property {boolean|null} [allowLoadToDraftAndDiscardChanges] UpdateEnvironmentRequest allowLoadToDraftAndDiscardChanges
                         */
    
                        /**
                         * Constructs a new UpdateEnvironmentRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an UpdateEnvironmentRequest.
                         * @implements IUpdateEnvironmentRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateEnvironmentRequest=} [properties] Properties to set
                         */
                        function UpdateEnvironmentRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * UpdateEnvironmentRequest environment.
                         * @member {google.cloud.dialogflow.v2beta1.IEnvironment|null|undefined} environment
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateEnvironmentRequest
                         * @instance
                         */
                        UpdateEnvironmentRequest.prototype.environment = null;
    
                        /**
                         * UpdateEnvironmentRequest updateMask.
                         * @member {google.protobuf.IFieldMask|null|undefined} updateMask
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateEnvironmentRequest
                         * @instance
                         */
                        UpdateEnvironmentRequest.prototype.updateMask = null;
    
                        /**
                         * UpdateEnvironmentRequest allowLoadToDraftAndDiscardChanges.
                         * @member {boolean} allowLoadToDraftAndDiscardChanges
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateEnvironmentRequest
                         * @instance
                         */
                        UpdateEnvironmentRequest.prototype.allowLoadToDraftAndDiscardChanges = false;
    
                        /**
                         * Creates a new UpdateEnvironmentRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateEnvironmentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateEnvironmentRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.UpdateEnvironmentRequest} UpdateEnvironmentRequest instance
                         */
                        UpdateEnvironmentRequest.create = function create(properties) {
                            return new UpdateEnvironmentRequest(properties);
                        };
    
                        /**
                         * Encodes the specified UpdateEnvironmentRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.UpdateEnvironmentRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateEnvironmentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateEnvironmentRequest} message UpdateEnvironmentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UpdateEnvironmentRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.environment != null && Object.hasOwnProperty.call(message, "environment"))
                                $root.google.cloud.dialogflow.v2beta1.Environment.encode(message.environment, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.updateMask != null && Object.hasOwnProperty.call(message, "updateMask"))
                                $root.google.protobuf.FieldMask.encode(message.updateMask, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.allowLoadToDraftAndDiscardChanges != null && Object.hasOwnProperty.call(message, "allowLoadToDraftAndDiscardChanges"))
                                writer.uint32(/* id 3, wireType 0 =*/24).bool(message.allowLoadToDraftAndDiscardChanges);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified UpdateEnvironmentRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.UpdateEnvironmentRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateEnvironmentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateEnvironmentRequest} message UpdateEnvironmentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UpdateEnvironmentRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an UpdateEnvironmentRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateEnvironmentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.UpdateEnvironmentRequest} UpdateEnvironmentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UpdateEnvironmentRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.UpdateEnvironmentRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.environment = $root.google.cloud.dialogflow.v2beta1.Environment.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.updateMask = $root.google.protobuf.FieldMask.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 3: {
                                        message.allowLoadToDraftAndDiscardChanges = reader.bool();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an UpdateEnvironmentRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateEnvironmentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.UpdateEnvironmentRequest} UpdateEnvironmentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UpdateEnvironmentRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an UpdateEnvironmentRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateEnvironmentRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        UpdateEnvironmentRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.environment != null && message.hasOwnProperty("environment")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.Environment.verify(message.environment);
                                if (error)
                                    return "environment." + error;
                            }
                            if (message.updateMask != null && message.hasOwnProperty("updateMask")) {
                                var error = $root.google.protobuf.FieldMask.verify(message.updateMask);
                                if (error)
                                    return "updateMask." + error;
                            }
                            if (message.allowLoadToDraftAndDiscardChanges != null && message.hasOwnProperty("allowLoadToDraftAndDiscardChanges"))
                                if (typeof message.allowLoadToDraftAndDiscardChanges !== "boolean")
                                    return "allowLoadToDraftAndDiscardChanges: boolean expected";
                            return null;
                        };
    
                        /**
                         * Creates an UpdateEnvironmentRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateEnvironmentRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.UpdateEnvironmentRequest} UpdateEnvironmentRequest
                         */
                        UpdateEnvironmentRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.UpdateEnvironmentRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.UpdateEnvironmentRequest();
                            if (object.environment != null) {
                                if (typeof object.environment !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.UpdateEnvironmentRequest.environment: object expected");
                                message.environment = $root.google.cloud.dialogflow.v2beta1.Environment.fromObject(object.environment);
                            }
                            if (object.updateMask != null) {
                                if (typeof object.updateMask !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.UpdateEnvironmentRequest.updateMask: object expected");
                                message.updateMask = $root.google.protobuf.FieldMask.fromObject(object.updateMask);
                            }
                            if (object.allowLoadToDraftAndDiscardChanges != null)
                                message.allowLoadToDraftAndDiscardChanges = Boolean(object.allowLoadToDraftAndDiscardChanges);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an UpdateEnvironmentRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateEnvironmentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.UpdateEnvironmentRequest} message UpdateEnvironmentRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        UpdateEnvironmentRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.environment = null;
                                object.updateMask = null;
                                object.allowLoadToDraftAndDiscardChanges = false;
                            }
                            if (message.environment != null && message.hasOwnProperty("environment"))
                                object.environment = $root.google.cloud.dialogflow.v2beta1.Environment.toObject(message.environment, options);
                            if (message.updateMask != null && message.hasOwnProperty("updateMask"))
                                object.updateMask = $root.google.protobuf.FieldMask.toObject(message.updateMask, options);
                            if (message.allowLoadToDraftAndDiscardChanges != null && message.hasOwnProperty("allowLoadToDraftAndDiscardChanges"))
                                object.allowLoadToDraftAndDiscardChanges = message.allowLoadToDraftAndDiscardChanges;
                            return object;
                        };
    
                        /**
                         * Converts this UpdateEnvironmentRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateEnvironmentRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        UpdateEnvironmentRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for UpdateEnvironmentRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateEnvironmentRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        UpdateEnvironmentRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.UpdateEnvironmentRequest";
                        };
    
                        return UpdateEnvironmentRequest;
                    })();
    
                    v2beta1.DeleteEnvironmentRequest = (function() {
    
                        /**
                         * Properties of a DeleteEnvironmentRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IDeleteEnvironmentRequest
                         * @property {string|null} [name] DeleteEnvironmentRequest name
                         */
    
                        /**
                         * Constructs a new DeleteEnvironmentRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a DeleteEnvironmentRequest.
                         * @implements IDeleteEnvironmentRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteEnvironmentRequest=} [properties] Properties to set
                         */
                        function DeleteEnvironmentRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * DeleteEnvironmentRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteEnvironmentRequest
                         * @instance
                         */
                        DeleteEnvironmentRequest.prototype.name = "";
    
                        /**
                         * Creates a new DeleteEnvironmentRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteEnvironmentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteEnvironmentRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.DeleteEnvironmentRequest} DeleteEnvironmentRequest instance
                         */
                        DeleteEnvironmentRequest.create = function create(properties) {
                            return new DeleteEnvironmentRequest(properties);
                        };
    
                        /**
                         * Encodes the specified DeleteEnvironmentRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.DeleteEnvironmentRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteEnvironmentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteEnvironmentRequest} message DeleteEnvironmentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteEnvironmentRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified DeleteEnvironmentRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.DeleteEnvironmentRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteEnvironmentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteEnvironmentRequest} message DeleteEnvironmentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteEnvironmentRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a DeleteEnvironmentRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteEnvironmentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.DeleteEnvironmentRequest} DeleteEnvironmentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteEnvironmentRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.DeleteEnvironmentRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a DeleteEnvironmentRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteEnvironmentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.DeleteEnvironmentRequest} DeleteEnvironmentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteEnvironmentRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a DeleteEnvironmentRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteEnvironmentRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        DeleteEnvironmentRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a DeleteEnvironmentRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteEnvironmentRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.DeleteEnvironmentRequest} DeleteEnvironmentRequest
                         */
                        DeleteEnvironmentRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.DeleteEnvironmentRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.DeleteEnvironmentRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a DeleteEnvironmentRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteEnvironmentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.DeleteEnvironmentRequest} message DeleteEnvironmentRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        DeleteEnvironmentRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.name = "";
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            return object;
                        };
    
                        /**
                         * Converts this DeleteEnvironmentRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteEnvironmentRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        DeleteEnvironmentRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for DeleteEnvironmentRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteEnvironmentRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        DeleteEnvironmentRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.DeleteEnvironmentRequest";
                        };
    
                        return DeleteEnvironmentRequest;
                    })();
    
                    v2beta1.GetEnvironmentHistoryRequest = (function() {
    
                        /**
                         * Properties of a GetEnvironmentHistoryRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IGetEnvironmentHistoryRequest
                         * @property {string|null} [parent] GetEnvironmentHistoryRequest parent
                         * @property {number|null} [pageSize] GetEnvironmentHistoryRequest pageSize
                         * @property {string|null} [pageToken] GetEnvironmentHistoryRequest pageToken
                         */
    
                        /**
                         * Constructs a new GetEnvironmentHistoryRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a GetEnvironmentHistoryRequest.
                         * @implements IGetEnvironmentHistoryRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IGetEnvironmentHistoryRequest=} [properties] Properties to set
                         */
                        function GetEnvironmentHistoryRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GetEnvironmentHistoryRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.GetEnvironmentHistoryRequest
                         * @instance
                         */
                        GetEnvironmentHistoryRequest.prototype.parent = "";
    
                        /**
                         * GetEnvironmentHistoryRequest pageSize.
                         * @member {number} pageSize
                         * @memberof google.cloud.dialogflow.v2beta1.GetEnvironmentHistoryRequest
                         * @instance
                         */
                        GetEnvironmentHistoryRequest.prototype.pageSize = 0;
    
                        /**
                         * GetEnvironmentHistoryRequest pageToken.
                         * @member {string} pageToken
                         * @memberof google.cloud.dialogflow.v2beta1.GetEnvironmentHistoryRequest
                         * @instance
                         */
                        GetEnvironmentHistoryRequest.prototype.pageToken = "";
    
                        /**
                         * Creates a new GetEnvironmentHistoryRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.GetEnvironmentHistoryRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetEnvironmentHistoryRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.GetEnvironmentHistoryRequest} GetEnvironmentHistoryRequest instance
                         */
                        GetEnvironmentHistoryRequest.create = function create(properties) {
                            return new GetEnvironmentHistoryRequest(properties);
                        };
    
                        /**
                         * Encodes the specified GetEnvironmentHistoryRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GetEnvironmentHistoryRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.GetEnvironmentHistoryRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetEnvironmentHistoryRequest} message GetEnvironmentHistoryRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetEnvironmentHistoryRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.pageSize != null && Object.hasOwnProperty.call(message, "pageSize"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.pageSize);
                            if (message.pageToken != null && Object.hasOwnProperty.call(message, "pageToken"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.pageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GetEnvironmentHistoryRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GetEnvironmentHistoryRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GetEnvironmentHistoryRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetEnvironmentHistoryRequest} message GetEnvironmentHistoryRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetEnvironmentHistoryRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GetEnvironmentHistoryRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.GetEnvironmentHistoryRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.GetEnvironmentHistoryRequest} GetEnvironmentHistoryRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetEnvironmentHistoryRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.GetEnvironmentHistoryRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.pageSize = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.pageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GetEnvironmentHistoryRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GetEnvironmentHistoryRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.GetEnvironmentHistoryRequest} GetEnvironmentHistoryRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetEnvironmentHistoryRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GetEnvironmentHistoryRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.GetEnvironmentHistoryRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GetEnvironmentHistoryRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                if (!$util.isInteger(message.pageSize))
                                    return "pageSize: integer expected";
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                if (!$util.isString(message.pageToken))
                                    return "pageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a GetEnvironmentHistoryRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.GetEnvironmentHistoryRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.GetEnvironmentHistoryRequest} GetEnvironmentHistoryRequest
                         */
                        GetEnvironmentHistoryRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.GetEnvironmentHistoryRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.GetEnvironmentHistoryRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.pageSize != null)
                                message.pageSize = object.pageSize | 0;
                            if (object.pageToken != null)
                                message.pageToken = String(object.pageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GetEnvironmentHistoryRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.GetEnvironmentHistoryRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.GetEnvironmentHistoryRequest} message GetEnvironmentHistoryRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GetEnvironmentHistoryRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.pageSize = 0;
                                object.pageToken = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                object.pageSize = message.pageSize;
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                object.pageToken = message.pageToken;
                            return object;
                        };
    
                        /**
                         * Converts this GetEnvironmentHistoryRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.GetEnvironmentHistoryRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GetEnvironmentHistoryRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GetEnvironmentHistoryRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.GetEnvironmentHistoryRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GetEnvironmentHistoryRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.GetEnvironmentHistoryRequest";
                        };
    
                        return GetEnvironmentHistoryRequest;
                    })();
    
                    v2beta1.EnvironmentHistory = (function() {
    
                        /**
                         * Properties of an EnvironmentHistory.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IEnvironmentHistory
                         * @property {string|null} [parent] EnvironmentHistory parent
                         * @property {Array.<google.cloud.dialogflow.v2beta1.EnvironmentHistory.IEntry>|null} [entries] EnvironmentHistory entries
                         * @property {string|null} [nextPageToken] EnvironmentHistory nextPageToken
                         */
    
                        /**
                         * Constructs a new EnvironmentHistory.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an EnvironmentHistory.
                         * @implements IEnvironmentHistory
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IEnvironmentHistory=} [properties] Properties to set
                         */
                        function EnvironmentHistory(properties) {
                            this.entries = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * EnvironmentHistory parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.EnvironmentHistory
                         * @instance
                         */
                        EnvironmentHistory.prototype.parent = "";
    
                        /**
                         * EnvironmentHistory entries.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.EnvironmentHistory.IEntry>} entries
                         * @memberof google.cloud.dialogflow.v2beta1.EnvironmentHistory
                         * @instance
                         */
                        EnvironmentHistory.prototype.entries = $util.emptyArray;
    
                        /**
                         * EnvironmentHistory nextPageToken.
                         * @member {string} nextPageToken
                         * @memberof google.cloud.dialogflow.v2beta1.EnvironmentHistory
                         * @instance
                         */
                        EnvironmentHistory.prototype.nextPageToken = "";
    
                        /**
                         * Creates a new EnvironmentHistory instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.EnvironmentHistory
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IEnvironmentHistory=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.EnvironmentHistory} EnvironmentHistory instance
                         */
                        EnvironmentHistory.create = function create(properties) {
                            return new EnvironmentHistory(properties);
                        };
    
                        /**
                         * Encodes the specified EnvironmentHistory message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.EnvironmentHistory.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.EnvironmentHistory
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IEnvironmentHistory} message EnvironmentHistory message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        EnvironmentHistory.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.entries != null && message.entries.length)
                                for (var i = 0; i < message.entries.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.EnvironmentHistory.Entry.encode(message.entries[i], writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.nextPageToken != null && Object.hasOwnProperty.call(message, "nextPageToken"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.nextPageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified EnvironmentHistory message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.EnvironmentHistory.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.EnvironmentHistory
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IEnvironmentHistory} message EnvironmentHistory message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        EnvironmentHistory.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an EnvironmentHistory message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.EnvironmentHistory
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.EnvironmentHistory} EnvironmentHistory
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        EnvironmentHistory.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.EnvironmentHistory();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        if (!(message.entries && message.entries.length))
                                            message.entries = [];
                                        message.entries.push($root.google.cloud.dialogflow.v2beta1.EnvironmentHistory.Entry.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 3: {
                                        message.nextPageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an EnvironmentHistory message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.EnvironmentHistory
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.EnvironmentHistory} EnvironmentHistory
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        EnvironmentHistory.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an EnvironmentHistory message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.EnvironmentHistory
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        EnvironmentHistory.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.entries != null && message.hasOwnProperty("entries")) {
                                if (!Array.isArray(message.entries))
                                    return "entries: array expected";
                                for (var i = 0; i < message.entries.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.EnvironmentHistory.Entry.verify(message.entries[i]);
                                    if (error)
                                        return "entries." + error;
                                }
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                if (!$util.isString(message.nextPageToken))
                                    return "nextPageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates an EnvironmentHistory message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.EnvironmentHistory
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.EnvironmentHistory} EnvironmentHistory
                         */
                        EnvironmentHistory.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.EnvironmentHistory)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.EnvironmentHistory();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.entries) {
                                if (!Array.isArray(object.entries))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.EnvironmentHistory.entries: array expected");
                                message.entries = [];
                                for (var i = 0; i < object.entries.length; ++i) {
                                    if (typeof object.entries[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.EnvironmentHistory.entries: object expected");
                                    message.entries[i] = $root.google.cloud.dialogflow.v2beta1.EnvironmentHistory.Entry.fromObject(object.entries[i]);
                                }
                            }
                            if (object.nextPageToken != null)
                                message.nextPageToken = String(object.nextPageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an EnvironmentHistory message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.EnvironmentHistory
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.EnvironmentHistory} message EnvironmentHistory
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        EnvironmentHistory.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.entries = [];
                            if (options.defaults) {
                                object.parent = "";
                                object.nextPageToken = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.entries && message.entries.length) {
                                object.entries = [];
                                for (var j = 0; j < message.entries.length; ++j)
                                    object.entries[j] = $root.google.cloud.dialogflow.v2beta1.EnvironmentHistory.Entry.toObject(message.entries[j], options);
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                object.nextPageToken = message.nextPageToken;
                            return object;
                        };
    
                        /**
                         * Converts this EnvironmentHistory to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.EnvironmentHistory
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        EnvironmentHistory.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for EnvironmentHistory
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.EnvironmentHistory
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        EnvironmentHistory.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.EnvironmentHistory";
                        };
    
                        EnvironmentHistory.Entry = (function() {
    
                            /**
                             * Properties of an Entry.
                             * @memberof google.cloud.dialogflow.v2beta1.EnvironmentHistory
                             * @interface IEntry
                             * @property {string|null} [agentVersion] Entry agentVersion
                             * @property {string|null} [description] Entry description
                             * @property {google.protobuf.ITimestamp|null} [createTime] Entry createTime
                             */
    
                            /**
                             * Constructs a new Entry.
                             * @memberof google.cloud.dialogflow.v2beta1.EnvironmentHistory
                             * @classdesc Represents an Entry.
                             * @implements IEntry
                             * @constructor
                             * @param {google.cloud.dialogflow.v2beta1.EnvironmentHistory.IEntry=} [properties] Properties to set
                             */
                            function Entry(properties) {
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * Entry agentVersion.
                             * @member {string} agentVersion
                             * @memberof google.cloud.dialogflow.v2beta1.EnvironmentHistory.Entry
                             * @instance
                             */
                            Entry.prototype.agentVersion = "";
    
                            /**
                             * Entry description.
                             * @member {string} description
                             * @memberof google.cloud.dialogflow.v2beta1.EnvironmentHistory.Entry
                             * @instance
                             */
                            Entry.prototype.description = "";
    
                            /**
                             * Entry createTime.
                             * @member {google.protobuf.ITimestamp|null|undefined} createTime
                             * @memberof google.cloud.dialogflow.v2beta1.EnvironmentHistory.Entry
                             * @instance
                             */
                            Entry.prototype.createTime = null;
    
                            /**
                             * Creates a new Entry instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2beta1.EnvironmentHistory.Entry
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.EnvironmentHistory.IEntry=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2beta1.EnvironmentHistory.Entry} Entry instance
                             */
                            Entry.create = function create(properties) {
                                return new Entry(properties);
                            };
    
                            /**
                             * Encodes the specified Entry message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.EnvironmentHistory.Entry.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2beta1.EnvironmentHistory.Entry
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.EnvironmentHistory.IEntry} message Entry message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            Entry.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.agentVersion != null && Object.hasOwnProperty.call(message, "agentVersion"))
                                    writer.uint32(/* id 1, wireType 2 =*/10).string(message.agentVersion);
                                if (message.description != null && Object.hasOwnProperty.call(message, "description"))
                                    writer.uint32(/* id 2, wireType 2 =*/18).string(message.description);
                                if (message.createTime != null && Object.hasOwnProperty.call(message, "createTime"))
                                    $root.google.protobuf.Timestamp.encode(message.createTime, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                                return writer;
                            };
    
                            /**
                             * Encodes the specified Entry message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.EnvironmentHistory.Entry.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.EnvironmentHistory.Entry
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.EnvironmentHistory.IEntry} message Entry message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            Entry.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes an Entry message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2beta1.EnvironmentHistory.Entry
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2beta1.EnvironmentHistory.Entry} Entry
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            Entry.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.EnvironmentHistory.Entry();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.agentVersion = reader.string();
                                            break;
                                        }
                                    case 2: {
                                            message.description = reader.string();
                                            break;
                                        }
                                    case 3: {
                                            message.createTime = $root.google.protobuf.Timestamp.decode(reader, reader.uint32());
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes an Entry message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.EnvironmentHistory.Entry
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2beta1.EnvironmentHistory.Entry} Entry
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            Entry.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies an Entry message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2beta1.EnvironmentHistory.Entry
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            Entry.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.agentVersion != null && message.hasOwnProperty("agentVersion"))
                                    if (!$util.isString(message.agentVersion))
                                        return "agentVersion: string expected";
                                if (message.description != null && message.hasOwnProperty("description"))
                                    if (!$util.isString(message.description))
                                        return "description: string expected";
                                if (message.createTime != null && message.hasOwnProperty("createTime")) {
                                    var error = $root.google.protobuf.Timestamp.verify(message.createTime);
                                    if (error)
                                        return "createTime." + error;
                                }
                                return null;
                            };
    
                            /**
                             * Creates an Entry message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2beta1.EnvironmentHistory.Entry
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2beta1.EnvironmentHistory.Entry} Entry
                             */
                            Entry.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2beta1.EnvironmentHistory.Entry)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2beta1.EnvironmentHistory.Entry();
                                if (object.agentVersion != null)
                                    message.agentVersion = String(object.agentVersion);
                                if (object.description != null)
                                    message.description = String(object.description);
                                if (object.createTime != null) {
                                    if (typeof object.createTime !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.EnvironmentHistory.Entry.createTime: object expected");
                                    message.createTime = $root.google.protobuf.Timestamp.fromObject(object.createTime);
                                }
                                return message;
                            };
    
                            /**
                             * Creates a plain object from an Entry message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2beta1.EnvironmentHistory.Entry
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.EnvironmentHistory.Entry} message Entry
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            Entry.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.defaults) {
                                    object.agentVersion = "";
                                    object.description = "";
                                    object.createTime = null;
                                }
                                if (message.agentVersion != null && message.hasOwnProperty("agentVersion"))
                                    object.agentVersion = message.agentVersion;
                                if (message.description != null && message.hasOwnProperty("description"))
                                    object.description = message.description;
                                if (message.createTime != null && message.hasOwnProperty("createTime"))
                                    object.createTime = $root.google.protobuf.Timestamp.toObject(message.createTime, options);
                                return object;
                            };
    
                            /**
                             * Converts this Entry to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2beta1.EnvironmentHistory.Entry
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            Entry.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for Entry
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2beta1.EnvironmentHistory.Entry
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            Entry.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.EnvironmentHistory.Entry";
                            };
    
                            return Entry;
                        })();
    
                        return EnvironmentHistory;
                    })();
    
                    v2beta1.Fulfillments = (function() {
    
                        /**
                         * Constructs a new Fulfillments service.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a Fulfillments
                         * @extends $protobuf.rpc.Service
                         * @constructor
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         */
                        function Fulfillments(rpcImpl, requestDelimited, responseDelimited) {
                            $protobuf.rpc.Service.call(this, rpcImpl, requestDelimited, responseDelimited);
                        }
    
                        (Fulfillments.prototype = Object.create($protobuf.rpc.Service.prototype)).constructor = Fulfillments;
    
                        /**
                         * Creates new Fulfillments service using the specified rpc implementation.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.Fulfillments
                         * @static
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         * @returns {Fulfillments} RPC service. Useful where requests and/or responses are streamed.
                         */
                        Fulfillments.create = function create(rpcImpl, requestDelimited, responseDelimited) {
                            return new this(rpcImpl, requestDelimited, responseDelimited);
                        };
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Fulfillments|getFulfillment}.
                         * @memberof google.cloud.dialogflow.v2beta1.Fulfillments
                         * @typedef GetFulfillmentCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.Fulfillment} [response] Fulfillment
                         */
    
                        /**
                         * Calls GetFulfillment.
                         * @function getFulfillment
                         * @memberof google.cloud.dialogflow.v2beta1.Fulfillments
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IGetFulfillmentRequest} request GetFulfillmentRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Fulfillments.GetFulfillmentCallback} callback Node-style callback called with the error, if any, and Fulfillment
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Fulfillments.prototype.getFulfillment = function getFulfillment(request, callback) {
                            return this.rpcCall(getFulfillment, $root.google.cloud.dialogflow.v2beta1.GetFulfillmentRequest, $root.google.cloud.dialogflow.v2beta1.Fulfillment, request, callback);
                        }, "name", { value: "GetFulfillment" });
    
                        /**
                         * Calls GetFulfillment.
                         * @function getFulfillment
                         * @memberof google.cloud.dialogflow.v2beta1.Fulfillments
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IGetFulfillmentRequest} request GetFulfillmentRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.Fulfillment>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Fulfillments|updateFulfillment}.
                         * @memberof google.cloud.dialogflow.v2beta1.Fulfillments
                         * @typedef UpdateFulfillmentCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.Fulfillment} [response] Fulfillment
                         */
    
                        /**
                         * Calls UpdateFulfillment.
                         * @function updateFulfillment
                         * @memberof google.cloud.dialogflow.v2beta1.Fulfillments
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateFulfillmentRequest} request UpdateFulfillmentRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Fulfillments.UpdateFulfillmentCallback} callback Node-style callback called with the error, if any, and Fulfillment
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Fulfillments.prototype.updateFulfillment = function updateFulfillment(request, callback) {
                            return this.rpcCall(updateFulfillment, $root.google.cloud.dialogflow.v2beta1.UpdateFulfillmentRequest, $root.google.cloud.dialogflow.v2beta1.Fulfillment, request, callback);
                        }, "name", { value: "UpdateFulfillment" });
    
                        /**
                         * Calls UpdateFulfillment.
                         * @function updateFulfillment
                         * @memberof google.cloud.dialogflow.v2beta1.Fulfillments
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateFulfillmentRequest} request UpdateFulfillmentRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.Fulfillment>} Promise
                         * @variation 2
                         */
    
                        return Fulfillments;
                    })();
    
                    v2beta1.Fulfillment = (function() {
    
                        /**
                         * Properties of a Fulfillment.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IFulfillment
                         * @property {string|null} [name] Fulfillment name
                         * @property {string|null} [displayName] Fulfillment displayName
                         * @property {google.cloud.dialogflow.v2beta1.Fulfillment.IGenericWebService|null} [genericWebService] Fulfillment genericWebService
                         * @property {boolean|null} [enabled] Fulfillment enabled
                         * @property {Array.<google.cloud.dialogflow.v2beta1.Fulfillment.IFeature>|null} [features] Fulfillment features
                         */
    
                        /**
                         * Constructs a new Fulfillment.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a Fulfillment.
                         * @implements IFulfillment
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IFulfillment=} [properties] Properties to set
                         */
                        function Fulfillment(properties) {
                            this.features = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * Fulfillment name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2beta1.Fulfillment
                         * @instance
                         */
                        Fulfillment.prototype.name = "";
    
                        /**
                         * Fulfillment displayName.
                         * @member {string} displayName
                         * @memberof google.cloud.dialogflow.v2beta1.Fulfillment
                         * @instance
                         */
                        Fulfillment.prototype.displayName = "";
    
                        /**
                         * Fulfillment genericWebService.
                         * @member {google.cloud.dialogflow.v2beta1.Fulfillment.IGenericWebService|null|undefined} genericWebService
                         * @memberof google.cloud.dialogflow.v2beta1.Fulfillment
                         * @instance
                         */
                        Fulfillment.prototype.genericWebService = null;
    
                        /**
                         * Fulfillment enabled.
                         * @member {boolean} enabled
                         * @memberof google.cloud.dialogflow.v2beta1.Fulfillment
                         * @instance
                         */
                        Fulfillment.prototype.enabled = false;
    
                        /**
                         * Fulfillment features.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.Fulfillment.IFeature>} features
                         * @memberof google.cloud.dialogflow.v2beta1.Fulfillment
                         * @instance
                         */
                        Fulfillment.prototype.features = $util.emptyArray;
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * Fulfillment fulfillment.
                         * @member {"genericWebService"|undefined} fulfillment
                         * @memberof google.cloud.dialogflow.v2beta1.Fulfillment
                         * @instance
                         */
                        Object.defineProperty(Fulfillment.prototype, "fulfillment", {
                            get: $util.oneOfGetter($oneOfFields = ["genericWebService"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new Fulfillment instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.Fulfillment
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IFulfillment=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.Fulfillment} Fulfillment instance
                         */
                        Fulfillment.create = function create(properties) {
                            return new Fulfillment(properties);
                        };
    
                        /**
                         * Encodes the specified Fulfillment message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Fulfillment.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.Fulfillment
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IFulfillment} message Fulfillment message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        Fulfillment.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            if (message.displayName != null && Object.hasOwnProperty.call(message, "displayName"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.displayName);
                            if (message.genericWebService != null && Object.hasOwnProperty.call(message, "genericWebService"))
                                $root.google.cloud.dialogflow.v2beta1.Fulfillment.GenericWebService.encode(message.genericWebService, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            if (message.enabled != null && Object.hasOwnProperty.call(message, "enabled"))
                                writer.uint32(/* id 4, wireType 0 =*/32).bool(message.enabled);
                            if (message.features != null && message.features.length)
                                for (var i = 0; i < message.features.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.Fulfillment.Feature.encode(message.features[i], writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified Fulfillment message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Fulfillment.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.Fulfillment
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IFulfillment} message Fulfillment message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        Fulfillment.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a Fulfillment message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.Fulfillment
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.Fulfillment} Fulfillment
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        Fulfillment.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Fulfillment();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.displayName = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.genericWebService = $root.google.cloud.dialogflow.v2beta1.Fulfillment.GenericWebService.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 4: {
                                        message.enabled = reader.bool();
                                        break;
                                    }
                                case 5: {
                                        if (!(message.features && message.features.length))
                                            message.features = [];
                                        message.features.push($root.google.cloud.dialogflow.v2beta1.Fulfillment.Feature.decode(reader, reader.uint32()));
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a Fulfillment message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.Fulfillment
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.Fulfillment} Fulfillment
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        Fulfillment.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a Fulfillment message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.Fulfillment
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        Fulfillment.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            if (message.displayName != null && message.hasOwnProperty("displayName"))
                                if (!$util.isString(message.displayName))
                                    return "displayName: string expected";
                            if (message.genericWebService != null && message.hasOwnProperty("genericWebService")) {
                                properties.fulfillment = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2beta1.Fulfillment.GenericWebService.verify(message.genericWebService);
                                    if (error)
                                        return "genericWebService." + error;
                                }
                            }
                            if (message.enabled != null && message.hasOwnProperty("enabled"))
                                if (typeof message.enabled !== "boolean")
                                    return "enabled: boolean expected";
                            if (message.features != null && message.hasOwnProperty("features")) {
                                if (!Array.isArray(message.features))
                                    return "features: array expected";
                                for (var i = 0; i < message.features.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.Fulfillment.Feature.verify(message.features[i]);
                                    if (error)
                                        return "features." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates a Fulfillment message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.Fulfillment
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.Fulfillment} Fulfillment
                         */
                        Fulfillment.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.Fulfillment)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.Fulfillment();
                            if (object.name != null)
                                message.name = String(object.name);
                            if (object.displayName != null)
                                message.displayName = String(object.displayName);
                            if (object.genericWebService != null) {
                                if (typeof object.genericWebService !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.Fulfillment.genericWebService: object expected");
                                message.genericWebService = $root.google.cloud.dialogflow.v2beta1.Fulfillment.GenericWebService.fromObject(object.genericWebService);
                            }
                            if (object.enabled != null)
                                message.enabled = Boolean(object.enabled);
                            if (object.features) {
                                if (!Array.isArray(object.features))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.Fulfillment.features: array expected");
                                message.features = [];
                                for (var i = 0; i < object.features.length; ++i) {
                                    if (typeof object.features[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.Fulfillment.features: object expected");
                                    message.features[i] = $root.google.cloud.dialogflow.v2beta1.Fulfillment.Feature.fromObject(object.features[i]);
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a Fulfillment message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.Fulfillment
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.Fulfillment} message Fulfillment
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        Fulfillment.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.features = [];
                            if (options.defaults) {
                                object.name = "";
                                object.displayName = "";
                                object.enabled = false;
                            }
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            if (message.displayName != null && message.hasOwnProperty("displayName"))
                                object.displayName = message.displayName;
                            if (message.genericWebService != null && message.hasOwnProperty("genericWebService")) {
                                object.genericWebService = $root.google.cloud.dialogflow.v2beta1.Fulfillment.GenericWebService.toObject(message.genericWebService, options);
                                if (options.oneofs)
                                    object.fulfillment = "genericWebService";
                            }
                            if (message.enabled != null && message.hasOwnProperty("enabled"))
                                object.enabled = message.enabled;
                            if (message.features && message.features.length) {
                                object.features = [];
                                for (var j = 0; j < message.features.length; ++j)
                                    object.features[j] = $root.google.cloud.dialogflow.v2beta1.Fulfillment.Feature.toObject(message.features[j], options);
                            }
                            return object;
                        };
    
                        /**
                         * Converts this Fulfillment to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.Fulfillment
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        Fulfillment.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for Fulfillment
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.Fulfillment
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        Fulfillment.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Fulfillment";
                        };
    
                        Fulfillment.GenericWebService = (function() {
    
                            /**
                             * Properties of a GenericWebService.
                             * @memberof google.cloud.dialogflow.v2beta1.Fulfillment
                             * @interface IGenericWebService
                             * @property {string|null} [uri] GenericWebService uri
                             * @property {string|null} [username] GenericWebService username
                             * @property {string|null} [password] GenericWebService password
                             * @property {Object.<string,string>|null} [requestHeaders] GenericWebService requestHeaders
                             * @property {boolean|null} [isCloudFunction] GenericWebService isCloudFunction
                             */
    
                            /**
                             * Constructs a new GenericWebService.
                             * @memberof google.cloud.dialogflow.v2beta1.Fulfillment
                             * @classdesc Represents a GenericWebService.
                             * @implements IGenericWebService
                             * @constructor
                             * @param {google.cloud.dialogflow.v2beta1.Fulfillment.IGenericWebService=} [properties] Properties to set
                             */
                            function GenericWebService(properties) {
                                this.requestHeaders = {};
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * GenericWebService uri.
                             * @member {string} uri
                             * @memberof google.cloud.dialogflow.v2beta1.Fulfillment.GenericWebService
                             * @instance
                             */
                            GenericWebService.prototype.uri = "";
    
                            /**
                             * GenericWebService username.
                             * @member {string} username
                             * @memberof google.cloud.dialogflow.v2beta1.Fulfillment.GenericWebService
                             * @instance
                             */
                            GenericWebService.prototype.username = "";
    
                            /**
                             * GenericWebService password.
                             * @member {string} password
                             * @memberof google.cloud.dialogflow.v2beta1.Fulfillment.GenericWebService
                             * @instance
                             */
                            GenericWebService.prototype.password = "";
    
                            /**
                             * GenericWebService requestHeaders.
                             * @member {Object.<string,string>} requestHeaders
                             * @memberof google.cloud.dialogflow.v2beta1.Fulfillment.GenericWebService
                             * @instance
                             */
                            GenericWebService.prototype.requestHeaders = $util.emptyObject;
    
                            /**
                             * GenericWebService isCloudFunction.
                             * @member {boolean} isCloudFunction
                             * @memberof google.cloud.dialogflow.v2beta1.Fulfillment.GenericWebService
                             * @instance
                             */
                            GenericWebService.prototype.isCloudFunction = false;
    
                            /**
                             * Creates a new GenericWebService instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2beta1.Fulfillment.GenericWebService
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.Fulfillment.IGenericWebService=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2beta1.Fulfillment.GenericWebService} GenericWebService instance
                             */
                            GenericWebService.create = function create(properties) {
                                return new GenericWebService(properties);
                            };
    
                            /**
                             * Encodes the specified GenericWebService message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Fulfillment.GenericWebService.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2beta1.Fulfillment.GenericWebService
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.Fulfillment.IGenericWebService} message GenericWebService message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            GenericWebService.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.uri != null && Object.hasOwnProperty.call(message, "uri"))
                                    writer.uint32(/* id 1, wireType 2 =*/10).string(message.uri);
                                if (message.username != null && Object.hasOwnProperty.call(message, "username"))
                                    writer.uint32(/* id 2, wireType 2 =*/18).string(message.username);
                                if (message.password != null && Object.hasOwnProperty.call(message, "password"))
                                    writer.uint32(/* id 3, wireType 2 =*/26).string(message.password);
                                if (message.requestHeaders != null && Object.hasOwnProperty.call(message, "requestHeaders"))
                                    for (var keys = Object.keys(message.requestHeaders), i = 0; i < keys.length; ++i)
                                        writer.uint32(/* id 4, wireType 2 =*/34).fork().uint32(/* id 1, wireType 2 =*/10).string(keys[i]).uint32(/* id 2, wireType 2 =*/18).string(message.requestHeaders[keys[i]]).ldelim();
                                if (message.isCloudFunction != null && Object.hasOwnProperty.call(message, "isCloudFunction"))
                                    writer.uint32(/* id 5, wireType 0 =*/40).bool(message.isCloudFunction);
                                return writer;
                            };
    
                            /**
                             * Encodes the specified GenericWebService message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Fulfillment.GenericWebService.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.Fulfillment.GenericWebService
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.Fulfillment.IGenericWebService} message GenericWebService message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            GenericWebService.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a GenericWebService message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2beta1.Fulfillment.GenericWebService
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2beta1.Fulfillment.GenericWebService} GenericWebService
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            GenericWebService.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Fulfillment.GenericWebService(), key, value;
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.uri = reader.string();
                                            break;
                                        }
                                    case 2: {
                                            message.username = reader.string();
                                            break;
                                        }
                                    case 3: {
                                            message.password = reader.string();
                                            break;
                                        }
                                    case 4: {
                                            if (message.requestHeaders === $util.emptyObject)
                                                message.requestHeaders = {};
                                            var end2 = reader.uint32() + reader.pos;
                                            key = "";
                                            value = "";
                                            while (reader.pos < end2) {
                                                var tag2 = reader.uint32();
                                                switch (tag2 >>> 3) {
                                                case 1:
                                                    key = reader.string();
                                                    break;
                                                case 2:
                                                    value = reader.string();
                                                    break;
                                                default:
                                                    reader.skipType(tag2 & 7);
                                                    break;
                                                }
                                            }
                                            message.requestHeaders[key] = value;
                                            break;
                                        }
                                    case 5: {
                                            message.isCloudFunction = reader.bool();
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a GenericWebService message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.Fulfillment.GenericWebService
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2beta1.Fulfillment.GenericWebService} GenericWebService
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            GenericWebService.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a GenericWebService message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2beta1.Fulfillment.GenericWebService
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            GenericWebService.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.uri != null && message.hasOwnProperty("uri"))
                                    if (!$util.isString(message.uri))
                                        return "uri: string expected";
                                if (message.username != null && message.hasOwnProperty("username"))
                                    if (!$util.isString(message.username))
                                        return "username: string expected";
                                if (message.password != null && message.hasOwnProperty("password"))
                                    if (!$util.isString(message.password))
                                        return "password: string expected";
                                if (message.requestHeaders != null && message.hasOwnProperty("requestHeaders")) {
                                    if (!$util.isObject(message.requestHeaders))
                                        return "requestHeaders: object expected";
                                    var key = Object.keys(message.requestHeaders);
                                    for (var i = 0; i < key.length; ++i)
                                        if (!$util.isString(message.requestHeaders[key[i]]))
                                            return "requestHeaders: string{k:string} expected";
                                }
                                if (message.isCloudFunction != null && message.hasOwnProperty("isCloudFunction"))
                                    if (typeof message.isCloudFunction !== "boolean")
                                        return "isCloudFunction: boolean expected";
                                return null;
                            };
    
                            /**
                             * Creates a GenericWebService message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2beta1.Fulfillment.GenericWebService
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2beta1.Fulfillment.GenericWebService} GenericWebService
                             */
                            GenericWebService.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2beta1.Fulfillment.GenericWebService)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2beta1.Fulfillment.GenericWebService();
                                if (object.uri != null)
                                    message.uri = String(object.uri);
                                if (object.username != null)
                                    message.username = String(object.username);
                                if (object.password != null)
                                    message.password = String(object.password);
                                if (object.requestHeaders) {
                                    if (typeof object.requestHeaders !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.Fulfillment.GenericWebService.requestHeaders: object expected");
                                    message.requestHeaders = {};
                                    for (var keys = Object.keys(object.requestHeaders), i = 0; i < keys.length; ++i)
                                        message.requestHeaders[keys[i]] = String(object.requestHeaders[keys[i]]);
                                }
                                if (object.isCloudFunction != null)
                                    message.isCloudFunction = Boolean(object.isCloudFunction);
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a GenericWebService message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2beta1.Fulfillment.GenericWebService
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.Fulfillment.GenericWebService} message GenericWebService
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            GenericWebService.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.objects || options.defaults)
                                    object.requestHeaders = {};
                                if (options.defaults) {
                                    object.uri = "";
                                    object.username = "";
                                    object.password = "";
                                    object.isCloudFunction = false;
                                }
                                if (message.uri != null && message.hasOwnProperty("uri"))
                                    object.uri = message.uri;
                                if (message.username != null && message.hasOwnProperty("username"))
                                    object.username = message.username;
                                if (message.password != null && message.hasOwnProperty("password"))
                                    object.password = message.password;
                                var keys2;
                                if (message.requestHeaders && (keys2 = Object.keys(message.requestHeaders)).length) {
                                    object.requestHeaders = {};
                                    for (var j = 0; j < keys2.length; ++j)
                                        object.requestHeaders[keys2[j]] = message.requestHeaders[keys2[j]];
                                }
                                if (message.isCloudFunction != null && message.hasOwnProperty("isCloudFunction"))
                                    object.isCloudFunction = message.isCloudFunction;
                                return object;
                            };
    
                            /**
                             * Converts this GenericWebService to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2beta1.Fulfillment.GenericWebService
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            GenericWebService.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for GenericWebService
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2beta1.Fulfillment.GenericWebService
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            GenericWebService.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Fulfillment.GenericWebService";
                            };
    
                            return GenericWebService;
                        })();
    
                        Fulfillment.Feature = (function() {
    
                            /**
                             * Properties of a Feature.
                             * @memberof google.cloud.dialogflow.v2beta1.Fulfillment
                             * @interface IFeature
                             * @property {google.cloud.dialogflow.v2beta1.Fulfillment.Feature.Type|null} [type] Feature type
                             */
    
                            /**
                             * Constructs a new Feature.
                             * @memberof google.cloud.dialogflow.v2beta1.Fulfillment
                             * @classdesc Represents a Feature.
                             * @implements IFeature
                             * @constructor
                             * @param {google.cloud.dialogflow.v2beta1.Fulfillment.IFeature=} [properties] Properties to set
                             */
                            function Feature(properties) {
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * Feature type.
                             * @member {google.cloud.dialogflow.v2beta1.Fulfillment.Feature.Type} type
                             * @memberof google.cloud.dialogflow.v2beta1.Fulfillment.Feature
                             * @instance
                             */
                            Feature.prototype.type = 0;
    
                            /**
                             * Creates a new Feature instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2beta1.Fulfillment.Feature
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.Fulfillment.IFeature=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2beta1.Fulfillment.Feature} Feature instance
                             */
                            Feature.create = function create(properties) {
                                return new Feature(properties);
                            };
    
                            /**
                             * Encodes the specified Feature message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Fulfillment.Feature.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2beta1.Fulfillment.Feature
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.Fulfillment.IFeature} message Feature message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            Feature.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.type != null && Object.hasOwnProperty.call(message, "type"))
                                    writer.uint32(/* id 1, wireType 0 =*/8).int32(message.type);
                                return writer;
                            };
    
                            /**
                             * Encodes the specified Feature message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Fulfillment.Feature.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.Fulfillment.Feature
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.Fulfillment.IFeature} message Feature message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            Feature.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes a Feature message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2beta1.Fulfillment.Feature
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2beta1.Fulfillment.Feature} Feature
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            Feature.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Fulfillment.Feature();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.type = reader.int32();
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes a Feature message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.Fulfillment.Feature
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2beta1.Fulfillment.Feature} Feature
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            Feature.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies a Feature message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2beta1.Fulfillment.Feature
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            Feature.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                if (message.type != null && message.hasOwnProperty("type"))
                                    switch (message.type) {
                                    default:
                                        return "type: enum value expected";
                                    case 0:
                                    case 1:
                                        break;
                                    }
                                return null;
                            };
    
                            /**
                             * Creates a Feature message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2beta1.Fulfillment.Feature
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2beta1.Fulfillment.Feature} Feature
                             */
                            Feature.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2beta1.Fulfillment.Feature)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2beta1.Fulfillment.Feature();
                                switch (object.type) {
                                default:
                                    if (typeof object.type === "number") {
                                        message.type = object.type;
                                        break;
                                    }
                                    break;
                                case "TYPE_UNSPECIFIED":
                                case 0:
                                    message.type = 0;
                                    break;
                                case "SMALLTALK":
                                case 1:
                                    message.type = 1;
                                    break;
                                }
                                return message;
                            };
    
                            /**
                             * Creates a plain object from a Feature message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2beta1.Fulfillment.Feature
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.Fulfillment.Feature} message Feature
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            Feature.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (options.defaults)
                                    object.type = options.enums === String ? "TYPE_UNSPECIFIED" : 0;
                                if (message.type != null && message.hasOwnProperty("type"))
                                    object.type = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.Fulfillment.Feature.Type[message.type] === undefined ? message.type : $root.google.cloud.dialogflow.v2beta1.Fulfillment.Feature.Type[message.type] : message.type;
                                return object;
                            };
    
                            /**
                             * Converts this Feature to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2beta1.Fulfillment.Feature
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            Feature.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for Feature
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2beta1.Fulfillment.Feature
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            Feature.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Fulfillment.Feature";
                            };
    
                            /**
                             * Type enum.
                             * @name google.cloud.dialogflow.v2beta1.Fulfillment.Feature.Type
                             * @enum {number}
                             * @property {number} TYPE_UNSPECIFIED=0 TYPE_UNSPECIFIED value
                             * @property {number} SMALLTALK=1 SMALLTALK value
                             */
                            Feature.Type = (function() {
                                var valuesById = {}, values = Object.create(valuesById);
                                values[valuesById[0] = "TYPE_UNSPECIFIED"] = 0;
                                values[valuesById[1] = "SMALLTALK"] = 1;
                                return values;
                            })();
    
                            return Feature;
                        })();
    
                        return Fulfillment;
                    })();
    
                    v2beta1.GetFulfillmentRequest = (function() {
    
                        /**
                         * Properties of a GetFulfillmentRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IGetFulfillmentRequest
                         * @property {string|null} [name] GetFulfillmentRequest name
                         */
    
                        /**
                         * Constructs a new GetFulfillmentRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a GetFulfillmentRequest.
                         * @implements IGetFulfillmentRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IGetFulfillmentRequest=} [properties] Properties to set
                         */
                        function GetFulfillmentRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GetFulfillmentRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2beta1.GetFulfillmentRequest
                         * @instance
                         */
                        GetFulfillmentRequest.prototype.name = "";
    
                        /**
                         * Creates a new GetFulfillmentRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.GetFulfillmentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetFulfillmentRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.GetFulfillmentRequest} GetFulfillmentRequest instance
                         */
                        GetFulfillmentRequest.create = function create(properties) {
                            return new GetFulfillmentRequest(properties);
                        };
    
                        /**
                         * Encodes the specified GetFulfillmentRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GetFulfillmentRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.GetFulfillmentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetFulfillmentRequest} message GetFulfillmentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetFulfillmentRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GetFulfillmentRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GetFulfillmentRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GetFulfillmentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetFulfillmentRequest} message GetFulfillmentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetFulfillmentRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GetFulfillmentRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.GetFulfillmentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.GetFulfillmentRequest} GetFulfillmentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetFulfillmentRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.GetFulfillmentRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GetFulfillmentRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GetFulfillmentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.GetFulfillmentRequest} GetFulfillmentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetFulfillmentRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GetFulfillmentRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.GetFulfillmentRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GetFulfillmentRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a GetFulfillmentRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.GetFulfillmentRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.GetFulfillmentRequest} GetFulfillmentRequest
                         */
                        GetFulfillmentRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.GetFulfillmentRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.GetFulfillmentRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GetFulfillmentRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.GetFulfillmentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.GetFulfillmentRequest} message GetFulfillmentRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GetFulfillmentRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.name = "";
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            return object;
                        };
    
                        /**
                         * Converts this GetFulfillmentRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.GetFulfillmentRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GetFulfillmentRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GetFulfillmentRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.GetFulfillmentRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GetFulfillmentRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.GetFulfillmentRequest";
                        };
    
                        return GetFulfillmentRequest;
                    })();
    
                    v2beta1.UpdateFulfillmentRequest = (function() {
    
                        /**
                         * Properties of an UpdateFulfillmentRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IUpdateFulfillmentRequest
                         * @property {google.cloud.dialogflow.v2beta1.IFulfillment|null} [fulfillment] UpdateFulfillmentRequest fulfillment
                         * @property {google.protobuf.IFieldMask|null} [updateMask] UpdateFulfillmentRequest updateMask
                         */
    
                        /**
                         * Constructs a new UpdateFulfillmentRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an UpdateFulfillmentRequest.
                         * @implements IUpdateFulfillmentRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateFulfillmentRequest=} [properties] Properties to set
                         */
                        function UpdateFulfillmentRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * UpdateFulfillmentRequest fulfillment.
                         * @member {google.cloud.dialogflow.v2beta1.IFulfillment|null|undefined} fulfillment
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateFulfillmentRequest
                         * @instance
                         */
                        UpdateFulfillmentRequest.prototype.fulfillment = null;
    
                        /**
                         * UpdateFulfillmentRequest updateMask.
                         * @member {google.protobuf.IFieldMask|null|undefined} updateMask
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateFulfillmentRequest
                         * @instance
                         */
                        UpdateFulfillmentRequest.prototype.updateMask = null;
    
                        /**
                         * Creates a new UpdateFulfillmentRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateFulfillmentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateFulfillmentRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.UpdateFulfillmentRequest} UpdateFulfillmentRequest instance
                         */
                        UpdateFulfillmentRequest.create = function create(properties) {
                            return new UpdateFulfillmentRequest(properties);
                        };
    
                        /**
                         * Encodes the specified UpdateFulfillmentRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.UpdateFulfillmentRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateFulfillmentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateFulfillmentRequest} message UpdateFulfillmentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UpdateFulfillmentRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.fulfillment != null && Object.hasOwnProperty.call(message, "fulfillment"))
                                $root.google.cloud.dialogflow.v2beta1.Fulfillment.encode(message.fulfillment, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.updateMask != null && Object.hasOwnProperty.call(message, "updateMask"))
                                $root.google.protobuf.FieldMask.encode(message.updateMask, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified UpdateFulfillmentRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.UpdateFulfillmentRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateFulfillmentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateFulfillmentRequest} message UpdateFulfillmentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UpdateFulfillmentRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an UpdateFulfillmentRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateFulfillmentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.UpdateFulfillmentRequest} UpdateFulfillmentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UpdateFulfillmentRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.UpdateFulfillmentRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.fulfillment = $root.google.cloud.dialogflow.v2beta1.Fulfillment.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.updateMask = $root.google.protobuf.FieldMask.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an UpdateFulfillmentRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateFulfillmentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.UpdateFulfillmentRequest} UpdateFulfillmentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UpdateFulfillmentRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an UpdateFulfillmentRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateFulfillmentRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        UpdateFulfillmentRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.fulfillment != null && message.hasOwnProperty("fulfillment")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.Fulfillment.verify(message.fulfillment);
                                if (error)
                                    return "fulfillment." + error;
                            }
                            if (message.updateMask != null && message.hasOwnProperty("updateMask")) {
                                var error = $root.google.protobuf.FieldMask.verify(message.updateMask);
                                if (error)
                                    return "updateMask." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates an UpdateFulfillmentRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateFulfillmentRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.UpdateFulfillmentRequest} UpdateFulfillmentRequest
                         */
                        UpdateFulfillmentRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.UpdateFulfillmentRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.UpdateFulfillmentRequest();
                            if (object.fulfillment != null) {
                                if (typeof object.fulfillment !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.UpdateFulfillmentRequest.fulfillment: object expected");
                                message.fulfillment = $root.google.cloud.dialogflow.v2beta1.Fulfillment.fromObject(object.fulfillment);
                            }
                            if (object.updateMask != null) {
                                if (typeof object.updateMask !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.UpdateFulfillmentRequest.updateMask: object expected");
                                message.updateMask = $root.google.protobuf.FieldMask.fromObject(object.updateMask);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an UpdateFulfillmentRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateFulfillmentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.UpdateFulfillmentRequest} message UpdateFulfillmentRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        UpdateFulfillmentRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.fulfillment = null;
                                object.updateMask = null;
                            }
                            if (message.fulfillment != null && message.hasOwnProperty("fulfillment"))
                                object.fulfillment = $root.google.cloud.dialogflow.v2beta1.Fulfillment.toObject(message.fulfillment, options);
                            if (message.updateMask != null && message.hasOwnProperty("updateMask"))
                                object.updateMask = $root.google.protobuf.FieldMask.toObject(message.updateMask, options);
                            return object;
                        };
    
                        /**
                         * Converts this UpdateFulfillmentRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateFulfillmentRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        UpdateFulfillmentRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for UpdateFulfillmentRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateFulfillmentRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        UpdateFulfillmentRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.UpdateFulfillmentRequest";
                        };
    
                        return UpdateFulfillmentRequest;
                    })();
    
                    v2beta1.HumanAgentAssistantEvent = (function() {
    
                        /**
                         * Properties of a HumanAgentAssistantEvent.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IHumanAgentAssistantEvent
                         * @property {string|null} [conversation] HumanAgentAssistantEvent conversation
                         * @property {string|null} [participant] HumanAgentAssistantEvent participant
                         * @property {Array.<google.cloud.dialogflow.v2beta1.ISuggestionResult>|null} [suggestionResults] HumanAgentAssistantEvent suggestionResults
                         */
    
                        /**
                         * Constructs a new HumanAgentAssistantEvent.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a HumanAgentAssistantEvent.
                         * @implements IHumanAgentAssistantEvent
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IHumanAgentAssistantEvent=} [properties] Properties to set
                         */
                        function HumanAgentAssistantEvent(properties) {
                            this.suggestionResults = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * HumanAgentAssistantEvent conversation.
                         * @member {string} conversation
                         * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantEvent
                         * @instance
                         */
                        HumanAgentAssistantEvent.prototype.conversation = "";
    
                        /**
                         * HumanAgentAssistantEvent participant.
                         * @member {string} participant
                         * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantEvent
                         * @instance
                         */
                        HumanAgentAssistantEvent.prototype.participant = "";
    
                        /**
                         * HumanAgentAssistantEvent suggestionResults.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.ISuggestionResult>} suggestionResults
                         * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantEvent
                         * @instance
                         */
                        HumanAgentAssistantEvent.prototype.suggestionResults = $util.emptyArray;
    
                        /**
                         * Creates a new HumanAgentAssistantEvent instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantEvent
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IHumanAgentAssistantEvent=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantEvent} HumanAgentAssistantEvent instance
                         */
                        HumanAgentAssistantEvent.create = function create(properties) {
                            return new HumanAgentAssistantEvent(properties);
                        };
    
                        /**
                         * Encodes the specified HumanAgentAssistantEvent message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.HumanAgentAssistantEvent.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantEvent
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IHumanAgentAssistantEvent} message HumanAgentAssistantEvent message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        HumanAgentAssistantEvent.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.conversation != null && Object.hasOwnProperty.call(message, "conversation"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.conversation);
                            if (message.participant != null && Object.hasOwnProperty.call(message, "participant"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.participant);
                            if (message.suggestionResults != null && message.suggestionResults.length)
                                for (var i = 0; i < message.suggestionResults.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.SuggestionResult.encode(message.suggestionResults[i], writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified HumanAgentAssistantEvent message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.HumanAgentAssistantEvent.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantEvent
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IHumanAgentAssistantEvent} message HumanAgentAssistantEvent message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        HumanAgentAssistantEvent.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a HumanAgentAssistantEvent message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantEvent
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantEvent} HumanAgentAssistantEvent
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        HumanAgentAssistantEvent.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantEvent();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.conversation = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.participant = reader.string();
                                        break;
                                    }
                                case 5: {
                                        if (!(message.suggestionResults && message.suggestionResults.length))
                                            message.suggestionResults = [];
                                        message.suggestionResults.push($root.google.cloud.dialogflow.v2beta1.SuggestionResult.decode(reader, reader.uint32()));
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a HumanAgentAssistantEvent message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantEvent
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantEvent} HumanAgentAssistantEvent
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        HumanAgentAssistantEvent.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a HumanAgentAssistantEvent message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantEvent
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        HumanAgentAssistantEvent.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.conversation != null && message.hasOwnProperty("conversation"))
                                if (!$util.isString(message.conversation))
                                    return "conversation: string expected";
                            if (message.participant != null && message.hasOwnProperty("participant"))
                                if (!$util.isString(message.participant))
                                    return "participant: string expected";
                            if (message.suggestionResults != null && message.hasOwnProperty("suggestionResults")) {
                                if (!Array.isArray(message.suggestionResults))
                                    return "suggestionResults: array expected";
                                for (var i = 0; i < message.suggestionResults.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.SuggestionResult.verify(message.suggestionResults[i]);
                                    if (error)
                                        return "suggestionResults." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates a HumanAgentAssistantEvent message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantEvent
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.HumanAgentAssistantEvent} HumanAgentAssistantEvent
                         */
                        HumanAgentAssistantEvent.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantEvent)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.HumanAgentAssistantEvent();
                            if (object.conversation != null)
                                message.conversation = String(object.conversation);
                            if (object.participant != null)
                                message.participant = String(object.participant);
                            if (object.suggestionResults) {
                                if (!Array.isArray(object.suggestionResults))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.HumanAgentAssistantEvent.suggestionResults: array expected");
                                message.suggestionResults = [];
                                for (var i = 0; i < object.suggestionResults.length; ++i) {
                                    if (typeof object.suggestionResults[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.HumanAgentAssistantEvent.suggestionResults: object expected");
                                    message.suggestionResults[i] = $root.google.cloud.dialogflow.v2beta1.SuggestionResult.fromObject(object.suggestionResults[i]);
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a HumanAgentAssistantEvent message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantEvent
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.HumanAgentAssistantEvent} message HumanAgentAssistantEvent
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        HumanAgentAssistantEvent.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.suggestionResults = [];
                            if (options.defaults) {
                                object.conversation = "";
                                object.participant = "";
                            }
                            if (message.conversation != null && message.hasOwnProperty("conversation"))
                                object.conversation = message.conversation;
                            if (message.participant != null && message.hasOwnProperty("participant"))
                                object.participant = message.participant;
                            if (message.suggestionResults && message.suggestionResults.length) {
                                object.suggestionResults = [];
                                for (var j = 0; j < message.suggestionResults.length; ++j)
                                    object.suggestionResults[j] = $root.google.cloud.dialogflow.v2beta1.SuggestionResult.toObject(message.suggestionResults[j], options);
                            }
                            return object;
                        };
    
                        /**
                         * Converts this HumanAgentAssistantEvent to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantEvent
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        HumanAgentAssistantEvent.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for HumanAgentAssistantEvent
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.HumanAgentAssistantEvent
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        HumanAgentAssistantEvent.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.HumanAgentAssistantEvent";
                        };
    
                        return HumanAgentAssistantEvent;
                    })();
    
                    v2beta1.KnowledgeBases = (function() {
    
                        /**
                         * Constructs a new KnowledgeBases service.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a KnowledgeBases
                         * @extends $protobuf.rpc.Service
                         * @constructor
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         */
                        function KnowledgeBases(rpcImpl, requestDelimited, responseDelimited) {
                            $protobuf.rpc.Service.call(this, rpcImpl, requestDelimited, responseDelimited);
                        }
    
                        (KnowledgeBases.prototype = Object.create($protobuf.rpc.Service.prototype)).constructor = KnowledgeBases;
    
                        /**
                         * Creates new KnowledgeBases service using the specified rpc implementation.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeBases
                         * @static
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         * @returns {KnowledgeBases} RPC service. Useful where requests and/or responses are streamed.
                         */
                        KnowledgeBases.create = function create(rpcImpl, requestDelimited, responseDelimited) {
                            return new this(rpcImpl, requestDelimited, responseDelimited);
                        };
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.KnowledgeBases|listKnowledgeBases}.
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeBases
                         * @typedef ListKnowledgeBasesCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.ListKnowledgeBasesResponse} [response] ListKnowledgeBasesResponse
                         */
    
                        /**
                         * Calls ListKnowledgeBases.
                         * @function listKnowledgeBases
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeBases
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IListKnowledgeBasesRequest} request ListKnowledgeBasesRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.KnowledgeBases.ListKnowledgeBasesCallback} callback Node-style callback called with the error, if any, and ListKnowledgeBasesResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(KnowledgeBases.prototype.listKnowledgeBases = function listKnowledgeBases(request, callback) {
                            return this.rpcCall(listKnowledgeBases, $root.google.cloud.dialogflow.v2beta1.ListKnowledgeBasesRequest, $root.google.cloud.dialogflow.v2beta1.ListKnowledgeBasesResponse, request, callback);
                        }, "name", { value: "ListKnowledgeBases" });
    
                        /**
                         * Calls ListKnowledgeBases.
                         * @function listKnowledgeBases
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeBases
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IListKnowledgeBasesRequest} request ListKnowledgeBasesRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.ListKnowledgeBasesResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.KnowledgeBases|getKnowledgeBase}.
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeBases
                         * @typedef GetKnowledgeBaseCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.KnowledgeBase} [response] KnowledgeBase
                         */
    
                        /**
                         * Calls GetKnowledgeBase.
                         * @function getKnowledgeBase
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeBases
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IGetKnowledgeBaseRequest} request GetKnowledgeBaseRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.KnowledgeBases.GetKnowledgeBaseCallback} callback Node-style callback called with the error, if any, and KnowledgeBase
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(KnowledgeBases.prototype.getKnowledgeBase = function getKnowledgeBase(request, callback) {
                            return this.rpcCall(getKnowledgeBase, $root.google.cloud.dialogflow.v2beta1.GetKnowledgeBaseRequest, $root.google.cloud.dialogflow.v2beta1.KnowledgeBase, request, callback);
                        }, "name", { value: "GetKnowledgeBase" });
    
                        /**
                         * Calls GetKnowledgeBase.
                         * @function getKnowledgeBase
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeBases
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IGetKnowledgeBaseRequest} request GetKnowledgeBaseRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.KnowledgeBase>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.KnowledgeBases|createKnowledgeBase}.
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeBases
                         * @typedef CreateKnowledgeBaseCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.KnowledgeBase} [response] KnowledgeBase
                         */
    
                        /**
                         * Calls CreateKnowledgeBase.
                         * @function createKnowledgeBase
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeBases
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.ICreateKnowledgeBaseRequest} request CreateKnowledgeBaseRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.KnowledgeBases.CreateKnowledgeBaseCallback} callback Node-style callback called with the error, if any, and KnowledgeBase
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(KnowledgeBases.prototype.createKnowledgeBase = function createKnowledgeBase(request, callback) {
                            return this.rpcCall(createKnowledgeBase, $root.google.cloud.dialogflow.v2beta1.CreateKnowledgeBaseRequest, $root.google.cloud.dialogflow.v2beta1.KnowledgeBase, request, callback);
                        }, "name", { value: "CreateKnowledgeBase" });
    
                        /**
                         * Calls CreateKnowledgeBase.
                         * @function createKnowledgeBase
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeBases
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.ICreateKnowledgeBaseRequest} request CreateKnowledgeBaseRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.KnowledgeBase>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.KnowledgeBases|deleteKnowledgeBase}.
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeBases
                         * @typedef DeleteKnowledgeBaseCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.protobuf.Empty} [response] Empty
                         */
    
                        /**
                         * Calls DeleteKnowledgeBase.
                         * @function deleteKnowledgeBase
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeBases
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteKnowledgeBaseRequest} request DeleteKnowledgeBaseRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.KnowledgeBases.DeleteKnowledgeBaseCallback} callback Node-style callback called with the error, if any, and Empty
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(KnowledgeBases.prototype.deleteKnowledgeBase = function deleteKnowledgeBase(request, callback) {
                            return this.rpcCall(deleteKnowledgeBase, $root.google.cloud.dialogflow.v2beta1.DeleteKnowledgeBaseRequest, $root.google.protobuf.Empty, request, callback);
                        }, "name", { value: "DeleteKnowledgeBase" });
    
                        /**
                         * Calls DeleteKnowledgeBase.
                         * @function deleteKnowledgeBase
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeBases
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteKnowledgeBaseRequest} request DeleteKnowledgeBaseRequest message or plain object
                         * @returns {Promise<google.protobuf.Empty>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.KnowledgeBases|updateKnowledgeBase}.
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeBases
                         * @typedef UpdateKnowledgeBaseCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.KnowledgeBase} [response] KnowledgeBase
                         */
    
                        /**
                         * Calls UpdateKnowledgeBase.
                         * @function updateKnowledgeBase
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeBases
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateKnowledgeBaseRequest} request UpdateKnowledgeBaseRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.KnowledgeBases.UpdateKnowledgeBaseCallback} callback Node-style callback called with the error, if any, and KnowledgeBase
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(KnowledgeBases.prototype.updateKnowledgeBase = function updateKnowledgeBase(request, callback) {
                            return this.rpcCall(updateKnowledgeBase, $root.google.cloud.dialogflow.v2beta1.UpdateKnowledgeBaseRequest, $root.google.cloud.dialogflow.v2beta1.KnowledgeBase, request, callback);
                        }, "name", { value: "UpdateKnowledgeBase" });
    
                        /**
                         * Calls UpdateKnowledgeBase.
                         * @function updateKnowledgeBase
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeBases
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateKnowledgeBaseRequest} request UpdateKnowledgeBaseRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.KnowledgeBase>} Promise
                         * @variation 2
                         */
    
                        return KnowledgeBases;
                    })();
    
                    v2beta1.KnowledgeBase = (function() {
    
                        /**
                         * Properties of a KnowledgeBase.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IKnowledgeBase
                         * @property {string|null} [name] KnowledgeBase name
                         * @property {string|null} [displayName] KnowledgeBase displayName
                         * @property {string|null} [languageCode] KnowledgeBase languageCode
                         */
    
                        /**
                         * Constructs a new KnowledgeBase.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a KnowledgeBase.
                         * @implements IKnowledgeBase
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IKnowledgeBase=} [properties] Properties to set
                         */
                        function KnowledgeBase(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * KnowledgeBase name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeBase
                         * @instance
                         */
                        KnowledgeBase.prototype.name = "";
    
                        /**
                         * KnowledgeBase displayName.
                         * @member {string} displayName
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeBase
                         * @instance
                         */
                        KnowledgeBase.prototype.displayName = "";
    
                        /**
                         * KnowledgeBase languageCode.
                         * @member {string} languageCode
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeBase
                         * @instance
                         */
                        KnowledgeBase.prototype.languageCode = "";
    
                        /**
                         * Creates a new KnowledgeBase instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeBase
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IKnowledgeBase=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.KnowledgeBase} KnowledgeBase instance
                         */
                        KnowledgeBase.create = function create(properties) {
                            return new KnowledgeBase(properties);
                        };
    
                        /**
                         * Encodes the specified KnowledgeBase message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.KnowledgeBase.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeBase
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IKnowledgeBase} message KnowledgeBase message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        KnowledgeBase.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            if (message.displayName != null && Object.hasOwnProperty.call(message, "displayName"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.displayName);
                            if (message.languageCode != null && Object.hasOwnProperty.call(message, "languageCode"))
                                writer.uint32(/* id 4, wireType 2 =*/34).string(message.languageCode);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified KnowledgeBase message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.KnowledgeBase.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeBase
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IKnowledgeBase} message KnowledgeBase message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        KnowledgeBase.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a KnowledgeBase message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeBase
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.KnowledgeBase} KnowledgeBase
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        KnowledgeBase.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.KnowledgeBase();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.displayName = reader.string();
                                        break;
                                    }
                                case 4: {
                                        message.languageCode = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a KnowledgeBase message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeBase
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.KnowledgeBase} KnowledgeBase
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        KnowledgeBase.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a KnowledgeBase message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeBase
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        KnowledgeBase.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            if (message.displayName != null && message.hasOwnProperty("displayName"))
                                if (!$util.isString(message.displayName))
                                    return "displayName: string expected";
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                if (!$util.isString(message.languageCode))
                                    return "languageCode: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a KnowledgeBase message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeBase
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.KnowledgeBase} KnowledgeBase
                         */
                        KnowledgeBase.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.KnowledgeBase)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.KnowledgeBase();
                            if (object.name != null)
                                message.name = String(object.name);
                            if (object.displayName != null)
                                message.displayName = String(object.displayName);
                            if (object.languageCode != null)
                                message.languageCode = String(object.languageCode);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a KnowledgeBase message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeBase
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.KnowledgeBase} message KnowledgeBase
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        KnowledgeBase.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.name = "";
                                object.displayName = "";
                                object.languageCode = "";
                            }
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            if (message.displayName != null && message.hasOwnProperty("displayName"))
                                object.displayName = message.displayName;
                            if (message.languageCode != null && message.hasOwnProperty("languageCode"))
                                object.languageCode = message.languageCode;
                            return object;
                        };
    
                        /**
                         * Converts this KnowledgeBase to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeBase
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        KnowledgeBase.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for KnowledgeBase
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.KnowledgeBase
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        KnowledgeBase.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.KnowledgeBase";
                        };
    
                        return KnowledgeBase;
                    })();
    
                    v2beta1.ListKnowledgeBasesRequest = (function() {
    
                        /**
                         * Properties of a ListKnowledgeBasesRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IListKnowledgeBasesRequest
                         * @property {string|null} [parent] ListKnowledgeBasesRequest parent
                         * @property {number|null} [pageSize] ListKnowledgeBasesRequest pageSize
                         * @property {string|null} [pageToken] ListKnowledgeBasesRequest pageToken
                         * @property {string|null} [filter] ListKnowledgeBasesRequest filter
                         */
    
                        /**
                         * Constructs a new ListKnowledgeBasesRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a ListKnowledgeBasesRequest.
                         * @implements IListKnowledgeBasesRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IListKnowledgeBasesRequest=} [properties] Properties to set
                         */
                        function ListKnowledgeBasesRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListKnowledgeBasesRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.ListKnowledgeBasesRequest
                         * @instance
                         */
                        ListKnowledgeBasesRequest.prototype.parent = "";
    
                        /**
                         * ListKnowledgeBasesRequest pageSize.
                         * @member {number} pageSize
                         * @memberof google.cloud.dialogflow.v2beta1.ListKnowledgeBasesRequest
                         * @instance
                         */
                        ListKnowledgeBasesRequest.prototype.pageSize = 0;
    
                        /**
                         * ListKnowledgeBasesRequest pageToken.
                         * @member {string} pageToken
                         * @memberof google.cloud.dialogflow.v2beta1.ListKnowledgeBasesRequest
                         * @instance
                         */
                        ListKnowledgeBasesRequest.prototype.pageToken = "";
    
                        /**
                         * ListKnowledgeBasesRequest filter.
                         * @member {string} filter
                         * @memberof google.cloud.dialogflow.v2beta1.ListKnowledgeBasesRequest
                         * @instance
                         */
                        ListKnowledgeBasesRequest.prototype.filter = "";
    
                        /**
                         * Creates a new ListKnowledgeBasesRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.ListKnowledgeBasesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListKnowledgeBasesRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.ListKnowledgeBasesRequest} ListKnowledgeBasesRequest instance
                         */
                        ListKnowledgeBasesRequest.create = function create(properties) {
                            return new ListKnowledgeBasesRequest(properties);
                        };
    
                        /**
                         * Encodes the specified ListKnowledgeBasesRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListKnowledgeBasesRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.ListKnowledgeBasesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListKnowledgeBasesRequest} message ListKnowledgeBasesRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListKnowledgeBasesRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.pageSize != null && Object.hasOwnProperty.call(message, "pageSize"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.pageSize);
                            if (message.pageToken != null && Object.hasOwnProperty.call(message, "pageToken"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.pageToken);
                            if (message.filter != null && Object.hasOwnProperty.call(message, "filter"))
                                writer.uint32(/* id 4, wireType 2 =*/34).string(message.filter);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListKnowledgeBasesRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListKnowledgeBasesRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListKnowledgeBasesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListKnowledgeBasesRequest} message ListKnowledgeBasesRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListKnowledgeBasesRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListKnowledgeBasesRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.ListKnowledgeBasesRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.ListKnowledgeBasesRequest} ListKnowledgeBasesRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListKnowledgeBasesRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ListKnowledgeBasesRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.pageSize = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.pageToken = reader.string();
                                        break;
                                    }
                                case 4: {
                                        message.filter = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListKnowledgeBasesRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListKnowledgeBasesRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.ListKnowledgeBasesRequest} ListKnowledgeBasesRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListKnowledgeBasesRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListKnowledgeBasesRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.ListKnowledgeBasesRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListKnowledgeBasesRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                if (!$util.isInteger(message.pageSize))
                                    return "pageSize: integer expected";
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                if (!$util.isString(message.pageToken))
                                    return "pageToken: string expected";
                            if (message.filter != null && message.hasOwnProperty("filter"))
                                if (!$util.isString(message.filter))
                                    return "filter: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListKnowledgeBasesRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListKnowledgeBasesRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.ListKnowledgeBasesRequest} ListKnowledgeBasesRequest
                         */
                        ListKnowledgeBasesRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.ListKnowledgeBasesRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.ListKnowledgeBasesRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.pageSize != null)
                                message.pageSize = object.pageSize | 0;
                            if (object.pageToken != null)
                                message.pageToken = String(object.pageToken);
                            if (object.filter != null)
                                message.filter = String(object.filter);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListKnowledgeBasesRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListKnowledgeBasesRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ListKnowledgeBasesRequest} message ListKnowledgeBasesRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListKnowledgeBasesRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.pageSize = 0;
                                object.pageToken = "";
                                object.filter = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                object.pageSize = message.pageSize;
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                object.pageToken = message.pageToken;
                            if (message.filter != null && message.hasOwnProperty("filter"))
                                object.filter = message.filter;
                            return object;
                        };
    
                        /**
                         * Converts this ListKnowledgeBasesRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.ListKnowledgeBasesRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListKnowledgeBasesRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListKnowledgeBasesRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.ListKnowledgeBasesRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListKnowledgeBasesRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ListKnowledgeBasesRequest";
                        };
    
                        return ListKnowledgeBasesRequest;
                    })();
    
                    v2beta1.ListKnowledgeBasesResponse = (function() {
    
                        /**
                         * Properties of a ListKnowledgeBasesResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IListKnowledgeBasesResponse
                         * @property {Array.<google.cloud.dialogflow.v2beta1.IKnowledgeBase>|null} [knowledgeBases] ListKnowledgeBasesResponse knowledgeBases
                         * @property {string|null} [nextPageToken] ListKnowledgeBasesResponse nextPageToken
                         */
    
                        /**
                         * Constructs a new ListKnowledgeBasesResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a ListKnowledgeBasesResponse.
                         * @implements IListKnowledgeBasesResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IListKnowledgeBasesResponse=} [properties] Properties to set
                         */
                        function ListKnowledgeBasesResponse(properties) {
                            this.knowledgeBases = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListKnowledgeBasesResponse knowledgeBases.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.IKnowledgeBase>} knowledgeBases
                         * @memberof google.cloud.dialogflow.v2beta1.ListKnowledgeBasesResponse
                         * @instance
                         */
                        ListKnowledgeBasesResponse.prototype.knowledgeBases = $util.emptyArray;
    
                        /**
                         * ListKnowledgeBasesResponse nextPageToken.
                         * @member {string} nextPageToken
                         * @memberof google.cloud.dialogflow.v2beta1.ListKnowledgeBasesResponse
                         * @instance
                         */
                        ListKnowledgeBasesResponse.prototype.nextPageToken = "";
    
                        /**
                         * Creates a new ListKnowledgeBasesResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.ListKnowledgeBasesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListKnowledgeBasesResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.ListKnowledgeBasesResponse} ListKnowledgeBasesResponse instance
                         */
                        ListKnowledgeBasesResponse.create = function create(properties) {
                            return new ListKnowledgeBasesResponse(properties);
                        };
    
                        /**
                         * Encodes the specified ListKnowledgeBasesResponse message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListKnowledgeBasesResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.ListKnowledgeBasesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListKnowledgeBasesResponse} message ListKnowledgeBasesResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListKnowledgeBasesResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.knowledgeBases != null && message.knowledgeBases.length)
                                for (var i = 0; i < message.knowledgeBases.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.KnowledgeBase.encode(message.knowledgeBases[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.nextPageToken != null && Object.hasOwnProperty.call(message, "nextPageToken"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.nextPageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListKnowledgeBasesResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListKnowledgeBasesResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListKnowledgeBasesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListKnowledgeBasesResponse} message ListKnowledgeBasesResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListKnowledgeBasesResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListKnowledgeBasesResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.ListKnowledgeBasesResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.ListKnowledgeBasesResponse} ListKnowledgeBasesResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListKnowledgeBasesResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ListKnowledgeBasesResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.knowledgeBases && message.knowledgeBases.length))
                                            message.knowledgeBases = [];
                                        message.knowledgeBases.push($root.google.cloud.dialogflow.v2beta1.KnowledgeBase.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 2: {
                                        message.nextPageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListKnowledgeBasesResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListKnowledgeBasesResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.ListKnowledgeBasesResponse} ListKnowledgeBasesResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListKnowledgeBasesResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListKnowledgeBasesResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.ListKnowledgeBasesResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListKnowledgeBasesResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.knowledgeBases != null && message.hasOwnProperty("knowledgeBases")) {
                                if (!Array.isArray(message.knowledgeBases))
                                    return "knowledgeBases: array expected";
                                for (var i = 0; i < message.knowledgeBases.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.KnowledgeBase.verify(message.knowledgeBases[i]);
                                    if (error)
                                        return "knowledgeBases." + error;
                                }
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                if (!$util.isString(message.nextPageToken))
                                    return "nextPageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListKnowledgeBasesResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListKnowledgeBasesResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.ListKnowledgeBasesResponse} ListKnowledgeBasesResponse
                         */
                        ListKnowledgeBasesResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.ListKnowledgeBasesResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.ListKnowledgeBasesResponse();
                            if (object.knowledgeBases) {
                                if (!Array.isArray(object.knowledgeBases))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.ListKnowledgeBasesResponse.knowledgeBases: array expected");
                                message.knowledgeBases = [];
                                for (var i = 0; i < object.knowledgeBases.length; ++i) {
                                    if (typeof object.knowledgeBases[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.ListKnowledgeBasesResponse.knowledgeBases: object expected");
                                    message.knowledgeBases[i] = $root.google.cloud.dialogflow.v2beta1.KnowledgeBase.fromObject(object.knowledgeBases[i]);
                                }
                            }
                            if (object.nextPageToken != null)
                                message.nextPageToken = String(object.nextPageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListKnowledgeBasesResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListKnowledgeBasesResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ListKnowledgeBasesResponse} message ListKnowledgeBasesResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListKnowledgeBasesResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.knowledgeBases = [];
                            if (options.defaults)
                                object.nextPageToken = "";
                            if (message.knowledgeBases && message.knowledgeBases.length) {
                                object.knowledgeBases = [];
                                for (var j = 0; j < message.knowledgeBases.length; ++j)
                                    object.knowledgeBases[j] = $root.google.cloud.dialogflow.v2beta1.KnowledgeBase.toObject(message.knowledgeBases[j], options);
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                object.nextPageToken = message.nextPageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListKnowledgeBasesResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.ListKnowledgeBasesResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListKnowledgeBasesResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListKnowledgeBasesResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.ListKnowledgeBasesResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListKnowledgeBasesResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ListKnowledgeBasesResponse";
                        };
    
                        return ListKnowledgeBasesResponse;
                    })();
    
                    v2beta1.GetKnowledgeBaseRequest = (function() {
    
                        /**
                         * Properties of a GetKnowledgeBaseRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IGetKnowledgeBaseRequest
                         * @property {string|null} [name] GetKnowledgeBaseRequest name
                         */
    
                        /**
                         * Constructs a new GetKnowledgeBaseRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a GetKnowledgeBaseRequest.
                         * @implements IGetKnowledgeBaseRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IGetKnowledgeBaseRequest=} [properties] Properties to set
                         */
                        function GetKnowledgeBaseRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GetKnowledgeBaseRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2beta1.GetKnowledgeBaseRequest
                         * @instance
                         */
                        GetKnowledgeBaseRequest.prototype.name = "";
    
                        /**
                         * Creates a new GetKnowledgeBaseRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.GetKnowledgeBaseRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetKnowledgeBaseRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.GetKnowledgeBaseRequest} GetKnowledgeBaseRequest instance
                         */
                        GetKnowledgeBaseRequest.create = function create(properties) {
                            return new GetKnowledgeBaseRequest(properties);
                        };
    
                        /**
                         * Encodes the specified GetKnowledgeBaseRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GetKnowledgeBaseRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.GetKnowledgeBaseRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetKnowledgeBaseRequest} message GetKnowledgeBaseRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetKnowledgeBaseRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GetKnowledgeBaseRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GetKnowledgeBaseRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GetKnowledgeBaseRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetKnowledgeBaseRequest} message GetKnowledgeBaseRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetKnowledgeBaseRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GetKnowledgeBaseRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.GetKnowledgeBaseRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.GetKnowledgeBaseRequest} GetKnowledgeBaseRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetKnowledgeBaseRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.GetKnowledgeBaseRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GetKnowledgeBaseRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GetKnowledgeBaseRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.GetKnowledgeBaseRequest} GetKnowledgeBaseRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetKnowledgeBaseRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GetKnowledgeBaseRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.GetKnowledgeBaseRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GetKnowledgeBaseRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a GetKnowledgeBaseRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.GetKnowledgeBaseRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.GetKnowledgeBaseRequest} GetKnowledgeBaseRequest
                         */
                        GetKnowledgeBaseRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.GetKnowledgeBaseRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.GetKnowledgeBaseRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GetKnowledgeBaseRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.GetKnowledgeBaseRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.GetKnowledgeBaseRequest} message GetKnowledgeBaseRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GetKnowledgeBaseRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.name = "";
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            return object;
                        };
    
                        /**
                         * Converts this GetKnowledgeBaseRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.GetKnowledgeBaseRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GetKnowledgeBaseRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GetKnowledgeBaseRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.GetKnowledgeBaseRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GetKnowledgeBaseRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.GetKnowledgeBaseRequest";
                        };
    
                        return GetKnowledgeBaseRequest;
                    })();
    
                    v2beta1.CreateKnowledgeBaseRequest = (function() {
    
                        /**
                         * Properties of a CreateKnowledgeBaseRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ICreateKnowledgeBaseRequest
                         * @property {string|null} [parent] CreateKnowledgeBaseRequest parent
                         * @property {google.cloud.dialogflow.v2beta1.IKnowledgeBase|null} [knowledgeBase] CreateKnowledgeBaseRequest knowledgeBase
                         */
    
                        /**
                         * Constructs a new CreateKnowledgeBaseRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a CreateKnowledgeBaseRequest.
                         * @implements ICreateKnowledgeBaseRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ICreateKnowledgeBaseRequest=} [properties] Properties to set
                         */
                        function CreateKnowledgeBaseRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * CreateKnowledgeBaseRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.CreateKnowledgeBaseRequest
                         * @instance
                         */
                        CreateKnowledgeBaseRequest.prototype.parent = "";
    
                        /**
                         * CreateKnowledgeBaseRequest knowledgeBase.
                         * @member {google.cloud.dialogflow.v2beta1.IKnowledgeBase|null|undefined} knowledgeBase
                         * @memberof google.cloud.dialogflow.v2beta1.CreateKnowledgeBaseRequest
                         * @instance
                         */
                        CreateKnowledgeBaseRequest.prototype.knowledgeBase = null;
    
                        /**
                         * Creates a new CreateKnowledgeBaseRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.CreateKnowledgeBaseRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ICreateKnowledgeBaseRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.CreateKnowledgeBaseRequest} CreateKnowledgeBaseRequest instance
                         */
                        CreateKnowledgeBaseRequest.create = function create(properties) {
                            return new CreateKnowledgeBaseRequest(properties);
                        };
    
                        /**
                         * Encodes the specified CreateKnowledgeBaseRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.CreateKnowledgeBaseRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.CreateKnowledgeBaseRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ICreateKnowledgeBaseRequest} message CreateKnowledgeBaseRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateKnowledgeBaseRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.knowledgeBase != null && Object.hasOwnProperty.call(message, "knowledgeBase"))
                                $root.google.cloud.dialogflow.v2beta1.KnowledgeBase.encode(message.knowledgeBase, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified CreateKnowledgeBaseRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.CreateKnowledgeBaseRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.CreateKnowledgeBaseRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ICreateKnowledgeBaseRequest} message CreateKnowledgeBaseRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateKnowledgeBaseRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a CreateKnowledgeBaseRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.CreateKnowledgeBaseRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.CreateKnowledgeBaseRequest} CreateKnowledgeBaseRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateKnowledgeBaseRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.CreateKnowledgeBaseRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.knowledgeBase = $root.google.cloud.dialogflow.v2beta1.KnowledgeBase.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a CreateKnowledgeBaseRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.CreateKnowledgeBaseRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.CreateKnowledgeBaseRequest} CreateKnowledgeBaseRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateKnowledgeBaseRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a CreateKnowledgeBaseRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.CreateKnowledgeBaseRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        CreateKnowledgeBaseRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.knowledgeBase != null && message.hasOwnProperty("knowledgeBase")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.KnowledgeBase.verify(message.knowledgeBase);
                                if (error)
                                    return "knowledgeBase." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a CreateKnowledgeBaseRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.CreateKnowledgeBaseRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.CreateKnowledgeBaseRequest} CreateKnowledgeBaseRequest
                         */
                        CreateKnowledgeBaseRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.CreateKnowledgeBaseRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.CreateKnowledgeBaseRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.knowledgeBase != null) {
                                if (typeof object.knowledgeBase !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.CreateKnowledgeBaseRequest.knowledgeBase: object expected");
                                message.knowledgeBase = $root.google.cloud.dialogflow.v2beta1.KnowledgeBase.fromObject(object.knowledgeBase);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a CreateKnowledgeBaseRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.CreateKnowledgeBaseRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.CreateKnowledgeBaseRequest} message CreateKnowledgeBaseRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        CreateKnowledgeBaseRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.knowledgeBase = null;
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.knowledgeBase != null && message.hasOwnProperty("knowledgeBase"))
                                object.knowledgeBase = $root.google.cloud.dialogflow.v2beta1.KnowledgeBase.toObject(message.knowledgeBase, options);
                            return object;
                        };
    
                        /**
                         * Converts this CreateKnowledgeBaseRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.CreateKnowledgeBaseRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        CreateKnowledgeBaseRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for CreateKnowledgeBaseRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.CreateKnowledgeBaseRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        CreateKnowledgeBaseRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.CreateKnowledgeBaseRequest";
                        };
    
                        return CreateKnowledgeBaseRequest;
                    })();
    
                    v2beta1.DeleteKnowledgeBaseRequest = (function() {
    
                        /**
                         * Properties of a DeleteKnowledgeBaseRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IDeleteKnowledgeBaseRequest
                         * @property {string|null} [name] DeleteKnowledgeBaseRequest name
                         * @property {boolean|null} [force] DeleteKnowledgeBaseRequest force
                         */
    
                        /**
                         * Constructs a new DeleteKnowledgeBaseRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a DeleteKnowledgeBaseRequest.
                         * @implements IDeleteKnowledgeBaseRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteKnowledgeBaseRequest=} [properties] Properties to set
                         */
                        function DeleteKnowledgeBaseRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * DeleteKnowledgeBaseRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteKnowledgeBaseRequest
                         * @instance
                         */
                        DeleteKnowledgeBaseRequest.prototype.name = "";
    
                        /**
                         * DeleteKnowledgeBaseRequest force.
                         * @member {boolean} force
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteKnowledgeBaseRequest
                         * @instance
                         */
                        DeleteKnowledgeBaseRequest.prototype.force = false;
    
                        /**
                         * Creates a new DeleteKnowledgeBaseRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteKnowledgeBaseRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteKnowledgeBaseRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.DeleteKnowledgeBaseRequest} DeleteKnowledgeBaseRequest instance
                         */
                        DeleteKnowledgeBaseRequest.create = function create(properties) {
                            return new DeleteKnowledgeBaseRequest(properties);
                        };
    
                        /**
                         * Encodes the specified DeleteKnowledgeBaseRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.DeleteKnowledgeBaseRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteKnowledgeBaseRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteKnowledgeBaseRequest} message DeleteKnowledgeBaseRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteKnowledgeBaseRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            if (message.force != null && Object.hasOwnProperty.call(message, "force"))
                                writer.uint32(/* id 2, wireType 0 =*/16).bool(message.force);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified DeleteKnowledgeBaseRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.DeleteKnowledgeBaseRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteKnowledgeBaseRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteKnowledgeBaseRequest} message DeleteKnowledgeBaseRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteKnowledgeBaseRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a DeleteKnowledgeBaseRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteKnowledgeBaseRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.DeleteKnowledgeBaseRequest} DeleteKnowledgeBaseRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteKnowledgeBaseRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.DeleteKnowledgeBaseRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.force = reader.bool();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a DeleteKnowledgeBaseRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteKnowledgeBaseRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.DeleteKnowledgeBaseRequest} DeleteKnowledgeBaseRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteKnowledgeBaseRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a DeleteKnowledgeBaseRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteKnowledgeBaseRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        DeleteKnowledgeBaseRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            if (message.force != null && message.hasOwnProperty("force"))
                                if (typeof message.force !== "boolean")
                                    return "force: boolean expected";
                            return null;
                        };
    
                        /**
                         * Creates a DeleteKnowledgeBaseRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteKnowledgeBaseRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.DeleteKnowledgeBaseRequest} DeleteKnowledgeBaseRequest
                         */
                        DeleteKnowledgeBaseRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.DeleteKnowledgeBaseRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.DeleteKnowledgeBaseRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            if (object.force != null)
                                message.force = Boolean(object.force);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a DeleteKnowledgeBaseRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteKnowledgeBaseRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.DeleteKnowledgeBaseRequest} message DeleteKnowledgeBaseRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        DeleteKnowledgeBaseRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.name = "";
                                object.force = false;
                            }
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            if (message.force != null && message.hasOwnProperty("force"))
                                object.force = message.force;
                            return object;
                        };
    
                        /**
                         * Converts this DeleteKnowledgeBaseRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteKnowledgeBaseRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        DeleteKnowledgeBaseRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for DeleteKnowledgeBaseRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteKnowledgeBaseRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        DeleteKnowledgeBaseRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.DeleteKnowledgeBaseRequest";
                        };
    
                        return DeleteKnowledgeBaseRequest;
                    })();
    
                    v2beta1.UpdateKnowledgeBaseRequest = (function() {
    
                        /**
                         * Properties of an UpdateKnowledgeBaseRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IUpdateKnowledgeBaseRequest
                         * @property {google.cloud.dialogflow.v2beta1.IKnowledgeBase|null} [knowledgeBase] UpdateKnowledgeBaseRequest knowledgeBase
                         * @property {google.protobuf.IFieldMask|null} [updateMask] UpdateKnowledgeBaseRequest updateMask
                         */
    
                        /**
                         * Constructs a new UpdateKnowledgeBaseRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an UpdateKnowledgeBaseRequest.
                         * @implements IUpdateKnowledgeBaseRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateKnowledgeBaseRequest=} [properties] Properties to set
                         */
                        function UpdateKnowledgeBaseRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * UpdateKnowledgeBaseRequest knowledgeBase.
                         * @member {google.cloud.dialogflow.v2beta1.IKnowledgeBase|null|undefined} knowledgeBase
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateKnowledgeBaseRequest
                         * @instance
                         */
                        UpdateKnowledgeBaseRequest.prototype.knowledgeBase = null;
    
                        /**
                         * UpdateKnowledgeBaseRequest updateMask.
                         * @member {google.protobuf.IFieldMask|null|undefined} updateMask
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateKnowledgeBaseRequest
                         * @instance
                         */
                        UpdateKnowledgeBaseRequest.prototype.updateMask = null;
    
                        /**
                         * Creates a new UpdateKnowledgeBaseRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateKnowledgeBaseRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateKnowledgeBaseRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.UpdateKnowledgeBaseRequest} UpdateKnowledgeBaseRequest instance
                         */
                        UpdateKnowledgeBaseRequest.create = function create(properties) {
                            return new UpdateKnowledgeBaseRequest(properties);
                        };
    
                        /**
                         * Encodes the specified UpdateKnowledgeBaseRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.UpdateKnowledgeBaseRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateKnowledgeBaseRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateKnowledgeBaseRequest} message UpdateKnowledgeBaseRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UpdateKnowledgeBaseRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.knowledgeBase != null && Object.hasOwnProperty.call(message, "knowledgeBase"))
                                $root.google.cloud.dialogflow.v2beta1.KnowledgeBase.encode(message.knowledgeBase, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.updateMask != null && Object.hasOwnProperty.call(message, "updateMask"))
                                $root.google.protobuf.FieldMask.encode(message.updateMask, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified UpdateKnowledgeBaseRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.UpdateKnowledgeBaseRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateKnowledgeBaseRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateKnowledgeBaseRequest} message UpdateKnowledgeBaseRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UpdateKnowledgeBaseRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an UpdateKnowledgeBaseRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateKnowledgeBaseRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.UpdateKnowledgeBaseRequest} UpdateKnowledgeBaseRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UpdateKnowledgeBaseRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.UpdateKnowledgeBaseRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.knowledgeBase = $root.google.cloud.dialogflow.v2beta1.KnowledgeBase.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.updateMask = $root.google.protobuf.FieldMask.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an UpdateKnowledgeBaseRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateKnowledgeBaseRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.UpdateKnowledgeBaseRequest} UpdateKnowledgeBaseRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UpdateKnowledgeBaseRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an UpdateKnowledgeBaseRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateKnowledgeBaseRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        UpdateKnowledgeBaseRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.knowledgeBase != null && message.hasOwnProperty("knowledgeBase")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.KnowledgeBase.verify(message.knowledgeBase);
                                if (error)
                                    return "knowledgeBase." + error;
                            }
                            if (message.updateMask != null && message.hasOwnProperty("updateMask")) {
                                var error = $root.google.protobuf.FieldMask.verify(message.updateMask);
                                if (error)
                                    return "updateMask." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates an UpdateKnowledgeBaseRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateKnowledgeBaseRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.UpdateKnowledgeBaseRequest} UpdateKnowledgeBaseRequest
                         */
                        UpdateKnowledgeBaseRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.UpdateKnowledgeBaseRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.UpdateKnowledgeBaseRequest();
                            if (object.knowledgeBase != null) {
                                if (typeof object.knowledgeBase !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.UpdateKnowledgeBaseRequest.knowledgeBase: object expected");
                                message.knowledgeBase = $root.google.cloud.dialogflow.v2beta1.KnowledgeBase.fromObject(object.knowledgeBase);
                            }
                            if (object.updateMask != null) {
                                if (typeof object.updateMask !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.UpdateKnowledgeBaseRequest.updateMask: object expected");
                                message.updateMask = $root.google.protobuf.FieldMask.fromObject(object.updateMask);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an UpdateKnowledgeBaseRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateKnowledgeBaseRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.UpdateKnowledgeBaseRequest} message UpdateKnowledgeBaseRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        UpdateKnowledgeBaseRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.knowledgeBase = null;
                                object.updateMask = null;
                            }
                            if (message.knowledgeBase != null && message.hasOwnProperty("knowledgeBase"))
                                object.knowledgeBase = $root.google.cloud.dialogflow.v2beta1.KnowledgeBase.toObject(message.knowledgeBase, options);
                            if (message.updateMask != null && message.hasOwnProperty("updateMask"))
                                object.updateMask = $root.google.protobuf.FieldMask.toObject(message.updateMask, options);
                            return object;
                        };
    
                        /**
                         * Converts this UpdateKnowledgeBaseRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateKnowledgeBaseRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        UpdateKnowledgeBaseRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for UpdateKnowledgeBaseRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateKnowledgeBaseRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        UpdateKnowledgeBaseRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.UpdateKnowledgeBaseRequest";
                        };
    
                        return UpdateKnowledgeBaseRequest;
                    })();
    
                    v2beta1.PhoneNumbers = (function() {
    
                        /**
                         * Constructs a new PhoneNumbers service.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a PhoneNumbers
                         * @extends $protobuf.rpc.Service
                         * @constructor
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         */
                        function PhoneNumbers(rpcImpl, requestDelimited, responseDelimited) {
                            $protobuf.rpc.Service.call(this, rpcImpl, requestDelimited, responseDelimited);
                        }
    
                        (PhoneNumbers.prototype = Object.create($protobuf.rpc.Service.prototype)).constructor = PhoneNumbers;
    
                        /**
                         * Creates new PhoneNumbers service using the specified rpc implementation.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.PhoneNumbers
                         * @static
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         * @returns {PhoneNumbers} RPC service. Useful where requests and/or responses are streamed.
                         */
                        PhoneNumbers.create = function create(rpcImpl, requestDelimited, responseDelimited) {
                            return new this(rpcImpl, requestDelimited, responseDelimited);
                        };
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.PhoneNumbers|listPhoneNumbers}.
                         * @memberof google.cloud.dialogflow.v2beta1.PhoneNumbers
                         * @typedef ListPhoneNumbersCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.ListPhoneNumbersResponse} [response] ListPhoneNumbersResponse
                         */
    
                        /**
                         * Calls ListPhoneNumbers.
                         * @function listPhoneNumbers
                         * @memberof google.cloud.dialogflow.v2beta1.PhoneNumbers
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IListPhoneNumbersRequest} request ListPhoneNumbersRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.PhoneNumbers.ListPhoneNumbersCallback} callback Node-style callback called with the error, if any, and ListPhoneNumbersResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(PhoneNumbers.prototype.listPhoneNumbers = function listPhoneNumbers(request, callback) {
                            return this.rpcCall(listPhoneNumbers, $root.google.cloud.dialogflow.v2beta1.ListPhoneNumbersRequest, $root.google.cloud.dialogflow.v2beta1.ListPhoneNumbersResponse, request, callback);
                        }, "name", { value: "ListPhoneNumbers" });
    
                        /**
                         * Calls ListPhoneNumbers.
                         * @function listPhoneNumbers
                         * @memberof google.cloud.dialogflow.v2beta1.PhoneNumbers
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IListPhoneNumbersRequest} request ListPhoneNumbersRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.ListPhoneNumbersResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.PhoneNumbers|updatePhoneNumber}.
                         * @memberof google.cloud.dialogflow.v2beta1.PhoneNumbers
                         * @typedef UpdatePhoneNumberCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.PhoneNumber} [response] PhoneNumber
                         */
    
                        /**
                         * Calls UpdatePhoneNumber.
                         * @function updatePhoneNumber
                         * @memberof google.cloud.dialogflow.v2beta1.PhoneNumbers
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IUpdatePhoneNumberRequest} request UpdatePhoneNumberRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.PhoneNumbers.UpdatePhoneNumberCallback} callback Node-style callback called with the error, if any, and PhoneNumber
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(PhoneNumbers.prototype.updatePhoneNumber = function updatePhoneNumber(request, callback) {
                            return this.rpcCall(updatePhoneNumber, $root.google.cloud.dialogflow.v2beta1.UpdatePhoneNumberRequest, $root.google.cloud.dialogflow.v2beta1.PhoneNumber, request, callback);
                        }, "name", { value: "UpdatePhoneNumber" });
    
                        /**
                         * Calls UpdatePhoneNumber.
                         * @function updatePhoneNumber
                         * @memberof google.cloud.dialogflow.v2beta1.PhoneNumbers
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IUpdatePhoneNumberRequest} request UpdatePhoneNumberRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.PhoneNumber>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.PhoneNumbers|deletePhoneNumber}.
                         * @memberof google.cloud.dialogflow.v2beta1.PhoneNumbers
                         * @typedef DeletePhoneNumberCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.PhoneNumber} [response] PhoneNumber
                         */
    
                        /**
                         * Calls DeletePhoneNumber.
                         * @function deletePhoneNumber
                         * @memberof google.cloud.dialogflow.v2beta1.PhoneNumbers
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IDeletePhoneNumberRequest} request DeletePhoneNumberRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.PhoneNumbers.DeletePhoneNumberCallback} callback Node-style callback called with the error, if any, and PhoneNumber
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(PhoneNumbers.prototype.deletePhoneNumber = function deletePhoneNumber(request, callback) {
                            return this.rpcCall(deletePhoneNumber, $root.google.cloud.dialogflow.v2beta1.DeletePhoneNumberRequest, $root.google.cloud.dialogflow.v2beta1.PhoneNumber, request, callback);
                        }, "name", { value: "DeletePhoneNumber" });
    
                        /**
                         * Calls DeletePhoneNumber.
                         * @function deletePhoneNumber
                         * @memberof google.cloud.dialogflow.v2beta1.PhoneNumbers
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IDeletePhoneNumberRequest} request DeletePhoneNumberRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.PhoneNumber>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.PhoneNumbers|undeletePhoneNumber}.
                         * @memberof google.cloud.dialogflow.v2beta1.PhoneNumbers
                         * @typedef UndeletePhoneNumberCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.PhoneNumber} [response] PhoneNumber
                         */
    
                        /**
                         * Calls UndeletePhoneNumber.
                         * @function undeletePhoneNumber
                         * @memberof google.cloud.dialogflow.v2beta1.PhoneNumbers
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IUndeletePhoneNumberRequest} request UndeletePhoneNumberRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.PhoneNumbers.UndeletePhoneNumberCallback} callback Node-style callback called with the error, if any, and PhoneNumber
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(PhoneNumbers.prototype.undeletePhoneNumber = function undeletePhoneNumber(request, callback) {
                            return this.rpcCall(undeletePhoneNumber, $root.google.cloud.dialogflow.v2beta1.UndeletePhoneNumberRequest, $root.google.cloud.dialogflow.v2beta1.PhoneNumber, request, callback);
                        }, "name", { value: "UndeletePhoneNumber" });
    
                        /**
                         * Calls UndeletePhoneNumber.
                         * @function undeletePhoneNumber
                         * @memberof google.cloud.dialogflow.v2beta1.PhoneNumbers
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IUndeletePhoneNumberRequest} request UndeletePhoneNumberRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.PhoneNumber>} Promise
                         * @variation 2
                         */
    
                        return PhoneNumbers;
                    })();
    
                    v2beta1.PhoneNumber = (function() {
    
                        /**
                         * Properties of a PhoneNumber.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IPhoneNumber
                         * @property {string|null} [name] PhoneNumber name
                         * @property {string|null} [phoneNumber] PhoneNumber phoneNumber
                         * @property {string|null} [conversationProfile] PhoneNumber conversationProfile
                         * @property {google.cloud.dialogflow.v2beta1.PhoneNumber.LifecycleState|null} [lifecycleState] PhoneNumber lifecycleState
                         */
    
                        /**
                         * Constructs a new PhoneNumber.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a PhoneNumber.
                         * @implements IPhoneNumber
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IPhoneNumber=} [properties] Properties to set
                         */
                        function PhoneNumber(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * PhoneNumber name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2beta1.PhoneNumber
                         * @instance
                         */
                        PhoneNumber.prototype.name = "";
    
                        /**
                         * PhoneNumber phoneNumber.
                         * @member {string} phoneNumber
                         * @memberof google.cloud.dialogflow.v2beta1.PhoneNumber
                         * @instance
                         */
                        PhoneNumber.prototype.phoneNumber = "";
    
                        /**
                         * PhoneNumber conversationProfile.
                         * @member {string} conversationProfile
                         * @memberof google.cloud.dialogflow.v2beta1.PhoneNumber
                         * @instance
                         */
                        PhoneNumber.prototype.conversationProfile = "";
    
                        /**
                         * PhoneNumber lifecycleState.
                         * @member {google.cloud.dialogflow.v2beta1.PhoneNumber.LifecycleState} lifecycleState
                         * @memberof google.cloud.dialogflow.v2beta1.PhoneNumber
                         * @instance
                         */
                        PhoneNumber.prototype.lifecycleState = 0;
    
                        /**
                         * Creates a new PhoneNumber instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.PhoneNumber
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IPhoneNumber=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.PhoneNumber} PhoneNumber instance
                         */
                        PhoneNumber.create = function create(properties) {
                            return new PhoneNumber(properties);
                        };
    
                        /**
                         * Encodes the specified PhoneNumber message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.PhoneNumber.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.PhoneNumber
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IPhoneNumber} message PhoneNumber message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        PhoneNumber.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            if (message.phoneNumber != null && Object.hasOwnProperty.call(message, "phoneNumber"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.phoneNumber);
                            if (message.conversationProfile != null && Object.hasOwnProperty.call(message, "conversationProfile"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.conversationProfile);
                            if (message.lifecycleState != null && Object.hasOwnProperty.call(message, "lifecycleState"))
                                writer.uint32(/* id 4, wireType 0 =*/32).int32(message.lifecycleState);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified PhoneNumber message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.PhoneNumber.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.PhoneNumber
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IPhoneNumber} message PhoneNumber message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        PhoneNumber.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a PhoneNumber message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.PhoneNumber
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.PhoneNumber} PhoneNumber
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        PhoneNumber.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.PhoneNumber();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.phoneNumber = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.conversationProfile = reader.string();
                                        break;
                                    }
                                case 4: {
                                        message.lifecycleState = reader.int32();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a PhoneNumber message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.PhoneNumber
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.PhoneNumber} PhoneNumber
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        PhoneNumber.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a PhoneNumber message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.PhoneNumber
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        PhoneNumber.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            if (message.phoneNumber != null && message.hasOwnProperty("phoneNumber"))
                                if (!$util.isString(message.phoneNumber))
                                    return "phoneNumber: string expected";
                            if (message.conversationProfile != null && message.hasOwnProperty("conversationProfile"))
                                if (!$util.isString(message.conversationProfile))
                                    return "conversationProfile: string expected";
                            if (message.lifecycleState != null && message.hasOwnProperty("lifecycleState"))
                                switch (message.lifecycleState) {
                                default:
                                    return "lifecycleState: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                    break;
                                }
                            return null;
                        };
    
                        /**
                         * Creates a PhoneNumber message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.PhoneNumber
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.PhoneNumber} PhoneNumber
                         */
                        PhoneNumber.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.PhoneNumber)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.PhoneNumber();
                            if (object.name != null)
                                message.name = String(object.name);
                            if (object.phoneNumber != null)
                                message.phoneNumber = String(object.phoneNumber);
                            if (object.conversationProfile != null)
                                message.conversationProfile = String(object.conversationProfile);
                            switch (object.lifecycleState) {
                            default:
                                if (typeof object.lifecycleState === "number") {
                                    message.lifecycleState = object.lifecycleState;
                                    break;
                                }
                                break;
                            case "LIFECYCLE_STATE_UNSPECIFIED":
                            case 0:
                                message.lifecycleState = 0;
                                break;
                            case "ACTIVE":
                            case 1:
                                message.lifecycleState = 1;
                                break;
                            case "DELETE_REQUESTED":
                            case 2:
                                message.lifecycleState = 2;
                                break;
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a PhoneNumber message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.PhoneNumber
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.PhoneNumber} message PhoneNumber
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        PhoneNumber.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.name = "";
                                object.phoneNumber = "";
                                object.conversationProfile = "";
                                object.lifecycleState = options.enums === String ? "LIFECYCLE_STATE_UNSPECIFIED" : 0;
                            }
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            if (message.phoneNumber != null && message.hasOwnProperty("phoneNumber"))
                                object.phoneNumber = message.phoneNumber;
                            if (message.conversationProfile != null && message.hasOwnProperty("conversationProfile"))
                                object.conversationProfile = message.conversationProfile;
                            if (message.lifecycleState != null && message.hasOwnProperty("lifecycleState"))
                                object.lifecycleState = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.PhoneNumber.LifecycleState[message.lifecycleState] === undefined ? message.lifecycleState : $root.google.cloud.dialogflow.v2beta1.PhoneNumber.LifecycleState[message.lifecycleState] : message.lifecycleState;
                            return object;
                        };
    
                        /**
                         * Converts this PhoneNumber to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.PhoneNumber
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        PhoneNumber.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for PhoneNumber
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.PhoneNumber
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        PhoneNumber.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.PhoneNumber";
                        };
    
                        /**
                         * LifecycleState enum.
                         * @name google.cloud.dialogflow.v2beta1.PhoneNumber.LifecycleState
                         * @enum {number}
                         * @property {number} LIFECYCLE_STATE_UNSPECIFIED=0 LIFECYCLE_STATE_UNSPECIFIED value
                         * @property {number} ACTIVE=1 ACTIVE value
                         * @property {number} DELETE_REQUESTED=2 DELETE_REQUESTED value
                         */
                        PhoneNumber.LifecycleState = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "LIFECYCLE_STATE_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "ACTIVE"] = 1;
                            values[valuesById[2] = "DELETE_REQUESTED"] = 2;
                            return values;
                        })();
    
                        return PhoneNumber;
                    })();
    
                    v2beta1.DeletePhoneNumberRequest = (function() {
    
                        /**
                         * Properties of a DeletePhoneNumberRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IDeletePhoneNumberRequest
                         * @property {string|null} [name] DeletePhoneNumberRequest name
                         */
    
                        /**
                         * Constructs a new DeletePhoneNumberRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a DeletePhoneNumberRequest.
                         * @implements IDeletePhoneNumberRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IDeletePhoneNumberRequest=} [properties] Properties to set
                         */
                        function DeletePhoneNumberRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * DeletePhoneNumberRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2beta1.DeletePhoneNumberRequest
                         * @instance
                         */
                        DeletePhoneNumberRequest.prototype.name = "";
    
                        /**
                         * Creates a new DeletePhoneNumberRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.DeletePhoneNumberRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDeletePhoneNumberRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.DeletePhoneNumberRequest} DeletePhoneNumberRequest instance
                         */
                        DeletePhoneNumberRequest.create = function create(properties) {
                            return new DeletePhoneNumberRequest(properties);
                        };
    
                        /**
                         * Encodes the specified DeletePhoneNumberRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.DeletePhoneNumberRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.DeletePhoneNumberRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDeletePhoneNumberRequest} message DeletePhoneNumberRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeletePhoneNumberRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified DeletePhoneNumberRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.DeletePhoneNumberRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.DeletePhoneNumberRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDeletePhoneNumberRequest} message DeletePhoneNumberRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeletePhoneNumberRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a DeletePhoneNumberRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.DeletePhoneNumberRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.DeletePhoneNumberRequest} DeletePhoneNumberRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeletePhoneNumberRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.DeletePhoneNumberRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a DeletePhoneNumberRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.DeletePhoneNumberRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.DeletePhoneNumberRequest} DeletePhoneNumberRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeletePhoneNumberRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a DeletePhoneNumberRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.DeletePhoneNumberRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        DeletePhoneNumberRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a DeletePhoneNumberRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.DeletePhoneNumberRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.DeletePhoneNumberRequest} DeletePhoneNumberRequest
                         */
                        DeletePhoneNumberRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.DeletePhoneNumberRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.DeletePhoneNumberRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a DeletePhoneNumberRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.DeletePhoneNumberRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.DeletePhoneNumberRequest} message DeletePhoneNumberRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        DeletePhoneNumberRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.name = "";
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            return object;
                        };
    
                        /**
                         * Converts this DeletePhoneNumberRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.DeletePhoneNumberRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        DeletePhoneNumberRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for DeletePhoneNumberRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.DeletePhoneNumberRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        DeletePhoneNumberRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.DeletePhoneNumberRequest";
                        };
    
                        return DeletePhoneNumberRequest;
                    })();
    
                    v2beta1.UndeletePhoneNumberRequest = (function() {
    
                        /**
                         * Properties of an UndeletePhoneNumberRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IUndeletePhoneNumberRequest
                         * @property {string|null} [name] UndeletePhoneNumberRequest name
                         */
    
                        /**
                         * Constructs a new UndeletePhoneNumberRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an UndeletePhoneNumberRequest.
                         * @implements IUndeletePhoneNumberRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IUndeletePhoneNumberRequest=} [properties] Properties to set
                         */
                        function UndeletePhoneNumberRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * UndeletePhoneNumberRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2beta1.UndeletePhoneNumberRequest
                         * @instance
                         */
                        UndeletePhoneNumberRequest.prototype.name = "";
    
                        /**
                         * Creates a new UndeletePhoneNumberRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.UndeletePhoneNumberRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IUndeletePhoneNumberRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.UndeletePhoneNumberRequest} UndeletePhoneNumberRequest instance
                         */
                        UndeletePhoneNumberRequest.create = function create(properties) {
                            return new UndeletePhoneNumberRequest(properties);
                        };
    
                        /**
                         * Encodes the specified UndeletePhoneNumberRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.UndeletePhoneNumberRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.UndeletePhoneNumberRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IUndeletePhoneNumberRequest} message UndeletePhoneNumberRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UndeletePhoneNumberRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified UndeletePhoneNumberRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.UndeletePhoneNumberRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.UndeletePhoneNumberRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IUndeletePhoneNumberRequest} message UndeletePhoneNumberRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UndeletePhoneNumberRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an UndeletePhoneNumberRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.UndeletePhoneNumberRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.UndeletePhoneNumberRequest} UndeletePhoneNumberRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UndeletePhoneNumberRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.UndeletePhoneNumberRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an UndeletePhoneNumberRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.UndeletePhoneNumberRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.UndeletePhoneNumberRequest} UndeletePhoneNumberRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UndeletePhoneNumberRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an UndeletePhoneNumberRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.UndeletePhoneNumberRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        UndeletePhoneNumberRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            return null;
                        };
    
                        /**
                         * Creates an UndeletePhoneNumberRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.UndeletePhoneNumberRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.UndeletePhoneNumberRequest} UndeletePhoneNumberRequest
                         */
                        UndeletePhoneNumberRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.UndeletePhoneNumberRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.UndeletePhoneNumberRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an UndeletePhoneNumberRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.UndeletePhoneNumberRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.UndeletePhoneNumberRequest} message UndeletePhoneNumberRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        UndeletePhoneNumberRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.name = "";
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            return object;
                        };
    
                        /**
                         * Converts this UndeletePhoneNumberRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.UndeletePhoneNumberRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        UndeletePhoneNumberRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for UndeletePhoneNumberRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.UndeletePhoneNumberRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        UndeletePhoneNumberRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.UndeletePhoneNumberRequest";
                        };
    
                        return UndeletePhoneNumberRequest;
                    })();
    
                    v2beta1.ListPhoneNumbersRequest = (function() {
    
                        /**
                         * Properties of a ListPhoneNumbersRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IListPhoneNumbersRequest
                         * @property {string|null} [parent] ListPhoneNumbersRequest parent
                         * @property {number|null} [pageSize] ListPhoneNumbersRequest pageSize
                         * @property {string|null} [pageToken] ListPhoneNumbersRequest pageToken
                         * @property {boolean|null} [showDeleted] ListPhoneNumbersRequest showDeleted
                         */
    
                        /**
                         * Constructs a new ListPhoneNumbersRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a ListPhoneNumbersRequest.
                         * @implements IListPhoneNumbersRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IListPhoneNumbersRequest=} [properties] Properties to set
                         */
                        function ListPhoneNumbersRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListPhoneNumbersRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.ListPhoneNumbersRequest
                         * @instance
                         */
                        ListPhoneNumbersRequest.prototype.parent = "";
    
                        /**
                         * ListPhoneNumbersRequest pageSize.
                         * @member {number} pageSize
                         * @memberof google.cloud.dialogflow.v2beta1.ListPhoneNumbersRequest
                         * @instance
                         */
                        ListPhoneNumbersRequest.prototype.pageSize = 0;
    
                        /**
                         * ListPhoneNumbersRequest pageToken.
                         * @member {string} pageToken
                         * @memberof google.cloud.dialogflow.v2beta1.ListPhoneNumbersRequest
                         * @instance
                         */
                        ListPhoneNumbersRequest.prototype.pageToken = "";
    
                        /**
                         * ListPhoneNumbersRequest showDeleted.
                         * @member {boolean} showDeleted
                         * @memberof google.cloud.dialogflow.v2beta1.ListPhoneNumbersRequest
                         * @instance
                         */
                        ListPhoneNumbersRequest.prototype.showDeleted = false;
    
                        /**
                         * Creates a new ListPhoneNumbersRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.ListPhoneNumbersRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListPhoneNumbersRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.ListPhoneNumbersRequest} ListPhoneNumbersRequest instance
                         */
                        ListPhoneNumbersRequest.create = function create(properties) {
                            return new ListPhoneNumbersRequest(properties);
                        };
    
                        /**
                         * Encodes the specified ListPhoneNumbersRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListPhoneNumbersRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.ListPhoneNumbersRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListPhoneNumbersRequest} message ListPhoneNumbersRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListPhoneNumbersRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.pageSize != null && Object.hasOwnProperty.call(message, "pageSize"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.pageSize);
                            if (message.pageToken != null && Object.hasOwnProperty.call(message, "pageToken"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.pageToken);
                            if (message.showDeleted != null && Object.hasOwnProperty.call(message, "showDeleted"))
                                writer.uint32(/* id 4, wireType 0 =*/32).bool(message.showDeleted);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListPhoneNumbersRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListPhoneNumbersRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListPhoneNumbersRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListPhoneNumbersRequest} message ListPhoneNumbersRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListPhoneNumbersRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListPhoneNumbersRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.ListPhoneNumbersRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.ListPhoneNumbersRequest} ListPhoneNumbersRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListPhoneNumbersRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ListPhoneNumbersRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.pageSize = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.pageToken = reader.string();
                                        break;
                                    }
                                case 4: {
                                        message.showDeleted = reader.bool();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListPhoneNumbersRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListPhoneNumbersRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.ListPhoneNumbersRequest} ListPhoneNumbersRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListPhoneNumbersRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListPhoneNumbersRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.ListPhoneNumbersRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListPhoneNumbersRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                if (!$util.isInteger(message.pageSize))
                                    return "pageSize: integer expected";
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                if (!$util.isString(message.pageToken))
                                    return "pageToken: string expected";
                            if (message.showDeleted != null && message.hasOwnProperty("showDeleted"))
                                if (typeof message.showDeleted !== "boolean")
                                    return "showDeleted: boolean expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListPhoneNumbersRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListPhoneNumbersRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.ListPhoneNumbersRequest} ListPhoneNumbersRequest
                         */
                        ListPhoneNumbersRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.ListPhoneNumbersRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.ListPhoneNumbersRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.pageSize != null)
                                message.pageSize = object.pageSize | 0;
                            if (object.pageToken != null)
                                message.pageToken = String(object.pageToken);
                            if (object.showDeleted != null)
                                message.showDeleted = Boolean(object.showDeleted);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListPhoneNumbersRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListPhoneNumbersRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ListPhoneNumbersRequest} message ListPhoneNumbersRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListPhoneNumbersRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.pageSize = 0;
                                object.pageToken = "";
                                object.showDeleted = false;
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                object.pageSize = message.pageSize;
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                object.pageToken = message.pageToken;
                            if (message.showDeleted != null && message.hasOwnProperty("showDeleted"))
                                object.showDeleted = message.showDeleted;
                            return object;
                        };
    
                        /**
                         * Converts this ListPhoneNumbersRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.ListPhoneNumbersRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListPhoneNumbersRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListPhoneNumbersRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.ListPhoneNumbersRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListPhoneNumbersRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ListPhoneNumbersRequest";
                        };
    
                        return ListPhoneNumbersRequest;
                    })();
    
                    v2beta1.ListPhoneNumbersResponse = (function() {
    
                        /**
                         * Properties of a ListPhoneNumbersResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IListPhoneNumbersResponse
                         * @property {Array.<google.cloud.dialogflow.v2beta1.IPhoneNumber>|null} [phoneNumbers] ListPhoneNumbersResponse phoneNumbers
                         * @property {string|null} [nextPageToken] ListPhoneNumbersResponse nextPageToken
                         */
    
                        /**
                         * Constructs a new ListPhoneNumbersResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a ListPhoneNumbersResponse.
                         * @implements IListPhoneNumbersResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IListPhoneNumbersResponse=} [properties] Properties to set
                         */
                        function ListPhoneNumbersResponse(properties) {
                            this.phoneNumbers = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListPhoneNumbersResponse phoneNumbers.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.IPhoneNumber>} phoneNumbers
                         * @memberof google.cloud.dialogflow.v2beta1.ListPhoneNumbersResponse
                         * @instance
                         */
                        ListPhoneNumbersResponse.prototype.phoneNumbers = $util.emptyArray;
    
                        /**
                         * ListPhoneNumbersResponse nextPageToken.
                         * @member {string} nextPageToken
                         * @memberof google.cloud.dialogflow.v2beta1.ListPhoneNumbersResponse
                         * @instance
                         */
                        ListPhoneNumbersResponse.prototype.nextPageToken = "";
    
                        /**
                         * Creates a new ListPhoneNumbersResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.ListPhoneNumbersResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListPhoneNumbersResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.ListPhoneNumbersResponse} ListPhoneNumbersResponse instance
                         */
                        ListPhoneNumbersResponse.create = function create(properties) {
                            return new ListPhoneNumbersResponse(properties);
                        };
    
                        /**
                         * Encodes the specified ListPhoneNumbersResponse message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListPhoneNumbersResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.ListPhoneNumbersResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListPhoneNumbersResponse} message ListPhoneNumbersResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListPhoneNumbersResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.phoneNumbers != null && message.phoneNumbers.length)
                                for (var i = 0; i < message.phoneNumbers.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.PhoneNumber.encode(message.phoneNumbers[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.nextPageToken != null && Object.hasOwnProperty.call(message, "nextPageToken"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.nextPageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListPhoneNumbersResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListPhoneNumbersResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListPhoneNumbersResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListPhoneNumbersResponse} message ListPhoneNumbersResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListPhoneNumbersResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListPhoneNumbersResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.ListPhoneNumbersResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.ListPhoneNumbersResponse} ListPhoneNumbersResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListPhoneNumbersResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ListPhoneNumbersResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.phoneNumbers && message.phoneNumbers.length))
                                            message.phoneNumbers = [];
                                        message.phoneNumbers.push($root.google.cloud.dialogflow.v2beta1.PhoneNumber.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 2: {
                                        message.nextPageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListPhoneNumbersResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListPhoneNumbersResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.ListPhoneNumbersResponse} ListPhoneNumbersResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListPhoneNumbersResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListPhoneNumbersResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.ListPhoneNumbersResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListPhoneNumbersResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.phoneNumbers != null && message.hasOwnProperty("phoneNumbers")) {
                                if (!Array.isArray(message.phoneNumbers))
                                    return "phoneNumbers: array expected";
                                for (var i = 0; i < message.phoneNumbers.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.PhoneNumber.verify(message.phoneNumbers[i]);
                                    if (error)
                                        return "phoneNumbers." + error;
                                }
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                if (!$util.isString(message.nextPageToken))
                                    return "nextPageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListPhoneNumbersResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListPhoneNumbersResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.ListPhoneNumbersResponse} ListPhoneNumbersResponse
                         */
                        ListPhoneNumbersResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.ListPhoneNumbersResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.ListPhoneNumbersResponse();
                            if (object.phoneNumbers) {
                                if (!Array.isArray(object.phoneNumbers))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.ListPhoneNumbersResponse.phoneNumbers: array expected");
                                message.phoneNumbers = [];
                                for (var i = 0; i < object.phoneNumbers.length; ++i) {
                                    if (typeof object.phoneNumbers[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.ListPhoneNumbersResponse.phoneNumbers: object expected");
                                    message.phoneNumbers[i] = $root.google.cloud.dialogflow.v2beta1.PhoneNumber.fromObject(object.phoneNumbers[i]);
                                }
                            }
                            if (object.nextPageToken != null)
                                message.nextPageToken = String(object.nextPageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListPhoneNumbersResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListPhoneNumbersResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ListPhoneNumbersResponse} message ListPhoneNumbersResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListPhoneNumbersResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.phoneNumbers = [];
                            if (options.defaults)
                                object.nextPageToken = "";
                            if (message.phoneNumbers && message.phoneNumbers.length) {
                                object.phoneNumbers = [];
                                for (var j = 0; j < message.phoneNumbers.length; ++j)
                                    object.phoneNumbers[j] = $root.google.cloud.dialogflow.v2beta1.PhoneNumber.toObject(message.phoneNumbers[j], options);
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                object.nextPageToken = message.nextPageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListPhoneNumbersResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.ListPhoneNumbersResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListPhoneNumbersResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListPhoneNumbersResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.ListPhoneNumbersResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListPhoneNumbersResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ListPhoneNumbersResponse";
                        };
    
                        return ListPhoneNumbersResponse;
                    })();
    
                    v2beta1.UpdatePhoneNumberRequest = (function() {
    
                        /**
                         * Properties of an UpdatePhoneNumberRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IUpdatePhoneNumberRequest
                         * @property {google.cloud.dialogflow.v2beta1.IPhoneNumber|null} [phoneNumber] UpdatePhoneNumberRequest phoneNumber
                         * @property {google.protobuf.IFieldMask|null} [updateMask] UpdatePhoneNumberRequest updateMask
                         */
    
                        /**
                         * Constructs a new UpdatePhoneNumberRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an UpdatePhoneNumberRequest.
                         * @implements IUpdatePhoneNumberRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IUpdatePhoneNumberRequest=} [properties] Properties to set
                         */
                        function UpdatePhoneNumberRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * UpdatePhoneNumberRequest phoneNumber.
                         * @member {google.cloud.dialogflow.v2beta1.IPhoneNumber|null|undefined} phoneNumber
                         * @memberof google.cloud.dialogflow.v2beta1.UpdatePhoneNumberRequest
                         * @instance
                         */
                        UpdatePhoneNumberRequest.prototype.phoneNumber = null;
    
                        /**
                         * UpdatePhoneNumberRequest updateMask.
                         * @member {google.protobuf.IFieldMask|null|undefined} updateMask
                         * @memberof google.cloud.dialogflow.v2beta1.UpdatePhoneNumberRequest
                         * @instance
                         */
                        UpdatePhoneNumberRequest.prototype.updateMask = null;
    
                        /**
                         * Creates a new UpdatePhoneNumberRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.UpdatePhoneNumberRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IUpdatePhoneNumberRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.UpdatePhoneNumberRequest} UpdatePhoneNumberRequest instance
                         */
                        UpdatePhoneNumberRequest.create = function create(properties) {
                            return new UpdatePhoneNumberRequest(properties);
                        };
    
                        /**
                         * Encodes the specified UpdatePhoneNumberRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.UpdatePhoneNumberRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.UpdatePhoneNumberRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IUpdatePhoneNumberRequest} message UpdatePhoneNumberRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UpdatePhoneNumberRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.phoneNumber != null && Object.hasOwnProperty.call(message, "phoneNumber"))
                                $root.google.cloud.dialogflow.v2beta1.PhoneNumber.encode(message.phoneNumber, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.updateMask != null && Object.hasOwnProperty.call(message, "updateMask"))
                                $root.google.protobuf.FieldMask.encode(message.updateMask, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified UpdatePhoneNumberRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.UpdatePhoneNumberRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.UpdatePhoneNumberRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IUpdatePhoneNumberRequest} message UpdatePhoneNumberRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UpdatePhoneNumberRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an UpdatePhoneNumberRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.UpdatePhoneNumberRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.UpdatePhoneNumberRequest} UpdatePhoneNumberRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UpdatePhoneNumberRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.UpdatePhoneNumberRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.phoneNumber = $root.google.cloud.dialogflow.v2beta1.PhoneNumber.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.updateMask = $root.google.protobuf.FieldMask.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an UpdatePhoneNumberRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.UpdatePhoneNumberRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.UpdatePhoneNumberRequest} UpdatePhoneNumberRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UpdatePhoneNumberRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an UpdatePhoneNumberRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.UpdatePhoneNumberRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        UpdatePhoneNumberRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.phoneNumber != null && message.hasOwnProperty("phoneNumber")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.PhoneNumber.verify(message.phoneNumber);
                                if (error)
                                    return "phoneNumber." + error;
                            }
                            if (message.updateMask != null && message.hasOwnProperty("updateMask")) {
                                var error = $root.google.protobuf.FieldMask.verify(message.updateMask);
                                if (error)
                                    return "updateMask." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates an UpdatePhoneNumberRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.UpdatePhoneNumberRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.UpdatePhoneNumberRequest} UpdatePhoneNumberRequest
                         */
                        UpdatePhoneNumberRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.UpdatePhoneNumberRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.UpdatePhoneNumberRequest();
                            if (object.phoneNumber != null) {
                                if (typeof object.phoneNumber !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.UpdatePhoneNumberRequest.phoneNumber: object expected");
                                message.phoneNumber = $root.google.cloud.dialogflow.v2beta1.PhoneNumber.fromObject(object.phoneNumber);
                            }
                            if (object.updateMask != null) {
                                if (typeof object.updateMask !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.UpdatePhoneNumberRequest.updateMask: object expected");
                                message.updateMask = $root.google.protobuf.FieldMask.fromObject(object.updateMask);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an UpdatePhoneNumberRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.UpdatePhoneNumberRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.UpdatePhoneNumberRequest} message UpdatePhoneNumberRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        UpdatePhoneNumberRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.phoneNumber = null;
                                object.updateMask = null;
                            }
                            if (message.phoneNumber != null && message.hasOwnProperty("phoneNumber"))
                                object.phoneNumber = $root.google.cloud.dialogflow.v2beta1.PhoneNumber.toObject(message.phoneNumber, options);
                            if (message.updateMask != null && message.hasOwnProperty("updateMask"))
                                object.updateMask = $root.google.protobuf.FieldMask.toObject(message.updateMask, options);
                            return object;
                        };
    
                        /**
                         * Converts this UpdatePhoneNumberRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.UpdatePhoneNumberRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        UpdatePhoneNumberRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for UpdatePhoneNumberRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.UpdatePhoneNumberRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        UpdatePhoneNumberRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.UpdatePhoneNumberRequest";
                        };
    
                        return UpdatePhoneNumberRequest;
                    })();
    
                    v2beta1.SipTrunks = (function() {
    
                        /**
                         * Constructs a new SipTrunks service.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a SipTrunks
                         * @extends $protobuf.rpc.Service
                         * @constructor
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         */
                        function SipTrunks(rpcImpl, requestDelimited, responseDelimited) {
                            $protobuf.rpc.Service.call(this, rpcImpl, requestDelimited, responseDelimited);
                        }
    
                        (SipTrunks.prototype = Object.create($protobuf.rpc.Service.prototype)).constructor = SipTrunks;
    
                        /**
                         * Creates new SipTrunks service using the specified rpc implementation.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.SipTrunks
                         * @static
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         * @returns {SipTrunks} RPC service. Useful where requests and/or responses are streamed.
                         */
                        SipTrunks.create = function create(rpcImpl, requestDelimited, responseDelimited) {
                            return new this(rpcImpl, requestDelimited, responseDelimited);
                        };
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.SipTrunks|createSipTrunk}.
                         * @memberof google.cloud.dialogflow.v2beta1.SipTrunks
                         * @typedef CreateSipTrunkCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.SipTrunk} [response] SipTrunk
                         */
    
                        /**
                         * Calls CreateSipTrunk.
                         * @function createSipTrunk
                         * @memberof google.cloud.dialogflow.v2beta1.SipTrunks
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.ICreateSipTrunkRequest} request CreateSipTrunkRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.SipTrunks.CreateSipTrunkCallback} callback Node-style callback called with the error, if any, and SipTrunk
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(SipTrunks.prototype.createSipTrunk = function createSipTrunk(request, callback) {
                            return this.rpcCall(createSipTrunk, $root.google.cloud.dialogflow.v2beta1.CreateSipTrunkRequest, $root.google.cloud.dialogflow.v2beta1.SipTrunk, request, callback);
                        }, "name", { value: "CreateSipTrunk" });
    
                        /**
                         * Calls CreateSipTrunk.
                         * @function createSipTrunk
                         * @memberof google.cloud.dialogflow.v2beta1.SipTrunks
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.ICreateSipTrunkRequest} request CreateSipTrunkRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.SipTrunk>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.SipTrunks|deleteSipTrunk}.
                         * @memberof google.cloud.dialogflow.v2beta1.SipTrunks
                         * @typedef DeleteSipTrunkCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.protobuf.Empty} [response] Empty
                         */
    
                        /**
                         * Calls DeleteSipTrunk.
                         * @function deleteSipTrunk
                         * @memberof google.cloud.dialogflow.v2beta1.SipTrunks
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteSipTrunkRequest} request DeleteSipTrunkRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.SipTrunks.DeleteSipTrunkCallback} callback Node-style callback called with the error, if any, and Empty
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(SipTrunks.prototype.deleteSipTrunk = function deleteSipTrunk(request, callback) {
                            return this.rpcCall(deleteSipTrunk, $root.google.cloud.dialogflow.v2beta1.DeleteSipTrunkRequest, $root.google.protobuf.Empty, request, callback);
                        }, "name", { value: "DeleteSipTrunk" });
    
                        /**
                         * Calls DeleteSipTrunk.
                         * @function deleteSipTrunk
                         * @memberof google.cloud.dialogflow.v2beta1.SipTrunks
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteSipTrunkRequest} request DeleteSipTrunkRequest message or plain object
                         * @returns {Promise<google.protobuf.Empty>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.SipTrunks|listSipTrunks}.
                         * @memberof google.cloud.dialogflow.v2beta1.SipTrunks
                         * @typedef ListSipTrunksCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.ListSipTrunksResponse} [response] ListSipTrunksResponse
                         */
    
                        /**
                         * Calls ListSipTrunks.
                         * @function listSipTrunks
                         * @memberof google.cloud.dialogflow.v2beta1.SipTrunks
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IListSipTrunksRequest} request ListSipTrunksRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.SipTrunks.ListSipTrunksCallback} callback Node-style callback called with the error, if any, and ListSipTrunksResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(SipTrunks.prototype.listSipTrunks = function listSipTrunks(request, callback) {
                            return this.rpcCall(listSipTrunks, $root.google.cloud.dialogflow.v2beta1.ListSipTrunksRequest, $root.google.cloud.dialogflow.v2beta1.ListSipTrunksResponse, request, callback);
                        }, "name", { value: "ListSipTrunks" });
    
                        /**
                         * Calls ListSipTrunks.
                         * @function listSipTrunks
                         * @memberof google.cloud.dialogflow.v2beta1.SipTrunks
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IListSipTrunksRequest} request ListSipTrunksRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.ListSipTrunksResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.SipTrunks|getSipTrunk}.
                         * @memberof google.cloud.dialogflow.v2beta1.SipTrunks
                         * @typedef GetSipTrunkCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.SipTrunk} [response] SipTrunk
                         */
    
                        /**
                         * Calls GetSipTrunk.
                         * @function getSipTrunk
                         * @memberof google.cloud.dialogflow.v2beta1.SipTrunks
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IGetSipTrunkRequest} request GetSipTrunkRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.SipTrunks.GetSipTrunkCallback} callback Node-style callback called with the error, if any, and SipTrunk
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(SipTrunks.prototype.getSipTrunk = function getSipTrunk(request, callback) {
                            return this.rpcCall(getSipTrunk, $root.google.cloud.dialogflow.v2beta1.GetSipTrunkRequest, $root.google.cloud.dialogflow.v2beta1.SipTrunk, request, callback);
                        }, "name", { value: "GetSipTrunk" });
    
                        /**
                         * Calls GetSipTrunk.
                         * @function getSipTrunk
                         * @memberof google.cloud.dialogflow.v2beta1.SipTrunks
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IGetSipTrunkRequest} request GetSipTrunkRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.SipTrunk>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.SipTrunks|updateSipTrunk}.
                         * @memberof google.cloud.dialogflow.v2beta1.SipTrunks
                         * @typedef UpdateSipTrunkCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.SipTrunk} [response] SipTrunk
                         */
    
                        /**
                         * Calls UpdateSipTrunk.
                         * @function updateSipTrunk
                         * @memberof google.cloud.dialogflow.v2beta1.SipTrunks
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateSipTrunkRequest} request UpdateSipTrunkRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.SipTrunks.UpdateSipTrunkCallback} callback Node-style callback called with the error, if any, and SipTrunk
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(SipTrunks.prototype.updateSipTrunk = function updateSipTrunk(request, callback) {
                            return this.rpcCall(updateSipTrunk, $root.google.cloud.dialogflow.v2beta1.UpdateSipTrunkRequest, $root.google.cloud.dialogflow.v2beta1.SipTrunk, request, callback);
                        }, "name", { value: "UpdateSipTrunk" });
    
                        /**
                         * Calls UpdateSipTrunk.
                         * @function updateSipTrunk
                         * @memberof google.cloud.dialogflow.v2beta1.SipTrunks
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateSipTrunkRequest} request UpdateSipTrunkRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.SipTrunk>} Promise
                         * @variation 2
                         */
    
                        return SipTrunks;
                    })();
    
                    v2beta1.CreateSipTrunkRequest = (function() {
    
                        /**
                         * Properties of a CreateSipTrunkRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ICreateSipTrunkRequest
                         * @property {string|null} [parent] CreateSipTrunkRequest parent
                         * @property {google.cloud.dialogflow.v2beta1.ISipTrunk|null} [sipTrunk] CreateSipTrunkRequest sipTrunk
                         */
    
                        /**
                         * Constructs a new CreateSipTrunkRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a CreateSipTrunkRequest.
                         * @implements ICreateSipTrunkRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ICreateSipTrunkRequest=} [properties] Properties to set
                         */
                        function CreateSipTrunkRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * CreateSipTrunkRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.CreateSipTrunkRequest
                         * @instance
                         */
                        CreateSipTrunkRequest.prototype.parent = "";
    
                        /**
                         * CreateSipTrunkRequest sipTrunk.
                         * @member {google.cloud.dialogflow.v2beta1.ISipTrunk|null|undefined} sipTrunk
                         * @memberof google.cloud.dialogflow.v2beta1.CreateSipTrunkRequest
                         * @instance
                         */
                        CreateSipTrunkRequest.prototype.sipTrunk = null;
    
                        /**
                         * Creates a new CreateSipTrunkRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.CreateSipTrunkRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ICreateSipTrunkRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.CreateSipTrunkRequest} CreateSipTrunkRequest instance
                         */
                        CreateSipTrunkRequest.create = function create(properties) {
                            return new CreateSipTrunkRequest(properties);
                        };
    
                        /**
                         * Encodes the specified CreateSipTrunkRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.CreateSipTrunkRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.CreateSipTrunkRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ICreateSipTrunkRequest} message CreateSipTrunkRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateSipTrunkRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.sipTrunk != null && Object.hasOwnProperty.call(message, "sipTrunk"))
                                $root.google.cloud.dialogflow.v2beta1.SipTrunk.encode(message.sipTrunk, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified CreateSipTrunkRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.CreateSipTrunkRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.CreateSipTrunkRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ICreateSipTrunkRequest} message CreateSipTrunkRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateSipTrunkRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a CreateSipTrunkRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.CreateSipTrunkRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.CreateSipTrunkRequest} CreateSipTrunkRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateSipTrunkRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.CreateSipTrunkRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.sipTrunk = $root.google.cloud.dialogflow.v2beta1.SipTrunk.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a CreateSipTrunkRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.CreateSipTrunkRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.CreateSipTrunkRequest} CreateSipTrunkRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateSipTrunkRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a CreateSipTrunkRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.CreateSipTrunkRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        CreateSipTrunkRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.sipTrunk != null && message.hasOwnProperty("sipTrunk")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.SipTrunk.verify(message.sipTrunk);
                                if (error)
                                    return "sipTrunk." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a CreateSipTrunkRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.CreateSipTrunkRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.CreateSipTrunkRequest} CreateSipTrunkRequest
                         */
                        CreateSipTrunkRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.CreateSipTrunkRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.CreateSipTrunkRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.sipTrunk != null) {
                                if (typeof object.sipTrunk !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.CreateSipTrunkRequest.sipTrunk: object expected");
                                message.sipTrunk = $root.google.cloud.dialogflow.v2beta1.SipTrunk.fromObject(object.sipTrunk);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a CreateSipTrunkRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.CreateSipTrunkRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.CreateSipTrunkRequest} message CreateSipTrunkRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        CreateSipTrunkRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.sipTrunk = null;
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.sipTrunk != null && message.hasOwnProperty("sipTrunk"))
                                object.sipTrunk = $root.google.cloud.dialogflow.v2beta1.SipTrunk.toObject(message.sipTrunk, options);
                            return object;
                        };
    
                        /**
                         * Converts this CreateSipTrunkRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.CreateSipTrunkRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        CreateSipTrunkRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for CreateSipTrunkRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.CreateSipTrunkRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        CreateSipTrunkRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.CreateSipTrunkRequest";
                        };
    
                        return CreateSipTrunkRequest;
                    })();
    
                    v2beta1.DeleteSipTrunkRequest = (function() {
    
                        /**
                         * Properties of a DeleteSipTrunkRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IDeleteSipTrunkRequest
                         * @property {string|null} [name] DeleteSipTrunkRequest name
                         */
    
                        /**
                         * Constructs a new DeleteSipTrunkRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a DeleteSipTrunkRequest.
                         * @implements IDeleteSipTrunkRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteSipTrunkRequest=} [properties] Properties to set
                         */
                        function DeleteSipTrunkRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * DeleteSipTrunkRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteSipTrunkRequest
                         * @instance
                         */
                        DeleteSipTrunkRequest.prototype.name = "";
    
                        /**
                         * Creates a new DeleteSipTrunkRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteSipTrunkRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteSipTrunkRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.DeleteSipTrunkRequest} DeleteSipTrunkRequest instance
                         */
                        DeleteSipTrunkRequest.create = function create(properties) {
                            return new DeleteSipTrunkRequest(properties);
                        };
    
                        /**
                         * Encodes the specified DeleteSipTrunkRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.DeleteSipTrunkRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteSipTrunkRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteSipTrunkRequest} message DeleteSipTrunkRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteSipTrunkRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified DeleteSipTrunkRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.DeleteSipTrunkRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteSipTrunkRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteSipTrunkRequest} message DeleteSipTrunkRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteSipTrunkRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a DeleteSipTrunkRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteSipTrunkRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.DeleteSipTrunkRequest} DeleteSipTrunkRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteSipTrunkRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.DeleteSipTrunkRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a DeleteSipTrunkRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteSipTrunkRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.DeleteSipTrunkRequest} DeleteSipTrunkRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteSipTrunkRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a DeleteSipTrunkRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteSipTrunkRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        DeleteSipTrunkRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a DeleteSipTrunkRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteSipTrunkRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.DeleteSipTrunkRequest} DeleteSipTrunkRequest
                         */
                        DeleteSipTrunkRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.DeleteSipTrunkRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.DeleteSipTrunkRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a DeleteSipTrunkRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteSipTrunkRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.DeleteSipTrunkRequest} message DeleteSipTrunkRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        DeleteSipTrunkRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.name = "";
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            return object;
                        };
    
                        /**
                         * Converts this DeleteSipTrunkRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteSipTrunkRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        DeleteSipTrunkRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for DeleteSipTrunkRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteSipTrunkRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        DeleteSipTrunkRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.DeleteSipTrunkRequest";
                        };
    
                        return DeleteSipTrunkRequest;
                    })();
    
                    v2beta1.ListSipTrunksRequest = (function() {
    
                        /**
                         * Properties of a ListSipTrunksRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IListSipTrunksRequest
                         * @property {string|null} [parent] ListSipTrunksRequest parent
                         * @property {number|null} [pageSize] ListSipTrunksRequest pageSize
                         * @property {string|null} [pageToken] ListSipTrunksRequest pageToken
                         */
    
                        /**
                         * Constructs a new ListSipTrunksRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a ListSipTrunksRequest.
                         * @implements IListSipTrunksRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IListSipTrunksRequest=} [properties] Properties to set
                         */
                        function ListSipTrunksRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListSipTrunksRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.ListSipTrunksRequest
                         * @instance
                         */
                        ListSipTrunksRequest.prototype.parent = "";
    
                        /**
                         * ListSipTrunksRequest pageSize.
                         * @member {number} pageSize
                         * @memberof google.cloud.dialogflow.v2beta1.ListSipTrunksRequest
                         * @instance
                         */
                        ListSipTrunksRequest.prototype.pageSize = 0;
    
                        /**
                         * ListSipTrunksRequest pageToken.
                         * @member {string} pageToken
                         * @memberof google.cloud.dialogflow.v2beta1.ListSipTrunksRequest
                         * @instance
                         */
                        ListSipTrunksRequest.prototype.pageToken = "";
    
                        /**
                         * Creates a new ListSipTrunksRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.ListSipTrunksRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListSipTrunksRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.ListSipTrunksRequest} ListSipTrunksRequest instance
                         */
                        ListSipTrunksRequest.create = function create(properties) {
                            return new ListSipTrunksRequest(properties);
                        };
    
                        /**
                         * Encodes the specified ListSipTrunksRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListSipTrunksRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.ListSipTrunksRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListSipTrunksRequest} message ListSipTrunksRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListSipTrunksRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.pageSize != null && Object.hasOwnProperty.call(message, "pageSize"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.pageSize);
                            if (message.pageToken != null && Object.hasOwnProperty.call(message, "pageToken"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.pageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListSipTrunksRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListSipTrunksRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListSipTrunksRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListSipTrunksRequest} message ListSipTrunksRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListSipTrunksRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListSipTrunksRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.ListSipTrunksRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.ListSipTrunksRequest} ListSipTrunksRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListSipTrunksRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ListSipTrunksRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.pageSize = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.pageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListSipTrunksRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListSipTrunksRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.ListSipTrunksRequest} ListSipTrunksRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListSipTrunksRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListSipTrunksRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.ListSipTrunksRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListSipTrunksRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                if (!$util.isInteger(message.pageSize))
                                    return "pageSize: integer expected";
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                if (!$util.isString(message.pageToken))
                                    return "pageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListSipTrunksRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListSipTrunksRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.ListSipTrunksRequest} ListSipTrunksRequest
                         */
                        ListSipTrunksRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.ListSipTrunksRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.ListSipTrunksRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.pageSize != null)
                                message.pageSize = object.pageSize | 0;
                            if (object.pageToken != null)
                                message.pageToken = String(object.pageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListSipTrunksRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListSipTrunksRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ListSipTrunksRequest} message ListSipTrunksRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListSipTrunksRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.pageSize = 0;
                                object.pageToken = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                object.pageSize = message.pageSize;
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                object.pageToken = message.pageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListSipTrunksRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.ListSipTrunksRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListSipTrunksRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListSipTrunksRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.ListSipTrunksRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListSipTrunksRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ListSipTrunksRequest";
                        };
    
                        return ListSipTrunksRequest;
                    })();
    
                    v2beta1.ListSipTrunksResponse = (function() {
    
                        /**
                         * Properties of a ListSipTrunksResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IListSipTrunksResponse
                         * @property {Array.<google.cloud.dialogflow.v2beta1.ISipTrunk>|null} [sipTrunks] ListSipTrunksResponse sipTrunks
                         * @property {string|null} [nextPageToken] ListSipTrunksResponse nextPageToken
                         */
    
                        /**
                         * Constructs a new ListSipTrunksResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a ListSipTrunksResponse.
                         * @implements IListSipTrunksResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IListSipTrunksResponse=} [properties] Properties to set
                         */
                        function ListSipTrunksResponse(properties) {
                            this.sipTrunks = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListSipTrunksResponse sipTrunks.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.ISipTrunk>} sipTrunks
                         * @memberof google.cloud.dialogflow.v2beta1.ListSipTrunksResponse
                         * @instance
                         */
                        ListSipTrunksResponse.prototype.sipTrunks = $util.emptyArray;
    
                        /**
                         * ListSipTrunksResponse nextPageToken.
                         * @member {string} nextPageToken
                         * @memberof google.cloud.dialogflow.v2beta1.ListSipTrunksResponse
                         * @instance
                         */
                        ListSipTrunksResponse.prototype.nextPageToken = "";
    
                        /**
                         * Creates a new ListSipTrunksResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.ListSipTrunksResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListSipTrunksResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.ListSipTrunksResponse} ListSipTrunksResponse instance
                         */
                        ListSipTrunksResponse.create = function create(properties) {
                            return new ListSipTrunksResponse(properties);
                        };
    
                        /**
                         * Encodes the specified ListSipTrunksResponse message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListSipTrunksResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.ListSipTrunksResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListSipTrunksResponse} message ListSipTrunksResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListSipTrunksResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.sipTrunks != null && message.sipTrunks.length)
                                for (var i = 0; i < message.sipTrunks.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.SipTrunk.encode(message.sipTrunks[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.nextPageToken != null && Object.hasOwnProperty.call(message, "nextPageToken"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.nextPageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListSipTrunksResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListSipTrunksResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListSipTrunksResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListSipTrunksResponse} message ListSipTrunksResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListSipTrunksResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListSipTrunksResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.ListSipTrunksResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.ListSipTrunksResponse} ListSipTrunksResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListSipTrunksResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ListSipTrunksResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.sipTrunks && message.sipTrunks.length))
                                            message.sipTrunks = [];
                                        message.sipTrunks.push($root.google.cloud.dialogflow.v2beta1.SipTrunk.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 2: {
                                        message.nextPageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListSipTrunksResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListSipTrunksResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.ListSipTrunksResponse} ListSipTrunksResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListSipTrunksResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListSipTrunksResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.ListSipTrunksResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListSipTrunksResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.sipTrunks != null && message.hasOwnProperty("sipTrunks")) {
                                if (!Array.isArray(message.sipTrunks))
                                    return "sipTrunks: array expected";
                                for (var i = 0; i < message.sipTrunks.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.SipTrunk.verify(message.sipTrunks[i]);
                                    if (error)
                                        return "sipTrunks." + error;
                                }
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                if (!$util.isString(message.nextPageToken))
                                    return "nextPageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListSipTrunksResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListSipTrunksResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.ListSipTrunksResponse} ListSipTrunksResponse
                         */
                        ListSipTrunksResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.ListSipTrunksResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.ListSipTrunksResponse();
                            if (object.sipTrunks) {
                                if (!Array.isArray(object.sipTrunks))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.ListSipTrunksResponse.sipTrunks: array expected");
                                message.sipTrunks = [];
                                for (var i = 0; i < object.sipTrunks.length; ++i) {
                                    if (typeof object.sipTrunks[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.ListSipTrunksResponse.sipTrunks: object expected");
                                    message.sipTrunks[i] = $root.google.cloud.dialogflow.v2beta1.SipTrunk.fromObject(object.sipTrunks[i]);
                                }
                            }
                            if (object.nextPageToken != null)
                                message.nextPageToken = String(object.nextPageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListSipTrunksResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListSipTrunksResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ListSipTrunksResponse} message ListSipTrunksResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListSipTrunksResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.sipTrunks = [];
                            if (options.defaults)
                                object.nextPageToken = "";
                            if (message.sipTrunks && message.sipTrunks.length) {
                                object.sipTrunks = [];
                                for (var j = 0; j < message.sipTrunks.length; ++j)
                                    object.sipTrunks[j] = $root.google.cloud.dialogflow.v2beta1.SipTrunk.toObject(message.sipTrunks[j], options);
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                object.nextPageToken = message.nextPageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListSipTrunksResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.ListSipTrunksResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListSipTrunksResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListSipTrunksResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.ListSipTrunksResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListSipTrunksResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ListSipTrunksResponse";
                        };
    
                        return ListSipTrunksResponse;
                    })();
    
                    v2beta1.GetSipTrunkRequest = (function() {
    
                        /**
                         * Properties of a GetSipTrunkRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IGetSipTrunkRequest
                         * @property {string|null} [name] GetSipTrunkRequest name
                         */
    
                        /**
                         * Constructs a new GetSipTrunkRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a GetSipTrunkRequest.
                         * @implements IGetSipTrunkRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IGetSipTrunkRequest=} [properties] Properties to set
                         */
                        function GetSipTrunkRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GetSipTrunkRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2beta1.GetSipTrunkRequest
                         * @instance
                         */
                        GetSipTrunkRequest.prototype.name = "";
    
                        /**
                         * Creates a new GetSipTrunkRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.GetSipTrunkRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetSipTrunkRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.GetSipTrunkRequest} GetSipTrunkRequest instance
                         */
                        GetSipTrunkRequest.create = function create(properties) {
                            return new GetSipTrunkRequest(properties);
                        };
    
                        /**
                         * Encodes the specified GetSipTrunkRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GetSipTrunkRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.GetSipTrunkRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetSipTrunkRequest} message GetSipTrunkRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetSipTrunkRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GetSipTrunkRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GetSipTrunkRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GetSipTrunkRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetSipTrunkRequest} message GetSipTrunkRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetSipTrunkRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GetSipTrunkRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.GetSipTrunkRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.GetSipTrunkRequest} GetSipTrunkRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetSipTrunkRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.GetSipTrunkRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GetSipTrunkRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GetSipTrunkRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.GetSipTrunkRequest} GetSipTrunkRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetSipTrunkRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GetSipTrunkRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.GetSipTrunkRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GetSipTrunkRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a GetSipTrunkRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.GetSipTrunkRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.GetSipTrunkRequest} GetSipTrunkRequest
                         */
                        GetSipTrunkRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.GetSipTrunkRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.GetSipTrunkRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GetSipTrunkRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.GetSipTrunkRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.GetSipTrunkRequest} message GetSipTrunkRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GetSipTrunkRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.name = "";
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            return object;
                        };
    
                        /**
                         * Converts this GetSipTrunkRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.GetSipTrunkRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GetSipTrunkRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GetSipTrunkRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.GetSipTrunkRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GetSipTrunkRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.GetSipTrunkRequest";
                        };
    
                        return GetSipTrunkRequest;
                    })();
    
                    v2beta1.UpdateSipTrunkRequest = (function() {
    
                        /**
                         * Properties of an UpdateSipTrunkRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IUpdateSipTrunkRequest
                         * @property {google.cloud.dialogflow.v2beta1.ISipTrunk|null} [sipTrunk] UpdateSipTrunkRequest sipTrunk
                         * @property {google.protobuf.IFieldMask|null} [updateMask] UpdateSipTrunkRequest updateMask
                         */
    
                        /**
                         * Constructs a new UpdateSipTrunkRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an UpdateSipTrunkRequest.
                         * @implements IUpdateSipTrunkRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateSipTrunkRequest=} [properties] Properties to set
                         */
                        function UpdateSipTrunkRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * UpdateSipTrunkRequest sipTrunk.
                         * @member {google.cloud.dialogflow.v2beta1.ISipTrunk|null|undefined} sipTrunk
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateSipTrunkRequest
                         * @instance
                         */
                        UpdateSipTrunkRequest.prototype.sipTrunk = null;
    
                        /**
                         * UpdateSipTrunkRequest updateMask.
                         * @member {google.protobuf.IFieldMask|null|undefined} updateMask
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateSipTrunkRequest
                         * @instance
                         */
                        UpdateSipTrunkRequest.prototype.updateMask = null;
    
                        /**
                         * Creates a new UpdateSipTrunkRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateSipTrunkRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateSipTrunkRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.UpdateSipTrunkRequest} UpdateSipTrunkRequest instance
                         */
                        UpdateSipTrunkRequest.create = function create(properties) {
                            return new UpdateSipTrunkRequest(properties);
                        };
    
                        /**
                         * Encodes the specified UpdateSipTrunkRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.UpdateSipTrunkRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateSipTrunkRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateSipTrunkRequest} message UpdateSipTrunkRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UpdateSipTrunkRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.sipTrunk != null && Object.hasOwnProperty.call(message, "sipTrunk"))
                                $root.google.cloud.dialogflow.v2beta1.SipTrunk.encode(message.sipTrunk, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.updateMask != null && Object.hasOwnProperty.call(message, "updateMask"))
                                $root.google.protobuf.FieldMask.encode(message.updateMask, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified UpdateSipTrunkRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.UpdateSipTrunkRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateSipTrunkRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateSipTrunkRequest} message UpdateSipTrunkRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UpdateSipTrunkRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an UpdateSipTrunkRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateSipTrunkRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.UpdateSipTrunkRequest} UpdateSipTrunkRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UpdateSipTrunkRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.UpdateSipTrunkRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.sipTrunk = $root.google.cloud.dialogflow.v2beta1.SipTrunk.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.updateMask = $root.google.protobuf.FieldMask.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an UpdateSipTrunkRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateSipTrunkRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.UpdateSipTrunkRequest} UpdateSipTrunkRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UpdateSipTrunkRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an UpdateSipTrunkRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateSipTrunkRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        UpdateSipTrunkRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.sipTrunk != null && message.hasOwnProperty("sipTrunk")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.SipTrunk.verify(message.sipTrunk);
                                if (error)
                                    return "sipTrunk." + error;
                            }
                            if (message.updateMask != null && message.hasOwnProperty("updateMask")) {
                                var error = $root.google.protobuf.FieldMask.verify(message.updateMask);
                                if (error)
                                    return "updateMask." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates an UpdateSipTrunkRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateSipTrunkRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.UpdateSipTrunkRequest} UpdateSipTrunkRequest
                         */
                        UpdateSipTrunkRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.UpdateSipTrunkRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.UpdateSipTrunkRequest();
                            if (object.sipTrunk != null) {
                                if (typeof object.sipTrunk !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.UpdateSipTrunkRequest.sipTrunk: object expected");
                                message.sipTrunk = $root.google.cloud.dialogflow.v2beta1.SipTrunk.fromObject(object.sipTrunk);
                            }
                            if (object.updateMask != null) {
                                if (typeof object.updateMask !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.UpdateSipTrunkRequest.updateMask: object expected");
                                message.updateMask = $root.google.protobuf.FieldMask.fromObject(object.updateMask);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an UpdateSipTrunkRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateSipTrunkRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.UpdateSipTrunkRequest} message UpdateSipTrunkRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        UpdateSipTrunkRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.sipTrunk = null;
                                object.updateMask = null;
                            }
                            if (message.sipTrunk != null && message.hasOwnProperty("sipTrunk"))
                                object.sipTrunk = $root.google.cloud.dialogflow.v2beta1.SipTrunk.toObject(message.sipTrunk, options);
                            if (message.updateMask != null && message.hasOwnProperty("updateMask"))
                                object.updateMask = $root.google.protobuf.FieldMask.toObject(message.updateMask, options);
                            return object;
                        };
    
                        /**
                         * Converts this UpdateSipTrunkRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateSipTrunkRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        UpdateSipTrunkRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for UpdateSipTrunkRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateSipTrunkRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        UpdateSipTrunkRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.UpdateSipTrunkRequest";
                        };
    
                        return UpdateSipTrunkRequest;
                    })();
    
                    v2beta1.SipTrunk = (function() {
    
                        /**
                         * Properties of a SipTrunk.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ISipTrunk
                         * @property {string|null} [name] SipTrunk name
                         * @property {Array.<string>|null} [expectedHostname] SipTrunk expectedHostname
                         * @property {Array.<google.cloud.dialogflow.v2beta1.IConnection>|null} [connections] SipTrunk connections
                         * @property {string|null} [displayName] SipTrunk displayName
                         */
    
                        /**
                         * Constructs a new SipTrunk.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a SipTrunk.
                         * @implements ISipTrunk
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ISipTrunk=} [properties] Properties to set
                         */
                        function SipTrunk(properties) {
                            this.expectedHostname = [];
                            this.connections = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * SipTrunk name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2beta1.SipTrunk
                         * @instance
                         */
                        SipTrunk.prototype.name = "";
    
                        /**
                         * SipTrunk expectedHostname.
                         * @member {Array.<string>} expectedHostname
                         * @memberof google.cloud.dialogflow.v2beta1.SipTrunk
                         * @instance
                         */
                        SipTrunk.prototype.expectedHostname = $util.emptyArray;
    
                        /**
                         * SipTrunk connections.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.IConnection>} connections
                         * @memberof google.cloud.dialogflow.v2beta1.SipTrunk
                         * @instance
                         */
                        SipTrunk.prototype.connections = $util.emptyArray;
    
                        /**
                         * SipTrunk displayName.
                         * @member {string} displayName
                         * @memberof google.cloud.dialogflow.v2beta1.SipTrunk
                         * @instance
                         */
                        SipTrunk.prototype.displayName = "";
    
                        /**
                         * Creates a new SipTrunk instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.SipTrunk
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISipTrunk=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.SipTrunk} SipTrunk instance
                         */
                        SipTrunk.create = function create(properties) {
                            return new SipTrunk(properties);
                        };
    
                        /**
                         * Encodes the specified SipTrunk message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SipTrunk.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.SipTrunk
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISipTrunk} message SipTrunk message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SipTrunk.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            if (message.expectedHostname != null && message.expectedHostname.length)
                                for (var i = 0; i < message.expectedHostname.length; ++i)
                                    writer.uint32(/* id 2, wireType 2 =*/18).string(message.expectedHostname[i]);
                            if (message.connections != null && message.connections.length)
                                for (var i = 0; i < message.connections.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.Connection.encode(message.connections[i], writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            if (message.displayName != null && Object.hasOwnProperty.call(message, "displayName"))
                                writer.uint32(/* id 4, wireType 2 =*/34).string(message.displayName);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified SipTrunk message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.SipTrunk.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SipTrunk
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ISipTrunk} message SipTrunk message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        SipTrunk.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a SipTrunk message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.SipTrunk
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.SipTrunk} SipTrunk
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SipTrunk.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.SipTrunk();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                case 2: {
                                        if (!(message.expectedHostname && message.expectedHostname.length))
                                            message.expectedHostname = [];
                                        message.expectedHostname.push(reader.string());
                                        break;
                                    }
                                case 3: {
                                        if (!(message.connections && message.connections.length))
                                            message.connections = [];
                                        message.connections.push($root.google.cloud.dialogflow.v2beta1.Connection.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 4: {
                                        message.displayName = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a SipTrunk message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.SipTrunk
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.SipTrunk} SipTrunk
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        SipTrunk.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a SipTrunk message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.SipTrunk
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        SipTrunk.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            if (message.expectedHostname != null && message.hasOwnProperty("expectedHostname")) {
                                if (!Array.isArray(message.expectedHostname))
                                    return "expectedHostname: array expected";
                                for (var i = 0; i < message.expectedHostname.length; ++i)
                                    if (!$util.isString(message.expectedHostname[i]))
                                        return "expectedHostname: string[] expected";
                            }
                            if (message.connections != null && message.hasOwnProperty("connections")) {
                                if (!Array.isArray(message.connections))
                                    return "connections: array expected";
                                for (var i = 0; i < message.connections.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.Connection.verify(message.connections[i]);
                                    if (error)
                                        return "connections." + error;
                                }
                            }
                            if (message.displayName != null && message.hasOwnProperty("displayName"))
                                if (!$util.isString(message.displayName))
                                    return "displayName: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a SipTrunk message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.SipTrunk
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.SipTrunk} SipTrunk
                         */
                        SipTrunk.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.SipTrunk)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.SipTrunk();
                            if (object.name != null)
                                message.name = String(object.name);
                            if (object.expectedHostname) {
                                if (!Array.isArray(object.expectedHostname))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.SipTrunk.expectedHostname: array expected");
                                message.expectedHostname = [];
                                for (var i = 0; i < object.expectedHostname.length; ++i)
                                    message.expectedHostname[i] = String(object.expectedHostname[i]);
                            }
                            if (object.connections) {
                                if (!Array.isArray(object.connections))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.SipTrunk.connections: array expected");
                                message.connections = [];
                                for (var i = 0; i < object.connections.length; ++i) {
                                    if (typeof object.connections[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.SipTrunk.connections: object expected");
                                    message.connections[i] = $root.google.cloud.dialogflow.v2beta1.Connection.fromObject(object.connections[i]);
                                }
                            }
                            if (object.displayName != null)
                                message.displayName = String(object.displayName);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a SipTrunk message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.SipTrunk
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.SipTrunk} message SipTrunk
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        SipTrunk.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults) {
                                object.expectedHostname = [];
                                object.connections = [];
                            }
                            if (options.defaults) {
                                object.name = "";
                                object.displayName = "";
                            }
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            if (message.expectedHostname && message.expectedHostname.length) {
                                object.expectedHostname = [];
                                for (var j = 0; j < message.expectedHostname.length; ++j)
                                    object.expectedHostname[j] = message.expectedHostname[j];
                            }
                            if (message.connections && message.connections.length) {
                                object.connections = [];
                                for (var j = 0; j < message.connections.length; ++j)
                                    object.connections[j] = $root.google.cloud.dialogflow.v2beta1.Connection.toObject(message.connections[j], options);
                            }
                            if (message.displayName != null && message.hasOwnProperty("displayName"))
                                object.displayName = message.displayName;
                            return object;
                        };
    
                        /**
                         * Converts this SipTrunk to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.SipTrunk
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        SipTrunk.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for SipTrunk
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.SipTrunk
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        SipTrunk.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.SipTrunk";
                        };
    
                        return SipTrunk;
                    })();
    
                    v2beta1.Connection = (function() {
    
                        /**
                         * Properties of a Connection.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IConnection
                         * @property {string|null} [connectionId] Connection connectionId
                         * @property {google.cloud.dialogflow.v2beta1.Connection.State|null} [state] Connection state
                         * @property {google.protobuf.ITimestamp|null} [updateTime] Connection updateTime
                         * @property {google.cloud.dialogflow.v2beta1.Connection.IErrorDetails|null} [errorDetails] Connection errorDetails
                         */
    
                        /**
                         * Constructs a new Connection.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a Connection.
                         * @implements IConnection
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IConnection=} [properties] Properties to set
                         */
                        function Connection(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * Connection connectionId.
                         * @member {string} connectionId
                         * @memberof google.cloud.dialogflow.v2beta1.Connection
                         * @instance
                         */
                        Connection.prototype.connectionId = "";
    
                        /**
                         * Connection state.
                         * @member {google.cloud.dialogflow.v2beta1.Connection.State} state
                         * @memberof google.cloud.dialogflow.v2beta1.Connection
                         * @instance
                         */
                        Connection.prototype.state = 0;
    
                        /**
                         * Connection updateTime.
                         * @member {google.protobuf.ITimestamp|null|undefined} updateTime
                         * @memberof google.cloud.dialogflow.v2beta1.Connection
                         * @instance
                         */
                        Connection.prototype.updateTime = null;
    
                        /**
                         * Connection errorDetails.
                         * @member {google.cloud.dialogflow.v2beta1.Connection.IErrorDetails|null|undefined} errorDetails
                         * @memberof google.cloud.dialogflow.v2beta1.Connection
                         * @instance
                         */
                        Connection.prototype.errorDetails = null;
    
                        // OneOf field names bound to virtual getters and setters
                        var $oneOfFields;
    
                        /**
                         * Connection _updateTime.
                         * @member {"updateTime"|undefined} _updateTime
                         * @memberof google.cloud.dialogflow.v2beta1.Connection
                         * @instance
                         */
                        Object.defineProperty(Connection.prototype, "_updateTime", {
                            get: $util.oneOfGetter($oneOfFields = ["updateTime"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Connection _errorDetails.
                         * @member {"errorDetails"|undefined} _errorDetails
                         * @memberof google.cloud.dialogflow.v2beta1.Connection
                         * @instance
                         */
                        Object.defineProperty(Connection.prototype, "_errorDetails", {
                            get: $util.oneOfGetter($oneOfFields = ["errorDetails"]),
                            set: $util.oneOfSetter($oneOfFields)
                        });
    
                        /**
                         * Creates a new Connection instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.Connection
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IConnection=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.Connection} Connection instance
                         */
                        Connection.create = function create(properties) {
                            return new Connection(properties);
                        };
    
                        /**
                         * Encodes the specified Connection message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Connection.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.Connection
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IConnection} message Connection message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        Connection.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.connectionId != null && Object.hasOwnProperty.call(message, "connectionId"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.connectionId);
                            if (message.state != null && Object.hasOwnProperty.call(message, "state"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.state);
                            if (message.updateTime != null && Object.hasOwnProperty.call(message, "updateTime"))
                                $root.google.protobuf.Timestamp.encode(message.updateTime, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            if (message.errorDetails != null && Object.hasOwnProperty.call(message, "errorDetails"))
                                $root.google.cloud.dialogflow.v2beta1.Connection.ErrorDetails.encode(message.errorDetails, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified Connection message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Connection.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.Connection
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IConnection} message Connection message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        Connection.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a Connection message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.Connection
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.Connection} Connection
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        Connection.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Connection();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.connectionId = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.state = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.updateTime = $root.google.protobuf.Timestamp.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 4: {
                                        message.errorDetails = $root.google.cloud.dialogflow.v2beta1.Connection.ErrorDetails.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a Connection message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.Connection
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.Connection} Connection
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        Connection.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a Connection message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.Connection
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        Connection.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            var properties = {};
                            if (message.connectionId != null && message.hasOwnProperty("connectionId"))
                                if (!$util.isString(message.connectionId))
                                    return "connectionId: string expected";
                            if (message.state != null && message.hasOwnProperty("state"))
                                switch (message.state) {
                                default:
                                    return "state: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                case 4:
                                    break;
                                }
                            if (message.updateTime != null && message.hasOwnProperty("updateTime")) {
                                properties._updateTime = 1;
                                {
                                    var error = $root.google.protobuf.Timestamp.verify(message.updateTime);
                                    if (error)
                                        return "updateTime." + error;
                                }
                            }
                            if (message.errorDetails != null && message.hasOwnProperty("errorDetails")) {
                                properties._errorDetails = 1;
                                {
                                    var error = $root.google.cloud.dialogflow.v2beta1.Connection.ErrorDetails.verify(message.errorDetails);
                                    if (error)
                                        return "errorDetails." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates a Connection message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.Connection
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.Connection} Connection
                         */
                        Connection.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.Connection)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.Connection();
                            if (object.connectionId != null)
                                message.connectionId = String(object.connectionId);
                            switch (object.state) {
                            default:
                                if (typeof object.state === "number") {
                                    message.state = object.state;
                                    break;
                                }
                                break;
                            case "STATE_UNSPECIFIED":
                            case 0:
                                message.state = 0;
                                break;
                            case "CONNECTED":
                            case 1:
                                message.state = 1;
                                break;
                            case "DISCONNECTED":
                            case 2:
                                message.state = 2;
                                break;
                            case "AUTHENTICATION_FAILED":
                            case 3:
                                message.state = 3;
                                break;
                            case "KEEPALIVE":
                            case 4:
                                message.state = 4;
                                break;
                            }
                            if (object.updateTime != null) {
                                if (typeof object.updateTime !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.Connection.updateTime: object expected");
                                message.updateTime = $root.google.protobuf.Timestamp.fromObject(object.updateTime);
                            }
                            if (object.errorDetails != null) {
                                if (typeof object.errorDetails !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.Connection.errorDetails: object expected");
                                message.errorDetails = $root.google.cloud.dialogflow.v2beta1.Connection.ErrorDetails.fromObject(object.errorDetails);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a Connection message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.Connection
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.Connection} message Connection
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        Connection.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.connectionId = "";
                                object.state = options.enums === String ? "STATE_UNSPECIFIED" : 0;
                            }
                            if (message.connectionId != null && message.hasOwnProperty("connectionId"))
                                object.connectionId = message.connectionId;
                            if (message.state != null && message.hasOwnProperty("state"))
                                object.state = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.Connection.State[message.state] === undefined ? message.state : $root.google.cloud.dialogflow.v2beta1.Connection.State[message.state] : message.state;
                            if (message.updateTime != null && message.hasOwnProperty("updateTime")) {
                                object.updateTime = $root.google.protobuf.Timestamp.toObject(message.updateTime, options);
                                if (options.oneofs)
                                    object._updateTime = "updateTime";
                            }
                            if (message.errorDetails != null && message.hasOwnProperty("errorDetails")) {
                                object.errorDetails = $root.google.cloud.dialogflow.v2beta1.Connection.ErrorDetails.toObject(message.errorDetails, options);
                                if (options.oneofs)
                                    object._errorDetails = "errorDetails";
                            }
                            return object;
                        };
    
                        /**
                         * Converts this Connection to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.Connection
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        Connection.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for Connection
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.Connection
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        Connection.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Connection";
                        };
    
                        /**
                         * State enum.
                         * @name google.cloud.dialogflow.v2beta1.Connection.State
                         * @enum {number}
                         * @property {number} STATE_UNSPECIFIED=0 STATE_UNSPECIFIED value
                         * @property {number} CONNECTED=1 CONNECTED value
                         * @property {number} DISCONNECTED=2 DISCONNECTED value
                         * @property {number} AUTHENTICATION_FAILED=3 AUTHENTICATION_FAILED value
                         * @property {number} KEEPALIVE=4 KEEPALIVE value
                         */
                        Connection.State = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "STATE_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "CONNECTED"] = 1;
                            values[valuesById[2] = "DISCONNECTED"] = 2;
                            values[valuesById[3] = "AUTHENTICATION_FAILED"] = 3;
                            values[valuesById[4] = "KEEPALIVE"] = 4;
                            return values;
                        })();
    
                        /**
                         * CertificateState enum.
                         * @name google.cloud.dialogflow.v2beta1.Connection.CertificateState
                         * @enum {number}
                         * @property {number} CERTIFICATE_STATE_UNSPECIFIED=0 CERTIFICATE_STATE_UNSPECIFIED value
                         * @property {number} CERTIFICATE_VALID=1 CERTIFICATE_VALID value
                         * @property {number} CERTIFICATE_INVALID=2 CERTIFICATE_INVALID value
                         * @property {number} CERTIFICATE_EXPIRED=3 CERTIFICATE_EXPIRED value
                         * @property {number} CERTIFICATE_HOSTNAME_NOT_FOUND=4 CERTIFICATE_HOSTNAME_NOT_FOUND value
                         * @property {number} CERTIFICATE_UNAUTHENTICATED=5 CERTIFICATE_UNAUTHENTICATED value
                         * @property {number} CERTIFICATE_TRUST_STORE_NOT_FOUND=6 CERTIFICATE_TRUST_STORE_NOT_FOUND value
                         * @property {number} CERTIFICATE_HOSTNAME_INVALID_FORMAT=7 CERTIFICATE_HOSTNAME_INVALID_FORMAT value
                         * @property {number} CERTIFICATE_QUOTA_EXCEEDED=8 CERTIFICATE_QUOTA_EXCEEDED value
                         */
                        Connection.CertificateState = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "CERTIFICATE_STATE_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "CERTIFICATE_VALID"] = 1;
                            values[valuesById[2] = "CERTIFICATE_INVALID"] = 2;
                            values[valuesById[3] = "CERTIFICATE_EXPIRED"] = 3;
                            values[valuesById[4] = "CERTIFICATE_HOSTNAME_NOT_FOUND"] = 4;
                            values[valuesById[5] = "CERTIFICATE_UNAUTHENTICATED"] = 5;
                            values[valuesById[6] = "CERTIFICATE_TRUST_STORE_NOT_FOUND"] = 6;
                            values[valuesById[7] = "CERTIFICATE_HOSTNAME_INVALID_FORMAT"] = 7;
                            values[valuesById[8] = "CERTIFICATE_QUOTA_EXCEEDED"] = 8;
                            return values;
                        })();
    
                        Connection.ErrorDetails = (function() {
    
                            /**
                             * Properties of an ErrorDetails.
                             * @memberof google.cloud.dialogflow.v2beta1.Connection
                             * @interface IErrorDetails
                             * @property {google.cloud.dialogflow.v2beta1.Connection.CertificateState|null} [certificateState] ErrorDetails certificateState
                             * @property {string|null} [errorMessage] ErrorDetails errorMessage
                             */
    
                            /**
                             * Constructs a new ErrorDetails.
                             * @memberof google.cloud.dialogflow.v2beta1.Connection
                             * @classdesc Represents an ErrorDetails.
                             * @implements IErrorDetails
                             * @constructor
                             * @param {google.cloud.dialogflow.v2beta1.Connection.IErrorDetails=} [properties] Properties to set
                             */
                            function ErrorDetails(properties) {
                                if (properties)
                                    for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                        if (properties[keys[i]] != null)
                                            this[keys[i]] = properties[keys[i]];
                            }
    
                            /**
                             * ErrorDetails certificateState.
                             * @member {google.cloud.dialogflow.v2beta1.Connection.CertificateState|null|undefined} certificateState
                             * @memberof google.cloud.dialogflow.v2beta1.Connection.ErrorDetails
                             * @instance
                             */
                            ErrorDetails.prototype.certificateState = null;
    
                            /**
                             * ErrorDetails errorMessage.
                             * @member {string|null|undefined} errorMessage
                             * @memberof google.cloud.dialogflow.v2beta1.Connection.ErrorDetails
                             * @instance
                             */
                            ErrorDetails.prototype.errorMessage = null;
    
                            // OneOf field names bound to virtual getters and setters
                            var $oneOfFields;
    
                            /**
                             * ErrorDetails _certificateState.
                             * @member {"certificateState"|undefined} _certificateState
                             * @memberof google.cloud.dialogflow.v2beta1.Connection.ErrorDetails
                             * @instance
                             */
                            Object.defineProperty(ErrorDetails.prototype, "_certificateState", {
                                get: $util.oneOfGetter($oneOfFields = ["certificateState"]),
                                set: $util.oneOfSetter($oneOfFields)
                            });
    
                            /**
                             * ErrorDetails _errorMessage.
                             * @member {"errorMessage"|undefined} _errorMessage
                             * @memberof google.cloud.dialogflow.v2beta1.Connection.ErrorDetails
                             * @instance
                             */
                            Object.defineProperty(ErrorDetails.prototype, "_errorMessage", {
                                get: $util.oneOfGetter($oneOfFields = ["errorMessage"]),
                                set: $util.oneOfSetter($oneOfFields)
                            });
    
                            /**
                             * Creates a new ErrorDetails instance using the specified properties.
                             * @function create
                             * @memberof google.cloud.dialogflow.v2beta1.Connection.ErrorDetails
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.Connection.IErrorDetails=} [properties] Properties to set
                             * @returns {google.cloud.dialogflow.v2beta1.Connection.ErrorDetails} ErrorDetails instance
                             */
                            ErrorDetails.create = function create(properties) {
                                return new ErrorDetails(properties);
                            };
    
                            /**
                             * Encodes the specified ErrorDetails message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Connection.ErrorDetails.verify|verify} messages.
                             * @function encode
                             * @memberof google.cloud.dialogflow.v2beta1.Connection.ErrorDetails
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.Connection.IErrorDetails} message ErrorDetails message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            ErrorDetails.encode = function encode(message, writer) {
                                if (!writer)
                                    writer = $Writer.create();
                                if (message.certificateState != null && Object.hasOwnProperty.call(message, "certificateState"))
                                    writer.uint32(/* id 1, wireType 0 =*/8).int32(message.certificateState);
                                if (message.errorMessage != null && Object.hasOwnProperty.call(message, "errorMessage"))
                                    writer.uint32(/* id 2, wireType 2 =*/18).string(message.errorMessage);
                                return writer;
                            };
    
                            /**
                             * Encodes the specified ErrorDetails message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Connection.ErrorDetails.verify|verify} messages.
                             * @function encodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.Connection.ErrorDetails
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.Connection.IErrorDetails} message ErrorDetails message or plain object to encode
                             * @param {$protobuf.Writer} [writer] Writer to encode to
                             * @returns {$protobuf.Writer} Writer
                             */
                            ErrorDetails.encodeDelimited = function encodeDelimited(message, writer) {
                                return this.encode(message, writer).ldelim();
                            };
    
                            /**
                             * Decodes an ErrorDetails message from the specified reader or buffer.
                             * @function decode
                             * @memberof google.cloud.dialogflow.v2beta1.Connection.ErrorDetails
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @param {number} [length] Message length if known beforehand
                             * @returns {google.cloud.dialogflow.v2beta1.Connection.ErrorDetails} ErrorDetails
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            ErrorDetails.decode = function decode(reader, length) {
                                if (!(reader instanceof $Reader))
                                    reader = $Reader.create(reader);
                                var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Connection.ErrorDetails();
                                while (reader.pos < end) {
                                    var tag = reader.uint32();
                                    switch (tag >>> 3) {
                                    case 1: {
                                            message.certificateState = reader.int32();
                                            break;
                                        }
                                    case 2: {
                                            message.errorMessage = reader.string();
                                            break;
                                        }
                                    default:
                                        reader.skipType(tag & 7);
                                        break;
                                    }
                                }
                                return message;
                            };
    
                            /**
                             * Decodes an ErrorDetails message from the specified reader or buffer, length delimited.
                             * @function decodeDelimited
                             * @memberof google.cloud.dialogflow.v2beta1.Connection.ErrorDetails
                             * @static
                             * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                             * @returns {google.cloud.dialogflow.v2beta1.Connection.ErrorDetails} ErrorDetails
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            ErrorDetails.decodeDelimited = function decodeDelimited(reader) {
                                if (!(reader instanceof $Reader))
                                    reader = new $Reader(reader);
                                return this.decode(reader, reader.uint32());
                            };
    
                            /**
                             * Verifies an ErrorDetails message.
                             * @function verify
                             * @memberof google.cloud.dialogflow.v2beta1.Connection.ErrorDetails
                             * @static
                             * @param {Object.<string,*>} message Plain object to verify
                             * @returns {string|null} `null` if valid, otherwise the reason why it is not
                             */
                            ErrorDetails.verify = function verify(message) {
                                if (typeof message !== "object" || message === null)
                                    return "object expected";
                                var properties = {};
                                if (message.certificateState != null && message.hasOwnProperty("certificateState")) {
                                    properties._certificateState = 1;
                                    switch (message.certificateState) {
                                    default:
                                        return "certificateState: enum value expected";
                                    case 0:
                                    case 1:
                                    case 2:
                                    case 3:
                                    case 4:
                                    case 5:
                                    case 6:
                                    case 7:
                                    case 8:
                                        break;
                                    }
                                }
                                if (message.errorMessage != null && message.hasOwnProperty("errorMessage")) {
                                    properties._errorMessage = 1;
                                    if (!$util.isString(message.errorMessage))
                                        return "errorMessage: string expected";
                                }
                                return null;
                            };
    
                            /**
                             * Creates an ErrorDetails message from a plain object. Also converts values to their respective internal types.
                             * @function fromObject
                             * @memberof google.cloud.dialogflow.v2beta1.Connection.ErrorDetails
                             * @static
                             * @param {Object.<string,*>} object Plain object
                             * @returns {google.cloud.dialogflow.v2beta1.Connection.ErrorDetails} ErrorDetails
                             */
                            ErrorDetails.fromObject = function fromObject(object) {
                                if (object instanceof $root.google.cloud.dialogflow.v2beta1.Connection.ErrorDetails)
                                    return object;
                                var message = new $root.google.cloud.dialogflow.v2beta1.Connection.ErrorDetails();
                                switch (object.certificateState) {
                                default:
                                    if (typeof object.certificateState === "number") {
                                        message.certificateState = object.certificateState;
                                        break;
                                    }
                                    break;
                                case "CERTIFICATE_STATE_UNSPECIFIED":
                                case 0:
                                    message.certificateState = 0;
                                    break;
                                case "CERTIFICATE_VALID":
                                case 1:
                                    message.certificateState = 1;
                                    break;
                                case "CERTIFICATE_INVALID":
                                case 2:
                                    message.certificateState = 2;
                                    break;
                                case "CERTIFICATE_EXPIRED":
                                case 3:
                                    message.certificateState = 3;
                                    break;
                                case "CERTIFICATE_HOSTNAME_NOT_FOUND":
                                case 4:
                                    message.certificateState = 4;
                                    break;
                                case "CERTIFICATE_UNAUTHENTICATED":
                                case 5:
                                    message.certificateState = 5;
                                    break;
                                case "CERTIFICATE_TRUST_STORE_NOT_FOUND":
                                case 6:
                                    message.certificateState = 6;
                                    break;
                                case "CERTIFICATE_HOSTNAME_INVALID_FORMAT":
                                case 7:
                                    message.certificateState = 7;
                                    break;
                                case "CERTIFICATE_QUOTA_EXCEEDED":
                                case 8:
                                    message.certificateState = 8;
                                    break;
                                }
                                if (object.errorMessage != null)
                                    message.errorMessage = String(object.errorMessage);
                                return message;
                            };
    
                            /**
                             * Creates a plain object from an ErrorDetails message. Also converts values to other types if specified.
                             * @function toObject
                             * @memberof google.cloud.dialogflow.v2beta1.Connection.ErrorDetails
                             * @static
                             * @param {google.cloud.dialogflow.v2beta1.Connection.ErrorDetails} message ErrorDetails
                             * @param {$protobuf.IConversionOptions} [options] Conversion options
                             * @returns {Object.<string,*>} Plain object
                             */
                            ErrorDetails.toObject = function toObject(message, options) {
                                if (!options)
                                    options = {};
                                var object = {};
                                if (message.certificateState != null && message.hasOwnProperty("certificateState")) {
                                    object.certificateState = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.Connection.CertificateState[message.certificateState] === undefined ? message.certificateState : $root.google.cloud.dialogflow.v2beta1.Connection.CertificateState[message.certificateState] : message.certificateState;
                                    if (options.oneofs)
                                        object._certificateState = "certificateState";
                                }
                                if (message.errorMessage != null && message.hasOwnProperty("errorMessage")) {
                                    object.errorMessage = message.errorMessage;
                                    if (options.oneofs)
                                        object._errorMessage = "errorMessage";
                                }
                                return object;
                            };
    
                            /**
                             * Converts this ErrorDetails to JSON.
                             * @function toJSON
                             * @memberof google.cloud.dialogflow.v2beta1.Connection.ErrorDetails
                             * @instance
                             * @returns {Object.<string,*>} JSON object
                             */
                            ErrorDetails.prototype.toJSON = function toJSON() {
                                return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                            };
    
                            /**
                             * Gets the default type url for ErrorDetails
                             * @function getTypeUrl
                             * @memberof google.cloud.dialogflow.v2beta1.Connection.ErrorDetails
                             * @static
                             * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns {string} The default type url
                             */
                            ErrorDetails.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                                if (typeUrlPrefix === undefined) {
                                    typeUrlPrefix = "type.googleapis.com";
                                }
                                return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Connection.ErrorDetails";
                            };
    
                            return ErrorDetails;
                        })();
    
                        return Connection;
                    })();
    
                    v2beta1.Versions = (function() {
    
                        /**
                         * Constructs a new Versions service.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a Versions
                         * @extends $protobuf.rpc.Service
                         * @constructor
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         */
                        function Versions(rpcImpl, requestDelimited, responseDelimited) {
                            $protobuf.rpc.Service.call(this, rpcImpl, requestDelimited, responseDelimited);
                        }
    
                        (Versions.prototype = Object.create($protobuf.rpc.Service.prototype)).constructor = Versions;
    
                        /**
                         * Creates new Versions service using the specified rpc implementation.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.Versions
                         * @static
                         * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                         * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                         * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                         * @returns {Versions} RPC service. Useful where requests and/or responses are streamed.
                         */
                        Versions.create = function create(rpcImpl, requestDelimited, responseDelimited) {
                            return new this(rpcImpl, requestDelimited, responseDelimited);
                        };
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Versions|listVersions}.
                         * @memberof google.cloud.dialogflow.v2beta1.Versions
                         * @typedef ListVersionsCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.ListVersionsResponse} [response] ListVersionsResponse
                         */
    
                        /**
                         * Calls ListVersions.
                         * @function listVersions
                         * @memberof google.cloud.dialogflow.v2beta1.Versions
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IListVersionsRequest} request ListVersionsRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Versions.ListVersionsCallback} callback Node-style callback called with the error, if any, and ListVersionsResponse
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Versions.prototype.listVersions = function listVersions(request, callback) {
                            return this.rpcCall(listVersions, $root.google.cloud.dialogflow.v2beta1.ListVersionsRequest, $root.google.cloud.dialogflow.v2beta1.ListVersionsResponse, request, callback);
                        }, "name", { value: "ListVersions" });
    
                        /**
                         * Calls ListVersions.
                         * @function listVersions
                         * @memberof google.cloud.dialogflow.v2beta1.Versions
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IListVersionsRequest} request ListVersionsRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.ListVersionsResponse>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Versions|getVersion}.
                         * @memberof google.cloud.dialogflow.v2beta1.Versions
                         * @typedef GetVersionCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.Version} [response] Version
                         */
    
                        /**
                         * Calls GetVersion.
                         * @function getVersion
                         * @memberof google.cloud.dialogflow.v2beta1.Versions
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IGetVersionRequest} request GetVersionRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Versions.GetVersionCallback} callback Node-style callback called with the error, if any, and Version
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Versions.prototype.getVersion = function getVersion(request, callback) {
                            return this.rpcCall(getVersion, $root.google.cloud.dialogflow.v2beta1.GetVersionRequest, $root.google.cloud.dialogflow.v2beta1.Version, request, callback);
                        }, "name", { value: "GetVersion" });
    
                        /**
                         * Calls GetVersion.
                         * @function getVersion
                         * @memberof google.cloud.dialogflow.v2beta1.Versions
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IGetVersionRequest} request GetVersionRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.Version>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Versions|createVersion}.
                         * @memberof google.cloud.dialogflow.v2beta1.Versions
                         * @typedef CreateVersionCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.Version} [response] Version
                         */
    
                        /**
                         * Calls CreateVersion.
                         * @function createVersion
                         * @memberof google.cloud.dialogflow.v2beta1.Versions
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.ICreateVersionRequest} request CreateVersionRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Versions.CreateVersionCallback} callback Node-style callback called with the error, if any, and Version
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Versions.prototype.createVersion = function createVersion(request, callback) {
                            return this.rpcCall(createVersion, $root.google.cloud.dialogflow.v2beta1.CreateVersionRequest, $root.google.cloud.dialogflow.v2beta1.Version, request, callback);
                        }, "name", { value: "CreateVersion" });
    
                        /**
                         * Calls CreateVersion.
                         * @function createVersion
                         * @memberof google.cloud.dialogflow.v2beta1.Versions
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.ICreateVersionRequest} request CreateVersionRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.Version>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Versions|updateVersion}.
                         * @memberof google.cloud.dialogflow.v2beta1.Versions
                         * @typedef UpdateVersionCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.cloud.dialogflow.v2beta1.Version} [response] Version
                         */
    
                        /**
                         * Calls UpdateVersion.
                         * @function updateVersion
                         * @memberof google.cloud.dialogflow.v2beta1.Versions
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateVersionRequest} request UpdateVersionRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Versions.UpdateVersionCallback} callback Node-style callback called with the error, if any, and Version
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Versions.prototype.updateVersion = function updateVersion(request, callback) {
                            return this.rpcCall(updateVersion, $root.google.cloud.dialogflow.v2beta1.UpdateVersionRequest, $root.google.cloud.dialogflow.v2beta1.Version, request, callback);
                        }, "name", { value: "UpdateVersion" });
    
                        /**
                         * Calls UpdateVersion.
                         * @function updateVersion
                         * @memberof google.cloud.dialogflow.v2beta1.Versions
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateVersionRequest} request UpdateVersionRequest message or plain object
                         * @returns {Promise<google.cloud.dialogflow.v2beta1.Version>} Promise
                         * @variation 2
                         */
    
                        /**
                         * Callback as used by {@link google.cloud.dialogflow.v2beta1.Versions|deleteVersion}.
                         * @memberof google.cloud.dialogflow.v2beta1.Versions
                         * @typedef DeleteVersionCallback
                         * @type {function}
                         * @param {Error|null} error Error, if any
                         * @param {google.protobuf.Empty} [response] Empty
                         */
    
                        /**
                         * Calls DeleteVersion.
                         * @function deleteVersion
                         * @memberof google.cloud.dialogflow.v2beta1.Versions
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteVersionRequest} request DeleteVersionRequest message or plain object
                         * @param {google.cloud.dialogflow.v2beta1.Versions.DeleteVersionCallback} callback Node-style callback called with the error, if any, and Empty
                         * @returns {undefined}
                         * @variation 1
                         */
                        Object.defineProperty(Versions.prototype.deleteVersion = function deleteVersion(request, callback) {
                            return this.rpcCall(deleteVersion, $root.google.cloud.dialogflow.v2beta1.DeleteVersionRequest, $root.google.protobuf.Empty, request, callback);
                        }, "name", { value: "DeleteVersion" });
    
                        /**
                         * Calls DeleteVersion.
                         * @function deleteVersion
                         * @memberof google.cloud.dialogflow.v2beta1.Versions
                         * @instance
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteVersionRequest} request DeleteVersionRequest message or plain object
                         * @returns {Promise<google.protobuf.Empty>} Promise
                         * @variation 2
                         */
    
                        return Versions;
                    })();
    
                    v2beta1.Version = (function() {
    
                        /**
                         * Properties of a Version.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IVersion
                         * @property {string|null} [name] Version name
                         * @property {string|null} [description] Version description
                         * @property {number|null} [versionNumber] Version versionNumber
                         * @property {google.protobuf.ITimestamp|null} [createTime] Version createTime
                         * @property {google.cloud.dialogflow.v2beta1.Version.VersionStatus|null} [status] Version status
                         */
    
                        /**
                         * Constructs a new Version.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a Version.
                         * @implements IVersion
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IVersion=} [properties] Properties to set
                         */
                        function Version(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * Version name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2beta1.Version
                         * @instance
                         */
                        Version.prototype.name = "";
    
                        /**
                         * Version description.
                         * @member {string} description
                         * @memberof google.cloud.dialogflow.v2beta1.Version
                         * @instance
                         */
                        Version.prototype.description = "";
    
                        /**
                         * Version versionNumber.
                         * @member {number} versionNumber
                         * @memberof google.cloud.dialogflow.v2beta1.Version
                         * @instance
                         */
                        Version.prototype.versionNumber = 0;
    
                        /**
                         * Version createTime.
                         * @member {google.protobuf.ITimestamp|null|undefined} createTime
                         * @memberof google.cloud.dialogflow.v2beta1.Version
                         * @instance
                         */
                        Version.prototype.createTime = null;
    
                        /**
                         * Version status.
                         * @member {google.cloud.dialogflow.v2beta1.Version.VersionStatus} status
                         * @memberof google.cloud.dialogflow.v2beta1.Version
                         * @instance
                         */
                        Version.prototype.status = 0;
    
                        /**
                         * Creates a new Version instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.Version
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IVersion=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.Version} Version instance
                         */
                        Version.create = function create(properties) {
                            return new Version(properties);
                        };
    
                        /**
                         * Encodes the specified Version message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Version.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.Version
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IVersion} message Version message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        Version.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            if (message.description != null && Object.hasOwnProperty.call(message, "description"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.description);
                            if (message.versionNumber != null && Object.hasOwnProperty.call(message, "versionNumber"))
                                writer.uint32(/* id 3, wireType 0 =*/24).int32(message.versionNumber);
                            if (message.createTime != null && Object.hasOwnProperty.call(message, "createTime"))
                                $root.google.protobuf.Timestamp.encode(message.createTime, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            if (message.status != null && Object.hasOwnProperty.call(message, "status"))
                                writer.uint32(/* id 6, wireType 0 =*/48).int32(message.status);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified Version message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.Version.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.Version
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IVersion} message Version message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        Version.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a Version message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.Version
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.Version} Version
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        Version.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.Version();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.description = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.versionNumber = reader.int32();
                                        break;
                                    }
                                case 4: {
                                        message.createTime = $root.google.protobuf.Timestamp.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 6: {
                                        message.status = reader.int32();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a Version message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.Version
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.Version} Version
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        Version.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a Version message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.Version
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        Version.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            if (message.description != null && message.hasOwnProperty("description"))
                                if (!$util.isString(message.description))
                                    return "description: string expected";
                            if (message.versionNumber != null && message.hasOwnProperty("versionNumber"))
                                if (!$util.isInteger(message.versionNumber))
                                    return "versionNumber: integer expected";
                            if (message.createTime != null && message.hasOwnProperty("createTime")) {
                                var error = $root.google.protobuf.Timestamp.verify(message.createTime);
                                if (error)
                                    return "createTime." + error;
                            }
                            if (message.status != null && message.hasOwnProperty("status"))
                                switch (message.status) {
                                default:
                                    return "status: enum value expected";
                                case 0:
                                case 1:
                                case 2:
                                case 3:
                                    break;
                                }
                            return null;
                        };
    
                        /**
                         * Creates a Version message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.Version
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.Version} Version
                         */
                        Version.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.Version)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.Version();
                            if (object.name != null)
                                message.name = String(object.name);
                            if (object.description != null)
                                message.description = String(object.description);
                            if (object.versionNumber != null)
                                message.versionNumber = object.versionNumber | 0;
                            if (object.createTime != null) {
                                if (typeof object.createTime !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.Version.createTime: object expected");
                                message.createTime = $root.google.protobuf.Timestamp.fromObject(object.createTime);
                            }
                            switch (object.status) {
                            default:
                                if (typeof object.status === "number") {
                                    message.status = object.status;
                                    break;
                                }
                                break;
                            case "VERSION_STATUS_UNSPECIFIED":
                            case 0:
                                message.status = 0;
                                break;
                            case "IN_PROGRESS":
                            case 1:
                                message.status = 1;
                                break;
                            case "READY":
                            case 2:
                                message.status = 2;
                                break;
                            case "FAILED":
                            case 3:
                                message.status = 3;
                                break;
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a Version message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.Version
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.Version} message Version
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        Version.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.name = "";
                                object.description = "";
                                object.versionNumber = 0;
                                object.createTime = null;
                                object.status = options.enums === String ? "VERSION_STATUS_UNSPECIFIED" : 0;
                            }
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            if (message.description != null && message.hasOwnProperty("description"))
                                object.description = message.description;
                            if (message.versionNumber != null && message.hasOwnProperty("versionNumber"))
                                object.versionNumber = message.versionNumber;
                            if (message.createTime != null && message.hasOwnProperty("createTime"))
                                object.createTime = $root.google.protobuf.Timestamp.toObject(message.createTime, options);
                            if (message.status != null && message.hasOwnProperty("status"))
                                object.status = options.enums === String ? $root.google.cloud.dialogflow.v2beta1.Version.VersionStatus[message.status] === undefined ? message.status : $root.google.cloud.dialogflow.v2beta1.Version.VersionStatus[message.status] : message.status;
                            return object;
                        };
    
                        /**
                         * Converts this Version to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.Version
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        Version.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for Version
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.Version
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        Version.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.Version";
                        };
    
                        /**
                         * VersionStatus enum.
                         * @name google.cloud.dialogflow.v2beta1.Version.VersionStatus
                         * @enum {number}
                         * @property {number} VERSION_STATUS_UNSPECIFIED=0 VERSION_STATUS_UNSPECIFIED value
                         * @property {number} IN_PROGRESS=1 IN_PROGRESS value
                         * @property {number} READY=2 READY value
                         * @property {number} FAILED=3 FAILED value
                         */
                        Version.VersionStatus = (function() {
                            var valuesById = {}, values = Object.create(valuesById);
                            values[valuesById[0] = "VERSION_STATUS_UNSPECIFIED"] = 0;
                            values[valuesById[1] = "IN_PROGRESS"] = 1;
                            values[valuesById[2] = "READY"] = 2;
                            values[valuesById[3] = "FAILED"] = 3;
                            return values;
                        })();
    
                        return Version;
                    })();
    
                    v2beta1.ListVersionsRequest = (function() {
    
                        /**
                         * Properties of a ListVersionsRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IListVersionsRequest
                         * @property {string|null} [parent] ListVersionsRequest parent
                         * @property {number|null} [pageSize] ListVersionsRequest pageSize
                         * @property {string|null} [pageToken] ListVersionsRequest pageToken
                         */
    
                        /**
                         * Constructs a new ListVersionsRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a ListVersionsRequest.
                         * @implements IListVersionsRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IListVersionsRequest=} [properties] Properties to set
                         */
                        function ListVersionsRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListVersionsRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.ListVersionsRequest
                         * @instance
                         */
                        ListVersionsRequest.prototype.parent = "";
    
                        /**
                         * ListVersionsRequest pageSize.
                         * @member {number} pageSize
                         * @memberof google.cloud.dialogflow.v2beta1.ListVersionsRequest
                         * @instance
                         */
                        ListVersionsRequest.prototype.pageSize = 0;
    
                        /**
                         * ListVersionsRequest pageToken.
                         * @member {string} pageToken
                         * @memberof google.cloud.dialogflow.v2beta1.ListVersionsRequest
                         * @instance
                         */
                        ListVersionsRequest.prototype.pageToken = "";
    
                        /**
                         * Creates a new ListVersionsRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.ListVersionsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListVersionsRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.ListVersionsRequest} ListVersionsRequest instance
                         */
                        ListVersionsRequest.create = function create(properties) {
                            return new ListVersionsRequest(properties);
                        };
    
                        /**
                         * Encodes the specified ListVersionsRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListVersionsRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.ListVersionsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListVersionsRequest} message ListVersionsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListVersionsRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.pageSize != null && Object.hasOwnProperty.call(message, "pageSize"))
                                writer.uint32(/* id 2, wireType 0 =*/16).int32(message.pageSize);
                            if (message.pageToken != null && Object.hasOwnProperty.call(message, "pageToken"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.pageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListVersionsRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListVersionsRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListVersionsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListVersionsRequest} message ListVersionsRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListVersionsRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListVersionsRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.ListVersionsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.ListVersionsRequest} ListVersionsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListVersionsRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ListVersionsRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.pageSize = reader.int32();
                                        break;
                                    }
                                case 3: {
                                        message.pageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListVersionsRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListVersionsRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.ListVersionsRequest} ListVersionsRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListVersionsRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListVersionsRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.ListVersionsRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListVersionsRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                if (!$util.isInteger(message.pageSize))
                                    return "pageSize: integer expected";
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                if (!$util.isString(message.pageToken))
                                    return "pageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListVersionsRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListVersionsRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.ListVersionsRequest} ListVersionsRequest
                         */
                        ListVersionsRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.ListVersionsRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.ListVersionsRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.pageSize != null)
                                message.pageSize = object.pageSize | 0;
                            if (object.pageToken != null)
                                message.pageToken = String(object.pageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListVersionsRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListVersionsRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ListVersionsRequest} message ListVersionsRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListVersionsRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.pageSize = 0;
                                object.pageToken = "";
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                                object.pageSize = message.pageSize;
                            if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                                object.pageToken = message.pageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListVersionsRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.ListVersionsRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListVersionsRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListVersionsRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.ListVersionsRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListVersionsRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ListVersionsRequest";
                        };
    
                        return ListVersionsRequest;
                    })();
    
                    v2beta1.ListVersionsResponse = (function() {
    
                        /**
                         * Properties of a ListVersionsResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IListVersionsResponse
                         * @property {Array.<google.cloud.dialogflow.v2beta1.IVersion>|null} [versions] ListVersionsResponse versions
                         * @property {string|null} [nextPageToken] ListVersionsResponse nextPageToken
                         */
    
                        /**
                         * Constructs a new ListVersionsResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a ListVersionsResponse.
                         * @implements IListVersionsResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IListVersionsResponse=} [properties] Properties to set
                         */
                        function ListVersionsResponse(properties) {
                            this.versions = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * ListVersionsResponse versions.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.IVersion>} versions
                         * @memberof google.cloud.dialogflow.v2beta1.ListVersionsResponse
                         * @instance
                         */
                        ListVersionsResponse.prototype.versions = $util.emptyArray;
    
                        /**
                         * ListVersionsResponse nextPageToken.
                         * @member {string} nextPageToken
                         * @memberof google.cloud.dialogflow.v2beta1.ListVersionsResponse
                         * @instance
                         */
                        ListVersionsResponse.prototype.nextPageToken = "";
    
                        /**
                         * Creates a new ListVersionsResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.ListVersionsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListVersionsResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.ListVersionsResponse} ListVersionsResponse instance
                         */
                        ListVersionsResponse.create = function create(properties) {
                            return new ListVersionsResponse(properties);
                        };
    
                        /**
                         * Encodes the specified ListVersionsResponse message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListVersionsResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.ListVersionsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListVersionsResponse} message ListVersionsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListVersionsResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.versions != null && message.versions.length)
                                for (var i = 0; i < message.versions.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.Version.encode(message.versions[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.nextPageToken != null && Object.hasOwnProperty.call(message, "nextPageToken"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.nextPageToken);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified ListVersionsResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.ListVersionsResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListVersionsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IListVersionsResponse} message ListVersionsResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        ListVersionsResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a ListVersionsResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.ListVersionsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.ListVersionsResponse} ListVersionsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListVersionsResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.ListVersionsResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        if (!(message.versions && message.versions.length))
                                            message.versions = [];
                                        message.versions.push($root.google.cloud.dialogflow.v2beta1.Version.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 2: {
                                        message.nextPageToken = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a ListVersionsResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.ListVersionsResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.ListVersionsResponse} ListVersionsResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        ListVersionsResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a ListVersionsResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.ListVersionsResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        ListVersionsResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.versions != null && message.hasOwnProperty("versions")) {
                                if (!Array.isArray(message.versions))
                                    return "versions: array expected";
                                for (var i = 0; i < message.versions.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.Version.verify(message.versions[i]);
                                    if (error)
                                        return "versions." + error;
                                }
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                if (!$util.isString(message.nextPageToken))
                                    return "nextPageToken: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a ListVersionsResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListVersionsResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.ListVersionsResponse} ListVersionsResponse
                         */
                        ListVersionsResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.ListVersionsResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.ListVersionsResponse();
                            if (object.versions) {
                                if (!Array.isArray(object.versions))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.ListVersionsResponse.versions: array expected");
                                message.versions = [];
                                for (var i = 0; i < object.versions.length; ++i) {
                                    if (typeof object.versions[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.ListVersionsResponse.versions: object expected");
                                    message.versions[i] = $root.google.cloud.dialogflow.v2beta1.Version.fromObject(object.versions[i]);
                                }
                            }
                            if (object.nextPageToken != null)
                                message.nextPageToken = String(object.nextPageToken);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a ListVersionsResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.ListVersionsResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ListVersionsResponse} message ListVersionsResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        ListVersionsResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.versions = [];
                            if (options.defaults)
                                object.nextPageToken = "";
                            if (message.versions && message.versions.length) {
                                object.versions = [];
                                for (var j = 0; j < message.versions.length; ++j)
                                    object.versions[j] = $root.google.cloud.dialogflow.v2beta1.Version.toObject(message.versions[j], options);
                            }
                            if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                                object.nextPageToken = message.nextPageToken;
                            return object;
                        };
    
                        /**
                         * Converts this ListVersionsResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.ListVersionsResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        ListVersionsResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for ListVersionsResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.ListVersionsResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        ListVersionsResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.ListVersionsResponse";
                        };
    
                        return ListVersionsResponse;
                    })();
    
                    v2beta1.GetVersionRequest = (function() {
    
                        /**
                         * Properties of a GetVersionRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IGetVersionRequest
                         * @property {string|null} [name] GetVersionRequest name
                         */
    
                        /**
                         * Constructs a new GetVersionRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a GetVersionRequest.
                         * @implements IGetVersionRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IGetVersionRequest=} [properties] Properties to set
                         */
                        function GetVersionRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * GetVersionRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2beta1.GetVersionRequest
                         * @instance
                         */
                        GetVersionRequest.prototype.name = "";
    
                        /**
                         * Creates a new GetVersionRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.GetVersionRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetVersionRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.GetVersionRequest} GetVersionRequest instance
                         */
                        GetVersionRequest.create = function create(properties) {
                            return new GetVersionRequest(properties);
                        };
    
                        /**
                         * Encodes the specified GetVersionRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GetVersionRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.GetVersionRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetVersionRequest} message GetVersionRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetVersionRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified GetVersionRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.GetVersionRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GetVersionRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IGetVersionRequest} message GetVersionRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        GetVersionRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a GetVersionRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.GetVersionRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.GetVersionRequest} GetVersionRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetVersionRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.GetVersionRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a GetVersionRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.GetVersionRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.GetVersionRequest} GetVersionRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        GetVersionRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a GetVersionRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.GetVersionRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        GetVersionRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a GetVersionRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.GetVersionRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.GetVersionRequest} GetVersionRequest
                         */
                        GetVersionRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.GetVersionRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.GetVersionRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a GetVersionRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.GetVersionRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.GetVersionRequest} message GetVersionRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        GetVersionRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.name = "";
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            return object;
                        };
    
                        /**
                         * Converts this GetVersionRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.GetVersionRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        GetVersionRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for GetVersionRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.GetVersionRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        GetVersionRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.GetVersionRequest";
                        };
    
                        return GetVersionRequest;
                    })();
    
                    v2beta1.CreateVersionRequest = (function() {
    
                        /**
                         * Properties of a CreateVersionRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface ICreateVersionRequest
                         * @property {string|null} [parent] CreateVersionRequest parent
                         * @property {google.cloud.dialogflow.v2beta1.IVersion|null} [version] CreateVersionRequest version
                         */
    
                        /**
                         * Constructs a new CreateVersionRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a CreateVersionRequest.
                         * @implements ICreateVersionRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.ICreateVersionRequest=} [properties] Properties to set
                         */
                        function CreateVersionRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * CreateVersionRequest parent.
                         * @member {string} parent
                         * @memberof google.cloud.dialogflow.v2beta1.CreateVersionRequest
                         * @instance
                         */
                        CreateVersionRequest.prototype.parent = "";
    
                        /**
                         * CreateVersionRequest version.
                         * @member {google.cloud.dialogflow.v2beta1.IVersion|null|undefined} version
                         * @memberof google.cloud.dialogflow.v2beta1.CreateVersionRequest
                         * @instance
                         */
                        CreateVersionRequest.prototype.version = null;
    
                        /**
                         * Creates a new CreateVersionRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.CreateVersionRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ICreateVersionRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.CreateVersionRequest} CreateVersionRequest instance
                         */
                        CreateVersionRequest.create = function create(properties) {
                            return new CreateVersionRequest(properties);
                        };
    
                        /**
                         * Encodes the specified CreateVersionRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.CreateVersionRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.CreateVersionRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ICreateVersionRequest} message CreateVersionRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateVersionRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.parent != null && Object.hasOwnProperty.call(message, "parent"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.parent);
                            if (message.version != null && Object.hasOwnProperty.call(message, "version"))
                                $root.google.cloud.dialogflow.v2beta1.Version.encode(message.version, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified CreateVersionRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.CreateVersionRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.CreateVersionRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.ICreateVersionRequest} message CreateVersionRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        CreateVersionRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a CreateVersionRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.CreateVersionRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.CreateVersionRequest} CreateVersionRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateVersionRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.CreateVersionRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.parent = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.version = $root.google.cloud.dialogflow.v2beta1.Version.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a CreateVersionRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.CreateVersionRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.CreateVersionRequest} CreateVersionRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        CreateVersionRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a CreateVersionRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.CreateVersionRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        CreateVersionRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                if (!$util.isString(message.parent))
                                    return "parent: string expected";
                            if (message.version != null && message.hasOwnProperty("version")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.Version.verify(message.version);
                                if (error)
                                    return "version." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a CreateVersionRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.CreateVersionRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.CreateVersionRequest} CreateVersionRequest
                         */
                        CreateVersionRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.CreateVersionRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.CreateVersionRequest();
                            if (object.parent != null)
                                message.parent = String(object.parent);
                            if (object.version != null) {
                                if (typeof object.version !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.CreateVersionRequest.version: object expected");
                                message.version = $root.google.cloud.dialogflow.v2beta1.Version.fromObject(object.version);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a CreateVersionRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.CreateVersionRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.CreateVersionRequest} message CreateVersionRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        CreateVersionRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.parent = "";
                                object.version = null;
                            }
                            if (message.parent != null && message.hasOwnProperty("parent"))
                                object.parent = message.parent;
                            if (message.version != null && message.hasOwnProperty("version"))
                                object.version = $root.google.cloud.dialogflow.v2beta1.Version.toObject(message.version, options);
                            return object;
                        };
    
                        /**
                         * Converts this CreateVersionRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.CreateVersionRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        CreateVersionRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for CreateVersionRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.CreateVersionRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        CreateVersionRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.CreateVersionRequest";
                        };
    
                        return CreateVersionRequest;
                    })();
    
                    v2beta1.UpdateVersionRequest = (function() {
    
                        /**
                         * Properties of an UpdateVersionRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IUpdateVersionRequest
                         * @property {google.cloud.dialogflow.v2beta1.IVersion|null} [version] UpdateVersionRequest version
                         * @property {google.protobuf.IFieldMask|null} [updateMask] UpdateVersionRequest updateMask
                         */
    
                        /**
                         * Constructs a new UpdateVersionRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an UpdateVersionRequest.
                         * @implements IUpdateVersionRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateVersionRequest=} [properties] Properties to set
                         */
                        function UpdateVersionRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * UpdateVersionRequest version.
                         * @member {google.cloud.dialogflow.v2beta1.IVersion|null|undefined} version
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateVersionRequest
                         * @instance
                         */
                        UpdateVersionRequest.prototype.version = null;
    
                        /**
                         * UpdateVersionRequest updateMask.
                         * @member {google.protobuf.IFieldMask|null|undefined} updateMask
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateVersionRequest
                         * @instance
                         */
                        UpdateVersionRequest.prototype.updateMask = null;
    
                        /**
                         * Creates a new UpdateVersionRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateVersionRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateVersionRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.UpdateVersionRequest} UpdateVersionRequest instance
                         */
                        UpdateVersionRequest.create = function create(properties) {
                            return new UpdateVersionRequest(properties);
                        };
    
                        /**
                         * Encodes the specified UpdateVersionRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.UpdateVersionRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateVersionRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateVersionRequest} message UpdateVersionRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UpdateVersionRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.version != null && Object.hasOwnProperty.call(message, "version"))
                                $root.google.cloud.dialogflow.v2beta1.Version.encode(message.version, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                            if (message.updateMask != null && Object.hasOwnProperty.call(message, "updateMask"))
                                $root.google.protobuf.FieldMask.encode(message.updateMask, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified UpdateVersionRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.UpdateVersionRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateVersionRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IUpdateVersionRequest} message UpdateVersionRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        UpdateVersionRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an UpdateVersionRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateVersionRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.UpdateVersionRequest} UpdateVersionRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UpdateVersionRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.UpdateVersionRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.version = $root.google.cloud.dialogflow.v2beta1.Version.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 2: {
                                        message.updateMask = $root.google.protobuf.FieldMask.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an UpdateVersionRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateVersionRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.UpdateVersionRequest} UpdateVersionRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        UpdateVersionRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an UpdateVersionRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateVersionRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        UpdateVersionRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.version != null && message.hasOwnProperty("version")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.Version.verify(message.version);
                                if (error)
                                    return "version." + error;
                            }
                            if (message.updateMask != null && message.hasOwnProperty("updateMask")) {
                                var error = $root.google.protobuf.FieldMask.verify(message.updateMask);
                                if (error)
                                    return "updateMask." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates an UpdateVersionRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateVersionRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.UpdateVersionRequest} UpdateVersionRequest
                         */
                        UpdateVersionRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.UpdateVersionRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.UpdateVersionRequest();
                            if (object.version != null) {
                                if (typeof object.version !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.UpdateVersionRequest.version: object expected");
                                message.version = $root.google.cloud.dialogflow.v2beta1.Version.fromObject(object.version);
                            }
                            if (object.updateMask != null) {
                                if (typeof object.updateMask !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.UpdateVersionRequest.updateMask: object expected");
                                message.updateMask = $root.google.protobuf.FieldMask.fromObject(object.updateMask);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an UpdateVersionRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateVersionRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.UpdateVersionRequest} message UpdateVersionRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        UpdateVersionRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.version = null;
                                object.updateMask = null;
                            }
                            if (message.version != null && message.hasOwnProperty("version"))
                                object.version = $root.google.cloud.dialogflow.v2beta1.Version.toObject(message.version, options);
                            if (message.updateMask != null && message.hasOwnProperty("updateMask"))
                                object.updateMask = $root.google.protobuf.FieldMask.toObject(message.updateMask, options);
                            return object;
                        };
    
                        /**
                         * Converts this UpdateVersionRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateVersionRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        UpdateVersionRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for UpdateVersionRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.UpdateVersionRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        UpdateVersionRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.UpdateVersionRequest";
                        };
    
                        return UpdateVersionRequest;
                    })();
    
                    v2beta1.DeleteVersionRequest = (function() {
    
                        /**
                         * Properties of a DeleteVersionRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IDeleteVersionRequest
                         * @property {string|null} [name] DeleteVersionRequest name
                         */
    
                        /**
                         * Constructs a new DeleteVersionRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a DeleteVersionRequest.
                         * @implements IDeleteVersionRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteVersionRequest=} [properties] Properties to set
                         */
                        function DeleteVersionRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * DeleteVersionRequest name.
                         * @member {string} name
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteVersionRequest
                         * @instance
                         */
                        DeleteVersionRequest.prototype.name = "";
    
                        /**
                         * Creates a new DeleteVersionRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteVersionRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteVersionRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.DeleteVersionRequest} DeleteVersionRequest instance
                         */
                        DeleteVersionRequest.create = function create(properties) {
                            return new DeleteVersionRequest(properties);
                        };
    
                        /**
                         * Encodes the specified DeleteVersionRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.DeleteVersionRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteVersionRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteVersionRequest} message DeleteVersionRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteVersionRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                            return writer;
                        };
    
                        /**
                         * Encodes the specified DeleteVersionRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.DeleteVersionRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteVersionRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IDeleteVersionRequest} message DeleteVersionRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        DeleteVersionRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a DeleteVersionRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteVersionRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.DeleteVersionRequest} DeleteVersionRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteVersionRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.DeleteVersionRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.name = reader.string();
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a DeleteVersionRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteVersionRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.DeleteVersionRequest} DeleteVersionRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        DeleteVersionRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a DeleteVersionRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteVersionRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        DeleteVersionRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.name != null && message.hasOwnProperty("name"))
                                if (!$util.isString(message.name))
                                    return "name: string expected";
                            return null;
                        };
    
                        /**
                         * Creates a DeleteVersionRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteVersionRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.DeleteVersionRequest} DeleteVersionRequest
                         */
                        DeleteVersionRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.DeleteVersionRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.DeleteVersionRequest();
                            if (object.name != null)
                                message.name = String(object.name);
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a DeleteVersionRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteVersionRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.DeleteVersionRequest} message DeleteVersionRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        DeleteVersionRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults)
                                object.name = "";
                            if (message.name != null && message.hasOwnProperty("name"))
                                object.name = message.name;
                            return object;
                        };
    
                        /**
                         * Converts this DeleteVersionRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteVersionRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        DeleteVersionRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for DeleteVersionRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.DeleteVersionRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        DeleteVersionRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.DeleteVersionRequest";
                        };
    
                        return DeleteVersionRequest;
                    })();
    
                    v2beta1.WebhookRequest = (function() {
    
                        /**
                         * Properties of a WebhookRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IWebhookRequest
                         * @property {string|null} [session] WebhookRequest session
                         * @property {string|null} [responseId] WebhookRequest responseId
                         * @property {google.cloud.dialogflow.v2beta1.IQueryResult|null} [queryResult] WebhookRequest queryResult
                         * @property {Array.<google.cloud.dialogflow.v2beta1.IQueryResult>|null} [alternativeQueryResults] WebhookRequest alternativeQueryResults
                         * @property {google.cloud.dialogflow.v2beta1.IOriginalDetectIntentRequest|null} [originalDetectIntentRequest] WebhookRequest originalDetectIntentRequest
                         */
    
                        /**
                         * Constructs a new WebhookRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a WebhookRequest.
                         * @implements IWebhookRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IWebhookRequest=} [properties] Properties to set
                         */
                        function WebhookRequest(properties) {
                            this.alternativeQueryResults = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * WebhookRequest session.
                         * @member {string} session
                         * @memberof google.cloud.dialogflow.v2beta1.WebhookRequest
                         * @instance
                         */
                        WebhookRequest.prototype.session = "";
    
                        /**
                         * WebhookRequest responseId.
                         * @member {string} responseId
                         * @memberof google.cloud.dialogflow.v2beta1.WebhookRequest
                         * @instance
                         */
                        WebhookRequest.prototype.responseId = "";
    
                        /**
                         * WebhookRequest queryResult.
                         * @member {google.cloud.dialogflow.v2beta1.IQueryResult|null|undefined} queryResult
                         * @memberof google.cloud.dialogflow.v2beta1.WebhookRequest
                         * @instance
                         */
                        WebhookRequest.prototype.queryResult = null;
    
                        /**
                         * WebhookRequest alternativeQueryResults.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.IQueryResult>} alternativeQueryResults
                         * @memberof google.cloud.dialogflow.v2beta1.WebhookRequest
                         * @instance
                         */
                        WebhookRequest.prototype.alternativeQueryResults = $util.emptyArray;
    
                        /**
                         * WebhookRequest originalDetectIntentRequest.
                         * @member {google.cloud.dialogflow.v2beta1.IOriginalDetectIntentRequest|null|undefined} originalDetectIntentRequest
                         * @memberof google.cloud.dialogflow.v2beta1.WebhookRequest
                         * @instance
                         */
                        WebhookRequest.prototype.originalDetectIntentRequest = null;
    
                        /**
                         * Creates a new WebhookRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.WebhookRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IWebhookRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.WebhookRequest} WebhookRequest instance
                         */
                        WebhookRequest.create = function create(properties) {
                            return new WebhookRequest(properties);
                        };
    
                        /**
                         * Encodes the specified WebhookRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.WebhookRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.WebhookRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IWebhookRequest} message WebhookRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        WebhookRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.responseId != null && Object.hasOwnProperty.call(message, "responseId"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.responseId);
                            if (message.queryResult != null && Object.hasOwnProperty.call(message, "queryResult"))
                                $root.google.cloud.dialogflow.v2beta1.QueryResult.encode(message.queryResult, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.originalDetectIntentRequest != null && Object.hasOwnProperty.call(message, "originalDetectIntentRequest"))
                                $root.google.cloud.dialogflow.v2beta1.OriginalDetectIntentRequest.encode(message.originalDetectIntentRequest, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            if (message.session != null && Object.hasOwnProperty.call(message, "session"))
                                writer.uint32(/* id 4, wireType 2 =*/34).string(message.session);
                            if (message.alternativeQueryResults != null && message.alternativeQueryResults.length)
                                for (var i = 0; i < message.alternativeQueryResults.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.QueryResult.encode(message.alternativeQueryResults[i], writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified WebhookRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.WebhookRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.WebhookRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IWebhookRequest} message WebhookRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        WebhookRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a WebhookRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.WebhookRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.WebhookRequest} WebhookRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        WebhookRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.WebhookRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 4: {
                                        message.session = reader.string();
                                        break;
                                    }
                                case 1: {
                                        message.responseId = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.queryResult = $root.google.cloud.dialogflow.v2beta1.QueryResult.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 5: {
                                        if (!(message.alternativeQueryResults && message.alternativeQueryResults.length))
                                            message.alternativeQueryResults = [];
                                        message.alternativeQueryResults.push($root.google.cloud.dialogflow.v2beta1.QueryResult.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 3: {
                                        message.originalDetectIntentRequest = $root.google.cloud.dialogflow.v2beta1.OriginalDetectIntentRequest.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a WebhookRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.WebhookRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.WebhookRequest} WebhookRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        WebhookRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a WebhookRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.WebhookRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        WebhookRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.session != null && message.hasOwnProperty("session"))
                                if (!$util.isString(message.session))
                                    return "session: string expected";
                            if (message.responseId != null && message.hasOwnProperty("responseId"))
                                if (!$util.isString(message.responseId))
                                    return "responseId: string expected";
                            if (message.queryResult != null && message.hasOwnProperty("queryResult")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.QueryResult.verify(message.queryResult);
                                if (error)
                                    return "queryResult." + error;
                            }
                            if (message.alternativeQueryResults != null && message.hasOwnProperty("alternativeQueryResults")) {
                                if (!Array.isArray(message.alternativeQueryResults))
                                    return "alternativeQueryResults: array expected";
                                for (var i = 0; i < message.alternativeQueryResults.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.QueryResult.verify(message.alternativeQueryResults[i]);
                                    if (error)
                                        return "alternativeQueryResults." + error;
                                }
                            }
                            if (message.originalDetectIntentRequest != null && message.hasOwnProperty("originalDetectIntentRequest")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.OriginalDetectIntentRequest.verify(message.originalDetectIntentRequest);
                                if (error)
                                    return "originalDetectIntentRequest." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates a WebhookRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.WebhookRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.WebhookRequest} WebhookRequest
                         */
                        WebhookRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.WebhookRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.WebhookRequest();
                            if (object.session != null)
                                message.session = String(object.session);
                            if (object.responseId != null)
                                message.responseId = String(object.responseId);
                            if (object.queryResult != null) {
                                if (typeof object.queryResult !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.WebhookRequest.queryResult: object expected");
                                message.queryResult = $root.google.cloud.dialogflow.v2beta1.QueryResult.fromObject(object.queryResult);
                            }
                            if (object.alternativeQueryResults) {
                                if (!Array.isArray(object.alternativeQueryResults))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.WebhookRequest.alternativeQueryResults: array expected");
                                message.alternativeQueryResults = [];
                                for (var i = 0; i < object.alternativeQueryResults.length; ++i) {
                                    if (typeof object.alternativeQueryResults[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.WebhookRequest.alternativeQueryResults: object expected");
                                    message.alternativeQueryResults[i] = $root.google.cloud.dialogflow.v2beta1.QueryResult.fromObject(object.alternativeQueryResults[i]);
                                }
                            }
                            if (object.originalDetectIntentRequest != null) {
                                if (typeof object.originalDetectIntentRequest !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.WebhookRequest.originalDetectIntentRequest: object expected");
                                message.originalDetectIntentRequest = $root.google.cloud.dialogflow.v2beta1.OriginalDetectIntentRequest.fromObject(object.originalDetectIntentRequest);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a WebhookRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.WebhookRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.WebhookRequest} message WebhookRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        WebhookRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults)
                                object.alternativeQueryResults = [];
                            if (options.defaults) {
                                object.responseId = "";
                                object.queryResult = null;
                                object.originalDetectIntentRequest = null;
                                object.session = "";
                            }
                            if (message.responseId != null && message.hasOwnProperty("responseId"))
                                object.responseId = message.responseId;
                            if (message.queryResult != null && message.hasOwnProperty("queryResult"))
                                object.queryResult = $root.google.cloud.dialogflow.v2beta1.QueryResult.toObject(message.queryResult, options);
                            if (message.originalDetectIntentRequest != null && message.hasOwnProperty("originalDetectIntentRequest"))
                                object.originalDetectIntentRequest = $root.google.cloud.dialogflow.v2beta1.OriginalDetectIntentRequest.toObject(message.originalDetectIntentRequest, options);
                            if (message.session != null && message.hasOwnProperty("session"))
                                object.session = message.session;
                            if (message.alternativeQueryResults && message.alternativeQueryResults.length) {
                                object.alternativeQueryResults = [];
                                for (var j = 0; j < message.alternativeQueryResults.length; ++j)
                                    object.alternativeQueryResults[j] = $root.google.cloud.dialogflow.v2beta1.QueryResult.toObject(message.alternativeQueryResults[j], options);
                            }
                            return object;
                        };
    
                        /**
                         * Converts this WebhookRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.WebhookRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        WebhookRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for WebhookRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.WebhookRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        WebhookRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.WebhookRequest";
                        };
    
                        return WebhookRequest;
                    })();
    
                    v2beta1.WebhookResponse = (function() {
    
                        /**
                         * Properties of a WebhookResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IWebhookResponse
                         * @property {string|null} [fulfillmentText] WebhookResponse fulfillmentText
                         * @property {Array.<google.cloud.dialogflow.v2beta1.Intent.IMessage>|null} [fulfillmentMessages] WebhookResponse fulfillmentMessages
                         * @property {string|null} [source] WebhookResponse source
                         * @property {google.protobuf.IStruct|null} [payload] WebhookResponse payload
                         * @property {Array.<google.cloud.dialogflow.v2beta1.IContext>|null} [outputContexts] WebhookResponse outputContexts
                         * @property {google.cloud.dialogflow.v2beta1.IEventInput|null} [followupEventInput] WebhookResponse followupEventInput
                         * @property {boolean|null} [liveAgentHandoff] WebhookResponse liveAgentHandoff
                         * @property {boolean|null} [endInteraction] WebhookResponse endInteraction
                         * @property {Array.<google.cloud.dialogflow.v2beta1.ISessionEntityType>|null} [sessionEntityTypes] WebhookResponse sessionEntityTypes
                         */
    
                        /**
                         * Constructs a new WebhookResponse.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents a WebhookResponse.
                         * @implements IWebhookResponse
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IWebhookResponse=} [properties] Properties to set
                         */
                        function WebhookResponse(properties) {
                            this.fulfillmentMessages = [];
                            this.outputContexts = [];
                            this.sessionEntityTypes = [];
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * WebhookResponse fulfillmentText.
                         * @member {string} fulfillmentText
                         * @memberof google.cloud.dialogflow.v2beta1.WebhookResponse
                         * @instance
                         */
                        WebhookResponse.prototype.fulfillmentText = "";
    
                        /**
                         * WebhookResponse fulfillmentMessages.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.Intent.IMessage>} fulfillmentMessages
                         * @memberof google.cloud.dialogflow.v2beta1.WebhookResponse
                         * @instance
                         */
                        WebhookResponse.prototype.fulfillmentMessages = $util.emptyArray;
    
                        /**
                         * WebhookResponse source.
                         * @member {string} source
                         * @memberof google.cloud.dialogflow.v2beta1.WebhookResponse
                         * @instance
                         */
                        WebhookResponse.prototype.source = "";
    
                        /**
                         * WebhookResponse payload.
                         * @member {google.protobuf.IStruct|null|undefined} payload
                         * @memberof google.cloud.dialogflow.v2beta1.WebhookResponse
                         * @instance
                         */
                        WebhookResponse.prototype.payload = null;
    
                        /**
                         * WebhookResponse outputContexts.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.IContext>} outputContexts
                         * @memberof google.cloud.dialogflow.v2beta1.WebhookResponse
                         * @instance
                         */
                        WebhookResponse.prototype.outputContexts = $util.emptyArray;
    
                        /**
                         * WebhookResponse followupEventInput.
                         * @member {google.cloud.dialogflow.v2beta1.IEventInput|null|undefined} followupEventInput
                         * @memberof google.cloud.dialogflow.v2beta1.WebhookResponse
                         * @instance
                         */
                        WebhookResponse.prototype.followupEventInput = null;
    
                        /**
                         * WebhookResponse liveAgentHandoff.
                         * @member {boolean} liveAgentHandoff
                         * @memberof google.cloud.dialogflow.v2beta1.WebhookResponse
                         * @instance
                         */
                        WebhookResponse.prototype.liveAgentHandoff = false;
    
                        /**
                         * WebhookResponse endInteraction.
                         * @member {boolean} endInteraction
                         * @memberof google.cloud.dialogflow.v2beta1.WebhookResponse
                         * @instance
                         */
                        WebhookResponse.prototype.endInteraction = false;
    
                        /**
                         * WebhookResponse sessionEntityTypes.
                         * @member {Array.<google.cloud.dialogflow.v2beta1.ISessionEntityType>} sessionEntityTypes
                         * @memberof google.cloud.dialogflow.v2beta1.WebhookResponse
                         * @instance
                         */
                        WebhookResponse.prototype.sessionEntityTypes = $util.emptyArray;
    
                        /**
                         * Creates a new WebhookResponse instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.WebhookResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IWebhookResponse=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.WebhookResponse} WebhookResponse instance
                         */
                        WebhookResponse.create = function create(properties) {
                            return new WebhookResponse(properties);
                        };
    
                        /**
                         * Encodes the specified WebhookResponse message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.WebhookResponse.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.WebhookResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IWebhookResponse} message WebhookResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        WebhookResponse.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.fulfillmentText != null && Object.hasOwnProperty.call(message, "fulfillmentText"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.fulfillmentText);
                            if (message.fulfillmentMessages != null && message.fulfillmentMessages.length)
                                for (var i = 0; i < message.fulfillmentMessages.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.Intent.Message.encode(message.fulfillmentMessages[i], writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                            if (message.source != null && Object.hasOwnProperty.call(message, "source"))
                                writer.uint32(/* id 3, wireType 2 =*/26).string(message.source);
                            if (message.payload != null && Object.hasOwnProperty.call(message, "payload"))
                                $root.google.protobuf.Struct.encode(message.payload, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                            if (message.outputContexts != null && message.outputContexts.length)
                                for (var i = 0; i < message.outputContexts.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.Context.encode(message.outputContexts[i], writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                            if (message.followupEventInput != null && Object.hasOwnProperty.call(message, "followupEventInput"))
                                $root.google.cloud.dialogflow.v2beta1.EventInput.encode(message.followupEventInput, writer.uint32(/* id 6, wireType 2 =*/50).fork()).ldelim();
                            if (message.liveAgentHandoff != null && Object.hasOwnProperty.call(message, "liveAgentHandoff"))
                                writer.uint32(/* id 7, wireType 0 =*/56).bool(message.liveAgentHandoff);
                            if (message.endInteraction != null && Object.hasOwnProperty.call(message, "endInteraction"))
                                writer.uint32(/* id 8, wireType 0 =*/64).bool(message.endInteraction);
                            if (message.sessionEntityTypes != null && message.sessionEntityTypes.length)
                                for (var i = 0; i < message.sessionEntityTypes.length; ++i)
                                    $root.google.cloud.dialogflow.v2beta1.SessionEntityType.encode(message.sessionEntityTypes[i], writer.uint32(/* id 10, wireType 2 =*/82).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified WebhookResponse message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.WebhookResponse.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.WebhookResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IWebhookResponse} message WebhookResponse message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        WebhookResponse.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes a WebhookResponse message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.WebhookResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.WebhookResponse} WebhookResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        WebhookResponse.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.WebhookResponse();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.fulfillmentText = reader.string();
                                        break;
                                    }
                                case 2: {
                                        if (!(message.fulfillmentMessages && message.fulfillmentMessages.length))
                                            message.fulfillmentMessages = [];
                                        message.fulfillmentMessages.push($root.google.cloud.dialogflow.v2beta1.Intent.Message.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 3: {
                                        message.source = reader.string();
                                        break;
                                    }
                                case 4: {
                                        message.payload = $root.google.protobuf.Struct.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 5: {
                                        if (!(message.outputContexts && message.outputContexts.length))
                                            message.outputContexts = [];
                                        message.outputContexts.push($root.google.cloud.dialogflow.v2beta1.Context.decode(reader, reader.uint32()));
                                        break;
                                    }
                                case 6: {
                                        message.followupEventInput = $root.google.cloud.dialogflow.v2beta1.EventInput.decode(reader, reader.uint32());
                                        break;
                                    }
                                case 7: {
                                        message.liveAgentHandoff = reader.bool();
                                        break;
                                    }
                                case 8: {
                                        message.endInteraction = reader.bool();
                                        break;
                                    }
                                case 10: {
                                        if (!(message.sessionEntityTypes && message.sessionEntityTypes.length))
                                            message.sessionEntityTypes = [];
                                        message.sessionEntityTypes.push($root.google.cloud.dialogflow.v2beta1.SessionEntityType.decode(reader, reader.uint32()));
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes a WebhookResponse message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.WebhookResponse
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.WebhookResponse} WebhookResponse
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        WebhookResponse.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies a WebhookResponse message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.WebhookResponse
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        WebhookResponse.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.fulfillmentText != null && message.hasOwnProperty("fulfillmentText"))
                                if (!$util.isString(message.fulfillmentText))
                                    return "fulfillmentText: string expected";
                            if (message.fulfillmentMessages != null && message.hasOwnProperty("fulfillmentMessages")) {
                                if (!Array.isArray(message.fulfillmentMessages))
                                    return "fulfillmentMessages: array expected";
                                for (var i = 0; i < message.fulfillmentMessages.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.Intent.Message.verify(message.fulfillmentMessages[i]);
                                    if (error)
                                        return "fulfillmentMessages." + error;
                                }
                            }
                            if (message.source != null && message.hasOwnProperty("source"))
                                if (!$util.isString(message.source))
                                    return "source: string expected";
                            if (message.payload != null && message.hasOwnProperty("payload")) {
                                var error = $root.google.protobuf.Struct.verify(message.payload);
                                if (error)
                                    return "payload." + error;
                            }
                            if (message.outputContexts != null && message.hasOwnProperty("outputContexts")) {
                                if (!Array.isArray(message.outputContexts))
                                    return "outputContexts: array expected";
                                for (var i = 0; i < message.outputContexts.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.Context.verify(message.outputContexts[i]);
                                    if (error)
                                        return "outputContexts." + error;
                                }
                            }
                            if (message.followupEventInput != null && message.hasOwnProperty("followupEventInput")) {
                                var error = $root.google.cloud.dialogflow.v2beta1.EventInput.verify(message.followupEventInput);
                                if (error)
                                    return "followupEventInput." + error;
                            }
                            if (message.liveAgentHandoff != null && message.hasOwnProperty("liveAgentHandoff"))
                                if (typeof message.liveAgentHandoff !== "boolean")
                                    return "liveAgentHandoff: boolean expected";
                            if (message.endInteraction != null && message.hasOwnProperty("endInteraction"))
                                if (typeof message.endInteraction !== "boolean")
                                    return "endInteraction: boolean expected";
                            if (message.sessionEntityTypes != null && message.hasOwnProperty("sessionEntityTypes")) {
                                if (!Array.isArray(message.sessionEntityTypes))
                                    return "sessionEntityTypes: array expected";
                                for (var i = 0; i < message.sessionEntityTypes.length; ++i) {
                                    var error = $root.google.cloud.dialogflow.v2beta1.SessionEntityType.verify(message.sessionEntityTypes[i]);
                                    if (error)
                                        return "sessionEntityTypes." + error;
                                }
                            }
                            return null;
                        };
    
                        /**
                         * Creates a WebhookResponse message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.WebhookResponse
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.WebhookResponse} WebhookResponse
                         */
                        WebhookResponse.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.WebhookResponse)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.WebhookResponse();
                            if (object.fulfillmentText != null)
                                message.fulfillmentText = String(object.fulfillmentText);
                            if (object.fulfillmentMessages) {
                                if (!Array.isArray(object.fulfillmentMessages))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.WebhookResponse.fulfillmentMessages: array expected");
                                message.fulfillmentMessages = [];
                                for (var i = 0; i < object.fulfillmentMessages.length; ++i) {
                                    if (typeof object.fulfillmentMessages[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.WebhookResponse.fulfillmentMessages: object expected");
                                    message.fulfillmentMessages[i] = $root.google.cloud.dialogflow.v2beta1.Intent.Message.fromObject(object.fulfillmentMessages[i]);
                                }
                            }
                            if (object.source != null)
                                message.source = String(object.source);
                            if (object.payload != null) {
                                if (typeof object.payload !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.WebhookResponse.payload: object expected");
                                message.payload = $root.google.protobuf.Struct.fromObject(object.payload);
                            }
                            if (object.outputContexts) {
                                if (!Array.isArray(object.outputContexts))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.WebhookResponse.outputContexts: array expected");
                                message.outputContexts = [];
                                for (var i = 0; i < object.outputContexts.length; ++i) {
                                    if (typeof object.outputContexts[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.WebhookResponse.outputContexts: object expected");
                                    message.outputContexts[i] = $root.google.cloud.dialogflow.v2beta1.Context.fromObject(object.outputContexts[i]);
                                }
                            }
                            if (object.followupEventInput != null) {
                                if (typeof object.followupEventInput !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.WebhookResponse.followupEventInput: object expected");
                                message.followupEventInput = $root.google.cloud.dialogflow.v2beta1.EventInput.fromObject(object.followupEventInput);
                            }
                            if (object.liveAgentHandoff != null)
                                message.liveAgentHandoff = Boolean(object.liveAgentHandoff);
                            if (object.endInteraction != null)
                                message.endInteraction = Boolean(object.endInteraction);
                            if (object.sessionEntityTypes) {
                                if (!Array.isArray(object.sessionEntityTypes))
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.WebhookResponse.sessionEntityTypes: array expected");
                                message.sessionEntityTypes = [];
                                for (var i = 0; i < object.sessionEntityTypes.length; ++i) {
                                    if (typeof object.sessionEntityTypes[i] !== "object")
                                        throw TypeError(".google.cloud.dialogflow.v2beta1.WebhookResponse.sessionEntityTypes: object expected");
                                    message.sessionEntityTypes[i] = $root.google.cloud.dialogflow.v2beta1.SessionEntityType.fromObject(object.sessionEntityTypes[i]);
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from a WebhookResponse message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.WebhookResponse
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.WebhookResponse} message WebhookResponse
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        WebhookResponse.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.arrays || options.defaults) {
                                object.fulfillmentMessages = [];
                                object.outputContexts = [];
                                object.sessionEntityTypes = [];
                            }
                            if (options.defaults) {
                                object.fulfillmentText = "";
                                object.source = "";
                                object.payload = null;
                                object.followupEventInput = null;
                                object.liveAgentHandoff = false;
                                object.endInteraction = false;
                            }
                            if (message.fulfillmentText != null && message.hasOwnProperty("fulfillmentText"))
                                object.fulfillmentText = message.fulfillmentText;
                            if (message.fulfillmentMessages && message.fulfillmentMessages.length) {
                                object.fulfillmentMessages = [];
                                for (var j = 0; j < message.fulfillmentMessages.length; ++j)
                                    object.fulfillmentMessages[j] = $root.google.cloud.dialogflow.v2beta1.Intent.Message.toObject(message.fulfillmentMessages[j], options);
                            }
                            if (message.source != null && message.hasOwnProperty("source"))
                                object.source = message.source;
                            if (message.payload != null && message.hasOwnProperty("payload"))
                                object.payload = $root.google.protobuf.Struct.toObject(message.payload, options);
                            if (message.outputContexts && message.outputContexts.length) {
                                object.outputContexts = [];
                                for (var j = 0; j < message.outputContexts.length; ++j)
                                    object.outputContexts[j] = $root.google.cloud.dialogflow.v2beta1.Context.toObject(message.outputContexts[j], options);
                            }
                            if (message.followupEventInput != null && message.hasOwnProperty("followupEventInput"))
                                object.followupEventInput = $root.google.cloud.dialogflow.v2beta1.EventInput.toObject(message.followupEventInput, options);
                            if (message.liveAgentHandoff != null && message.hasOwnProperty("liveAgentHandoff"))
                                object.liveAgentHandoff = message.liveAgentHandoff;
                            if (message.endInteraction != null && message.hasOwnProperty("endInteraction"))
                                object.endInteraction = message.endInteraction;
                            if (message.sessionEntityTypes && message.sessionEntityTypes.length) {
                                object.sessionEntityTypes = [];
                                for (var j = 0; j < message.sessionEntityTypes.length; ++j)
                                    object.sessionEntityTypes[j] = $root.google.cloud.dialogflow.v2beta1.SessionEntityType.toObject(message.sessionEntityTypes[j], options);
                            }
                            return object;
                        };
    
                        /**
                         * Converts this WebhookResponse to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.WebhookResponse
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        WebhookResponse.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for WebhookResponse
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.WebhookResponse
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        WebhookResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.WebhookResponse";
                        };
    
                        return WebhookResponse;
                    })();
    
                    v2beta1.OriginalDetectIntentRequest = (function() {
    
                        /**
                         * Properties of an OriginalDetectIntentRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @interface IOriginalDetectIntentRequest
                         * @property {string|null} [source] OriginalDetectIntentRequest source
                         * @property {string|null} [version] OriginalDetectIntentRequest version
                         * @property {google.protobuf.IStruct|null} [payload] OriginalDetectIntentRequest payload
                         */
    
                        /**
                         * Constructs a new OriginalDetectIntentRequest.
                         * @memberof google.cloud.dialogflow.v2beta1
                         * @classdesc Represents an OriginalDetectIntentRequest.
                         * @implements IOriginalDetectIntentRequest
                         * @constructor
                         * @param {google.cloud.dialogflow.v2beta1.IOriginalDetectIntentRequest=} [properties] Properties to set
                         */
                        function OriginalDetectIntentRequest(properties) {
                            if (properties)
                                for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                    if (properties[keys[i]] != null)
                                        this[keys[i]] = properties[keys[i]];
                        }
    
                        /**
                         * OriginalDetectIntentRequest source.
                         * @member {string} source
                         * @memberof google.cloud.dialogflow.v2beta1.OriginalDetectIntentRequest
                         * @instance
                         */
                        OriginalDetectIntentRequest.prototype.source = "";
    
                        /**
                         * OriginalDetectIntentRequest version.
                         * @member {string} version
                         * @memberof google.cloud.dialogflow.v2beta1.OriginalDetectIntentRequest
                         * @instance
                         */
                        OriginalDetectIntentRequest.prototype.version = "";
    
                        /**
                         * OriginalDetectIntentRequest payload.
                         * @member {google.protobuf.IStruct|null|undefined} payload
                         * @memberof google.cloud.dialogflow.v2beta1.OriginalDetectIntentRequest
                         * @instance
                         */
                        OriginalDetectIntentRequest.prototype.payload = null;
    
                        /**
                         * Creates a new OriginalDetectIntentRequest instance using the specified properties.
                         * @function create
                         * @memberof google.cloud.dialogflow.v2beta1.OriginalDetectIntentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IOriginalDetectIntentRequest=} [properties] Properties to set
                         * @returns {google.cloud.dialogflow.v2beta1.OriginalDetectIntentRequest} OriginalDetectIntentRequest instance
                         */
                        OriginalDetectIntentRequest.create = function create(properties) {
                            return new OriginalDetectIntentRequest(properties);
                        };
    
                        /**
                         * Encodes the specified OriginalDetectIntentRequest message. Does not implicitly {@link google.cloud.dialogflow.v2beta1.OriginalDetectIntentRequest.verify|verify} messages.
                         * @function encode
                         * @memberof google.cloud.dialogflow.v2beta1.OriginalDetectIntentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IOriginalDetectIntentRequest} message OriginalDetectIntentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        OriginalDetectIntentRequest.encode = function encode(message, writer) {
                            if (!writer)
                                writer = $Writer.create();
                            if (message.source != null && Object.hasOwnProperty.call(message, "source"))
                                writer.uint32(/* id 1, wireType 2 =*/10).string(message.source);
                            if (message.version != null && Object.hasOwnProperty.call(message, "version"))
                                writer.uint32(/* id 2, wireType 2 =*/18).string(message.version);
                            if (message.payload != null && Object.hasOwnProperty.call(message, "payload"))
                                $root.google.protobuf.Struct.encode(message.payload, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                            return writer;
                        };
    
                        /**
                         * Encodes the specified OriginalDetectIntentRequest message, length delimited. Does not implicitly {@link google.cloud.dialogflow.v2beta1.OriginalDetectIntentRequest.verify|verify} messages.
                         * @function encodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.OriginalDetectIntentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.IOriginalDetectIntentRequest} message OriginalDetectIntentRequest message or plain object to encode
                         * @param {$protobuf.Writer} [writer] Writer to encode to
                         * @returns {$protobuf.Writer} Writer
                         */
                        OriginalDetectIntentRequest.encodeDelimited = function encodeDelimited(message, writer) {
                            return this.encode(message, writer).ldelim();
                        };
    
                        /**
                         * Decodes an OriginalDetectIntentRequest message from the specified reader or buffer.
                         * @function decode
                         * @memberof google.cloud.dialogflow.v2beta1.OriginalDetectIntentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @param {number} [length] Message length if known beforehand
                         * @returns {google.cloud.dialogflow.v2beta1.OriginalDetectIntentRequest} OriginalDetectIntentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        OriginalDetectIntentRequest.decode = function decode(reader, length) {
                            if (!(reader instanceof $Reader))
                                reader = $Reader.create(reader);
                            var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.cloud.dialogflow.v2beta1.OriginalDetectIntentRequest();
                            while (reader.pos < end) {
                                var tag = reader.uint32();
                                switch (tag >>> 3) {
                                case 1: {
                                        message.source = reader.string();
                                        break;
                                    }
                                case 2: {
                                        message.version = reader.string();
                                        break;
                                    }
                                case 3: {
                                        message.payload = $root.google.protobuf.Struct.decode(reader, reader.uint32());
                                        break;
                                    }
                                default:
                                    reader.skipType(tag & 7);
                                    break;
                                }
                            }
                            return message;
                        };
    
                        /**
                         * Decodes an OriginalDetectIntentRequest message from the specified reader or buffer, length delimited.
                         * @function decodeDelimited
                         * @memberof google.cloud.dialogflow.v2beta1.OriginalDetectIntentRequest
                         * @static
                         * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                         * @returns {google.cloud.dialogflow.v2beta1.OriginalDetectIntentRequest} OriginalDetectIntentRequest
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        OriginalDetectIntentRequest.decodeDelimited = function decodeDelimited(reader) {
                            if (!(reader instanceof $Reader))
                                reader = new $Reader(reader);
                            return this.decode(reader, reader.uint32());
                        };
    
                        /**
                         * Verifies an OriginalDetectIntentRequest message.
                         * @function verify
                         * @memberof google.cloud.dialogflow.v2beta1.OriginalDetectIntentRequest
                         * @static
                         * @param {Object.<string,*>} message Plain object to verify
                         * @returns {string|null} `null` if valid, otherwise the reason why it is not
                         */
                        OriginalDetectIntentRequest.verify = function verify(message) {
                            if (typeof message !== "object" || message === null)
                                return "object expected";
                            if (message.source != null && message.hasOwnProperty("source"))
                                if (!$util.isString(message.source))
                                    return "source: string expected";
                            if (message.version != null && message.hasOwnProperty("version"))
                                if (!$util.isString(message.version))
                                    return "version: string expected";
                            if (message.payload != null && message.hasOwnProperty("payload")) {
                                var error = $root.google.protobuf.Struct.verify(message.payload);
                                if (error)
                                    return "payload." + error;
                            }
                            return null;
                        };
    
                        /**
                         * Creates an OriginalDetectIntentRequest message from a plain object. Also converts values to their respective internal types.
                         * @function fromObject
                         * @memberof google.cloud.dialogflow.v2beta1.OriginalDetectIntentRequest
                         * @static
                         * @param {Object.<string,*>} object Plain object
                         * @returns {google.cloud.dialogflow.v2beta1.OriginalDetectIntentRequest} OriginalDetectIntentRequest
                         */
                        OriginalDetectIntentRequest.fromObject = function fromObject(object) {
                            if (object instanceof $root.google.cloud.dialogflow.v2beta1.OriginalDetectIntentRequest)
                                return object;
                            var message = new $root.google.cloud.dialogflow.v2beta1.OriginalDetectIntentRequest();
                            if (object.source != null)
                                message.source = String(object.source);
                            if (object.version != null)
                                message.version = String(object.version);
                            if (object.payload != null) {
                                if (typeof object.payload !== "object")
                                    throw TypeError(".google.cloud.dialogflow.v2beta1.OriginalDetectIntentRequest.payload: object expected");
                                message.payload = $root.google.protobuf.Struct.fromObject(object.payload);
                            }
                            return message;
                        };
    
                        /**
                         * Creates a plain object from an OriginalDetectIntentRequest message. Also converts values to other types if specified.
                         * @function toObject
                         * @memberof google.cloud.dialogflow.v2beta1.OriginalDetectIntentRequest
                         * @static
                         * @param {google.cloud.dialogflow.v2beta1.OriginalDetectIntentRequest} message OriginalDetectIntentRequest
                         * @param {$protobuf.IConversionOptions} [options] Conversion options
                         * @returns {Object.<string,*>} Plain object
                         */
                        OriginalDetectIntentRequest.toObject = function toObject(message, options) {
                            if (!options)
                                options = {};
                            var object = {};
                            if (options.defaults) {
                                object.source = "";
                                object.version = "";
                                object.payload = null;
                            }
                            if (message.source != null && message.hasOwnProperty("source"))
                                object.source = message.source;
                            if (message.version != null && message.hasOwnProperty("version"))
                                object.version = message.version;
                            if (message.payload != null && message.hasOwnProperty("payload"))
                                object.payload = $root.google.protobuf.Struct.toObject(message.payload, options);
                            return object;
                        };
    
                        /**
                         * Converts this OriginalDetectIntentRequest to JSON.
                         * @function toJSON
                         * @memberof google.cloud.dialogflow.v2beta1.OriginalDetectIntentRequest
                         * @instance
                         * @returns {Object.<string,*>} JSON object
                         */
                        OriginalDetectIntentRequest.prototype.toJSON = function toJSON() {
                            return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                        };
    
                        /**
                         * Gets the default type url for OriginalDetectIntentRequest
                         * @function getTypeUrl
                         * @memberof google.cloud.dialogflow.v2beta1.OriginalDetectIntentRequest
                         * @static
                         * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns {string} The default type url
                         */
                        OriginalDetectIntentRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                            if (typeUrlPrefix === undefined) {
                                typeUrlPrefix = "type.googleapis.com";
                            }
                            return typeUrlPrefix + "/google.cloud.dialogflow.v2beta1.OriginalDetectIntentRequest";
                        };
    
                        return OriginalDetectIntentRequest;
                    })();
    
                    return v2beta1;
                })();
    
                return dialogflow;
            })();
    
            return cloud;
        })();
    
        google.api = (function() {
    
            /**
             * Namespace api.
             * @memberof google
             * @namespace
             */
            var api = {};
    
            api.Http = (function() {
    
                /**
                 * Properties of a Http.
                 * @memberof google.api
                 * @interface IHttp
                 * @property {Array.<google.api.IHttpRule>|null} [rules] Http rules
                 * @property {boolean|null} [fullyDecodeReservedExpansion] Http fullyDecodeReservedExpansion
                 */
    
                /**
                 * Constructs a new Http.
                 * @memberof google.api
                 * @classdesc Represents a Http.
                 * @implements IHttp
                 * @constructor
                 * @param {google.api.IHttp=} [properties] Properties to set
                 */
                function Http(properties) {
                    this.rules = [];
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * Http rules.
                 * @member {Array.<google.api.IHttpRule>} rules
                 * @memberof google.api.Http
                 * @instance
                 */
                Http.prototype.rules = $util.emptyArray;
    
                /**
                 * Http fullyDecodeReservedExpansion.
                 * @member {boolean} fullyDecodeReservedExpansion
                 * @memberof google.api.Http
                 * @instance
                 */
                Http.prototype.fullyDecodeReservedExpansion = false;
    
                /**
                 * Creates a new Http instance using the specified properties.
                 * @function create
                 * @memberof google.api.Http
                 * @static
                 * @param {google.api.IHttp=} [properties] Properties to set
                 * @returns {google.api.Http} Http instance
                 */
                Http.create = function create(properties) {
                    return new Http(properties);
                };
    
                /**
                 * Encodes the specified Http message. Does not implicitly {@link google.api.Http.verify|verify} messages.
                 * @function encode
                 * @memberof google.api.Http
                 * @static
                 * @param {google.api.IHttp} message Http message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                Http.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.rules != null && message.rules.length)
                        for (var i = 0; i < message.rules.length; ++i)
                            $root.google.api.HttpRule.encode(message.rules[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                    if (message.fullyDecodeReservedExpansion != null && Object.hasOwnProperty.call(message, "fullyDecodeReservedExpansion"))
                        writer.uint32(/* id 2, wireType 0 =*/16).bool(message.fullyDecodeReservedExpansion);
                    return writer;
                };
    
                /**
                 * Encodes the specified Http message, length delimited. Does not implicitly {@link google.api.Http.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.api.Http
                 * @static
                 * @param {google.api.IHttp} message Http message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                Http.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes a Http message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.api.Http
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.api.Http} Http
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                Http.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.api.Http();
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 1: {
                                if (!(message.rules && message.rules.length))
                                    message.rules = [];
                                message.rules.push($root.google.api.HttpRule.decode(reader, reader.uint32()));
                                break;
                            }
                        case 2: {
                                message.fullyDecodeReservedExpansion = reader.bool();
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes a Http message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.api.Http
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.api.Http} Http
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                Http.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies a Http message.
                 * @function verify
                 * @memberof google.api.Http
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                Http.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    if (message.rules != null && message.hasOwnProperty("rules")) {
                        if (!Array.isArray(message.rules))
                            return "rules: array expected";
                        for (var i = 0; i < message.rules.length; ++i) {
                            var error = $root.google.api.HttpRule.verify(message.rules[i]);
                            if (error)
                                return "rules." + error;
                        }
                    }
                    if (message.fullyDecodeReservedExpansion != null && message.hasOwnProperty("fullyDecodeReservedExpansion"))
                        if (typeof message.fullyDecodeReservedExpansion !== "boolean")
                            return "fullyDecodeReservedExpansion: boolean expected";
                    return null;
                };
    
                /**
                 * Creates a Http message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.api.Http
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.api.Http} Http
                 */
                Http.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.api.Http)
                        return object;
                    var message = new $root.google.api.Http();
                    if (object.rules) {
                        if (!Array.isArray(object.rules))
                            throw TypeError(".google.api.Http.rules: array expected");
                        message.rules = [];
                        for (var i = 0; i < object.rules.length; ++i) {
                            if (typeof object.rules[i] !== "object")
                                throw TypeError(".google.api.Http.rules: object expected");
                            message.rules[i] = $root.google.api.HttpRule.fromObject(object.rules[i]);
                        }
                    }
                    if (object.fullyDecodeReservedExpansion != null)
                        message.fullyDecodeReservedExpansion = Boolean(object.fullyDecodeReservedExpansion);
                    return message;
                };
    
                /**
                 * Creates a plain object from a Http message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.api.Http
                 * @static
                 * @param {google.api.Http} message Http
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                Http.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (options.arrays || options.defaults)
                        object.rules = [];
                    if (options.defaults)
                        object.fullyDecodeReservedExpansion = false;
                    if (message.rules && message.rules.length) {
                        object.rules = [];
                        for (var j = 0; j < message.rules.length; ++j)
                            object.rules[j] = $root.google.api.HttpRule.toObject(message.rules[j], options);
                    }
                    if (message.fullyDecodeReservedExpansion != null && message.hasOwnProperty("fullyDecodeReservedExpansion"))
                        object.fullyDecodeReservedExpansion = message.fullyDecodeReservedExpansion;
                    return object;
                };
    
                /**
                 * Converts this Http to JSON.
                 * @function toJSON
                 * @memberof google.api.Http
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                Http.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for Http
                 * @function getTypeUrl
                 * @memberof google.api.Http
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                Http.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.api.Http";
                };
    
                return Http;
            })();
    
            api.HttpRule = (function() {
    
                /**
                 * Properties of a HttpRule.
                 * @memberof google.api
                 * @interface IHttpRule
                 * @property {string|null} [selector] HttpRule selector
                 * @property {string|null} [get] HttpRule get
                 * @property {string|null} [put] HttpRule put
                 * @property {string|null} [post] HttpRule post
                 * @property {string|null} ["delete"] HttpRule delete
                 * @property {string|null} [patch] HttpRule patch
                 * @property {google.api.ICustomHttpPattern|null} [custom] HttpRule custom
                 * @property {string|null} [body] HttpRule body
                 * @property {string|null} [responseBody] HttpRule responseBody
                 * @property {Array.<google.api.IHttpRule>|null} [additionalBindings] HttpRule additionalBindings
                 */
    
                /**
                 * Constructs a new HttpRule.
                 * @memberof google.api
                 * @classdesc Represents a HttpRule.
                 * @implements IHttpRule
                 * @constructor
                 * @param {google.api.IHttpRule=} [properties] Properties to set
                 */
                function HttpRule(properties) {
                    this.additionalBindings = [];
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * HttpRule selector.
                 * @member {string} selector
                 * @memberof google.api.HttpRule
                 * @instance
                 */
                HttpRule.prototype.selector = "";
    
                /**
                 * HttpRule get.
                 * @member {string|null|undefined} get
                 * @memberof google.api.HttpRule
                 * @instance
                 */
                HttpRule.prototype.get = null;
    
                /**
                 * HttpRule put.
                 * @member {string|null|undefined} put
                 * @memberof google.api.HttpRule
                 * @instance
                 */
                HttpRule.prototype.put = null;
    
                /**
                 * HttpRule post.
                 * @member {string|null|undefined} post
                 * @memberof google.api.HttpRule
                 * @instance
                 */
                HttpRule.prototype.post = null;
    
                /**
                 * HttpRule delete.
                 * @member {string|null|undefined} delete
                 * @memberof google.api.HttpRule
                 * @instance
                 */
                HttpRule.prototype["delete"] = null;
    
                /**
                 * HttpRule patch.
                 * @member {string|null|undefined} patch
                 * @memberof google.api.HttpRule
                 * @instance
                 */
                HttpRule.prototype.patch = null;
    
                /**
                 * HttpRule custom.
                 * @member {google.api.ICustomHttpPattern|null|undefined} custom
                 * @memberof google.api.HttpRule
                 * @instance
                 */
                HttpRule.prototype.custom = null;
    
                /**
                 * HttpRule body.
                 * @member {string} body
                 * @memberof google.api.HttpRule
                 * @instance
                 */
                HttpRule.prototype.body = "";
    
                /**
                 * HttpRule responseBody.
                 * @member {string} responseBody
                 * @memberof google.api.HttpRule
                 * @instance
                 */
                HttpRule.prototype.responseBody = "";
    
                /**
                 * HttpRule additionalBindings.
                 * @member {Array.<google.api.IHttpRule>} additionalBindings
                 * @memberof google.api.HttpRule
                 * @instance
                 */
                HttpRule.prototype.additionalBindings = $util.emptyArray;
    
                // OneOf field names bound to virtual getters and setters
                var $oneOfFields;
    
                /**
                 * HttpRule pattern.
                 * @member {"get"|"put"|"post"|"delete"|"patch"|"custom"|undefined} pattern
                 * @memberof google.api.HttpRule
                 * @instance
                 */
                Object.defineProperty(HttpRule.prototype, "pattern", {
                    get: $util.oneOfGetter($oneOfFields = ["get", "put", "post", "delete", "patch", "custom"]),
                    set: $util.oneOfSetter($oneOfFields)
                });
    
                /**
                 * Creates a new HttpRule instance using the specified properties.
                 * @function create
                 * @memberof google.api.HttpRule
                 * @static
                 * @param {google.api.IHttpRule=} [properties] Properties to set
                 * @returns {google.api.HttpRule} HttpRule instance
                 */
                HttpRule.create = function create(properties) {
                    return new HttpRule(properties);
                };
    
                /**
                 * Encodes the specified HttpRule message. Does not implicitly {@link google.api.HttpRule.verify|verify} messages.
                 * @function encode
                 * @memberof google.api.HttpRule
                 * @static
                 * @param {google.api.IHttpRule} message HttpRule message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                HttpRule.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.selector != null && Object.hasOwnProperty.call(message, "selector"))
                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.selector);
                    if (message.get != null && Object.hasOwnProperty.call(message, "get"))
                        writer.uint32(/* id 2, wireType 2 =*/18).string(message.get);
                    if (message.put != null && Object.hasOwnProperty.call(message, "put"))
                        writer.uint32(/* id 3, wireType 2 =*/26).string(message.put);
                    if (message.post != null && Object.hasOwnProperty.call(message, "post"))
                        writer.uint32(/* id 4, wireType 2 =*/34).string(message.post);
                    if (message["delete"] != null && Object.hasOwnProperty.call(message, "delete"))
                        writer.uint32(/* id 5, wireType 2 =*/42).string(message["delete"]);
                    if (message.patch != null && Object.hasOwnProperty.call(message, "patch"))
                        writer.uint32(/* id 6, wireType 2 =*/50).string(message.patch);
                    if (message.body != null && Object.hasOwnProperty.call(message, "body"))
                        writer.uint32(/* id 7, wireType 2 =*/58).string(message.body);
                    if (message.custom != null && Object.hasOwnProperty.call(message, "custom"))
                        $root.google.api.CustomHttpPattern.encode(message.custom, writer.uint32(/* id 8, wireType 2 =*/66).fork()).ldelim();
                    if (message.additionalBindings != null && message.additionalBindings.length)
                        for (var i = 0; i < message.additionalBindings.length; ++i)
                            $root.google.api.HttpRule.encode(message.additionalBindings[i], writer.uint32(/* id 11, wireType 2 =*/90).fork()).ldelim();
                    if (message.responseBody != null && Object.hasOwnProperty.call(message, "responseBody"))
                        writer.uint32(/* id 12, wireType 2 =*/98).string(message.responseBody);
                    return writer;
                };
    
                /**
                 * Encodes the specified HttpRule message, length delimited. Does not implicitly {@link google.api.HttpRule.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.api.HttpRule
                 * @static
                 * @param {google.api.IHttpRule} message HttpRule message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                HttpRule.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes a HttpRule message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.api.HttpRule
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.api.HttpRule} HttpRule
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                HttpRule.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.api.HttpRule();
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 1: {
                                message.selector = reader.string();
                                break;
                            }
                        case 2: {
                                message.get = reader.string();
                                break;
                            }
                        case 3: {
                                message.put = reader.string();
                                break;
                            }
                        case 4: {
                                message.post = reader.string();
                                break;
                            }
                        case 5: {
                                message["delete"] = reader.string();
                                break;
                            }
                        case 6: {
                                message.patch = reader.string();
                                break;
                            }
                        case 8: {
                                message.custom = $root.google.api.CustomHttpPattern.decode(reader, reader.uint32());
                                break;
                            }
                        case 7: {
                                message.body = reader.string();
                                break;
                            }
                        case 12: {
                                message.responseBody = reader.string();
                                break;
                            }
                        case 11: {
                                if (!(message.additionalBindings && message.additionalBindings.length))
                                    message.additionalBindings = [];
                                message.additionalBindings.push($root.google.api.HttpRule.decode(reader, reader.uint32()));
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes a HttpRule message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.api.HttpRule
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.api.HttpRule} HttpRule
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                HttpRule.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies a HttpRule message.
                 * @function verify
                 * @memberof google.api.HttpRule
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                HttpRule.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    var properties = {};
                    if (message.selector != null && message.hasOwnProperty("selector"))
                        if (!$util.isString(message.selector))
                            return "selector: string expected";
                    if (message.get != null && message.hasOwnProperty("get")) {
                        properties.pattern = 1;
                        if (!$util.isString(message.get))
                            return "get: string expected";
                    }
                    if (message.put != null && message.hasOwnProperty("put")) {
                        if (properties.pattern === 1)
                            return "pattern: multiple values";
                        properties.pattern = 1;
                        if (!$util.isString(message.put))
                            return "put: string expected";
                    }
                    if (message.post != null && message.hasOwnProperty("post")) {
                        if (properties.pattern === 1)
                            return "pattern: multiple values";
                        properties.pattern = 1;
                        if (!$util.isString(message.post))
                            return "post: string expected";
                    }
                    if (message["delete"] != null && message.hasOwnProperty("delete")) {
                        if (properties.pattern === 1)
                            return "pattern: multiple values";
                        properties.pattern = 1;
                        if (!$util.isString(message["delete"]))
                            return "delete: string expected";
                    }
                    if (message.patch != null && message.hasOwnProperty("patch")) {
                        if (properties.pattern === 1)
                            return "pattern: multiple values";
                        properties.pattern = 1;
                        if (!$util.isString(message.patch))
                            return "patch: string expected";
                    }
                    if (message.custom != null && message.hasOwnProperty("custom")) {
                        if (properties.pattern === 1)
                            return "pattern: multiple values";
                        properties.pattern = 1;
                        {
                            var error = $root.google.api.CustomHttpPattern.verify(message.custom);
                            if (error)
                                return "custom." + error;
                        }
                    }
                    if (message.body != null && message.hasOwnProperty("body"))
                        if (!$util.isString(message.body))
                            return "body: string expected";
                    if (message.responseBody != null && message.hasOwnProperty("responseBody"))
                        if (!$util.isString(message.responseBody))
                            return "responseBody: string expected";
                    if (message.additionalBindings != null && message.hasOwnProperty("additionalBindings")) {
                        if (!Array.isArray(message.additionalBindings))
                            return "additionalBindings: array expected";
                        for (var i = 0; i < message.additionalBindings.length; ++i) {
                            var error = $root.google.api.HttpRule.verify(message.additionalBindings[i]);
                            if (error)
                                return "additionalBindings." + error;
                        }
                    }
                    return null;
                };
    
                /**
                 * Creates a HttpRule message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.api.HttpRule
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.api.HttpRule} HttpRule
                 */
                HttpRule.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.api.HttpRule)
                        return object;
                    var message = new $root.google.api.HttpRule();
                    if (object.selector != null)
                        message.selector = String(object.selector);
                    if (object.get != null)
                        message.get = String(object.get);
                    if (object.put != null)
                        message.put = String(object.put);
                    if (object.post != null)
                        message.post = String(object.post);
                    if (object["delete"] != null)
                        message["delete"] = String(object["delete"]);
                    if (object.patch != null)
                        message.patch = String(object.patch);
                    if (object.custom != null) {
                        if (typeof object.custom !== "object")
                            throw TypeError(".google.api.HttpRule.custom: object expected");
                        message.custom = $root.google.api.CustomHttpPattern.fromObject(object.custom);
                    }
                    if (object.body != null)
                        message.body = String(object.body);
                    if (object.responseBody != null)
                        message.responseBody = String(object.responseBody);
                    if (object.additionalBindings) {
                        if (!Array.isArray(object.additionalBindings))
                            throw TypeError(".google.api.HttpRule.additionalBindings: array expected");
                        message.additionalBindings = [];
                        for (var i = 0; i < object.additionalBindings.length; ++i) {
                            if (typeof object.additionalBindings[i] !== "object")
                                throw TypeError(".google.api.HttpRule.additionalBindings: object expected");
                            message.additionalBindings[i] = $root.google.api.HttpRule.fromObject(object.additionalBindings[i]);
                        }
                    }
                    return message;
                };
    
                /**
                 * Creates a plain object from a HttpRule message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.api.HttpRule
                 * @static
                 * @param {google.api.HttpRule} message HttpRule
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                HttpRule.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (options.arrays || options.defaults)
                        object.additionalBindings = [];
                    if (options.defaults) {
                        object.selector = "";
                        object.body = "";
                        object.responseBody = "";
                    }
                    if (message.selector != null && message.hasOwnProperty("selector"))
                        object.selector = message.selector;
                    if (message.get != null && message.hasOwnProperty("get")) {
                        object.get = message.get;
                        if (options.oneofs)
                            object.pattern = "get";
                    }
                    if (message.put != null && message.hasOwnProperty("put")) {
                        object.put = message.put;
                        if (options.oneofs)
                            object.pattern = "put";
                    }
                    if (message.post != null && message.hasOwnProperty("post")) {
                        object.post = message.post;
                        if (options.oneofs)
                            object.pattern = "post";
                    }
                    if (message["delete"] != null && message.hasOwnProperty("delete")) {
                        object["delete"] = message["delete"];
                        if (options.oneofs)
                            object.pattern = "delete";
                    }
                    if (message.patch != null && message.hasOwnProperty("patch")) {
                        object.patch = message.patch;
                        if (options.oneofs)
                            object.pattern = "patch";
                    }
                    if (message.body != null && message.hasOwnProperty("body"))
                        object.body = message.body;
                    if (message.custom != null && message.hasOwnProperty("custom")) {
                        object.custom = $root.google.api.CustomHttpPattern.toObject(message.custom, options);
                        if (options.oneofs)
                            object.pattern = "custom";
                    }
                    if (message.additionalBindings && message.additionalBindings.length) {
                        object.additionalBindings = [];
                        for (var j = 0; j < message.additionalBindings.length; ++j)
                            object.additionalBindings[j] = $root.google.api.HttpRule.toObject(message.additionalBindings[j], options);
                    }
                    if (message.responseBody != null && message.hasOwnProperty("responseBody"))
                        object.responseBody = message.responseBody;
                    return object;
                };
    
                /**
                 * Converts this HttpRule to JSON.
                 * @function toJSON
                 * @memberof google.api.HttpRule
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                HttpRule.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for HttpRule
                 * @function getTypeUrl
                 * @memberof google.api.HttpRule
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                HttpRule.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.api.HttpRule";
                };
    
                return HttpRule;
            })();
    
            api.CustomHttpPattern = (function() {
    
                /**
                 * Properties of a CustomHttpPattern.
                 * @memberof google.api
                 * @interface ICustomHttpPattern
                 * @property {string|null} [kind] CustomHttpPattern kind
                 * @property {string|null} [path] CustomHttpPattern path
                 */
    
                /**
                 * Constructs a new CustomHttpPattern.
                 * @memberof google.api
                 * @classdesc Represents a CustomHttpPattern.
                 * @implements ICustomHttpPattern
                 * @constructor
                 * @param {google.api.ICustomHttpPattern=} [properties] Properties to set
                 */
                function CustomHttpPattern(properties) {
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * CustomHttpPattern kind.
                 * @member {string} kind
                 * @memberof google.api.CustomHttpPattern
                 * @instance
                 */
                CustomHttpPattern.prototype.kind = "";
    
                /**
                 * CustomHttpPattern path.
                 * @member {string} path
                 * @memberof google.api.CustomHttpPattern
                 * @instance
                 */
                CustomHttpPattern.prototype.path = "";
    
                /**
                 * Creates a new CustomHttpPattern instance using the specified properties.
                 * @function create
                 * @memberof google.api.CustomHttpPattern
                 * @static
                 * @param {google.api.ICustomHttpPattern=} [properties] Properties to set
                 * @returns {google.api.CustomHttpPattern} CustomHttpPattern instance
                 */
                CustomHttpPattern.create = function create(properties) {
                    return new CustomHttpPattern(properties);
                };
    
                /**
                 * Encodes the specified CustomHttpPattern message. Does not implicitly {@link google.api.CustomHttpPattern.verify|verify} messages.
                 * @function encode
                 * @memberof google.api.CustomHttpPattern
                 * @static
                 * @param {google.api.ICustomHttpPattern} message CustomHttpPattern message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                CustomHttpPattern.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.kind != null && Object.hasOwnProperty.call(message, "kind"))
                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.kind);
                    if (message.path != null && Object.hasOwnProperty.call(message, "path"))
                        writer.uint32(/* id 2, wireType 2 =*/18).string(message.path);
                    return writer;
                };
    
                /**
                 * Encodes the specified CustomHttpPattern message, length delimited. Does not implicitly {@link google.api.CustomHttpPattern.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.api.CustomHttpPattern
                 * @static
                 * @param {google.api.ICustomHttpPattern} message CustomHttpPattern message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                CustomHttpPattern.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes a CustomHttpPattern message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.api.CustomHttpPattern
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.api.CustomHttpPattern} CustomHttpPattern
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                CustomHttpPattern.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.api.CustomHttpPattern();
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 1: {
                                message.kind = reader.string();
                                break;
                            }
                        case 2: {
                                message.path = reader.string();
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes a CustomHttpPattern message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.api.CustomHttpPattern
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.api.CustomHttpPattern} CustomHttpPattern
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                CustomHttpPattern.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies a CustomHttpPattern message.
                 * @function verify
                 * @memberof google.api.CustomHttpPattern
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                CustomHttpPattern.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    if (message.kind != null && message.hasOwnProperty("kind"))
                        if (!$util.isString(message.kind))
                            return "kind: string expected";
                    if (message.path != null && message.hasOwnProperty("path"))
                        if (!$util.isString(message.path))
                            return "path: string expected";
                    return null;
                };
    
                /**
                 * Creates a CustomHttpPattern message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.api.CustomHttpPattern
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.api.CustomHttpPattern} CustomHttpPattern
                 */
                CustomHttpPattern.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.api.CustomHttpPattern)
                        return object;
                    var message = new $root.google.api.CustomHttpPattern();
                    if (object.kind != null)
                        message.kind = String(object.kind);
                    if (object.path != null)
                        message.path = String(object.path);
                    return message;
                };
    
                /**
                 * Creates a plain object from a CustomHttpPattern message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.api.CustomHttpPattern
                 * @static
                 * @param {google.api.CustomHttpPattern} message CustomHttpPattern
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                CustomHttpPattern.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (options.defaults) {
                        object.kind = "";
                        object.path = "";
                    }
                    if (message.kind != null && message.hasOwnProperty("kind"))
                        object.kind = message.kind;
                    if (message.path != null && message.hasOwnProperty("path"))
                        object.path = message.path;
                    return object;
                };
    
                /**
                 * Converts this CustomHttpPattern to JSON.
                 * @function toJSON
                 * @memberof google.api.CustomHttpPattern
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                CustomHttpPattern.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for CustomHttpPattern
                 * @function getTypeUrl
                 * @memberof google.api.CustomHttpPattern
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                CustomHttpPattern.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.api.CustomHttpPattern";
                };
    
                return CustomHttpPattern;
            })();
    
            api.CommonLanguageSettings = (function() {
    
                /**
                 * Properties of a CommonLanguageSettings.
                 * @memberof google.api
                 * @interface ICommonLanguageSettings
                 * @property {string|null} [referenceDocsUri] CommonLanguageSettings referenceDocsUri
                 * @property {Array.<google.api.ClientLibraryDestination>|null} [destinations] CommonLanguageSettings destinations
                 */
    
                /**
                 * Constructs a new CommonLanguageSettings.
                 * @memberof google.api
                 * @classdesc Represents a CommonLanguageSettings.
                 * @implements ICommonLanguageSettings
                 * @constructor
                 * @param {google.api.ICommonLanguageSettings=} [properties] Properties to set
                 */
                function CommonLanguageSettings(properties) {
                    this.destinations = [];
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * CommonLanguageSettings referenceDocsUri.
                 * @member {string} referenceDocsUri
                 * @memberof google.api.CommonLanguageSettings
                 * @instance
                 */
                CommonLanguageSettings.prototype.referenceDocsUri = "";
    
                /**
                 * CommonLanguageSettings destinations.
                 * @member {Array.<google.api.ClientLibraryDestination>} destinations
                 * @memberof google.api.CommonLanguageSettings
                 * @instance
                 */
                CommonLanguageSettings.prototype.destinations = $util.emptyArray;
    
                /**
                 * Creates a new CommonLanguageSettings instance using the specified properties.
                 * @function create
                 * @memberof google.api.CommonLanguageSettings
                 * @static
                 * @param {google.api.ICommonLanguageSettings=} [properties] Properties to set
                 * @returns {google.api.CommonLanguageSettings} CommonLanguageSettings instance
                 */
                CommonLanguageSettings.create = function create(properties) {
                    return new CommonLanguageSettings(properties);
                };
    
                /**
                 * Encodes the specified CommonLanguageSettings message. Does not implicitly {@link google.api.CommonLanguageSettings.verify|verify} messages.
                 * @function encode
                 * @memberof google.api.CommonLanguageSettings
                 * @static
                 * @param {google.api.ICommonLanguageSettings} message CommonLanguageSettings message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                CommonLanguageSettings.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.referenceDocsUri != null && Object.hasOwnProperty.call(message, "referenceDocsUri"))
                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.referenceDocsUri);
                    if (message.destinations != null && message.destinations.length) {
                        writer.uint32(/* id 2, wireType 2 =*/18).fork();
                        for (var i = 0; i < message.destinations.length; ++i)
                            writer.int32(message.destinations[i]);
                        writer.ldelim();
                    }
                    return writer;
                };
    
                /**
                 * Encodes the specified CommonLanguageSettings message, length delimited. Does not implicitly {@link google.api.CommonLanguageSettings.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.api.CommonLanguageSettings
                 * @static
                 * @param {google.api.ICommonLanguageSettings} message CommonLanguageSettings message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                CommonLanguageSettings.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes a CommonLanguageSettings message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.api.CommonLanguageSettings
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.api.CommonLanguageSettings} CommonLanguageSettings
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                CommonLanguageSettings.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.api.CommonLanguageSettings();
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 1: {
                                message.referenceDocsUri = reader.string();
                                break;
                            }
                        case 2: {
                                if (!(message.destinations && message.destinations.length))
                                    message.destinations = [];
                                if ((tag & 7) === 2) {
                                    var end2 = reader.uint32() + reader.pos;
                                    while (reader.pos < end2)
                                        message.destinations.push(reader.int32());
                                } else
                                    message.destinations.push(reader.int32());
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes a CommonLanguageSettings message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.api.CommonLanguageSettings
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.api.CommonLanguageSettings} CommonLanguageSettings
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                CommonLanguageSettings.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies a CommonLanguageSettings message.
                 * @function verify
                 * @memberof google.api.CommonLanguageSettings
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                CommonLanguageSettings.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    if (message.referenceDocsUri != null && message.hasOwnProperty("referenceDocsUri"))
                        if (!$util.isString(message.referenceDocsUri))
                            return "referenceDocsUri: string expected";
                    if (message.destinations != null && message.hasOwnProperty("destinations")) {
                        if (!Array.isArray(message.destinations))
                            return "destinations: array expected";
                        for (var i = 0; i < message.destinations.length; ++i)
                            switch (message.destinations[i]) {
                            default:
                                return "destinations: enum value[] expected";
                            case 0:
                            case 10:
                            case 20:
                                break;
                            }
                    }
                    return null;
                };
    
                /**
                 * Creates a CommonLanguageSettings message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.api.CommonLanguageSettings
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.api.CommonLanguageSettings} CommonLanguageSettings
                 */
                CommonLanguageSettings.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.api.CommonLanguageSettings)
                        return object;
                    var message = new $root.google.api.CommonLanguageSettings();
                    if (object.referenceDocsUri != null)
                        message.referenceDocsUri = String(object.referenceDocsUri);
                    if (object.destinations) {
                        if (!Array.isArray(object.destinations))
                            throw TypeError(".google.api.CommonLanguageSettings.destinations: array expected");
                        message.destinations = [];
                        for (var i = 0; i < object.destinations.length; ++i)
                            switch (object.destinations[i]) {
                            default:
                                if (typeof object.destinations[i] === "number") {
                                    message.destinations[i] = object.destinations[i];
                                    break;
                                }
                            case "CLIENT_LIBRARY_DESTINATION_UNSPECIFIED":
                            case 0:
                                message.destinations[i] = 0;
                                break;
                            case "GITHUB":
                            case 10:
                                message.destinations[i] = 10;
                                break;
                            case "PACKAGE_MANAGER":
                            case 20:
                                message.destinations[i] = 20;
                                break;
                            }
                    }
                    return message;
                };
    
                /**
                 * Creates a plain object from a CommonLanguageSettings message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.api.CommonLanguageSettings
                 * @static
                 * @param {google.api.CommonLanguageSettings} message CommonLanguageSettings
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                CommonLanguageSettings.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (options.arrays || options.defaults)
                        object.destinations = [];
                    if (options.defaults)
                        object.referenceDocsUri = "";
                    if (message.referenceDocsUri != null && message.hasOwnProperty("referenceDocsUri"))
                        object.referenceDocsUri = message.referenceDocsUri;
                    if (message.destinations && message.destinations.length) {
                        object.destinations = [];
                        for (var j = 0; j < message.destinations.length; ++j)
                            object.destinations[j] = options.enums === String ? $root.google.api.ClientLibraryDestination[message.destinations[j]] === undefined ? message.destinations[j] : $root.google.api.ClientLibraryDestination[message.destinations[j]] : message.destinations[j];
                    }
                    return object;
                };
    
                /**
                 * Converts this CommonLanguageSettings to JSON.
                 * @function toJSON
                 * @memberof google.api.CommonLanguageSettings
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                CommonLanguageSettings.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for CommonLanguageSettings
                 * @function getTypeUrl
                 * @memberof google.api.CommonLanguageSettings
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                CommonLanguageSettings.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.api.CommonLanguageSettings";
                };
    
                return CommonLanguageSettings;
            })();
    
            api.ClientLibrarySettings = (function() {
    
                /**
                 * Properties of a ClientLibrarySettings.
                 * @memberof google.api
                 * @interface IClientLibrarySettings
                 * @property {string|null} [version] ClientLibrarySettings version
                 * @property {google.api.LaunchStage|null} [launchStage] ClientLibrarySettings launchStage
                 * @property {boolean|null} [restNumericEnums] ClientLibrarySettings restNumericEnums
                 * @property {google.api.IJavaSettings|null} [javaSettings] ClientLibrarySettings javaSettings
                 * @property {google.api.ICppSettings|null} [cppSettings] ClientLibrarySettings cppSettings
                 * @property {google.api.IPhpSettings|null} [phpSettings] ClientLibrarySettings phpSettings
                 * @property {google.api.IPythonSettings|null} [pythonSettings] ClientLibrarySettings pythonSettings
                 * @property {google.api.INodeSettings|null} [nodeSettings] ClientLibrarySettings nodeSettings
                 * @property {google.api.IDotnetSettings|null} [dotnetSettings] ClientLibrarySettings dotnetSettings
                 * @property {google.api.IRubySettings|null} [rubySettings] ClientLibrarySettings rubySettings
                 * @property {google.api.IGoSettings|null} [goSettings] ClientLibrarySettings goSettings
                 */
    
                /**
                 * Constructs a new ClientLibrarySettings.
                 * @memberof google.api
                 * @classdesc Represents a ClientLibrarySettings.
                 * @implements IClientLibrarySettings
                 * @constructor
                 * @param {google.api.IClientLibrarySettings=} [properties] Properties to set
                 */
                function ClientLibrarySettings(properties) {
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * ClientLibrarySettings version.
                 * @member {string} version
                 * @memberof google.api.ClientLibrarySettings
                 * @instance
                 */
                ClientLibrarySettings.prototype.version = "";
    
                /**
                 * ClientLibrarySettings launchStage.
                 * @member {google.api.LaunchStage} launchStage
                 * @memberof google.api.ClientLibrarySettings
                 * @instance
                 */
                ClientLibrarySettings.prototype.launchStage = 0;
    
                /**
                 * ClientLibrarySettings restNumericEnums.
                 * @member {boolean} restNumericEnums
                 * @memberof google.api.ClientLibrarySettings
                 * @instance
                 */
                ClientLibrarySettings.prototype.restNumericEnums = false;
    
                /**
                 * ClientLibrarySettings javaSettings.
                 * @member {google.api.IJavaSettings|null|undefined} javaSettings
                 * @memberof google.api.ClientLibrarySettings
                 * @instance
                 */
                ClientLibrarySettings.prototype.javaSettings = null;
    
                /**
                 * ClientLibrarySettings cppSettings.
                 * @member {google.api.ICppSettings|null|undefined} cppSettings
                 * @memberof google.api.ClientLibrarySettings
                 * @instance
                 */
                ClientLibrarySettings.prototype.cppSettings = null;
    
                /**
                 * ClientLibrarySettings phpSettings.
                 * @member {google.api.IPhpSettings|null|undefined} phpSettings
                 * @memberof google.api.ClientLibrarySettings
                 * @instance
                 */
                ClientLibrarySettings.prototype.phpSettings = null;
    
                /**
                 * ClientLibrarySettings pythonSettings.
                 * @member {google.api.IPythonSettings|null|undefined} pythonSettings
                 * @memberof google.api.ClientLibrarySettings
                 * @instance
                 */
                ClientLibrarySettings.prototype.pythonSettings = null;
    
                /**
                 * ClientLibrarySettings nodeSettings.
                 * @member {google.api.INodeSettings|null|undefined} nodeSettings
                 * @memberof google.api.ClientLibrarySettings
                 * @instance
                 */
                ClientLibrarySettings.prototype.nodeSettings = null;
    
                /**
                 * ClientLibrarySettings dotnetSettings.
                 * @member {google.api.IDotnetSettings|null|undefined} dotnetSettings
                 * @memberof google.api.ClientLibrarySettings
                 * @instance
                 */
                ClientLibrarySettings.prototype.dotnetSettings = null;
    
                /**
                 * ClientLibrarySettings rubySettings.
                 * @member {google.api.IRubySettings|null|undefined} rubySettings
                 * @memberof google.api.ClientLibrarySettings
                 * @instance
                 */
                ClientLibrarySettings.prototype.rubySettings = null;
    
                /**
                 * ClientLibrarySettings goSettings.
                 * @member {google.api.IGoSettings|null|undefined} goSettings
                 * @memberof google.api.ClientLibrarySettings
                 * @instance
                 */
                ClientLibrarySettings.prototype.goSettings = null;
    
                /**
                 * Creates a new ClientLibrarySettings instance using the specified properties.
                 * @function create
                 * @memberof google.api.ClientLibrarySettings
                 * @static
                 * @param {google.api.IClientLibrarySettings=} [properties] Properties to set
                 * @returns {google.api.ClientLibrarySettings} ClientLibrarySettings instance
                 */
                ClientLibrarySettings.create = function create(properties) {
                    return new ClientLibrarySettings(properties);
                };
    
                /**
                 * Encodes the specified ClientLibrarySettings message. Does not implicitly {@link google.api.ClientLibrarySettings.verify|verify} messages.
                 * @function encode
                 * @memberof google.api.ClientLibrarySettings
                 * @static
                 * @param {google.api.IClientLibrarySettings} message ClientLibrarySettings message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                ClientLibrarySettings.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.version != null && Object.hasOwnProperty.call(message, "version"))
                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.version);
                    if (message.launchStage != null && Object.hasOwnProperty.call(message, "launchStage"))
                        writer.uint32(/* id 2, wireType 0 =*/16).int32(message.launchStage);
                    if (message.restNumericEnums != null && Object.hasOwnProperty.call(message, "restNumericEnums"))
                        writer.uint32(/* id 3, wireType 0 =*/24).bool(message.restNumericEnums);
                    if (message.javaSettings != null && Object.hasOwnProperty.call(message, "javaSettings"))
                        $root.google.api.JavaSettings.encode(message.javaSettings, writer.uint32(/* id 21, wireType 2 =*/170).fork()).ldelim();
                    if (message.cppSettings != null && Object.hasOwnProperty.call(message, "cppSettings"))
                        $root.google.api.CppSettings.encode(message.cppSettings, writer.uint32(/* id 22, wireType 2 =*/178).fork()).ldelim();
                    if (message.phpSettings != null && Object.hasOwnProperty.call(message, "phpSettings"))
                        $root.google.api.PhpSettings.encode(message.phpSettings, writer.uint32(/* id 23, wireType 2 =*/186).fork()).ldelim();
                    if (message.pythonSettings != null && Object.hasOwnProperty.call(message, "pythonSettings"))
                        $root.google.api.PythonSettings.encode(message.pythonSettings, writer.uint32(/* id 24, wireType 2 =*/194).fork()).ldelim();
                    if (message.nodeSettings != null && Object.hasOwnProperty.call(message, "nodeSettings"))
                        $root.google.api.NodeSettings.encode(message.nodeSettings, writer.uint32(/* id 25, wireType 2 =*/202).fork()).ldelim();
                    if (message.dotnetSettings != null && Object.hasOwnProperty.call(message, "dotnetSettings"))
                        $root.google.api.DotnetSettings.encode(message.dotnetSettings, writer.uint32(/* id 26, wireType 2 =*/210).fork()).ldelim();
                    if (message.rubySettings != null && Object.hasOwnProperty.call(message, "rubySettings"))
                        $root.google.api.RubySettings.encode(message.rubySettings, writer.uint32(/* id 27, wireType 2 =*/218).fork()).ldelim();
                    if (message.goSettings != null && Object.hasOwnProperty.call(message, "goSettings"))
                        $root.google.api.GoSettings.encode(message.goSettings, writer.uint32(/* id 28, wireType 2 =*/226).fork()).ldelim();
                    return writer;
                };
    
                /**
                 * Encodes the specified ClientLibrarySettings message, length delimited. Does not implicitly {@link google.api.ClientLibrarySettings.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.api.ClientLibrarySettings
                 * @static
                 * @param {google.api.IClientLibrarySettings} message ClientLibrarySettings message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                ClientLibrarySettings.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes a ClientLibrarySettings message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.api.ClientLibrarySettings
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.api.ClientLibrarySettings} ClientLibrarySettings
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                ClientLibrarySettings.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.api.ClientLibrarySettings();
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 1: {
                                message.version = reader.string();
                                break;
                            }
                        case 2: {
                                message.launchStage = reader.int32();
                                break;
                            }
                        case 3: {
                                message.restNumericEnums = reader.bool();
                                break;
                            }
                        case 21: {
                                message.javaSettings = $root.google.api.JavaSettings.decode(reader, reader.uint32());
                                break;
                            }
                        case 22: {
                                message.cppSettings = $root.google.api.CppSettings.decode(reader, reader.uint32());
                                break;
                            }
                        case 23: {
                                message.phpSettings = $root.google.api.PhpSettings.decode(reader, reader.uint32());
                                break;
                            }
                        case 24: {
                                message.pythonSettings = $root.google.api.PythonSettings.decode(reader, reader.uint32());
                                break;
                            }
                        case 25: {
                                message.nodeSettings = $root.google.api.NodeSettings.decode(reader, reader.uint32());
                                break;
                            }
                        case 26: {
                                message.dotnetSettings = $root.google.api.DotnetSettings.decode(reader, reader.uint32());
                                break;
                            }
                        case 27: {
                                message.rubySettings = $root.google.api.RubySettings.decode(reader, reader.uint32());
                                break;
                            }
                        case 28: {
                                message.goSettings = $root.google.api.GoSettings.decode(reader, reader.uint32());
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes a ClientLibrarySettings message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.api.ClientLibrarySettings
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.api.ClientLibrarySettings} ClientLibrarySettings
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                ClientLibrarySettings.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies a ClientLibrarySettings message.
                 * @function verify
                 * @memberof google.api.ClientLibrarySettings
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                ClientLibrarySettings.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    if (message.version != null && message.hasOwnProperty("version"))
                        if (!$util.isString(message.version))
                            return "version: string expected";
                    if (message.launchStage != null && message.hasOwnProperty("launchStage"))
                        switch (message.launchStage) {
                        default:
                            return "launchStage: enum value expected";
                        case 0:
                        case 6:
                        case 7:
                        case 1:
                        case 2:
                        case 3:
                        case 4:
                        case 5:
                            break;
                        }
                    if (message.restNumericEnums != null && message.hasOwnProperty("restNumericEnums"))
                        if (typeof message.restNumericEnums !== "boolean")
                            return "restNumericEnums: boolean expected";
                    if (message.javaSettings != null && message.hasOwnProperty("javaSettings")) {
                        var error = $root.google.api.JavaSettings.verify(message.javaSettings);
                        if (error)
                            return "javaSettings." + error;
                    }
                    if (message.cppSettings != null && message.hasOwnProperty("cppSettings")) {
                        var error = $root.google.api.CppSettings.verify(message.cppSettings);
                        if (error)
                            return "cppSettings." + error;
                    }
                    if (message.phpSettings != null && message.hasOwnProperty("phpSettings")) {
                        var error = $root.google.api.PhpSettings.verify(message.phpSettings);
                        if (error)
                            return "phpSettings." + error;
                    }
                    if (message.pythonSettings != null && message.hasOwnProperty("pythonSettings")) {
                        var error = $root.google.api.PythonSettings.verify(message.pythonSettings);
                        if (error)
                            return "pythonSettings." + error;
                    }
                    if (message.nodeSettings != null && message.hasOwnProperty("nodeSettings")) {
                        var error = $root.google.api.NodeSettings.verify(message.nodeSettings);
                        if (error)
                            return "nodeSettings." + error;
                    }
                    if (message.dotnetSettings != null && message.hasOwnProperty("dotnetSettings")) {
                        var error = $root.google.api.DotnetSettings.verify(message.dotnetSettings);
                        if (error)
                            return "dotnetSettings." + error;
                    }
                    if (message.rubySettings != null && message.hasOwnProperty("rubySettings")) {
                        var error = $root.google.api.RubySettings.verify(message.rubySettings);
                        if (error)
                            return "rubySettings." + error;
                    }
                    if (message.goSettings != null && message.hasOwnProperty("goSettings")) {
                        var error = $root.google.api.GoSettings.verify(message.goSettings);
                        if (error)
                            return "goSettings." + error;
                    }
                    return null;
                };
    
                /**
                 * Creates a ClientLibrarySettings message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.api.ClientLibrarySettings
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.api.ClientLibrarySettings} ClientLibrarySettings
                 */
                ClientLibrarySettings.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.api.ClientLibrarySettings)
                        return object;
                    var message = new $root.google.api.ClientLibrarySettings();
                    if (object.version != null)
                        message.version = String(object.version);
                    switch (object.launchStage) {
                    default:
                        if (typeof object.launchStage === "number") {
                            message.launchStage = object.launchStage;
                            break;
                        }
                        break;
                    case "LAUNCH_STAGE_UNSPECIFIED":
                    case 0:
                        message.launchStage = 0;
                        break;
                    case "UNIMPLEMENTED":
                    case 6:
                        message.launchStage = 6;
                        break;
                    case "PRELAUNCH":
                    case 7:
                        message.launchStage = 7;
                        break;
                    case "EARLY_ACCESS":
                    case 1:
                        message.launchStage = 1;
                        break;
                    case "ALPHA":
                    case 2:
                        message.launchStage = 2;
                        break;
                    case "BETA":
                    case 3:
                        message.launchStage = 3;
                        break;
                    case "GA":
                    case 4:
                        message.launchStage = 4;
                        break;
                    case "DEPRECATED":
                    case 5:
                        message.launchStage = 5;
                        break;
                    }
                    if (object.restNumericEnums != null)
                        message.restNumericEnums = Boolean(object.restNumericEnums);
                    if (object.javaSettings != null) {
                        if (typeof object.javaSettings !== "object")
                            throw TypeError(".google.api.ClientLibrarySettings.javaSettings: object expected");
                        message.javaSettings = $root.google.api.JavaSettings.fromObject(object.javaSettings);
                    }
                    if (object.cppSettings != null) {
                        if (typeof object.cppSettings !== "object")
                            throw TypeError(".google.api.ClientLibrarySettings.cppSettings: object expected");
                        message.cppSettings = $root.google.api.CppSettings.fromObject(object.cppSettings);
                    }
                    if (object.phpSettings != null) {
                        if (typeof object.phpSettings !== "object")
                            throw TypeError(".google.api.ClientLibrarySettings.phpSettings: object expected");
                        message.phpSettings = $root.google.api.PhpSettings.fromObject(object.phpSettings);
                    }
                    if (object.pythonSettings != null) {
                        if (typeof object.pythonSettings !== "object")
                            throw TypeError(".google.api.ClientLibrarySettings.pythonSettings: object expected");
                        message.pythonSettings = $root.google.api.PythonSettings.fromObject(object.pythonSettings);
                    }
                    if (object.nodeSettings != null) {
                        if (typeof object.nodeSettings !== "object")
                            throw TypeError(".google.api.ClientLibrarySettings.nodeSettings: object expected");
                        message.nodeSettings = $root.google.api.NodeSettings.fromObject(object.nodeSettings);
                    }
                    if (object.dotnetSettings != null) {
                        if (typeof object.dotnetSettings !== "object")
                            throw TypeError(".google.api.ClientLibrarySettings.dotnetSettings: object expected");
                        message.dotnetSettings = $root.google.api.DotnetSettings.fromObject(object.dotnetSettings);
                    }
                    if (object.rubySettings != null) {
                        if (typeof object.rubySettings !== "object")
                            throw TypeError(".google.api.ClientLibrarySettings.rubySettings: object expected");
                        message.rubySettings = $root.google.api.RubySettings.fromObject(object.rubySettings);
                    }
                    if (object.goSettings != null) {
                        if (typeof object.goSettings !== "object")
                            throw TypeError(".google.api.ClientLibrarySettings.goSettings: object expected");
                        message.goSettings = $root.google.api.GoSettings.fromObject(object.goSettings);
                    }
                    return message;
                };
    
                /**
                 * Creates a plain object from a ClientLibrarySettings message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.api.ClientLibrarySettings
                 * @static
                 * @param {google.api.ClientLibrarySettings} message ClientLibrarySettings
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                ClientLibrarySettings.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (options.defaults) {
                        object.version = "";
                        object.launchStage = options.enums === String ? "LAUNCH_STAGE_UNSPECIFIED" : 0;
                        object.restNumericEnums = false;
                        object.javaSettings = null;
                        object.cppSettings = null;
                        object.phpSettings = null;
                        object.pythonSettings = null;
                        object.nodeSettings = null;
                        object.dotnetSettings = null;
                        object.rubySettings = null;
                        object.goSettings = null;
                    }
                    if (message.version != null && message.hasOwnProperty("version"))
                        object.version = message.version;
                    if (message.launchStage != null && message.hasOwnProperty("launchStage"))
                        object.launchStage = options.enums === String ? $root.google.api.LaunchStage[message.launchStage] === undefined ? message.launchStage : $root.google.api.LaunchStage[message.launchStage] : message.launchStage;
                    if (message.restNumericEnums != null && message.hasOwnProperty("restNumericEnums"))
                        object.restNumericEnums = message.restNumericEnums;
                    if (message.javaSettings != null && message.hasOwnProperty("javaSettings"))
                        object.javaSettings = $root.google.api.JavaSettings.toObject(message.javaSettings, options);
                    if (message.cppSettings != null && message.hasOwnProperty("cppSettings"))
                        object.cppSettings = $root.google.api.CppSettings.toObject(message.cppSettings, options);
                    if (message.phpSettings != null && message.hasOwnProperty("phpSettings"))
                        object.phpSettings = $root.google.api.PhpSettings.toObject(message.phpSettings, options);
                    if (message.pythonSettings != null && message.hasOwnProperty("pythonSettings"))
                        object.pythonSettings = $root.google.api.PythonSettings.toObject(message.pythonSettings, options);
                    if (message.nodeSettings != null && message.hasOwnProperty("nodeSettings"))
                        object.nodeSettings = $root.google.api.NodeSettings.toObject(message.nodeSettings, options);
                    if (message.dotnetSettings != null && message.hasOwnProperty("dotnetSettings"))
                        object.dotnetSettings = $root.google.api.DotnetSettings.toObject(message.dotnetSettings, options);
                    if (message.rubySettings != null && message.hasOwnProperty("rubySettings"))
                        object.rubySettings = $root.google.api.RubySettings.toObject(message.rubySettings, options);
                    if (message.goSettings != null && message.hasOwnProperty("goSettings"))
                        object.goSettings = $root.google.api.GoSettings.toObject(message.goSettings, options);
                    return object;
                };
    
                /**
                 * Converts this ClientLibrarySettings to JSON.
                 * @function toJSON
                 * @memberof google.api.ClientLibrarySettings
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                ClientLibrarySettings.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for ClientLibrarySettings
                 * @function getTypeUrl
                 * @memberof google.api.ClientLibrarySettings
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                ClientLibrarySettings.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.api.ClientLibrarySettings";
                };
    
                return ClientLibrarySettings;
            })();
    
            api.Publishing = (function() {
    
                /**
                 * Properties of a Publishing.
                 * @memberof google.api
                 * @interface IPublishing
                 * @property {Array.<google.api.IMethodSettings>|null} [methodSettings] Publishing methodSettings
                 * @property {string|null} [newIssueUri] Publishing newIssueUri
                 * @property {string|null} [documentationUri] Publishing documentationUri
                 * @property {string|null} [apiShortName] Publishing apiShortName
                 * @property {string|null} [githubLabel] Publishing githubLabel
                 * @property {Array.<string>|null} [codeownerGithubTeams] Publishing codeownerGithubTeams
                 * @property {string|null} [docTagPrefix] Publishing docTagPrefix
                 * @property {google.api.ClientLibraryOrganization|null} [organization] Publishing organization
                 * @property {Array.<google.api.IClientLibrarySettings>|null} [librarySettings] Publishing librarySettings
                 * @property {string|null} [protoReferenceDocumentationUri] Publishing protoReferenceDocumentationUri
                 */
    
                /**
                 * Constructs a new Publishing.
                 * @memberof google.api
                 * @classdesc Represents a Publishing.
                 * @implements IPublishing
                 * @constructor
                 * @param {google.api.IPublishing=} [properties] Properties to set
                 */
                function Publishing(properties) {
                    this.methodSettings = [];
                    this.codeownerGithubTeams = [];
                    this.librarySettings = [];
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * Publishing methodSettings.
                 * @member {Array.<google.api.IMethodSettings>} methodSettings
                 * @memberof google.api.Publishing
                 * @instance
                 */
                Publishing.prototype.methodSettings = $util.emptyArray;
    
                /**
                 * Publishing newIssueUri.
                 * @member {string} newIssueUri
                 * @memberof google.api.Publishing
                 * @instance
                 */
                Publishing.prototype.newIssueUri = "";
    
                /**
                 * Publishing documentationUri.
                 * @member {string} documentationUri
                 * @memberof google.api.Publishing
                 * @instance
                 */
                Publishing.prototype.documentationUri = "";
    
                /**
                 * Publishing apiShortName.
                 * @member {string} apiShortName
                 * @memberof google.api.Publishing
                 * @instance
                 */
                Publishing.prototype.apiShortName = "";
    
                /**
                 * Publishing githubLabel.
                 * @member {string} githubLabel
                 * @memberof google.api.Publishing
                 * @instance
                 */
                Publishing.prototype.githubLabel = "";
    
                /**
                 * Publishing codeownerGithubTeams.
                 * @member {Array.<string>} codeownerGithubTeams
                 * @memberof google.api.Publishing
                 * @instance
                 */
                Publishing.prototype.codeownerGithubTeams = $util.emptyArray;
    
                /**
                 * Publishing docTagPrefix.
                 * @member {string} docTagPrefix
                 * @memberof google.api.Publishing
                 * @instance
                 */
                Publishing.prototype.docTagPrefix = "";
    
                /**
                 * Publishing organization.
                 * @member {google.api.ClientLibraryOrganization} organization
                 * @memberof google.api.Publishing
                 * @instance
                 */
                Publishing.prototype.organization = 0;
    
                /**
                 * Publishing librarySettings.
                 * @member {Array.<google.api.IClientLibrarySettings>} librarySettings
                 * @memberof google.api.Publishing
                 * @instance
                 */
                Publishing.prototype.librarySettings = $util.emptyArray;
    
                /**
                 * Publishing protoReferenceDocumentationUri.
                 * @member {string} protoReferenceDocumentationUri
                 * @memberof google.api.Publishing
                 * @instance
                 */
                Publishing.prototype.protoReferenceDocumentationUri = "";
    
                /**
                 * Creates a new Publishing instance using the specified properties.
                 * @function create
                 * @memberof google.api.Publishing
                 * @static
                 * @param {google.api.IPublishing=} [properties] Properties to set
                 * @returns {google.api.Publishing} Publishing instance
                 */
                Publishing.create = function create(properties) {
                    return new Publishing(properties);
                };
    
                /**
                 * Encodes the specified Publishing message. Does not implicitly {@link google.api.Publishing.verify|verify} messages.
                 * @function encode
                 * @memberof google.api.Publishing
                 * @static
                 * @param {google.api.IPublishing} message Publishing message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                Publishing.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.methodSettings != null && message.methodSettings.length)
                        for (var i = 0; i < message.methodSettings.length; ++i)
                            $root.google.api.MethodSettings.encode(message.methodSettings[i], writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                    if (message.newIssueUri != null && Object.hasOwnProperty.call(message, "newIssueUri"))
                        writer.uint32(/* id 101, wireType 2 =*/810).string(message.newIssueUri);
                    if (message.documentationUri != null && Object.hasOwnProperty.call(message, "documentationUri"))
                        writer.uint32(/* id 102, wireType 2 =*/818).string(message.documentationUri);
                    if (message.apiShortName != null && Object.hasOwnProperty.call(message, "apiShortName"))
                        writer.uint32(/* id 103, wireType 2 =*/826).string(message.apiShortName);
                    if (message.githubLabel != null && Object.hasOwnProperty.call(message, "githubLabel"))
                        writer.uint32(/* id 104, wireType 2 =*/834).string(message.githubLabel);
                    if (message.codeownerGithubTeams != null && message.codeownerGithubTeams.length)
                        for (var i = 0; i < message.codeownerGithubTeams.length; ++i)
                            writer.uint32(/* id 105, wireType 2 =*/842).string(message.codeownerGithubTeams[i]);
                    if (message.docTagPrefix != null && Object.hasOwnProperty.call(message, "docTagPrefix"))
                        writer.uint32(/* id 106, wireType 2 =*/850).string(message.docTagPrefix);
                    if (message.organization != null && Object.hasOwnProperty.call(message, "organization"))
                        writer.uint32(/* id 107, wireType 0 =*/856).int32(message.organization);
                    if (message.librarySettings != null && message.librarySettings.length)
                        for (var i = 0; i < message.librarySettings.length; ++i)
                            $root.google.api.ClientLibrarySettings.encode(message.librarySettings[i], writer.uint32(/* id 109, wireType 2 =*/874).fork()).ldelim();
                    if (message.protoReferenceDocumentationUri != null && Object.hasOwnProperty.call(message, "protoReferenceDocumentationUri"))
                        writer.uint32(/* id 110, wireType 2 =*/882).string(message.protoReferenceDocumentationUri);
                    return writer;
                };
    
                /**
                 * Encodes the specified Publishing message, length delimited. Does not implicitly {@link google.api.Publishing.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.api.Publishing
                 * @static
                 * @param {google.api.IPublishing} message Publishing message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                Publishing.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes a Publishing message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.api.Publishing
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.api.Publishing} Publishing
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                Publishing.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.api.Publishing();
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 2: {
                                if (!(message.methodSettings && message.methodSettings.length))
                                    message.methodSettings = [];
                                message.methodSettings.push($root.google.api.MethodSettings.decode(reader, reader.uint32()));
                                break;
                            }
                        case 101: {
                                message.newIssueUri = reader.string();
                                break;
                            }
                        case 102: {
                                message.documentationUri = reader.string();
                                break;
                            }
                        case 103: {
                                message.apiShortName = reader.string();
                                break;
                            }
                        case 104: {
                                message.githubLabel = reader.string();
                                break;
                            }
                        case 105: {
                                if (!(message.codeownerGithubTeams && message.codeownerGithubTeams.length))
                                    message.codeownerGithubTeams = [];
                                message.codeownerGithubTeams.push(reader.string());
                                break;
                            }
                        case 106: {
                                message.docTagPrefix = reader.string();
                                break;
                            }
                        case 107: {
                                message.organization = reader.int32();
                                break;
                            }
                        case 109: {
                                if (!(message.librarySettings && message.librarySettings.length))
                                    message.librarySettings = [];
                                message.librarySettings.push($root.google.api.ClientLibrarySettings.decode(reader, reader.uint32()));
                                break;
                            }
                        case 110: {
                                message.protoReferenceDocumentationUri = reader.string();
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes a Publishing message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.api.Publishing
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.api.Publishing} Publishing
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                Publishing.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies a Publishing message.
                 * @function verify
                 * @memberof google.api.Publishing
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                Publishing.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    if (message.methodSettings != null && message.hasOwnProperty("methodSettings")) {
                        if (!Array.isArray(message.methodSettings))
                            return "methodSettings: array expected";
                        for (var i = 0; i < message.methodSettings.length; ++i) {
                            var error = $root.google.api.MethodSettings.verify(message.methodSettings[i]);
                            if (error)
                                return "methodSettings." + error;
                        }
                    }
                    if (message.newIssueUri != null && message.hasOwnProperty("newIssueUri"))
                        if (!$util.isString(message.newIssueUri))
                            return "newIssueUri: string expected";
                    if (message.documentationUri != null && message.hasOwnProperty("documentationUri"))
                        if (!$util.isString(message.documentationUri))
                            return "documentationUri: string expected";
                    if (message.apiShortName != null && message.hasOwnProperty("apiShortName"))
                        if (!$util.isString(message.apiShortName))
                            return "apiShortName: string expected";
                    if (message.githubLabel != null && message.hasOwnProperty("githubLabel"))
                        if (!$util.isString(message.githubLabel))
                            return "githubLabel: string expected";
                    if (message.codeownerGithubTeams != null && message.hasOwnProperty("codeownerGithubTeams")) {
                        if (!Array.isArray(message.codeownerGithubTeams))
                            return "codeownerGithubTeams: array expected";
                        for (var i = 0; i < message.codeownerGithubTeams.length; ++i)
                            if (!$util.isString(message.codeownerGithubTeams[i]))
                                return "codeownerGithubTeams: string[] expected";
                    }
                    if (message.docTagPrefix != null && message.hasOwnProperty("docTagPrefix"))
                        if (!$util.isString(message.docTagPrefix))
                            return "docTagPrefix: string expected";
                    if (message.organization != null && message.hasOwnProperty("organization"))
                        switch (message.organization) {
                        default:
                            return "organization: enum value expected";
                        case 0:
                        case 1:
                        case 2:
                        case 3:
                        case 4:
                        case 5:
                        case 6:
                        case 7:
                            break;
                        }
                    if (message.librarySettings != null && message.hasOwnProperty("librarySettings")) {
                        if (!Array.isArray(message.librarySettings))
                            return "librarySettings: array expected";
                        for (var i = 0; i < message.librarySettings.length; ++i) {
                            var error = $root.google.api.ClientLibrarySettings.verify(message.librarySettings[i]);
                            if (error)
                                return "librarySettings." + error;
                        }
                    }
                    if (message.protoReferenceDocumentationUri != null && message.hasOwnProperty("protoReferenceDocumentationUri"))
                        if (!$util.isString(message.protoReferenceDocumentationUri))
                            return "protoReferenceDocumentationUri: string expected";
                    return null;
                };
    
                /**
                 * Creates a Publishing message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.api.Publishing
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.api.Publishing} Publishing
                 */
                Publishing.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.api.Publishing)
                        return object;
                    var message = new $root.google.api.Publishing();
                    if (object.methodSettings) {
                        if (!Array.isArray(object.methodSettings))
                            throw TypeError(".google.api.Publishing.methodSettings: array expected");
                        message.methodSettings = [];
                        for (var i = 0; i < object.methodSettings.length; ++i) {
                            if (typeof object.methodSettings[i] !== "object")
                                throw TypeError(".google.api.Publishing.methodSettings: object expected");
                            message.methodSettings[i] = $root.google.api.MethodSettings.fromObject(object.methodSettings[i]);
                        }
                    }
                    if (object.newIssueUri != null)
                        message.newIssueUri = String(object.newIssueUri);
                    if (object.documentationUri != null)
                        message.documentationUri = String(object.documentationUri);
                    if (object.apiShortName != null)
                        message.apiShortName = String(object.apiShortName);
                    if (object.githubLabel != null)
                        message.githubLabel = String(object.githubLabel);
                    if (object.codeownerGithubTeams) {
                        if (!Array.isArray(object.codeownerGithubTeams))
                            throw TypeError(".google.api.Publishing.codeownerGithubTeams: array expected");
                        message.codeownerGithubTeams = [];
                        for (var i = 0; i < object.codeownerGithubTeams.length; ++i)
                            message.codeownerGithubTeams[i] = String(object.codeownerGithubTeams[i]);
                    }
                    if (object.docTagPrefix != null)
                        message.docTagPrefix = String(object.docTagPrefix);
                    switch (object.organization) {
                    default:
                        if (typeof object.organization === "number") {
                            message.organization = object.organization;
                            break;
                        }
                        break;
                    case "CLIENT_LIBRARY_ORGANIZATION_UNSPECIFIED":
                    case 0:
                        message.organization = 0;
                        break;
                    case "CLOUD":
                    case 1:
                        message.organization = 1;
                        break;
                    case "ADS":
                    case 2:
                        message.organization = 2;
                        break;
                    case "PHOTOS":
                    case 3:
                        message.organization = 3;
                        break;
                    case "STREET_VIEW":
                    case 4:
                        message.organization = 4;
                        break;
                    case "SHOPPING":
                    case 5:
                        message.organization = 5;
                        break;
                    case "GEO":
                    case 6:
                        message.organization = 6;
                        break;
                    case "GENERATIVE_AI":
                    case 7:
                        message.organization = 7;
                        break;
                    }
                    if (object.librarySettings) {
                        if (!Array.isArray(object.librarySettings))
                            throw TypeError(".google.api.Publishing.librarySettings: array expected");
                        message.librarySettings = [];
                        for (var i = 0; i < object.librarySettings.length; ++i) {
                            if (typeof object.librarySettings[i] !== "object")
                                throw TypeError(".google.api.Publishing.librarySettings: object expected");
                            message.librarySettings[i] = $root.google.api.ClientLibrarySettings.fromObject(object.librarySettings[i]);
                        }
                    }
                    if (object.protoReferenceDocumentationUri != null)
                        message.protoReferenceDocumentationUri = String(object.protoReferenceDocumentationUri);
                    return message;
                };
    
                /**
                 * Creates a plain object from a Publishing message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.api.Publishing
                 * @static
                 * @param {google.api.Publishing} message Publishing
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                Publishing.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (options.arrays || options.defaults) {
                        object.methodSettings = [];
                        object.codeownerGithubTeams = [];
                        object.librarySettings = [];
                    }
                    if (options.defaults) {
                        object.newIssueUri = "";
                        object.documentationUri = "";
                        object.apiShortName = "";
                        object.githubLabel = "";
                        object.docTagPrefix = "";
                        object.organization = options.enums === String ? "CLIENT_LIBRARY_ORGANIZATION_UNSPECIFIED" : 0;
                        object.protoReferenceDocumentationUri = "";
                    }
                    if (message.methodSettings && message.methodSettings.length) {
                        object.methodSettings = [];
                        for (var j = 0; j < message.methodSettings.length; ++j)
                            object.methodSettings[j] = $root.google.api.MethodSettings.toObject(message.methodSettings[j], options);
                    }
                    if (message.newIssueUri != null && message.hasOwnProperty("newIssueUri"))
                        object.newIssueUri = message.newIssueUri;
                    if (message.documentationUri != null && message.hasOwnProperty("documentationUri"))
                        object.documentationUri = message.documentationUri;
                    if (message.apiShortName != null && message.hasOwnProperty("apiShortName"))
                        object.apiShortName = message.apiShortName;
                    if (message.githubLabel != null && message.hasOwnProperty("githubLabel"))
                        object.githubLabel = message.githubLabel;
                    if (message.codeownerGithubTeams && message.codeownerGithubTeams.length) {
                        object.codeownerGithubTeams = [];
                        for (var j = 0; j < message.codeownerGithubTeams.length; ++j)
                            object.codeownerGithubTeams[j] = message.codeownerGithubTeams[j];
                    }
                    if (message.docTagPrefix != null && message.hasOwnProperty("docTagPrefix"))
                        object.docTagPrefix = message.docTagPrefix;
                    if (message.organization != null && message.hasOwnProperty("organization"))
                        object.organization = options.enums === String ? $root.google.api.ClientLibraryOrganization[message.organization] === undefined ? message.organization : $root.google.api.ClientLibraryOrganization[message.organization] : message.organization;
                    if (message.librarySettings && message.librarySettings.length) {
                        object.librarySettings = [];
                        for (var j = 0; j < message.librarySettings.length; ++j)
                            object.librarySettings[j] = $root.google.api.ClientLibrarySettings.toObject(message.librarySettings[j], options);
                    }
                    if (message.protoReferenceDocumentationUri != null && message.hasOwnProperty("protoReferenceDocumentationUri"))
                        object.protoReferenceDocumentationUri = message.protoReferenceDocumentationUri;
                    return object;
                };
    
                /**
                 * Converts this Publishing to JSON.
                 * @function toJSON
                 * @memberof google.api.Publishing
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                Publishing.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for Publishing
                 * @function getTypeUrl
                 * @memberof google.api.Publishing
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                Publishing.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.api.Publishing";
                };
    
                return Publishing;
            })();
    
            api.JavaSettings = (function() {
    
                /**
                 * Properties of a JavaSettings.
                 * @memberof google.api
                 * @interface IJavaSettings
                 * @property {string|null} [libraryPackage] JavaSettings libraryPackage
                 * @property {Object.<string,string>|null} [serviceClassNames] JavaSettings serviceClassNames
                 * @property {google.api.ICommonLanguageSettings|null} [common] JavaSettings common
                 */
    
                /**
                 * Constructs a new JavaSettings.
                 * @memberof google.api
                 * @classdesc Represents a JavaSettings.
                 * @implements IJavaSettings
                 * @constructor
                 * @param {google.api.IJavaSettings=} [properties] Properties to set
                 */
                function JavaSettings(properties) {
                    this.serviceClassNames = {};
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * JavaSettings libraryPackage.
                 * @member {string} libraryPackage
                 * @memberof google.api.JavaSettings
                 * @instance
                 */
                JavaSettings.prototype.libraryPackage = "";
    
                /**
                 * JavaSettings serviceClassNames.
                 * @member {Object.<string,string>} serviceClassNames
                 * @memberof google.api.JavaSettings
                 * @instance
                 */
                JavaSettings.prototype.serviceClassNames = $util.emptyObject;
    
                /**
                 * JavaSettings common.
                 * @member {google.api.ICommonLanguageSettings|null|undefined} common
                 * @memberof google.api.JavaSettings
                 * @instance
                 */
                JavaSettings.prototype.common = null;
    
                /**
                 * Creates a new JavaSettings instance using the specified properties.
                 * @function create
                 * @memberof google.api.JavaSettings
                 * @static
                 * @param {google.api.IJavaSettings=} [properties] Properties to set
                 * @returns {google.api.JavaSettings} JavaSettings instance
                 */
                JavaSettings.create = function create(properties) {
                    return new JavaSettings(properties);
                };
    
                /**
                 * Encodes the specified JavaSettings message. Does not implicitly {@link google.api.JavaSettings.verify|verify} messages.
                 * @function encode
                 * @memberof google.api.JavaSettings
                 * @static
                 * @param {google.api.IJavaSettings} message JavaSettings message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                JavaSettings.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.libraryPackage != null && Object.hasOwnProperty.call(message, "libraryPackage"))
                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.libraryPackage);
                    if (message.serviceClassNames != null && Object.hasOwnProperty.call(message, "serviceClassNames"))
                        for (var keys = Object.keys(message.serviceClassNames), i = 0; i < keys.length; ++i)
                            writer.uint32(/* id 2, wireType 2 =*/18).fork().uint32(/* id 1, wireType 2 =*/10).string(keys[i]).uint32(/* id 2, wireType 2 =*/18).string(message.serviceClassNames[keys[i]]).ldelim();
                    if (message.common != null && Object.hasOwnProperty.call(message, "common"))
                        $root.google.api.CommonLanguageSettings.encode(message.common, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                    return writer;
                };
    
                /**
                 * Encodes the specified JavaSettings message, length delimited. Does not implicitly {@link google.api.JavaSettings.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.api.JavaSettings
                 * @static
                 * @param {google.api.IJavaSettings} message JavaSettings message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                JavaSettings.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes a JavaSettings message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.api.JavaSettings
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.api.JavaSettings} JavaSettings
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                JavaSettings.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.api.JavaSettings(), key, value;
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 1: {
                                message.libraryPackage = reader.string();
                                break;
                            }
                        case 2: {
                                if (message.serviceClassNames === $util.emptyObject)
                                    message.serviceClassNames = {};
                                var end2 = reader.uint32() + reader.pos;
                                key = "";
                                value = "";
                                while (reader.pos < end2) {
                                    var tag2 = reader.uint32();
                                    switch (tag2 >>> 3) {
                                    case 1:
                                        key = reader.string();
                                        break;
                                    case 2:
                                        value = reader.string();
                                        break;
                                    default:
                                        reader.skipType(tag2 & 7);
                                        break;
                                    }
                                }
                                message.serviceClassNames[key] = value;
                                break;
                            }
                        case 3: {
                                message.common = $root.google.api.CommonLanguageSettings.decode(reader, reader.uint32());
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes a JavaSettings message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.api.JavaSettings
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.api.JavaSettings} JavaSettings
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                JavaSettings.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies a JavaSettings message.
                 * @function verify
                 * @memberof google.api.JavaSettings
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                JavaSettings.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    if (message.libraryPackage != null && message.hasOwnProperty("libraryPackage"))
                        if (!$util.isString(message.libraryPackage))
                            return "libraryPackage: string expected";
                    if (message.serviceClassNames != null && message.hasOwnProperty("serviceClassNames")) {
                        if (!$util.isObject(message.serviceClassNames))
                            return "serviceClassNames: object expected";
                        var key = Object.keys(message.serviceClassNames);
                        for (var i = 0; i < key.length; ++i)
                            if (!$util.isString(message.serviceClassNames[key[i]]))
                                return "serviceClassNames: string{k:string} expected";
                    }
                    if (message.common != null && message.hasOwnProperty("common")) {
                        var error = $root.google.api.CommonLanguageSettings.verify(message.common);
                        if (error)
                            return "common." + error;
                    }
                    return null;
                };
    
                /**
                 * Creates a JavaSettings message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.api.JavaSettings
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.api.JavaSettings} JavaSettings
                 */
                JavaSettings.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.api.JavaSettings)
                        return object;
                    var message = new $root.google.api.JavaSettings();
                    if (object.libraryPackage != null)
                        message.libraryPackage = String(object.libraryPackage);
                    if (object.serviceClassNames) {
                        if (typeof object.serviceClassNames !== "object")
                            throw TypeError(".google.api.JavaSettings.serviceClassNames: object expected");
                        message.serviceClassNames = {};
                        for (var keys = Object.keys(object.serviceClassNames), i = 0; i < keys.length; ++i)
                            message.serviceClassNames[keys[i]] = String(object.serviceClassNames[keys[i]]);
                    }
                    if (object.common != null) {
                        if (typeof object.common !== "object")
                            throw TypeError(".google.api.JavaSettings.common: object expected");
                        message.common = $root.google.api.CommonLanguageSettings.fromObject(object.common);
                    }
                    return message;
                };
    
                /**
                 * Creates a plain object from a JavaSettings message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.api.JavaSettings
                 * @static
                 * @param {google.api.JavaSettings} message JavaSettings
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                JavaSettings.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (options.objects || options.defaults)
                        object.serviceClassNames = {};
                    if (options.defaults) {
                        object.libraryPackage = "";
                        object.common = null;
                    }
                    if (message.libraryPackage != null && message.hasOwnProperty("libraryPackage"))
                        object.libraryPackage = message.libraryPackage;
                    var keys2;
                    if (message.serviceClassNames && (keys2 = Object.keys(message.serviceClassNames)).length) {
                        object.serviceClassNames = {};
                        for (var j = 0; j < keys2.length; ++j)
                            object.serviceClassNames[keys2[j]] = message.serviceClassNames[keys2[j]];
                    }
                    if (message.common != null && message.hasOwnProperty("common"))
                        object.common = $root.google.api.CommonLanguageSettings.toObject(message.common, options);
                    return object;
                };
    
                /**
                 * Converts this JavaSettings to JSON.
                 * @function toJSON
                 * @memberof google.api.JavaSettings
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                JavaSettings.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for JavaSettings
                 * @function getTypeUrl
                 * @memberof google.api.JavaSettings
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                JavaSettings.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.api.JavaSettings";
                };
    
                return JavaSettings;
            })();
    
            api.CppSettings = (function() {
    
                /**
                 * Properties of a CppSettings.
                 * @memberof google.api
                 * @interface ICppSettings
                 * @property {google.api.ICommonLanguageSettings|null} [common] CppSettings common
                 */
    
                /**
                 * Constructs a new CppSettings.
                 * @memberof google.api
                 * @classdesc Represents a CppSettings.
                 * @implements ICppSettings
                 * @constructor
                 * @param {google.api.ICppSettings=} [properties] Properties to set
                 */
                function CppSettings(properties) {
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * CppSettings common.
                 * @member {google.api.ICommonLanguageSettings|null|undefined} common
                 * @memberof google.api.CppSettings
                 * @instance
                 */
                CppSettings.prototype.common = null;
    
                /**
                 * Creates a new CppSettings instance using the specified properties.
                 * @function create
                 * @memberof google.api.CppSettings
                 * @static
                 * @param {google.api.ICppSettings=} [properties] Properties to set
                 * @returns {google.api.CppSettings} CppSettings instance
                 */
                CppSettings.create = function create(properties) {
                    return new CppSettings(properties);
                };
    
                /**
                 * Encodes the specified CppSettings message. Does not implicitly {@link google.api.CppSettings.verify|verify} messages.
                 * @function encode
                 * @memberof google.api.CppSettings
                 * @static
                 * @param {google.api.ICppSettings} message CppSettings message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                CppSettings.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.common != null && Object.hasOwnProperty.call(message, "common"))
                        $root.google.api.CommonLanguageSettings.encode(message.common, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                    return writer;
                };
    
                /**
                 * Encodes the specified CppSettings message, length delimited. Does not implicitly {@link google.api.CppSettings.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.api.CppSettings
                 * @static
                 * @param {google.api.ICppSettings} message CppSettings message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                CppSettings.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes a CppSettings message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.api.CppSettings
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.api.CppSettings} CppSettings
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                CppSettings.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.api.CppSettings();
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 1: {
                                message.common = $root.google.api.CommonLanguageSettings.decode(reader, reader.uint32());
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes a CppSettings message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.api.CppSettings
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.api.CppSettings} CppSettings
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                CppSettings.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies a CppSettings message.
                 * @function verify
                 * @memberof google.api.CppSettings
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                CppSettings.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    if (message.common != null && message.hasOwnProperty("common")) {
                        var error = $root.google.api.CommonLanguageSettings.verify(message.common);
                        if (error)
                            return "common." + error;
                    }
                    return null;
                };
    
                /**
                 * Creates a CppSettings message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.api.CppSettings
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.api.CppSettings} CppSettings
                 */
                CppSettings.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.api.CppSettings)
                        return object;
                    var message = new $root.google.api.CppSettings();
                    if (object.common != null) {
                        if (typeof object.common !== "object")
                            throw TypeError(".google.api.CppSettings.common: object expected");
                        message.common = $root.google.api.CommonLanguageSettings.fromObject(object.common);
                    }
                    return message;
                };
    
                /**
                 * Creates a plain object from a CppSettings message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.api.CppSettings
                 * @static
                 * @param {google.api.CppSettings} message CppSettings
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                CppSettings.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (options.defaults)
                        object.common = null;
                    if (message.common != null && message.hasOwnProperty("common"))
                        object.common = $root.google.api.CommonLanguageSettings.toObject(message.common, options);
                    return object;
                };
    
                /**
                 * Converts this CppSettings to JSON.
                 * @function toJSON
                 * @memberof google.api.CppSettings
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                CppSettings.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for CppSettings
                 * @function getTypeUrl
                 * @memberof google.api.CppSettings
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                CppSettings.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.api.CppSettings";
                };
    
                return CppSettings;
            })();
    
            api.PhpSettings = (function() {
    
                /**
                 * Properties of a PhpSettings.
                 * @memberof google.api
                 * @interface IPhpSettings
                 * @property {google.api.ICommonLanguageSettings|null} [common] PhpSettings common
                 */
    
                /**
                 * Constructs a new PhpSettings.
                 * @memberof google.api
                 * @classdesc Represents a PhpSettings.
                 * @implements IPhpSettings
                 * @constructor
                 * @param {google.api.IPhpSettings=} [properties] Properties to set
                 */
                function PhpSettings(properties) {
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * PhpSettings common.
                 * @member {google.api.ICommonLanguageSettings|null|undefined} common
                 * @memberof google.api.PhpSettings
                 * @instance
                 */
                PhpSettings.prototype.common = null;
    
                /**
                 * Creates a new PhpSettings instance using the specified properties.
                 * @function create
                 * @memberof google.api.PhpSettings
                 * @static
                 * @param {google.api.IPhpSettings=} [properties] Properties to set
                 * @returns {google.api.PhpSettings} PhpSettings instance
                 */
                PhpSettings.create = function create(properties) {
                    return new PhpSettings(properties);
                };
    
                /**
                 * Encodes the specified PhpSettings message. Does not implicitly {@link google.api.PhpSettings.verify|verify} messages.
                 * @function encode
                 * @memberof google.api.PhpSettings
                 * @static
                 * @param {google.api.IPhpSettings} message PhpSettings message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                PhpSettings.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.common != null && Object.hasOwnProperty.call(message, "common"))
                        $root.google.api.CommonLanguageSettings.encode(message.common, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                    return writer;
                };
    
                /**
                 * Encodes the specified PhpSettings message, length delimited. Does not implicitly {@link google.api.PhpSettings.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.api.PhpSettings
                 * @static
                 * @param {google.api.IPhpSettings} message PhpSettings message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                PhpSettings.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes a PhpSettings message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.api.PhpSettings
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.api.PhpSettings} PhpSettings
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                PhpSettings.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.api.PhpSettings();
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 1: {
                                message.common = $root.google.api.CommonLanguageSettings.decode(reader, reader.uint32());
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes a PhpSettings message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.api.PhpSettings
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.api.PhpSettings} PhpSettings
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                PhpSettings.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies a PhpSettings message.
                 * @function verify
                 * @memberof google.api.PhpSettings
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                PhpSettings.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    if (message.common != null && message.hasOwnProperty("common")) {
                        var error = $root.google.api.CommonLanguageSettings.verify(message.common);
                        if (error)
                            return "common." + error;
                    }
                    return null;
                };
    
                /**
                 * Creates a PhpSettings message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.api.PhpSettings
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.api.PhpSettings} PhpSettings
                 */
                PhpSettings.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.api.PhpSettings)
                        return object;
                    var message = new $root.google.api.PhpSettings();
                    if (object.common != null) {
                        if (typeof object.common !== "object")
                            throw TypeError(".google.api.PhpSettings.common: object expected");
                        message.common = $root.google.api.CommonLanguageSettings.fromObject(object.common);
                    }
                    return message;
                };
    
                /**
                 * Creates a plain object from a PhpSettings message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.api.PhpSettings
                 * @static
                 * @param {google.api.PhpSettings} message PhpSettings
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                PhpSettings.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (options.defaults)
                        object.common = null;
                    if (message.common != null && message.hasOwnProperty("common"))
                        object.common = $root.google.api.CommonLanguageSettings.toObject(message.common, options);
                    return object;
                };
    
                /**
                 * Converts this PhpSettings to JSON.
                 * @function toJSON
                 * @memberof google.api.PhpSettings
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                PhpSettings.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for PhpSettings
                 * @function getTypeUrl
                 * @memberof google.api.PhpSettings
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                PhpSettings.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.api.PhpSettings";
                };
    
                return PhpSettings;
            })();
    
            api.PythonSettings = (function() {
    
                /**
                 * Properties of a PythonSettings.
                 * @memberof google.api
                 * @interface IPythonSettings
                 * @property {google.api.ICommonLanguageSettings|null} [common] PythonSettings common
                 */
    
                /**
                 * Constructs a new PythonSettings.
                 * @memberof google.api
                 * @classdesc Represents a PythonSettings.
                 * @implements IPythonSettings
                 * @constructor
                 * @param {google.api.IPythonSettings=} [properties] Properties to set
                 */
                function PythonSettings(properties) {
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * PythonSettings common.
                 * @member {google.api.ICommonLanguageSettings|null|undefined} common
                 * @memberof google.api.PythonSettings
                 * @instance
                 */
                PythonSettings.prototype.common = null;
    
                /**
                 * Creates a new PythonSettings instance using the specified properties.
                 * @function create
                 * @memberof google.api.PythonSettings
                 * @static
                 * @param {google.api.IPythonSettings=} [properties] Properties to set
                 * @returns {google.api.PythonSettings} PythonSettings instance
                 */
                PythonSettings.create = function create(properties) {
                    return new PythonSettings(properties);
                };
    
                /**
                 * Encodes the specified PythonSettings message. Does not implicitly {@link google.api.PythonSettings.verify|verify} messages.
                 * @function encode
                 * @memberof google.api.PythonSettings
                 * @static
                 * @param {google.api.IPythonSettings} message PythonSettings message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                PythonSettings.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.common != null && Object.hasOwnProperty.call(message, "common"))
                        $root.google.api.CommonLanguageSettings.encode(message.common, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                    return writer;
                };
    
                /**
                 * Encodes the specified PythonSettings message, length delimited. Does not implicitly {@link google.api.PythonSettings.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.api.PythonSettings
                 * @static
                 * @param {google.api.IPythonSettings} message PythonSettings message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                PythonSettings.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes a PythonSettings message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.api.PythonSettings
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.api.PythonSettings} PythonSettings
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                PythonSettings.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.api.PythonSettings();
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 1: {
                                message.common = $root.google.api.CommonLanguageSettings.decode(reader, reader.uint32());
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes a PythonSettings message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.api.PythonSettings
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.api.PythonSettings} PythonSettings
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                PythonSettings.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies a PythonSettings message.
                 * @function verify
                 * @memberof google.api.PythonSettings
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                PythonSettings.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    if (message.common != null && message.hasOwnProperty("common")) {
                        var error = $root.google.api.CommonLanguageSettings.verify(message.common);
                        if (error)
                            return "common." + error;
                    }
                    return null;
                };
    
                /**
                 * Creates a PythonSettings message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.api.PythonSettings
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.api.PythonSettings} PythonSettings
                 */
                PythonSettings.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.api.PythonSettings)
                        return object;
                    var message = new $root.google.api.PythonSettings();
                    if (object.common != null) {
                        if (typeof object.common !== "object")
                            throw TypeError(".google.api.PythonSettings.common: object expected");
                        message.common = $root.google.api.CommonLanguageSettings.fromObject(object.common);
                    }
                    return message;
                };
    
                /**
                 * Creates a plain object from a PythonSettings message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.api.PythonSettings
                 * @static
                 * @param {google.api.PythonSettings} message PythonSettings
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                PythonSettings.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (options.defaults)
                        object.common = null;
                    if (message.common != null && message.hasOwnProperty("common"))
                        object.common = $root.google.api.CommonLanguageSettings.toObject(message.common, options);
                    return object;
                };
    
                /**
                 * Converts this PythonSettings to JSON.
                 * @function toJSON
                 * @memberof google.api.PythonSettings
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                PythonSettings.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for PythonSettings
                 * @function getTypeUrl
                 * @memberof google.api.PythonSettings
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                PythonSettings.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.api.PythonSettings";
                };
    
                return PythonSettings;
            })();
    
            api.NodeSettings = (function() {
    
                /**
                 * Properties of a NodeSettings.
                 * @memberof google.api
                 * @interface INodeSettings
                 * @property {google.api.ICommonLanguageSettings|null} [common] NodeSettings common
                 */
    
                /**
                 * Constructs a new NodeSettings.
                 * @memberof google.api
                 * @classdesc Represents a NodeSettings.
                 * @implements INodeSettings
                 * @constructor
                 * @param {google.api.INodeSettings=} [properties] Properties to set
                 */
                function NodeSettings(properties) {
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * NodeSettings common.
                 * @member {google.api.ICommonLanguageSettings|null|undefined} common
                 * @memberof google.api.NodeSettings
                 * @instance
                 */
                NodeSettings.prototype.common = null;
    
                /**
                 * Creates a new NodeSettings instance using the specified properties.
                 * @function create
                 * @memberof google.api.NodeSettings
                 * @static
                 * @param {google.api.INodeSettings=} [properties] Properties to set
                 * @returns {google.api.NodeSettings} NodeSettings instance
                 */
                NodeSettings.create = function create(properties) {
                    return new NodeSettings(properties);
                };
    
                /**
                 * Encodes the specified NodeSettings message. Does not implicitly {@link google.api.NodeSettings.verify|verify} messages.
                 * @function encode
                 * @memberof google.api.NodeSettings
                 * @static
                 * @param {google.api.INodeSettings} message NodeSettings message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                NodeSettings.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.common != null && Object.hasOwnProperty.call(message, "common"))
                        $root.google.api.CommonLanguageSettings.encode(message.common, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                    return writer;
                };
    
                /**
                 * Encodes the specified NodeSettings message, length delimited. Does not implicitly {@link google.api.NodeSettings.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.api.NodeSettings
                 * @static
                 * @param {google.api.INodeSettings} message NodeSettings message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                NodeSettings.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes a NodeSettings message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.api.NodeSettings
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.api.NodeSettings} NodeSettings
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                NodeSettings.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.api.NodeSettings();
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 1: {
                                message.common = $root.google.api.CommonLanguageSettings.decode(reader, reader.uint32());
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes a NodeSettings message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.api.NodeSettings
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.api.NodeSettings} NodeSettings
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                NodeSettings.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies a NodeSettings message.
                 * @function verify
                 * @memberof google.api.NodeSettings
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                NodeSettings.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    if (message.common != null && message.hasOwnProperty("common")) {
                        var error = $root.google.api.CommonLanguageSettings.verify(message.common);
                        if (error)
                            return "common." + error;
                    }
                    return null;
                };
    
                /**
                 * Creates a NodeSettings message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.api.NodeSettings
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.api.NodeSettings} NodeSettings
                 */
                NodeSettings.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.api.NodeSettings)
                        return object;
                    var message = new $root.google.api.NodeSettings();
                    if (object.common != null) {
                        if (typeof object.common !== "object")
                            throw TypeError(".google.api.NodeSettings.common: object expected");
                        message.common = $root.google.api.CommonLanguageSettings.fromObject(object.common);
                    }
                    return message;
                };
    
                /**
                 * Creates a plain object from a NodeSettings message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.api.NodeSettings
                 * @static
                 * @param {google.api.NodeSettings} message NodeSettings
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                NodeSettings.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (options.defaults)
                        object.common = null;
                    if (message.common != null && message.hasOwnProperty("common"))
                        object.common = $root.google.api.CommonLanguageSettings.toObject(message.common, options);
                    return object;
                };
    
                /**
                 * Converts this NodeSettings to JSON.
                 * @function toJSON
                 * @memberof google.api.NodeSettings
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                NodeSettings.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for NodeSettings
                 * @function getTypeUrl
                 * @memberof google.api.NodeSettings
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                NodeSettings.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.api.NodeSettings";
                };
    
                return NodeSettings;
            })();
    
            api.DotnetSettings = (function() {
    
                /**
                 * Properties of a DotnetSettings.
                 * @memberof google.api
                 * @interface IDotnetSettings
                 * @property {google.api.ICommonLanguageSettings|null} [common] DotnetSettings common
                 * @property {Object.<string,string>|null} [renamedServices] DotnetSettings renamedServices
                 * @property {Object.<string,string>|null} [renamedResources] DotnetSettings renamedResources
                 * @property {Array.<string>|null} [ignoredResources] DotnetSettings ignoredResources
                 * @property {Array.<string>|null} [forcedNamespaceAliases] DotnetSettings forcedNamespaceAliases
                 * @property {Array.<string>|null} [handwrittenSignatures] DotnetSettings handwrittenSignatures
                 */
    
                /**
                 * Constructs a new DotnetSettings.
                 * @memberof google.api
                 * @classdesc Represents a DotnetSettings.
                 * @implements IDotnetSettings
                 * @constructor
                 * @param {google.api.IDotnetSettings=} [properties] Properties to set
                 */
                function DotnetSettings(properties) {
                    this.renamedServices = {};
                    this.renamedResources = {};
                    this.ignoredResources = [];
                    this.forcedNamespaceAliases = [];
                    this.handwrittenSignatures = [];
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * DotnetSettings common.
                 * @member {google.api.ICommonLanguageSettings|null|undefined} common
                 * @memberof google.api.DotnetSettings
                 * @instance
                 */
                DotnetSettings.prototype.common = null;
    
                /**
                 * DotnetSettings renamedServices.
                 * @member {Object.<string,string>} renamedServices
                 * @memberof google.api.DotnetSettings
                 * @instance
                 */
                DotnetSettings.prototype.renamedServices = $util.emptyObject;
    
                /**
                 * DotnetSettings renamedResources.
                 * @member {Object.<string,string>} renamedResources
                 * @memberof google.api.DotnetSettings
                 * @instance
                 */
                DotnetSettings.prototype.renamedResources = $util.emptyObject;
    
                /**
                 * DotnetSettings ignoredResources.
                 * @member {Array.<string>} ignoredResources
                 * @memberof google.api.DotnetSettings
                 * @instance
                 */
                DotnetSettings.prototype.ignoredResources = $util.emptyArray;
    
                /**
                 * DotnetSettings forcedNamespaceAliases.
                 * @member {Array.<string>} forcedNamespaceAliases
                 * @memberof google.api.DotnetSettings
                 * @instance
                 */
                DotnetSettings.prototype.forcedNamespaceAliases = $util.emptyArray;
    
                /**
                 * DotnetSettings handwrittenSignatures.
                 * @member {Array.<string>} handwrittenSignatures
                 * @memberof google.api.DotnetSettings
                 * @instance
                 */
                DotnetSettings.prototype.handwrittenSignatures = $util.emptyArray;
    
                /**
                 * Creates a new DotnetSettings instance using the specified properties.
                 * @function create
                 * @memberof google.api.DotnetSettings
                 * @static
                 * @param {google.api.IDotnetSettings=} [properties] Properties to set
                 * @returns {google.api.DotnetSettings} DotnetSettings instance
                 */
                DotnetSettings.create = function create(properties) {
                    return new DotnetSettings(properties);
                };
    
                /**
                 * Encodes the specified DotnetSettings message. Does not implicitly {@link google.api.DotnetSettings.verify|verify} messages.
                 * @function encode
                 * @memberof google.api.DotnetSettings
                 * @static
                 * @param {google.api.IDotnetSettings} message DotnetSettings message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                DotnetSettings.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.common != null && Object.hasOwnProperty.call(message, "common"))
                        $root.google.api.CommonLanguageSettings.encode(message.common, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                    if (message.renamedServices != null && Object.hasOwnProperty.call(message, "renamedServices"))
                        for (var keys = Object.keys(message.renamedServices), i = 0; i < keys.length; ++i)
                            writer.uint32(/* id 2, wireType 2 =*/18).fork().uint32(/* id 1, wireType 2 =*/10).string(keys[i]).uint32(/* id 2, wireType 2 =*/18).string(message.renamedServices[keys[i]]).ldelim();
                    if (message.renamedResources != null && Object.hasOwnProperty.call(message, "renamedResources"))
                        for (var keys = Object.keys(message.renamedResources), i = 0; i < keys.length; ++i)
                            writer.uint32(/* id 3, wireType 2 =*/26).fork().uint32(/* id 1, wireType 2 =*/10).string(keys[i]).uint32(/* id 2, wireType 2 =*/18).string(message.renamedResources[keys[i]]).ldelim();
                    if (message.ignoredResources != null && message.ignoredResources.length)
                        for (var i = 0; i < message.ignoredResources.length; ++i)
                            writer.uint32(/* id 4, wireType 2 =*/34).string(message.ignoredResources[i]);
                    if (message.forcedNamespaceAliases != null && message.forcedNamespaceAliases.length)
                        for (var i = 0; i < message.forcedNamespaceAliases.length; ++i)
                            writer.uint32(/* id 5, wireType 2 =*/42).string(message.forcedNamespaceAliases[i]);
                    if (message.handwrittenSignatures != null && message.handwrittenSignatures.length)
                        for (var i = 0; i < message.handwrittenSignatures.length; ++i)
                            writer.uint32(/* id 6, wireType 2 =*/50).string(message.handwrittenSignatures[i]);
                    return writer;
                };
    
                /**
                 * Encodes the specified DotnetSettings message, length delimited. Does not implicitly {@link google.api.DotnetSettings.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.api.DotnetSettings
                 * @static
                 * @param {google.api.IDotnetSettings} message DotnetSettings message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                DotnetSettings.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes a DotnetSettings message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.api.DotnetSettings
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.api.DotnetSettings} DotnetSettings
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                DotnetSettings.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.api.DotnetSettings(), key, value;
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 1: {
                                message.common = $root.google.api.CommonLanguageSettings.decode(reader, reader.uint32());
                                break;
                            }
                        case 2: {
                                if (message.renamedServices === $util.emptyObject)
                                    message.renamedServices = {};
                                var end2 = reader.uint32() + reader.pos;
                                key = "";
                                value = "";
                                while (reader.pos < end2) {
                                    var tag2 = reader.uint32();
                                    switch (tag2 >>> 3) {
                                    case 1:
                                        key = reader.string();
                                        break;
                                    case 2:
                                        value = reader.string();
                                        break;
                                    default:
                                        reader.skipType(tag2 & 7);
                                        break;
                                    }
                                }
                                message.renamedServices[key] = value;
                                break;
                            }
                        case 3: {
                                if (message.renamedResources === $util.emptyObject)
                                    message.renamedResources = {};
                                var end2 = reader.uint32() + reader.pos;
                                key = "";
                                value = "";
                                while (reader.pos < end2) {
                                    var tag2 = reader.uint32();
                                    switch (tag2 >>> 3) {
                                    case 1:
                                        key = reader.string();
                                        break;
                                    case 2:
                                        value = reader.string();
                                        break;
                                    default:
                                        reader.skipType(tag2 & 7);
                                        break;
                                    }
                                }
                                message.renamedResources[key] = value;
                                break;
                            }
                        case 4: {
                                if (!(message.ignoredResources && message.ignoredResources.length))
                                    message.ignoredResources = [];
                                message.ignoredResources.push(reader.string());
                                break;
                            }
                        case 5: {
                                if (!(message.forcedNamespaceAliases && message.forcedNamespaceAliases.length))
                                    message.forcedNamespaceAliases = [];
                                message.forcedNamespaceAliases.push(reader.string());
                                break;
                            }
                        case 6: {
                                if (!(message.handwrittenSignatures && message.handwrittenSignatures.length))
                                    message.handwrittenSignatures = [];
                                message.handwrittenSignatures.push(reader.string());
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes a DotnetSettings message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.api.DotnetSettings
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.api.DotnetSettings} DotnetSettings
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                DotnetSettings.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies a DotnetSettings message.
                 * @function verify
                 * @memberof google.api.DotnetSettings
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                DotnetSettings.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    if (message.common != null && message.hasOwnProperty("common")) {
                        var error = $root.google.api.CommonLanguageSettings.verify(message.common);
                        if (error)
                            return "common." + error;
                    }
                    if (message.renamedServices != null && message.hasOwnProperty("renamedServices")) {
                        if (!$util.isObject(message.renamedServices))
                            return "renamedServices: object expected";
                        var key = Object.keys(message.renamedServices);
                        for (var i = 0; i < key.length; ++i)
                            if (!$util.isString(message.renamedServices[key[i]]))
                                return "renamedServices: string{k:string} expected";
                    }
                    if (message.renamedResources != null && message.hasOwnProperty("renamedResources")) {
                        if (!$util.isObject(message.renamedResources))
                            return "renamedResources: object expected";
                        var key = Object.keys(message.renamedResources);
                        for (var i = 0; i < key.length; ++i)
                            if (!$util.isString(message.renamedResources[key[i]]))
                                return "renamedResources: string{k:string} expected";
                    }
                    if (message.ignoredResources != null && message.hasOwnProperty("ignoredResources")) {
                        if (!Array.isArray(message.ignoredResources))
                            return "ignoredResources: array expected";
                        for (var i = 0; i < message.ignoredResources.length; ++i)
                            if (!$util.isString(message.ignoredResources[i]))
                                return "ignoredResources: string[] expected";
                    }
                    if (message.forcedNamespaceAliases != null && message.hasOwnProperty("forcedNamespaceAliases")) {
                        if (!Array.isArray(message.forcedNamespaceAliases))
                            return "forcedNamespaceAliases: array expected";
                        for (var i = 0; i < message.forcedNamespaceAliases.length; ++i)
                            if (!$util.isString(message.forcedNamespaceAliases[i]))
                                return "forcedNamespaceAliases: string[] expected";
                    }
                    if (message.handwrittenSignatures != null && message.hasOwnProperty("handwrittenSignatures")) {
                        if (!Array.isArray(message.handwrittenSignatures))
                            return "handwrittenSignatures: array expected";
                        for (var i = 0; i < message.handwrittenSignatures.length; ++i)
                            if (!$util.isString(message.handwrittenSignatures[i]))
                                return "handwrittenSignatures: string[] expected";
                    }
                    return null;
                };
    
                /**
                 * Creates a DotnetSettings message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.api.DotnetSettings
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.api.DotnetSettings} DotnetSettings
                 */
                DotnetSettings.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.api.DotnetSettings)
                        return object;
                    var message = new $root.google.api.DotnetSettings();
                    if (object.common != null) {
                        if (typeof object.common !== "object")
                            throw TypeError(".google.api.DotnetSettings.common: object expected");
                        message.common = $root.google.api.CommonLanguageSettings.fromObject(object.common);
                    }
                    if (object.renamedServices) {
                        if (typeof object.renamedServices !== "object")
                            throw TypeError(".google.api.DotnetSettings.renamedServices: object expected");
                        message.renamedServices = {};
                        for (var keys = Object.keys(object.renamedServices), i = 0; i < keys.length; ++i)
                            message.renamedServices[keys[i]] = String(object.renamedServices[keys[i]]);
                    }
                    if (object.renamedResources) {
                        if (typeof object.renamedResources !== "object")
                            throw TypeError(".google.api.DotnetSettings.renamedResources: object expected");
                        message.renamedResources = {};
                        for (var keys = Object.keys(object.renamedResources), i = 0; i < keys.length; ++i)
                            message.renamedResources[keys[i]] = String(object.renamedResources[keys[i]]);
                    }
                    if (object.ignoredResources) {
                        if (!Array.isArray(object.ignoredResources))
                            throw TypeError(".google.api.DotnetSettings.ignoredResources: array expected");
                        message.ignoredResources = [];
                        for (var i = 0; i < object.ignoredResources.length; ++i)
                            message.ignoredResources[i] = String(object.ignoredResources[i]);
                    }
                    if (object.forcedNamespaceAliases) {
                        if (!Array.isArray(object.forcedNamespaceAliases))
                            throw TypeError(".google.api.DotnetSettings.forcedNamespaceAliases: array expected");
                        message.forcedNamespaceAliases = [];
                        for (var i = 0; i < object.forcedNamespaceAliases.length; ++i)
                            message.forcedNamespaceAliases[i] = String(object.forcedNamespaceAliases[i]);
                    }
                    if (object.handwrittenSignatures) {
                        if (!Array.isArray(object.handwrittenSignatures))
                            throw TypeError(".google.api.DotnetSettings.handwrittenSignatures: array expected");
                        message.handwrittenSignatures = [];
                        for (var i = 0; i < object.handwrittenSignatures.length; ++i)
                            message.handwrittenSignatures[i] = String(object.handwrittenSignatures[i]);
                    }
                    return message;
                };
    
                /**
                 * Creates a plain object from a DotnetSettings message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.api.DotnetSettings
                 * @static
                 * @param {google.api.DotnetSettings} message DotnetSettings
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                DotnetSettings.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (options.arrays || options.defaults) {
                        object.ignoredResources = [];
                        object.forcedNamespaceAliases = [];
                        object.handwrittenSignatures = [];
                    }
                    if (options.objects || options.defaults) {
                        object.renamedServices = {};
                        object.renamedResources = {};
                    }
                    if (options.defaults)
                        object.common = null;
                    if (message.common != null && message.hasOwnProperty("common"))
                        object.common = $root.google.api.CommonLanguageSettings.toObject(message.common, options);
                    var keys2;
                    if (message.renamedServices && (keys2 = Object.keys(message.renamedServices)).length) {
                        object.renamedServices = {};
                        for (var j = 0; j < keys2.length; ++j)
                            object.renamedServices[keys2[j]] = message.renamedServices[keys2[j]];
                    }
                    if (message.renamedResources && (keys2 = Object.keys(message.renamedResources)).length) {
                        object.renamedResources = {};
                        for (var j = 0; j < keys2.length; ++j)
                            object.renamedResources[keys2[j]] = message.renamedResources[keys2[j]];
                    }
                    if (message.ignoredResources && message.ignoredResources.length) {
                        object.ignoredResources = [];
                        for (var j = 0; j < message.ignoredResources.length; ++j)
                            object.ignoredResources[j] = message.ignoredResources[j];
                    }
                    if (message.forcedNamespaceAliases && message.forcedNamespaceAliases.length) {
                        object.forcedNamespaceAliases = [];
                        for (var j = 0; j < message.forcedNamespaceAliases.length; ++j)
                            object.forcedNamespaceAliases[j] = message.forcedNamespaceAliases[j];
                    }
                    if (message.handwrittenSignatures && message.handwrittenSignatures.length) {
                        object.handwrittenSignatures = [];
                        for (var j = 0; j < message.handwrittenSignatures.length; ++j)
                            object.handwrittenSignatures[j] = message.handwrittenSignatures[j];
                    }
                    return object;
                };
    
                /**
                 * Converts this DotnetSettings to JSON.
                 * @function toJSON
                 * @memberof google.api.DotnetSettings
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                DotnetSettings.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for DotnetSettings
                 * @function getTypeUrl
                 * @memberof google.api.DotnetSettings
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                DotnetSettings.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.api.DotnetSettings";
                };
    
                return DotnetSettings;
            })();
    
            api.RubySettings = (function() {
    
                /**
                 * Properties of a RubySettings.
                 * @memberof google.api
                 * @interface IRubySettings
                 * @property {google.api.ICommonLanguageSettings|null} [common] RubySettings common
                 */
    
                /**
                 * Constructs a new RubySettings.
                 * @memberof google.api
                 * @classdesc Represents a RubySettings.
                 * @implements IRubySettings
                 * @constructor
                 * @param {google.api.IRubySettings=} [properties] Properties to set
                 */
                function RubySettings(properties) {
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * RubySettings common.
                 * @member {google.api.ICommonLanguageSettings|null|undefined} common
                 * @memberof google.api.RubySettings
                 * @instance
                 */
                RubySettings.prototype.common = null;
    
                /**
                 * Creates a new RubySettings instance using the specified properties.
                 * @function create
                 * @memberof google.api.RubySettings
                 * @static
                 * @param {google.api.IRubySettings=} [properties] Properties to set
                 * @returns {google.api.RubySettings} RubySettings instance
                 */
                RubySettings.create = function create(properties) {
                    return new RubySettings(properties);
                };
    
                /**
                 * Encodes the specified RubySettings message. Does not implicitly {@link google.api.RubySettings.verify|verify} messages.
                 * @function encode
                 * @memberof google.api.RubySettings
                 * @static
                 * @param {google.api.IRubySettings} message RubySettings message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                RubySettings.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.common != null && Object.hasOwnProperty.call(message, "common"))
                        $root.google.api.CommonLanguageSettings.encode(message.common, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                    return writer;
                };
    
                /**
                 * Encodes the specified RubySettings message, length delimited. Does not implicitly {@link google.api.RubySettings.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.api.RubySettings
                 * @static
                 * @param {google.api.IRubySettings} message RubySettings message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                RubySettings.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes a RubySettings message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.api.RubySettings
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.api.RubySettings} RubySettings
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                RubySettings.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.api.RubySettings();
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 1: {
                                message.common = $root.google.api.CommonLanguageSettings.decode(reader, reader.uint32());
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes a RubySettings message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.api.RubySettings
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.api.RubySettings} RubySettings
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                RubySettings.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies a RubySettings message.
                 * @function verify
                 * @memberof google.api.RubySettings
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                RubySettings.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    if (message.common != null && message.hasOwnProperty("common")) {
                        var error = $root.google.api.CommonLanguageSettings.verify(message.common);
                        if (error)
                            return "common." + error;
                    }
                    return null;
                };
    
                /**
                 * Creates a RubySettings message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.api.RubySettings
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.api.RubySettings} RubySettings
                 */
                RubySettings.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.api.RubySettings)
                        return object;
                    var message = new $root.google.api.RubySettings();
                    if (object.common != null) {
                        if (typeof object.common !== "object")
                            throw TypeError(".google.api.RubySettings.common: object expected");
                        message.common = $root.google.api.CommonLanguageSettings.fromObject(object.common);
                    }
                    return message;
                };
    
                /**
                 * Creates a plain object from a RubySettings message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.api.RubySettings
                 * @static
                 * @param {google.api.RubySettings} message RubySettings
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                RubySettings.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (options.defaults)
                        object.common = null;
                    if (message.common != null && message.hasOwnProperty("common"))
                        object.common = $root.google.api.CommonLanguageSettings.toObject(message.common, options);
                    return object;
                };
    
                /**
                 * Converts this RubySettings to JSON.
                 * @function toJSON
                 * @memberof google.api.RubySettings
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                RubySettings.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for RubySettings
                 * @function getTypeUrl
                 * @memberof google.api.RubySettings
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                RubySettings.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.api.RubySettings";
                };
    
                return RubySettings;
            })();
    
            api.GoSettings = (function() {
    
                /**
                 * Properties of a GoSettings.
                 * @memberof google.api
                 * @interface IGoSettings
                 * @property {google.api.ICommonLanguageSettings|null} [common] GoSettings common
                 */
    
                /**
                 * Constructs a new GoSettings.
                 * @memberof google.api
                 * @classdesc Represents a GoSettings.
                 * @implements IGoSettings
                 * @constructor
                 * @param {google.api.IGoSettings=} [properties] Properties to set
                 */
                function GoSettings(properties) {
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * GoSettings common.
                 * @member {google.api.ICommonLanguageSettings|null|undefined} common
                 * @memberof google.api.GoSettings
                 * @instance
                 */
                GoSettings.prototype.common = null;
    
                /**
                 * Creates a new GoSettings instance using the specified properties.
                 * @function create
                 * @memberof google.api.GoSettings
                 * @static
                 * @param {google.api.IGoSettings=} [properties] Properties to set
                 * @returns {google.api.GoSettings} GoSettings instance
                 */
                GoSettings.create = function create(properties) {
                    return new GoSettings(properties);
                };
    
                /**
                 * Encodes the specified GoSettings message. Does not implicitly {@link google.api.GoSettings.verify|verify} messages.
                 * @function encode
                 * @memberof google.api.GoSettings
                 * @static
                 * @param {google.api.IGoSettings} message GoSettings message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                GoSettings.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.common != null && Object.hasOwnProperty.call(message, "common"))
                        $root.google.api.CommonLanguageSettings.encode(message.common, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                    return writer;
                };
    
                /**
                 * Encodes the specified GoSettings message, length delimited. Does not implicitly {@link google.api.GoSettings.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.api.GoSettings
                 * @static
                 * @param {google.api.IGoSettings} message GoSettings message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                GoSettings.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes a GoSettings message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.api.GoSettings
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.api.GoSettings} GoSettings
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                GoSettings.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.api.GoSettings();
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 1: {
                                message.common = $root.google.api.CommonLanguageSettings.decode(reader, reader.uint32());
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes a GoSettings message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.api.GoSettings
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.api.GoSettings} GoSettings
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                GoSettings.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies a GoSettings message.
                 * @function verify
                 * @memberof google.api.GoSettings
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                GoSettings.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    if (message.common != null && message.hasOwnProperty("common")) {
                        var error = $root.google.api.CommonLanguageSettings.verify(message.common);
                        if (error)
                            return "common." + error;
                    }
                    return null;
                };
    
                /**
                 * Creates a GoSettings message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.api.GoSettings
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.api.GoSettings} GoSettings
                 */
                GoSettings.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.api.GoSettings)
                        return object;
                    var message = new $root.google.api.GoSettings();
                    if (object.common != null) {
                        if (typeof object.common !== "object")
                            throw TypeError(".google.api.GoSettings.common: object expected");
                        message.common = $root.google.api.CommonLanguageSettings.fromObject(object.common);
                    }
                    return message;
                };
    
                /**
                 * Creates a plain object from a GoSettings message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.api.GoSettings
                 * @static
                 * @param {google.api.GoSettings} message GoSettings
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                GoSettings.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (options.defaults)
                        object.common = null;
                    if (message.common != null && message.hasOwnProperty("common"))
                        object.common = $root.google.api.CommonLanguageSettings.toObject(message.common, options);
                    return object;
                };
    
                /**
                 * Converts this GoSettings to JSON.
                 * @function toJSON
                 * @memberof google.api.GoSettings
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                GoSettings.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for GoSettings
                 * @function getTypeUrl
                 * @memberof google.api.GoSettings
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                GoSettings.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.api.GoSettings";
                };
    
                return GoSettings;
            })();
    
            api.MethodSettings = (function() {
    
                /**
                 * Properties of a MethodSettings.
                 * @memberof google.api
                 * @interface IMethodSettings
                 * @property {string|null} [selector] MethodSettings selector
                 * @property {google.api.MethodSettings.ILongRunning|null} [longRunning] MethodSettings longRunning
                 * @property {Array.<string>|null} [autoPopulatedFields] MethodSettings autoPopulatedFields
                 */
    
                /**
                 * Constructs a new MethodSettings.
                 * @memberof google.api
                 * @classdesc Represents a MethodSettings.
                 * @implements IMethodSettings
                 * @constructor
                 * @param {google.api.IMethodSettings=} [properties] Properties to set
                 */
                function MethodSettings(properties) {
                    this.autoPopulatedFields = [];
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * MethodSettings selector.
                 * @member {string} selector
                 * @memberof google.api.MethodSettings
                 * @instance
                 */
                MethodSettings.prototype.selector = "";
    
                /**
                 * MethodSettings longRunning.
                 * @member {google.api.MethodSettings.ILongRunning|null|undefined} longRunning
                 * @memberof google.api.MethodSettings
                 * @instance
                 */
                MethodSettings.prototype.longRunning = null;
    
                /**
                 * MethodSettings autoPopulatedFields.
                 * @member {Array.<string>} autoPopulatedFields
                 * @memberof google.api.MethodSettings
                 * @instance
                 */
                MethodSettings.prototype.autoPopulatedFields = $util.emptyArray;
    
                /**
                 * Creates a new MethodSettings instance using the specified properties.
                 * @function create
                 * @memberof google.api.MethodSettings
                 * @static
                 * @param {google.api.IMethodSettings=} [properties] Properties to set
                 * @returns {google.api.MethodSettings} MethodSettings instance
                 */
                MethodSettings.create = function create(properties) {
                    return new MethodSettings(properties);
                };
    
                /**
                 * Encodes the specified MethodSettings message. Does not implicitly {@link google.api.MethodSettings.verify|verify} messages.
                 * @function encode
                 * @memberof google.api.MethodSettings
                 * @static
                 * @param {google.api.IMethodSettings} message MethodSettings message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                MethodSettings.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.selector != null && Object.hasOwnProperty.call(message, "selector"))
                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.selector);
                    if (message.longRunning != null && Object.hasOwnProperty.call(message, "longRunning"))
                        $root.google.api.MethodSettings.LongRunning.encode(message.longRunning, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                    if (message.autoPopulatedFields != null && message.autoPopulatedFields.length)
                        for (var i = 0; i < message.autoPopulatedFields.length; ++i)
                            writer.uint32(/* id 3, wireType 2 =*/26).string(message.autoPopulatedFields[i]);
                    return writer;
                };
    
                /**
                 * Encodes the specified MethodSettings message, length delimited. Does not implicitly {@link google.api.MethodSettings.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.api.MethodSettings
                 * @static
                 * @param {google.api.IMethodSettings} message MethodSettings message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                MethodSettings.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes a MethodSettings message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.api.MethodSettings
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.api.MethodSettings} MethodSettings
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                MethodSettings.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.api.MethodSettings();
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 1: {
                                message.selector = reader.string();
                                break;
                            }
                        case 2: {
                                message.longRunning = $root.google.api.MethodSettings.LongRunning.decode(reader, reader.uint32());
                                break;
                            }
                        case 3: {
                                if (!(message.autoPopulatedFields && message.autoPopulatedFields.length))
                                    message.autoPopulatedFields = [];
                                message.autoPopulatedFields.push(reader.string());
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes a MethodSettings message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.api.MethodSettings
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.api.MethodSettings} MethodSettings
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                MethodSettings.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies a MethodSettings message.
                 * @function verify
                 * @memberof google.api.MethodSettings
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                MethodSettings.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    if (message.selector != null && message.hasOwnProperty("selector"))
                        if (!$util.isString(message.selector))
                            return "selector: string expected";
                    if (message.longRunning != null && message.hasOwnProperty("longRunning")) {
                        var error = $root.google.api.MethodSettings.LongRunning.verify(message.longRunning);
                        if (error)
                            return "longRunning." + error;
                    }
                    if (message.autoPopulatedFields != null && message.hasOwnProperty("autoPopulatedFields")) {
                        if (!Array.isArray(message.autoPopulatedFields))
                            return "autoPopulatedFields: array expected";
                        for (var i = 0; i < message.autoPopulatedFields.length; ++i)
                            if (!$util.isString(message.autoPopulatedFields[i]))
                                return "autoPopulatedFields: string[] expected";
                    }
                    return null;
                };
    
                /**
                 * Creates a MethodSettings message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.api.MethodSettings
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.api.MethodSettings} MethodSettings
                 */
                MethodSettings.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.api.MethodSettings)
                        return object;
                    var message = new $root.google.api.MethodSettings();
                    if (object.selector != null)
                        message.selector = String(object.selector);
                    if (object.longRunning != null) {
                        if (typeof object.longRunning !== "object")
                            throw TypeError(".google.api.MethodSettings.longRunning: object expected");
                        message.longRunning = $root.google.api.MethodSettings.LongRunning.fromObject(object.longRunning);
                    }
                    if (object.autoPopulatedFields) {
                        if (!Array.isArray(object.autoPopulatedFields))
                            throw TypeError(".google.api.MethodSettings.autoPopulatedFields: array expected");
                        message.autoPopulatedFields = [];
                        for (var i = 0; i < object.autoPopulatedFields.length; ++i)
                            message.autoPopulatedFields[i] = String(object.autoPopulatedFields[i]);
                    }
                    return message;
                };
    
                /**
                 * Creates a plain object from a MethodSettings message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.api.MethodSettings
                 * @static
                 * @param {google.api.MethodSettings} message MethodSettings
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                MethodSettings.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (options.arrays || options.defaults)
                        object.autoPopulatedFields = [];
                    if (options.defaults) {
                        object.selector = "";
                        object.longRunning = null;
                    }
                    if (message.selector != null && message.hasOwnProperty("selector"))
                        object.selector = message.selector;
                    if (message.longRunning != null && message.hasOwnProperty("longRunning"))
                        object.longRunning = $root.google.api.MethodSettings.LongRunning.toObject(message.longRunning, options);
                    if (message.autoPopulatedFields && message.autoPopulatedFields.length) {
                        object.autoPopulatedFields = [];
                        for (var j = 0; j < message.autoPopulatedFields.length; ++j)
                            object.autoPopulatedFields[j] = message.autoPopulatedFields[j];
                    }
                    return object;
                };
    
                /**
                 * Converts this MethodSettings to JSON.
                 * @function toJSON
                 * @memberof google.api.MethodSettings
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                MethodSettings.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for MethodSettings
                 * @function getTypeUrl
                 * @memberof google.api.MethodSettings
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                MethodSettings.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.api.MethodSettings";
                };
    
                MethodSettings.LongRunning = (function() {
    
                    /**
                     * Properties of a LongRunning.
                     * @memberof google.api.MethodSettings
                     * @interface ILongRunning
                     * @property {google.protobuf.IDuration|null} [initialPollDelay] LongRunning initialPollDelay
                     * @property {number|null} [pollDelayMultiplier] LongRunning pollDelayMultiplier
                     * @property {google.protobuf.IDuration|null} [maxPollDelay] LongRunning maxPollDelay
                     * @property {google.protobuf.IDuration|null} [totalPollTimeout] LongRunning totalPollTimeout
                     */
    
                    /**
                     * Constructs a new LongRunning.
                     * @memberof google.api.MethodSettings
                     * @classdesc Represents a LongRunning.
                     * @implements ILongRunning
                     * @constructor
                     * @param {google.api.MethodSettings.ILongRunning=} [properties] Properties to set
                     */
                    function LongRunning(properties) {
                        if (properties)
                            for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                if (properties[keys[i]] != null)
                                    this[keys[i]] = properties[keys[i]];
                    }
    
                    /**
                     * LongRunning initialPollDelay.
                     * @member {google.protobuf.IDuration|null|undefined} initialPollDelay
                     * @memberof google.api.MethodSettings.LongRunning
                     * @instance
                     */
                    LongRunning.prototype.initialPollDelay = null;
    
                    /**
                     * LongRunning pollDelayMultiplier.
                     * @member {number} pollDelayMultiplier
                     * @memberof google.api.MethodSettings.LongRunning
                     * @instance
                     */
                    LongRunning.prototype.pollDelayMultiplier = 0;
    
                    /**
                     * LongRunning maxPollDelay.
                     * @member {google.protobuf.IDuration|null|undefined} maxPollDelay
                     * @memberof google.api.MethodSettings.LongRunning
                     * @instance
                     */
                    LongRunning.prototype.maxPollDelay = null;
    
                    /**
                     * LongRunning totalPollTimeout.
                     * @member {google.protobuf.IDuration|null|undefined} totalPollTimeout
                     * @memberof google.api.MethodSettings.LongRunning
                     * @instance
                     */
                    LongRunning.prototype.totalPollTimeout = null;
    
                    /**
                     * Creates a new LongRunning instance using the specified properties.
                     * @function create
                     * @memberof google.api.MethodSettings.LongRunning
                     * @static
                     * @param {google.api.MethodSettings.ILongRunning=} [properties] Properties to set
                     * @returns {google.api.MethodSettings.LongRunning} LongRunning instance
                     */
                    LongRunning.create = function create(properties) {
                        return new LongRunning(properties);
                    };
    
                    /**
                     * Encodes the specified LongRunning message. Does not implicitly {@link google.api.MethodSettings.LongRunning.verify|verify} messages.
                     * @function encode
                     * @memberof google.api.MethodSettings.LongRunning
                     * @static
                     * @param {google.api.MethodSettings.ILongRunning} message LongRunning message or plain object to encode
                     * @param {$protobuf.Writer} [writer] Writer to encode to
                     * @returns {$protobuf.Writer} Writer
                     */
                    LongRunning.encode = function encode(message, writer) {
                        if (!writer)
                            writer = $Writer.create();
                        if (message.initialPollDelay != null && Object.hasOwnProperty.call(message, "initialPollDelay"))
                            $root.google.protobuf.Duration.encode(message.initialPollDelay, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                        if (message.pollDelayMultiplier != null && Object.hasOwnProperty.call(message, "pollDelayMultiplier"))
                            writer.uint32(/* id 2, wireType 5 =*/21).float(message.pollDelayMultiplier);
                        if (message.maxPollDelay != null && Object.hasOwnProperty.call(message, "maxPollDelay"))
                            $root.google.protobuf.Duration.encode(message.maxPollDelay, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                        if (message.totalPollTimeout != null && Object.hasOwnProperty.call(message, "totalPollTimeout"))
                            $root.google.protobuf.Duration.encode(message.totalPollTimeout, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                        return writer;
                    };
    
                    /**
                     * Encodes the specified LongRunning message, length delimited. Does not implicitly {@link google.api.MethodSettings.LongRunning.verify|verify} messages.
                     * @function encodeDelimited
                     * @memberof google.api.MethodSettings.LongRunning
                     * @static
                     * @param {google.api.MethodSettings.ILongRunning} message LongRunning message or plain object to encode
                     * @param {$protobuf.Writer} [writer] Writer to encode to
                     * @returns {$protobuf.Writer} Writer
                     */
                    LongRunning.encodeDelimited = function encodeDelimited(message, writer) {
                        return this.encode(message, writer).ldelim();
                    };
    
                    /**
                     * Decodes a LongRunning message from the specified reader or buffer.
                     * @function decode
                     * @memberof google.api.MethodSettings.LongRunning
                     * @static
                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                     * @param {number} [length] Message length if known beforehand
                     * @returns {google.api.MethodSettings.LongRunning} LongRunning
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    LongRunning.decode = function decode(reader, length) {
                        if (!(reader instanceof $Reader))
                            reader = $Reader.create(reader);
                        var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.api.MethodSettings.LongRunning();
                        while (reader.pos < end) {
                            var tag = reader.uint32();
                            switch (tag >>> 3) {
                            case 1: {
                                    message.initialPollDelay = $root.google.protobuf.Duration.decode(reader, reader.uint32());
                                    break;
                                }
                            case 2: {
                                    message.pollDelayMultiplier = reader.float();
                                    break;
                                }
                            case 3: {
                                    message.maxPollDelay = $root.google.protobuf.Duration.decode(reader, reader.uint32());
                                    break;
                                }
                            case 4: {
                                    message.totalPollTimeout = $root.google.protobuf.Duration.decode(reader, reader.uint32());
                                    break;
                                }
                            default:
                                reader.skipType(tag & 7);
                                break;
                            }
                        }
                        return message;
                    };
    
                    /**
                     * Decodes a LongRunning message from the specified reader or buffer, length delimited.
                     * @function decodeDelimited
                     * @memberof google.api.MethodSettings.LongRunning
                     * @static
                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                     * @returns {google.api.MethodSettings.LongRunning} LongRunning
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    LongRunning.decodeDelimited = function decodeDelimited(reader) {
                        if (!(reader instanceof $Reader))
                            reader = new $Reader(reader);
                        return this.decode(reader, reader.uint32());
                    };
    
                    /**
                     * Verifies a LongRunning message.
                     * @function verify
                     * @memberof google.api.MethodSettings.LongRunning
                     * @static
                     * @param {Object.<string,*>} message Plain object to verify
                     * @returns {string|null} `null` if valid, otherwise the reason why it is not
                     */
                    LongRunning.verify = function verify(message) {
                        if (typeof message !== "object" || message === null)
                            return "object expected";
                        if (message.initialPollDelay != null && message.hasOwnProperty("initialPollDelay")) {
                            var error = $root.google.protobuf.Duration.verify(message.initialPollDelay);
                            if (error)
                                return "initialPollDelay." + error;
                        }
                        if (message.pollDelayMultiplier != null && message.hasOwnProperty("pollDelayMultiplier"))
                            if (typeof message.pollDelayMultiplier !== "number")
                                return "pollDelayMultiplier: number expected";
                        if (message.maxPollDelay != null && message.hasOwnProperty("maxPollDelay")) {
                            var error = $root.google.protobuf.Duration.verify(message.maxPollDelay);
                            if (error)
                                return "maxPollDelay." + error;
                        }
                        if (message.totalPollTimeout != null && message.hasOwnProperty("totalPollTimeout")) {
                            var error = $root.google.protobuf.Duration.verify(message.totalPollTimeout);
                            if (error)
                                return "totalPollTimeout." + error;
                        }
                        return null;
                    };
    
                    /**
                     * Creates a LongRunning message from a plain object. Also converts values to their respective internal types.
                     * @function fromObject
                     * @memberof google.api.MethodSettings.LongRunning
                     * @static
                     * @param {Object.<string,*>} object Plain object
                     * @returns {google.api.MethodSettings.LongRunning} LongRunning
                     */
                    LongRunning.fromObject = function fromObject(object) {
                        if (object instanceof $root.google.api.MethodSettings.LongRunning)
                            return object;
                        var message = new $root.google.api.MethodSettings.LongRunning();
                        if (object.initialPollDelay != null) {
                            if (typeof object.initialPollDelay !== "object")
                                throw TypeError(".google.api.MethodSettings.LongRunning.initialPollDelay: object expected");
                            message.initialPollDelay = $root.google.protobuf.Duration.fromObject(object.initialPollDelay);
                        }
                        if (object.pollDelayMultiplier != null)
                            message.pollDelayMultiplier = Number(object.pollDelayMultiplier);
                        if (object.maxPollDelay != null) {
                            if (typeof object.maxPollDelay !== "object")
                                throw TypeError(".google.api.MethodSettings.LongRunning.maxPollDelay: object expected");
                            message.maxPollDelay = $root.google.protobuf.Duration.fromObject(object.maxPollDelay);
                        }
                        if (object.totalPollTimeout != null) {
                            if (typeof object.totalPollTimeout !== "object")
                                throw TypeError(".google.api.MethodSettings.LongRunning.totalPollTimeout: object expected");
                            message.totalPollTimeout = $root.google.protobuf.Duration.fromObject(object.totalPollTimeout);
                        }
                        return message;
                    };
    
                    /**
                     * Creates a plain object from a LongRunning message. Also converts values to other types if specified.
                     * @function toObject
                     * @memberof google.api.MethodSettings.LongRunning
                     * @static
                     * @param {google.api.MethodSettings.LongRunning} message LongRunning
                     * @param {$protobuf.IConversionOptions} [options] Conversion options
                     * @returns {Object.<string,*>} Plain object
                     */
                    LongRunning.toObject = function toObject(message, options) {
                        if (!options)
                            options = {};
                        var object = {};
                        if (options.defaults) {
                            object.initialPollDelay = null;
                            object.pollDelayMultiplier = 0;
                            object.maxPollDelay = null;
                            object.totalPollTimeout = null;
                        }
                        if (message.initialPollDelay != null && message.hasOwnProperty("initialPollDelay"))
                            object.initialPollDelay = $root.google.protobuf.Duration.toObject(message.initialPollDelay, options);
                        if (message.pollDelayMultiplier != null && message.hasOwnProperty("pollDelayMultiplier"))
                            object.pollDelayMultiplier = options.json && !isFinite(message.pollDelayMultiplier) ? String(message.pollDelayMultiplier) : message.pollDelayMultiplier;
                        if (message.maxPollDelay != null && message.hasOwnProperty("maxPollDelay"))
                            object.maxPollDelay = $root.google.protobuf.Duration.toObject(message.maxPollDelay, options);
                        if (message.totalPollTimeout != null && message.hasOwnProperty("totalPollTimeout"))
                            object.totalPollTimeout = $root.google.protobuf.Duration.toObject(message.totalPollTimeout, options);
                        return object;
                    };
    
                    /**
                     * Converts this LongRunning to JSON.
                     * @function toJSON
                     * @memberof google.api.MethodSettings.LongRunning
                     * @instance
                     * @returns {Object.<string,*>} JSON object
                     */
                    LongRunning.prototype.toJSON = function toJSON() {
                        return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                    };
    
                    /**
                     * Gets the default type url for LongRunning
                     * @function getTypeUrl
                     * @memberof google.api.MethodSettings.LongRunning
                     * @static
                     * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns {string} The default type url
                     */
                    LongRunning.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                        if (typeUrlPrefix === undefined) {
                            typeUrlPrefix = "type.googleapis.com";
                        }
                        return typeUrlPrefix + "/google.api.MethodSettings.LongRunning";
                    };
    
                    return LongRunning;
                })();
    
                return MethodSettings;
            })();
    
            /**
             * ClientLibraryOrganization enum.
             * @name google.api.ClientLibraryOrganization
             * @enum {number}
             * @property {number} CLIENT_LIBRARY_ORGANIZATION_UNSPECIFIED=0 CLIENT_LIBRARY_ORGANIZATION_UNSPECIFIED value
             * @property {number} CLOUD=1 CLOUD value
             * @property {number} ADS=2 ADS value
             * @property {number} PHOTOS=3 PHOTOS value
             * @property {number} STREET_VIEW=4 STREET_VIEW value
             * @property {number} SHOPPING=5 SHOPPING value
             * @property {number} GEO=6 GEO value
             * @property {number} GENERATIVE_AI=7 GENERATIVE_AI value
             */
            api.ClientLibraryOrganization = (function() {
                var valuesById = {}, values = Object.create(valuesById);
                values[valuesById[0] = "CLIENT_LIBRARY_ORGANIZATION_UNSPECIFIED"] = 0;
                values[valuesById[1] = "CLOUD"] = 1;
                values[valuesById[2] = "ADS"] = 2;
                values[valuesById[3] = "PHOTOS"] = 3;
                values[valuesById[4] = "STREET_VIEW"] = 4;
                values[valuesById[5] = "SHOPPING"] = 5;
                values[valuesById[6] = "GEO"] = 6;
                values[valuesById[7] = "GENERATIVE_AI"] = 7;
                return values;
            })();
    
            /**
             * ClientLibraryDestination enum.
             * @name google.api.ClientLibraryDestination
             * @enum {number}
             * @property {number} CLIENT_LIBRARY_DESTINATION_UNSPECIFIED=0 CLIENT_LIBRARY_DESTINATION_UNSPECIFIED value
             * @property {number} GITHUB=10 GITHUB value
             * @property {number} PACKAGE_MANAGER=20 PACKAGE_MANAGER value
             */
            api.ClientLibraryDestination = (function() {
                var valuesById = {}, values = Object.create(valuesById);
                values[valuesById[0] = "CLIENT_LIBRARY_DESTINATION_UNSPECIFIED"] = 0;
                values[valuesById[10] = "GITHUB"] = 10;
                values[valuesById[20] = "PACKAGE_MANAGER"] = 20;
                return values;
            })();
    
            /**
             * LaunchStage enum.
             * @name google.api.LaunchStage
             * @enum {number}
             * @property {number} LAUNCH_STAGE_UNSPECIFIED=0 LAUNCH_STAGE_UNSPECIFIED value
             * @property {number} UNIMPLEMENTED=6 UNIMPLEMENTED value
             * @property {number} PRELAUNCH=7 PRELAUNCH value
             * @property {number} EARLY_ACCESS=1 EARLY_ACCESS value
             * @property {number} ALPHA=2 ALPHA value
             * @property {number} BETA=3 BETA value
             * @property {number} GA=4 GA value
             * @property {number} DEPRECATED=5 DEPRECATED value
             */
            api.LaunchStage = (function() {
                var valuesById = {}, values = Object.create(valuesById);
                values[valuesById[0] = "LAUNCH_STAGE_UNSPECIFIED"] = 0;
                values[valuesById[6] = "UNIMPLEMENTED"] = 6;
                values[valuesById[7] = "PRELAUNCH"] = 7;
                values[valuesById[1] = "EARLY_ACCESS"] = 1;
                values[valuesById[2] = "ALPHA"] = 2;
                values[valuesById[3] = "BETA"] = 3;
                values[valuesById[4] = "GA"] = 4;
                values[valuesById[5] = "DEPRECATED"] = 5;
                return values;
            })();
    
            /**
             * FieldBehavior enum.
             * @name google.api.FieldBehavior
             * @enum {number}
             * @property {number} FIELD_BEHAVIOR_UNSPECIFIED=0 FIELD_BEHAVIOR_UNSPECIFIED value
             * @property {number} OPTIONAL=1 OPTIONAL value
             * @property {number} REQUIRED=2 REQUIRED value
             * @property {number} OUTPUT_ONLY=3 OUTPUT_ONLY value
             * @property {number} INPUT_ONLY=4 INPUT_ONLY value
             * @property {number} IMMUTABLE=5 IMMUTABLE value
             * @property {number} UNORDERED_LIST=6 UNORDERED_LIST value
             * @property {number} NON_EMPTY_DEFAULT=7 NON_EMPTY_DEFAULT value
             * @property {number} IDENTIFIER=8 IDENTIFIER value
             */
            api.FieldBehavior = (function() {
                var valuesById = {}, values = Object.create(valuesById);
                values[valuesById[0] = "FIELD_BEHAVIOR_UNSPECIFIED"] = 0;
                values[valuesById[1] = "OPTIONAL"] = 1;
                values[valuesById[2] = "REQUIRED"] = 2;
                values[valuesById[3] = "OUTPUT_ONLY"] = 3;
                values[valuesById[4] = "INPUT_ONLY"] = 4;
                values[valuesById[5] = "IMMUTABLE"] = 5;
                values[valuesById[6] = "UNORDERED_LIST"] = 6;
                values[valuesById[7] = "NON_EMPTY_DEFAULT"] = 7;
                values[valuesById[8] = "IDENTIFIER"] = 8;
                return values;
            })();
    
            api.ResourceDescriptor = (function() {
    
                /**
                 * Properties of a ResourceDescriptor.
                 * @memberof google.api
                 * @interface IResourceDescriptor
                 * @property {string|null} [type] ResourceDescriptor type
                 * @property {Array.<string>|null} [pattern] ResourceDescriptor pattern
                 * @property {string|null} [nameField] ResourceDescriptor nameField
                 * @property {google.api.ResourceDescriptor.History|null} [history] ResourceDescriptor history
                 * @property {string|null} [plural] ResourceDescriptor plural
                 * @property {string|null} [singular] ResourceDescriptor singular
                 * @property {Array.<google.api.ResourceDescriptor.Style>|null} [style] ResourceDescriptor style
                 */
    
                /**
                 * Constructs a new ResourceDescriptor.
                 * @memberof google.api
                 * @classdesc Represents a ResourceDescriptor.
                 * @implements IResourceDescriptor
                 * @constructor
                 * @param {google.api.IResourceDescriptor=} [properties] Properties to set
                 */
                function ResourceDescriptor(properties) {
                    this.pattern = [];
                    this.style = [];
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * ResourceDescriptor type.
                 * @member {string} type
                 * @memberof google.api.ResourceDescriptor
                 * @instance
                 */
                ResourceDescriptor.prototype.type = "";
    
                /**
                 * ResourceDescriptor pattern.
                 * @member {Array.<string>} pattern
                 * @memberof google.api.ResourceDescriptor
                 * @instance
                 */
                ResourceDescriptor.prototype.pattern = $util.emptyArray;
    
                /**
                 * ResourceDescriptor nameField.
                 * @member {string} nameField
                 * @memberof google.api.ResourceDescriptor
                 * @instance
                 */
                ResourceDescriptor.prototype.nameField = "";
    
                /**
                 * ResourceDescriptor history.
                 * @member {google.api.ResourceDescriptor.History} history
                 * @memberof google.api.ResourceDescriptor
                 * @instance
                 */
                ResourceDescriptor.prototype.history = 0;
    
                /**
                 * ResourceDescriptor plural.
                 * @member {string} plural
                 * @memberof google.api.ResourceDescriptor
                 * @instance
                 */
                ResourceDescriptor.prototype.plural = "";
    
                /**
                 * ResourceDescriptor singular.
                 * @member {string} singular
                 * @memberof google.api.ResourceDescriptor
                 * @instance
                 */
                ResourceDescriptor.prototype.singular = "";
    
                /**
                 * ResourceDescriptor style.
                 * @member {Array.<google.api.ResourceDescriptor.Style>} style
                 * @memberof google.api.ResourceDescriptor
                 * @instance
                 */
                ResourceDescriptor.prototype.style = $util.emptyArray;
    
                /**
                 * Creates a new ResourceDescriptor instance using the specified properties.
                 * @function create
                 * @memberof google.api.ResourceDescriptor
                 * @static
                 * @param {google.api.IResourceDescriptor=} [properties] Properties to set
                 * @returns {google.api.ResourceDescriptor} ResourceDescriptor instance
                 */
                ResourceDescriptor.create = function create(properties) {
                    return new ResourceDescriptor(properties);
                };
    
                /**
                 * Encodes the specified ResourceDescriptor message. Does not implicitly {@link google.api.ResourceDescriptor.verify|verify} messages.
                 * @function encode
                 * @memberof google.api.ResourceDescriptor
                 * @static
                 * @param {google.api.IResourceDescriptor} message ResourceDescriptor message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                ResourceDescriptor.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.type != null && Object.hasOwnProperty.call(message, "type"))
                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.type);
                    if (message.pattern != null && message.pattern.length)
                        for (var i = 0; i < message.pattern.length; ++i)
                            writer.uint32(/* id 2, wireType 2 =*/18).string(message.pattern[i]);
                    if (message.nameField != null && Object.hasOwnProperty.call(message, "nameField"))
                        writer.uint32(/* id 3, wireType 2 =*/26).string(message.nameField);
                    if (message.history != null && Object.hasOwnProperty.call(message, "history"))
                        writer.uint32(/* id 4, wireType 0 =*/32).int32(message.history);
                    if (message.plural != null && Object.hasOwnProperty.call(message, "plural"))
                        writer.uint32(/* id 5, wireType 2 =*/42).string(message.plural);
                    if (message.singular != null && Object.hasOwnProperty.call(message, "singular"))
                        writer.uint32(/* id 6, wireType 2 =*/50).string(message.singular);
                    if (message.style != null && message.style.length) {
                        writer.uint32(/* id 10, wireType 2 =*/82).fork();
                        for (var i = 0; i < message.style.length; ++i)
                            writer.int32(message.style[i]);
                        writer.ldelim();
                    }
                    return writer;
                };
    
                /**
                 * Encodes the specified ResourceDescriptor message, length delimited. Does not implicitly {@link google.api.ResourceDescriptor.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.api.ResourceDescriptor
                 * @static
                 * @param {google.api.IResourceDescriptor} message ResourceDescriptor message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                ResourceDescriptor.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes a ResourceDescriptor message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.api.ResourceDescriptor
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.api.ResourceDescriptor} ResourceDescriptor
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                ResourceDescriptor.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.api.ResourceDescriptor();
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 1: {
                                message.type = reader.string();
                                break;
                            }
                        case 2: {
                                if (!(message.pattern && message.pattern.length))
                                    message.pattern = [];
                                message.pattern.push(reader.string());
                                break;
                            }
                        case 3: {
                                message.nameField = reader.string();
                                break;
                            }
                        case 4: {
                                message.history = reader.int32();
                                break;
                            }
                        case 5: {
                                message.plural = reader.string();
                                break;
                            }
                        case 6: {
                                message.singular = reader.string();
                                break;
                            }
                        case 10: {
                                if (!(message.style && message.style.length))
                                    message.style = [];
                                if ((tag & 7) === 2) {
                                    var end2 = reader.uint32() + reader.pos;
                                    while (reader.pos < end2)
                                        message.style.push(reader.int32());
                                } else
                                    message.style.push(reader.int32());
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes a ResourceDescriptor message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.api.ResourceDescriptor
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.api.ResourceDescriptor} ResourceDescriptor
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                ResourceDescriptor.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies a ResourceDescriptor message.
                 * @function verify
                 * @memberof google.api.ResourceDescriptor
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                ResourceDescriptor.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    if (message.type != null && message.hasOwnProperty("type"))
                        if (!$util.isString(message.type))
                            return "type: string expected";
                    if (message.pattern != null && message.hasOwnProperty("pattern")) {
                        if (!Array.isArray(message.pattern))
                            return "pattern: array expected";
                        for (var i = 0; i < message.pattern.length; ++i)
                            if (!$util.isString(message.pattern[i]))
                                return "pattern: string[] expected";
                    }
                    if (message.nameField != null && message.hasOwnProperty("nameField"))
                        if (!$util.isString(message.nameField))
                            return "nameField: string expected";
                    if (message.history != null && message.hasOwnProperty("history"))
                        switch (message.history) {
                        default:
                            return "history: enum value expected";
                        case 0:
                        case 1:
                        case 2:
                            break;
                        }
                    if (message.plural != null && message.hasOwnProperty("plural"))
                        if (!$util.isString(message.plural))
                            return "plural: string expected";
                    if (message.singular != null && message.hasOwnProperty("singular"))
                        if (!$util.isString(message.singular))
                            return "singular: string expected";
                    if (message.style != null && message.hasOwnProperty("style")) {
                        if (!Array.isArray(message.style))
                            return "style: array expected";
                        for (var i = 0; i < message.style.length; ++i)
                            switch (message.style[i]) {
                            default:
                                return "style: enum value[] expected";
                            case 0:
                            case 1:
                                break;
                            }
                    }
                    return null;
                };
    
                /**
                 * Creates a ResourceDescriptor message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.api.ResourceDescriptor
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.api.ResourceDescriptor} ResourceDescriptor
                 */
                ResourceDescriptor.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.api.ResourceDescriptor)
                        return object;
                    var message = new $root.google.api.ResourceDescriptor();
                    if (object.type != null)
                        message.type = String(object.type);
                    if (object.pattern) {
                        if (!Array.isArray(object.pattern))
                            throw TypeError(".google.api.ResourceDescriptor.pattern: array expected");
                        message.pattern = [];
                        for (var i = 0; i < object.pattern.length; ++i)
                            message.pattern[i] = String(object.pattern[i]);
                    }
                    if (object.nameField != null)
                        message.nameField = String(object.nameField);
                    switch (object.history) {
                    default:
                        if (typeof object.history === "number") {
                            message.history = object.history;
                            break;
                        }
                        break;
                    case "HISTORY_UNSPECIFIED":
                    case 0:
                        message.history = 0;
                        break;
                    case "ORIGINALLY_SINGLE_PATTERN":
                    case 1:
                        message.history = 1;
                        break;
                    case "FUTURE_MULTI_PATTERN":
                    case 2:
                        message.history = 2;
                        break;
                    }
                    if (object.plural != null)
                        message.plural = String(object.plural);
                    if (object.singular != null)
                        message.singular = String(object.singular);
                    if (object.style) {
                        if (!Array.isArray(object.style))
                            throw TypeError(".google.api.ResourceDescriptor.style: array expected");
                        message.style = [];
                        for (var i = 0; i < object.style.length; ++i)
                            switch (object.style[i]) {
                            default:
                                if (typeof object.style[i] === "number") {
                                    message.style[i] = object.style[i];
                                    break;
                                }
                            case "STYLE_UNSPECIFIED":
                            case 0:
                                message.style[i] = 0;
                                break;
                            case "DECLARATIVE_FRIENDLY":
                            case 1:
                                message.style[i] = 1;
                                break;
                            }
                    }
                    return message;
                };
    
                /**
                 * Creates a plain object from a ResourceDescriptor message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.api.ResourceDescriptor
                 * @static
                 * @param {google.api.ResourceDescriptor} message ResourceDescriptor
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                ResourceDescriptor.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (options.arrays || options.defaults) {
                        object.pattern = [];
                        object.style = [];
                    }
                    if (options.defaults) {
                        object.type = "";
                        object.nameField = "";
                        object.history = options.enums === String ? "HISTORY_UNSPECIFIED" : 0;
                        object.plural = "";
                        object.singular = "";
                    }
                    if (message.type != null && message.hasOwnProperty("type"))
                        object.type = message.type;
                    if (message.pattern && message.pattern.length) {
                        object.pattern = [];
                        for (var j = 0; j < message.pattern.length; ++j)
                            object.pattern[j] = message.pattern[j];
                    }
                    if (message.nameField != null && message.hasOwnProperty("nameField"))
                        object.nameField = message.nameField;
                    if (message.history != null && message.hasOwnProperty("history"))
                        object.history = options.enums === String ? $root.google.api.ResourceDescriptor.History[message.history] === undefined ? message.history : $root.google.api.ResourceDescriptor.History[message.history] : message.history;
                    if (message.plural != null && message.hasOwnProperty("plural"))
                        object.plural = message.plural;
                    if (message.singular != null && message.hasOwnProperty("singular"))
                        object.singular = message.singular;
                    if (message.style && message.style.length) {
                        object.style = [];
                        for (var j = 0; j < message.style.length; ++j)
                            object.style[j] = options.enums === String ? $root.google.api.ResourceDescriptor.Style[message.style[j]] === undefined ? message.style[j] : $root.google.api.ResourceDescriptor.Style[message.style[j]] : message.style[j];
                    }
                    return object;
                };
    
                /**
                 * Converts this ResourceDescriptor to JSON.
                 * @function toJSON
                 * @memberof google.api.ResourceDescriptor
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                ResourceDescriptor.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for ResourceDescriptor
                 * @function getTypeUrl
                 * @memberof google.api.ResourceDescriptor
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                ResourceDescriptor.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.api.ResourceDescriptor";
                };
    
                /**
                 * History enum.
                 * @name google.api.ResourceDescriptor.History
                 * @enum {number}
                 * @property {number} HISTORY_UNSPECIFIED=0 HISTORY_UNSPECIFIED value
                 * @property {number} ORIGINALLY_SINGLE_PATTERN=1 ORIGINALLY_SINGLE_PATTERN value
                 * @property {number} FUTURE_MULTI_PATTERN=2 FUTURE_MULTI_PATTERN value
                 */
                ResourceDescriptor.History = (function() {
                    var valuesById = {}, values = Object.create(valuesById);
                    values[valuesById[0] = "HISTORY_UNSPECIFIED"] = 0;
                    values[valuesById[1] = "ORIGINALLY_SINGLE_PATTERN"] = 1;
                    values[valuesById[2] = "FUTURE_MULTI_PATTERN"] = 2;
                    return values;
                })();
    
                /**
                 * Style enum.
                 * @name google.api.ResourceDescriptor.Style
                 * @enum {number}
                 * @property {number} STYLE_UNSPECIFIED=0 STYLE_UNSPECIFIED value
                 * @property {number} DECLARATIVE_FRIENDLY=1 DECLARATIVE_FRIENDLY value
                 */
                ResourceDescriptor.Style = (function() {
                    var valuesById = {}, values = Object.create(valuesById);
                    values[valuesById[0] = "STYLE_UNSPECIFIED"] = 0;
                    values[valuesById[1] = "DECLARATIVE_FRIENDLY"] = 1;
                    return values;
                })();
    
                return ResourceDescriptor;
            })();
    
            api.ResourceReference = (function() {
    
                /**
                 * Properties of a ResourceReference.
                 * @memberof google.api
                 * @interface IResourceReference
                 * @property {string|null} [type] ResourceReference type
                 * @property {string|null} [childType] ResourceReference childType
                 */
    
                /**
                 * Constructs a new ResourceReference.
                 * @memberof google.api
                 * @classdesc Represents a ResourceReference.
                 * @implements IResourceReference
                 * @constructor
                 * @param {google.api.IResourceReference=} [properties] Properties to set
                 */
                function ResourceReference(properties) {
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * ResourceReference type.
                 * @member {string} type
                 * @memberof google.api.ResourceReference
                 * @instance
                 */
                ResourceReference.prototype.type = "";
    
                /**
                 * ResourceReference childType.
                 * @member {string} childType
                 * @memberof google.api.ResourceReference
                 * @instance
                 */
                ResourceReference.prototype.childType = "";
    
                /**
                 * Creates a new ResourceReference instance using the specified properties.
                 * @function create
                 * @memberof google.api.ResourceReference
                 * @static
                 * @param {google.api.IResourceReference=} [properties] Properties to set
                 * @returns {google.api.ResourceReference} ResourceReference instance
                 */
                ResourceReference.create = function create(properties) {
                    return new ResourceReference(properties);
                };
    
                /**
                 * Encodes the specified ResourceReference message. Does not implicitly {@link google.api.ResourceReference.verify|verify} messages.
                 * @function encode
                 * @memberof google.api.ResourceReference
                 * @static
                 * @param {google.api.IResourceReference} message ResourceReference message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                ResourceReference.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.type != null && Object.hasOwnProperty.call(message, "type"))
                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.type);
                    if (message.childType != null && Object.hasOwnProperty.call(message, "childType"))
                        writer.uint32(/* id 2, wireType 2 =*/18).string(message.childType);
                    return writer;
                };
    
                /**
                 * Encodes the specified ResourceReference message, length delimited. Does not implicitly {@link google.api.ResourceReference.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.api.ResourceReference
                 * @static
                 * @param {google.api.IResourceReference} message ResourceReference message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                ResourceReference.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes a ResourceReference message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.api.ResourceReference
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.api.ResourceReference} ResourceReference
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                ResourceReference.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.api.ResourceReference();
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 1: {
                                message.type = reader.string();
                                break;
                            }
                        case 2: {
                                message.childType = reader.string();
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes a ResourceReference message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.api.ResourceReference
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.api.ResourceReference} ResourceReference
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                ResourceReference.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies a ResourceReference message.
                 * @function verify
                 * @memberof google.api.ResourceReference
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                ResourceReference.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    if (message.type != null && message.hasOwnProperty("type"))
                        if (!$util.isString(message.type))
                            return "type: string expected";
                    if (message.childType != null && message.hasOwnProperty("childType"))
                        if (!$util.isString(message.childType))
                            return "childType: string expected";
                    return null;
                };
    
                /**
                 * Creates a ResourceReference message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.api.ResourceReference
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.api.ResourceReference} ResourceReference
                 */
                ResourceReference.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.api.ResourceReference)
                        return object;
                    var message = new $root.google.api.ResourceReference();
                    if (object.type != null)
                        message.type = String(object.type);
                    if (object.childType != null)
                        message.childType = String(object.childType);
                    return message;
                };
    
                /**
                 * Creates a plain object from a ResourceReference message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.api.ResourceReference
                 * @static
                 * @param {google.api.ResourceReference} message ResourceReference
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                ResourceReference.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (options.defaults) {
                        object.type = "";
                        object.childType = "";
                    }
                    if (message.type != null && message.hasOwnProperty("type"))
                        object.type = message.type;
                    if (message.childType != null && message.hasOwnProperty("childType"))
                        object.childType = message.childType;
                    return object;
                };
    
                /**
                 * Converts this ResourceReference to JSON.
                 * @function toJSON
                 * @memberof google.api.ResourceReference
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                ResourceReference.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for ResourceReference
                 * @function getTypeUrl
                 * @memberof google.api.ResourceReference
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                ResourceReference.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.api.ResourceReference";
                };
    
                return ResourceReference;
            })();
    
            return api;
        })();
    
        google.protobuf = (function() {
    
            /**
             * Namespace protobuf.
             * @memberof google
             * @namespace
             */
            var protobuf = {};
    
            protobuf.FileDescriptorSet = (function() {
    
                /**
                 * Properties of a FileDescriptorSet.
                 * @memberof google.protobuf
                 * @interface IFileDescriptorSet
                 * @property {Array.<google.protobuf.IFileDescriptorProto>|null} [file] FileDescriptorSet file
                 */
    
                /**
                 * Constructs a new FileDescriptorSet.
                 * @memberof google.protobuf
                 * @classdesc Represents a FileDescriptorSet.
                 * @implements IFileDescriptorSet
                 * @constructor
                 * @param {google.protobuf.IFileDescriptorSet=} [properties] Properties to set
                 */
                function FileDescriptorSet(properties) {
                    this.file = [];
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * FileDescriptorSet file.
                 * @member {Array.<google.protobuf.IFileDescriptorProto>} file
                 * @memberof google.protobuf.FileDescriptorSet
                 * @instance
                 */
                FileDescriptorSet.prototype.file = $util.emptyArray;
    
                /**
                 * Creates a new FileDescriptorSet instance using the specified properties.
                 * @function create
                 * @memberof google.protobuf.FileDescriptorSet
                 * @static
                 * @param {google.protobuf.IFileDescriptorSet=} [properties] Properties to set
                 * @returns {google.protobuf.FileDescriptorSet} FileDescriptorSet instance
                 */
                FileDescriptorSet.create = function create(properties) {
                    return new FileDescriptorSet(properties);
                };
    
                /**
                 * Encodes the specified FileDescriptorSet message. Does not implicitly {@link google.protobuf.FileDescriptorSet.verify|verify} messages.
                 * @function encode
                 * @memberof google.protobuf.FileDescriptorSet
                 * @static
                 * @param {google.protobuf.IFileDescriptorSet} message FileDescriptorSet message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                FileDescriptorSet.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.file != null && message.file.length)
                        for (var i = 0; i < message.file.length; ++i)
                            $root.google.protobuf.FileDescriptorProto.encode(message.file[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                    return writer;
                };
    
                /**
                 * Encodes the specified FileDescriptorSet message, length delimited. Does not implicitly {@link google.protobuf.FileDescriptorSet.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.protobuf.FileDescriptorSet
                 * @static
                 * @param {google.protobuf.IFileDescriptorSet} message FileDescriptorSet message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                FileDescriptorSet.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes a FileDescriptorSet message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.protobuf.FileDescriptorSet
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.protobuf.FileDescriptorSet} FileDescriptorSet
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                FileDescriptorSet.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.protobuf.FileDescriptorSet();
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 1: {
                                if (!(message.file && message.file.length))
                                    message.file = [];
                                message.file.push($root.google.protobuf.FileDescriptorProto.decode(reader, reader.uint32()));
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes a FileDescriptorSet message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.protobuf.FileDescriptorSet
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.protobuf.FileDescriptorSet} FileDescriptorSet
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                FileDescriptorSet.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies a FileDescriptorSet message.
                 * @function verify
                 * @memberof google.protobuf.FileDescriptorSet
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                FileDescriptorSet.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    if (message.file != null && message.hasOwnProperty("file")) {
                        if (!Array.isArray(message.file))
                            return "file: array expected";
                        for (var i = 0; i < message.file.length; ++i) {
                            var error = $root.google.protobuf.FileDescriptorProto.verify(message.file[i]);
                            if (error)
                                return "file." + error;
                        }
                    }
                    return null;
                };
    
                /**
                 * Creates a FileDescriptorSet message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.protobuf.FileDescriptorSet
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.protobuf.FileDescriptorSet} FileDescriptorSet
                 */
                FileDescriptorSet.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.protobuf.FileDescriptorSet)
                        return object;
                    var message = new $root.google.protobuf.FileDescriptorSet();
                    if (object.file) {
                        if (!Array.isArray(object.file))
                            throw TypeError(".google.protobuf.FileDescriptorSet.file: array expected");
                        message.file = [];
                        for (var i = 0; i < object.file.length; ++i) {
                            if (typeof object.file[i] !== "object")
                                throw TypeError(".google.protobuf.FileDescriptorSet.file: object expected");
                            message.file[i] = $root.google.protobuf.FileDescriptorProto.fromObject(object.file[i]);
                        }
                    }
                    return message;
                };
    
                /**
                 * Creates a plain object from a FileDescriptorSet message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.protobuf.FileDescriptorSet
                 * @static
                 * @param {google.protobuf.FileDescriptorSet} message FileDescriptorSet
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                FileDescriptorSet.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (options.arrays || options.defaults)
                        object.file = [];
                    if (message.file && message.file.length) {
                        object.file = [];
                        for (var j = 0; j < message.file.length; ++j)
                            object.file[j] = $root.google.protobuf.FileDescriptorProto.toObject(message.file[j], options);
                    }
                    return object;
                };
    
                /**
                 * Converts this FileDescriptorSet to JSON.
                 * @function toJSON
                 * @memberof google.protobuf.FileDescriptorSet
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                FileDescriptorSet.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for FileDescriptorSet
                 * @function getTypeUrl
                 * @memberof google.protobuf.FileDescriptorSet
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                FileDescriptorSet.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.protobuf.FileDescriptorSet";
                };
    
                return FileDescriptorSet;
            })();
    
            /**
             * Edition enum.
             * @name google.protobuf.Edition
             * @enum {number}
             * @property {number} EDITION_UNKNOWN=0 EDITION_UNKNOWN value
             * @property {number} EDITION_PROTO2=998 EDITION_PROTO2 value
             * @property {number} EDITION_PROTO3=999 EDITION_PROTO3 value
             * @property {number} EDITION_2023=1000 EDITION_2023 value
             * @property {number} EDITION_2024=1001 EDITION_2024 value
             * @property {number} EDITION_1_TEST_ONLY=1 EDITION_1_TEST_ONLY value
             * @property {number} EDITION_2_TEST_ONLY=2 EDITION_2_TEST_ONLY value
             * @property {number} EDITION_99997_TEST_ONLY=99997 EDITION_99997_TEST_ONLY value
             * @property {number} EDITION_99998_TEST_ONLY=99998 EDITION_99998_TEST_ONLY value
             * @property {number} EDITION_99999_TEST_ONLY=99999 EDITION_99999_TEST_ONLY value
             * @property {number} EDITION_MAX=2147483647 EDITION_MAX value
             */
            protobuf.Edition = (function() {
                var valuesById = {}, values = Object.create(valuesById);
                values[valuesById[0] = "EDITION_UNKNOWN"] = 0;
                values[valuesById[998] = "EDITION_PROTO2"] = 998;
                values[valuesById[999] = "EDITION_PROTO3"] = 999;
                values[valuesById[1000] = "EDITION_2023"] = 1000;
                values[valuesById[1001] = "EDITION_2024"] = 1001;
                values[valuesById[1] = "EDITION_1_TEST_ONLY"] = 1;
                values[valuesById[2] = "EDITION_2_TEST_ONLY"] = 2;
                values[valuesById[99997] = "EDITION_99997_TEST_ONLY"] = 99997;
                values[valuesById[99998] = "EDITION_99998_TEST_ONLY"] = 99998;
                values[valuesById[99999] = "EDITION_99999_TEST_ONLY"] = 99999;
                values[valuesById[2147483647] = "EDITION_MAX"] = 2147483647;
                return values;
            })();
    
            protobuf.FileDescriptorProto = (function() {
    
                /**
                 * Properties of a FileDescriptorProto.
                 * @memberof google.protobuf
                 * @interface IFileDescriptorProto
                 * @property {string|null} [name] FileDescriptorProto name
                 * @property {string|null} ["package"] FileDescriptorProto package
                 * @property {Array.<string>|null} [dependency] FileDescriptorProto dependency
                 * @property {Array.<number>|null} [publicDependency] FileDescriptorProto publicDependency
                 * @property {Array.<number>|null} [weakDependency] FileDescriptorProto weakDependency
                 * @property {Array.<google.protobuf.IDescriptorProto>|null} [messageType] FileDescriptorProto messageType
                 * @property {Array.<google.protobuf.IEnumDescriptorProto>|null} [enumType] FileDescriptorProto enumType
                 * @property {Array.<google.protobuf.IServiceDescriptorProto>|null} [service] FileDescriptorProto service
                 * @property {Array.<google.protobuf.IFieldDescriptorProto>|null} [extension] FileDescriptorProto extension
                 * @property {google.protobuf.IFileOptions|null} [options] FileDescriptorProto options
                 * @property {google.protobuf.ISourceCodeInfo|null} [sourceCodeInfo] FileDescriptorProto sourceCodeInfo
                 * @property {string|null} [syntax] FileDescriptorProto syntax
                 * @property {google.protobuf.Edition|null} [edition] FileDescriptorProto edition
                 */
    
                /**
                 * Constructs a new FileDescriptorProto.
                 * @memberof google.protobuf
                 * @classdesc Represents a FileDescriptorProto.
                 * @implements IFileDescriptorProto
                 * @constructor
                 * @param {google.protobuf.IFileDescriptorProto=} [properties] Properties to set
                 */
                function FileDescriptorProto(properties) {
                    this.dependency = [];
                    this.publicDependency = [];
                    this.weakDependency = [];
                    this.messageType = [];
                    this.enumType = [];
                    this.service = [];
                    this.extension = [];
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * FileDescriptorProto name.
                 * @member {string} name
                 * @memberof google.protobuf.FileDescriptorProto
                 * @instance
                 */
                FileDescriptorProto.prototype.name = "";
    
                /**
                 * FileDescriptorProto package.
                 * @member {string} package
                 * @memberof google.protobuf.FileDescriptorProto
                 * @instance
                 */
                FileDescriptorProto.prototype["package"] = "";
    
                /**
                 * FileDescriptorProto dependency.
                 * @member {Array.<string>} dependency
                 * @memberof google.protobuf.FileDescriptorProto
                 * @instance
                 */
                FileDescriptorProto.prototype.dependency = $util.emptyArray;
    
                /**
                 * FileDescriptorProto publicDependency.
                 * @member {Array.<number>} publicDependency
                 * @memberof google.protobuf.FileDescriptorProto
                 * @instance
                 */
                FileDescriptorProto.prototype.publicDependency = $util.emptyArray;
    
                /**
                 * FileDescriptorProto weakDependency.
                 * @member {Array.<number>} weakDependency
                 * @memberof google.protobuf.FileDescriptorProto
                 * @instance
                 */
                FileDescriptorProto.prototype.weakDependency = $util.emptyArray;
    
                /**
                 * FileDescriptorProto messageType.
                 * @member {Array.<google.protobuf.IDescriptorProto>} messageType
                 * @memberof google.protobuf.FileDescriptorProto
                 * @instance
                 */
                FileDescriptorProto.prototype.messageType = $util.emptyArray;
    
                /**
                 * FileDescriptorProto enumType.
                 * @member {Array.<google.protobuf.IEnumDescriptorProto>} enumType
                 * @memberof google.protobuf.FileDescriptorProto
                 * @instance
                 */
                FileDescriptorProto.prototype.enumType = $util.emptyArray;
    
                /**
                 * FileDescriptorProto service.
                 * @member {Array.<google.protobuf.IServiceDescriptorProto>} service
                 * @memberof google.protobuf.FileDescriptorProto
                 * @instance
                 */
                FileDescriptorProto.prototype.service = $util.emptyArray;
    
                /**
                 * FileDescriptorProto extension.
                 * @member {Array.<google.protobuf.IFieldDescriptorProto>} extension
                 * @memberof google.protobuf.FileDescriptorProto
                 * @instance
                 */
                FileDescriptorProto.prototype.extension = $util.emptyArray;
    
                /**
                 * FileDescriptorProto options.
                 * @member {google.protobuf.IFileOptions|null|undefined} options
                 * @memberof google.protobuf.FileDescriptorProto
                 * @instance
                 */
                FileDescriptorProto.prototype.options = null;
    
                /**
                 * FileDescriptorProto sourceCodeInfo.
                 * @member {google.protobuf.ISourceCodeInfo|null|undefined} sourceCodeInfo
                 * @memberof google.protobuf.FileDescriptorProto
                 * @instance
                 */
                FileDescriptorProto.prototype.sourceCodeInfo = null;
    
                /**
                 * FileDescriptorProto syntax.
                 * @member {string} syntax
                 * @memberof google.protobuf.FileDescriptorProto
                 * @instance
                 */
                FileDescriptorProto.prototype.syntax = "";
    
                /**
                 * FileDescriptorProto edition.
                 * @member {google.protobuf.Edition} edition
                 * @memberof google.protobuf.FileDescriptorProto
                 * @instance
                 */
                FileDescriptorProto.prototype.edition = 0;
    
                /**
                 * Creates a new FileDescriptorProto instance using the specified properties.
                 * @function create
                 * @memberof google.protobuf.FileDescriptorProto
                 * @static
                 * @param {google.protobuf.IFileDescriptorProto=} [properties] Properties to set
                 * @returns {google.protobuf.FileDescriptorProto} FileDescriptorProto instance
                 */
                FileDescriptorProto.create = function create(properties) {
                    return new FileDescriptorProto(properties);
                };
    
                /**
                 * Encodes the specified FileDescriptorProto message. Does not implicitly {@link google.protobuf.FileDescriptorProto.verify|verify} messages.
                 * @function encode
                 * @memberof google.protobuf.FileDescriptorProto
                 * @static
                 * @param {google.protobuf.IFileDescriptorProto} message FileDescriptorProto message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                FileDescriptorProto.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                    if (message["package"] != null && Object.hasOwnProperty.call(message, "package"))
                        writer.uint32(/* id 2, wireType 2 =*/18).string(message["package"]);
                    if (message.dependency != null && message.dependency.length)
                        for (var i = 0; i < message.dependency.length; ++i)
                            writer.uint32(/* id 3, wireType 2 =*/26).string(message.dependency[i]);
                    if (message.messageType != null && message.messageType.length)
                        for (var i = 0; i < message.messageType.length; ++i)
                            $root.google.protobuf.DescriptorProto.encode(message.messageType[i], writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                    if (message.enumType != null && message.enumType.length)
                        for (var i = 0; i < message.enumType.length; ++i)
                            $root.google.protobuf.EnumDescriptorProto.encode(message.enumType[i], writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                    if (message.service != null && message.service.length)
                        for (var i = 0; i < message.service.length; ++i)
                            $root.google.protobuf.ServiceDescriptorProto.encode(message.service[i], writer.uint32(/* id 6, wireType 2 =*/50).fork()).ldelim();
                    if (message.extension != null && message.extension.length)
                        for (var i = 0; i < message.extension.length; ++i)
                            $root.google.protobuf.FieldDescriptorProto.encode(message.extension[i], writer.uint32(/* id 7, wireType 2 =*/58).fork()).ldelim();
                    if (message.options != null && Object.hasOwnProperty.call(message, "options"))
                        $root.google.protobuf.FileOptions.encode(message.options, writer.uint32(/* id 8, wireType 2 =*/66).fork()).ldelim();
                    if (message.sourceCodeInfo != null && Object.hasOwnProperty.call(message, "sourceCodeInfo"))
                        $root.google.protobuf.SourceCodeInfo.encode(message.sourceCodeInfo, writer.uint32(/* id 9, wireType 2 =*/74).fork()).ldelim();
                    if (message.publicDependency != null && message.publicDependency.length)
                        for (var i = 0; i < message.publicDependency.length; ++i)
                            writer.uint32(/* id 10, wireType 0 =*/80).int32(message.publicDependency[i]);
                    if (message.weakDependency != null && message.weakDependency.length)
                        for (var i = 0; i < message.weakDependency.length; ++i)
                            writer.uint32(/* id 11, wireType 0 =*/88).int32(message.weakDependency[i]);
                    if (message.syntax != null && Object.hasOwnProperty.call(message, "syntax"))
                        writer.uint32(/* id 12, wireType 2 =*/98).string(message.syntax);
                    if (message.edition != null && Object.hasOwnProperty.call(message, "edition"))
                        writer.uint32(/* id 14, wireType 0 =*/112).int32(message.edition);
                    return writer;
                };
    
                /**
                 * Encodes the specified FileDescriptorProto message, length delimited. Does not implicitly {@link google.protobuf.FileDescriptorProto.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.protobuf.FileDescriptorProto
                 * @static
                 * @param {google.protobuf.IFileDescriptorProto} message FileDescriptorProto message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                FileDescriptorProto.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes a FileDescriptorProto message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.protobuf.FileDescriptorProto
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.protobuf.FileDescriptorProto} FileDescriptorProto
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                FileDescriptorProto.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.protobuf.FileDescriptorProto();
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 1: {
                                message.name = reader.string();
                                break;
                            }
                        case 2: {
                                message["package"] = reader.string();
                                break;
                            }
                        case 3: {
                                if (!(message.dependency && message.dependency.length))
                                    message.dependency = [];
                                message.dependency.push(reader.string());
                                break;
                            }
                        case 10: {
                                if (!(message.publicDependency && message.publicDependency.length))
                                    message.publicDependency = [];
                                if ((tag & 7) === 2) {
                                    var end2 = reader.uint32() + reader.pos;
                                    while (reader.pos < end2)
                                        message.publicDependency.push(reader.int32());
                                } else
                                    message.publicDependency.push(reader.int32());
                                break;
                            }
                        case 11: {
                                if (!(message.weakDependency && message.weakDependency.length))
                                    message.weakDependency = [];
                                if ((tag & 7) === 2) {
                                    var end2 = reader.uint32() + reader.pos;
                                    while (reader.pos < end2)
                                        message.weakDependency.push(reader.int32());
                                } else
                                    message.weakDependency.push(reader.int32());
                                break;
                            }
                        case 4: {
                                if (!(message.messageType && message.messageType.length))
                                    message.messageType = [];
                                message.messageType.push($root.google.protobuf.DescriptorProto.decode(reader, reader.uint32()));
                                break;
                            }
                        case 5: {
                                if (!(message.enumType && message.enumType.length))
                                    message.enumType = [];
                                message.enumType.push($root.google.protobuf.EnumDescriptorProto.decode(reader, reader.uint32()));
                                break;
                            }
                        case 6: {
                                if (!(message.service && message.service.length))
                                    message.service = [];
                                message.service.push($root.google.protobuf.ServiceDescriptorProto.decode(reader, reader.uint32()));
                                break;
                            }
                        case 7: {
                                if (!(message.extension && message.extension.length))
                                    message.extension = [];
                                message.extension.push($root.google.protobuf.FieldDescriptorProto.decode(reader, reader.uint32()));
                                break;
                            }
                        case 8: {
                                message.options = $root.google.protobuf.FileOptions.decode(reader, reader.uint32());
                                break;
                            }
                        case 9: {
                                message.sourceCodeInfo = $root.google.protobuf.SourceCodeInfo.decode(reader, reader.uint32());
                                break;
                            }
                        case 12: {
                                message.syntax = reader.string();
                                break;
                            }
                        case 14: {
                                message.edition = reader.int32();
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes a FileDescriptorProto message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.protobuf.FileDescriptorProto
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.protobuf.FileDescriptorProto} FileDescriptorProto
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                FileDescriptorProto.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies a FileDescriptorProto message.
                 * @function verify
                 * @memberof google.protobuf.FileDescriptorProto
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                FileDescriptorProto.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    if (message.name != null && message.hasOwnProperty("name"))
                        if (!$util.isString(message.name))
                            return "name: string expected";
                    if (message["package"] != null && message.hasOwnProperty("package"))
                        if (!$util.isString(message["package"]))
                            return "package: string expected";
                    if (message.dependency != null && message.hasOwnProperty("dependency")) {
                        if (!Array.isArray(message.dependency))
                            return "dependency: array expected";
                        for (var i = 0; i < message.dependency.length; ++i)
                            if (!$util.isString(message.dependency[i]))
                                return "dependency: string[] expected";
                    }
                    if (message.publicDependency != null && message.hasOwnProperty("publicDependency")) {
                        if (!Array.isArray(message.publicDependency))
                            return "publicDependency: array expected";
                        for (var i = 0; i < message.publicDependency.length; ++i)
                            if (!$util.isInteger(message.publicDependency[i]))
                                return "publicDependency: integer[] expected";
                    }
                    if (message.weakDependency != null && message.hasOwnProperty("weakDependency")) {
                        if (!Array.isArray(message.weakDependency))
                            return "weakDependency: array expected";
                        for (var i = 0; i < message.weakDependency.length; ++i)
                            if (!$util.isInteger(message.weakDependency[i]))
                                return "weakDependency: integer[] expected";
                    }
                    if (message.messageType != null && message.hasOwnProperty("messageType")) {
                        if (!Array.isArray(message.messageType))
                            return "messageType: array expected";
                        for (var i = 0; i < message.messageType.length; ++i) {
                            var error = $root.google.protobuf.DescriptorProto.verify(message.messageType[i]);
                            if (error)
                                return "messageType." + error;
                        }
                    }
                    if (message.enumType != null && message.hasOwnProperty("enumType")) {
                        if (!Array.isArray(message.enumType))
                            return "enumType: array expected";
                        for (var i = 0; i < message.enumType.length; ++i) {
                            var error = $root.google.protobuf.EnumDescriptorProto.verify(message.enumType[i]);
                            if (error)
                                return "enumType." + error;
                        }
                    }
                    if (message.service != null && message.hasOwnProperty("service")) {
                        if (!Array.isArray(message.service))
                            return "service: array expected";
                        for (var i = 0; i < message.service.length; ++i) {
                            var error = $root.google.protobuf.ServiceDescriptorProto.verify(message.service[i]);
                            if (error)
                                return "service." + error;
                        }
                    }
                    if (message.extension != null && message.hasOwnProperty("extension")) {
                        if (!Array.isArray(message.extension))
                            return "extension: array expected";
                        for (var i = 0; i < message.extension.length; ++i) {
                            var error = $root.google.protobuf.FieldDescriptorProto.verify(message.extension[i]);
                            if (error)
                                return "extension." + error;
                        }
                    }
                    if (message.options != null && message.hasOwnProperty("options")) {
                        var error = $root.google.protobuf.FileOptions.verify(message.options);
                        if (error)
                            return "options." + error;
                    }
                    if (message.sourceCodeInfo != null && message.hasOwnProperty("sourceCodeInfo")) {
                        var error = $root.google.protobuf.SourceCodeInfo.verify(message.sourceCodeInfo);
                        if (error)
                            return "sourceCodeInfo." + error;
                    }
                    if (message.syntax != null && message.hasOwnProperty("syntax"))
                        if (!$util.isString(message.syntax))
                            return "syntax: string expected";
                    if (message.edition != null && message.hasOwnProperty("edition"))
                        switch (message.edition) {
                        default:
                            return "edition: enum value expected";
                        case 0:
                        case 998:
                        case 999:
                        case 1000:
                        case 1001:
                        case 1:
                        case 2:
                        case 99997:
                        case 99998:
                        case 99999:
                        case 2147483647:
                            break;
                        }
                    return null;
                };
    
                /**
                 * Creates a FileDescriptorProto message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.protobuf.FileDescriptorProto
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.protobuf.FileDescriptorProto} FileDescriptorProto
                 */
                FileDescriptorProto.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.protobuf.FileDescriptorProto)
                        return object;
                    var message = new $root.google.protobuf.FileDescriptorProto();
                    if (object.name != null)
                        message.name = String(object.name);
                    if (object["package"] != null)
                        message["package"] = String(object["package"]);
                    if (object.dependency) {
                        if (!Array.isArray(object.dependency))
                            throw TypeError(".google.protobuf.FileDescriptorProto.dependency: array expected");
                        message.dependency = [];
                        for (var i = 0; i < object.dependency.length; ++i)
                            message.dependency[i] = String(object.dependency[i]);
                    }
                    if (object.publicDependency) {
                        if (!Array.isArray(object.publicDependency))
                            throw TypeError(".google.protobuf.FileDescriptorProto.publicDependency: array expected");
                        message.publicDependency = [];
                        for (var i = 0; i < object.publicDependency.length; ++i)
                            message.publicDependency[i] = object.publicDependency[i] | 0;
                    }
                    if (object.weakDependency) {
                        if (!Array.isArray(object.weakDependency))
                            throw TypeError(".google.protobuf.FileDescriptorProto.weakDependency: array expected");
                        message.weakDependency = [];
                        for (var i = 0; i < object.weakDependency.length; ++i)
                            message.weakDependency[i] = object.weakDependency[i] | 0;
                    }
                    if (object.messageType) {
                        if (!Array.isArray(object.messageType))
                            throw TypeError(".google.protobuf.FileDescriptorProto.messageType: array expected");
                        message.messageType = [];
                        for (var i = 0; i < object.messageType.length; ++i) {
                            if (typeof object.messageType[i] !== "object")
                                throw TypeError(".google.protobuf.FileDescriptorProto.messageType: object expected");
                            message.messageType[i] = $root.google.protobuf.DescriptorProto.fromObject(object.messageType[i]);
                        }
                    }
                    if (object.enumType) {
                        if (!Array.isArray(object.enumType))
                            throw TypeError(".google.protobuf.FileDescriptorProto.enumType: array expected");
                        message.enumType = [];
                        for (var i = 0; i < object.enumType.length; ++i) {
                            if (typeof object.enumType[i] !== "object")
                                throw TypeError(".google.protobuf.FileDescriptorProto.enumType: object expected");
                            message.enumType[i] = $root.google.protobuf.EnumDescriptorProto.fromObject(object.enumType[i]);
                        }
                    }
                    if (object.service) {
                        if (!Array.isArray(object.service))
                            throw TypeError(".google.protobuf.FileDescriptorProto.service: array expected");
                        message.service = [];
                        for (var i = 0; i < object.service.length; ++i) {
                            if (typeof object.service[i] !== "object")
                                throw TypeError(".google.protobuf.FileDescriptorProto.service: object expected");
                            message.service[i] = $root.google.protobuf.ServiceDescriptorProto.fromObject(object.service[i]);
                        }
                    }
                    if (object.extension) {
                        if (!Array.isArray(object.extension))
                            throw TypeError(".google.protobuf.FileDescriptorProto.extension: array expected");
                        message.extension = [];
                        for (var i = 0; i < object.extension.length; ++i) {
                            if (typeof object.extension[i] !== "object")
                                throw TypeError(".google.protobuf.FileDescriptorProto.extension: object expected");
                            message.extension[i] = $root.google.protobuf.FieldDescriptorProto.fromObject(object.extension[i]);
                        }
                    }
                    if (object.options != null) {
                        if (typeof object.options !== "object")
                            throw TypeError(".google.protobuf.FileDescriptorProto.options: object expected");
                        message.options = $root.google.protobuf.FileOptions.fromObject(object.options);
                    }
                    if (object.sourceCodeInfo != null) {
                        if (typeof object.sourceCodeInfo !== "object")
                            throw TypeError(".google.protobuf.FileDescriptorProto.sourceCodeInfo: object expected");
                        message.sourceCodeInfo = $root.google.protobuf.SourceCodeInfo.fromObject(object.sourceCodeInfo);
                    }
                    if (object.syntax != null)
                        message.syntax = String(object.syntax);
                    switch (object.edition) {
                    default:
                        if (typeof object.edition === "number") {
                            message.edition = object.edition;
                            break;
                        }
                        break;
                    case "EDITION_UNKNOWN":
                    case 0:
                        message.edition = 0;
                        break;
                    case "EDITION_PROTO2":
                    case 998:
                        message.edition = 998;
                        break;
                    case "EDITION_PROTO3":
                    case 999:
                        message.edition = 999;
                        break;
                    case "EDITION_2023":
                    case 1000:
                        message.edition = 1000;
                        break;
                    case "EDITION_2024":
                    case 1001:
                        message.edition = 1001;
                        break;
                    case "EDITION_1_TEST_ONLY":
                    case 1:
                        message.edition = 1;
                        break;
                    case "EDITION_2_TEST_ONLY":
                    case 2:
                        message.edition = 2;
                        break;
                    case "EDITION_99997_TEST_ONLY":
                    case 99997:
                        message.edition = 99997;
                        break;
                    case "EDITION_99998_TEST_ONLY":
                    case 99998:
                        message.edition = 99998;
                        break;
                    case "EDITION_99999_TEST_ONLY":
                    case 99999:
                        message.edition = 99999;
                        break;
                    case "EDITION_MAX":
                    case 2147483647:
                        message.edition = 2147483647;
                        break;
                    }
                    return message;
                };
    
                /**
                 * Creates a plain object from a FileDescriptorProto message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.protobuf.FileDescriptorProto
                 * @static
                 * @param {google.protobuf.FileDescriptorProto} message FileDescriptorProto
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                FileDescriptorProto.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (options.arrays || options.defaults) {
                        object.dependency = [];
                        object.messageType = [];
                        object.enumType = [];
                        object.service = [];
                        object.extension = [];
                        object.publicDependency = [];
                        object.weakDependency = [];
                    }
                    if (options.defaults) {
                        object.name = "";
                        object["package"] = "";
                        object.options = null;
                        object.sourceCodeInfo = null;
                        object.syntax = "";
                        object.edition = options.enums === String ? "EDITION_UNKNOWN" : 0;
                    }
                    if (message.name != null && message.hasOwnProperty("name"))
                        object.name = message.name;
                    if (message["package"] != null && message.hasOwnProperty("package"))
                        object["package"] = message["package"];
                    if (message.dependency && message.dependency.length) {
                        object.dependency = [];
                        for (var j = 0; j < message.dependency.length; ++j)
                            object.dependency[j] = message.dependency[j];
                    }
                    if (message.messageType && message.messageType.length) {
                        object.messageType = [];
                        for (var j = 0; j < message.messageType.length; ++j)
                            object.messageType[j] = $root.google.protobuf.DescriptorProto.toObject(message.messageType[j], options);
                    }
                    if (message.enumType && message.enumType.length) {
                        object.enumType = [];
                        for (var j = 0; j < message.enumType.length; ++j)
                            object.enumType[j] = $root.google.protobuf.EnumDescriptorProto.toObject(message.enumType[j], options);
                    }
                    if (message.service && message.service.length) {
                        object.service = [];
                        for (var j = 0; j < message.service.length; ++j)
                            object.service[j] = $root.google.protobuf.ServiceDescriptorProto.toObject(message.service[j], options);
                    }
                    if (message.extension && message.extension.length) {
                        object.extension = [];
                        for (var j = 0; j < message.extension.length; ++j)
                            object.extension[j] = $root.google.protobuf.FieldDescriptorProto.toObject(message.extension[j], options);
                    }
                    if (message.options != null && message.hasOwnProperty("options"))
                        object.options = $root.google.protobuf.FileOptions.toObject(message.options, options);
                    if (message.sourceCodeInfo != null && message.hasOwnProperty("sourceCodeInfo"))
                        object.sourceCodeInfo = $root.google.protobuf.SourceCodeInfo.toObject(message.sourceCodeInfo, options);
                    if (message.publicDependency && message.publicDependency.length) {
                        object.publicDependency = [];
                        for (var j = 0; j < message.publicDependency.length; ++j)
                            object.publicDependency[j] = message.publicDependency[j];
                    }
                    if (message.weakDependency && message.weakDependency.length) {
                        object.weakDependency = [];
                        for (var j = 0; j < message.weakDependency.length; ++j)
                            object.weakDependency[j] = message.weakDependency[j];
                    }
                    if (message.syntax != null && message.hasOwnProperty("syntax"))
                        object.syntax = message.syntax;
                    if (message.edition != null && message.hasOwnProperty("edition"))
                        object.edition = options.enums === String ? $root.google.protobuf.Edition[message.edition] === undefined ? message.edition : $root.google.protobuf.Edition[message.edition] : message.edition;
                    return object;
                };
    
                /**
                 * Converts this FileDescriptorProto to JSON.
                 * @function toJSON
                 * @memberof google.protobuf.FileDescriptorProto
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                FileDescriptorProto.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for FileDescriptorProto
                 * @function getTypeUrl
                 * @memberof google.protobuf.FileDescriptorProto
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                FileDescriptorProto.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.protobuf.FileDescriptorProto";
                };
    
                return FileDescriptorProto;
            })();
    
            protobuf.DescriptorProto = (function() {
    
                /**
                 * Properties of a DescriptorProto.
                 * @memberof google.protobuf
                 * @interface IDescriptorProto
                 * @property {string|null} [name] DescriptorProto name
                 * @property {Array.<google.protobuf.IFieldDescriptorProto>|null} [field] DescriptorProto field
                 * @property {Array.<google.protobuf.IFieldDescriptorProto>|null} [extension] DescriptorProto extension
                 * @property {Array.<google.protobuf.IDescriptorProto>|null} [nestedType] DescriptorProto nestedType
                 * @property {Array.<google.protobuf.IEnumDescriptorProto>|null} [enumType] DescriptorProto enumType
                 * @property {Array.<google.protobuf.DescriptorProto.IExtensionRange>|null} [extensionRange] DescriptorProto extensionRange
                 * @property {Array.<google.protobuf.IOneofDescriptorProto>|null} [oneofDecl] DescriptorProto oneofDecl
                 * @property {google.protobuf.IMessageOptions|null} [options] DescriptorProto options
                 * @property {Array.<google.protobuf.DescriptorProto.IReservedRange>|null} [reservedRange] DescriptorProto reservedRange
                 * @property {Array.<string>|null} [reservedName] DescriptorProto reservedName
                 */
    
                /**
                 * Constructs a new DescriptorProto.
                 * @memberof google.protobuf
                 * @classdesc Represents a DescriptorProto.
                 * @implements IDescriptorProto
                 * @constructor
                 * @param {google.protobuf.IDescriptorProto=} [properties] Properties to set
                 */
                function DescriptorProto(properties) {
                    this.field = [];
                    this.extension = [];
                    this.nestedType = [];
                    this.enumType = [];
                    this.extensionRange = [];
                    this.oneofDecl = [];
                    this.reservedRange = [];
                    this.reservedName = [];
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * DescriptorProto name.
                 * @member {string} name
                 * @memberof google.protobuf.DescriptorProto
                 * @instance
                 */
                DescriptorProto.prototype.name = "";
    
                /**
                 * DescriptorProto field.
                 * @member {Array.<google.protobuf.IFieldDescriptorProto>} field
                 * @memberof google.protobuf.DescriptorProto
                 * @instance
                 */
                DescriptorProto.prototype.field = $util.emptyArray;
    
                /**
                 * DescriptorProto extension.
                 * @member {Array.<google.protobuf.IFieldDescriptorProto>} extension
                 * @memberof google.protobuf.DescriptorProto
                 * @instance
                 */
                DescriptorProto.prototype.extension = $util.emptyArray;
    
                /**
                 * DescriptorProto nestedType.
                 * @member {Array.<google.protobuf.IDescriptorProto>} nestedType
                 * @memberof google.protobuf.DescriptorProto
                 * @instance
                 */
                DescriptorProto.prototype.nestedType = $util.emptyArray;
    
                /**
                 * DescriptorProto enumType.
                 * @member {Array.<google.protobuf.IEnumDescriptorProto>} enumType
                 * @memberof google.protobuf.DescriptorProto
                 * @instance
                 */
                DescriptorProto.prototype.enumType = $util.emptyArray;
    
                /**
                 * DescriptorProto extensionRange.
                 * @member {Array.<google.protobuf.DescriptorProto.IExtensionRange>} extensionRange
                 * @memberof google.protobuf.DescriptorProto
                 * @instance
                 */
                DescriptorProto.prototype.extensionRange = $util.emptyArray;
    
                /**
                 * DescriptorProto oneofDecl.
                 * @member {Array.<google.protobuf.IOneofDescriptorProto>} oneofDecl
                 * @memberof google.protobuf.DescriptorProto
                 * @instance
                 */
                DescriptorProto.prototype.oneofDecl = $util.emptyArray;
    
                /**
                 * DescriptorProto options.
                 * @member {google.protobuf.IMessageOptions|null|undefined} options
                 * @memberof google.protobuf.DescriptorProto
                 * @instance
                 */
                DescriptorProto.prototype.options = null;
    
                /**
                 * DescriptorProto reservedRange.
                 * @member {Array.<google.protobuf.DescriptorProto.IReservedRange>} reservedRange
                 * @memberof google.protobuf.DescriptorProto
                 * @instance
                 */
                DescriptorProto.prototype.reservedRange = $util.emptyArray;
    
                /**
                 * DescriptorProto reservedName.
                 * @member {Array.<string>} reservedName
                 * @memberof google.protobuf.DescriptorProto
                 * @instance
                 */
                DescriptorProto.prototype.reservedName = $util.emptyArray;
    
                /**
                 * Creates a new DescriptorProto instance using the specified properties.
                 * @function create
                 * @memberof google.protobuf.DescriptorProto
                 * @static
                 * @param {google.protobuf.IDescriptorProto=} [properties] Properties to set
                 * @returns {google.protobuf.DescriptorProto} DescriptorProto instance
                 */
                DescriptorProto.create = function create(properties) {
                    return new DescriptorProto(properties);
                };
    
                /**
                 * Encodes the specified DescriptorProto message. Does not implicitly {@link google.protobuf.DescriptorProto.verify|verify} messages.
                 * @function encode
                 * @memberof google.protobuf.DescriptorProto
                 * @static
                 * @param {google.protobuf.IDescriptorProto} message DescriptorProto message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                DescriptorProto.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                    if (message.field != null && message.field.length)
                        for (var i = 0; i < message.field.length; ++i)
                            $root.google.protobuf.FieldDescriptorProto.encode(message.field[i], writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                    if (message.nestedType != null && message.nestedType.length)
                        for (var i = 0; i < message.nestedType.length; ++i)
                            $root.google.protobuf.DescriptorProto.encode(message.nestedType[i], writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                    if (message.enumType != null && message.enumType.length)
                        for (var i = 0; i < message.enumType.length; ++i)
                            $root.google.protobuf.EnumDescriptorProto.encode(message.enumType[i], writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                    if (message.extensionRange != null && message.extensionRange.length)
                        for (var i = 0; i < message.extensionRange.length; ++i)
                            $root.google.protobuf.DescriptorProto.ExtensionRange.encode(message.extensionRange[i], writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                    if (message.extension != null && message.extension.length)
                        for (var i = 0; i < message.extension.length; ++i)
                            $root.google.protobuf.FieldDescriptorProto.encode(message.extension[i], writer.uint32(/* id 6, wireType 2 =*/50).fork()).ldelim();
                    if (message.options != null && Object.hasOwnProperty.call(message, "options"))
                        $root.google.protobuf.MessageOptions.encode(message.options, writer.uint32(/* id 7, wireType 2 =*/58).fork()).ldelim();
                    if (message.oneofDecl != null && message.oneofDecl.length)
                        for (var i = 0; i < message.oneofDecl.length; ++i)
                            $root.google.protobuf.OneofDescriptorProto.encode(message.oneofDecl[i], writer.uint32(/* id 8, wireType 2 =*/66).fork()).ldelim();
                    if (message.reservedRange != null && message.reservedRange.length)
                        for (var i = 0; i < message.reservedRange.length; ++i)
                            $root.google.protobuf.DescriptorProto.ReservedRange.encode(message.reservedRange[i], writer.uint32(/* id 9, wireType 2 =*/74).fork()).ldelim();
                    if (message.reservedName != null && message.reservedName.length)
                        for (var i = 0; i < message.reservedName.length; ++i)
                            writer.uint32(/* id 10, wireType 2 =*/82).string(message.reservedName[i]);
                    return writer;
                };
    
                /**
                 * Encodes the specified DescriptorProto message, length delimited. Does not implicitly {@link google.protobuf.DescriptorProto.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.protobuf.DescriptorProto
                 * @static
                 * @param {google.protobuf.IDescriptorProto} message DescriptorProto message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                DescriptorProto.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes a DescriptorProto message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.protobuf.DescriptorProto
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.protobuf.DescriptorProto} DescriptorProto
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                DescriptorProto.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.protobuf.DescriptorProto();
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 1: {
                                message.name = reader.string();
                                break;
                            }
                        case 2: {
                                if (!(message.field && message.field.length))
                                    message.field = [];
                                message.field.push($root.google.protobuf.FieldDescriptorProto.decode(reader, reader.uint32()));
                                break;
                            }
                        case 6: {
                                if (!(message.extension && message.extension.length))
                                    message.extension = [];
                                message.extension.push($root.google.protobuf.FieldDescriptorProto.decode(reader, reader.uint32()));
                                break;
                            }
                        case 3: {
                                if (!(message.nestedType && message.nestedType.length))
                                    message.nestedType = [];
                                message.nestedType.push($root.google.protobuf.DescriptorProto.decode(reader, reader.uint32()));
                                break;
                            }
                        case 4: {
                                if (!(message.enumType && message.enumType.length))
                                    message.enumType = [];
                                message.enumType.push($root.google.protobuf.EnumDescriptorProto.decode(reader, reader.uint32()));
                                break;
                            }
                        case 5: {
                                if (!(message.extensionRange && message.extensionRange.length))
                                    message.extensionRange = [];
                                message.extensionRange.push($root.google.protobuf.DescriptorProto.ExtensionRange.decode(reader, reader.uint32()));
                                break;
                            }
                        case 8: {
                                if (!(message.oneofDecl && message.oneofDecl.length))
                                    message.oneofDecl = [];
                                message.oneofDecl.push($root.google.protobuf.OneofDescriptorProto.decode(reader, reader.uint32()));
                                break;
                            }
                        case 7: {
                                message.options = $root.google.protobuf.MessageOptions.decode(reader, reader.uint32());
                                break;
                            }
                        case 9: {
                                if (!(message.reservedRange && message.reservedRange.length))
                                    message.reservedRange = [];
                                message.reservedRange.push($root.google.protobuf.DescriptorProto.ReservedRange.decode(reader, reader.uint32()));
                                break;
                            }
                        case 10: {
                                if (!(message.reservedName && message.reservedName.length))
                                    message.reservedName = [];
                                message.reservedName.push(reader.string());
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes a DescriptorProto message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.protobuf.DescriptorProto
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.protobuf.DescriptorProto} DescriptorProto
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                DescriptorProto.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies a DescriptorProto message.
                 * @function verify
                 * @memberof google.protobuf.DescriptorProto
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                DescriptorProto.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    if (message.name != null && message.hasOwnProperty("name"))
                        if (!$util.isString(message.name))
                            return "name: string expected";
                    if (message.field != null && message.hasOwnProperty("field")) {
                        if (!Array.isArray(message.field))
                            return "field: array expected";
                        for (var i = 0; i < message.field.length; ++i) {
                            var error = $root.google.protobuf.FieldDescriptorProto.verify(message.field[i]);
                            if (error)
                                return "field." + error;
                        }
                    }
                    if (message.extension != null && message.hasOwnProperty("extension")) {
                        if (!Array.isArray(message.extension))
                            return "extension: array expected";
                        for (var i = 0; i < message.extension.length; ++i) {
                            var error = $root.google.protobuf.FieldDescriptorProto.verify(message.extension[i]);
                            if (error)
                                return "extension." + error;
                        }
                    }
                    if (message.nestedType != null && message.hasOwnProperty("nestedType")) {
                        if (!Array.isArray(message.nestedType))
                            return "nestedType: array expected";
                        for (var i = 0; i < message.nestedType.length; ++i) {
                            var error = $root.google.protobuf.DescriptorProto.verify(message.nestedType[i]);
                            if (error)
                                return "nestedType." + error;
                        }
                    }
                    if (message.enumType != null && message.hasOwnProperty("enumType")) {
                        if (!Array.isArray(message.enumType))
                            return "enumType: array expected";
                        for (var i = 0; i < message.enumType.length; ++i) {
                            var error = $root.google.protobuf.EnumDescriptorProto.verify(message.enumType[i]);
                            if (error)
                                return "enumType." + error;
                        }
                    }
                    if (message.extensionRange != null && message.hasOwnProperty("extensionRange")) {
                        if (!Array.isArray(message.extensionRange))
                            return "extensionRange: array expected";
                        for (var i = 0; i < message.extensionRange.length; ++i) {
                            var error = $root.google.protobuf.DescriptorProto.ExtensionRange.verify(message.extensionRange[i]);
                            if (error)
                                return "extensionRange." + error;
                        }
                    }
                    if (message.oneofDecl != null && message.hasOwnProperty("oneofDecl")) {
                        if (!Array.isArray(message.oneofDecl))
                            return "oneofDecl: array expected";
                        for (var i = 0; i < message.oneofDecl.length; ++i) {
                            var error = $root.google.protobuf.OneofDescriptorProto.verify(message.oneofDecl[i]);
                            if (error)
                                return "oneofDecl." + error;
                        }
                    }
                    if (message.options != null && message.hasOwnProperty("options")) {
                        var error = $root.google.protobuf.MessageOptions.verify(message.options);
                        if (error)
                            return "options." + error;
                    }
                    if (message.reservedRange != null && message.hasOwnProperty("reservedRange")) {
                        if (!Array.isArray(message.reservedRange))
                            return "reservedRange: array expected";
                        for (var i = 0; i < message.reservedRange.length; ++i) {
                            var error = $root.google.protobuf.DescriptorProto.ReservedRange.verify(message.reservedRange[i]);
                            if (error)
                                return "reservedRange." + error;
                        }
                    }
                    if (message.reservedName != null && message.hasOwnProperty("reservedName")) {
                        if (!Array.isArray(message.reservedName))
                            return "reservedName: array expected";
                        for (var i = 0; i < message.reservedName.length; ++i)
                            if (!$util.isString(message.reservedName[i]))
                                return "reservedName: string[] expected";
                    }
                    return null;
                };
    
                /**
                 * Creates a DescriptorProto message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.protobuf.DescriptorProto
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.protobuf.DescriptorProto} DescriptorProto
                 */
                DescriptorProto.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.protobuf.DescriptorProto)
                        return object;
                    var message = new $root.google.protobuf.DescriptorProto();
                    if (object.name != null)
                        message.name = String(object.name);
                    if (object.field) {
                        if (!Array.isArray(object.field))
                            throw TypeError(".google.protobuf.DescriptorProto.field: array expected");
                        message.field = [];
                        for (var i = 0; i < object.field.length; ++i) {
                            if (typeof object.field[i] !== "object")
                                throw TypeError(".google.protobuf.DescriptorProto.field: object expected");
                            message.field[i] = $root.google.protobuf.FieldDescriptorProto.fromObject(object.field[i]);
                        }
                    }
                    if (object.extension) {
                        if (!Array.isArray(object.extension))
                            throw TypeError(".google.protobuf.DescriptorProto.extension: array expected");
                        message.extension = [];
                        for (var i = 0; i < object.extension.length; ++i) {
                            if (typeof object.extension[i] !== "object")
                                throw TypeError(".google.protobuf.DescriptorProto.extension: object expected");
                            message.extension[i] = $root.google.protobuf.FieldDescriptorProto.fromObject(object.extension[i]);
                        }
                    }
                    if (object.nestedType) {
                        if (!Array.isArray(object.nestedType))
                            throw TypeError(".google.protobuf.DescriptorProto.nestedType: array expected");
                        message.nestedType = [];
                        for (var i = 0; i < object.nestedType.length; ++i) {
                            if (typeof object.nestedType[i] !== "object")
                                throw TypeError(".google.protobuf.DescriptorProto.nestedType: object expected");
                            message.nestedType[i] = $root.google.protobuf.DescriptorProto.fromObject(object.nestedType[i]);
                        }
                    }
                    if (object.enumType) {
                        if (!Array.isArray(object.enumType))
                            throw TypeError(".google.protobuf.DescriptorProto.enumType: array expected");
                        message.enumType = [];
                        for (var i = 0; i < object.enumType.length; ++i) {
                            if (typeof object.enumType[i] !== "object")
                                throw TypeError(".google.protobuf.DescriptorProto.enumType: object expected");
                            message.enumType[i] = $root.google.protobuf.EnumDescriptorProto.fromObject(object.enumType[i]);
                        }
                    }
                    if (object.extensionRange) {
                        if (!Array.isArray(object.extensionRange))
                            throw TypeError(".google.protobuf.DescriptorProto.extensionRange: array expected");
                        message.extensionRange = [];
                        for (var i = 0; i < object.extensionRange.length; ++i) {
                            if (typeof object.extensionRange[i] !== "object")
                                throw TypeError(".google.protobuf.DescriptorProto.extensionRange: object expected");
                            message.extensionRange[i] = $root.google.protobuf.DescriptorProto.ExtensionRange.fromObject(object.extensionRange[i]);
                        }
                    }
                    if (object.oneofDecl) {
                        if (!Array.isArray(object.oneofDecl))
                            throw TypeError(".google.protobuf.DescriptorProto.oneofDecl: array expected");
                        message.oneofDecl = [];
                        for (var i = 0; i < object.oneofDecl.length; ++i) {
                            if (typeof object.oneofDecl[i] !== "object")
                                throw TypeError(".google.protobuf.DescriptorProto.oneofDecl: object expected");
                            message.oneofDecl[i] = $root.google.protobuf.OneofDescriptorProto.fromObject(object.oneofDecl[i]);
                        }
                    }
                    if (object.options != null) {
                        if (typeof object.options !== "object")
                            throw TypeError(".google.protobuf.DescriptorProto.options: object expected");
                        message.options = $root.google.protobuf.MessageOptions.fromObject(object.options);
                    }
                    if (object.reservedRange) {
                        if (!Array.isArray(object.reservedRange))
                            throw TypeError(".google.protobuf.DescriptorProto.reservedRange: array expected");
                        message.reservedRange = [];
                        for (var i = 0; i < object.reservedRange.length; ++i) {
                            if (typeof object.reservedRange[i] !== "object")
                                throw TypeError(".google.protobuf.DescriptorProto.reservedRange: object expected");
                            message.reservedRange[i] = $root.google.protobuf.DescriptorProto.ReservedRange.fromObject(object.reservedRange[i]);
                        }
                    }
                    if (object.reservedName) {
                        if (!Array.isArray(object.reservedName))
                            throw TypeError(".google.protobuf.DescriptorProto.reservedName: array expected");
                        message.reservedName = [];
                        for (var i = 0; i < object.reservedName.length; ++i)
                            message.reservedName[i] = String(object.reservedName[i]);
                    }
                    return message;
                };
    
                /**
                 * Creates a plain object from a DescriptorProto message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.protobuf.DescriptorProto
                 * @static
                 * @param {google.protobuf.DescriptorProto} message DescriptorProto
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                DescriptorProto.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (options.arrays || options.defaults) {
                        object.field = [];
                        object.nestedType = [];
                        object.enumType = [];
                        object.extensionRange = [];
                        object.extension = [];
                        object.oneofDecl = [];
                        object.reservedRange = [];
                        object.reservedName = [];
                    }
                    if (options.defaults) {
                        object.name = "";
                        object.options = null;
                    }
                    if (message.name != null && message.hasOwnProperty("name"))
                        object.name = message.name;
                    if (message.field && message.field.length) {
                        object.field = [];
                        for (var j = 0; j < message.field.length; ++j)
                            object.field[j] = $root.google.protobuf.FieldDescriptorProto.toObject(message.field[j], options);
                    }
                    if (message.nestedType && message.nestedType.length) {
                        object.nestedType = [];
                        for (var j = 0; j < message.nestedType.length; ++j)
                            object.nestedType[j] = $root.google.protobuf.DescriptorProto.toObject(message.nestedType[j], options);
                    }
                    if (message.enumType && message.enumType.length) {
                        object.enumType = [];
                        for (var j = 0; j < message.enumType.length; ++j)
                            object.enumType[j] = $root.google.protobuf.EnumDescriptorProto.toObject(message.enumType[j], options);
                    }
                    if (message.extensionRange && message.extensionRange.length) {
                        object.extensionRange = [];
                        for (var j = 0; j < message.extensionRange.length; ++j)
                            object.extensionRange[j] = $root.google.protobuf.DescriptorProto.ExtensionRange.toObject(message.extensionRange[j], options);
                    }
                    if (message.extension && message.extension.length) {
                        object.extension = [];
                        for (var j = 0; j < message.extension.length; ++j)
                            object.extension[j] = $root.google.protobuf.FieldDescriptorProto.toObject(message.extension[j], options);
                    }
                    if (message.options != null && message.hasOwnProperty("options"))
                        object.options = $root.google.protobuf.MessageOptions.toObject(message.options, options);
                    if (message.oneofDecl && message.oneofDecl.length) {
                        object.oneofDecl = [];
                        for (var j = 0; j < message.oneofDecl.length; ++j)
                            object.oneofDecl[j] = $root.google.protobuf.OneofDescriptorProto.toObject(message.oneofDecl[j], options);
                    }
                    if (message.reservedRange && message.reservedRange.length) {
                        object.reservedRange = [];
                        for (var j = 0; j < message.reservedRange.length; ++j)
                            object.reservedRange[j] = $root.google.protobuf.DescriptorProto.ReservedRange.toObject(message.reservedRange[j], options);
                    }
                    if (message.reservedName && message.reservedName.length) {
                        object.reservedName = [];
                        for (var j = 0; j < message.reservedName.length; ++j)
                            object.reservedName[j] = message.reservedName[j];
                    }
                    return object;
                };
    
                /**
                 * Converts this DescriptorProto to JSON.
                 * @function toJSON
                 * @memberof google.protobuf.DescriptorProto
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                DescriptorProto.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for DescriptorProto
                 * @function getTypeUrl
                 * @memberof google.protobuf.DescriptorProto
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                DescriptorProto.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.protobuf.DescriptorProto";
                };
    
                DescriptorProto.ExtensionRange = (function() {
    
                    /**
                     * Properties of an ExtensionRange.
                     * @memberof google.protobuf.DescriptorProto
                     * @interface IExtensionRange
                     * @property {number|null} [start] ExtensionRange start
                     * @property {number|null} [end] ExtensionRange end
                     * @property {google.protobuf.IExtensionRangeOptions|null} [options] ExtensionRange options
                     */
    
                    /**
                     * Constructs a new ExtensionRange.
                     * @memberof google.protobuf.DescriptorProto
                     * @classdesc Represents an ExtensionRange.
                     * @implements IExtensionRange
                     * @constructor
                     * @param {google.protobuf.DescriptorProto.IExtensionRange=} [properties] Properties to set
                     */
                    function ExtensionRange(properties) {
                        if (properties)
                            for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                if (properties[keys[i]] != null)
                                    this[keys[i]] = properties[keys[i]];
                    }
    
                    /**
                     * ExtensionRange start.
                     * @member {number} start
                     * @memberof google.protobuf.DescriptorProto.ExtensionRange
                     * @instance
                     */
                    ExtensionRange.prototype.start = 0;
    
                    /**
                     * ExtensionRange end.
                     * @member {number} end
                     * @memberof google.protobuf.DescriptorProto.ExtensionRange
                     * @instance
                     */
                    ExtensionRange.prototype.end = 0;
    
                    /**
                     * ExtensionRange options.
                     * @member {google.protobuf.IExtensionRangeOptions|null|undefined} options
                     * @memberof google.protobuf.DescriptorProto.ExtensionRange
                     * @instance
                     */
                    ExtensionRange.prototype.options = null;
    
                    /**
                     * Creates a new ExtensionRange instance using the specified properties.
                     * @function create
                     * @memberof google.protobuf.DescriptorProto.ExtensionRange
                     * @static
                     * @param {google.protobuf.DescriptorProto.IExtensionRange=} [properties] Properties to set
                     * @returns {google.protobuf.DescriptorProto.ExtensionRange} ExtensionRange instance
                     */
                    ExtensionRange.create = function create(properties) {
                        return new ExtensionRange(properties);
                    };
    
                    /**
                     * Encodes the specified ExtensionRange message. Does not implicitly {@link google.protobuf.DescriptorProto.ExtensionRange.verify|verify} messages.
                     * @function encode
                     * @memberof google.protobuf.DescriptorProto.ExtensionRange
                     * @static
                     * @param {google.protobuf.DescriptorProto.IExtensionRange} message ExtensionRange message or plain object to encode
                     * @param {$protobuf.Writer} [writer] Writer to encode to
                     * @returns {$protobuf.Writer} Writer
                     */
                    ExtensionRange.encode = function encode(message, writer) {
                        if (!writer)
                            writer = $Writer.create();
                        if (message.start != null && Object.hasOwnProperty.call(message, "start"))
                            writer.uint32(/* id 1, wireType 0 =*/8).int32(message.start);
                        if (message.end != null && Object.hasOwnProperty.call(message, "end"))
                            writer.uint32(/* id 2, wireType 0 =*/16).int32(message.end);
                        if (message.options != null && Object.hasOwnProperty.call(message, "options"))
                            $root.google.protobuf.ExtensionRangeOptions.encode(message.options, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                        return writer;
                    };
    
                    /**
                     * Encodes the specified ExtensionRange message, length delimited. Does not implicitly {@link google.protobuf.DescriptorProto.ExtensionRange.verify|verify} messages.
                     * @function encodeDelimited
                     * @memberof google.protobuf.DescriptorProto.ExtensionRange
                     * @static
                     * @param {google.protobuf.DescriptorProto.IExtensionRange} message ExtensionRange message or plain object to encode
                     * @param {$protobuf.Writer} [writer] Writer to encode to
                     * @returns {$protobuf.Writer} Writer
                     */
                    ExtensionRange.encodeDelimited = function encodeDelimited(message, writer) {
                        return this.encode(message, writer).ldelim();
                    };
    
                    /**
                     * Decodes an ExtensionRange message from the specified reader or buffer.
                     * @function decode
                     * @memberof google.protobuf.DescriptorProto.ExtensionRange
                     * @static
                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                     * @param {number} [length] Message length if known beforehand
                     * @returns {google.protobuf.DescriptorProto.ExtensionRange} ExtensionRange
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    ExtensionRange.decode = function decode(reader, length) {
                        if (!(reader instanceof $Reader))
                            reader = $Reader.create(reader);
                        var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.protobuf.DescriptorProto.ExtensionRange();
                        while (reader.pos < end) {
                            var tag = reader.uint32();
                            switch (tag >>> 3) {
                            case 1: {
                                    message.start = reader.int32();
                                    break;
                                }
                            case 2: {
                                    message.end = reader.int32();
                                    break;
                                }
                            case 3: {
                                    message.options = $root.google.protobuf.ExtensionRangeOptions.decode(reader, reader.uint32());
                                    break;
                                }
                            default:
                                reader.skipType(tag & 7);
                                break;
                            }
                        }
                        return message;
                    };
    
                    /**
                     * Decodes an ExtensionRange message from the specified reader or buffer, length delimited.
                     * @function decodeDelimited
                     * @memberof google.protobuf.DescriptorProto.ExtensionRange
                     * @static
                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                     * @returns {google.protobuf.DescriptorProto.ExtensionRange} ExtensionRange
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    ExtensionRange.decodeDelimited = function decodeDelimited(reader) {
                        if (!(reader instanceof $Reader))
                            reader = new $Reader(reader);
                        return this.decode(reader, reader.uint32());
                    };
    
                    /**
                     * Verifies an ExtensionRange message.
                     * @function verify
                     * @memberof google.protobuf.DescriptorProto.ExtensionRange
                     * @static
                     * @param {Object.<string,*>} message Plain object to verify
                     * @returns {string|null} `null` if valid, otherwise the reason why it is not
                     */
                    ExtensionRange.verify = function verify(message) {
                        if (typeof message !== "object" || message === null)
                            return "object expected";
                        if (message.start != null && message.hasOwnProperty("start"))
                            if (!$util.isInteger(message.start))
                                return "start: integer expected";
                        if (message.end != null && message.hasOwnProperty("end"))
                            if (!$util.isInteger(message.end))
                                return "end: integer expected";
                        if (message.options != null && message.hasOwnProperty("options")) {
                            var error = $root.google.protobuf.ExtensionRangeOptions.verify(message.options);
                            if (error)
                                return "options." + error;
                        }
                        return null;
                    };
    
                    /**
                     * Creates an ExtensionRange message from a plain object. Also converts values to their respective internal types.
                     * @function fromObject
                     * @memberof google.protobuf.DescriptorProto.ExtensionRange
                     * @static
                     * @param {Object.<string,*>} object Plain object
                     * @returns {google.protobuf.DescriptorProto.ExtensionRange} ExtensionRange
                     */
                    ExtensionRange.fromObject = function fromObject(object) {
                        if (object instanceof $root.google.protobuf.DescriptorProto.ExtensionRange)
                            return object;
                        var message = new $root.google.protobuf.DescriptorProto.ExtensionRange();
                        if (object.start != null)
                            message.start = object.start | 0;
                        if (object.end != null)
                            message.end = object.end | 0;
                        if (object.options != null) {
                            if (typeof object.options !== "object")
                                throw TypeError(".google.protobuf.DescriptorProto.ExtensionRange.options: object expected");
                            message.options = $root.google.protobuf.ExtensionRangeOptions.fromObject(object.options);
                        }
                        return message;
                    };
    
                    /**
                     * Creates a plain object from an ExtensionRange message. Also converts values to other types if specified.
                     * @function toObject
                     * @memberof google.protobuf.DescriptorProto.ExtensionRange
                     * @static
                     * @param {google.protobuf.DescriptorProto.ExtensionRange} message ExtensionRange
                     * @param {$protobuf.IConversionOptions} [options] Conversion options
                     * @returns {Object.<string,*>} Plain object
                     */
                    ExtensionRange.toObject = function toObject(message, options) {
                        if (!options)
                            options = {};
                        var object = {};
                        if (options.defaults) {
                            object.start = 0;
                            object.end = 0;
                            object.options = null;
                        }
                        if (message.start != null && message.hasOwnProperty("start"))
                            object.start = message.start;
                        if (message.end != null && message.hasOwnProperty("end"))
                            object.end = message.end;
                        if (message.options != null && message.hasOwnProperty("options"))
                            object.options = $root.google.protobuf.ExtensionRangeOptions.toObject(message.options, options);
                        return object;
                    };
    
                    /**
                     * Converts this ExtensionRange to JSON.
                     * @function toJSON
                     * @memberof google.protobuf.DescriptorProto.ExtensionRange
                     * @instance
                     * @returns {Object.<string,*>} JSON object
                     */
                    ExtensionRange.prototype.toJSON = function toJSON() {
                        return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                    };
    
                    /**
                     * Gets the default type url for ExtensionRange
                     * @function getTypeUrl
                     * @memberof google.protobuf.DescriptorProto.ExtensionRange
                     * @static
                     * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns {string} The default type url
                     */
                    ExtensionRange.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                        if (typeUrlPrefix === undefined) {
                            typeUrlPrefix = "type.googleapis.com";
                        }
                        return typeUrlPrefix + "/google.protobuf.DescriptorProto.ExtensionRange";
                    };
    
                    return ExtensionRange;
                })();
    
                DescriptorProto.ReservedRange = (function() {
    
                    /**
                     * Properties of a ReservedRange.
                     * @memberof google.protobuf.DescriptorProto
                     * @interface IReservedRange
                     * @property {number|null} [start] ReservedRange start
                     * @property {number|null} [end] ReservedRange end
                     */
    
                    /**
                     * Constructs a new ReservedRange.
                     * @memberof google.protobuf.DescriptorProto
                     * @classdesc Represents a ReservedRange.
                     * @implements IReservedRange
                     * @constructor
                     * @param {google.protobuf.DescriptorProto.IReservedRange=} [properties] Properties to set
                     */
                    function ReservedRange(properties) {
                        if (properties)
                            for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                if (properties[keys[i]] != null)
                                    this[keys[i]] = properties[keys[i]];
                    }
    
                    /**
                     * ReservedRange start.
                     * @member {number} start
                     * @memberof google.protobuf.DescriptorProto.ReservedRange
                     * @instance
                     */
                    ReservedRange.prototype.start = 0;
    
                    /**
                     * ReservedRange end.
                     * @member {number} end
                     * @memberof google.protobuf.DescriptorProto.ReservedRange
                     * @instance
                     */
                    ReservedRange.prototype.end = 0;
    
                    /**
                     * Creates a new ReservedRange instance using the specified properties.
                     * @function create
                     * @memberof google.protobuf.DescriptorProto.ReservedRange
                     * @static
                     * @param {google.protobuf.DescriptorProto.IReservedRange=} [properties] Properties to set
                     * @returns {google.protobuf.DescriptorProto.ReservedRange} ReservedRange instance
                     */
                    ReservedRange.create = function create(properties) {
                        return new ReservedRange(properties);
                    };
    
                    /**
                     * Encodes the specified ReservedRange message. Does not implicitly {@link google.protobuf.DescriptorProto.ReservedRange.verify|verify} messages.
                     * @function encode
                     * @memberof google.protobuf.DescriptorProto.ReservedRange
                     * @static
                     * @param {google.protobuf.DescriptorProto.IReservedRange} message ReservedRange message or plain object to encode
                     * @param {$protobuf.Writer} [writer] Writer to encode to
                     * @returns {$protobuf.Writer} Writer
                     */
                    ReservedRange.encode = function encode(message, writer) {
                        if (!writer)
                            writer = $Writer.create();
                        if (message.start != null && Object.hasOwnProperty.call(message, "start"))
                            writer.uint32(/* id 1, wireType 0 =*/8).int32(message.start);
                        if (message.end != null && Object.hasOwnProperty.call(message, "end"))
                            writer.uint32(/* id 2, wireType 0 =*/16).int32(message.end);
                        return writer;
                    };
    
                    /**
                     * Encodes the specified ReservedRange message, length delimited. Does not implicitly {@link google.protobuf.DescriptorProto.ReservedRange.verify|verify} messages.
                     * @function encodeDelimited
                     * @memberof google.protobuf.DescriptorProto.ReservedRange
                     * @static
                     * @param {google.protobuf.DescriptorProto.IReservedRange} message ReservedRange message or plain object to encode
                     * @param {$protobuf.Writer} [writer] Writer to encode to
                     * @returns {$protobuf.Writer} Writer
                     */
                    ReservedRange.encodeDelimited = function encodeDelimited(message, writer) {
                        return this.encode(message, writer).ldelim();
                    };
    
                    /**
                     * Decodes a ReservedRange message from the specified reader or buffer.
                     * @function decode
                     * @memberof google.protobuf.DescriptorProto.ReservedRange
                     * @static
                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                     * @param {number} [length] Message length if known beforehand
                     * @returns {google.protobuf.DescriptorProto.ReservedRange} ReservedRange
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    ReservedRange.decode = function decode(reader, length) {
                        if (!(reader instanceof $Reader))
                            reader = $Reader.create(reader);
                        var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.protobuf.DescriptorProto.ReservedRange();
                        while (reader.pos < end) {
                            var tag = reader.uint32();
                            switch (tag >>> 3) {
                            case 1: {
                                    message.start = reader.int32();
                                    break;
                                }
                            case 2: {
                                    message.end = reader.int32();
                                    break;
                                }
                            default:
                                reader.skipType(tag & 7);
                                break;
                            }
                        }
                        return message;
                    };
    
                    /**
                     * Decodes a ReservedRange message from the specified reader or buffer, length delimited.
                     * @function decodeDelimited
                     * @memberof google.protobuf.DescriptorProto.ReservedRange
                     * @static
                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                     * @returns {google.protobuf.DescriptorProto.ReservedRange} ReservedRange
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    ReservedRange.decodeDelimited = function decodeDelimited(reader) {
                        if (!(reader instanceof $Reader))
                            reader = new $Reader(reader);
                        return this.decode(reader, reader.uint32());
                    };
    
                    /**
                     * Verifies a ReservedRange message.
                     * @function verify
                     * @memberof google.protobuf.DescriptorProto.ReservedRange
                     * @static
                     * @param {Object.<string,*>} message Plain object to verify
                     * @returns {string|null} `null` if valid, otherwise the reason why it is not
                     */
                    ReservedRange.verify = function verify(message) {
                        if (typeof message !== "object" || message === null)
                            return "object expected";
                        if (message.start != null && message.hasOwnProperty("start"))
                            if (!$util.isInteger(message.start))
                                return "start: integer expected";
                        if (message.end != null && message.hasOwnProperty("end"))
                            if (!$util.isInteger(message.end))
                                return "end: integer expected";
                        return null;
                    };
    
                    /**
                     * Creates a ReservedRange message from a plain object. Also converts values to their respective internal types.
                     * @function fromObject
                     * @memberof google.protobuf.DescriptorProto.ReservedRange
                     * @static
                     * @param {Object.<string,*>} object Plain object
                     * @returns {google.protobuf.DescriptorProto.ReservedRange} ReservedRange
                     */
                    ReservedRange.fromObject = function fromObject(object) {
                        if (object instanceof $root.google.protobuf.DescriptorProto.ReservedRange)
                            return object;
                        var message = new $root.google.protobuf.DescriptorProto.ReservedRange();
                        if (object.start != null)
                            message.start = object.start | 0;
                        if (object.end != null)
                            message.end = object.end | 0;
                        return message;
                    };
    
                    /**
                     * Creates a plain object from a ReservedRange message. Also converts values to other types if specified.
                     * @function toObject
                     * @memberof google.protobuf.DescriptorProto.ReservedRange
                     * @static
                     * @param {google.protobuf.DescriptorProto.ReservedRange} message ReservedRange
                     * @param {$protobuf.IConversionOptions} [options] Conversion options
                     * @returns {Object.<string,*>} Plain object
                     */
                    ReservedRange.toObject = function toObject(message, options) {
                        if (!options)
                            options = {};
                        var object = {};
                        if (options.defaults) {
                            object.start = 0;
                            object.end = 0;
                        }
                        if (message.start != null && message.hasOwnProperty("start"))
                            object.start = message.start;
                        if (message.end != null && message.hasOwnProperty("end"))
                            object.end = message.end;
                        return object;
                    };
    
                    /**
                     * Converts this ReservedRange to JSON.
                     * @function toJSON
                     * @memberof google.protobuf.DescriptorProto.ReservedRange
                     * @instance
                     * @returns {Object.<string,*>} JSON object
                     */
                    ReservedRange.prototype.toJSON = function toJSON() {
                        return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                    };
    
                    /**
                     * Gets the default type url for ReservedRange
                     * @function getTypeUrl
                     * @memberof google.protobuf.DescriptorProto.ReservedRange
                     * @static
                     * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns {string} The default type url
                     */
                    ReservedRange.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                        if (typeUrlPrefix === undefined) {
                            typeUrlPrefix = "type.googleapis.com";
                        }
                        return typeUrlPrefix + "/google.protobuf.DescriptorProto.ReservedRange";
                    };
    
                    return ReservedRange;
                })();
    
                return DescriptorProto;
            })();
    
            protobuf.ExtensionRangeOptions = (function() {
    
                /**
                 * Properties of an ExtensionRangeOptions.
                 * @memberof google.protobuf
                 * @interface IExtensionRangeOptions
                 * @property {Array.<google.protobuf.IUninterpretedOption>|null} [uninterpretedOption] ExtensionRangeOptions uninterpretedOption
                 * @property {Array.<google.protobuf.ExtensionRangeOptions.IDeclaration>|null} [declaration] ExtensionRangeOptions declaration
                 * @property {google.protobuf.IFeatureSet|null} [features] ExtensionRangeOptions features
                 * @property {google.protobuf.ExtensionRangeOptions.VerificationState|null} [verification] ExtensionRangeOptions verification
                 */
    
                /**
                 * Constructs a new ExtensionRangeOptions.
                 * @memberof google.protobuf
                 * @classdesc Represents an ExtensionRangeOptions.
                 * @implements IExtensionRangeOptions
                 * @constructor
                 * @param {google.protobuf.IExtensionRangeOptions=} [properties] Properties to set
                 */
                function ExtensionRangeOptions(properties) {
                    this.uninterpretedOption = [];
                    this.declaration = [];
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * ExtensionRangeOptions uninterpretedOption.
                 * @member {Array.<google.protobuf.IUninterpretedOption>} uninterpretedOption
                 * @memberof google.protobuf.ExtensionRangeOptions
                 * @instance
                 */
                ExtensionRangeOptions.prototype.uninterpretedOption = $util.emptyArray;
    
                /**
                 * ExtensionRangeOptions declaration.
                 * @member {Array.<google.protobuf.ExtensionRangeOptions.IDeclaration>} declaration
                 * @memberof google.protobuf.ExtensionRangeOptions
                 * @instance
                 */
                ExtensionRangeOptions.prototype.declaration = $util.emptyArray;
    
                /**
                 * ExtensionRangeOptions features.
                 * @member {google.protobuf.IFeatureSet|null|undefined} features
                 * @memberof google.protobuf.ExtensionRangeOptions
                 * @instance
                 */
                ExtensionRangeOptions.prototype.features = null;
    
                /**
                 * ExtensionRangeOptions verification.
                 * @member {google.protobuf.ExtensionRangeOptions.VerificationState} verification
                 * @memberof google.protobuf.ExtensionRangeOptions
                 * @instance
                 */
                ExtensionRangeOptions.prototype.verification = 1;
    
                /**
                 * Creates a new ExtensionRangeOptions instance using the specified properties.
                 * @function create
                 * @memberof google.protobuf.ExtensionRangeOptions
                 * @static
                 * @param {google.protobuf.IExtensionRangeOptions=} [properties] Properties to set
                 * @returns {google.protobuf.ExtensionRangeOptions} ExtensionRangeOptions instance
                 */
                ExtensionRangeOptions.create = function create(properties) {
                    return new ExtensionRangeOptions(properties);
                };
    
                /**
                 * Encodes the specified ExtensionRangeOptions message. Does not implicitly {@link google.protobuf.ExtensionRangeOptions.verify|verify} messages.
                 * @function encode
                 * @memberof google.protobuf.ExtensionRangeOptions
                 * @static
                 * @param {google.protobuf.IExtensionRangeOptions} message ExtensionRangeOptions message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                ExtensionRangeOptions.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.declaration != null && message.declaration.length)
                        for (var i = 0; i < message.declaration.length; ++i)
                            $root.google.protobuf.ExtensionRangeOptions.Declaration.encode(message.declaration[i], writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                    if (message.verification != null && Object.hasOwnProperty.call(message, "verification"))
                        writer.uint32(/* id 3, wireType 0 =*/24).int32(message.verification);
                    if (message.features != null && Object.hasOwnProperty.call(message, "features"))
                        $root.google.protobuf.FeatureSet.encode(message.features, writer.uint32(/* id 50, wireType 2 =*/402).fork()).ldelim();
                    if (message.uninterpretedOption != null && message.uninterpretedOption.length)
                        for (var i = 0; i < message.uninterpretedOption.length; ++i)
                            $root.google.protobuf.UninterpretedOption.encode(message.uninterpretedOption[i], writer.uint32(/* id 999, wireType 2 =*/7994).fork()).ldelim();
                    return writer;
                };
    
                /**
                 * Encodes the specified ExtensionRangeOptions message, length delimited. Does not implicitly {@link google.protobuf.ExtensionRangeOptions.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.protobuf.ExtensionRangeOptions
                 * @static
                 * @param {google.protobuf.IExtensionRangeOptions} message ExtensionRangeOptions message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                ExtensionRangeOptions.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes an ExtensionRangeOptions message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.protobuf.ExtensionRangeOptions
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.protobuf.ExtensionRangeOptions} ExtensionRangeOptions
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                ExtensionRangeOptions.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.protobuf.ExtensionRangeOptions();
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 999: {
                                if (!(message.uninterpretedOption && message.uninterpretedOption.length))
                                    message.uninterpretedOption = [];
                                message.uninterpretedOption.push($root.google.protobuf.UninterpretedOption.decode(reader, reader.uint32()));
                                break;
                            }
                        case 2: {
                                if (!(message.declaration && message.declaration.length))
                                    message.declaration = [];
                                message.declaration.push($root.google.protobuf.ExtensionRangeOptions.Declaration.decode(reader, reader.uint32()));
                                break;
                            }
                        case 50: {
                                message.features = $root.google.protobuf.FeatureSet.decode(reader, reader.uint32());
                                break;
                            }
                        case 3: {
                                message.verification = reader.int32();
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes an ExtensionRangeOptions message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.protobuf.ExtensionRangeOptions
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.protobuf.ExtensionRangeOptions} ExtensionRangeOptions
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                ExtensionRangeOptions.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies an ExtensionRangeOptions message.
                 * @function verify
                 * @memberof google.protobuf.ExtensionRangeOptions
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                ExtensionRangeOptions.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    if (message.uninterpretedOption != null && message.hasOwnProperty("uninterpretedOption")) {
                        if (!Array.isArray(message.uninterpretedOption))
                            return "uninterpretedOption: array expected";
                        for (var i = 0; i < message.uninterpretedOption.length; ++i) {
                            var error = $root.google.protobuf.UninterpretedOption.verify(message.uninterpretedOption[i]);
                            if (error)
                                return "uninterpretedOption." + error;
                        }
                    }
                    if (message.declaration != null && message.hasOwnProperty("declaration")) {
                        if (!Array.isArray(message.declaration))
                            return "declaration: array expected";
                        for (var i = 0; i < message.declaration.length; ++i) {
                            var error = $root.google.protobuf.ExtensionRangeOptions.Declaration.verify(message.declaration[i]);
                            if (error)
                                return "declaration." + error;
                        }
                    }
                    if (message.features != null && message.hasOwnProperty("features")) {
                        var error = $root.google.protobuf.FeatureSet.verify(message.features);
                        if (error)
                            return "features." + error;
                    }
                    if (message.verification != null && message.hasOwnProperty("verification"))
                        switch (message.verification) {
                        default:
                            return "verification: enum value expected";
                        case 0:
                        case 1:
                            break;
                        }
                    return null;
                };
    
                /**
                 * Creates an ExtensionRangeOptions message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.protobuf.ExtensionRangeOptions
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.protobuf.ExtensionRangeOptions} ExtensionRangeOptions
                 */
                ExtensionRangeOptions.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.protobuf.ExtensionRangeOptions)
                        return object;
                    var message = new $root.google.protobuf.ExtensionRangeOptions();
                    if (object.uninterpretedOption) {
                        if (!Array.isArray(object.uninterpretedOption))
                            throw TypeError(".google.protobuf.ExtensionRangeOptions.uninterpretedOption: array expected");
                        message.uninterpretedOption = [];
                        for (var i = 0; i < object.uninterpretedOption.length; ++i) {
                            if (typeof object.uninterpretedOption[i] !== "object")
                                throw TypeError(".google.protobuf.ExtensionRangeOptions.uninterpretedOption: object expected");
                            message.uninterpretedOption[i] = $root.google.protobuf.UninterpretedOption.fromObject(object.uninterpretedOption[i]);
                        }
                    }
                    if (object.declaration) {
                        if (!Array.isArray(object.declaration))
                            throw TypeError(".google.protobuf.ExtensionRangeOptions.declaration: array expected");
                        message.declaration = [];
                        for (var i = 0; i < object.declaration.length; ++i) {
                            if (typeof object.declaration[i] !== "object")
                                throw TypeError(".google.protobuf.ExtensionRangeOptions.declaration: object expected");
                            message.declaration[i] = $root.google.protobuf.ExtensionRangeOptions.Declaration.fromObject(object.declaration[i]);
                        }
                    }
                    if (object.features != null) {
                        if (typeof object.features !== "object")
                            throw TypeError(".google.protobuf.ExtensionRangeOptions.features: object expected");
                        message.features = $root.google.protobuf.FeatureSet.fromObject(object.features);
                    }
                    switch (object.verification) {
                    case "DECLARATION":
                    case 0:
                        message.verification = 0;
                        break;
                    default:
                        if (typeof object.verification === "number") {
                            message.verification = object.verification;
                            break;
                        }
                        break;
                    case "UNVERIFIED":
                    case 1:
                        message.verification = 1;
                        break;
                    }
                    return message;
                };
    
                /**
                 * Creates a plain object from an ExtensionRangeOptions message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.protobuf.ExtensionRangeOptions
                 * @static
                 * @param {google.protobuf.ExtensionRangeOptions} message ExtensionRangeOptions
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                ExtensionRangeOptions.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (options.arrays || options.defaults) {
                        object.declaration = [];
                        object.uninterpretedOption = [];
                    }
                    if (options.defaults) {
                        object.verification = options.enums === String ? "UNVERIFIED" : 1;
                        object.features = null;
                    }
                    if (message.declaration && message.declaration.length) {
                        object.declaration = [];
                        for (var j = 0; j < message.declaration.length; ++j)
                            object.declaration[j] = $root.google.protobuf.ExtensionRangeOptions.Declaration.toObject(message.declaration[j], options);
                    }
                    if (message.verification != null && message.hasOwnProperty("verification"))
                        object.verification = options.enums === String ? $root.google.protobuf.ExtensionRangeOptions.VerificationState[message.verification] === undefined ? message.verification : $root.google.protobuf.ExtensionRangeOptions.VerificationState[message.verification] : message.verification;
                    if (message.features != null && message.hasOwnProperty("features"))
                        object.features = $root.google.protobuf.FeatureSet.toObject(message.features, options);
                    if (message.uninterpretedOption && message.uninterpretedOption.length) {
                        object.uninterpretedOption = [];
                        for (var j = 0; j < message.uninterpretedOption.length; ++j)
                            object.uninterpretedOption[j] = $root.google.protobuf.UninterpretedOption.toObject(message.uninterpretedOption[j], options);
                    }
                    return object;
                };
    
                /**
                 * Converts this ExtensionRangeOptions to JSON.
                 * @function toJSON
                 * @memberof google.protobuf.ExtensionRangeOptions
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                ExtensionRangeOptions.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for ExtensionRangeOptions
                 * @function getTypeUrl
                 * @memberof google.protobuf.ExtensionRangeOptions
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                ExtensionRangeOptions.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.protobuf.ExtensionRangeOptions";
                };
    
                ExtensionRangeOptions.Declaration = (function() {
    
                    /**
                     * Properties of a Declaration.
                     * @memberof google.protobuf.ExtensionRangeOptions
                     * @interface IDeclaration
                     * @property {number|null} [number] Declaration number
                     * @property {string|null} [fullName] Declaration fullName
                     * @property {string|null} [type] Declaration type
                     * @property {boolean|null} [reserved] Declaration reserved
                     * @property {boolean|null} [repeated] Declaration repeated
                     */
    
                    /**
                     * Constructs a new Declaration.
                     * @memberof google.protobuf.ExtensionRangeOptions
                     * @classdesc Represents a Declaration.
                     * @implements IDeclaration
                     * @constructor
                     * @param {google.protobuf.ExtensionRangeOptions.IDeclaration=} [properties] Properties to set
                     */
                    function Declaration(properties) {
                        if (properties)
                            for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                if (properties[keys[i]] != null)
                                    this[keys[i]] = properties[keys[i]];
                    }
    
                    /**
                     * Declaration number.
                     * @member {number} number
                     * @memberof google.protobuf.ExtensionRangeOptions.Declaration
                     * @instance
                     */
                    Declaration.prototype.number = 0;
    
                    /**
                     * Declaration fullName.
                     * @member {string} fullName
                     * @memberof google.protobuf.ExtensionRangeOptions.Declaration
                     * @instance
                     */
                    Declaration.prototype.fullName = "";
    
                    /**
                     * Declaration type.
                     * @member {string} type
                     * @memberof google.protobuf.ExtensionRangeOptions.Declaration
                     * @instance
                     */
                    Declaration.prototype.type = "";
    
                    /**
                     * Declaration reserved.
                     * @member {boolean} reserved
                     * @memberof google.protobuf.ExtensionRangeOptions.Declaration
                     * @instance
                     */
                    Declaration.prototype.reserved = false;
    
                    /**
                     * Declaration repeated.
                     * @member {boolean} repeated
                     * @memberof google.protobuf.ExtensionRangeOptions.Declaration
                     * @instance
                     */
                    Declaration.prototype.repeated = false;
    
                    /**
                     * Creates a new Declaration instance using the specified properties.
                     * @function create
                     * @memberof google.protobuf.ExtensionRangeOptions.Declaration
                     * @static
                     * @param {google.protobuf.ExtensionRangeOptions.IDeclaration=} [properties] Properties to set
                     * @returns {google.protobuf.ExtensionRangeOptions.Declaration} Declaration instance
                     */
                    Declaration.create = function create(properties) {
                        return new Declaration(properties);
                    };
    
                    /**
                     * Encodes the specified Declaration message. Does not implicitly {@link google.protobuf.ExtensionRangeOptions.Declaration.verify|verify} messages.
                     * @function encode
                     * @memberof google.protobuf.ExtensionRangeOptions.Declaration
                     * @static
                     * @param {google.protobuf.ExtensionRangeOptions.IDeclaration} message Declaration message or plain object to encode
                     * @param {$protobuf.Writer} [writer] Writer to encode to
                     * @returns {$protobuf.Writer} Writer
                     */
                    Declaration.encode = function encode(message, writer) {
                        if (!writer)
                            writer = $Writer.create();
                        if (message.number != null && Object.hasOwnProperty.call(message, "number"))
                            writer.uint32(/* id 1, wireType 0 =*/8).int32(message.number);
                        if (message.fullName != null && Object.hasOwnProperty.call(message, "fullName"))
                            writer.uint32(/* id 2, wireType 2 =*/18).string(message.fullName);
                        if (message.type != null && Object.hasOwnProperty.call(message, "type"))
                            writer.uint32(/* id 3, wireType 2 =*/26).string(message.type);
                        if (message.reserved != null && Object.hasOwnProperty.call(message, "reserved"))
                            writer.uint32(/* id 5, wireType 0 =*/40).bool(message.reserved);
                        if (message.repeated != null && Object.hasOwnProperty.call(message, "repeated"))
                            writer.uint32(/* id 6, wireType 0 =*/48).bool(message.repeated);
                        return writer;
                    };
    
                    /**
                     * Encodes the specified Declaration message, length delimited. Does not implicitly {@link google.protobuf.ExtensionRangeOptions.Declaration.verify|verify} messages.
                     * @function encodeDelimited
                     * @memberof google.protobuf.ExtensionRangeOptions.Declaration
                     * @static
                     * @param {google.protobuf.ExtensionRangeOptions.IDeclaration} message Declaration message or plain object to encode
                     * @param {$protobuf.Writer} [writer] Writer to encode to
                     * @returns {$protobuf.Writer} Writer
                     */
                    Declaration.encodeDelimited = function encodeDelimited(message, writer) {
                        return this.encode(message, writer).ldelim();
                    };
    
                    /**
                     * Decodes a Declaration message from the specified reader or buffer.
                     * @function decode
                     * @memberof google.protobuf.ExtensionRangeOptions.Declaration
                     * @static
                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                     * @param {number} [length] Message length if known beforehand
                     * @returns {google.protobuf.ExtensionRangeOptions.Declaration} Declaration
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    Declaration.decode = function decode(reader, length) {
                        if (!(reader instanceof $Reader))
                            reader = $Reader.create(reader);
                        var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.protobuf.ExtensionRangeOptions.Declaration();
                        while (reader.pos < end) {
                            var tag = reader.uint32();
                            switch (tag >>> 3) {
                            case 1: {
                                    message.number = reader.int32();
                                    break;
                                }
                            case 2: {
                                    message.fullName = reader.string();
                                    break;
                                }
                            case 3: {
                                    message.type = reader.string();
                                    break;
                                }
                            case 5: {
                                    message.reserved = reader.bool();
                                    break;
                                }
                            case 6: {
                                    message.repeated = reader.bool();
                                    break;
                                }
                            default:
                                reader.skipType(tag & 7);
                                break;
                            }
                        }
                        return message;
                    };
    
                    /**
                     * Decodes a Declaration message from the specified reader or buffer, length delimited.
                     * @function decodeDelimited
                     * @memberof google.protobuf.ExtensionRangeOptions.Declaration
                     * @static
                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                     * @returns {google.protobuf.ExtensionRangeOptions.Declaration} Declaration
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    Declaration.decodeDelimited = function decodeDelimited(reader) {
                        if (!(reader instanceof $Reader))
                            reader = new $Reader(reader);
                        return this.decode(reader, reader.uint32());
                    };
    
                    /**
                     * Verifies a Declaration message.
                     * @function verify
                     * @memberof google.protobuf.ExtensionRangeOptions.Declaration
                     * @static
                     * @param {Object.<string,*>} message Plain object to verify
                     * @returns {string|null} `null` if valid, otherwise the reason why it is not
                     */
                    Declaration.verify = function verify(message) {
                        if (typeof message !== "object" || message === null)
                            return "object expected";
                        if (message.number != null && message.hasOwnProperty("number"))
                            if (!$util.isInteger(message.number))
                                return "number: integer expected";
                        if (message.fullName != null && message.hasOwnProperty("fullName"))
                            if (!$util.isString(message.fullName))
                                return "fullName: string expected";
                        if (message.type != null && message.hasOwnProperty("type"))
                            if (!$util.isString(message.type))
                                return "type: string expected";
                        if (message.reserved != null && message.hasOwnProperty("reserved"))
                            if (typeof message.reserved !== "boolean")
                                return "reserved: boolean expected";
                        if (message.repeated != null && message.hasOwnProperty("repeated"))
                            if (typeof message.repeated !== "boolean")
                                return "repeated: boolean expected";
                        return null;
                    };
    
                    /**
                     * Creates a Declaration message from a plain object. Also converts values to their respective internal types.
                     * @function fromObject
                     * @memberof google.protobuf.ExtensionRangeOptions.Declaration
                     * @static
                     * @param {Object.<string,*>} object Plain object
                     * @returns {google.protobuf.ExtensionRangeOptions.Declaration} Declaration
                     */
                    Declaration.fromObject = function fromObject(object) {
                        if (object instanceof $root.google.protobuf.ExtensionRangeOptions.Declaration)
                            return object;
                        var message = new $root.google.protobuf.ExtensionRangeOptions.Declaration();
                        if (object.number != null)
                            message.number = object.number | 0;
                        if (object.fullName != null)
                            message.fullName = String(object.fullName);
                        if (object.type != null)
                            message.type = String(object.type);
                        if (object.reserved != null)
                            message.reserved = Boolean(object.reserved);
                        if (object.repeated != null)
                            message.repeated = Boolean(object.repeated);
                        return message;
                    };
    
                    /**
                     * Creates a plain object from a Declaration message. Also converts values to other types if specified.
                     * @function toObject
                     * @memberof google.protobuf.ExtensionRangeOptions.Declaration
                     * @static
                     * @param {google.protobuf.ExtensionRangeOptions.Declaration} message Declaration
                     * @param {$protobuf.IConversionOptions} [options] Conversion options
                     * @returns {Object.<string,*>} Plain object
                     */
                    Declaration.toObject = function toObject(message, options) {
                        if (!options)
                            options = {};
                        var object = {};
                        if (options.defaults) {
                            object.number = 0;
                            object.fullName = "";
                            object.type = "";
                            object.reserved = false;
                            object.repeated = false;
                        }
                        if (message.number != null && message.hasOwnProperty("number"))
                            object.number = message.number;
                        if (message.fullName != null && message.hasOwnProperty("fullName"))
                            object.fullName = message.fullName;
                        if (message.type != null && message.hasOwnProperty("type"))
                            object.type = message.type;
                        if (message.reserved != null && message.hasOwnProperty("reserved"))
                            object.reserved = message.reserved;
                        if (message.repeated != null && message.hasOwnProperty("repeated"))
                            object.repeated = message.repeated;
                        return object;
                    };
    
                    /**
                     * Converts this Declaration to JSON.
                     * @function toJSON
                     * @memberof google.protobuf.ExtensionRangeOptions.Declaration
                     * @instance
                     * @returns {Object.<string,*>} JSON object
                     */
                    Declaration.prototype.toJSON = function toJSON() {
                        return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                    };
    
                    /**
                     * Gets the default type url for Declaration
                     * @function getTypeUrl
                     * @memberof google.protobuf.ExtensionRangeOptions.Declaration
                     * @static
                     * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns {string} The default type url
                     */
                    Declaration.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                        if (typeUrlPrefix === undefined) {
                            typeUrlPrefix = "type.googleapis.com";
                        }
                        return typeUrlPrefix + "/google.protobuf.ExtensionRangeOptions.Declaration";
                    };
    
                    return Declaration;
                })();
    
                /**
                 * VerificationState enum.
                 * @name google.protobuf.ExtensionRangeOptions.VerificationState
                 * @enum {number}
                 * @property {number} DECLARATION=0 DECLARATION value
                 * @property {number} UNVERIFIED=1 UNVERIFIED value
                 */
                ExtensionRangeOptions.VerificationState = (function() {
                    var valuesById = {}, values = Object.create(valuesById);
                    values[valuesById[0] = "DECLARATION"] = 0;
                    values[valuesById[1] = "UNVERIFIED"] = 1;
                    return values;
                })();
    
                return ExtensionRangeOptions;
            })();
    
            protobuf.FieldDescriptorProto = (function() {
    
                /**
                 * Properties of a FieldDescriptorProto.
                 * @memberof google.protobuf
                 * @interface IFieldDescriptorProto
                 * @property {string|null} [name] FieldDescriptorProto name
                 * @property {number|null} [number] FieldDescriptorProto number
                 * @property {google.protobuf.FieldDescriptorProto.Label|null} [label] FieldDescriptorProto label
                 * @property {google.protobuf.FieldDescriptorProto.Type|null} [type] FieldDescriptorProto type
                 * @property {string|null} [typeName] FieldDescriptorProto typeName
                 * @property {string|null} [extendee] FieldDescriptorProto extendee
                 * @property {string|null} [defaultValue] FieldDescriptorProto defaultValue
                 * @property {number|null} [oneofIndex] FieldDescriptorProto oneofIndex
                 * @property {string|null} [jsonName] FieldDescriptorProto jsonName
                 * @property {google.protobuf.IFieldOptions|null} [options] FieldDescriptorProto options
                 * @property {boolean|null} [proto3Optional] FieldDescriptorProto proto3Optional
                 */
    
                /**
                 * Constructs a new FieldDescriptorProto.
                 * @memberof google.protobuf
                 * @classdesc Represents a FieldDescriptorProto.
                 * @implements IFieldDescriptorProto
                 * @constructor
                 * @param {google.protobuf.IFieldDescriptorProto=} [properties] Properties to set
                 */
                function FieldDescriptorProto(properties) {
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * FieldDescriptorProto name.
                 * @member {string} name
                 * @memberof google.protobuf.FieldDescriptorProto
                 * @instance
                 */
                FieldDescriptorProto.prototype.name = "";
    
                /**
                 * FieldDescriptorProto number.
                 * @member {number} number
                 * @memberof google.protobuf.FieldDescriptorProto
                 * @instance
                 */
                FieldDescriptorProto.prototype.number = 0;
    
                /**
                 * FieldDescriptorProto label.
                 * @member {google.protobuf.FieldDescriptorProto.Label} label
                 * @memberof google.protobuf.FieldDescriptorProto
                 * @instance
                 */
                FieldDescriptorProto.prototype.label = 1;
    
                /**
                 * FieldDescriptorProto type.
                 * @member {google.protobuf.FieldDescriptorProto.Type} type
                 * @memberof google.protobuf.FieldDescriptorProto
                 * @instance
                 */
                FieldDescriptorProto.prototype.type = 1;
    
                /**
                 * FieldDescriptorProto typeName.
                 * @member {string} typeName
                 * @memberof google.protobuf.FieldDescriptorProto
                 * @instance
                 */
                FieldDescriptorProto.prototype.typeName = "";
    
                /**
                 * FieldDescriptorProto extendee.
                 * @member {string} extendee
                 * @memberof google.protobuf.FieldDescriptorProto
                 * @instance
                 */
                FieldDescriptorProto.prototype.extendee = "";
    
                /**
                 * FieldDescriptorProto defaultValue.
                 * @member {string} defaultValue
                 * @memberof google.protobuf.FieldDescriptorProto
                 * @instance
                 */
                FieldDescriptorProto.prototype.defaultValue = "";
    
                /**
                 * FieldDescriptorProto oneofIndex.
                 * @member {number} oneofIndex
                 * @memberof google.protobuf.FieldDescriptorProto
                 * @instance
                 */
                FieldDescriptorProto.prototype.oneofIndex = 0;
    
                /**
                 * FieldDescriptorProto jsonName.
                 * @member {string} jsonName
                 * @memberof google.protobuf.FieldDescriptorProto
                 * @instance
                 */
                FieldDescriptorProto.prototype.jsonName = "";
    
                /**
                 * FieldDescriptorProto options.
                 * @member {google.protobuf.IFieldOptions|null|undefined} options
                 * @memberof google.protobuf.FieldDescriptorProto
                 * @instance
                 */
                FieldDescriptorProto.prototype.options = null;
    
                /**
                 * FieldDescriptorProto proto3Optional.
                 * @member {boolean} proto3Optional
                 * @memberof google.protobuf.FieldDescriptorProto
                 * @instance
                 */
                FieldDescriptorProto.prototype.proto3Optional = false;
    
                /**
                 * Creates a new FieldDescriptorProto instance using the specified properties.
                 * @function create
                 * @memberof google.protobuf.FieldDescriptorProto
                 * @static
                 * @param {google.protobuf.IFieldDescriptorProto=} [properties] Properties to set
                 * @returns {google.protobuf.FieldDescriptorProto} FieldDescriptorProto instance
                 */
                FieldDescriptorProto.create = function create(properties) {
                    return new FieldDescriptorProto(properties);
                };
    
                /**
                 * Encodes the specified FieldDescriptorProto message. Does not implicitly {@link google.protobuf.FieldDescriptorProto.verify|verify} messages.
                 * @function encode
                 * @memberof google.protobuf.FieldDescriptorProto
                 * @static
                 * @param {google.protobuf.IFieldDescriptorProto} message FieldDescriptorProto message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                FieldDescriptorProto.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                    if (message.extendee != null && Object.hasOwnProperty.call(message, "extendee"))
                        writer.uint32(/* id 2, wireType 2 =*/18).string(message.extendee);
                    if (message.number != null && Object.hasOwnProperty.call(message, "number"))
                        writer.uint32(/* id 3, wireType 0 =*/24).int32(message.number);
                    if (message.label != null && Object.hasOwnProperty.call(message, "label"))
                        writer.uint32(/* id 4, wireType 0 =*/32).int32(message.label);
                    if (message.type != null && Object.hasOwnProperty.call(message, "type"))
                        writer.uint32(/* id 5, wireType 0 =*/40).int32(message.type);
                    if (message.typeName != null && Object.hasOwnProperty.call(message, "typeName"))
                        writer.uint32(/* id 6, wireType 2 =*/50).string(message.typeName);
                    if (message.defaultValue != null && Object.hasOwnProperty.call(message, "defaultValue"))
                        writer.uint32(/* id 7, wireType 2 =*/58).string(message.defaultValue);
                    if (message.options != null && Object.hasOwnProperty.call(message, "options"))
                        $root.google.protobuf.FieldOptions.encode(message.options, writer.uint32(/* id 8, wireType 2 =*/66).fork()).ldelim();
                    if (message.oneofIndex != null && Object.hasOwnProperty.call(message, "oneofIndex"))
                        writer.uint32(/* id 9, wireType 0 =*/72).int32(message.oneofIndex);
                    if (message.jsonName != null && Object.hasOwnProperty.call(message, "jsonName"))
                        writer.uint32(/* id 10, wireType 2 =*/82).string(message.jsonName);
                    if (message.proto3Optional != null && Object.hasOwnProperty.call(message, "proto3Optional"))
                        writer.uint32(/* id 17, wireType 0 =*/136).bool(message.proto3Optional);
                    return writer;
                };
    
                /**
                 * Encodes the specified FieldDescriptorProto message, length delimited. Does not implicitly {@link google.protobuf.FieldDescriptorProto.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.protobuf.FieldDescriptorProto
                 * @static
                 * @param {google.protobuf.IFieldDescriptorProto} message FieldDescriptorProto message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                FieldDescriptorProto.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes a FieldDescriptorProto message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.protobuf.FieldDescriptorProto
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.protobuf.FieldDescriptorProto} FieldDescriptorProto
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                FieldDescriptorProto.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.protobuf.FieldDescriptorProto();
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 1: {
                                message.name = reader.string();
                                break;
                            }
                        case 3: {
                                message.number = reader.int32();
                                break;
                            }
                        case 4: {
                                message.label = reader.int32();
                                break;
                            }
                        case 5: {
                                message.type = reader.int32();
                                break;
                            }
                        case 6: {
                                message.typeName = reader.string();
                                break;
                            }
                        case 2: {
                                message.extendee = reader.string();
                                break;
                            }
                        case 7: {
                                message.defaultValue = reader.string();
                                break;
                            }
                        case 9: {
                                message.oneofIndex = reader.int32();
                                break;
                            }
                        case 10: {
                                message.jsonName = reader.string();
                                break;
                            }
                        case 8: {
                                message.options = $root.google.protobuf.FieldOptions.decode(reader, reader.uint32());
                                break;
                            }
                        case 17: {
                                message.proto3Optional = reader.bool();
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes a FieldDescriptorProto message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.protobuf.FieldDescriptorProto
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.protobuf.FieldDescriptorProto} FieldDescriptorProto
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                FieldDescriptorProto.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies a FieldDescriptorProto message.
                 * @function verify
                 * @memberof google.protobuf.FieldDescriptorProto
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                FieldDescriptorProto.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    if (message.name != null && message.hasOwnProperty("name"))
                        if (!$util.isString(message.name))
                            return "name: string expected";
                    if (message.number != null && message.hasOwnProperty("number"))
                        if (!$util.isInteger(message.number))
                            return "number: integer expected";
                    if (message.label != null && message.hasOwnProperty("label"))
                        switch (message.label) {
                        default:
                            return "label: enum value expected";
                        case 1:
                        case 3:
                        case 2:
                            break;
                        }
                    if (message.type != null && message.hasOwnProperty("type"))
                        switch (message.type) {
                        default:
                            return "type: enum value expected";
                        case 1:
                        case 2:
                        case 3:
                        case 4:
                        case 5:
                        case 6:
                        case 7:
                        case 8:
                        case 9:
                        case 10:
                        case 11:
                        case 12:
                        case 13:
                        case 14:
                        case 15:
                        case 16:
                        case 17:
                        case 18:
                            break;
                        }
                    if (message.typeName != null && message.hasOwnProperty("typeName"))
                        if (!$util.isString(message.typeName))
                            return "typeName: string expected";
                    if (message.extendee != null && message.hasOwnProperty("extendee"))
                        if (!$util.isString(message.extendee))
                            return "extendee: string expected";
                    if (message.defaultValue != null && message.hasOwnProperty("defaultValue"))
                        if (!$util.isString(message.defaultValue))
                            return "defaultValue: string expected";
                    if (message.oneofIndex != null && message.hasOwnProperty("oneofIndex"))
                        if (!$util.isInteger(message.oneofIndex))
                            return "oneofIndex: integer expected";
                    if (message.jsonName != null && message.hasOwnProperty("jsonName"))
                        if (!$util.isString(message.jsonName))
                            return "jsonName: string expected";
                    if (message.options != null && message.hasOwnProperty("options")) {
                        var error = $root.google.protobuf.FieldOptions.verify(message.options);
                        if (error)
                            return "options." + error;
                    }
                    if (message.proto3Optional != null && message.hasOwnProperty("proto3Optional"))
                        if (typeof message.proto3Optional !== "boolean")
                            return "proto3Optional: boolean expected";
                    return null;
                };
    
                /**
                 * Creates a FieldDescriptorProto message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.protobuf.FieldDescriptorProto
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.protobuf.FieldDescriptorProto} FieldDescriptorProto
                 */
                FieldDescriptorProto.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.protobuf.FieldDescriptorProto)
                        return object;
                    var message = new $root.google.protobuf.FieldDescriptorProto();
                    if (object.name != null)
                        message.name = String(object.name);
                    if (object.number != null)
                        message.number = object.number | 0;
                    switch (object.label) {
                    default:
                        if (typeof object.label === "number") {
                            message.label = object.label;
                            break;
                        }
                        break;
                    case "LABEL_OPTIONAL":
                    case 1:
                        message.label = 1;
                        break;
                    case "LABEL_REPEATED":
                    case 3:
                        message.label = 3;
                        break;
                    case "LABEL_REQUIRED":
                    case 2:
                        message.label = 2;
                        break;
                    }
                    switch (object.type) {
                    default:
                        if (typeof object.type === "number") {
                            message.type = object.type;
                            break;
                        }
                        break;
                    case "TYPE_DOUBLE":
                    case 1:
                        message.type = 1;
                        break;
                    case "TYPE_FLOAT":
                    case 2:
                        message.type = 2;
                        break;
                    case "TYPE_INT64":
                    case 3:
                        message.type = 3;
                        break;
                    case "TYPE_UINT64":
                    case 4:
                        message.type = 4;
                        break;
                    case "TYPE_INT32":
                    case 5:
                        message.type = 5;
                        break;
                    case "TYPE_FIXED64":
                    case 6:
                        message.type = 6;
                        break;
                    case "TYPE_FIXED32":
                    case 7:
                        message.type = 7;
                        break;
                    case "TYPE_BOOL":
                    case 8:
                        message.type = 8;
                        break;
                    case "TYPE_STRING":
                    case 9:
                        message.type = 9;
                        break;
                    case "TYPE_GROUP":
                    case 10:
                        message.type = 10;
                        break;
                    case "TYPE_MESSAGE":
                    case 11:
                        message.type = 11;
                        break;
                    case "TYPE_BYTES":
                    case 12:
                        message.type = 12;
                        break;
                    case "TYPE_UINT32":
                    case 13:
                        message.type = 13;
                        break;
                    case "TYPE_ENUM":
                    case 14:
                        message.type = 14;
                        break;
                    case "TYPE_SFIXED32":
                    case 15:
                        message.type = 15;
                        break;
                    case "TYPE_SFIXED64":
                    case 16:
                        message.type = 16;
                        break;
                    case "TYPE_SINT32":
                    case 17:
                        message.type = 17;
                        break;
                    case "TYPE_SINT64":
                    case 18:
                        message.type = 18;
                        break;
                    }
                    if (object.typeName != null)
                        message.typeName = String(object.typeName);
                    if (object.extendee != null)
                        message.extendee = String(object.extendee);
                    if (object.defaultValue != null)
                        message.defaultValue = String(object.defaultValue);
                    if (object.oneofIndex != null)
                        message.oneofIndex = object.oneofIndex | 0;
                    if (object.jsonName != null)
                        message.jsonName = String(object.jsonName);
                    if (object.options != null) {
                        if (typeof object.options !== "object")
                            throw TypeError(".google.protobuf.FieldDescriptorProto.options: object expected");
                        message.options = $root.google.protobuf.FieldOptions.fromObject(object.options);
                    }
                    if (object.proto3Optional != null)
                        message.proto3Optional = Boolean(object.proto3Optional);
                    return message;
                };
    
                /**
                 * Creates a plain object from a FieldDescriptorProto message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.protobuf.FieldDescriptorProto
                 * @static
                 * @param {google.protobuf.FieldDescriptorProto} message FieldDescriptorProto
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                FieldDescriptorProto.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (options.defaults) {
                        object.name = "";
                        object.extendee = "";
                        object.number = 0;
                        object.label = options.enums === String ? "LABEL_OPTIONAL" : 1;
                        object.type = options.enums === String ? "TYPE_DOUBLE" : 1;
                        object.typeName = "";
                        object.defaultValue = "";
                        object.options = null;
                        object.oneofIndex = 0;
                        object.jsonName = "";
                        object.proto3Optional = false;
                    }
                    if (message.name != null && message.hasOwnProperty("name"))
                        object.name = message.name;
                    if (message.extendee != null && message.hasOwnProperty("extendee"))
                        object.extendee = message.extendee;
                    if (message.number != null && message.hasOwnProperty("number"))
                        object.number = message.number;
                    if (message.label != null && message.hasOwnProperty("label"))
                        object.label = options.enums === String ? $root.google.protobuf.FieldDescriptorProto.Label[message.label] === undefined ? message.label : $root.google.protobuf.FieldDescriptorProto.Label[message.label] : message.label;
                    if (message.type != null && message.hasOwnProperty("type"))
                        object.type = options.enums === String ? $root.google.protobuf.FieldDescriptorProto.Type[message.type] === undefined ? message.type : $root.google.protobuf.FieldDescriptorProto.Type[message.type] : message.type;
                    if (message.typeName != null && message.hasOwnProperty("typeName"))
                        object.typeName = message.typeName;
                    if (message.defaultValue != null && message.hasOwnProperty("defaultValue"))
                        object.defaultValue = message.defaultValue;
                    if (message.options != null && message.hasOwnProperty("options"))
                        object.options = $root.google.protobuf.FieldOptions.toObject(message.options, options);
                    if (message.oneofIndex != null && message.hasOwnProperty("oneofIndex"))
                        object.oneofIndex = message.oneofIndex;
                    if (message.jsonName != null && message.hasOwnProperty("jsonName"))
                        object.jsonName = message.jsonName;
                    if (message.proto3Optional != null && message.hasOwnProperty("proto3Optional"))
                        object.proto3Optional = message.proto3Optional;
                    return object;
                };
    
                /**
                 * Converts this FieldDescriptorProto to JSON.
                 * @function toJSON
                 * @memberof google.protobuf.FieldDescriptorProto
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                FieldDescriptorProto.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for FieldDescriptorProto
                 * @function getTypeUrl
                 * @memberof google.protobuf.FieldDescriptorProto
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                FieldDescriptorProto.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.protobuf.FieldDescriptorProto";
                };
    
                /**
                 * Type enum.
                 * @name google.protobuf.FieldDescriptorProto.Type
                 * @enum {number}
                 * @property {number} TYPE_DOUBLE=1 TYPE_DOUBLE value
                 * @property {number} TYPE_FLOAT=2 TYPE_FLOAT value
                 * @property {number} TYPE_INT64=3 TYPE_INT64 value
                 * @property {number} TYPE_UINT64=4 TYPE_UINT64 value
                 * @property {number} TYPE_INT32=5 TYPE_INT32 value
                 * @property {number} TYPE_FIXED64=6 TYPE_FIXED64 value
                 * @property {number} TYPE_FIXED32=7 TYPE_FIXED32 value
                 * @property {number} TYPE_BOOL=8 TYPE_BOOL value
                 * @property {number} TYPE_STRING=9 TYPE_STRING value
                 * @property {number} TYPE_GROUP=10 TYPE_GROUP value
                 * @property {number} TYPE_MESSAGE=11 TYPE_MESSAGE value
                 * @property {number} TYPE_BYTES=12 TYPE_BYTES value
                 * @property {number} TYPE_UINT32=13 TYPE_UINT32 value
                 * @property {number} TYPE_ENUM=14 TYPE_ENUM value
                 * @property {number} TYPE_SFIXED32=15 TYPE_SFIXED32 value
                 * @property {number} TYPE_SFIXED64=16 TYPE_SFIXED64 value
                 * @property {number} TYPE_SINT32=17 TYPE_SINT32 value
                 * @property {number} TYPE_SINT64=18 TYPE_SINT64 value
                 */
                FieldDescriptorProto.Type = (function() {
                    var valuesById = {}, values = Object.create(valuesById);
                    values[valuesById[1] = "TYPE_DOUBLE"] = 1;
                    values[valuesById[2] = "TYPE_FLOAT"] = 2;
                    values[valuesById[3] = "TYPE_INT64"] = 3;
                    values[valuesById[4] = "TYPE_UINT64"] = 4;
                    values[valuesById[5] = "TYPE_INT32"] = 5;
                    values[valuesById[6] = "TYPE_FIXED64"] = 6;
                    values[valuesById[7] = "TYPE_FIXED32"] = 7;
                    values[valuesById[8] = "TYPE_BOOL"] = 8;
                    values[valuesById[9] = "TYPE_STRING"] = 9;
                    values[valuesById[10] = "TYPE_GROUP"] = 10;
                    values[valuesById[11] = "TYPE_MESSAGE"] = 11;
                    values[valuesById[12] = "TYPE_BYTES"] = 12;
                    values[valuesById[13] = "TYPE_UINT32"] = 13;
                    values[valuesById[14] = "TYPE_ENUM"] = 14;
                    values[valuesById[15] = "TYPE_SFIXED32"] = 15;
                    values[valuesById[16] = "TYPE_SFIXED64"] = 16;
                    values[valuesById[17] = "TYPE_SINT32"] = 17;
                    values[valuesById[18] = "TYPE_SINT64"] = 18;
                    return values;
                })();
    
                /**
                 * Label enum.
                 * @name google.protobuf.FieldDescriptorProto.Label
                 * @enum {number}
                 * @property {number} LABEL_OPTIONAL=1 LABEL_OPTIONAL value
                 * @property {number} LABEL_REPEATED=3 LABEL_REPEATED value
                 * @property {number} LABEL_REQUIRED=2 LABEL_REQUIRED value
                 */
                FieldDescriptorProto.Label = (function() {
                    var valuesById = {}, values = Object.create(valuesById);
                    values[valuesById[1] = "LABEL_OPTIONAL"] = 1;
                    values[valuesById[3] = "LABEL_REPEATED"] = 3;
                    values[valuesById[2] = "LABEL_REQUIRED"] = 2;
                    return values;
                })();
    
                return FieldDescriptorProto;
            })();
    
            protobuf.OneofDescriptorProto = (function() {
    
                /**
                 * Properties of an OneofDescriptorProto.
                 * @memberof google.protobuf
                 * @interface IOneofDescriptorProto
                 * @property {string|null} [name] OneofDescriptorProto name
                 * @property {google.protobuf.IOneofOptions|null} [options] OneofDescriptorProto options
                 */
    
                /**
                 * Constructs a new OneofDescriptorProto.
                 * @memberof google.protobuf
                 * @classdesc Represents an OneofDescriptorProto.
                 * @implements IOneofDescriptorProto
                 * @constructor
                 * @param {google.protobuf.IOneofDescriptorProto=} [properties] Properties to set
                 */
                function OneofDescriptorProto(properties) {
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * OneofDescriptorProto name.
                 * @member {string} name
                 * @memberof google.protobuf.OneofDescriptorProto
                 * @instance
                 */
                OneofDescriptorProto.prototype.name = "";
    
                /**
                 * OneofDescriptorProto options.
                 * @member {google.protobuf.IOneofOptions|null|undefined} options
                 * @memberof google.protobuf.OneofDescriptorProto
                 * @instance
                 */
                OneofDescriptorProto.prototype.options = null;
    
                /**
                 * Creates a new OneofDescriptorProto instance using the specified properties.
                 * @function create
                 * @memberof google.protobuf.OneofDescriptorProto
                 * @static
                 * @param {google.protobuf.IOneofDescriptorProto=} [properties] Properties to set
                 * @returns {google.protobuf.OneofDescriptorProto} OneofDescriptorProto instance
                 */
                OneofDescriptorProto.create = function create(properties) {
                    return new OneofDescriptorProto(properties);
                };
    
                /**
                 * Encodes the specified OneofDescriptorProto message. Does not implicitly {@link google.protobuf.OneofDescriptorProto.verify|verify} messages.
                 * @function encode
                 * @memberof google.protobuf.OneofDescriptorProto
                 * @static
                 * @param {google.protobuf.IOneofDescriptorProto} message OneofDescriptorProto message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                OneofDescriptorProto.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                    if (message.options != null && Object.hasOwnProperty.call(message, "options"))
                        $root.google.protobuf.OneofOptions.encode(message.options, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                    return writer;
                };
    
                /**
                 * Encodes the specified OneofDescriptorProto message, length delimited. Does not implicitly {@link google.protobuf.OneofDescriptorProto.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.protobuf.OneofDescriptorProto
                 * @static
                 * @param {google.protobuf.IOneofDescriptorProto} message OneofDescriptorProto message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                OneofDescriptorProto.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes an OneofDescriptorProto message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.protobuf.OneofDescriptorProto
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.protobuf.OneofDescriptorProto} OneofDescriptorProto
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                OneofDescriptorProto.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.protobuf.OneofDescriptorProto();
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 1: {
                                message.name = reader.string();
                                break;
                            }
                        case 2: {
                                message.options = $root.google.protobuf.OneofOptions.decode(reader, reader.uint32());
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes an OneofDescriptorProto message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.protobuf.OneofDescriptorProto
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.protobuf.OneofDescriptorProto} OneofDescriptorProto
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                OneofDescriptorProto.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies an OneofDescriptorProto message.
                 * @function verify
                 * @memberof google.protobuf.OneofDescriptorProto
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                OneofDescriptorProto.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    if (message.name != null && message.hasOwnProperty("name"))
                        if (!$util.isString(message.name))
                            return "name: string expected";
                    if (message.options != null && message.hasOwnProperty("options")) {
                        var error = $root.google.protobuf.OneofOptions.verify(message.options);
                        if (error)
                            return "options." + error;
                    }
                    return null;
                };
    
                /**
                 * Creates an OneofDescriptorProto message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.protobuf.OneofDescriptorProto
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.protobuf.OneofDescriptorProto} OneofDescriptorProto
                 */
                OneofDescriptorProto.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.protobuf.OneofDescriptorProto)
                        return object;
                    var message = new $root.google.protobuf.OneofDescriptorProto();
                    if (object.name != null)
                        message.name = String(object.name);
                    if (object.options != null) {
                        if (typeof object.options !== "object")
                            throw TypeError(".google.protobuf.OneofDescriptorProto.options: object expected");
                        message.options = $root.google.protobuf.OneofOptions.fromObject(object.options);
                    }
                    return message;
                };
    
                /**
                 * Creates a plain object from an OneofDescriptorProto message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.protobuf.OneofDescriptorProto
                 * @static
                 * @param {google.protobuf.OneofDescriptorProto} message OneofDescriptorProto
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                OneofDescriptorProto.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (options.defaults) {
                        object.name = "";
                        object.options = null;
                    }
                    if (message.name != null && message.hasOwnProperty("name"))
                        object.name = message.name;
                    if (message.options != null && message.hasOwnProperty("options"))
                        object.options = $root.google.protobuf.OneofOptions.toObject(message.options, options);
                    return object;
                };
    
                /**
                 * Converts this OneofDescriptorProto to JSON.
                 * @function toJSON
                 * @memberof google.protobuf.OneofDescriptorProto
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                OneofDescriptorProto.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for OneofDescriptorProto
                 * @function getTypeUrl
                 * @memberof google.protobuf.OneofDescriptorProto
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                OneofDescriptorProto.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.protobuf.OneofDescriptorProto";
                };
    
                return OneofDescriptorProto;
            })();
    
            protobuf.EnumDescriptorProto = (function() {
    
                /**
                 * Properties of an EnumDescriptorProto.
                 * @memberof google.protobuf
                 * @interface IEnumDescriptorProto
                 * @property {string|null} [name] EnumDescriptorProto name
                 * @property {Array.<google.protobuf.IEnumValueDescriptorProto>|null} [value] EnumDescriptorProto value
                 * @property {google.protobuf.IEnumOptions|null} [options] EnumDescriptorProto options
                 * @property {Array.<google.protobuf.EnumDescriptorProto.IEnumReservedRange>|null} [reservedRange] EnumDescriptorProto reservedRange
                 * @property {Array.<string>|null} [reservedName] EnumDescriptorProto reservedName
                 */
    
                /**
                 * Constructs a new EnumDescriptorProto.
                 * @memberof google.protobuf
                 * @classdesc Represents an EnumDescriptorProto.
                 * @implements IEnumDescriptorProto
                 * @constructor
                 * @param {google.protobuf.IEnumDescriptorProto=} [properties] Properties to set
                 */
                function EnumDescriptorProto(properties) {
                    this.value = [];
                    this.reservedRange = [];
                    this.reservedName = [];
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * EnumDescriptorProto name.
                 * @member {string} name
                 * @memberof google.protobuf.EnumDescriptorProto
                 * @instance
                 */
                EnumDescriptorProto.prototype.name = "";
    
                /**
                 * EnumDescriptorProto value.
                 * @member {Array.<google.protobuf.IEnumValueDescriptorProto>} value
                 * @memberof google.protobuf.EnumDescriptorProto
                 * @instance
                 */
                EnumDescriptorProto.prototype.value = $util.emptyArray;
    
                /**
                 * EnumDescriptorProto options.
                 * @member {google.protobuf.IEnumOptions|null|undefined} options
                 * @memberof google.protobuf.EnumDescriptorProto
                 * @instance
                 */
                EnumDescriptorProto.prototype.options = null;
    
                /**
                 * EnumDescriptorProto reservedRange.
                 * @member {Array.<google.protobuf.EnumDescriptorProto.IEnumReservedRange>} reservedRange
                 * @memberof google.protobuf.EnumDescriptorProto
                 * @instance
                 */
                EnumDescriptorProto.prototype.reservedRange = $util.emptyArray;
    
                /**
                 * EnumDescriptorProto reservedName.
                 * @member {Array.<string>} reservedName
                 * @memberof google.protobuf.EnumDescriptorProto
                 * @instance
                 */
                EnumDescriptorProto.prototype.reservedName = $util.emptyArray;
    
                /**
                 * Creates a new EnumDescriptorProto instance using the specified properties.
                 * @function create
                 * @memberof google.protobuf.EnumDescriptorProto
                 * @static
                 * @param {google.protobuf.IEnumDescriptorProto=} [properties] Properties to set
                 * @returns {google.protobuf.EnumDescriptorProto} EnumDescriptorProto instance
                 */
                EnumDescriptorProto.create = function create(properties) {
                    return new EnumDescriptorProto(properties);
                };
    
                /**
                 * Encodes the specified EnumDescriptorProto message. Does not implicitly {@link google.protobuf.EnumDescriptorProto.verify|verify} messages.
                 * @function encode
                 * @memberof google.protobuf.EnumDescriptorProto
                 * @static
                 * @param {google.protobuf.IEnumDescriptorProto} message EnumDescriptorProto message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                EnumDescriptorProto.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                    if (message.value != null && message.value.length)
                        for (var i = 0; i < message.value.length; ++i)
                            $root.google.protobuf.EnumValueDescriptorProto.encode(message.value[i], writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                    if (message.options != null && Object.hasOwnProperty.call(message, "options"))
                        $root.google.protobuf.EnumOptions.encode(message.options, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                    if (message.reservedRange != null && message.reservedRange.length)
                        for (var i = 0; i < message.reservedRange.length; ++i)
                            $root.google.protobuf.EnumDescriptorProto.EnumReservedRange.encode(message.reservedRange[i], writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                    if (message.reservedName != null && message.reservedName.length)
                        for (var i = 0; i < message.reservedName.length; ++i)
                            writer.uint32(/* id 5, wireType 2 =*/42).string(message.reservedName[i]);
                    return writer;
                };
    
                /**
                 * Encodes the specified EnumDescriptorProto message, length delimited. Does not implicitly {@link google.protobuf.EnumDescriptorProto.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.protobuf.EnumDescriptorProto
                 * @static
                 * @param {google.protobuf.IEnumDescriptorProto} message EnumDescriptorProto message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                EnumDescriptorProto.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes an EnumDescriptorProto message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.protobuf.EnumDescriptorProto
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.protobuf.EnumDescriptorProto} EnumDescriptorProto
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                EnumDescriptorProto.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.protobuf.EnumDescriptorProto();
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 1: {
                                message.name = reader.string();
                                break;
                            }
                        case 2: {
                                if (!(message.value && message.value.length))
                                    message.value = [];
                                message.value.push($root.google.protobuf.EnumValueDescriptorProto.decode(reader, reader.uint32()));
                                break;
                            }
                        case 3: {
                                message.options = $root.google.protobuf.EnumOptions.decode(reader, reader.uint32());
                                break;
                            }
                        case 4: {
                                if (!(message.reservedRange && message.reservedRange.length))
                                    message.reservedRange = [];
                                message.reservedRange.push($root.google.protobuf.EnumDescriptorProto.EnumReservedRange.decode(reader, reader.uint32()));
                                break;
                            }
                        case 5: {
                                if (!(message.reservedName && message.reservedName.length))
                                    message.reservedName = [];
                                message.reservedName.push(reader.string());
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes an EnumDescriptorProto message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.protobuf.EnumDescriptorProto
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.protobuf.EnumDescriptorProto} EnumDescriptorProto
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                EnumDescriptorProto.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies an EnumDescriptorProto message.
                 * @function verify
                 * @memberof google.protobuf.EnumDescriptorProto
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                EnumDescriptorProto.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    if (message.name != null && message.hasOwnProperty("name"))
                        if (!$util.isString(message.name))
                            return "name: string expected";
                    if (message.value != null && message.hasOwnProperty("value")) {
                        if (!Array.isArray(message.value))
                            return "value: array expected";
                        for (var i = 0; i < message.value.length; ++i) {
                            var error = $root.google.protobuf.EnumValueDescriptorProto.verify(message.value[i]);
                            if (error)
                                return "value." + error;
                        }
                    }
                    if (message.options != null && message.hasOwnProperty("options")) {
                        var error = $root.google.protobuf.EnumOptions.verify(message.options);
                        if (error)
                            return "options." + error;
                    }
                    if (message.reservedRange != null && message.hasOwnProperty("reservedRange")) {
                        if (!Array.isArray(message.reservedRange))
                            return "reservedRange: array expected";
                        for (var i = 0; i < message.reservedRange.length; ++i) {
                            var error = $root.google.protobuf.EnumDescriptorProto.EnumReservedRange.verify(message.reservedRange[i]);
                            if (error)
                                return "reservedRange." + error;
                        }
                    }
                    if (message.reservedName != null && message.hasOwnProperty("reservedName")) {
                        if (!Array.isArray(message.reservedName))
                            return "reservedName: array expected";
                        for (var i = 0; i < message.reservedName.length; ++i)
                            if (!$util.isString(message.reservedName[i]))
                                return "reservedName: string[] expected";
                    }
                    return null;
                };
    
                /**
                 * Creates an EnumDescriptorProto message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.protobuf.EnumDescriptorProto
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.protobuf.EnumDescriptorProto} EnumDescriptorProto
                 */
                EnumDescriptorProto.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.protobuf.EnumDescriptorProto)
                        return object;
                    var message = new $root.google.protobuf.EnumDescriptorProto();
                    if (object.name != null)
                        message.name = String(object.name);
                    if (object.value) {
                        if (!Array.isArray(object.value))
                            throw TypeError(".google.protobuf.EnumDescriptorProto.value: array expected");
                        message.value = [];
                        for (var i = 0; i < object.value.length; ++i) {
                            if (typeof object.value[i] !== "object")
                                throw TypeError(".google.protobuf.EnumDescriptorProto.value: object expected");
                            message.value[i] = $root.google.protobuf.EnumValueDescriptorProto.fromObject(object.value[i]);
                        }
                    }
                    if (object.options != null) {
                        if (typeof object.options !== "object")
                            throw TypeError(".google.protobuf.EnumDescriptorProto.options: object expected");
                        message.options = $root.google.protobuf.EnumOptions.fromObject(object.options);
                    }
                    if (object.reservedRange) {
                        if (!Array.isArray(object.reservedRange))
                            throw TypeError(".google.protobuf.EnumDescriptorProto.reservedRange: array expected");
                        message.reservedRange = [];
                        for (var i = 0; i < object.reservedRange.length; ++i) {
                            if (typeof object.reservedRange[i] !== "object")
                                throw TypeError(".google.protobuf.EnumDescriptorProto.reservedRange: object expected");
                            message.reservedRange[i] = $root.google.protobuf.EnumDescriptorProto.EnumReservedRange.fromObject(object.reservedRange[i]);
                        }
                    }
                    if (object.reservedName) {
                        if (!Array.isArray(object.reservedName))
                            throw TypeError(".google.protobuf.EnumDescriptorProto.reservedName: array expected");
                        message.reservedName = [];
                        for (var i = 0; i < object.reservedName.length; ++i)
                            message.reservedName[i] = String(object.reservedName[i]);
                    }
                    return message;
                };
    
                /**
                 * Creates a plain object from an EnumDescriptorProto message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.protobuf.EnumDescriptorProto
                 * @static
                 * @param {google.protobuf.EnumDescriptorProto} message EnumDescriptorProto
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                EnumDescriptorProto.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (options.arrays || options.defaults) {
                        object.value = [];
                        object.reservedRange = [];
                        object.reservedName = [];
                    }
                    if (options.defaults) {
                        object.name = "";
                        object.options = null;
                    }
                    if (message.name != null && message.hasOwnProperty("name"))
                        object.name = message.name;
                    if (message.value && message.value.length) {
                        object.value = [];
                        for (var j = 0; j < message.value.length; ++j)
                            object.value[j] = $root.google.protobuf.EnumValueDescriptorProto.toObject(message.value[j], options);
                    }
                    if (message.options != null && message.hasOwnProperty("options"))
                        object.options = $root.google.protobuf.EnumOptions.toObject(message.options, options);
                    if (message.reservedRange && message.reservedRange.length) {
                        object.reservedRange = [];
                        for (var j = 0; j < message.reservedRange.length; ++j)
                            object.reservedRange[j] = $root.google.protobuf.EnumDescriptorProto.EnumReservedRange.toObject(message.reservedRange[j], options);
                    }
                    if (message.reservedName && message.reservedName.length) {
                        object.reservedName = [];
                        for (var j = 0; j < message.reservedName.length; ++j)
                            object.reservedName[j] = message.reservedName[j];
                    }
                    return object;
                };
    
                /**
                 * Converts this EnumDescriptorProto to JSON.
                 * @function toJSON
                 * @memberof google.protobuf.EnumDescriptorProto
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                EnumDescriptorProto.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for EnumDescriptorProto
                 * @function getTypeUrl
                 * @memberof google.protobuf.EnumDescriptorProto
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                EnumDescriptorProto.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.protobuf.EnumDescriptorProto";
                };
    
                EnumDescriptorProto.EnumReservedRange = (function() {
    
                    /**
                     * Properties of an EnumReservedRange.
                     * @memberof google.protobuf.EnumDescriptorProto
                     * @interface IEnumReservedRange
                     * @property {number|null} [start] EnumReservedRange start
                     * @property {number|null} [end] EnumReservedRange end
                     */
    
                    /**
                     * Constructs a new EnumReservedRange.
                     * @memberof google.protobuf.EnumDescriptorProto
                     * @classdesc Represents an EnumReservedRange.
                     * @implements IEnumReservedRange
                     * @constructor
                     * @param {google.protobuf.EnumDescriptorProto.IEnumReservedRange=} [properties] Properties to set
                     */
                    function EnumReservedRange(properties) {
                        if (properties)
                            for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                if (properties[keys[i]] != null)
                                    this[keys[i]] = properties[keys[i]];
                    }
    
                    /**
                     * EnumReservedRange start.
                     * @member {number} start
                     * @memberof google.protobuf.EnumDescriptorProto.EnumReservedRange
                     * @instance
                     */
                    EnumReservedRange.prototype.start = 0;
    
                    /**
                     * EnumReservedRange end.
                     * @member {number} end
                     * @memberof google.protobuf.EnumDescriptorProto.EnumReservedRange
                     * @instance
                     */
                    EnumReservedRange.prototype.end = 0;
    
                    /**
                     * Creates a new EnumReservedRange instance using the specified properties.
                     * @function create
                     * @memberof google.protobuf.EnumDescriptorProto.EnumReservedRange
                     * @static
                     * @param {google.protobuf.EnumDescriptorProto.IEnumReservedRange=} [properties] Properties to set
                     * @returns {google.protobuf.EnumDescriptorProto.EnumReservedRange} EnumReservedRange instance
                     */
                    EnumReservedRange.create = function create(properties) {
                        return new EnumReservedRange(properties);
                    };
    
                    /**
                     * Encodes the specified EnumReservedRange message. Does not implicitly {@link google.protobuf.EnumDescriptorProto.EnumReservedRange.verify|verify} messages.
                     * @function encode
                     * @memberof google.protobuf.EnumDescriptorProto.EnumReservedRange
                     * @static
                     * @param {google.protobuf.EnumDescriptorProto.IEnumReservedRange} message EnumReservedRange message or plain object to encode
                     * @param {$protobuf.Writer} [writer] Writer to encode to
                     * @returns {$protobuf.Writer} Writer
                     */
                    EnumReservedRange.encode = function encode(message, writer) {
                        if (!writer)
                            writer = $Writer.create();
                        if (message.start != null && Object.hasOwnProperty.call(message, "start"))
                            writer.uint32(/* id 1, wireType 0 =*/8).int32(message.start);
                        if (message.end != null && Object.hasOwnProperty.call(message, "end"))
                            writer.uint32(/* id 2, wireType 0 =*/16).int32(message.end);
                        return writer;
                    };
    
                    /**
                     * Encodes the specified EnumReservedRange message, length delimited. Does not implicitly {@link google.protobuf.EnumDescriptorProto.EnumReservedRange.verify|verify} messages.
                     * @function encodeDelimited
                     * @memberof google.protobuf.EnumDescriptorProto.EnumReservedRange
                     * @static
                     * @param {google.protobuf.EnumDescriptorProto.IEnumReservedRange} message EnumReservedRange message or plain object to encode
                     * @param {$protobuf.Writer} [writer] Writer to encode to
                     * @returns {$protobuf.Writer} Writer
                     */
                    EnumReservedRange.encodeDelimited = function encodeDelimited(message, writer) {
                        return this.encode(message, writer).ldelim();
                    };
    
                    /**
                     * Decodes an EnumReservedRange message from the specified reader or buffer.
                     * @function decode
                     * @memberof google.protobuf.EnumDescriptorProto.EnumReservedRange
                     * @static
                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                     * @param {number} [length] Message length if known beforehand
                     * @returns {google.protobuf.EnumDescriptorProto.EnumReservedRange} EnumReservedRange
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    EnumReservedRange.decode = function decode(reader, length) {
                        if (!(reader instanceof $Reader))
                            reader = $Reader.create(reader);
                        var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.protobuf.EnumDescriptorProto.EnumReservedRange();
                        while (reader.pos < end) {
                            var tag = reader.uint32();
                            switch (tag >>> 3) {
                            case 1: {
                                    message.start = reader.int32();
                                    break;
                                }
                            case 2: {
                                    message.end = reader.int32();
                                    break;
                                }
                            default:
                                reader.skipType(tag & 7);
                                break;
                            }
                        }
                        return message;
                    };
    
                    /**
                     * Decodes an EnumReservedRange message from the specified reader or buffer, length delimited.
                     * @function decodeDelimited
                     * @memberof google.protobuf.EnumDescriptorProto.EnumReservedRange
                     * @static
                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                     * @returns {google.protobuf.EnumDescriptorProto.EnumReservedRange} EnumReservedRange
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    EnumReservedRange.decodeDelimited = function decodeDelimited(reader) {
                        if (!(reader instanceof $Reader))
                            reader = new $Reader(reader);
                        return this.decode(reader, reader.uint32());
                    };
    
                    /**
                     * Verifies an EnumReservedRange message.
                     * @function verify
                     * @memberof google.protobuf.EnumDescriptorProto.EnumReservedRange
                     * @static
                     * @param {Object.<string,*>} message Plain object to verify
                     * @returns {string|null} `null` if valid, otherwise the reason why it is not
                     */
                    EnumReservedRange.verify = function verify(message) {
                        if (typeof message !== "object" || message === null)
                            return "object expected";
                        if (message.start != null && message.hasOwnProperty("start"))
                            if (!$util.isInteger(message.start))
                                return "start: integer expected";
                        if (message.end != null && message.hasOwnProperty("end"))
                            if (!$util.isInteger(message.end))
                                return "end: integer expected";
                        return null;
                    };
    
                    /**
                     * Creates an EnumReservedRange message from a plain object. Also converts values to their respective internal types.
                     * @function fromObject
                     * @memberof google.protobuf.EnumDescriptorProto.EnumReservedRange
                     * @static
                     * @param {Object.<string,*>} object Plain object
                     * @returns {google.protobuf.EnumDescriptorProto.EnumReservedRange} EnumReservedRange
                     */
                    EnumReservedRange.fromObject = function fromObject(object) {
                        if (object instanceof $root.google.protobuf.EnumDescriptorProto.EnumReservedRange)
                            return object;
                        var message = new $root.google.protobuf.EnumDescriptorProto.EnumReservedRange();
                        if (object.start != null)
                            message.start = object.start | 0;
                        if (object.end != null)
                            message.end = object.end | 0;
                        return message;
                    };
    
                    /**
                     * Creates a plain object from an EnumReservedRange message. Also converts values to other types if specified.
                     * @function toObject
                     * @memberof google.protobuf.EnumDescriptorProto.EnumReservedRange
                     * @static
                     * @param {google.protobuf.EnumDescriptorProto.EnumReservedRange} message EnumReservedRange
                     * @param {$protobuf.IConversionOptions} [options] Conversion options
                     * @returns {Object.<string,*>} Plain object
                     */
                    EnumReservedRange.toObject = function toObject(message, options) {
                        if (!options)
                            options = {};
                        var object = {};
                        if (options.defaults) {
                            object.start = 0;
                            object.end = 0;
                        }
                        if (message.start != null && message.hasOwnProperty("start"))
                            object.start = message.start;
                        if (message.end != null && message.hasOwnProperty("end"))
                            object.end = message.end;
                        return object;
                    };
    
                    /**
                     * Converts this EnumReservedRange to JSON.
                     * @function toJSON
                     * @memberof google.protobuf.EnumDescriptorProto.EnumReservedRange
                     * @instance
                     * @returns {Object.<string,*>} JSON object
                     */
                    EnumReservedRange.prototype.toJSON = function toJSON() {
                        return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                    };
    
                    /**
                     * Gets the default type url for EnumReservedRange
                     * @function getTypeUrl
                     * @memberof google.protobuf.EnumDescriptorProto.EnumReservedRange
                     * @static
                     * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns {string} The default type url
                     */
                    EnumReservedRange.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                        if (typeUrlPrefix === undefined) {
                            typeUrlPrefix = "type.googleapis.com";
                        }
                        return typeUrlPrefix + "/google.protobuf.EnumDescriptorProto.EnumReservedRange";
                    };
    
                    return EnumReservedRange;
                })();
    
                return EnumDescriptorProto;
            })();
    
            protobuf.EnumValueDescriptorProto = (function() {
    
                /**
                 * Properties of an EnumValueDescriptorProto.
                 * @memberof google.protobuf
                 * @interface IEnumValueDescriptorProto
                 * @property {string|null} [name] EnumValueDescriptorProto name
                 * @property {number|null} [number] EnumValueDescriptorProto number
                 * @property {google.protobuf.IEnumValueOptions|null} [options] EnumValueDescriptorProto options
                 */
    
                /**
                 * Constructs a new EnumValueDescriptorProto.
                 * @memberof google.protobuf
                 * @classdesc Represents an EnumValueDescriptorProto.
                 * @implements IEnumValueDescriptorProto
                 * @constructor
                 * @param {google.protobuf.IEnumValueDescriptorProto=} [properties] Properties to set
                 */
                function EnumValueDescriptorProto(properties) {
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * EnumValueDescriptorProto name.
                 * @member {string} name
                 * @memberof google.protobuf.EnumValueDescriptorProto
                 * @instance
                 */
                EnumValueDescriptorProto.prototype.name = "";
    
                /**
                 * EnumValueDescriptorProto number.
                 * @member {number} number
                 * @memberof google.protobuf.EnumValueDescriptorProto
                 * @instance
                 */
                EnumValueDescriptorProto.prototype.number = 0;
    
                /**
                 * EnumValueDescriptorProto options.
                 * @member {google.protobuf.IEnumValueOptions|null|undefined} options
                 * @memberof google.protobuf.EnumValueDescriptorProto
                 * @instance
                 */
                EnumValueDescriptorProto.prototype.options = null;
    
                /**
                 * Creates a new EnumValueDescriptorProto instance using the specified properties.
                 * @function create
                 * @memberof google.protobuf.EnumValueDescriptorProto
                 * @static
                 * @param {google.protobuf.IEnumValueDescriptorProto=} [properties] Properties to set
                 * @returns {google.protobuf.EnumValueDescriptorProto} EnumValueDescriptorProto instance
                 */
                EnumValueDescriptorProto.create = function create(properties) {
                    return new EnumValueDescriptorProto(properties);
                };
    
                /**
                 * Encodes the specified EnumValueDescriptorProto message. Does not implicitly {@link google.protobuf.EnumValueDescriptorProto.verify|verify} messages.
                 * @function encode
                 * @memberof google.protobuf.EnumValueDescriptorProto
                 * @static
                 * @param {google.protobuf.IEnumValueDescriptorProto} message EnumValueDescriptorProto message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                EnumValueDescriptorProto.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                    if (message.number != null && Object.hasOwnProperty.call(message, "number"))
                        writer.uint32(/* id 2, wireType 0 =*/16).int32(message.number);
                    if (message.options != null && Object.hasOwnProperty.call(message, "options"))
                        $root.google.protobuf.EnumValueOptions.encode(message.options, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                    return writer;
                };
    
                /**
                 * Encodes the specified EnumValueDescriptorProto message, length delimited. Does not implicitly {@link google.protobuf.EnumValueDescriptorProto.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.protobuf.EnumValueDescriptorProto
                 * @static
                 * @param {google.protobuf.IEnumValueDescriptorProto} message EnumValueDescriptorProto message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                EnumValueDescriptorProto.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes an EnumValueDescriptorProto message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.protobuf.EnumValueDescriptorProto
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.protobuf.EnumValueDescriptorProto} EnumValueDescriptorProto
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                EnumValueDescriptorProto.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.protobuf.EnumValueDescriptorProto();
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 1: {
                                message.name = reader.string();
                                break;
                            }
                        case 2: {
                                message.number = reader.int32();
                                break;
                            }
                        case 3: {
                                message.options = $root.google.protobuf.EnumValueOptions.decode(reader, reader.uint32());
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes an EnumValueDescriptorProto message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.protobuf.EnumValueDescriptorProto
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.protobuf.EnumValueDescriptorProto} EnumValueDescriptorProto
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                EnumValueDescriptorProto.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies an EnumValueDescriptorProto message.
                 * @function verify
                 * @memberof google.protobuf.EnumValueDescriptorProto
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                EnumValueDescriptorProto.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    if (message.name != null && message.hasOwnProperty("name"))
                        if (!$util.isString(message.name))
                            return "name: string expected";
                    if (message.number != null && message.hasOwnProperty("number"))
                        if (!$util.isInteger(message.number))
                            return "number: integer expected";
                    if (message.options != null && message.hasOwnProperty("options")) {
                        var error = $root.google.protobuf.EnumValueOptions.verify(message.options);
                        if (error)
                            return "options." + error;
                    }
                    return null;
                };
    
                /**
                 * Creates an EnumValueDescriptorProto message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.protobuf.EnumValueDescriptorProto
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.protobuf.EnumValueDescriptorProto} EnumValueDescriptorProto
                 */
                EnumValueDescriptorProto.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.protobuf.EnumValueDescriptorProto)
                        return object;
                    var message = new $root.google.protobuf.EnumValueDescriptorProto();
                    if (object.name != null)
                        message.name = String(object.name);
                    if (object.number != null)
                        message.number = object.number | 0;
                    if (object.options != null) {
                        if (typeof object.options !== "object")
                            throw TypeError(".google.protobuf.EnumValueDescriptorProto.options: object expected");
                        message.options = $root.google.protobuf.EnumValueOptions.fromObject(object.options);
                    }
                    return message;
                };
    
                /**
                 * Creates a plain object from an EnumValueDescriptorProto message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.protobuf.EnumValueDescriptorProto
                 * @static
                 * @param {google.protobuf.EnumValueDescriptorProto} message EnumValueDescriptorProto
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                EnumValueDescriptorProto.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (options.defaults) {
                        object.name = "";
                        object.number = 0;
                        object.options = null;
                    }
                    if (message.name != null && message.hasOwnProperty("name"))
                        object.name = message.name;
                    if (message.number != null && message.hasOwnProperty("number"))
                        object.number = message.number;
                    if (message.options != null && message.hasOwnProperty("options"))
                        object.options = $root.google.protobuf.EnumValueOptions.toObject(message.options, options);
                    return object;
                };
    
                /**
                 * Converts this EnumValueDescriptorProto to JSON.
                 * @function toJSON
                 * @memberof google.protobuf.EnumValueDescriptorProto
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                EnumValueDescriptorProto.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for EnumValueDescriptorProto
                 * @function getTypeUrl
                 * @memberof google.protobuf.EnumValueDescriptorProto
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                EnumValueDescriptorProto.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.protobuf.EnumValueDescriptorProto";
                };
    
                return EnumValueDescriptorProto;
            })();
    
            protobuf.ServiceDescriptorProto = (function() {
    
                /**
                 * Properties of a ServiceDescriptorProto.
                 * @memberof google.protobuf
                 * @interface IServiceDescriptorProto
                 * @property {string|null} [name] ServiceDescriptorProto name
                 * @property {Array.<google.protobuf.IMethodDescriptorProto>|null} [method] ServiceDescriptorProto method
                 * @property {google.protobuf.IServiceOptions|null} [options] ServiceDescriptorProto options
                 */
    
                /**
                 * Constructs a new ServiceDescriptorProto.
                 * @memberof google.protobuf
                 * @classdesc Represents a ServiceDescriptorProto.
                 * @implements IServiceDescriptorProto
                 * @constructor
                 * @param {google.protobuf.IServiceDescriptorProto=} [properties] Properties to set
                 */
                function ServiceDescriptorProto(properties) {
                    this.method = [];
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * ServiceDescriptorProto name.
                 * @member {string} name
                 * @memberof google.protobuf.ServiceDescriptorProto
                 * @instance
                 */
                ServiceDescriptorProto.prototype.name = "";
    
                /**
                 * ServiceDescriptorProto method.
                 * @member {Array.<google.protobuf.IMethodDescriptorProto>} method
                 * @memberof google.protobuf.ServiceDescriptorProto
                 * @instance
                 */
                ServiceDescriptorProto.prototype.method = $util.emptyArray;
    
                /**
                 * ServiceDescriptorProto options.
                 * @member {google.protobuf.IServiceOptions|null|undefined} options
                 * @memberof google.protobuf.ServiceDescriptorProto
                 * @instance
                 */
                ServiceDescriptorProto.prototype.options = null;
    
                /**
                 * Creates a new ServiceDescriptorProto instance using the specified properties.
                 * @function create
                 * @memberof google.protobuf.ServiceDescriptorProto
                 * @static
                 * @param {google.protobuf.IServiceDescriptorProto=} [properties] Properties to set
                 * @returns {google.protobuf.ServiceDescriptorProto} ServiceDescriptorProto instance
                 */
                ServiceDescriptorProto.create = function create(properties) {
                    return new ServiceDescriptorProto(properties);
                };
    
                /**
                 * Encodes the specified ServiceDescriptorProto message. Does not implicitly {@link google.protobuf.ServiceDescriptorProto.verify|verify} messages.
                 * @function encode
                 * @memberof google.protobuf.ServiceDescriptorProto
                 * @static
                 * @param {google.protobuf.IServiceDescriptorProto} message ServiceDescriptorProto message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                ServiceDescriptorProto.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                    if (message.method != null && message.method.length)
                        for (var i = 0; i < message.method.length; ++i)
                            $root.google.protobuf.MethodDescriptorProto.encode(message.method[i], writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                    if (message.options != null && Object.hasOwnProperty.call(message, "options"))
                        $root.google.protobuf.ServiceOptions.encode(message.options, writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                    return writer;
                };
    
                /**
                 * Encodes the specified ServiceDescriptorProto message, length delimited. Does not implicitly {@link google.protobuf.ServiceDescriptorProto.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.protobuf.ServiceDescriptorProto
                 * @static
                 * @param {google.protobuf.IServiceDescriptorProto} message ServiceDescriptorProto message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                ServiceDescriptorProto.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes a ServiceDescriptorProto message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.protobuf.ServiceDescriptorProto
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.protobuf.ServiceDescriptorProto} ServiceDescriptorProto
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                ServiceDescriptorProto.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.protobuf.ServiceDescriptorProto();
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 1: {
                                message.name = reader.string();
                                break;
                            }
                        case 2: {
                                if (!(message.method && message.method.length))
                                    message.method = [];
                                message.method.push($root.google.protobuf.MethodDescriptorProto.decode(reader, reader.uint32()));
                                break;
                            }
                        case 3: {
                                message.options = $root.google.protobuf.ServiceOptions.decode(reader, reader.uint32());
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes a ServiceDescriptorProto message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.protobuf.ServiceDescriptorProto
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.protobuf.ServiceDescriptorProto} ServiceDescriptorProto
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                ServiceDescriptorProto.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies a ServiceDescriptorProto message.
                 * @function verify
                 * @memberof google.protobuf.ServiceDescriptorProto
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                ServiceDescriptorProto.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    if (message.name != null && message.hasOwnProperty("name"))
                        if (!$util.isString(message.name))
                            return "name: string expected";
                    if (message.method != null && message.hasOwnProperty("method")) {
                        if (!Array.isArray(message.method))
                            return "method: array expected";
                        for (var i = 0; i < message.method.length; ++i) {
                            var error = $root.google.protobuf.MethodDescriptorProto.verify(message.method[i]);
                            if (error)
                                return "method." + error;
                        }
                    }
                    if (message.options != null && message.hasOwnProperty("options")) {
                        var error = $root.google.protobuf.ServiceOptions.verify(message.options);
                        if (error)
                            return "options." + error;
                    }
                    return null;
                };
    
                /**
                 * Creates a ServiceDescriptorProto message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.protobuf.ServiceDescriptorProto
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.protobuf.ServiceDescriptorProto} ServiceDescriptorProto
                 */
                ServiceDescriptorProto.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.protobuf.ServiceDescriptorProto)
                        return object;
                    var message = new $root.google.protobuf.ServiceDescriptorProto();
                    if (object.name != null)
                        message.name = String(object.name);
                    if (object.method) {
                        if (!Array.isArray(object.method))
                            throw TypeError(".google.protobuf.ServiceDescriptorProto.method: array expected");
                        message.method = [];
                        for (var i = 0; i < object.method.length; ++i) {
                            if (typeof object.method[i] !== "object")
                                throw TypeError(".google.protobuf.ServiceDescriptorProto.method: object expected");
                            message.method[i] = $root.google.protobuf.MethodDescriptorProto.fromObject(object.method[i]);
                        }
                    }
                    if (object.options != null) {
                        if (typeof object.options !== "object")
                            throw TypeError(".google.protobuf.ServiceDescriptorProto.options: object expected");
                        message.options = $root.google.protobuf.ServiceOptions.fromObject(object.options);
                    }
                    return message;
                };
    
                /**
                 * Creates a plain object from a ServiceDescriptorProto message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.protobuf.ServiceDescriptorProto
                 * @static
                 * @param {google.protobuf.ServiceDescriptorProto} message ServiceDescriptorProto
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                ServiceDescriptorProto.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (options.arrays || options.defaults)
                        object.method = [];
                    if (options.defaults) {
                        object.name = "";
                        object.options = null;
                    }
                    if (message.name != null && message.hasOwnProperty("name"))
                        object.name = message.name;
                    if (message.method && message.method.length) {
                        object.method = [];
                        for (var j = 0; j < message.method.length; ++j)
                            object.method[j] = $root.google.protobuf.MethodDescriptorProto.toObject(message.method[j], options);
                    }
                    if (message.options != null && message.hasOwnProperty("options"))
                        object.options = $root.google.protobuf.ServiceOptions.toObject(message.options, options);
                    return object;
                };
    
                /**
                 * Converts this ServiceDescriptorProto to JSON.
                 * @function toJSON
                 * @memberof google.protobuf.ServiceDescriptorProto
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                ServiceDescriptorProto.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for ServiceDescriptorProto
                 * @function getTypeUrl
                 * @memberof google.protobuf.ServiceDescriptorProto
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                ServiceDescriptorProto.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.protobuf.ServiceDescriptorProto";
                };
    
                return ServiceDescriptorProto;
            })();
    
            protobuf.MethodDescriptorProto = (function() {
    
                /**
                 * Properties of a MethodDescriptorProto.
                 * @memberof google.protobuf
                 * @interface IMethodDescriptorProto
                 * @property {string|null} [name] MethodDescriptorProto name
                 * @property {string|null} [inputType] MethodDescriptorProto inputType
                 * @property {string|null} [outputType] MethodDescriptorProto outputType
                 * @property {google.protobuf.IMethodOptions|null} [options] MethodDescriptorProto options
                 * @property {boolean|null} [clientStreaming] MethodDescriptorProto clientStreaming
                 * @property {boolean|null} [serverStreaming] MethodDescriptorProto serverStreaming
                 */
    
                /**
                 * Constructs a new MethodDescriptorProto.
                 * @memberof google.protobuf
                 * @classdesc Represents a MethodDescriptorProto.
                 * @implements IMethodDescriptorProto
                 * @constructor
                 * @param {google.protobuf.IMethodDescriptorProto=} [properties] Properties to set
                 */
                function MethodDescriptorProto(properties) {
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * MethodDescriptorProto name.
                 * @member {string} name
                 * @memberof google.protobuf.MethodDescriptorProto
                 * @instance
                 */
                MethodDescriptorProto.prototype.name = "";
    
                /**
                 * MethodDescriptorProto inputType.
                 * @member {string} inputType
                 * @memberof google.protobuf.MethodDescriptorProto
                 * @instance
                 */
                MethodDescriptorProto.prototype.inputType = "";
    
                /**
                 * MethodDescriptorProto outputType.
                 * @member {string} outputType
                 * @memberof google.protobuf.MethodDescriptorProto
                 * @instance
                 */
                MethodDescriptorProto.prototype.outputType = "";
    
                /**
                 * MethodDescriptorProto options.
                 * @member {google.protobuf.IMethodOptions|null|undefined} options
                 * @memberof google.protobuf.MethodDescriptorProto
                 * @instance
                 */
                MethodDescriptorProto.prototype.options = null;
    
                /**
                 * MethodDescriptorProto clientStreaming.
                 * @member {boolean} clientStreaming
                 * @memberof google.protobuf.MethodDescriptorProto
                 * @instance
                 */
                MethodDescriptorProto.prototype.clientStreaming = false;
    
                /**
                 * MethodDescriptorProto serverStreaming.
                 * @member {boolean} serverStreaming
                 * @memberof google.protobuf.MethodDescriptorProto
                 * @instance
                 */
                MethodDescriptorProto.prototype.serverStreaming = false;
    
                /**
                 * Creates a new MethodDescriptorProto instance using the specified properties.
                 * @function create
                 * @memberof google.protobuf.MethodDescriptorProto
                 * @static
                 * @param {google.protobuf.IMethodDescriptorProto=} [properties] Properties to set
                 * @returns {google.protobuf.MethodDescriptorProto} MethodDescriptorProto instance
                 */
                MethodDescriptorProto.create = function create(properties) {
                    return new MethodDescriptorProto(properties);
                };
    
                /**
                 * Encodes the specified MethodDescriptorProto message. Does not implicitly {@link google.protobuf.MethodDescriptorProto.verify|verify} messages.
                 * @function encode
                 * @memberof google.protobuf.MethodDescriptorProto
                 * @static
                 * @param {google.protobuf.IMethodDescriptorProto} message MethodDescriptorProto message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                MethodDescriptorProto.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                    if (message.inputType != null && Object.hasOwnProperty.call(message, "inputType"))
                        writer.uint32(/* id 2, wireType 2 =*/18).string(message.inputType);
                    if (message.outputType != null && Object.hasOwnProperty.call(message, "outputType"))
                        writer.uint32(/* id 3, wireType 2 =*/26).string(message.outputType);
                    if (message.options != null && Object.hasOwnProperty.call(message, "options"))
                        $root.google.protobuf.MethodOptions.encode(message.options, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                    if (message.clientStreaming != null && Object.hasOwnProperty.call(message, "clientStreaming"))
                        writer.uint32(/* id 5, wireType 0 =*/40).bool(message.clientStreaming);
                    if (message.serverStreaming != null && Object.hasOwnProperty.call(message, "serverStreaming"))
                        writer.uint32(/* id 6, wireType 0 =*/48).bool(message.serverStreaming);
                    return writer;
                };
    
                /**
                 * Encodes the specified MethodDescriptorProto message, length delimited. Does not implicitly {@link google.protobuf.MethodDescriptorProto.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.protobuf.MethodDescriptorProto
                 * @static
                 * @param {google.protobuf.IMethodDescriptorProto} message MethodDescriptorProto message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                MethodDescriptorProto.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes a MethodDescriptorProto message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.protobuf.MethodDescriptorProto
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.protobuf.MethodDescriptorProto} MethodDescriptorProto
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                MethodDescriptorProto.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.protobuf.MethodDescriptorProto();
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 1: {
                                message.name = reader.string();
                                break;
                            }
                        case 2: {
                                message.inputType = reader.string();
                                break;
                            }
                        case 3: {
                                message.outputType = reader.string();
                                break;
                            }
                        case 4: {
                                message.options = $root.google.protobuf.MethodOptions.decode(reader, reader.uint32());
                                break;
                            }
                        case 5: {
                                message.clientStreaming = reader.bool();
                                break;
                            }
                        case 6: {
                                message.serverStreaming = reader.bool();
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes a MethodDescriptorProto message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.protobuf.MethodDescriptorProto
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.protobuf.MethodDescriptorProto} MethodDescriptorProto
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                MethodDescriptorProto.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies a MethodDescriptorProto message.
                 * @function verify
                 * @memberof google.protobuf.MethodDescriptorProto
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                MethodDescriptorProto.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    if (message.name != null && message.hasOwnProperty("name"))
                        if (!$util.isString(message.name))
                            return "name: string expected";
                    if (message.inputType != null && message.hasOwnProperty("inputType"))
                        if (!$util.isString(message.inputType))
                            return "inputType: string expected";
                    if (message.outputType != null && message.hasOwnProperty("outputType"))
                        if (!$util.isString(message.outputType))
                            return "outputType: string expected";
                    if (message.options != null && message.hasOwnProperty("options")) {
                        var error = $root.google.protobuf.MethodOptions.verify(message.options);
                        if (error)
                            return "options." + error;
                    }
                    if (message.clientStreaming != null && message.hasOwnProperty("clientStreaming"))
                        if (typeof message.clientStreaming !== "boolean")
                            return "clientStreaming: boolean expected";
                    if (message.serverStreaming != null && message.hasOwnProperty("serverStreaming"))
                        if (typeof message.serverStreaming !== "boolean")
                            return "serverStreaming: boolean expected";
                    return null;
                };
    
                /**
                 * Creates a MethodDescriptorProto message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.protobuf.MethodDescriptorProto
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.protobuf.MethodDescriptorProto} MethodDescriptorProto
                 */
                MethodDescriptorProto.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.protobuf.MethodDescriptorProto)
                        return object;
                    var message = new $root.google.protobuf.MethodDescriptorProto();
                    if (object.name != null)
                        message.name = String(object.name);
                    if (object.inputType != null)
                        message.inputType = String(object.inputType);
                    if (object.outputType != null)
                        message.outputType = String(object.outputType);
                    if (object.options != null) {
                        if (typeof object.options !== "object")
                            throw TypeError(".google.protobuf.MethodDescriptorProto.options: object expected");
                        message.options = $root.google.protobuf.MethodOptions.fromObject(object.options);
                    }
                    if (object.clientStreaming != null)
                        message.clientStreaming = Boolean(object.clientStreaming);
                    if (object.serverStreaming != null)
                        message.serverStreaming = Boolean(object.serverStreaming);
                    return message;
                };
    
                /**
                 * Creates a plain object from a MethodDescriptorProto message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.protobuf.MethodDescriptorProto
                 * @static
                 * @param {google.protobuf.MethodDescriptorProto} message MethodDescriptorProto
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                MethodDescriptorProto.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (options.defaults) {
                        object.name = "";
                        object.inputType = "";
                        object.outputType = "";
                        object.options = null;
                        object.clientStreaming = false;
                        object.serverStreaming = false;
                    }
                    if (message.name != null && message.hasOwnProperty("name"))
                        object.name = message.name;
                    if (message.inputType != null && message.hasOwnProperty("inputType"))
                        object.inputType = message.inputType;
                    if (message.outputType != null && message.hasOwnProperty("outputType"))
                        object.outputType = message.outputType;
                    if (message.options != null && message.hasOwnProperty("options"))
                        object.options = $root.google.protobuf.MethodOptions.toObject(message.options, options);
                    if (message.clientStreaming != null && message.hasOwnProperty("clientStreaming"))
                        object.clientStreaming = message.clientStreaming;
                    if (message.serverStreaming != null && message.hasOwnProperty("serverStreaming"))
                        object.serverStreaming = message.serverStreaming;
                    return object;
                };
    
                /**
                 * Converts this MethodDescriptorProto to JSON.
                 * @function toJSON
                 * @memberof google.protobuf.MethodDescriptorProto
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                MethodDescriptorProto.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for MethodDescriptorProto
                 * @function getTypeUrl
                 * @memberof google.protobuf.MethodDescriptorProto
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                MethodDescriptorProto.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.protobuf.MethodDescriptorProto";
                };
    
                return MethodDescriptorProto;
            })();
    
            protobuf.FileOptions = (function() {
    
                /**
                 * Properties of a FileOptions.
                 * @memberof google.protobuf
                 * @interface IFileOptions
                 * @property {string|null} [javaPackage] FileOptions javaPackage
                 * @property {string|null} [javaOuterClassname] FileOptions javaOuterClassname
                 * @property {boolean|null} [javaMultipleFiles] FileOptions javaMultipleFiles
                 * @property {boolean|null} [javaGenerateEqualsAndHash] FileOptions javaGenerateEqualsAndHash
                 * @property {boolean|null} [javaStringCheckUtf8] FileOptions javaStringCheckUtf8
                 * @property {google.protobuf.FileOptions.OptimizeMode|null} [optimizeFor] FileOptions optimizeFor
                 * @property {string|null} [goPackage] FileOptions goPackage
                 * @property {boolean|null} [ccGenericServices] FileOptions ccGenericServices
                 * @property {boolean|null} [javaGenericServices] FileOptions javaGenericServices
                 * @property {boolean|null} [pyGenericServices] FileOptions pyGenericServices
                 * @property {boolean|null} [deprecated] FileOptions deprecated
                 * @property {boolean|null} [ccEnableArenas] FileOptions ccEnableArenas
                 * @property {string|null} [objcClassPrefix] FileOptions objcClassPrefix
                 * @property {string|null} [csharpNamespace] FileOptions csharpNamespace
                 * @property {string|null} [swiftPrefix] FileOptions swiftPrefix
                 * @property {string|null} [phpClassPrefix] FileOptions phpClassPrefix
                 * @property {string|null} [phpNamespace] FileOptions phpNamespace
                 * @property {string|null} [phpMetadataNamespace] FileOptions phpMetadataNamespace
                 * @property {string|null} [rubyPackage] FileOptions rubyPackage
                 * @property {google.protobuf.IFeatureSet|null} [features] FileOptions features
                 * @property {Array.<google.protobuf.IUninterpretedOption>|null} [uninterpretedOption] FileOptions uninterpretedOption
                 * @property {Array.<google.api.IResourceDescriptor>|null} [".google.api.resourceDefinition"] FileOptions .google.api.resourceDefinition
                 */
    
                /**
                 * Constructs a new FileOptions.
                 * @memberof google.protobuf
                 * @classdesc Represents a FileOptions.
                 * @implements IFileOptions
                 * @constructor
                 * @param {google.protobuf.IFileOptions=} [properties] Properties to set
                 */
                function FileOptions(properties) {
                    this.uninterpretedOption = [];
                    this[".google.api.resourceDefinition"] = [];
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * FileOptions javaPackage.
                 * @member {string} javaPackage
                 * @memberof google.protobuf.FileOptions
                 * @instance
                 */
                FileOptions.prototype.javaPackage = "";
    
                /**
                 * FileOptions javaOuterClassname.
                 * @member {string} javaOuterClassname
                 * @memberof google.protobuf.FileOptions
                 * @instance
                 */
                FileOptions.prototype.javaOuterClassname = "";
    
                /**
                 * FileOptions javaMultipleFiles.
                 * @member {boolean} javaMultipleFiles
                 * @memberof google.protobuf.FileOptions
                 * @instance
                 */
                FileOptions.prototype.javaMultipleFiles = false;
    
                /**
                 * FileOptions javaGenerateEqualsAndHash.
                 * @member {boolean} javaGenerateEqualsAndHash
                 * @memberof google.protobuf.FileOptions
                 * @instance
                 */
                FileOptions.prototype.javaGenerateEqualsAndHash = false;
    
                /**
                 * FileOptions javaStringCheckUtf8.
                 * @member {boolean} javaStringCheckUtf8
                 * @memberof google.protobuf.FileOptions
                 * @instance
                 */
                FileOptions.prototype.javaStringCheckUtf8 = false;
    
                /**
                 * FileOptions optimizeFor.
                 * @member {google.protobuf.FileOptions.OptimizeMode} optimizeFor
                 * @memberof google.protobuf.FileOptions
                 * @instance
                 */
                FileOptions.prototype.optimizeFor = 1;
    
                /**
                 * FileOptions goPackage.
                 * @member {string} goPackage
                 * @memberof google.protobuf.FileOptions
                 * @instance
                 */
                FileOptions.prototype.goPackage = "";
    
                /**
                 * FileOptions ccGenericServices.
                 * @member {boolean} ccGenericServices
                 * @memberof google.protobuf.FileOptions
                 * @instance
                 */
                FileOptions.prototype.ccGenericServices = false;
    
                /**
                 * FileOptions javaGenericServices.
                 * @member {boolean} javaGenericServices
                 * @memberof google.protobuf.FileOptions
                 * @instance
                 */
                FileOptions.prototype.javaGenericServices = false;
    
                /**
                 * FileOptions pyGenericServices.
                 * @member {boolean} pyGenericServices
                 * @memberof google.protobuf.FileOptions
                 * @instance
                 */
                FileOptions.prototype.pyGenericServices = false;
    
                /**
                 * FileOptions deprecated.
                 * @member {boolean} deprecated
                 * @memberof google.protobuf.FileOptions
                 * @instance
                 */
                FileOptions.prototype.deprecated = false;
    
                /**
                 * FileOptions ccEnableArenas.
                 * @member {boolean} ccEnableArenas
                 * @memberof google.protobuf.FileOptions
                 * @instance
                 */
                FileOptions.prototype.ccEnableArenas = true;
    
                /**
                 * FileOptions objcClassPrefix.
                 * @member {string} objcClassPrefix
                 * @memberof google.protobuf.FileOptions
                 * @instance
                 */
                FileOptions.prototype.objcClassPrefix = "";
    
                /**
                 * FileOptions csharpNamespace.
                 * @member {string} csharpNamespace
                 * @memberof google.protobuf.FileOptions
                 * @instance
                 */
                FileOptions.prototype.csharpNamespace = "";
    
                /**
                 * FileOptions swiftPrefix.
                 * @member {string} swiftPrefix
                 * @memberof google.protobuf.FileOptions
                 * @instance
                 */
                FileOptions.prototype.swiftPrefix = "";
    
                /**
                 * FileOptions phpClassPrefix.
                 * @member {string} phpClassPrefix
                 * @memberof google.protobuf.FileOptions
                 * @instance
                 */
                FileOptions.prototype.phpClassPrefix = "";
    
                /**
                 * FileOptions phpNamespace.
                 * @member {string} phpNamespace
                 * @memberof google.protobuf.FileOptions
                 * @instance
                 */
                FileOptions.prototype.phpNamespace = "";
    
                /**
                 * FileOptions phpMetadataNamespace.
                 * @member {string} phpMetadataNamespace
                 * @memberof google.protobuf.FileOptions
                 * @instance
                 */
                FileOptions.prototype.phpMetadataNamespace = "";
    
                /**
                 * FileOptions rubyPackage.
                 * @member {string} rubyPackage
                 * @memberof google.protobuf.FileOptions
                 * @instance
                 */
                FileOptions.prototype.rubyPackage = "";
    
                /**
                 * FileOptions features.
                 * @member {google.protobuf.IFeatureSet|null|undefined} features
                 * @memberof google.protobuf.FileOptions
                 * @instance
                 */
                FileOptions.prototype.features = null;
    
                /**
                 * FileOptions uninterpretedOption.
                 * @member {Array.<google.protobuf.IUninterpretedOption>} uninterpretedOption
                 * @memberof google.protobuf.FileOptions
                 * @instance
                 */
                FileOptions.prototype.uninterpretedOption = $util.emptyArray;
    
                /**
                 * FileOptions .google.api.resourceDefinition.
                 * @member {Array.<google.api.IResourceDescriptor>} .google.api.resourceDefinition
                 * @memberof google.protobuf.FileOptions
                 * @instance
                 */
                FileOptions.prototype[".google.api.resourceDefinition"] = $util.emptyArray;
    
                /**
                 * Creates a new FileOptions instance using the specified properties.
                 * @function create
                 * @memberof google.protobuf.FileOptions
                 * @static
                 * @param {google.protobuf.IFileOptions=} [properties] Properties to set
                 * @returns {google.protobuf.FileOptions} FileOptions instance
                 */
                FileOptions.create = function create(properties) {
                    return new FileOptions(properties);
                };
    
                /**
                 * Encodes the specified FileOptions message. Does not implicitly {@link google.protobuf.FileOptions.verify|verify} messages.
                 * @function encode
                 * @memberof google.protobuf.FileOptions
                 * @static
                 * @param {google.protobuf.IFileOptions} message FileOptions message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                FileOptions.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.javaPackage != null && Object.hasOwnProperty.call(message, "javaPackage"))
                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.javaPackage);
                    if (message.javaOuterClassname != null && Object.hasOwnProperty.call(message, "javaOuterClassname"))
                        writer.uint32(/* id 8, wireType 2 =*/66).string(message.javaOuterClassname);
                    if (message.optimizeFor != null && Object.hasOwnProperty.call(message, "optimizeFor"))
                        writer.uint32(/* id 9, wireType 0 =*/72).int32(message.optimizeFor);
                    if (message.javaMultipleFiles != null && Object.hasOwnProperty.call(message, "javaMultipleFiles"))
                        writer.uint32(/* id 10, wireType 0 =*/80).bool(message.javaMultipleFiles);
                    if (message.goPackage != null && Object.hasOwnProperty.call(message, "goPackage"))
                        writer.uint32(/* id 11, wireType 2 =*/90).string(message.goPackage);
                    if (message.ccGenericServices != null && Object.hasOwnProperty.call(message, "ccGenericServices"))
                        writer.uint32(/* id 16, wireType 0 =*/128).bool(message.ccGenericServices);
                    if (message.javaGenericServices != null && Object.hasOwnProperty.call(message, "javaGenericServices"))
                        writer.uint32(/* id 17, wireType 0 =*/136).bool(message.javaGenericServices);
                    if (message.pyGenericServices != null && Object.hasOwnProperty.call(message, "pyGenericServices"))
                        writer.uint32(/* id 18, wireType 0 =*/144).bool(message.pyGenericServices);
                    if (message.javaGenerateEqualsAndHash != null && Object.hasOwnProperty.call(message, "javaGenerateEqualsAndHash"))
                        writer.uint32(/* id 20, wireType 0 =*/160).bool(message.javaGenerateEqualsAndHash);
                    if (message.deprecated != null && Object.hasOwnProperty.call(message, "deprecated"))
                        writer.uint32(/* id 23, wireType 0 =*/184).bool(message.deprecated);
                    if (message.javaStringCheckUtf8 != null && Object.hasOwnProperty.call(message, "javaStringCheckUtf8"))
                        writer.uint32(/* id 27, wireType 0 =*/216).bool(message.javaStringCheckUtf8);
                    if (message.ccEnableArenas != null && Object.hasOwnProperty.call(message, "ccEnableArenas"))
                        writer.uint32(/* id 31, wireType 0 =*/248).bool(message.ccEnableArenas);
                    if (message.objcClassPrefix != null && Object.hasOwnProperty.call(message, "objcClassPrefix"))
                        writer.uint32(/* id 36, wireType 2 =*/290).string(message.objcClassPrefix);
                    if (message.csharpNamespace != null && Object.hasOwnProperty.call(message, "csharpNamespace"))
                        writer.uint32(/* id 37, wireType 2 =*/298).string(message.csharpNamespace);
                    if (message.swiftPrefix != null && Object.hasOwnProperty.call(message, "swiftPrefix"))
                        writer.uint32(/* id 39, wireType 2 =*/314).string(message.swiftPrefix);
                    if (message.phpClassPrefix != null && Object.hasOwnProperty.call(message, "phpClassPrefix"))
                        writer.uint32(/* id 40, wireType 2 =*/322).string(message.phpClassPrefix);
                    if (message.phpNamespace != null && Object.hasOwnProperty.call(message, "phpNamespace"))
                        writer.uint32(/* id 41, wireType 2 =*/330).string(message.phpNamespace);
                    if (message.phpMetadataNamespace != null && Object.hasOwnProperty.call(message, "phpMetadataNamespace"))
                        writer.uint32(/* id 44, wireType 2 =*/354).string(message.phpMetadataNamespace);
                    if (message.rubyPackage != null && Object.hasOwnProperty.call(message, "rubyPackage"))
                        writer.uint32(/* id 45, wireType 2 =*/362).string(message.rubyPackage);
                    if (message.features != null && Object.hasOwnProperty.call(message, "features"))
                        $root.google.protobuf.FeatureSet.encode(message.features, writer.uint32(/* id 50, wireType 2 =*/402).fork()).ldelim();
                    if (message.uninterpretedOption != null && message.uninterpretedOption.length)
                        for (var i = 0; i < message.uninterpretedOption.length; ++i)
                            $root.google.protobuf.UninterpretedOption.encode(message.uninterpretedOption[i], writer.uint32(/* id 999, wireType 2 =*/7994).fork()).ldelim();
                    if (message[".google.api.resourceDefinition"] != null && message[".google.api.resourceDefinition"].length)
                        for (var i = 0; i < message[".google.api.resourceDefinition"].length; ++i)
                            $root.google.api.ResourceDescriptor.encode(message[".google.api.resourceDefinition"][i], writer.uint32(/* id 1053, wireType 2 =*/8426).fork()).ldelim();
                    return writer;
                };
    
                /**
                 * Encodes the specified FileOptions message, length delimited. Does not implicitly {@link google.protobuf.FileOptions.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.protobuf.FileOptions
                 * @static
                 * @param {google.protobuf.IFileOptions} message FileOptions message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                FileOptions.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes a FileOptions message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.protobuf.FileOptions
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.protobuf.FileOptions} FileOptions
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                FileOptions.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.protobuf.FileOptions();
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 1: {
                                message.javaPackage = reader.string();
                                break;
                            }
                        case 8: {
                                message.javaOuterClassname = reader.string();
                                break;
                            }
                        case 10: {
                                message.javaMultipleFiles = reader.bool();
                                break;
                            }
                        case 20: {
                                message.javaGenerateEqualsAndHash = reader.bool();
                                break;
                            }
                        case 27: {
                                message.javaStringCheckUtf8 = reader.bool();
                                break;
                            }
                        case 9: {
                                message.optimizeFor = reader.int32();
                                break;
                            }
                        case 11: {
                                message.goPackage = reader.string();
                                break;
                            }
                        case 16: {
                                message.ccGenericServices = reader.bool();
                                break;
                            }
                        case 17: {
                                message.javaGenericServices = reader.bool();
                                break;
                            }
                        case 18: {
                                message.pyGenericServices = reader.bool();
                                break;
                            }
                        case 23: {
                                message.deprecated = reader.bool();
                                break;
                            }
                        case 31: {
                                message.ccEnableArenas = reader.bool();
                                break;
                            }
                        case 36: {
                                message.objcClassPrefix = reader.string();
                                break;
                            }
                        case 37: {
                                message.csharpNamespace = reader.string();
                                break;
                            }
                        case 39: {
                                message.swiftPrefix = reader.string();
                                break;
                            }
                        case 40: {
                                message.phpClassPrefix = reader.string();
                                break;
                            }
                        case 41: {
                                message.phpNamespace = reader.string();
                                break;
                            }
                        case 44: {
                                message.phpMetadataNamespace = reader.string();
                                break;
                            }
                        case 45: {
                                message.rubyPackage = reader.string();
                                break;
                            }
                        case 50: {
                                message.features = $root.google.protobuf.FeatureSet.decode(reader, reader.uint32());
                                break;
                            }
                        case 999: {
                                if (!(message.uninterpretedOption && message.uninterpretedOption.length))
                                    message.uninterpretedOption = [];
                                message.uninterpretedOption.push($root.google.protobuf.UninterpretedOption.decode(reader, reader.uint32()));
                                break;
                            }
                        case 1053: {
                                if (!(message[".google.api.resourceDefinition"] && message[".google.api.resourceDefinition"].length))
                                    message[".google.api.resourceDefinition"] = [];
                                message[".google.api.resourceDefinition"].push($root.google.api.ResourceDescriptor.decode(reader, reader.uint32()));
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes a FileOptions message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.protobuf.FileOptions
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.protobuf.FileOptions} FileOptions
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                FileOptions.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies a FileOptions message.
                 * @function verify
                 * @memberof google.protobuf.FileOptions
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                FileOptions.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    if (message.javaPackage != null && message.hasOwnProperty("javaPackage"))
                        if (!$util.isString(message.javaPackage))
                            return "javaPackage: string expected";
                    if (message.javaOuterClassname != null && message.hasOwnProperty("javaOuterClassname"))
                        if (!$util.isString(message.javaOuterClassname))
                            return "javaOuterClassname: string expected";
                    if (message.javaMultipleFiles != null && message.hasOwnProperty("javaMultipleFiles"))
                        if (typeof message.javaMultipleFiles !== "boolean")
                            return "javaMultipleFiles: boolean expected";
                    if (message.javaGenerateEqualsAndHash != null && message.hasOwnProperty("javaGenerateEqualsAndHash"))
                        if (typeof message.javaGenerateEqualsAndHash !== "boolean")
                            return "javaGenerateEqualsAndHash: boolean expected";
                    if (message.javaStringCheckUtf8 != null && message.hasOwnProperty("javaStringCheckUtf8"))
                        if (typeof message.javaStringCheckUtf8 !== "boolean")
                            return "javaStringCheckUtf8: boolean expected";
                    if (message.optimizeFor != null && message.hasOwnProperty("optimizeFor"))
                        switch (message.optimizeFor) {
                        default:
                            return "optimizeFor: enum value expected";
                        case 1:
                        case 2:
                        case 3:
                            break;
                        }
                    if (message.goPackage != null && message.hasOwnProperty("goPackage"))
                        if (!$util.isString(message.goPackage))
                            return "goPackage: string expected";
                    if (message.ccGenericServices != null && message.hasOwnProperty("ccGenericServices"))
                        if (typeof message.ccGenericServices !== "boolean")
                            return "ccGenericServices: boolean expected";
                    if (message.javaGenericServices != null && message.hasOwnProperty("javaGenericServices"))
                        if (typeof message.javaGenericServices !== "boolean")
                            return "javaGenericServices: boolean expected";
                    if (message.pyGenericServices != null && message.hasOwnProperty("pyGenericServices"))
                        if (typeof message.pyGenericServices !== "boolean")
                            return "pyGenericServices: boolean expected";
                    if (message.deprecated != null && message.hasOwnProperty("deprecated"))
                        if (typeof message.deprecated !== "boolean")
                            return "deprecated: boolean expected";
                    if (message.ccEnableArenas != null && message.hasOwnProperty("ccEnableArenas"))
                        if (typeof message.ccEnableArenas !== "boolean")
                            return "ccEnableArenas: boolean expected";
                    if (message.objcClassPrefix != null && message.hasOwnProperty("objcClassPrefix"))
                        if (!$util.isString(message.objcClassPrefix))
                            return "objcClassPrefix: string expected";
                    if (message.csharpNamespace != null && message.hasOwnProperty("csharpNamespace"))
                        if (!$util.isString(message.csharpNamespace))
                            return "csharpNamespace: string expected";
                    if (message.swiftPrefix != null && message.hasOwnProperty("swiftPrefix"))
                        if (!$util.isString(message.swiftPrefix))
                            return "swiftPrefix: string expected";
                    if (message.phpClassPrefix != null && message.hasOwnProperty("phpClassPrefix"))
                        if (!$util.isString(message.phpClassPrefix))
                            return "phpClassPrefix: string expected";
                    if (message.phpNamespace != null && message.hasOwnProperty("phpNamespace"))
                        if (!$util.isString(message.phpNamespace))
                            return "phpNamespace: string expected";
                    if (message.phpMetadataNamespace != null && message.hasOwnProperty("phpMetadataNamespace"))
                        if (!$util.isString(message.phpMetadataNamespace))
                            return "phpMetadataNamespace: string expected";
                    if (message.rubyPackage != null && message.hasOwnProperty("rubyPackage"))
                        if (!$util.isString(message.rubyPackage))
                            return "rubyPackage: string expected";
                    if (message.features != null && message.hasOwnProperty("features")) {
                        var error = $root.google.protobuf.FeatureSet.verify(message.features);
                        if (error)
                            return "features." + error;
                    }
                    if (message.uninterpretedOption != null && message.hasOwnProperty("uninterpretedOption")) {
                        if (!Array.isArray(message.uninterpretedOption))
                            return "uninterpretedOption: array expected";
                        for (var i = 0; i < message.uninterpretedOption.length; ++i) {
                            var error = $root.google.protobuf.UninterpretedOption.verify(message.uninterpretedOption[i]);
                            if (error)
                                return "uninterpretedOption." + error;
                        }
                    }
                    if (message[".google.api.resourceDefinition"] != null && message.hasOwnProperty(".google.api.resourceDefinition")) {
                        if (!Array.isArray(message[".google.api.resourceDefinition"]))
                            return ".google.api.resourceDefinition: array expected";
                        for (var i = 0; i < message[".google.api.resourceDefinition"].length; ++i) {
                            var error = $root.google.api.ResourceDescriptor.verify(message[".google.api.resourceDefinition"][i]);
                            if (error)
                                return ".google.api.resourceDefinition." + error;
                        }
                    }
                    return null;
                };
    
                /**
                 * Creates a FileOptions message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.protobuf.FileOptions
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.protobuf.FileOptions} FileOptions
                 */
                FileOptions.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.protobuf.FileOptions)
                        return object;
                    var message = new $root.google.protobuf.FileOptions();
                    if (object.javaPackage != null)
                        message.javaPackage = String(object.javaPackage);
                    if (object.javaOuterClassname != null)
                        message.javaOuterClassname = String(object.javaOuterClassname);
                    if (object.javaMultipleFiles != null)
                        message.javaMultipleFiles = Boolean(object.javaMultipleFiles);
                    if (object.javaGenerateEqualsAndHash != null)
                        message.javaGenerateEqualsAndHash = Boolean(object.javaGenerateEqualsAndHash);
                    if (object.javaStringCheckUtf8 != null)
                        message.javaStringCheckUtf8 = Boolean(object.javaStringCheckUtf8);
                    switch (object.optimizeFor) {
                    default:
                        if (typeof object.optimizeFor === "number") {
                            message.optimizeFor = object.optimizeFor;
                            break;
                        }
                        break;
                    case "SPEED":
                    case 1:
                        message.optimizeFor = 1;
                        break;
                    case "CODE_SIZE":
                    case 2:
                        message.optimizeFor = 2;
                        break;
                    case "LITE_RUNTIME":
                    case 3:
                        message.optimizeFor = 3;
                        break;
                    }
                    if (object.goPackage != null)
                        message.goPackage = String(object.goPackage);
                    if (object.ccGenericServices != null)
                        message.ccGenericServices = Boolean(object.ccGenericServices);
                    if (object.javaGenericServices != null)
                        message.javaGenericServices = Boolean(object.javaGenericServices);
                    if (object.pyGenericServices != null)
                        message.pyGenericServices = Boolean(object.pyGenericServices);
                    if (object.deprecated != null)
                        message.deprecated = Boolean(object.deprecated);
                    if (object.ccEnableArenas != null)
                        message.ccEnableArenas = Boolean(object.ccEnableArenas);
                    if (object.objcClassPrefix != null)
                        message.objcClassPrefix = String(object.objcClassPrefix);
                    if (object.csharpNamespace != null)
                        message.csharpNamespace = String(object.csharpNamespace);
                    if (object.swiftPrefix != null)
                        message.swiftPrefix = String(object.swiftPrefix);
                    if (object.phpClassPrefix != null)
                        message.phpClassPrefix = String(object.phpClassPrefix);
                    if (object.phpNamespace != null)
                        message.phpNamespace = String(object.phpNamespace);
                    if (object.phpMetadataNamespace != null)
                        message.phpMetadataNamespace = String(object.phpMetadataNamespace);
                    if (object.rubyPackage != null)
                        message.rubyPackage = String(object.rubyPackage);
                    if (object.features != null) {
                        if (typeof object.features !== "object")
                            throw TypeError(".google.protobuf.FileOptions.features: object expected");
                        message.features = $root.google.protobuf.FeatureSet.fromObject(object.features);
                    }
                    if (object.uninterpretedOption) {
                        if (!Array.isArray(object.uninterpretedOption))
                            throw TypeError(".google.protobuf.FileOptions.uninterpretedOption: array expected");
                        message.uninterpretedOption = [];
                        for (var i = 0; i < object.uninterpretedOption.length; ++i) {
                            if (typeof object.uninterpretedOption[i] !== "object")
                                throw TypeError(".google.protobuf.FileOptions.uninterpretedOption: object expected");
                            message.uninterpretedOption[i] = $root.google.protobuf.UninterpretedOption.fromObject(object.uninterpretedOption[i]);
                        }
                    }
                    if (object[".google.api.resourceDefinition"]) {
                        if (!Array.isArray(object[".google.api.resourceDefinition"]))
                            throw TypeError(".google.protobuf.FileOptions..google.api.resourceDefinition: array expected");
                        message[".google.api.resourceDefinition"] = [];
                        for (var i = 0; i < object[".google.api.resourceDefinition"].length; ++i) {
                            if (typeof object[".google.api.resourceDefinition"][i] !== "object")
                                throw TypeError(".google.protobuf.FileOptions..google.api.resourceDefinition: object expected");
                            message[".google.api.resourceDefinition"][i] = $root.google.api.ResourceDescriptor.fromObject(object[".google.api.resourceDefinition"][i]);
                        }
                    }
                    return message;
                };
    
                /**
                 * Creates a plain object from a FileOptions message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.protobuf.FileOptions
                 * @static
                 * @param {google.protobuf.FileOptions} message FileOptions
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                FileOptions.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (options.arrays || options.defaults) {
                        object.uninterpretedOption = [];
                        object[".google.api.resourceDefinition"] = [];
                    }
                    if (options.defaults) {
                        object.javaPackage = "";
                        object.javaOuterClassname = "";
                        object.optimizeFor = options.enums === String ? "SPEED" : 1;
                        object.javaMultipleFiles = false;
                        object.goPackage = "";
                        object.ccGenericServices = false;
                        object.javaGenericServices = false;
                        object.pyGenericServices = false;
                        object.javaGenerateEqualsAndHash = false;
                        object.deprecated = false;
                        object.javaStringCheckUtf8 = false;
                        object.ccEnableArenas = true;
                        object.objcClassPrefix = "";
                        object.csharpNamespace = "";
                        object.swiftPrefix = "";
                        object.phpClassPrefix = "";
                        object.phpNamespace = "";
                        object.phpMetadataNamespace = "";
                        object.rubyPackage = "";
                        object.features = null;
                    }
                    if (message.javaPackage != null && message.hasOwnProperty("javaPackage"))
                        object.javaPackage = message.javaPackage;
                    if (message.javaOuterClassname != null && message.hasOwnProperty("javaOuterClassname"))
                        object.javaOuterClassname = message.javaOuterClassname;
                    if (message.optimizeFor != null && message.hasOwnProperty("optimizeFor"))
                        object.optimizeFor = options.enums === String ? $root.google.protobuf.FileOptions.OptimizeMode[message.optimizeFor] === undefined ? message.optimizeFor : $root.google.protobuf.FileOptions.OptimizeMode[message.optimizeFor] : message.optimizeFor;
                    if (message.javaMultipleFiles != null && message.hasOwnProperty("javaMultipleFiles"))
                        object.javaMultipleFiles = message.javaMultipleFiles;
                    if (message.goPackage != null && message.hasOwnProperty("goPackage"))
                        object.goPackage = message.goPackage;
                    if (message.ccGenericServices != null && message.hasOwnProperty("ccGenericServices"))
                        object.ccGenericServices = message.ccGenericServices;
                    if (message.javaGenericServices != null && message.hasOwnProperty("javaGenericServices"))
                        object.javaGenericServices = message.javaGenericServices;
                    if (message.pyGenericServices != null && message.hasOwnProperty("pyGenericServices"))
                        object.pyGenericServices = message.pyGenericServices;
                    if (message.javaGenerateEqualsAndHash != null && message.hasOwnProperty("javaGenerateEqualsAndHash"))
                        object.javaGenerateEqualsAndHash = message.javaGenerateEqualsAndHash;
                    if (message.deprecated != null && message.hasOwnProperty("deprecated"))
                        object.deprecated = message.deprecated;
                    if (message.javaStringCheckUtf8 != null && message.hasOwnProperty("javaStringCheckUtf8"))
                        object.javaStringCheckUtf8 = message.javaStringCheckUtf8;
                    if (message.ccEnableArenas != null && message.hasOwnProperty("ccEnableArenas"))
                        object.ccEnableArenas = message.ccEnableArenas;
                    if (message.objcClassPrefix != null && message.hasOwnProperty("objcClassPrefix"))
                        object.objcClassPrefix = message.objcClassPrefix;
                    if (message.csharpNamespace != null && message.hasOwnProperty("csharpNamespace"))
                        object.csharpNamespace = message.csharpNamespace;
                    if (message.swiftPrefix != null && message.hasOwnProperty("swiftPrefix"))
                        object.swiftPrefix = message.swiftPrefix;
                    if (message.phpClassPrefix != null && message.hasOwnProperty("phpClassPrefix"))
                        object.phpClassPrefix = message.phpClassPrefix;
                    if (message.phpNamespace != null && message.hasOwnProperty("phpNamespace"))
                        object.phpNamespace = message.phpNamespace;
                    if (message.phpMetadataNamespace != null && message.hasOwnProperty("phpMetadataNamespace"))
                        object.phpMetadataNamespace = message.phpMetadataNamespace;
                    if (message.rubyPackage != null && message.hasOwnProperty("rubyPackage"))
                        object.rubyPackage = message.rubyPackage;
                    if (message.features != null && message.hasOwnProperty("features"))
                        object.features = $root.google.protobuf.FeatureSet.toObject(message.features, options);
                    if (message.uninterpretedOption && message.uninterpretedOption.length) {
                        object.uninterpretedOption = [];
                        for (var j = 0; j < message.uninterpretedOption.length; ++j)
                            object.uninterpretedOption[j] = $root.google.protobuf.UninterpretedOption.toObject(message.uninterpretedOption[j], options);
                    }
                    if (message[".google.api.resourceDefinition"] && message[".google.api.resourceDefinition"].length) {
                        object[".google.api.resourceDefinition"] = [];
                        for (var j = 0; j < message[".google.api.resourceDefinition"].length; ++j)
                            object[".google.api.resourceDefinition"][j] = $root.google.api.ResourceDescriptor.toObject(message[".google.api.resourceDefinition"][j], options);
                    }
                    return object;
                };
    
                /**
                 * Converts this FileOptions to JSON.
                 * @function toJSON
                 * @memberof google.protobuf.FileOptions
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                FileOptions.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for FileOptions
                 * @function getTypeUrl
                 * @memberof google.protobuf.FileOptions
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                FileOptions.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.protobuf.FileOptions";
                };
    
                /**
                 * OptimizeMode enum.
                 * @name google.protobuf.FileOptions.OptimizeMode
                 * @enum {number}
                 * @property {number} SPEED=1 SPEED value
                 * @property {number} CODE_SIZE=2 CODE_SIZE value
                 * @property {number} LITE_RUNTIME=3 LITE_RUNTIME value
                 */
                FileOptions.OptimizeMode = (function() {
                    var valuesById = {}, values = Object.create(valuesById);
                    values[valuesById[1] = "SPEED"] = 1;
                    values[valuesById[2] = "CODE_SIZE"] = 2;
                    values[valuesById[3] = "LITE_RUNTIME"] = 3;
                    return values;
                })();
    
                return FileOptions;
            })();
    
            protobuf.MessageOptions = (function() {
    
                /**
                 * Properties of a MessageOptions.
                 * @memberof google.protobuf
                 * @interface IMessageOptions
                 * @property {boolean|null} [messageSetWireFormat] MessageOptions messageSetWireFormat
                 * @property {boolean|null} [noStandardDescriptorAccessor] MessageOptions noStandardDescriptorAccessor
                 * @property {boolean|null} [deprecated] MessageOptions deprecated
                 * @property {boolean|null} [mapEntry] MessageOptions mapEntry
                 * @property {boolean|null} [deprecatedLegacyJsonFieldConflicts] MessageOptions deprecatedLegacyJsonFieldConflicts
                 * @property {google.protobuf.IFeatureSet|null} [features] MessageOptions features
                 * @property {Array.<google.protobuf.IUninterpretedOption>|null} [uninterpretedOption] MessageOptions uninterpretedOption
                 * @property {google.api.IResourceDescriptor|null} [".google.api.resource"] MessageOptions .google.api.resource
                 */
    
                /**
                 * Constructs a new MessageOptions.
                 * @memberof google.protobuf
                 * @classdesc Represents a MessageOptions.
                 * @implements IMessageOptions
                 * @constructor
                 * @param {google.protobuf.IMessageOptions=} [properties] Properties to set
                 */
                function MessageOptions(properties) {
                    this.uninterpretedOption = [];
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * MessageOptions messageSetWireFormat.
                 * @member {boolean} messageSetWireFormat
                 * @memberof google.protobuf.MessageOptions
                 * @instance
                 */
                MessageOptions.prototype.messageSetWireFormat = false;
    
                /**
                 * MessageOptions noStandardDescriptorAccessor.
                 * @member {boolean} noStandardDescriptorAccessor
                 * @memberof google.protobuf.MessageOptions
                 * @instance
                 */
                MessageOptions.prototype.noStandardDescriptorAccessor = false;
    
                /**
                 * MessageOptions deprecated.
                 * @member {boolean} deprecated
                 * @memberof google.protobuf.MessageOptions
                 * @instance
                 */
                MessageOptions.prototype.deprecated = false;
    
                /**
                 * MessageOptions mapEntry.
                 * @member {boolean} mapEntry
                 * @memberof google.protobuf.MessageOptions
                 * @instance
                 */
                MessageOptions.prototype.mapEntry = false;
    
                /**
                 * MessageOptions deprecatedLegacyJsonFieldConflicts.
                 * @member {boolean} deprecatedLegacyJsonFieldConflicts
                 * @memberof google.protobuf.MessageOptions
                 * @instance
                 */
                MessageOptions.prototype.deprecatedLegacyJsonFieldConflicts = false;
    
                /**
                 * MessageOptions features.
                 * @member {google.protobuf.IFeatureSet|null|undefined} features
                 * @memberof google.protobuf.MessageOptions
                 * @instance
                 */
                MessageOptions.prototype.features = null;
    
                /**
                 * MessageOptions uninterpretedOption.
                 * @member {Array.<google.protobuf.IUninterpretedOption>} uninterpretedOption
                 * @memberof google.protobuf.MessageOptions
                 * @instance
                 */
                MessageOptions.prototype.uninterpretedOption = $util.emptyArray;
    
                /**
                 * MessageOptions .google.api.resource.
                 * @member {google.api.IResourceDescriptor|null|undefined} .google.api.resource
                 * @memberof google.protobuf.MessageOptions
                 * @instance
                 */
                MessageOptions.prototype[".google.api.resource"] = null;
    
                /**
                 * Creates a new MessageOptions instance using the specified properties.
                 * @function create
                 * @memberof google.protobuf.MessageOptions
                 * @static
                 * @param {google.protobuf.IMessageOptions=} [properties] Properties to set
                 * @returns {google.protobuf.MessageOptions} MessageOptions instance
                 */
                MessageOptions.create = function create(properties) {
                    return new MessageOptions(properties);
                };
    
                /**
                 * Encodes the specified MessageOptions message. Does not implicitly {@link google.protobuf.MessageOptions.verify|verify} messages.
                 * @function encode
                 * @memberof google.protobuf.MessageOptions
                 * @static
                 * @param {google.protobuf.IMessageOptions} message MessageOptions message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                MessageOptions.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.messageSetWireFormat != null && Object.hasOwnProperty.call(message, "messageSetWireFormat"))
                        writer.uint32(/* id 1, wireType 0 =*/8).bool(message.messageSetWireFormat);
                    if (message.noStandardDescriptorAccessor != null && Object.hasOwnProperty.call(message, "noStandardDescriptorAccessor"))
                        writer.uint32(/* id 2, wireType 0 =*/16).bool(message.noStandardDescriptorAccessor);
                    if (message.deprecated != null && Object.hasOwnProperty.call(message, "deprecated"))
                        writer.uint32(/* id 3, wireType 0 =*/24).bool(message.deprecated);
                    if (message.mapEntry != null && Object.hasOwnProperty.call(message, "mapEntry"))
                        writer.uint32(/* id 7, wireType 0 =*/56).bool(message.mapEntry);
                    if (message.deprecatedLegacyJsonFieldConflicts != null && Object.hasOwnProperty.call(message, "deprecatedLegacyJsonFieldConflicts"))
                        writer.uint32(/* id 11, wireType 0 =*/88).bool(message.deprecatedLegacyJsonFieldConflicts);
                    if (message.features != null && Object.hasOwnProperty.call(message, "features"))
                        $root.google.protobuf.FeatureSet.encode(message.features, writer.uint32(/* id 12, wireType 2 =*/98).fork()).ldelim();
                    if (message.uninterpretedOption != null && message.uninterpretedOption.length)
                        for (var i = 0; i < message.uninterpretedOption.length; ++i)
                            $root.google.protobuf.UninterpretedOption.encode(message.uninterpretedOption[i], writer.uint32(/* id 999, wireType 2 =*/7994).fork()).ldelim();
                    if (message[".google.api.resource"] != null && Object.hasOwnProperty.call(message, ".google.api.resource"))
                        $root.google.api.ResourceDescriptor.encode(message[".google.api.resource"], writer.uint32(/* id 1053, wireType 2 =*/8426).fork()).ldelim();
                    return writer;
                };
    
                /**
                 * Encodes the specified MessageOptions message, length delimited. Does not implicitly {@link google.protobuf.MessageOptions.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.protobuf.MessageOptions
                 * @static
                 * @param {google.protobuf.IMessageOptions} message MessageOptions message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                MessageOptions.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes a MessageOptions message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.protobuf.MessageOptions
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.protobuf.MessageOptions} MessageOptions
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                MessageOptions.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.protobuf.MessageOptions();
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 1: {
                                message.messageSetWireFormat = reader.bool();
                                break;
                            }
                        case 2: {
                                message.noStandardDescriptorAccessor = reader.bool();
                                break;
                            }
                        case 3: {
                                message.deprecated = reader.bool();
                                break;
                            }
                        case 7: {
                                message.mapEntry = reader.bool();
                                break;
                            }
                        case 11: {
                                message.deprecatedLegacyJsonFieldConflicts = reader.bool();
                                break;
                            }
                        case 12: {
                                message.features = $root.google.protobuf.FeatureSet.decode(reader, reader.uint32());
                                break;
                            }
                        case 999: {
                                if (!(message.uninterpretedOption && message.uninterpretedOption.length))
                                    message.uninterpretedOption = [];
                                message.uninterpretedOption.push($root.google.protobuf.UninterpretedOption.decode(reader, reader.uint32()));
                                break;
                            }
                        case 1053: {
                                message[".google.api.resource"] = $root.google.api.ResourceDescriptor.decode(reader, reader.uint32());
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes a MessageOptions message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.protobuf.MessageOptions
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.protobuf.MessageOptions} MessageOptions
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                MessageOptions.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies a MessageOptions message.
                 * @function verify
                 * @memberof google.protobuf.MessageOptions
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                MessageOptions.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    if (message.messageSetWireFormat != null && message.hasOwnProperty("messageSetWireFormat"))
                        if (typeof message.messageSetWireFormat !== "boolean")
                            return "messageSetWireFormat: boolean expected";
                    if (message.noStandardDescriptorAccessor != null && message.hasOwnProperty("noStandardDescriptorAccessor"))
                        if (typeof message.noStandardDescriptorAccessor !== "boolean")
                            return "noStandardDescriptorAccessor: boolean expected";
                    if (message.deprecated != null && message.hasOwnProperty("deprecated"))
                        if (typeof message.deprecated !== "boolean")
                            return "deprecated: boolean expected";
                    if (message.mapEntry != null && message.hasOwnProperty("mapEntry"))
                        if (typeof message.mapEntry !== "boolean")
                            return "mapEntry: boolean expected";
                    if (message.deprecatedLegacyJsonFieldConflicts != null && message.hasOwnProperty("deprecatedLegacyJsonFieldConflicts"))
                        if (typeof message.deprecatedLegacyJsonFieldConflicts !== "boolean")
                            return "deprecatedLegacyJsonFieldConflicts: boolean expected";
                    if (message.features != null && message.hasOwnProperty("features")) {
                        var error = $root.google.protobuf.FeatureSet.verify(message.features);
                        if (error)
                            return "features." + error;
                    }
                    if (message.uninterpretedOption != null && message.hasOwnProperty("uninterpretedOption")) {
                        if (!Array.isArray(message.uninterpretedOption))
                            return "uninterpretedOption: array expected";
                        for (var i = 0; i < message.uninterpretedOption.length; ++i) {
                            var error = $root.google.protobuf.UninterpretedOption.verify(message.uninterpretedOption[i]);
                            if (error)
                                return "uninterpretedOption." + error;
                        }
                    }
                    if (message[".google.api.resource"] != null && message.hasOwnProperty(".google.api.resource")) {
                        var error = $root.google.api.ResourceDescriptor.verify(message[".google.api.resource"]);
                        if (error)
                            return ".google.api.resource." + error;
                    }
                    return null;
                };
    
                /**
                 * Creates a MessageOptions message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.protobuf.MessageOptions
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.protobuf.MessageOptions} MessageOptions
                 */
                MessageOptions.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.protobuf.MessageOptions)
                        return object;
                    var message = new $root.google.protobuf.MessageOptions();
                    if (object.messageSetWireFormat != null)
                        message.messageSetWireFormat = Boolean(object.messageSetWireFormat);
                    if (object.noStandardDescriptorAccessor != null)
                        message.noStandardDescriptorAccessor = Boolean(object.noStandardDescriptorAccessor);
                    if (object.deprecated != null)
                        message.deprecated = Boolean(object.deprecated);
                    if (object.mapEntry != null)
                        message.mapEntry = Boolean(object.mapEntry);
                    if (object.deprecatedLegacyJsonFieldConflicts != null)
                        message.deprecatedLegacyJsonFieldConflicts = Boolean(object.deprecatedLegacyJsonFieldConflicts);
                    if (object.features != null) {
                        if (typeof object.features !== "object")
                            throw TypeError(".google.protobuf.MessageOptions.features: object expected");
                        message.features = $root.google.protobuf.FeatureSet.fromObject(object.features);
                    }
                    if (object.uninterpretedOption) {
                        if (!Array.isArray(object.uninterpretedOption))
                            throw TypeError(".google.protobuf.MessageOptions.uninterpretedOption: array expected");
                        message.uninterpretedOption = [];
                        for (var i = 0; i < object.uninterpretedOption.length; ++i) {
                            if (typeof object.uninterpretedOption[i] !== "object")
                                throw TypeError(".google.protobuf.MessageOptions.uninterpretedOption: object expected");
                            message.uninterpretedOption[i] = $root.google.protobuf.UninterpretedOption.fromObject(object.uninterpretedOption[i]);
                        }
                    }
                    if (object[".google.api.resource"] != null) {
                        if (typeof object[".google.api.resource"] !== "object")
                            throw TypeError(".google.protobuf.MessageOptions..google.api.resource: object expected");
                        message[".google.api.resource"] = $root.google.api.ResourceDescriptor.fromObject(object[".google.api.resource"]);
                    }
                    return message;
                };
    
                /**
                 * Creates a plain object from a MessageOptions message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.protobuf.MessageOptions
                 * @static
                 * @param {google.protobuf.MessageOptions} message MessageOptions
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                MessageOptions.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (options.arrays || options.defaults)
                        object.uninterpretedOption = [];
                    if (options.defaults) {
                        object.messageSetWireFormat = false;
                        object.noStandardDescriptorAccessor = false;
                        object.deprecated = false;
                        object.mapEntry = false;
                        object.deprecatedLegacyJsonFieldConflicts = false;
                        object.features = null;
                        object[".google.api.resource"] = null;
                    }
                    if (message.messageSetWireFormat != null && message.hasOwnProperty("messageSetWireFormat"))
                        object.messageSetWireFormat = message.messageSetWireFormat;
                    if (message.noStandardDescriptorAccessor != null && message.hasOwnProperty("noStandardDescriptorAccessor"))
                        object.noStandardDescriptorAccessor = message.noStandardDescriptorAccessor;
                    if (message.deprecated != null && message.hasOwnProperty("deprecated"))
                        object.deprecated = message.deprecated;
                    if (message.mapEntry != null && message.hasOwnProperty("mapEntry"))
                        object.mapEntry = message.mapEntry;
                    if (message.deprecatedLegacyJsonFieldConflicts != null && message.hasOwnProperty("deprecatedLegacyJsonFieldConflicts"))
                        object.deprecatedLegacyJsonFieldConflicts = message.deprecatedLegacyJsonFieldConflicts;
                    if (message.features != null && message.hasOwnProperty("features"))
                        object.features = $root.google.protobuf.FeatureSet.toObject(message.features, options);
                    if (message.uninterpretedOption && message.uninterpretedOption.length) {
                        object.uninterpretedOption = [];
                        for (var j = 0; j < message.uninterpretedOption.length; ++j)
                            object.uninterpretedOption[j] = $root.google.protobuf.UninterpretedOption.toObject(message.uninterpretedOption[j], options);
                    }
                    if (message[".google.api.resource"] != null && message.hasOwnProperty(".google.api.resource"))
                        object[".google.api.resource"] = $root.google.api.ResourceDescriptor.toObject(message[".google.api.resource"], options);
                    return object;
                };
    
                /**
                 * Converts this MessageOptions to JSON.
                 * @function toJSON
                 * @memberof google.protobuf.MessageOptions
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                MessageOptions.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for MessageOptions
                 * @function getTypeUrl
                 * @memberof google.protobuf.MessageOptions
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                MessageOptions.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.protobuf.MessageOptions";
                };
    
                return MessageOptions;
            })();
    
            protobuf.FieldOptions = (function() {
    
                /**
                 * Properties of a FieldOptions.
                 * @memberof google.protobuf
                 * @interface IFieldOptions
                 * @property {google.protobuf.FieldOptions.CType|null} [ctype] FieldOptions ctype
                 * @property {boolean|null} [packed] FieldOptions packed
                 * @property {google.protobuf.FieldOptions.JSType|null} [jstype] FieldOptions jstype
                 * @property {boolean|null} [lazy] FieldOptions lazy
                 * @property {boolean|null} [unverifiedLazy] FieldOptions unverifiedLazy
                 * @property {boolean|null} [deprecated] FieldOptions deprecated
                 * @property {boolean|null} [weak] FieldOptions weak
                 * @property {boolean|null} [debugRedact] FieldOptions debugRedact
                 * @property {google.protobuf.FieldOptions.OptionRetention|null} [retention] FieldOptions retention
                 * @property {Array.<google.protobuf.FieldOptions.OptionTargetType>|null} [targets] FieldOptions targets
                 * @property {Array.<google.protobuf.FieldOptions.IEditionDefault>|null} [editionDefaults] FieldOptions editionDefaults
                 * @property {google.protobuf.IFeatureSet|null} [features] FieldOptions features
                 * @property {Array.<google.protobuf.IUninterpretedOption>|null} [uninterpretedOption] FieldOptions uninterpretedOption
                 * @property {Array.<google.api.FieldBehavior>|null} [".google.api.fieldBehavior"] FieldOptions .google.api.fieldBehavior
                 * @property {google.api.IResourceReference|null} [".google.api.resourceReference"] FieldOptions .google.api.resourceReference
                 */
    
                /**
                 * Constructs a new FieldOptions.
                 * @memberof google.protobuf
                 * @classdesc Represents a FieldOptions.
                 * @implements IFieldOptions
                 * @constructor
                 * @param {google.protobuf.IFieldOptions=} [properties] Properties to set
                 */
                function FieldOptions(properties) {
                    this.targets = [];
                    this.editionDefaults = [];
                    this.uninterpretedOption = [];
                    this[".google.api.fieldBehavior"] = [];
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * FieldOptions ctype.
                 * @member {google.protobuf.FieldOptions.CType} ctype
                 * @memberof google.protobuf.FieldOptions
                 * @instance
                 */
                FieldOptions.prototype.ctype = 0;
    
                /**
                 * FieldOptions packed.
                 * @member {boolean} packed
                 * @memberof google.protobuf.FieldOptions
                 * @instance
                 */
                FieldOptions.prototype.packed = false;
    
                /**
                 * FieldOptions jstype.
                 * @member {google.protobuf.FieldOptions.JSType} jstype
                 * @memberof google.protobuf.FieldOptions
                 * @instance
                 */
                FieldOptions.prototype.jstype = 0;
    
                /**
                 * FieldOptions lazy.
                 * @member {boolean} lazy
                 * @memberof google.protobuf.FieldOptions
                 * @instance
                 */
                FieldOptions.prototype.lazy = false;
    
                /**
                 * FieldOptions unverifiedLazy.
                 * @member {boolean} unverifiedLazy
                 * @memberof google.protobuf.FieldOptions
                 * @instance
                 */
                FieldOptions.prototype.unverifiedLazy = false;
    
                /**
                 * FieldOptions deprecated.
                 * @member {boolean} deprecated
                 * @memberof google.protobuf.FieldOptions
                 * @instance
                 */
                FieldOptions.prototype.deprecated = false;
    
                /**
                 * FieldOptions weak.
                 * @member {boolean} weak
                 * @memberof google.protobuf.FieldOptions
                 * @instance
                 */
                FieldOptions.prototype.weak = false;
    
                /**
                 * FieldOptions debugRedact.
                 * @member {boolean} debugRedact
                 * @memberof google.protobuf.FieldOptions
                 * @instance
                 */
                FieldOptions.prototype.debugRedact = false;
    
                /**
                 * FieldOptions retention.
                 * @member {google.protobuf.FieldOptions.OptionRetention} retention
                 * @memberof google.protobuf.FieldOptions
                 * @instance
                 */
                FieldOptions.prototype.retention = 0;
    
                /**
                 * FieldOptions targets.
                 * @member {Array.<google.protobuf.FieldOptions.OptionTargetType>} targets
                 * @memberof google.protobuf.FieldOptions
                 * @instance
                 */
                FieldOptions.prototype.targets = $util.emptyArray;
    
                /**
                 * FieldOptions editionDefaults.
                 * @member {Array.<google.protobuf.FieldOptions.IEditionDefault>} editionDefaults
                 * @memberof google.protobuf.FieldOptions
                 * @instance
                 */
                FieldOptions.prototype.editionDefaults = $util.emptyArray;
    
                /**
                 * FieldOptions features.
                 * @member {google.protobuf.IFeatureSet|null|undefined} features
                 * @memberof google.protobuf.FieldOptions
                 * @instance
                 */
                FieldOptions.prototype.features = null;
    
                /**
                 * FieldOptions uninterpretedOption.
                 * @member {Array.<google.protobuf.IUninterpretedOption>} uninterpretedOption
                 * @memberof google.protobuf.FieldOptions
                 * @instance
                 */
                FieldOptions.prototype.uninterpretedOption = $util.emptyArray;
    
                /**
                 * FieldOptions .google.api.fieldBehavior.
                 * @member {Array.<google.api.FieldBehavior>} .google.api.fieldBehavior
                 * @memberof google.protobuf.FieldOptions
                 * @instance
                 */
                FieldOptions.prototype[".google.api.fieldBehavior"] = $util.emptyArray;
    
                /**
                 * FieldOptions .google.api.resourceReference.
                 * @member {google.api.IResourceReference|null|undefined} .google.api.resourceReference
                 * @memberof google.protobuf.FieldOptions
                 * @instance
                 */
                FieldOptions.prototype[".google.api.resourceReference"] = null;
    
                /**
                 * Creates a new FieldOptions instance using the specified properties.
                 * @function create
                 * @memberof google.protobuf.FieldOptions
                 * @static
                 * @param {google.protobuf.IFieldOptions=} [properties] Properties to set
                 * @returns {google.protobuf.FieldOptions} FieldOptions instance
                 */
                FieldOptions.create = function create(properties) {
                    return new FieldOptions(properties);
                };
    
                /**
                 * Encodes the specified FieldOptions message. Does not implicitly {@link google.protobuf.FieldOptions.verify|verify} messages.
                 * @function encode
                 * @memberof google.protobuf.FieldOptions
                 * @static
                 * @param {google.protobuf.IFieldOptions} message FieldOptions message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                FieldOptions.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.ctype != null && Object.hasOwnProperty.call(message, "ctype"))
                        writer.uint32(/* id 1, wireType 0 =*/8).int32(message.ctype);
                    if (message.packed != null && Object.hasOwnProperty.call(message, "packed"))
                        writer.uint32(/* id 2, wireType 0 =*/16).bool(message.packed);
                    if (message.deprecated != null && Object.hasOwnProperty.call(message, "deprecated"))
                        writer.uint32(/* id 3, wireType 0 =*/24).bool(message.deprecated);
                    if (message.lazy != null && Object.hasOwnProperty.call(message, "lazy"))
                        writer.uint32(/* id 5, wireType 0 =*/40).bool(message.lazy);
                    if (message.jstype != null && Object.hasOwnProperty.call(message, "jstype"))
                        writer.uint32(/* id 6, wireType 0 =*/48).int32(message.jstype);
                    if (message.weak != null && Object.hasOwnProperty.call(message, "weak"))
                        writer.uint32(/* id 10, wireType 0 =*/80).bool(message.weak);
                    if (message.unverifiedLazy != null && Object.hasOwnProperty.call(message, "unverifiedLazy"))
                        writer.uint32(/* id 15, wireType 0 =*/120).bool(message.unverifiedLazy);
                    if (message.debugRedact != null && Object.hasOwnProperty.call(message, "debugRedact"))
                        writer.uint32(/* id 16, wireType 0 =*/128).bool(message.debugRedact);
                    if (message.retention != null && Object.hasOwnProperty.call(message, "retention"))
                        writer.uint32(/* id 17, wireType 0 =*/136).int32(message.retention);
                    if (message.targets != null && message.targets.length)
                        for (var i = 0; i < message.targets.length; ++i)
                            writer.uint32(/* id 19, wireType 0 =*/152).int32(message.targets[i]);
                    if (message.editionDefaults != null && message.editionDefaults.length)
                        for (var i = 0; i < message.editionDefaults.length; ++i)
                            $root.google.protobuf.FieldOptions.EditionDefault.encode(message.editionDefaults[i], writer.uint32(/* id 20, wireType 2 =*/162).fork()).ldelim();
                    if (message.features != null && Object.hasOwnProperty.call(message, "features"))
                        $root.google.protobuf.FeatureSet.encode(message.features, writer.uint32(/* id 21, wireType 2 =*/170).fork()).ldelim();
                    if (message.uninterpretedOption != null && message.uninterpretedOption.length)
                        for (var i = 0; i < message.uninterpretedOption.length; ++i)
                            $root.google.protobuf.UninterpretedOption.encode(message.uninterpretedOption[i], writer.uint32(/* id 999, wireType 2 =*/7994).fork()).ldelim();
                    if (message[".google.api.fieldBehavior"] != null && message[".google.api.fieldBehavior"].length) {
                        writer.uint32(/* id 1052, wireType 2 =*/8418).fork();
                        for (var i = 0; i < message[".google.api.fieldBehavior"].length; ++i)
                            writer.int32(message[".google.api.fieldBehavior"][i]);
                        writer.ldelim();
                    }
                    if (message[".google.api.resourceReference"] != null && Object.hasOwnProperty.call(message, ".google.api.resourceReference"))
                        $root.google.api.ResourceReference.encode(message[".google.api.resourceReference"], writer.uint32(/* id 1055, wireType 2 =*/8442).fork()).ldelim();
                    return writer;
                };
    
                /**
                 * Encodes the specified FieldOptions message, length delimited. Does not implicitly {@link google.protobuf.FieldOptions.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.protobuf.FieldOptions
                 * @static
                 * @param {google.protobuf.IFieldOptions} message FieldOptions message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                FieldOptions.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes a FieldOptions message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.protobuf.FieldOptions
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.protobuf.FieldOptions} FieldOptions
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                FieldOptions.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.protobuf.FieldOptions();
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 1: {
                                message.ctype = reader.int32();
                                break;
                            }
                        case 2: {
                                message.packed = reader.bool();
                                break;
                            }
                        case 6: {
                                message.jstype = reader.int32();
                                break;
                            }
                        case 5: {
                                message.lazy = reader.bool();
                                break;
                            }
                        case 15: {
                                message.unverifiedLazy = reader.bool();
                                break;
                            }
                        case 3: {
                                message.deprecated = reader.bool();
                                break;
                            }
                        case 10: {
                                message.weak = reader.bool();
                                break;
                            }
                        case 16: {
                                message.debugRedact = reader.bool();
                                break;
                            }
                        case 17: {
                                message.retention = reader.int32();
                                break;
                            }
                        case 19: {
                                if (!(message.targets && message.targets.length))
                                    message.targets = [];
                                if ((tag & 7) === 2) {
                                    var end2 = reader.uint32() + reader.pos;
                                    while (reader.pos < end2)
                                        message.targets.push(reader.int32());
                                } else
                                    message.targets.push(reader.int32());
                                break;
                            }
                        case 20: {
                                if (!(message.editionDefaults && message.editionDefaults.length))
                                    message.editionDefaults = [];
                                message.editionDefaults.push($root.google.protobuf.FieldOptions.EditionDefault.decode(reader, reader.uint32()));
                                break;
                            }
                        case 21: {
                                message.features = $root.google.protobuf.FeatureSet.decode(reader, reader.uint32());
                                break;
                            }
                        case 999: {
                                if (!(message.uninterpretedOption && message.uninterpretedOption.length))
                                    message.uninterpretedOption = [];
                                message.uninterpretedOption.push($root.google.protobuf.UninterpretedOption.decode(reader, reader.uint32()));
                                break;
                            }
                        case 1052: {
                                if (!(message[".google.api.fieldBehavior"] && message[".google.api.fieldBehavior"].length))
                                    message[".google.api.fieldBehavior"] = [];
                                if ((tag & 7) === 2) {
                                    var end2 = reader.uint32() + reader.pos;
                                    while (reader.pos < end2)
                                        message[".google.api.fieldBehavior"].push(reader.int32());
                                } else
                                    message[".google.api.fieldBehavior"].push(reader.int32());
                                break;
                            }
                        case 1055: {
                                message[".google.api.resourceReference"] = $root.google.api.ResourceReference.decode(reader, reader.uint32());
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes a FieldOptions message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.protobuf.FieldOptions
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.protobuf.FieldOptions} FieldOptions
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                FieldOptions.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies a FieldOptions message.
                 * @function verify
                 * @memberof google.protobuf.FieldOptions
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                FieldOptions.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    if (message.ctype != null && message.hasOwnProperty("ctype"))
                        switch (message.ctype) {
                        default:
                            return "ctype: enum value expected";
                        case 0:
                        case 1:
                        case 2:
                            break;
                        }
                    if (message.packed != null && message.hasOwnProperty("packed"))
                        if (typeof message.packed !== "boolean")
                            return "packed: boolean expected";
                    if (message.jstype != null && message.hasOwnProperty("jstype"))
                        switch (message.jstype) {
                        default:
                            return "jstype: enum value expected";
                        case 0:
                        case 1:
                        case 2:
                            break;
                        }
                    if (message.lazy != null && message.hasOwnProperty("lazy"))
                        if (typeof message.lazy !== "boolean")
                            return "lazy: boolean expected";
                    if (message.unverifiedLazy != null && message.hasOwnProperty("unverifiedLazy"))
                        if (typeof message.unverifiedLazy !== "boolean")
                            return "unverifiedLazy: boolean expected";
                    if (message.deprecated != null && message.hasOwnProperty("deprecated"))
                        if (typeof message.deprecated !== "boolean")
                            return "deprecated: boolean expected";
                    if (message.weak != null && message.hasOwnProperty("weak"))
                        if (typeof message.weak !== "boolean")
                            return "weak: boolean expected";
                    if (message.debugRedact != null && message.hasOwnProperty("debugRedact"))
                        if (typeof message.debugRedact !== "boolean")
                            return "debugRedact: boolean expected";
                    if (message.retention != null && message.hasOwnProperty("retention"))
                        switch (message.retention) {
                        default:
                            return "retention: enum value expected";
                        case 0:
                        case 1:
                        case 2:
                            break;
                        }
                    if (message.targets != null && message.hasOwnProperty("targets")) {
                        if (!Array.isArray(message.targets))
                            return "targets: array expected";
                        for (var i = 0; i < message.targets.length; ++i)
                            switch (message.targets[i]) {
                            default:
                                return "targets: enum value[] expected";
                            case 0:
                            case 1:
                            case 2:
                            case 3:
                            case 4:
                            case 5:
                            case 6:
                            case 7:
                            case 8:
                            case 9:
                                break;
                            }
                    }
                    if (message.editionDefaults != null && message.hasOwnProperty("editionDefaults")) {
                        if (!Array.isArray(message.editionDefaults))
                            return "editionDefaults: array expected";
                        for (var i = 0; i < message.editionDefaults.length; ++i) {
                            var error = $root.google.protobuf.FieldOptions.EditionDefault.verify(message.editionDefaults[i]);
                            if (error)
                                return "editionDefaults." + error;
                        }
                    }
                    if (message.features != null && message.hasOwnProperty("features")) {
                        var error = $root.google.protobuf.FeatureSet.verify(message.features);
                        if (error)
                            return "features." + error;
                    }
                    if (message.uninterpretedOption != null && message.hasOwnProperty("uninterpretedOption")) {
                        if (!Array.isArray(message.uninterpretedOption))
                            return "uninterpretedOption: array expected";
                        for (var i = 0; i < message.uninterpretedOption.length; ++i) {
                            var error = $root.google.protobuf.UninterpretedOption.verify(message.uninterpretedOption[i]);
                            if (error)
                                return "uninterpretedOption." + error;
                        }
                    }
                    if (message[".google.api.fieldBehavior"] != null && message.hasOwnProperty(".google.api.fieldBehavior")) {
                        if (!Array.isArray(message[".google.api.fieldBehavior"]))
                            return ".google.api.fieldBehavior: array expected";
                        for (var i = 0; i < message[".google.api.fieldBehavior"].length; ++i)
                            switch (message[".google.api.fieldBehavior"][i]) {
                            default:
                                return ".google.api.fieldBehavior: enum value[] expected";
                            case 0:
                            case 1:
                            case 2:
                            case 3:
                            case 4:
                            case 5:
                            case 6:
                            case 7:
                            case 8:
                                break;
                            }
                    }
                    if (message[".google.api.resourceReference"] != null && message.hasOwnProperty(".google.api.resourceReference")) {
                        var error = $root.google.api.ResourceReference.verify(message[".google.api.resourceReference"]);
                        if (error)
                            return ".google.api.resourceReference." + error;
                    }
                    return null;
                };
    
                /**
                 * Creates a FieldOptions message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.protobuf.FieldOptions
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.protobuf.FieldOptions} FieldOptions
                 */
                FieldOptions.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.protobuf.FieldOptions)
                        return object;
                    var message = new $root.google.protobuf.FieldOptions();
                    switch (object.ctype) {
                    default:
                        if (typeof object.ctype === "number") {
                            message.ctype = object.ctype;
                            break;
                        }
                        break;
                    case "STRING":
                    case 0:
                        message.ctype = 0;
                        break;
                    case "CORD":
                    case 1:
                        message.ctype = 1;
                        break;
                    case "STRING_PIECE":
                    case 2:
                        message.ctype = 2;
                        break;
                    }
                    if (object.packed != null)
                        message.packed = Boolean(object.packed);
                    switch (object.jstype) {
                    default:
                        if (typeof object.jstype === "number") {
                            message.jstype = object.jstype;
                            break;
                        }
                        break;
                    case "JS_NORMAL":
                    case 0:
                        message.jstype = 0;
                        break;
                    case "JS_STRING":
                    case 1:
                        message.jstype = 1;
                        break;
                    case "JS_NUMBER":
                    case 2:
                        message.jstype = 2;
                        break;
                    }
                    if (object.lazy != null)
                        message.lazy = Boolean(object.lazy);
                    if (object.unverifiedLazy != null)
                        message.unverifiedLazy = Boolean(object.unverifiedLazy);
                    if (object.deprecated != null)
                        message.deprecated = Boolean(object.deprecated);
                    if (object.weak != null)
                        message.weak = Boolean(object.weak);
                    if (object.debugRedact != null)
                        message.debugRedact = Boolean(object.debugRedact);
                    switch (object.retention) {
                    default:
                        if (typeof object.retention === "number") {
                            message.retention = object.retention;
                            break;
                        }
                        break;
                    case "RETENTION_UNKNOWN":
                    case 0:
                        message.retention = 0;
                        break;
                    case "RETENTION_RUNTIME":
                    case 1:
                        message.retention = 1;
                        break;
                    case "RETENTION_SOURCE":
                    case 2:
                        message.retention = 2;
                        break;
                    }
                    if (object.targets) {
                        if (!Array.isArray(object.targets))
                            throw TypeError(".google.protobuf.FieldOptions.targets: array expected");
                        message.targets = [];
                        for (var i = 0; i < object.targets.length; ++i)
                            switch (object.targets[i]) {
                            default:
                                if (typeof object.targets[i] === "number") {
                                    message.targets[i] = object.targets[i];
                                    break;
                                }
                            case "TARGET_TYPE_UNKNOWN":
                            case 0:
                                message.targets[i] = 0;
                                break;
                            case "TARGET_TYPE_FILE":
                            case 1:
                                message.targets[i] = 1;
                                break;
                            case "TARGET_TYPE_EXTENSION_RANGE":
                            case 2:
                                message.targets[i] = 2;
                                break;
                            case "TARGET_TYPE_MESSAGE":
                            case 3:
                                message.targets[i] = 3;
                                break;
                            case "TARGET_TYPE_FIELD":
                            case 4:
                                message.targets[i] = 4;
                                break;
                            case "TARGET_TYPE_ONEOF":
                            case 5:
                                message.targets[i] = 5;
                                break;
                            case "TARGET_TYPE_ENUM":
                            case 6:
                                message.targets[i] = 6;
                                break;
                            case "TARGET_TYPE_ENUM_ENTRY":
                            case 7:
                                message.targets[i] = 7;
                                break;
                            case "TARGET_TYPE_SERVICE":
                            case 8:
                                message.targets[i] = 8;
                                break;
                            case "TARGET_TYPE_METHOD":
                            case 9:
                                message.targets[i] = 9;
                                break;
                            }
                    }
                    if (object.editionDefaults) {
                        if (!Array.isArray(object.editionDefaults))
                            throw TypeError(".google.protobuf.FieldOptions.editionDefaults: array expected");
                        message.editionDefaults = [];
                        for (var i = 0; i < object.editionDefaults.length; ++i) {
                            if (typeof object.editionDefaults[i] !== "object")
                                throw TypeError(".google.protobuf.FieldOptions.editionDefaults: object expected");
                            message.editionDefaults[i] = $root.google.protobuf.FieldOptions.EditionDefault.fromObject(object.editionDefaults[i]);
                        }
                    }
                    if (object.features != null) {
                        if (typeof object.features !== "object")
                            throw TypeError(".google.protobuf.FieldOptions.features: object expected");
                        message.features = $root.google.protobuf.FeatureSet.fromObject(object.features);
                    }
                    if (object.uninterpretedOption) {
                        if (!Array.isArray(object.uninterpretedOption))
                            throw TypeError(".google.protobuf.FieldOptions.uninterpretedOption: array expected");
                        message.uninterpretedOption = [];
                        for (var i = 0; i < object.uninterpretedOption.length; ++i) {
                            if (typeof object.uninterpretedOption[i] !== "object")
                                throw TypeError(".google.protobuf.FieldOptions.uninterpretedOption: object expected");
                            message.uninterpretedOption[i] = $root.google.protobuf.UninterpretedOption.fromObject(object.uninterpretedOption[i]);
                        }
                    }
                    if (object[".google.api.fieldBehavior"]) {
                        if (!Array.isArray(object[".google.api.fieldBehavior"]))
                            throw TypeError(".google.protobuf.FieldOptions..google.api.fieldBehavior: array expected");
                        message[".google.api.fieldBehavior"] = [];
                        for (var i = 0; i < object[".google.api.fieldBehavior"].length; ++i)
                            switch (object[".google.api.fieldBehavior"][i]) {
                            default:
                                if (typeof object[".google.api.fieldBehavior"][i] === "number") {
                                    message[".google.api.fieldBehavior"][i] = object[".google.api.fieldBehavior"][i];
                                    break;
                                }
                            case "FIELD_BEHAVIOR_UNSPECIFIED":
                            case 0:
                                message[".google.api.fieldBehavior"][i] = 0;
                                break;
                            case "OPTIONAL":
                            case 1:
                                message[".google.api.fieldBehavior"][i] = 1;
                                break;
                            case "REQUIRED":
                            case 2:
                                message[".google.api.fieldBehavior"][i] = 2;
                                break;
                            case "OUTPUT_ONLY":
                            case 3:
                                message[".google.api.fieldBehavior"][i] = 3;
                                break;
                            case "INPUT_ONLY":
                            case 4:
                                message[".google.api.fieldBehavior"][i] = 4;
                                break;
                            case "IMMUTABLE":
                            case 5:
                                message[".google.api.fieldBehavior"][i] = 5;
                                break;
                            case "UNORDERED_LIST":
                            case 6:
                                message[".google.api.fieldBehavior"][i] = 6;
                                break;
                            case "NON_EMPTY_DEFAULT":
                            case 7:
                                message[".google.api.fieldBehavior"][i] = 7;
                                break;
                            case "IDENTIFIER":
                            case 8:
                                message[".google.api.fieldBehavior"][i] = 8;
                                break;
                            }
                    }
                    if (object[".google.api.resourceReference"] != null) {
                        if (typeof object[".google.api.resourceReference"] !== "object")
                            throw TypeError(".google.protobuf.FieldOptions..google.api.resourceReference: object expected");
                        message[".google.api.resourceReference"] = $root.google.api.ResourceReference.fromObject(object[".google.api.resourceReference"]);
                    }
                    return message;
                };
    
                /**
                 * Creates a plain object from a FieldOptions message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.protobuf.FieldOptions
                 * @static
                 * @param {google.protobuf.FieldOptions} message FieldOptions
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                FieldOptions.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (options.arrays || options.defaults) {
                        object.targets = [];
                        object.editionDefaults = [];
                        object.uninterpretedOption = [];
                        object[".google.api.fieldBehavior"] = [];
                    }
                    if (options.defaults) {
                        object.ctype = options.enums === String ? "STRING" : 0;
                        object.packed = false;
                        object.deprecated = false;
                        object.lazy = false;
                        object.jstype = options.enums === String ? "JS_NORMAL" : 0;
                        object.weak = false;
                        object.unverifiedLazy = false;
                        object.debugRedact = false;
                        object.retention = options.enums === String ? "RETENTION_UNKNOWN" : 0;
                        object.features = null;
                        object[".google.api.resourceReference"] = null;
                    }
                    if (message.ctype != null && message.hasOwnProperty("ctype"))
                        object.ctype = options.enums === String ? $root.google.protobuf.FieldOptions.CType[message.ctype] === undefined ? message.ctype : $root.google.protobuf.FieldOptions.CType[message.ctype] : message.ctype;
                    if (message.packed != null && message.hasOwnProperty("packed"))
                        object.packed = message.packed;
                    if (message.deprecated != null && message.hasOwnProperty("deprecated"))
                        object.deprecated = message.deprecated;
                    if (message.lazy != null && message.hasOwnProperty("lazy"))
                        object.lazy = message.lazy;
                    if (message.jstype != null && message.hasOwnProperty("jstype"))
                        object.jstype = options.enums === String ? $root.google.protobuf.FieldOptions.JSType[message.jstype] === undefined ? message.jstype : $root.google.protobuf.FieldOptions.JSType[message.jstype] : message.jstype;
                    if (message.weak != null && message.hasOwnProperty("weak"))
                        object.weak = message.weak;
                    if (message.unverifiedLazy != null && message.hasOwnProperty("unverifiedLazy"))
                        object.unverifiedLazy = message.unverifiedLazy;
                    if (message.debugRedact != null && message.hasOwnProperty("debugRedact"))
                        object.debugRedact = message.debugRedact;
                    if (message.retention != null && message.hasOwnProperty("retention"))
                        object.retention = options.enums === String ? $root.google.protobuf.FieldOptions.OptionRetention[message.retention] === undefined ? message.retention : $root.google.protobuf.FieldOptions.OptionRetention[message.retention] : message.retention;
                    if (message.targets && message.targets.length) {
                        object.targets = [];
                        for (var j = 0; j < message.targets.length; ++j)
                            object.targets[j] = options.enums === String ? $root.google.protobuf.FieldOptions.OptionTargetType[message.targets[j]] === undefined ? message.targets[j] : $root.google.protobuf.FieldOptions.OptionTargetType[message.targets[j]] : message.targets[j];
                    }
                    if (message.editionDefaults && message.editionDefaults.length) {
                        object.editionDefaults = [];
                        for (var j = 0; j < message.editionDefaults.length; ++j)
                            object.editionDefaults[j] = $root.google.protobuf.FieldOptions.EditionDefault.toObject(message.editionDefaults[j], options);
                    }
                    if (message.features != null && message.hasOwnProperty("features"))
                        object.features = $root.google.protobuf.FeatureSet.toObject(message.features, options);
                    if (message.uninterpretedOption && message.uninterpretedOption.length) {
                        object.uninterpretedOption = [];
                        for (var j = 0; j < message.uninterpretedOption.length; ++j)
                            object.uninterpretedOption[j] = $root.google.protobuf.UninterpretedOption.toObject(message.uninterpretedOption[j], options);
                    }
                    if (message[".google.api.fieldBehavior"] && message[".google.api.fieldBehavior"].length) {
                        object[".google.api.fieldBehavior"] = [];
                        for (var j = 0; j < message[".google.api.fieldBehavior"].length; ++j)
                            object[".google.api.fieldBehavior"][j] = options.enums === String ? $root.google.api.FieldBehavior[message[".google.api.fieldBehavior"][j]] === undefined ? message[".google.api.fieldBehavior"][j] : $root.google.api.FieldBehavior[message[".google.api.fieldBehavior"][j]] : message[".google.api.fieldBehavior"][j];
                    }
                    if (message[".google.api.resourceReference"] != null && message.hasOwnProperty(".google.api.resourceReference"))
                        object[".google.api.resourceReference"] = $root.google.api.ResourceReference.toObject(message[".google.api.resourceReference"], options);
                    return object;
                };
    
                /**
                 * Converts this FieldOptions to JSON.
                 * @function toJSON
                 * @memberof google.protobuf.FieldOptions
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                FieldOptions.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for FieldOptions
                 * @function getTypeUrl
                 * @memberof google.protobuf.FieldOptions
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                FieldOptions.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.protobuf.FieldOptions";
                };
    
                /**
                 * CType enum.
                 * @name google.protobuf.FieldOptions.CType
                 * @enum {number}
                 * @property {number} STRING=0 STRING value
                 * @property {number} CORD=1 CORD value
                 * @property {number} STRING_PIECE=2 STRING_PIECE value
                 */
                FieldOptions.CType = (function() {
                    var valuesById = {}, values = Object.create(valuesById);
                    values[valuesById[0] = "STRING"] = 0;
                    values[valuesById[1] = "CORD"] = 1;
                    values[valuesById[2] = "STRING_PIECE"] = 2;
                    return values;
                })();
    
                /**
                 * JSType enum.
                 * @name google.protobuf.FieldOptions.JSType
                 * @enum {number}
                 * @property {number} JS_NORMAL=0 JS_NORMAL value
                 * @property {number} JS_STRING=1 JS_STRING value
                 * @property {number} JS_NUMBER=2 JS_NUMBER value
                 */
                FieldOptions.JSType = (function() {
                    var valuesById = {}, values = Object.create(valuesById);
                    values[valuesById[0] = "JS_NORMAL"] = 0;
                    values[valuesById[1] = "JS_STRING"] = 1;
                    values[valuesById[2] = "JS_NUMBER"] = 2;
                    return values;
                })();
    
                /**
                 * OptionRetention enum.
                 * @name google.protobuf.FieldOptions.OptionRetention
                 * @enum {number}
                 * @property {number} RETENTION_UNKNOWN=0 RETENTION_UNKNOWN value
                 * @property {number} RETENTION_RUNTIME=1 RETENTION_RUNTIME value
                 * @property {number} RETENTION_SOURCE=2 RETENTION_SOURCE value
                 */
                FieldOptions.OptionRetention = (function() {
                    var valuesById = {}, values = Object.create(valuesById);
                    values[valuesById[0] = "RETENTION_UNKNOWN"] = 0;
                    values[valuesById[1] = "RETENTION_RUNTIME"] = 1;
                    values[valuesById[2] = "RETENTION_SOURCE"] = 2;
                    return values;
                })();
    
                /**
                 * OptionTargetType enum.
                 * @name google.protobuf.FieldOptions.OptionTargetType
                 * @enum {number}
                 * @property {number} TARGET_TYPE_UNKNOWN=0 TARGET_TYPE_UNKNOWN value
                 * @property {number} TARGET_TYPE_FILE=1 TARGET_TYPE_FILE value
                 * @property {number} TARGET_TYPE_EXTENSION_RANGE=2 TARGET_TYPE_EXTENSION_RANGE value
                 * @property {number} TARGET_TYPE_MESSAGE=3 TARGET_TYPE_MESSAGE value
                 * @property {number} TARGET_TYPE_FIELD=4 TARGET_TYPE_FIELD value
                 * @property {number} TARGET_TYPE_ONEOF=5 TARGET_TYPE_ONEOF value
                 * @property {number} TARGET_TYPE_ENUM=6 TARGET_TYPE_ENUM value
                 * @property {number} TARGET_TYPE_ENUM_ENTRY=7 TARGET_TYPE_ENUM_ENTRY value
                 * @property {number} TARGET_TYPE_SERVICE=8 TARGET_TYPE_SERVICE value
                 * @property {number} TARGET_TYPE_METHOD=9 TARGET_TYPE_METHOD value
                 */
                FieldOptions.OptionTargetType = (function() {
                    var valuesById = {}, values = Object.create(valuesById);
                    values[valuesById[0] = "TARGET_TYPE_UNKNOWN"] = 0;
                    values[valuesById[1] = "TARGET_TYPE_FILE"] = 1;
                    values[valuesById[2] = "TARGET_TYPE_EXTENSION_RANGE"] = 2;
                    values[valuesById[3] = "TARGET_TYPE_MESSAGE"] = 3;
                    values[valuesById[4] = "TARGET_TYPE_FIELD"] = 4;
                    values[valuesById[5] = "TARGET_TYPE_ONEOF"] = 5;
                    values[valuesById[6] = "TARGET_TYPE_ENUM"] = 6;
                    values[valuesById[7] = "TARGET_TYPE_ENUM_ENTRY"] = 7;
                    values[valuesById[8] = "TARGET_TYPE_SERVICE"] = 8;
                    values[valuesById[9] = "TARGET_TYPE_METHOD"] = 9;
                    return values;
                })();
    
                FieldOptions.EditionDefault = (function() {
    
                    /**
                     * Properties of an EditionDefault.
                     * @memberof google.protobuf.FieldOptions
                     * @interface IEditionDefault
                     * @property {google.protobuf.Edition|null} [edition] EditionDefault edition
                     * @property {string|null} [value] EditionDefault value
                     */
    
                    /**
                     * Constructs a new EditionDefault.
                     * @memberof google.protobuf.FieldOptions
                     * @classdesc Represents an EditionDefault.
                     * @implements IEditionDefault
                     * @constructor
                     * @param {google.protobuf.FieldOptions.IEditionDefault=} [properties] Properties to set
                     */
                    function EditionDefault(properties) {
                        if (properties)
                            for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                if (properties[keys[i]] != null)
                                    this[keys[i]] = properties[keys[i]];
                    }
    
                    /**
                     * EditionDefault edition.
                     * @member {google.protobuf.Edition} edition
                     * @memberof google.protobuf.FieldOptions.EditionDefault
                     * @instance
                     */
                    EditionDefault.prototype.edition = 0;
    
                    /**
                     * EditionDefault value.
                     * @member {string} value
                     * @memberof google.protobuf.FieldOptions.EditionDefault
                     * @instance
                     */
                    EditionDefault.prototype.value = "";
    
                    /**
                     * Creates a new EditionDefault instance using the specified properties.
                     * @function create
                     * @memberof google.protobuf.FieldOptions.EditionDefault
                     * @static
                     * @param {google.protobuf.FieldOptions.IEditionDefault=} [properties] Properties to set
                     * @returns {google.protobuf.FieldOptions.EditionDefault} EditionDefault instance
                     */
                    EditionDefault.create = function create(properties) {
                        return new EditionDefault(properties);
                    };
    
                    /**
                     * Encodes the specified EditionDefault message. Does not implicitly {@link google.protobuf.FieldOptions.EditionDefault.verify|verify} messages.
                     * @function encode
                     * @memberof google.protobuf.FieldOptions.EditionDefault
                     * @static
                     * @param {google.protobuf.FieldOptions.IEditionDefault} message EditionDefault message or plain object to encode
                     * @param {$protobuf.Writer} [writer] Writer to encode to
                     * @returns {$protobuf.Writer} Writer
                     */
                    EditionDefault.encode = function encode(message, writer) {
                        if (!writer)
                            writer = $Writer.create();
                        if (message.value != null && Object.hasOwnProperty.call(message, "value"))
                            writer.uint32(/* id 2, wireType 2 =*/18).string(message.value);
                        if (message.edition != null && Object.hasOwnProperty.call(message, "edition"))
                            writer.uint32(/* id 3, wireType 0 =*/24).int32(message.edition);
                        return writer;
                    };
    
                    /**
                     * Encodes the specified EditionDefault message, length delimited. Does not implicitly {@link google.protobuf.FieldOptions.EditionDefault.verify|verify} messages.
                     * @function encodeDelimited
                     * @memberof google.protobuf.FieldOptions.EditionDefault
                     * @static
                     * @param {google.protobuf.FieldOptions.IEditionDefault} message EditionDefault message or plain object to encode
                     * @param {$protobuf.Writer} [writer] Writer to encode to
                     * @returns {$protobuf.Writer} Writer
                     */
                    EditionDefault.encodeDelimited = function encodeDelimited(message, writer) {
                        return this.encode(message, writer).ldelim();
                    };
    
                    /**
                     * Decodes an EditionDefault message from the specified reader or buffer.
                     * @function decode
                     * @memberof google.protobuf.FieldOptions.EditionDefault
                     * @static
                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                     * @param {number} [length] Message length if known beforehand
                     * @returns {google.protobuf.FieldOptions.EditionDefault} EditionDefault
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    EditionDefault.decode = function decode(reader, length) {
                        if (!(reader instanceof $Reader))
                            reader = $Reader.create(reader);
                        var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.protobuf.FieldOptions.EditionDefault();
                        while (reader.pos < end) {
                            var tag = reader.uint32();
                            switch (tag >>> 3) {
                            case 3: {
                                    message.edition = reader.int32();
                                    break;
                                }
                            case 2: {
                                    message.value = reader.string();
                                    break;
                                }
                            default:
                                reader.skipType(tag & 7);
                                break;
                            }
                        }
                        return message;
                    };
    
                    /**
                     * Decodes an EditionDefault message from the specified reader or buffer, length delimited.
                     * @function decodeDelimited
                     * @memberof google.protobuf.FieldOptions.EditionDefault
                     * @static
                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                     * @returns {google.protobuf.FieldOptions.EditionDefault} EditionDefault
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    EditionDefault.decodeDelimited = function decodeDelimited(reader) {
                        if (!(reader instanceof $Reader))
                            reader = new $Reader(reader);
                        return this.decode(reader, reader.uint32());
                    };
    
                    /**
                     * Verifies an EditionDefault message.
                     * @function verify
                     * @memberof google.protobuf.FieldOptions.EditionDefault
                     * @static
                     * @param {Object.<string,*>} message Plain object to verify
                     * @returns {string|null} `null` if valid, otherwise the reason why it is not
                     */
                    EditionDefault.verify = function verify(message) {
                        if (typeof message !== "object" || message === null)
                            return "object expected";
                        if (message.edition != null && message.hasOwnProperty("edition"))
                            switch (message.edition) {
                            default:
                                return "edition: enum value expected";
                            case 0:
                            case 998:
                            case 999:
                            case 1000:
                            case 1001:
                            case 1:
                            case 2:
                            case 99997:
                            case 99998:
                            case 99999:
                            case 2147483647:
                                break;
                            }
                        if (message.value != null && message.hasOwnProperty("value"))
                            if (!$util.isString(message.value))
                                return "value: string expected";
                        return null;
                    };
    
                    /**
                     * Creates an EditionDefault message from a plain object. Also converts values to their respective internal types.
                     * @function fromObject
                     * @memberof google.protobuf.FieldOptions.EditionDefault
                     * @static
                     * @param {Object.<string,*>} object Plain object
                     * @returns {google.protobuf.FieldOptions.EditionDefault} EditionDefault
                     */
                    EditionDefault.fromObject = function fromObject(object) {
                        if (object instanceof $root.google.protobuf.FieldOptions.EditionDefault)
                            return object;
                        var message = new $root.google.protobuf.FieldOptions.EditionDefault();
                        switch (object.edition) {
                        default:
                            if (typeof object.edition === "number") {
                                message.edition = object.edition;
                                break;
                            }
                            break;
                        case "EDITION_UNKNOWN":
                        case 0:
                            message.edition = 0;
                            break;
                        case "EDITION_PROTO2":
                        case 998:
                            message.edition = 998;
                            break;
                        case "EDITION_PROTO3":
                        case 999:
                            message.edition = 999;
                            break;
                        case "EDITION_2023":
                        case 1000:
                            message.edition = 1000;
                            break;
                        case "EDITION_2024":
                        case 1001:
                            message.edition = 1001;
                            break;
                        case "EDITION_1_TEST_ONLY":
                        case 1:
                            message.edition = 1;
                            break;
                        case "EDITION_2_TEST_ONLY":
                        case 2:
                            message.edition = 2;
                            break;
                        case "EDITION_99997_TEST_ONLY":
                        case 99997:
                            message.edition = 99997;
                            break;
                        case "EDITION_99998_TEST_ONLY":
                        case 99998:
                            message.edition = 99998;
                            break;
                        case "EDITION_99999_TEST_ONLY":
                        case 99999:
                            message.edition = 99999;
                            break;
                        case "EDITION_MAX":
                        case 2147483647:
                            message.edition = 2147483647;
                            break;
                        }
                        if (object.value != null)
                            message.value = String(object.value);
                        return message;
                    };
    
                    /**
                     * Creates a plain object from an EditionDefault message. Also converts values to other types if specified.
                     * @function toObject
                     * @memberof google.protobuf.FieldOptions.EditionDefault
                     * @static
                     * @param {google.protobuf.FieldOptions.EditionDefault} message EditionDefault
                     * @param {$protobuf.IConversionOptions} [options] Conversion options
                     * @returns {Object.<string,*>} Plain object
                     */
                    EditionDefault.toObject = function toObject(message, options) {
                        if (!options)
                            options = {};
                        var object = {};
                        if (options.defaults) {
                            object.value = "";
                            object.edition = options.enums === String ? "EDITION_UNKNOWN" : 0;
                        }
                        if (message.value != null && message.hasOwnProperty("value"))
                            object.value = message.value;
                        if (message.edition != null && message.hasOwnProperty("edition"))
                            object.edition = options.enums === String ? $root.google.protobuf.Edition[message.edition] === undefined ? message.edition : $root.google.protobuf.Edition[message.edition] : message.edition;
                        return object;
                    };
    
                    /**
                     * Converts this EditionDefault to JSON.
                     * @function toJSON
                     * @memberof google.protobuf.FieldOptions.EditionDefault
                     * @instance
                     * @returns {Object.<string,*>} JSON object
                     */
                    EditionDefault.prototype.toJSON = function toJSON() {
                        return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                    };
    
                    /**
                     * Gets the default type url for EditionDefault
                     * @function getTypeUrl
                     * @memberof google.protobuf.FieldOptions.EditionDefault
                     * @static
                     * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns {string} The default type url
                     */
                    EditionDefault.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                        if (typeUrlPrefix === undefined) {
                            typeUrlPrefix = "type.googleapis.com";
                        }
                        return typeUrlPrefix + "/google.protobuf.FieldOptions.EditionDefault";
                    };
    
                    return EditionDefault;
                })();
    
                return FieldOptions;
            })();
    
            protobuf.OneofOptions = (function() {
    
                /**
                 * Properties of an OneofOptions.
                 * @memberof google.protobuf
                 * @interface IOneofOptions
                 * @property {google.protobuf.IFeatureSet|null} [features] OneofOptions features
                 * @property {Array.<google.protobuf.IUninterpretedOption>|null} [uninterpretedOption] OneofOptions uninterpretedOption
                 */
    
                /**
                 * Constructs a new OneofOptions.
                 * @memberof google.protobuf
                 * @classdesc Represents an OneofOptions.
                 * @implements IOneofOptions
                 * @constructor
                 * @param {google.protobuf.IOneofOptions=} [properties] Properties to set
                 */
                function OneofOptions(properties) {
                    this.uninterpretedOption = [];
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * OneofOptions features.
                 * @member {google.protobuf.IFeatureSet|null|undefined} features
                 * @memberof google.protobuf.OneofOptions
                 * @instance
                 */
                OneofOptions.prototype.features = null;
    
                /**
                 * OneofOptions uninterpretedOption.
                 * @member {Array.<google.protobuf.IUninterpretedOption>} uninterpretedOption
                 * @memberof google.protobuf.OneofOptions
                 * @instance
                 */
                OneofOptions.prototype.uninterpretedOption = $util.emptyArray;
    
                /**
                 * Creates a new OneofOptions instance using the specified properties.
                 * @function create
                 * @memberof google.protobuf.OneofOptions
                 * @static
                 * @param {google.protobuf.IOneofOptions=} [properties] Properties to set
                 * @returns {google.protobuf.OneofOptions} OneofOptions instance
                 */
                OneofOptions.create = function create(properties) {
                    return new OneofOptions(properties);
                };
    
                /**
                 * Encodes the specified OneofOptions message. Does not implicitly {@link google.protobuf.OneofOptions.verify|verify} messages.
                 * @function encode
                 * @memberof google.protobuf.OneofOptions
                 * @static
                 * @param {google.protobuf.IOneofOptions} message OneofOptions message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                OneofOptions.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.features != null && Object.hasOwnProperty.call(message, "features"))
                        $root.google.protobuf.FeatureSet.encode(message.features, writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                    if (message.uninterpretedOption != null && message.uninterpretedOption.length)
                        for (var i = 0; i < message.uninterpretedOption.length; ++i)
                            $root.google.protobuf.UninterpretedOption.encode(message.uninterpretedOption[i], writer.uint32(/* id 999, wireType 2 =*/7994).fork()).ldelim();
                    return writer;
                };
    
                /**
                 * Encodes the specified OneofOptions message, length delimited. Does not implicitly {@link google.protobuf.OneofOptions.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.protobuf.OneofOptions
                 * @static
                 * @param {google.protobuf.IOneofOptions} message OneofOptions message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                OneofOptions.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes an OneofOptions message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.protobuf.OneofOptions
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.protobuf.OneofOptions} OneofOptions
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                OneofOptions.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.protobuf.OneofOptions();
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 1: {
                                message.features = $root.google.protobuf.FeatureSet.decode(reader, reader.uint32());
                                break;
                            }
                        case 999: {
                                if (!(message.uninterpretedOption && message.uninterpretedOption.length))
                                    message.uninterpretedOption = [];
                                message.uninterpretedOption.push($root.google.protobuf.UninterpretedOption.decode(reader, reader.uint32()));
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes an OneofOptions message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.protobuf.OneofOptions
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.protobuf.OneofOptions} OneofOptions
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                OneofOptions.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies an OneofOptions message.
                 * @function verify
                 * @memberof google.protobuf.OneofOptions
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                OneofOptions.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    if (message.features != null && message.hasOwnProperty("features")) {
                        var error = $root.google.protobuf.FeatureSet.verify(message.features);
                        if (error)
                            return "features." + error;
                    }
                    if (message.uninterpretedOption != null && message.hasOwnProperty("uninterpretedOption")) {
                        if (!Array.isArray(message.uninterpretedOption))
                            return "uninterpretedOption: array expected";
                        for (var i = 0; i < message.uninterpretedOption.length; ++i) {
                            var error = $root.google.protobuf.UninterpretedOption.verify(message.uninterpretedOption[i]);
                            if (error)
                                return "uninterpretedOption." + error;
                        }
                    }
                    return null;
                };
    
                /**
                 * Creates an OneofOptions message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.protobuf.OneofOptions
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.protobuf.OneofOptions} OneofOptions
                 */
                OneofOptions.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.protobuf.OneofOptions)
                        return object;
                    var message = new $root.google.protobuf.OneofOptions();
                    if (object.features != null) {
                        if (typeof object.features !== "object")
                            throw TypeError(".google.protobuf.OneofOptions.features: object expected");
                        message.features = $root.google.protobuf.FeatureSet.fromObject(object.features);
                    }
                    if (object.uninterpretedOption) {
                        if (!Array.isArray(object.uninterpretedOption))
                            throw TypeError(".google.protobuf.OneofOptions.uninterpretedOption: array expected");
                        message.uninterpretedOption = [];
                        for (var i = 0; i < object.uninterpretedOption.length; ++i) {
                            if (typeof object.uninterpretedOption[i] !== "object")
                                throw TypeError(".google.protobuf.OneofOptions.uninterpretedOption: object expected");
                            message.uninterpretedOption[i] = $root.google.protobuf.UninterpretedOption.fromObject(object.uninterpretedOption[i]);
                        }
                    }
                    return message;
                };
    
                /**
                 * Creates a plain object from an OneofOptions message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.protobuf.OneofOptions
                 * @static
                 * @param {google.protobuf.OneofOptions} message OneofOptions
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                OneofOptions.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (options.arrays || options.defaults)
                        object.uninterpretedOption = [];
                    if (options.defaults)
                        object.features = null;
                    if (message.features != null && message.hasOwnProperty("features"))
                        object.features = $root.google.protobuf.FeatureSet.toObject(message.features, options);
                    if (message.uninterpretedOption && message.uninterpretedOption.length) {
                        object.uninterpretedOption = [];
                        for (var j = 0; j < message.uninterpretedOption.length; ++j)
                            object.uninterpretedOption[j] = $root.google.protobuf.UninterpretedOption.toObject(message.uninterpretedOption[j], options);
                    }
                    return object;
                };
    
                /**
                 * Converts this OneofOptions to JSON.
                 * @function toJSON
                 * @memberof google.protobuf.OneofOptions
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                OneofOptions.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for OneofOptions
                 * @function getTypeUrl
                 * @memberof google.protobuf.OneofOptions
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                OneofOptions.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.protobuf.OneofOptions";
                };
    
                return OneofOptions;
            })();
    
            protobuf.EnumOptions = (function() {
    
                /**
                 * Properties of an EnumOptions.
                 * @memberof google.protobuf
                 * @interface IEnumOptions
                 * @property {boolean|null} [allowAlias] EnumOptions allowAlias
                 * @property {boolean|null} [deprecated] EnumOptions deprecated
                 * @property {boolean|null} [deprecatedLegacyJsonFieldConflicts] EnumOptions deprecatedLegacyJsonFieldConflicts
                 * @property {google.protobuf.IFeatureSet|null} [features] EnumOptions features
                 * @property {Array.<google.protobuf.IUninterpretedOption>|null} [uninterpretedOption] EnumOptions uninterpretedOption
                 */
    
                /**
                 * Constructs a new EnumOptions.
                 * @memberof google.protobuf
                 * @classdesc Represents an EnumOptions.
                 * @implements IEnumOptions
                 * @constructor
                 * @param {google.protobuf.IEnumOptions=} [properties] Properties to set
                 */
                function EnumOptions(properties) {
                    this.uninterpretedOption = [];
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * EnumOptions allowAlias.
                 * @member {boolean} allowAlias
                 * @memberof google.protobuf.EnumOptions
                 * @instance
                 */
                EnumOptions.prototype.allowAlias = false;
    
                /**
                 * EnumOptions deprecated.
                 * @member {boolean} deprecated
                 * @memberof google.protobuf.EnumOptions
                 * @instance
                 */
                EnumOptions.prototype.deprecated = false;
    
                /**
                 * EnumOptions deprecatedLegacyJsonFieldConflicts.
                 * @member {boolean} deprecatedLegacyJsonFieldConflicts
                 * @memberof google.protobuf.EnumOptions
                 * @instance
                 */
                EnumOptions.prototype.deprecatedLegacyJsonFieldConflicts = false;
    
                /**
                 * EnumOptions features.
                 * @member {google.protobuf.IFeatureSet|null|undefined} features
                 * @memberof google.protobuf.EnumOptions
                 * @instance
                 */
                EnumOptions.prototype.features = null;
    
                /**
                 * EnumOptions uninterpretedOption.
                 * @member {Array.<google.protobuf.IUninterpretedOption>} uninterpretedOption
                 * @memberof google.protobuf.EnumOptions
                 * @instance
                 */
                EnumOptions.prototype.uninterpretedOption = $util.emptyArray;
    
                /**
                 * Creates a new EnumOptions instance using the specified properties.
                 * @function create
                 * @memberof google.protobuf.EnumOptions
                 * @static
                 * @param {google.protobuf.IEnumOptions=} [properties] Properties to set
                 * @returns {google.protobuf.EnumOptions} EnumOptions instance
                 */
                EnumOptions.create = function create(properties) {
                    return new EnumOptions(properties);
                };
    
                /**
                 * Encodes the specified EnumOptions message. Does not implicitly {@link google.protobuf.EnumOptions.verify|verify} messages.
                 * @function encode
                 * @memberof google.protobuf.EnumOptions
                 * @static
                 * @param {google.protobuf.IEnumOptions} message EnumOptions message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                EnumOptions.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.allowAlias != null && Object.hasOwnProperty.call(message, "allowAlias"))
                        writer.uint32(/* id 2, wireType 0 =*/16).bool(message.allowAlias);
                    if (message.deprecated != null && Object.hasOwnProperty.call(message, "deprecated"))
                        writer.uint32(/* id 3, wireType 0 =*/24).bool(message.deprecated);
                    if (message.deprecatedLegacyJsonFieldConflicts != null && Object.hasOwnProperty.call(message, "deprecatedLegacyJsonFieldConflicts"))
                        writer.uint32(/* id 6, wireType 0 =*/48).bool(message.deprecatedLegacyJsonFieldConflicts);
                    if (message.features != null && Object.hasOwnProperty.call(message, "features"))
                        $root.google.protobuf.FeatureSet.encode(message.features, writer.uint32(/* id 7, wireType 2 =*/58).fork()).ldelim();
                    if (message.uninterpretedOption != null && message.uninterpretedOption.length)
                        for (var i = 0; i < message.uninterpretedOption.length; ++i)
                            $root.google.protobuf.UninterpretedOption.encode(message.uninterpretedOption[i], writer.uint32(/* id 999, wireType 2 =*/7994).fork()).ldelim();
                    return writer;
                };
    
                /**
                 * Encodes the specified EnumOptions message, length delimited. Does not implicitly {@link google.protobuf.EnumOptions.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.protobuf.EnumOptions
                 * @static
                 * @param {google.protobuf.IEnumOptions} message EnumOptions message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                EnumOptions.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes an EnumOptions message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.protobuf.EnumOptions
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.protobuf.EnumOptions} EnumOptions
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                EnumOptions.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.protobuf.EnumOptions();
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 2: {
                                message.allowAlias = reader.bool();
                                break;
                            }
                        case 3: {
                                message.deprecated = reader.bool();
                                break;
                            }
                        case 6: {
                                message.deprecatedLegacyJsonFieldConflicts = reader.bool();
                                break;
                            }
                        case 7: {
                                message.features = $root.google.protobuf.FeatureSet.decode(reader, reader.uint32());
                                break;
                            }
                        case 999: {
                                if (!(message.uninterpretedOption && message.uninterpretedOption.length))
                                    message.uninterpretedOption = [];
                                message.uninterpretedOption.push($root.google.protobuf.UninterpretedOption.decode(reader, reader.uint32()));
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes an EnumOptions message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.protobuf.EnumOptions
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.protobuf.EnumOptions} EnumOptions
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                EnumOptions.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies an EnumOptions message.
                 * @function verify
                 * @memberof google.protobuf.EnumOptions
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                EnumOptions.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    if (message.allowAlias != null && message.hasOwnProperty("allowAlias"))
                        if (typeof message.allowAlias !== "boolean")
                            return "allowAlias: boolean expected";
                    if (message.deprecated != null && message.hasOwnProperty("deprecated"))
                        if (typeof message.deprecated !== "boolean")
                            return "deprecated: boolean expected";
                    if (message.deprecatedLegacyJsonFieldConflicts != null && message.hasOwnProperty("deprecatedLegacyJsonFieldConflicts"))
                        if (typeof message.deprecatedLegacyJsonFieldConflicts !== "boolean")
                            return "deprecatedLegacyJsonFieldConflicts: boolean expected";
                    if (message.features != null && message.hasOwnProperty("features")) {
                        var error = $root.google.protobuf.FeatureSet.verify(message.features);
                        if (error)
                            return "features." + error;
                    }
                    if (message.uninterpretedOption != null && message.hasOwnProperty("uninterpretedOption")) {
                        if (!Array.isArray(message.uninterpretedOption))
                            return "uninterpretedOption: array expected";
                        for (var i = 0; i < message.uninterpretedOption.length; ++i) {
                            var error = $root.google.protobuf.UninterpretedOption.verify(message.uninterpretedOption[i]);
                            if (error)
                                return "uninterpretedOption." + error;
                        }
                    }
                    return null;
                };
    
                /**
                 * Creates an EnumOptions message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.protobuf.EnumOptions
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.protobuf.EnumOptions} EnumOptions
                 */
                EnumOptions.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.protobuf.EnumOptions)
                        return object;
                    var message = new $root.google.protobuf.EnumOptions();
                    if (object.allowAlias != null)
                        message.allowAlias = Boolean(object.allowAlias);
                    if (object.deprecated != null)
                        message.deprecated = Boolean(object.deprecated);
                    if (object.deprecatedLegacyJsonFieldConflicts != null)
                        message.deprecatedLegacyJsonFieldConflicts = Boolean(object.deprecatedLegacyJsonFieldConflicts);
                    if (object.features != null) {
                        if (typeof object.features !== "object")
                            throw TypeError(".google.protobuf.EnumOptions.features: object expected");
                        message.features = $root.google.protobuf.FeatureSet.fromObject(object.features);
                    }
                    if (object.uninterpretedOption) {
                        if (!Array.isArray(object.uninterpretedOption))
                            throw TypeError(".google.protobuf.EnumOptions.uninterpretedOption: array expected");
                        message.uninterpretedOption = [];
                        for (var i = 0; i < object.uninterpretedOption.length; ++i) {
                            if (typeof object.uninterpretedOption[i] !== "object")
                                throw TypeError(".google.protobuf.EnumOptions.uninterpretedOption: object expected");
                            message.uninterpretedOption[i] = $root.google.protobuf.UninterpretedOption.fromObject(object.uninterpretedOption[i]);
                        }
                    }
                    return message;
                };
    
                /**
                 * Creates a plain object from an EnumOptions message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.protobuf.EnumOptions
                 * @static
                 * @param {google.protobuf.EnumOptions} message EnumOptions
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                EnumOptions.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (options.arrays || options.defaults)
                        object.uninterpretedOption = [];
                    if (options.defaults) {
                        object.allowAlias = false;
                        object.deprecated = false;
                        object.deprecatedLegacyJsonFieldConflicts = false;
                        object.features = null;
                    }
                    if (message.allowAlias != null && message.hasOwnProperty("allowAlias"))
                        object.allowAlias = message.allowAlias;
                    if (message.deprecated != null && message.hasOwnProperty("deprecated"))
                        object.deprecated = message.deprecated;
                    if (message.deprecatedLegacyJsonFieldConflicts != null && message.hasOwnProperty("deprecatedLegacyJsonFieldConflicts"))
                        object.deprecatedLegacyJsonFieldConflicts = message.deprecatedLegacyJsonFieldConflicts;
                    if (message.features != null && message.hasOwnProperty("features"))
                        object.features = $root.google.protobuf.FeatureSet.toObject(message.features, options);
                    if (message.uninterpretedOption && message.uninterpretedOption.length) {
                        object.uninterpretedOption = [];
                        for (var j = 0; j < message.uninterpretedOption.length; ++j)
                            object.uninterpretedOption[j] = $root.google.protobuf.UninterpretedOption.toObject(message.uninterpretedOption[j], options);
                    }
                    return object;
                };
    
                /**
                 * Converts this EnumOptions to JSON.
                 * @function toJSON
                 * @memberof google.protobuf.EnumOptions
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                EnumOptions.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for EnumOptions
                 * @function getTypeUrl
                 * @memberof google.protobuf.EnumOptions
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                EnumOptions.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.protobuf.EnumOptions";
                };
    
                return EnumOptions;
            })();
    
            protobuf.EnumValueOptions = (function() {
    
                /**
                 * Properties of an EnumValueOptions.
                 * @memberof google.protobuf
                 * @interface IEnumValueOptions
                 * @property {boolean|null} [deprecated] EnumValueOptions deprecated
                 * @property {google.protobuf.IFeatureSet|null} [features] EnumValueOptions features
                 * @property {boolean|null} [debugRedact] EnumValueOptions debugRedact
                 * @property {Array.<google.protobuf.IUninterpretedOption>|null} [uninterpretedOption] EnumValueOptions uninterpretedOption
                 */
    
                /**
                 * Constructs a new EnumValueOptions.
                 * @memberof google.protobuf
                 * @classdesc Represents an EnumValueOptions.
                 * @implements IEnumValueOptions
                 * @constructor
                 * @param {google.protobuf.IEnumValueOptions=} [properties] Properties to set
                 */
                function EnumValueOptions(properties) {
                    this.uninterpretedOption = [];
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * EnumValueOptions deprecated.
                 * @member {boolean} deprecated
                 * @memberof google.protobuf.EnumValueOptions
                 * @instance
                 */
                EnumValueOptions.prototype.deprecated = false;
    
                /**
                 * EnumValueOptions features.
                 * @member {google.protobuf.IFeatureSet|null|undefined} features
                 * @memberof google.protobuf.EnumValueOptions
                 * @instance
                 */
                EnumValueOptions.prototype.features = null;
    
                /**
                 * EnumValueOptions debugRedact.
                 * @member {boolean} debugRedact
                 * @memberof google.protobuf.EnumValueOptions
                 * @instance
                 */
                EnumValueOptions.prototype.debugRedact = false;
    
                /**
                 * EnumValueOptions uninterpretedOption.
                 * @member {Array.<google.protobuf.IUninterpretedOption>} uninterpretedOption
                 * @memberof google.protobuf.EnumValueOptions
                 * @instance
                 */
                EnumValueOptions.prototype.uninterpretedOption = $util.emptyArray;
    
                /**
                 * Creates a new EnumValueOptions instance using the specified properties.
                 * @function create
                 * @memberof google.protobuf.EnumValueOptions
                 * @static
                 * @param {google.protobuf.IEnumValueOptions=} [properties] Properties to set
                 * @returns {google.protobuf.EnumValueOptions} EnumValueOptions instance
                 */
                EnumValueOptions.create = function create(properties) {
                    return new EnumValueOptions(properties);
                };
    
                /**
                 * Encodes the specified EnumValueOptions message. Does not implicitly {@link google.protobuf.EnumValueOptions.verify|verify} messages.
                 * @function encode
                 * @memberof google.protobuf.EnumValueOptions
                 * @static
                 * @param {google.protobuf.IEnumValueOptions} message EnumValueOptions message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                EnumValueOptions.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.deprecated != null && Object.hasOwnProperty.call(message, "deprecated"))
                        writer.uint32(/* id 1, wireType 0 =*/8).bool(message.deprecated);
                    if (message.features != null && Object.hasOwnProperty.call(message, "features"))
                        $root.google.protobuf.FeatureSet.encode(message.features, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                    if (message.debugRedact != null && Object.hasOwnProperty.call(message, "debugRedact"))
                        writer.uint32(/* id 3, wireType 0 =*/24).bool(message.debugRedact);
                    if (message.uninterpretedOption != null && message.uninterpretedOption.length)
                        for (var i = 0; i < message.uninterpretedOption.length; ++i)
                            $root.google.protobuf.UninterpretedOption.encode(message.uninterpretedOption[i], writer.uint32(/* id 999, wireType 2 =*/7994).fork()).ldelim();
                    return writer;
                };
    
                /**
                 * Encodes the specified EnumValueOptions message, length delimited. Does not implicitly {@link google.protobuf.EnumValueOptions.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.protobuf.EnumValueOptions
                 * @static
                 * @param {google.protobuf.IEnumValueOptions} message EnumValueOptions message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                EnumValueOptions.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes an EnumValueOptions message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.protobuf.EnumValueOptions
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.protobuf.EnumValueOptions} EnumValueOptions
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                EnumValueOptions.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.protobuf.EnumValueOptions();
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 1: {
                                message.deprecated = reader.bool();
                                break;
                            }
                        case 2: {
                                message.features = $root.google.protobuf.FeatureSet.decode(reader, reader.uint32());
                                break;
                            }
                        case 3: {
                                message.debugRedact = reader.bool();
                                break;
                            }
                        case 999: {
                                if (!(message.uninterpretedOption && message.uninterpretedOption.length))
                                    message.uninterpretedOption = [];
                                message.uninterpretedOption.push($root.google.protobuf.UninterpretedOption.decode(reader, reader.uint32()));
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes an EnumValueOptions message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.protobuf.EnumValueOptions
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.protobuf.EnumValueOptions} EnumValueOptions
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                EnumValueOptions.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies an EnumValueOptions message.
                 * @function verify
                 * @memberof google.protobuf.EnumValueOptions
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                EnumValueOptions.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    if (message.deprecated != null && message.hasOwnProperty("deprecated"))
                        if (typeof message.deprecated !== "boolean")
                            return "deprecated: boolean expected";
                    if (message.features != null && message.hasOwnProperty("features")) {
                        var error = $root.google.protobuf.FeatureSet.verify(message.features);
                        if (error)
                            return "features." + error;
                    }
                    if (message.debugRedact != null && message.hasOwnProperty("debugRedact"))
                        if (typeof message.debugRedact !== "boolean")
                            return "debugRedact: boolean expected";
                    if (message.uninterpretedOption != null && message.hasOwnProperty("uninterpretedOption")) {
                        if (!Array.isArray(message.uninterpretedOption))
                            return "uninterpretedOption: array expected";
                        for (var i = 0; i < message.uninterpretedOption.length; ++i) {
                            var error = $root.google.protobuf.UninterpretedOption.verify(message.uninterpretedOption[i]);
                            if (error)
                                return "uninterpretedOption." + error;
                        }
                    }
                    return null;
                };
    
                /**
                 * Creates an EnumValueOptions message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.protobuf.EnumValueOptions
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.protobuf.EnumValueOptions} EnumValueOptions
                 */
                EnumValueOptions.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.protobuf.EnumValueOptions)
                        return object;
                    var message = new $root.google.protobuf.EnumValueOptions();
                    if (object.deprecated != null)
                        message.deprecated = Boolean(object.deprecated);
                    if (object.features != null) {
                        if (typeof object.features !== "object")
                            throw TypeError(".google.protobuf.EnumValueOptions.features: object expected");
                        message.features = $root.google.protobuf.FeatureSet.fromObject(object.features);
                    }
                    if (object.debugRedact != null)
                        message.debugRedact = Boolean(object.debugRedact);
                    if (object.uninterpretedOption) {
                        if (!Array.isArray(object.uninterpretedOption))
                            throw TypeError(".google.protobuf.EnumValueOptions.uninterpretedOption: array expected");
                        message.uninterpretedOption = [];
                        for (var i = 0; i < object.uninterpretedOption.length; ++i) {
                            if (typeof object.uninterpretedOption[i] !== "object")
                                throw TypeError(".google.protobuf.EnumValueOptions.uninterpretedOption: object expected");
                            message.uninterpretedOption[i] = $root.google.protobuf.UninterpretedOption.fromObject(object.uninterpretedOption[i]);
                        }
                    }
                    return message;
                };
    
                /**
                 * Creates a plain object from an EnumValueOptions message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.protobuf.EnumValueOptions
                 * @static
                 * @param {google.protobuf.EnumValueOptions} message EnumValueOptions
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                EnumValueOptions.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (options.arrays || options.defaults)
                        object.uninterpretedOption = [];
                    if (options.defaults) {
                        object.deprecated = false;
                        object.features = null;
                        object.debugRedact = false;
                    }
                    if (message.deprecated != null && message.hasOwnProperty("deprecated"))
                        object.deprecated = message.deprecated;
                    if (message.features != null && message.hasOwnProperty("features"))
                        object.features = $root.google.protobuf.FeatureSet.toObject(message.features, options);
                    if (message.debugRedact != null && message.hasOwnProperty("debugRedact"))
                        object.debugRedact = message.debugRedact;
                    if (message.uninterpretedOption && message.uninterpretedOption.length) {
                        object.uninterpretedOption = [];
                        for (var j = 0; j < message.uninterpretedOption.length; ++j)
                            object.uninterpretedOption[j] = $root.google.protobuf.UninterpretedOption.toObject(message.uninterpretedOption[j], options);
                    }
                    return object;
                };
    
                /**
                 * Converts this EnumValueOptions to JSON.
                 * @function toJSON
                 * @memberof google.protobuf.EnumValueOptions
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                EnumValueOptions.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for EnumValueOptions
                 * @function getTypeUrl
                 * @memberof google.protobuf.EnumValueOptions
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                EnumValueOptions.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.protobuf.EnumValueOptions";
                };
    
                return EnumValueOptions;
            })();
    
            protobuf.ServiceOptions = (function() {
    
                /**
                 * Properties of a ServiceOptions.
                 * @memberof google.protobuf
                 * @interface IServiceOptions
                 * @property {google.protobuf.IFeatureSet|null} [features] ServiceOptions features
                 * @property {boolean|null} [deprecated] ServiceOptions deprecated
                 * @property {Array.<google.protobuf.IUninterpretedOption>|null} [uninterpretedOption] ServiceOptions uninterpretedOption
                 * @property {string|null} [".google.api.defaultHost"] ServiceOptions .google.api.defaultHost
                 * @property {string|null} [".google.api.oauthScopes"] ServiceOptions .google.api.oauthScopes
                 */
    
                /**
                 * Constructs a new ServiceOptions.
                 * @memberof google.protobuf
                 * @classdesc Represents a ServiceOptions.
                 * @implements IServiceOptions
                 * @constructor
                 * @param {google.protobuf.IServiceOptions=} [properties] Properties to set
                 */
                function ServiceOptions(properties) {
                    this.uninterpretedOption = [];
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * ServiceOptions features.
                 * @member {google.protobuf.IFeatureSet|null|undefined} features
                 * @memberof google.protobuf.ServiceOptions
                 * @instance
                 */
                ServiceOptions.prototype.features = null;
    
                /**
                 * ServiceOptions deprecated.
                 * @member {boolean} deprecated
                 * @memberof google.protobuf.ServiceOptions
                 * @instance
                 */
                ServiceOptions.prototype.deprecated = false;
    
                /**
                 * ServiceOptions uninterpretedOption.
                 * @member {Array.<google.protobuf.IUninterpretedOption>} uninterpretedOption
                 * @memberof google.protobuf.ServiceOptions
                 * @instance
                 */
                ServiceOptions.prototype.uninterpretedOption = $util.emptyArray;
    
                /**
                 * ServiceOptions .google.api.defaultHost.
                 * @member {string} .google.api.defaultHost
                 * @memberof google.protobuf.ServiceOptions
                 * @instance
                 */
                ServiceOptions.prototype[".google.api.defaultHost"] = "";
    
                /**
                 * ServiceOptions .google.api.oauthScopes.
                 * @member {string} .google.api.oauthScopes
                 * @memberof google.protobuf.ServiceOptions
                 * @instance
                 */
                ServiceOptions.prototype[".google.api.oauthScopes"] = "";
    
                /**
                 * Creates a new ServiceOptions instance using the specified properties.
                 * @function create
                 * @memberof google.protobuf.ServiceOptions
                 * @static
                 * @param {google.protobuf.IServiceOptions=} [properties] Properties to set
                 * @returns {google.protobuf.ServiceOptions} ServiceOptions instance
                 */
                ServiceOptions.create = function create(properties) {
                    return new ServiceOptions(properties);
                };
    
                /**
                 * Encodes the specified ServiceOptions message. Does not implicitly {@link google.protobuf.ServiceOptions.verify|verify} messages.
                 * @function encode
                 * @memberof google.protobuf.ServiceOptions
                 * @static
                 * @param {google.protobuf.IServiceOptions} message ServiceOptions message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                ServiceOptions.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.deprecated != null && Object.hasOwnProperty.call(message, "deprecated"))
                        writer.uint32(/* id 33, wireType 0 =*/264).bool(message.deprecated);
                    if (message.features != null && Object.hasOwnProperty.call(message, "features"))
                        $root.google.protobuf.FeatureSet.encode(message.features, writer.uint32(/* id 34, wireType 2 =*/274).fork()).ldelim();
                    if (message.uninterpretedOption != null && message.uninterpretedOption.length)
                        for (var i = 0; i < message.uninterpretedOption.length; ++i)
                            $root.google.protobuf.UninterpretedOption.encode(message.uninterpretedOption[i], writer.uint32(/* id 999, wireType 2 =*/7994).fork()).ldelim();
                    if (message[".google.api.defaultHost"] != null && Object.hasOwnProperty.call(message, ".google.api.defaultHost"))
                        writer.uint32(/* id 1049, wireType 2 =*/8394).string(message[".google.api.defaultHost"]);
                    if (message[".google.api.oauthScopes"] != null && Object.hasOwnProperty.call(message, ".google.api.oauthScopes"))
                        writer.uint32(/* id 1050, wireType 2 =*/8402).string(message[".google.api.oauthScopes"]);
                    return writer;
                };
    
                /**
                 * Encodes the specified ServiceOptions message, length delimited. Does not implicitly {@link google.protobuf.ServiceOptions.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.protobuf.ServiceOptions
                 * @static
                 * @param {google.protobuf.IServiceOptions} message ServiceOptions message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                ServiceOptions.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes a ServiceOptions message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.protobuf.ServiceOptions
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.protobuf.ServiceOptions} ServiceOptions
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                ServiceOptions.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.protobuf.ServiceOptions();
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 34: {
                                message.features = $root.google.protobuf.FeatureSet.decode(reader, reader.uint32());
                                break;
                            }
                        case 33: {
                                message.deprecated = reader.bool();
                                break;
                            }
                        case 999: {
                                if (!(message.uninterpretedOption && message.uninterpretedOption.length))
                                    message.uninterpretedOption = [];
                                message.uninterpretedOption.push($root.google.protobuf.UninterpretedOption.decode(reader, reader.uint32()));
                                break;
                            }
                        case 1049: {
                                message[".google.api.defaultHost"] = reader.string();
                                break;
                            }
                        case 1050: {
                                message[".google.api.oauthScopes"] = reader.string();
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes a ServiceOptions message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.protobuf.ServiceOptions
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.protobuf.ServiceOptions} ServiceOptions
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                ServiceOptions.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies a ServiceOptions message.
                 * @function verify
                 * @memberof google.protobuf.ServiceOptions
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                ServiceOptions.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    if (message.features != null && message.hasOwnProperty("features")) {
                        var error = $root.google.protobuf.FeatureSet.verify(message.features);
                        if (error)
                            return "features." + error;
                    }
                    if (message.deprecated != null && message.hasOwnProperty("deprecated"))
                        if (typeof message.deprecated !== "boolean")
                            return "deprecated: boolean expected";
                    if (message.uninterpretedOption != null && message.hasOwnProperty("uninterpretedOption")) {
                        if (!Array.isArray(message.uninterpretedOption))
                            return "uninterpretedOption: array expected";
                        for (var i = 0; i < message.uninterpretedOption.length; ++i) {
                            var error = $root.google.protobuf.UninterpretedOption.verify(message.uninterpretedOption[i]);
                            if (error)
                                return "uninterpretedOption." + error;
                        }
                    }
                    if (message[".google.api.defaultHost"] != null && message.hasOwnProperty(".google.api.defaultHost"))
                        if (!$util.isString(message[".google.api.defaultHost"]))
                            return ".google.api.defaultHost: string expected";
                    if (message[".google.api.oauthScopes"] != null && message.hasOwnProperty(".google.api.oauthScopes"))
                        if (!$util.isString(message[".google.api.oauthScopes"]))
                            return ".google.api.oauthScopes: string expected";
                    return null;
                };
    
                /**
                 * Creates a ServiceOptions message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.protobuf.ServiceOptions
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.protobuf.ServiceOptions} ServiceOptions
                 */
                ServiceOptions.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.protobuf.ServiceOptions)
                        return object;
                    var message = new $root.google.protobuf.ServiceOptions();
                    if (object.features != null) {
                        if (typeof object.features !== "object")
                            throw TypeError(".google.protobuf.ServiceOptions.features: object expected");
                        message.features = $root.google.protobuf.FeatureSet.fromObject(object.features);
                    }
                    if (object.deprecated != null)
                        message.deprecated = Boolean(object.deprecated);
                    if (object.uninterpretedOption) {
                        if (!Array.isArray(object.uninterpretedOption))
                            throw TypeError(".google.protobuf.ServiceOptions.uninterpretedOption: array expected");
                        message.uninterpretedOption = [];
                        for (var i = 0; i < object.uninterpretedOption.length; ++i) {
                            if (typeof object.uninterpretedOption[i] !== "object")
                                throw TypeError(".google.protobuf.ServiceOptions.uninterpretedOption: object expected");
                            message.uninterpretedOption[i] = $root.google.protobuf.UninterpretedOption.fromObject(object.uninterpretedOption[i]);
                        }
                    }
                    if (object[".google.api.defaultHost"] != null)
                        message[".google.api.defaultHost"] = String(object[".google.api.defaultHost"]);
                    if (object[".google.api.oauthScopes"] != null)
                        message[".google.api.oauthScopes"] = String(object[".google.api.oauthScopes"]);
                    return message;
                };
    
                /**
                 * Creates a plain object from a ServiceOptions message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.protobuf.ServiceOptions
                 * @static
                 * @param {google.protobuf.ServiceOptions} message ServiceOptions
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                ServiceOptions.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (options.arrays || options.defaults)
                        object.uninterpretedOption = [];
                    if (options.defaults) {
                        object.deprecated = false;
                        object.features = null;
                        object[".google.api.defaultHost"] = "";
                        object[".google.api.oauthScopes"] = "";
                    }
                    if (message.deprecated != null && message.hasOwnProperty("deprecated"))
                        object.deprecated = message.deprecated;
                    if (message.features != null && message.hasOwnProperty("features"))
                        object.features = $root.google.protobuf.FeatureSet.toObject(message.features, options);
                    if (message.uninterpretedOption && message.uninterpretedOption.length) {
                        object.uninterpretedOption = [];
                        for (var j = 0; j < message.uninterpretedOption.length; ++j)
                            object.uninterpretedOption[j] = $root.google.protobuf.UninterpretedOption.toObject(message.uninterpretedOption[j], options);
                    }
                    if (message[".google.api.defaultHost"] != null && message.hasOwnProperty(".google.api.defaultHost"))
                        object[".google.api.defaultHost"] = message[".google.api.defaultHost"];
                    if (message[".google.api.oauthScopes"] != null && message.hasOwnProperty(".google.api.oauthScopes"))
                        object[".google.api.oauthScopes"] = message[".google.api.oauthScopes"];
                    return object;
                };
    
                /**
                 * Converts this ServiceOptions to JSON.
                 * @function toJSON
                 * @memberof google.protobuf.ServiceOptions
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                ServiceOptions.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for ServiceOptions
                 * @function getTypeUrl
                 * @memberof google.protobuf.ServiceOptions
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                ServiceOptions.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.protobuf.ServiceOptions";
                };
    
                return ServiceOptions;
            })();
    
            protobuf.MethodOptions = (function() {
    
                /**
                 * Properties of a MethodOptions.
                 * @memberof google.protobuf
                 * @interface IMethodOptions
                 * @property {boolean|null} [deprecated] MethodOptions deprecated
                 * @property {google.protobuf.MethodOptions.IdempotencyLevel|null} [idempotencyLevel] MethodOptions idempotencyLevel
                 * @property {google.protobuf.IFeatureSet|null} [features] MethodOptions features
                 * @property {Array.<google.protobuf.IUninterpretedOption>|null} [uninterpretedOption] MethodOptions uninterpretedOption
                 * @property {google.api.IHttpRule|null} [".google.api.http"] MethodOptions .google.api.http
                 * @property {Array.<string>|null} [".google.api.methodSignature"] MethodOptions .google.api.methodSignature
                 * @property {google.longrunning.IOperationInfo|null} [".google.longrunning.operationInfo"] MethodOptions .google.longrunning.operationInfo
                 */
    
                /**
                 * Constructs a new MethodOptions.
                 * @memberof google.protobuf
                 * @classdesc Represents a MethodOptions.
                 * @implements IMethodOptions
                 * @constructor
                 * @param {google.protobuf.IMethodOptions=} [properties] Properties to set
                 */
                function MethodOptions(properties) {
                    this.uninterpretedOption = [];
                    this[".google.api.methodSignature"] = [];
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * MethodOptions deprecated.
                 * @member {boolean} deprecated
                 * @memberof google.protobuf.MethodOptions
                 * @instance
                 */
                MethodOptions.prototype.deprecated = false;
    
                /**
                 * MethodOptions idempotencyLevel.
                 * @member {google.protobuf.MethodOptions.IdempotencyLevel} idempotencyLevel
                 * @memberof google.protobuf.MethodOptions
                 * @instance
                 */
                MethodOptions.prototype.idempotencyLevel = 0;
    
                /**
                 * MethodOptions features.
                 * @member {google.protobuf.IFeatureSet|null|undefined} features
                 * @memberof google.protobuf.MethodOptions
                 * @instance
                 */
                MethodOptions.prototype.features = null;
    
                /**
                 * MethodOptions uninterpretedOption.
                 * @member {Array.<google.protobuf.IUninterpretedOption>} uninterpretedOption
                 * @memberof google.protobuf.MethodOptions
                 * @instance
                 */
                MethodOptions.prototype.uninterpretedOption = $util.emptyArray;
    
                /**
                 * MethodOptions .google.api.http.
                 * @member {google.api.IHttpRule|null|undefined} .google.api.http
                 * @memberof google.protobuf.MethodOptions
                 * @instance
                 */
                MethodOptions.prototype[".google.api.http"] = null;
    
                /**
                 * MethodOptions .google.api.methodSignature.
                 * @member {Array.<string>} .google.api.methodSignature
                 * @memberof google.protobuf.MethodOptions
                 * @instance
                 */
                MethodOptions.prototype[".google.api.methodSignature"] = $util.emptyArray;
    
                /**
                 * MethodOptions .google.longrunning.operationInfo.
                 * @member {google.longrunning.IOperationInfo|null|undefined} .google.longrunning.operationInfo
                 * @memberof google.protobuf.MethodOptions
                 * @instance
                 */
                MethodOptions.prototype[".google.longrunning.operationInfo"] = null;
    
                /**
                 * Creates a new MethodOptions instance using the specified properties.
                 * @function create
                 * @memberof google.protobuf.MethodOptions
                 * @static
                 * @param {google.protobuf.IMethodOptions=} [properties] Properties to set
                 * @returns {google.protobuf.MethodOptions} MethodOptions instance
                 */
                MethodOptions.create = function create(properties) {
                    return new MethodOptions(properties);
                };
    
                /**
                 * Encodes the specified MethodOptions message. Does not implicitly {@link google.protobuf.MethodOptions.verify|verify} messages.
                 * @function encode
                 * @memberof google.protobuf.MethodOptions
                 * @static
                 * @param {google.protobuf.IMethodOptions} message MethodOptions message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                MethodOptions.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.deprecated != null && Object.hasOwnProperty.call(message, "deprecated"))
                        writer.uint32(/* id 33, wireType 0 =*/264).bool(message.deprecated);
                    if (message.idempotencyLevel != null && Object.hasOwnProperty.call(message, "idempotencyLevel"))
                        writer.uint32(/* id 34, wireType 0 =*/272).int32(message.idempotencyLevel);
                    if (message.features != null && Object.hasOwnProperty.call(message, "features"))
                        $root.google.protobuf.FeatureSet.encode(message.features, writer.uint32(/* id 35, wireType 2 =*/282).fork()).ldelim();
                    if (message.uninterpretedOption != null && message.uninterpretedOption.length)
                        for (var i = 0; i < message.uninterpretedOption.length; ++i)
                            $root.google.protobuf.UninterpretedOption.encode(message.uninterpretedOption[i], writer.uint32(/* id 999, wireType 2 =*/7994).fork()).ldelim();
                    if (message[".google.longrunning.operationInfo"] != null && Object.hasOwnProperty.call(message, ".google.longrunning.operationInfo"))
                        $root.google.longrunning.OperationInfo.encode(message[".google.longrunning.operationInfo"], writer.uint32(/* id 1049, wireType 2 =*/8394).fork()).ldelim();
                    if (message[".google.api.methodSignature"] != null && message[".google.api.methodSignature"].length)
                        for (var i = 0; i < message[".google.api.methodSignature"].length; ++i)
                            writer.uint32(/* id 1051, wireType 2 =*/8410).string(message[".google.api.methodSignature"][i]);
                    if (message[".google.api.http"] != null && Object.hasOwnProperty.call(message, ".google.api.http"))
                        $root.google.api.HttpRule.encode(message[".google.api.http"], writer.uint32(/* id 72295728, wireType 2 =*/578365826).fork()).ldelim();
                    return writer;
                };
    
                /**
                 * Encodes the specified MethodOptions message, length delimited. Does not implicitly {@link google.protobuf.MethodOptions.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.protobuf.MethodOptions
                 * @static
                 * @param {google.protobuf.IMethodOptions} message MethodOptions message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                MethodOptions.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes a MethodOptions message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.protobuf.MethodOptions
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.protobuf.MethodOptions} MethodOptions
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                MethodOptions.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.protobuf.MethodOptions();
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 33: {
                                message.deprecated = reader.bool();
                                break;
                            }
                        case 34: {
                                message.idempotencyLevel = reader.int32();
                                break;
                            }
                        case 35: {
                                message.features = $root.google.protobuf.FeatureSet.decode(reader, reader.uint32());
                                break;
                            }
                        case 999: {
                                if (!(message.uninterpretedOption && message.uninterpretedOption.length))
                                    message.uninterpretedOption = [];
                                message.uninterpretedOption.push($root.google.protobuf.UninterpretedOption.decode(reader, reader.uint32()));
                                break;
                            }
                        case 72295728: {
                                message[".google.api.http"] = $root.google.api.HttpRule.decode(reader, reader.uint32());
                                break;
                            }
                        case 1051: {
                                if (!(message[".google.api.methodSignature"] && message[".google.api.methodSignature"].length))
                                    message[".google.api.methodSignature"] = [];
                                message[".google.api.methodSignature"].push(reader.string());
                                break;
                            }
                        case 1049: {
                                message[".google.longrunning.operationInfo"] = $root.google.longrunning.OperationInfo.decode(reader, reader.uint32());
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes a MethodOptions message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.protobuf.MethodOptions
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.protobuf.MethodOptions} MethodOptions
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                MethodOptions.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies a MethodOptions message.
                 * @function verify
                 * @memberof google.protobuf.MethodOptions
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                MethodOptions.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    if (message.deprecated != null && message.hasOwnProperty("deprecated"))
                        if (typeof message.deprecated !== "boolean")
                            return "deprecated: boolean expected";
                    if (message.idempotencyLevel != null && message.hasOwnProperty("idempotencyLevel"))
                        switch (message.idempotencyLevel) {
                        default:
                            return "idempotencyLevel: enum value expected";
                        case 0:
                        case 1:
                        case 2:
                            break;
                        }
                    if (message.features != null && message.hasOwnProperty("features")) {
                        var error = $root.google.protobuf.FeatureSet.verify(message.features);
                        if (error)
                            return "features." + error;
                    }
                    if (message.uninterpretedOption != null && message.hasOwnProperty("uninterpretedOption")) {
                        if (!Array.isArray(message.uninterpretedOption))
                            return "uninterpretedOption: array expected";
                        for (var i = 0; i < message.uninterpretedOption.length; ++i) {
                            var error = $root.google.protobuf.UninterpretedOption.verify(message.uninterpretedOption[i]);
                            if (error)
                                return "uninterpretedOption." + error;
                        }
                    }
                    if (message[".google.api.http"] != null && message.hasOwnProperty(".google.api.http")) {
                        var error = $root.google.api.HttpRule.verify(message[".google.api.http"]);
                        if (error)
                            return ".google.api.http." + error;
                    }
                    if (message[".google.api.methodSignature"] != null && message.hasOwnProperty(".google.api.methodSignature")) {
                        if (!Array.isArray(message[".google.api.methodSignature"]))
                            return ".google.api.methodSignature: array expected";
                        for (var i = 0; i < message[".google.api.methodSignature"].length; ++i)
                            if (!$util.isString(message[".google.api.methodSignature"][i]))
                                return ".google.api.methodSignature: string[] expected";
                    }
                    if (message[".google.longrunning.operationInfo"] != null && message.hasOwnProperty(".google.longrunning.operationInfo")) {
                        var error = $root.google.longrunning.OperationInfo.verify(message[".google.longrunning.operationInfo"]);
                        if (error)
                            return ".google.longrunning.operationInfo." + error;
                    }
                    return null;
                };
    
                /**
                 * Creates a MethodOptions message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.protobuf.MethodOptions
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.protobuf.MethodOptions} MethodOptions
                 */
                MethodOptions.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.protobuf.MethodOptions)
                        return object;
                    var message = new $root.google.protobuf.MethodOptions();
                    if (object.deprecated != null)
                        message.deprecated = Boolean(object.deprecated);
                    switch (object.idempotencyLevel) {
                    default:
                        if (typeof object.idempotencyLevel === "number") {
                            message.idempotencyLevel = object.idempotencyLevel;
                            break;
                        }
                        break;
                    case "IDEMPOTENCY_UNKNOWN":
                    case 0:
                        message.idempotencyLevel = 0;
                        break;
                    case "NO_SIDE_EFFECTS":
                    case 1:
                        message.idempotencyLevel = 1;
                        break;
                    case "IDEMPOTENT":
                    case 2:
                        message.idempotencyLevel = 2;
                        break;
                    }
                    if (object.features != null) {
                        if (typeof object.features !== "object")
                            throw TypeError(".google.protobuf.MethodOptions.features: object expected");
                        message.features = $root.google.protobuf.FeatureSet.fromObject(object.features);
                    }
                    if (object.uninterpretedOption) {
                        if (!Array.isArray(object.uninterpretedOption))
                            throw TypeError(".google.protobuf.MethodOptions.uninterpretedOption: array expected");
                        message.uninterpretedOption = [];
                        for (var i = 0; i < object.uninterpretedOption.length; ++i) {
                            if (typeof object.uninterpretedOption[i] !== "object")
                                throw TypeError(".google.protobuf.MethodOptions.uninterpretedOption: object expected");
                            message.uninterpretedOption[i] = $root.google.protobuf.UninterpretedOption.fromObject(object.uninterpretedOption[i]);
                        }
                    }
                    if (object[".google.api.http"] != null) {
                        if (typeof object[".google.api.http"] !== "object")
                            throw TypeError(".google.protobuf.MethodOptions..google.api.http: object expected");
                        message[".google.api.http"] = $root.google.api.HttpRule.fromObject(object[".google.api.http"]);
                    }
                    if (object[".google.api.methodSignature"]) {
                        if (!Array.isArray(object[".google.api.methodSignature"]))
                            throw TypeError(".google.protobuf.MethodOptions..google.api.methodSignature: array expected");
                        message[".google.api.methodSignature"] = [];
                        for (var i = 0; i < object[".google.api.methodSignature"].length; ++i)
                            message[".google.api.methodSignature"][i] = String(object[".google.api.methodSignature"][i]);
                    }
                    if (object[".google.longrunning.operationInfo"] != null) {
                        if (typeof object[".google.longrunning.operationInfo"] !== "object")
                            throw TypeError(".google.protobuf.MethodOptions..google.longrunning.operationInfo: object expected");
                        message[".google.longrunning.operationInfo"] = $root.google.longrunning.OperationInfo.fromObject(object[".google.longrunning.operationInfo"]);
                    }
                    return message;
                };
    
                /**
                 * Creates a plain object from a MethodOptions message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.protobuf.MethodOptions
                 * @static
                 * @param {google.protobuf.MethodOptions} message MethodOptions
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                MethodOptions.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (options.arrays || options.defaults) {
                        object.uninterpretedOption = [];
                        object[".google.api.methodSignature"] = [];
                    }
                    if (options.defaults) {
                        object.deprecated = false;
                        object.idempotencyLevel = options.enums === String ? "IDEMPOTENCY_UNKNOWN" : 0;
                        object.features = null;
                        object[".google.longrunning.operationInfo"] = null;
                        object[".google.api.http"] = null;
                    }
                    if (message.deprecated != null && message.hasOwnProperty("deprecated"))
                        object.deprecated = message.deprecated;
                    if (message.idempotencyLevel != null && message.hasOwnProperty("idempotencyLevel"))
                        object.idempotencyLevel = options.enums === String ? $root.google.protobuf.MethodOptions.IdempotencyLevel[message.idempotencyLevel] === undefined ? message.idempotencyLevel : $root.google.protobuf.MethodOptions.IdempotencyLevel[message.idempotencyLevel] : message.idempotencyLevel;
                    if (message.features != null && message.hasOwnProperty("features"))
                        object.features = $root.google.protobuf.FeatureSet.toObject(message.features, options);
                    if (message.uninterpretedOption && message.uninterpretedOption.length) {
                        object.uninterpretedOption = [];
                        for (var j = 0; j < message.uninterpretedOption.length; ++j)
                            object.uninterpretedOption[j] = $root.google.protobuf.UninterpretedOption.toObject(message.uninterpretedOption[j], options);
                    }
                    if (message[".google.longrunning.operationInfo"] != null && message.hasOwnProperty(".google.longrunning.operationInfo"))
                        object[".google.longrunning.operationInfo"] = $root.google.longrunning.OperationInfo.toObject(message[".google.longrunning.operationInfo"], options);
                    if (message[".google.api.methodSignature"] && message[".google.api.methodSignature"].length) {
                        object[".google.api.methodSignature"] = [];
                        for (var j = 0; j < message[".google.api.methodSignature"].length; ++j)
                            object[".google.api.methodSignature"][j] = message[".google.api.methodSignature"][j];
                    }
                    if (message[".google.api.http"] != null && message.hasOwnProperty(".google.api.http"))
                        object[".google.api.http"] = $root.google.api.HttpRule.toObject(message[".google.api.http"], options);
                    return object;
                };
    
                /**
                 * Converts this MethodOptions to JSON.
                 * @function toJSON
                 * @memberof google.protobuf.MethodOptions
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                MethodOptions.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for MethodOptions
                 * @function getTypeUrl
                 * @memberof google.protobuf.MethodOptions
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                MethodOptions.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.protobuf.MethodOptions";
                };
    
                /**
                 * IdempotencyLevel enum.
                 * @name google.protobuf.MethodOptions.IdempotencyLevel
                 * @enum {number}
                 * @property {number} IDEMPOTENCY_UNKNOWN=0 IDEMPOTENCY_UNKNOWN value
                 * @property {number} NO_SIDE_EFFECTS=1 NO_SIDE_EFFECTS value
                 * @property {number} IDEMPOTENT=2 IDEMPOTENT value
                 */
                MethodOptions.IdempotencyLevel = (function() {
                    var valuesById = {}, values = Object.create(valuesById);
                    values[valuesById[0] = "IDEMPOTENCY_UNKNOWN"] = 0;
                    values[valuesById[1] = "NO_SIDE_EFFECTS"] = 1;
                    values[valuesById[2] = "IDEMPOTENT"] = 2;
                    return values;
                })();
    
                return MethodOptions;
            })();
    
            protobuf.UninterpretedOption = (function() {
    
                /**
                 * Properties of an UninterpretedOption.
                 * @memberof google.protobuf
                 * @interface IUninterpretedOption
                 * @property {Array.<google.protobuf.UninterpretedOption.INamePart>|null} [name] UninterpretedOption name
                 * @property {string|null} [identifierValue] UninterpretedOption identifierValue
                 * @property {number|Long|null} [positiveIntValue] UninterpretedOption positiveIntValue
                 * @property {number|Long|null} [negativeIntValue] UninterpretedOption negativeIntValue
                 * @property {number|null} [doubleValue] UninterpretedOption doubleValue
                 * @property {Uint8Array|null} [stringValue] UninterpretedOption stringValue
                 * @property {string|null} [aggregateValue] UninterpretedOption aggregateValue
                 */
    
                /**
                 * Constructs a new UninterpretedOption.
                 * @memberof google.protobuf
                 * @classdesc Represents an UninterpretedOption.
                 * @implements IUninterpretedOption
                 * @constructor
                 * @param {google.protobuf.IUninterpretedOption=} [properties] Properties to set
                 */
                function UninterpretedOption(properties) {
                    this.name = [];
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * UninterpretedOption name.
                 * @member {Array.<google.protobuf.UninterpretedOption.INamePart>} name
                 * @memberof google.protobuf.UninterpretedOption
                 * @instance
                 */
                UninterpretedOption.prototype.name = $util.emptyArray;
    
                /**
                 * UninterpretedOption identifierValue.
                 * @member {string} identifierValue
                 * @memberof google.protobuf.UninterpretedOption
                 * @instance
                 */
                UninterpretedOption.prototype.identifierValue = "";
    
                /**
                 * UninterpretedOption positiveIntValue.
                 * @member {number|Long} positiveIntValue
                 * @memberof google.protobuf.UninterpretedOption
                 * @instance
                 */
                UninterpretedOption.prototype.positiveIntValue = $util.Long ? $util.Long.fromBits(0,0,true) : 0;
    
                /**
                 * UninterpretedOption negativeIntValue.
                 * @member {number|Long} negativeIntValue
                 * @memberof google.protobuf.UninterpretedOption
                 * @instance
                 */
                UninterpretedOption.prototype.negativeIntValue = $util.Long ? $util.Long.fromBits(0,0,false) : 0;
    
                /**
                 * UninterpretedOption doubleValue.
                 * @member {number} doubleValue
                 * @memberof google.protobuf.UninterpretedOption
                 * @instance
                 */
                UninterpretedOption.prototype.doubleValue = 0;
    
                /**
                 * UninterpretedOption stringValue.
                 * @member {Uint8Array} stringValue
                 * @memberof google.protobuf.UninterpretedOption
                 * @instance
                 */
                UninterpretedOption.prototype.stringValue = $util.newBuffer([]);
    
                /**
                 * UninterpretedOption aggregateValue.
                 * @member {string} aggregateValue
                 * @memberof google.protobuf.UninterpretedOption
                 * @instance
                 */
                UninterpretedOption.prototype.aggregateValue = "";
    
                /**
                 * Creates a new UninterpretedOption instance using the specified properties.
                 * @function create
                 * @memberof google.protobuf.UninterpretedOption
                 * @static
                 * @param {google.protobuf.IUninterpretedOption=} [properties] Properties to set
                 * @returns {google.protobuf.UninterpretedOption} UninterpretedOption instance
                 */
                UninterpretedOption.create = function create(properties) {
                    return new UninterpretedOption(properties);
                };
    
                /**
                 * Encodes the specified UninterpretedOption message. Does not implicitly {@link google.protobuf.UninterpretedOption.verify|verify} messages.
                 * @function encode
                 * @memberof google.protobuf.UninterpretedOption
                 * @static
                 * @param {google.protobuf.IUninterpretedOption} message UninterpretedOption message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                UninterpretedOption.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.name != null && message.name.length)
                        for (var i = 0; i < message.name.length; ++i)
                            $root.google.protobuf.UninterpretedOption.NamePart.encode(message.name[i], writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                    if (message.identifierValue != null && Object.hasOwnProperty.call(message, "identifierValue"))
                        writer.uint32(/* id 3, wireType 2 =*/26).string(message.identifierValue);
                    if (message.positiveIntValue != null && Object.hasOwnProperty.call(message, "positiveIntValue"))
                        writer.uint32(/* id 4, wireType 0 =*/32).uint64(message.positiveIntValue);
                    if (message.negativeIntValue != null && Object.hasOwnProperty.call(message, "negativeIntValue"))
                        writer.uint32(/* id 5, wireType 0 =*/40).int64(message.negativeIntValue);
                    if (message.doubleValue != null && Object.hasOwnProperty.call(message, "doubleValue"))
                        writer.uint32(/* id 6, wireType 1 =*/49).double(message.doubleValue);
                    if (message.stringValue != null && Object.hasOwnProperty.call(message, "stringValue"))
                        writer.uint32(/* id 7, wireType 2 =*/58).bytes(message.stringValue);
                    if (message.aggregateValue != null && Object.hasOwnProperty.call(message, "aggregateValue"))
                        writer.uint32(/* id 8, wireType 2 =*/66).string(message.aggregateValue);
                    return writer;
                };
    
                /**
                 * Encodes the specified UninterpretedOption message, length delimited. Does not implicitly {@link google.protobuf.UninterpretedOption.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.protobuf.UninterpretedOption
                 * @static
                 * @param {google.protobuf.IUninterpretedOption} message UninterpretedOption message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                UninterpretedOption.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes an UninterpretedOption message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.protobuf.UninterpretedOption
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.protobuf.UninterpretedOption} UninterpretedOption
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                UninterpretedOption.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.protobuf.UninterpretedOption();
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 2: {
                                if (!(message.name && message.name.length))
                                    message.name = [];
                                message.name.push($root.google.protobuf.UninterpretedOption.NamePart.decode(reader, reader.uint32()));
                                break;
                            }
                        case 3: {
                                message.identifierValue = reader.string();
                                break;
                            }
                        case 4: {
                                message.positiveIntValue = reader.uint64();
                                break;
                            }
                        case 5: {
                                message.negativeIntValue = reader.int64();
                                break;
                            }
                        case 6: {
                                message.doubleValue = reader.double();
                                break;
                            }
                        case 7: {
                                message.stringValue = reader.bytes();
                                break;
                            }
                        case 8: {
                                message.aggregateValue = reader.string();
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes an UninterpretedOption message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.protobuf.UninterpretedOption
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.protobuf.UninterpretedOption} UninterpretedOption
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                UninterpretedOption.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies an UninterpretedOption message.
                 * @function verify
                 * @memberof google.protobuf.UninterpretedOption
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                UninterpretedOption.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    if (message.name != null && message.hasOwnProperty("name")) {
                        if (!Array.isArray(message.name))
                            return "name: array expected";
                        for (var i = 0; i < message.name.length; ++i) {
                            var error = $root.google.protobuf.UninterpretedOption.NamePart.verify(message.name[i]);
                            if (error)
                                return "name." + error;
                        }
                    }
                    if (message.identifierValue != null && message.hasOwnProperty("identifierValue"))
                        if (!$util.isString(message.identifierValue))
                            return "identifierValue: string expected";
                    if (message.positiveIntValue != null && message.hasOwnProperty("positiveIntValue"))
                        if (!$util.isInteger(message.positiveIntValue) && !(message.positiveIntValue && $util.isInteger(message.positiveIntValue.low) && $util.isInteger(message.positiveIntValue.high)))
                            return "positiveIntValue: integer|Long expected";
                    if (message.negativeIntValue != null && message.hasOwnProperty("negativeIntValue"))
                        if (!$util.isInteger(message.negativeIntValue) && !(message.negativeIntValue && $util.isInteger(message.negativeIntValue.low) && $util.isInteger(message.negativeIntValue.high)))
                            return "negativeIntValue: integer|Long expected";
                    if (message.doubleValue != null && message.hasOwnProperty("doubleValue"))
                        if (typeof message.doubleValue !== "number")
                            return "doubleValue: number expected";
                    if (message.stringValue != null && message.hasOwnProperty("stringValue"))
                        if (!(message.stringValue && typeof message.stringValue.length === "number" || $util.isString(message.stringValue)))
                            return "stringValue: buffer expected";
                    if (message.aggregateValue != null && message.hasOwnProperty("aggregateValue"))
                        if (!$util.isString(message.aggregateValue))
                            return "aggregateValue: string expected";
                    return null;
                };
    
                /**
                 * Creates an UninterpretedOption message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.protobuf.UninterpretedOption
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.protobuf.UninterpretedOption} UninterpretedOption
                 */
                UninterpretedOption.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.protobuf.UninterpretedOption)
                        return object;
                    var message = new $root.google.protobuf.UninterpretedOption();
                    if (object.name) {
                        if (!Array.isArray(object.name))
                            throw TypeError(".google.protobuf.UninterpretedOption.name: array expected");
                        message.name = [];
                        for (var i = 0; i < object.name.length; ++i) {
                            if (typeof object.name[i] !== "object")
                                throw TypeError(".google.protobuf.UninterpretedOption.name: object expected");
                            message.name[i] = $root.google.protobuf.UninterpretedOption.NamePart.fromObject(object.name[i]);
                        }
                    }
                    if (object.identifierValue != null)
                        message.identifierValue = String(object.identifierValue);
                    if (object.positiveIntValue != null)
                        if ($util.Long)
                            (message.positiveIntValue = $util.Long.fromValue(object.positiveIntValue)).unsigned = true;
                        else if (typeof object.positiveIntValue === "string")
                            message.positiveIntValue = parseInt(object.positiveIntValue, 10);
                        else if (typeof object.positiveIntValue === "number")
                            message.positiveIntValue = object.positiveIntValue;
                        else if (typeof object.positiveIntValue === "object")
                            message.positiveIntValue = new $util.LongBits(object.positiveIntValue.low >>> 0, object.positiveIntValue.high >>> 0).toNumber(true);
                    if (object.negativeIntValue != null)
                        if ($util.Long)
                            (message.negativeIntValue = $util.Long.fromValue(object.negativeIntValue)).unsigned = false;
                        else if (typeof object.negativeIntValue === "string")
                            message.negativeIntValue = parseInt(object.negativeIntValue, 10);
                        else if (typeof object.negativeIntValue === "number")
                            message.negativeIntValue = object.negativeIntValue;
                        else if (typeof object.negativeIntValue === "object")
                            message.negativeIntValue = new $util.LongBits(object.negativeIntValue.low >>> 0, object.negativeIntValue.high >>> 0).toNumber();
                    if (object.doubleValue != null)
                        message.doubleValue = Number(object.doubleValue);
                    if (object.stringValue != null)
                        if (typeof object.stringValue === "string")
                            $util.base64.decode(object.stringValue, message.stringValue = $util.newBuffer($util.base64.length(object.stringValue)), 0);
                        else if (object.stringValue.length >= 0)
                            message.stringValue = object.stringValue;
                    if (object.aggregateValue != null)
                        message.aggregateValue = String(object.aggregateValue);
                    return message;
                };
    
                /**
                 * Creates a plain object from an UninterpretedOption message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.protobuf.UninterpretedOption
                 * @static
                 * @param {google.protobuf.UninterpretedOption} message UninterpretedOption
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                UninterpretedOption.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (options.arrays || options.defaults)
                        object.name = [];
                    if (options.defaults) {
                        object.identifierValue = "";
                        if ($util.Long) {
                            var long = new $util.Long(0, 0, true);
                            object.positiveIntValue = options.longs === String ? long.toString() : options.longs === Number ? long.toNumber() : long;
                        } else
                            object.positiveIntValue = options.longs === String ? "0" : 0;
                        if ($util.Long) {
                            var long = new $util.Long(0, 0, false);
                            object.negativeIntValue = options.longs === String ? long.toString() : options.longs === Number ? long.toNumber() : long;
                        } else
                            object.negativeIntValue = options.longs === String ? "0" : 0;
                        object.doubleValue = 0;
                        if (options.bytes === String)
                            object.stringValue = "";
                        else {
                            object.stringValue = [];
                            if (options.bytes !== Array)
                                object.stringValue = $util.newBuffer(object.stringValue);
                        }
                        object.aggregateValue = "";
                    }
                    if (message.name && message.name.length) {
                        object.name = [];
                        for (var j = 0; j < message.name.length; ++j)
                            object.name[j] = $root.google.protobuf.UninterpretedOption.NamePart.toObject(message.name[j], options);
                    }
                    if (message.identifierValue != null && message.hasOwnProperty("identifierValue"))
                        object.identifierValue = message.identifierValue;
                    if (message.positiveIntValue != null && message.hasOwnProperty("positiveIntValue"))
                        if (typeof message.positiveIntValue === "number")
                            object.positiveIntValue = options.longs === String ? String(message.positiveIntValue) : message.positiveIntValue;
                        else
                            object.positiveIntValue = options.longs === String ? $util.Long.prototype.toString.call(message.positiveIntValue) : options.longs === Number ? new $util.LongBits(message.positiveIntValue.low >>> 0, message.positiveIntValue.high >>> 0).toNumber(true) : message.positiveIntValue;
                    if (message.negativeIntValue != null && message.hasOwnProperty("negativeIntValue"))
                        if (typeof message.negativeIntValue === "number")
                            object.negativeIntValue = options.longs === String ? String(message.negativeIntValue) : message.negativeIntValue;
                        else
                            object.negativeIntValue = options.longs === String ? $util.Long.prototype.toString.call(message.negativeIntValue) : options.longs === Number ? new $util.LongBits(message.negativeIntValue.low >>> 0, message.negativeIntValue.high >>> 0).toNumber() : message.negativeIntValue;
                    if (message.doubleValue != null && message.hasOwnProperty("doubleValue"))
                        object.doubleValue = options.json && !isFinite(message.doubleValue) ? String(message.doubleValue) : message.doubleValue;
                    if (message.stringValue != null && message.hasOwnProperty("stringValue"))
                        object.stringValue = options.bytes === String ? $util.base64.encode(message.stringValue, 0, message.stringValue.length) : options.bytes === Array ? Array.prototype.slice.call(message.stringValue) : message.stringValue;
                    if (message.aggregateValue != null && message.hasOwnProperty("aggregateValue"))
                        object.aggregateValue = message.aggregateValue;
                    return object;
                };
    
                /**
                 * Converts this UninterpretedOption to JSON.
                 * @function toJSON
                 * @memberof google.protobuf.UninterpretedOption
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                UninterpretedOption.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for UninterpretedOption
                 * @function getTypeUrl
                 * @memberof google.protobuf.UninterpretedOption
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                UninterpretedOption.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.protobuf.UninterpretedOption";
                };
    
                UninterpretedOption.NamePart = (function() {
    
                    /**
                     * Properties of a NamePart.
                     * @memberof google.protobuf.UninterpretedOption
                     * @interface INamePart
                     * @property {string} namePart NamePart namePart
                     * @property {boolean} isExtension NamePart isExtension
                     */
    
                    /**
                     * Constructs a new NamePart.
                     * @memberof google.protobuf.UninterpretedOption
                     * @classdesc Represents a NamePart.
                     * @implements INamePart
                     * @constructor
                     * @param {google.protobuf.UninterpretedOption.INamePart=} [properties] Properties to set
                     */
                    function NamePart(properties) {
                        if (properties)
                            for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                if (properties[keys[i]] != null)
                                    this[keys[i]] = properties[keys[i]];
                    }
    
                    /**
                     * NamePart namePart.
                     * @member {string} namePart
                     * @memberof google.protobuf.UninterpretedOption.NamePart
                     * @instance
                     */
                    NamePart.prototype.namePart = "";
    
                    /**
                     * NamePart isExtension.
                     * @member {boolean} isExtension
                     * @memberof google.protobuf.UninterpretedOption.NamePart
                     * @instance
                     */
                    NamePart.prototype.isExtension = false;
    
                    /**
                     * Creates a new NamePart instance using the specified properties.
                     * @function create
                     * @memberof google.protobuf.UninterpretedOption.NamePart
                     * @static
                     * @param {google.protobuf.UninterpretedOption.INamePart=} [properties] Properties to set
                     * @returns {google.protobuf.UninterpretedOption.NamePart} NamePart instance
                     */
                    NamePart.create = function create(properties) {
                        return new NamePart(properties);
                    };
    
                    /**
                     * Encodes the specified NamePart message. Does not implicitly {@link google.protobuf.UninterpretedOption.NamePart.verify|verify} messages.
                     * @function encode
                     * @memberof google.protobuf.UninterpretedOption.NamePart
                     * @static
                     * @param {google.protobuf.UninterpretedOption.INamePart} message NamePart message or plain object to encode
                     * @param {$protobuf.Writer} [writer] Writer to encode to
                     * @returns {$protobuf.Writer} Writer
                     */
                    NamePart.encode = function encode(message, writer) {
                        if (!writer)
                            writer = $Writer.create();
                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.namePart);
                        writer.uint32(/* id 2, wireType 0 =*/16).bool(message.isExtension);
                        return writer;
                    };
    
                    /**
                     * Encodes the specified NamePart message, length delimited. Does not implicitly {@link google.protobuf.UninterpretedOption.NamePart.verify|verify} messages.
                     * @function encodeDelimited
                     * @memberof google.protobuf.UninterpretedOption.NamePart
                     * @static
                     * @param {google.protobuf.UninterpretedOption.INamePart} message NamePart message or plain object to encode
                     * @param {$protobuf.Writer} [writer] Writer to encode to
                     * @returns {$protobuf.Writer} Writer
                     */
                    NamePart.encodeDelimited = function encodeDelimited(message, writer) {
                        return this.encode(message, writer).ldelim();
                    };
    
                    /**
                     * Decodes a NamePart message from the specified reader or buffer.
                     * @function decode
                     * @memberof google.protobuf.UninterpretedOption.NamePart
                     * @static
                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                     * @param {number} [length] Message length if known beforehand
                     * @returns {google.protobuf.UninterpretedOption.NamePart} NamePart
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    NamePart.decode = function decode(reader, length) {
                        if (!(reader instanceof $Reader))
                            reader = $Reader.create(reader);
                        var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.protobuf.UninterpretedOption.NamePart();
                        while (reader.pos < end) {
                            var tag = reader.uint32();
                            switch (tag >>> 3) {
                            case 1: {
                                    message.namePart = reader.string();
                                    break;
                                }
                            case 2: {
                                    message.isExtension = reader.bool();
                                    break;
                                }
                            default:
                                reader.skipType(tag & 7);
                                break;
                            }
                        }
                        if (!message.hasOwnProperty("namePart"))
                            throw $util.ProtocolError("missing required 'namePart'", { instance: message });
                        if (!message.hasOwnProperty("isExtension"))
                            throw $util.ProtocolError("missing required 'isExtension'", { instance: message });
                        return message;
                    };
    
                    /**
                     * Decodes a NamePart message from the specified reader or buffer, length delimited.
                     * @function decodeDelimited
                     * @memberof google.protobuf.UninterpretedOption.NamePart
                     * @static
                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                     * @returns {google.protobuf.UninterpretedOption.NamePart} NamePart
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    NamePart.decodeDelimited = function decodeDelimited(reader) {
                        if (!(reader instanceof $Reader))
                            reader = new $Reader(reader);
                        return this.decode(reader, reader.uint32());
                    };
    
                    /**
                     * Verifies a NamePart message.
                     * @function verify
                     * @memberof google.protobuf.UninterpretedOption.NamePart
                     * @static
                     * @param {Object.<string,*>} message Plain object to verify
                     * @returns {string|null} `null` if valid, otherwise the reason why it is not
                     */
                    NamePart.verify = function verify(message) {
                        if (typeof message !== "object" || message === null)
                            return "object expected";
                        if (!$util.isString(message.namePart))
                            return "namePart: string expected";
                        if (typeof message.isExtension !== "boolean")
                            return "isExtension: boolean expected";
                        return null;
                    };
    
                    /**
                     * Creates a NamePart message from a plain object. Also converts values to their respective internal types.
                     * @function fromObject
                     * @memberof google.protobuf.UninterpretedOption.NamePart
                     * @static
                     * @param {Object.<string,*>} object Plain object
                     * @returns {google.protobuf.UninterpretedOption.NamePart} NamePart
                     */
                    NamePart.fromObject = function fromObject(object) {
                        if (object instanceof $root.google.protobuf.UninterpretedOption.NamePart)
                            return object;
                        var message = new $root.google.protobuf.UninterpretedOption.NamePart();
                        if (object.namePart != null)
                            message.namePart = String(object.namePart);
                        if (object.isExtension != null)
                            message.isExtension = Boolean(object.isExtension);
                        return message;
                    };
    
                    /**
                     * Creates a plain object from a NamePart message. Also converts values to other types if specified.
                     * @function toObject
                     * @memberof google.protobuf.UninterpretedOption.NamePart
                     * @static
                     * @param {google.protobuf.UninterpretedOption.NamePart} message NamePart
                     * @param {$protobuf.IConversionOptions} [options] Conversion options
                     * @returns {Object.<string,*>} Plain object
                     */
                    NamePart.toObject = function toObject(message, options) {
                        if (!options)
                            options = {};
                        var object = {};
                        if (options.defaults) {
                            object.namePart = "";
                            object.isExtension = false;
                        }
                        if (message.namePart != null && message.hasOwnProperty("namePart"))
                            object.namePart = message.namePart;
                        if (message.isExtension != null && message.hasOwnProperty("isExtension"))
                            object.isExtension = message.isExtension;
                        return object;
                    };
    
                    /**
                     * Converts this NamePart to JSON.
                     * @function toJSON
                     * @memberof google.protobuf.UninterpretedOption.NamePart
                     * @instance
                     * @returns {Object.<string,*>} JSON object
                     */
                    NamePart.prototype.toJSON = function toJSON() {
                        return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                    };
    
                    /**
                     * Gets the default type url for NamePart
                     * @function getTypeUrl
                     * @memberof google.protobuf.UninterpretedOption.NamePart
                     * @static
                     * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns {string} The default type url
                     */
                    NamePart.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                        if (typeUrlPrefix === undefined) {
                            typeUrlPrefix = "type.googleapis.com";
                        }
                        return typeUrlPrefix + "/google.protobuf.UninterpretedOption.NamePart";
                    };
    
                    return NamePart;
                })();
    
                return UninterpretedOption;
            })();
    
            protobuf.FeatureSet = (function() {
    
                /**
                 * Properties of a FeatureSet.
                 * @memberof google.protobuf
                 * @interface IFeatureSet
                 * @property {google.protobuf.FeatureSet.FieldPresence|null} [fieldPresence] FeatureSet fieldPresence
                 * @property {google.protobuf.FeatureSet.EnumType|null} [enumType] FeatureSet enumType
                 * @property {google.protobuf.FeatureSet.RepeatedFieldEncoding|null} [repeatedFieldEncoding] FeatureSet repeatedFieldEncoding
                 * @property {google.protobuf.FeatureSet.Utf8Validation|null} [utf8Validation] FeatureSet utf8Validation
                 * @property {google.protobuf.FeatureSet.MessageEncoding|null} [messageEncoding] FeatureSet messageEncoding
                 * @property {google.protobuf.FeatureSet.JsonFormat|null} [jsonFormat] FeatureSet jsonFormat
                 */
    
                /**
                 * Constructs a new FeatureSet.
                 * @memberof google.protobuf
                 * @classdesc Represents a FeatureSet.
                 * @implements IFeatureSet
                 * @constructor
                 * @param {google.protobuf.IFeatureSet=} [properties] Properties to set
                 */
                function FeatureSet(properties) {
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * FeatureSet fieldPresence.
                 * @member {google.protobuf.FeatureSet.FieldPresence} fieldPresence
                 * @memberof google.protobuf.FeatureSet
                 * @instance
                 */
                FeatureSet.prototype.fieldPresence = 0;
    
                /**
                 * FeatureSet enumType.
                 * @member {google.protobuf.FeatureSet.EnumType} enumType
                 * @memberof google.protobuf.FeatureSet
                 * @instance
                 */
                FeatureSet.prototype.enumType = 0;
    
                /**
                 * FeatureSet repeatedFieldEncoding.
                 * @member {google.protobuf.FeatureSet.RepeatedFieldEncoding} repeatedFieldEncoding
                 * @memberof google.protobuf.FeatureSet
                 * @instance
                 */
                FeatureSet.prototype.repeatedFieldEncoding = 0;
    
                /**
                 * FeatureSet utf8Validation.
                 * @member {google.protobuf.FeatureSet.Utf8Validation} utf8Validation
                 * @memberof google.protobuf.FeatureSet
                 * @instance
                 */
                FeatureSet.prototype.utf8Validation = 0;
    
                /**
                 * FeatureSet messageEncoding.
                 * @member {google.protobuf.FeatureSet.MessageEncoding} messageEncoding
                 * @memberof google.protobuf.FeatureSet
                 * @instance
                 */
                FeatureSet.prototype.messageEncoding = 0;
    
                /**
                 * FeatureSet jsonFormat.
                 * @member {google.protobuf.FeatureSet.JsonFormat} jsonFormat
                 * @memberof google.protobuf.FeatureSet
                 * @instance
                 */
                FeatureSet.prototype.jsonFormat = 0;
    
                /**
                 * Creates a new FeatureSet instance using the specified properties.
                 * @function create
                 * @memberof google.protobuf.FeatureSet
                 * @static
                 * @param {google.protobuf.IFeatureSet=} [properties] Properties to set
                 * @returns {google.protobuf.FeatureSet} FeatureSet instance
                 */
                FeatureSet.create = function create(properties) {
                    return new FeatureSet(properties);
                };
    
                /**
                 * Encodes the specified FeatureSet message. Does not implicitly {@link google.protobuf.FeatureSet.verify|verify} messages.
                 * @function encode
                 * @memberof google.protobuf.FeatureSet
                 * @static
                 * @param {google.protobuf.IFeatureSet} message FeatureSet message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                FeatureSet.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.fieldPresence != null && Object.hasOwnProperty.call(message, "fieldPresence"))
                        writer.uint32(/* id 1, wireType 0 =*/8).int32(message.fieldPresence);
                    if (message.enumType != null && Object.hasOwnProperty.call(message, "enumType"))
                        writer.uint32(/* id 2, wireType 0 =*/16).int32(message.enumType);
                    if (message.repeatedFieldEncoding != null && Object.hasOwnProperty.call(message, "repeatedFieldEncoding"))
                        writer.uint32(/* id 3, wireType 0 =*/24).int32(message.repeatedFieldEncoding);
                    if (message.utf8Validation != null && Object.hasOwnProperty.call(message, "utf8Validation"))
                        writer.uint32(/* id 4, wireType 0 =*/32).int32(message.utf8Validation);
                    if (message.messageEncoding != null && Object.hasOwnProperty.call(message, "messageEncoding"))
                        writer.uint32(/* id 5, wireType 0 =*/40).int32(message.messageEncoding);
                    if (message.jsonFormat != null && Object.hasOwnProperty.call(message, "jsonFormat"))
                        writer.uint32(/* id 6, wireType 0 =*/48).int32(message.jsonFormat);
                    return writer;
                };
    
                /**
                 * Encodes the specified FeatureSet message, length delimited. Does not implicitly {@link google.protobuf.FeatureSet.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.protobuf.FeatureSet
                 * @static
                 * @param {google.protobuf.IFeatureSet} message FeatureSet message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                FeatureSet.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes a FeatureSet message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.protobuf.FeatureSet
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.protobuf.FeatureSet} FeatureSet
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                FeatureSet.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.protobuf.FeatureSet();
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 1: {
                                message.fieldPresence = reader.int32();
                                break;
                            }
                        case 2: {
                                message.enumType = reader.int32();
                                break;
                            }
                        case 3: {
                                message.repeatedFieldEncoding = reader.int32();
                                break;
                            }
                        case 4: {
                                message.utf8Validation = reader.int32();
                                break;
                            }
                        case 5: {
                                message.messageEncoding = reader.int32();
                                break;
                            }
                        case 6: {
                                message.jsonFormat = reader.int32();
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes a FeatureSet message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.protobuf.FeatureSet
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.protobuf.FeatureSet} FeatureSet
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                FeatureSet.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies a FeatureSet message.
                 * @function verify
                 * @memberof google.protobuf.FeatureSet
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                FeatureSet.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    if (message.fieldPresence != null && message.hasOwnProperty("fieldPresence"))
                        switch (message.fieldPresence) {
                        default:
                            return "fieldPresence: enum value expected";
                        case 0:
                        case 1:
                        case 2:
                        case 3:
                            break;
                        }
                    if (message.enumType != null && message.hasOwnProperty("enumType"))
                        switch (message.enumType) {
                        default:
                            return "enumType: enum value expected";
                        case 0:
                        case 1:
                        case 2:
                            break;
                        }
                    if (message.repeatedFieldEncoding != null && message.hasOwnProperty("repeatedFieldEncoding"))
                        switch (message.repeatedFieldEncoding) {
                        default:
                            return "repeatedFieldEncoding: enum value expected";
                        case 0:
                        case 1:
                        case 2:
                            break;
                        }
                    if (message.utf8Validation != null && message.hasOwnProperty("utf8Validation"))
                        switch (message.utf8Validation) {
                        default:
                            return "utf8Validation: enum value expected";
                        case 0:
                        case 2:
                        case 3:
                            break;
                        }
                    if (message.messageEncoding != null && message.hasOwnProperty("messageEncoding"))
                        switch (message.messageEncoding) {
                        default:
                            return "messageEncoding: enum value expected";
                        case 0:
                        case 1:
                        case 2:
                            break;
                        }
                    if (message.jsonFormat != null && message.hasOwnProperty("jsonFormat"))
                        switch (message.jsonFormat) {
                        default:
                            return "jsonFormat: enum value expected";
                        case 0:
                        case 1:
                        case 2:
                            break;
                        }
                    return null;
                };
    
                /**
                 * Creates a FeatureSet message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.protobuf.FeatureSet
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.protobuf.FeatureSet} FeatureSet
                 */
                FeatureSet.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.protobuf.FeatureSet)
                        return object;
                    var message = new $root.google.protobuf.FeatureSet();
                    switch (object.fieldPresence) {
                    default:
                        if (typeof object.fieldPresence === "number") {
                            message.fieldPresence = object.fieldPresence;
                            break;
                        }
                        break;
                    case "FIELD_PRESENCE_UNKNOWN":
                    case 0:
                        message.fieldPresence = 0;
                        break;
                    case "EXPLICIT":
                    case 1:
                        message.fieldPresence = 1;
                        break;
                    case "IMPLICIT":
                    case 2:
                        message.fieldPresence = 2;
                        break;
                    case "LEGACY_REQUIRED":
                    case 3:
                        message.fieldPresence = 3;
                        break;
                    }
                    switch (object.enumType) {
                    default:
                        if (typeof object.enumType === "number") {
                            message.enumType = object.enumType;
                            break;
                        }
                        break;
                    case "ENUM_TYPE_UNKNOWN":
                    case 0:
                        message.enumType = 0;
                        break;
                    case "OPEN":
                    case 1:
                        message.enumType = 1;
                        break;
                    case "CLOSED":
                    case 2:
                        message.enumType = 2;
                        break;
                    }
                    switch (object.repeatedFieldEncoding) {
                    default:
                        if (typeof object.repeatedFieldEncoding === "number") {
                            message.repeatedFieldEncoding = object.repeatedFieldEncoding;
                            break;
                        }
                        break;
                    case "REPEATED_FIELD_ENCODING_UNKNOWN":
                    case 0:
                        message.repeatedFieldEncoding = 0;
                        break;
                    case "PACKED":
                    case 1:
                        message.repeatedFieldEncoding = 1;
                        break;
                    case "EXPANDED":
                    case 2:
                        message.repeatedFieldEncoding = 2;
                        break;
                    }
                    switch (object.utf8Validation) {
                    default:
                        if (typeof object.utf8Validation === "number") {
                            message.utf8Validation = object.utf8Validation;
                            break;
                        }
                        break;
                    case "UTF8_VALIDATION_UNKNOWN":
                    case 0:
                        message.utf8Validation = 0;
                        break;
                    case "VERIFY":
                    case 2:
                        message.utf8Validation = 2;
                        break;
                    case "NONE":
                    case 3:
                        message.utf8Validation = 3;
                        break;
                    }
                    switch (object.messageEncoding) {
                    default:
                        if (typeof object.messageEncoding === "number") {
                            message.messageEncoding = object.messageEncoding;
                            break;
                        }
                        break;
                    case "MESSAGE_ENCODING_UNKNOWN":
                    case 0:
                        message.messageEncoding = 0;
                        break;
                    case "LENGTH_PREFIXED":
                    case 1:
                        message.messageEncoding = 1;
                        break;
                    case "DELIMITED":
                    case 2:
                        message.messageEncoding = 2;
                        break;
                    }
                    switch (object.jsonFormat) {
                    default:
                        if (typeof object.jsonFormat === "number") {
                            message.jsonFormat = object.jsonFormat;
                            break;
                        }
                        break;
                    case "JSON_FORMAT_UNKNOWN":
                    case 0:
                        message.jsonFormat = 0;
                        break;
                    case "ALLOW":
                    case 1:
                        message.jsonFormat = 1;
                        break;
                    case "LEGACY_BEST_EFFORT":
                    case 2:
                        message.jsonFormat = 2;
                        break;
                    }
                    return message;
                };
    
                /**
                 * Creates a plain object from a FeatureSet message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.protobuf.FeatureSet
                 * @static
                 * @param {google.protobuf.FeatureSet} message FeatureSet
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                FeatureSet.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (options.defaults) {
                        object.fieldPresence = options.enums === String ? "FIELD_PRESENCE_UNKNOWN" : 0;
                        object.enumType = options.enums === String ? "ENUM_TYPE_UNKNOWN" : 0;
                        object.repeatedFieldEncoding = options.enums === String ? "REPEATED_FIELD_ENCODING_UNKNOWN" : 0;
                        object.utf8Validation = options.enums === String ? "UTF8_VALIDATION_UNKNOWN" : 0;
                        object.messageEncoding = options.enums === String ? "MESSAGE_ENCODING_UNKNOWN" : 0;
                        object.jsonFormat = options.enums === String ? "JSON_FORMAT_UNKNOWN" : 0;
                    }
                    if (message.fieldPresence != null && message.hasOwnProperty("fieldPresence"))
                        object.fieldPresence = options.enums === String ? $root.google.protobuf.FeatureSet.FieldPresence[message.fieldPresence] === undefined ? message.fieldPresence : $root.google.protobuf.FeatureSet.FieldPresence[message.fieldPresence] : message.fieldPresence;
                    if (message.enumType != null && message.hasOwnProperty("enumType"))
                        object.enumType = options.enums === String ? $root.google.protobuf.FeatureSet.EnumType[message.enumType] === undefined ? message.enumType : $root.google.protobuf.FeatureSet.EnumType[message.enumType] : message.enumType;
                    if (message.repeatedFieldEncoding != null && message.hasOwnProperty("repeatedFieldEncoding"))
                        object.repeatedFieldEncoding = options.enums === String ? $root.google.protobuf.FeatureSet.RepeatedFieldEncoding[message.repeatedFieldEncoding] === undefined ? message.repeatedFieldEncoding : $root.google.protobuf.FeatureSet.RepeatedFieldEncoding[message.repeatedFieldEncoding] : message.repeatedFieldEncoding;
                    if (message.utf8Validation != null && message.hasOwnProperty("utf8Validation"))
                        object.utf8Validation = options.enums === String ? $root.google.protobuf.FeatureSet.Utf8Validation[message.utf8Validation] === undefined ? message.utf8Validation : $root.google.protobuf.FeatureSet.Utf8Validation[message.utf8Validation] : message.utf8Validation;
                    if (message.messageEncoding != null && message.hasOwnProperty("messageEncoding"))
                        object.messageEncoding = options.enums === String ? $root.google.protobuf.FeatureSet.MessageEncoding[message.messageEncoding] === undefined ? message.messageEncoding : $root.google.protobuf.FeatureSet.MessageEncoding[message.messageEncoding] : message.messageEncoding;
                    if (message.jsonFormat != null && message.hasOwnProperty("jsonFormat"))
                        object.jsonFormat = options.enums === String ? $root.google.protobuf.FeatureSet.JsonFormat[message.jsonFormat] === undefined ? message.jsonFormat : $root.google.protobuf.FeatureSet.JsonFormat[message.jsonFormat] : message.jsonFormat;
                    return object;
                };
    
                /**
                 * Converts this FeatureSet to JSON.
                 * @function toJSON
                 * @memberof google.protobuf.FeatureSet
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                FeatureSet.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for FeatureSet
                 * @function getTypeUrl
                 * @memberof google.protobuf.FeatureSet
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                FeatureSet.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.protobuf.FeatureSet";
                };
    
                /**
                 * FieldPresence enum.
                 * @name google.protobuf.FeatureSet.FieldPresence
                 * @enum {number}
                 * @property {number} FIELD_PRESENCE_UNKNOWN=0 FIELD_PRESENCE_UNKNOWN value
                 * @property {number} EXPLICIT=1 EXPLICIT value
                 * @property {number} IMPLICIT=2 IMPLICIT value
                 * @property {number} LEGACY_REQUIRED=3 LEGACY_REQUIRED value
                 */
                FeatureSet.FieldPresence = (function() {
                    var valuesById = {}, values = Object.create(valuesById);
                    values[valuesById[0] = "FIELD_PRESENCE_UNKNOWN"] = 0;
                    values[valuesById[1] = "EXPLICIT"] = 1;
                    values[valuesById[2] = "IMPLICIT"] = 2;
                    values[valuesById[3] = "LEGACY_REQUIRED"] = 3;
                    return values;
                })();
    
                /**
                 * EnumType enum.
                 * @name google.protobuf.FeatureSet.EnumType
                 * @enum {number}
                 * @property {number} ENUM_TYPE_UNKNOWN=0 ENUM_TYPE_UNKNOWN value
                 * @property {number} OPEN=1 OPEN value
                 * @property {number} CLOSED=2 CLOSED value
                 */
                FeatureSet.EnumType = (function() {
                    var valuesById = {}, values = Object.create(valuesById);
                    values[valuesById[0] = "ENUM_TYPE_UNKNOWN"] = 0;
                    values[valuesById[1] = "OPEN"] = 1;
                    values[valuesById[2] = "CLOSED"] = 2;
                    return values;
                })();
    
                /**
                 * RepeatedFieldEncoding enum.
                 * @name google.protobuf.FeatureSet.RepeatedFieldEncoding
                 * @enum {number}
                 * @property {number} REPEATED_FIELD_ENCODING_UNKNOWN=0 REPEATED_FIELD_ENCODING_UNKNOWN value
                 * @property {number} PACKED=1 PACKED value
                 * @property {number} EXPANDED=2 EXPANDED value
                 */
                FeatureSet.RepeatedFieldEncoding = (function() {
                    var valuesById = {}, values = Object.create(valuesById);
                    values[valuesById[0] = "REPEATED_FIELD_ENCODING_UNKNOWN"] = 0;
                    values[valuesById[1] = "PACKED"] = 1;
                    values[valuesById[2] = "EXPANDED"] = 2;
                    return values;
                })();
    
                /**
                 * Utf8Validation enum.
                 * @name google.protobuf.FeatureSet.Utf8Validation
                 * @enum {number}
                 * @property {number} UTF8_VALIDATION_UNKNOWN=0 UTF8_VALIDATION_UNKNOWN value
                 * @property {number} VERIFY=2 VERIFY value
                 * @property {number} NONE=3 NONE value
                 */
                FeatureSet.Utf8Validation = (function() {
                    var valuesById = {}, values = Object.create(valuesById);
                    values[valuesById[0] = "UTF8_VALIDATION_UNKNOWN"] = 0;
                    values[valuesById[2] = "VERIFY"] = 2;
                    values[valuesById[3] = "NONE"] = 3;
                    return values;
                })();
    
                /**
                 * MessageEncoding enum.
                 * @name google.protobuf.FeatureSet.MessageEncoding
                 * @enum {number}
                 * @property {number} MESSAGE_ENCODING_UNKNOWN=0 MESSAGE_ENCODING_UNKNOWN value
                 * @property {number} LENGTH_PREFIXED=1 LENGTH_PREFIXED value
                 * @property {number} DELIMITED=2 DELIMITED value
                 */
                FeatureSet.MessageEncoding = (function() {
                    var valuesById = {}, values = Object.create(valuesById);
                    values[valuesById[0] = "MESSAGE_ENCODING_UNKNOWN"] = 0;
                    values[valuesById[1] = "LENGTH_PREFIXED"] = 1;
                    values[valuesById[2] = "DELIMITED"] = 2;
                    return values;
                })();
    
                /**
                 * JsonFormat enum.
                 * @name google.protobuf.FeatureSet.JsonFormat
                 * @enum {number}
                 * @property {number} JSON_FORMAT_UNKNOWN=0 JSON_FORMAT_UNKNOWN value
                 * @property {number} ALLOW=1 ALLOW value
                 * @property {number} LEGACY_BEST_EFFORT=2 LEGACY_BEST_EFFORT value
                 */
                FeatureSet.JsonFormat = (function() {
                    var valuesById = {}, values = Object.create(valuesById);
                    values[valuesById[0] = "JSON_FORMAT_UNKNOWN"] = 0;
                    values[valuesById[1] = "ALLOW"] = 1;
                    values[valuesById[2] = "LEGACY_BEST_EFFORT"] = 2;
                    return values;
                })();
    
                return FeatureSet;
            })();
    
            protobuf.FeatureSetDefaults = (function() {
    
                /**
                 * Properties of a FeatureSetDefaults.
                 * @memberof google.protobuf
                 * @interface IFeatureSetDefaults
                 * @property {Array.<google.protobuf.FeatureSetDefaults.IFeatureSetEditionDefault>|null} [defaults] FeatureSetDefaults defaults
                 * @property {google.protobuf.Edition|null} [minimumEdition] FeatureSetDefaults minimumEdition
                 * @property {google.protobuf.Edition|null} [maximumEdition] FeatureSetDefaults maximumEdition
                 */
    
                /**
                 * Constructs a new FeatureSetDefaults.
                 * @memberof google.protobuf
                 * @classdesc Represents a FeatureSetDefaults.
                 * @implements IFeatureSetDefaults
                 * @constructor
                 * @param {google.protobuf.IFeatureSetDefaults=} [properties] Properties to set
                 */
                function FeatureSetDefaults(properties) {
                    this.defaults = [];
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * FeatureSetDefaults defaults.
                 * @member {Array.<google.protobuf.FeatureSetDefaults.IFeatureSetEditionDefault>} defaults
                 * @memberof google.protobuf.FeatureSetDefaults
                 * @instance
                 */
                FeatureSetDefaults.prototype.defaults = $util.emptyArray;
    
                /**
                 * FeatureSetDefaults minimumEdition.
                 * @member {google.protobuf.Edition} minimumEdition
                 * @memberof google.protobuf.FeatureSetDefaults
                 * @instance
                 */
                FeatureSetDefaults.prototype.minimumEdition = 0;
    
                /**
                 * FeatureSetDefaults maximumEdition.
                 * @member {google.protobuf.Edition} maximumEdition
                 * @memberof google.protobuf.FeatureSetDefaults
                 * @instance
                 */
                FeatureSetDefaults.prototype.maximumEdition = 0;
    
                /**
                 * Creates a new FeatureSetDefaults instance using the specified properties.
                 * @function create
                 * @memberof google.protobuf.FeatureSetDefaults
                 * @static
                 * @param {google.protobuf.IFeatureSetDefaults=} [properties] Properties to set
                 * @returns {google.protobuf.FeatureSetDefaults} FeatureSetDefaults instance
                 */
                FeatureSetDefaults.create = function create(properties) {
                    return new FeatureSetDefaults(properties);
                };
    
                /**
                 * Encodes the specified FeatureSetDefaults message. Does not implicitly {@link google.protobuf.FeatureSetDefaults.verify|verify} messages.
                 * @function encode
                 * @memberof google.protobuf.FeatureSetDefaults
                 * @static
                 * @param {google.protobuf.IFeatureSetDefaults} message FeatureSetDefaults message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                FeatureSetDefaults.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.defaults != null && message.defaults.length)
                        for (var i = 0; i < message.defaults.length; ++i)
                            $root.google.protobuf.FeatureSetDefaults.FeatureSetEditionDefault.encode(message.defaults[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                    if (message.minimumEdition != null && Object.hasOwnProperty.call(message, "minimumEdition"))
                        writer.uint32(/* id 4, wireType 0 =*/32).int32(message.minimumEdition);
                    if (message.maximumEdition != null && Object.hasOwnProperty.call(message, "maximumEdition"))
                        writer.uint32(/* id 5, wireType 0 =*/40).int32(message.maximumEdition);
                    return writer;
                };
    
                /**
                 * Encodes the specified FeatureSetDefaults message, length delimited. Does not implicitly {@link google.protobuf.FeatureSetDefaults.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.protobuf.FeatureSetDefaults
                 * @static
                 * @param {google.protobuf.IFeatureSetDefaults} message FeatureSetDefaults message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                FeatureSetDefaults.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes a FeatureSetDefaults message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.protobuf.FeatureSetDefaults
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.protobuf.FeatureSetDefaults} FeatureSetDefaults
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                FeatureSetDefaults.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.protobuf.FeatureSetDefaults();
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 1: {
                                if (!(message.defaults && message.defaults.length))
                                    message.defaults = [];
                                message.defaults.push($root.google.protobuf.FeatureSetDefaults.FeatureSetEditionDefault.decode(reader, reader.uint32()));
                                break;
                            }
                        case 4: {
                                message.minimumEdition = reader.int32();
                                break;
                            }
                        case 5: {
                                message.maximumEdition = reader.int32();
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes a FeatureSetDefaults message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.protobuf.FeatureSetDefaults
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.protobuf.FeatureSetDefaults} FeatureSetDefaults
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                FeatureSetDefaults.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies a FeatureSetDefaults message.
                 * @function verify
                 * @memberof google.protobuf.FeatureSetDefaults
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                FeatureSetDefaults.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    if (message.defaults != null && message.hasOwnProperty("defaults")) {
                        if (!Array.isArray(message.defaults))
                            return "defaults: array expected";
                        for (var i = 0; i < message.defaults.length; ++i) {
                            var error = $root.google.protobuf.FeatureSetDefaults.FeatureSetEditionDefault.verify(message.defaults[i]);
                            if (error)
                                return "defaults." + error;
                        }
                    }
                    if (message.minimumEdition != null && message.hasOwnProperty("minimumEdition"))
                        switch (message.minimumEdition) {
                        default:
                            return "minimumEdition: enum value expected";
                        case 0:
                        case 998:
                        case 999:
                        case 1000:
                        case 1001:
                        case 1:
                        case 2:
                        case 99997:
                        case 99998:
                        case 99999:
                        case 2147483647:
                            break;
                        }
                    if (message.maximumEdition != null && message.hasOwnProperty("maximumEdition"))
                        switch (message.maximumEdition) {
                        default:
                            return "maximumEdition: enum value expected";
                        case 0:
                        case 998:
                        case 999:
                        case 1000:
                        case 1001:
                        case 1:
                        case 2:
                        case 99997:
                        case 99998:
                        case 99999:
                        case 2147483647:
                            break;
                        }
                    return null;
                };
    
                /**
                 * Creates a FeatureSetDefaults message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.protobuf.FeatureSetDefaults
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.protobuf.FeatureSetDefaults} FeatureSetDefaults
                 */
                FeatureSetDefaults.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.protobuf.FeatureSetDefaults)
                        return object;
                    var message = new $root.google.protobuf.FeatureSetDefaults();
                    if (object.defaults) {
                        if (!Array.isArray(object.defaults))
                            throw TypeError(".google.protobuf.FeatureSetDefaults.defaults: array expected");
                        message.defaults = [];
                        for (var i = 0; i < object.defaults.length; ++i) {
                            if (typeof object.defaults[i] !== "object")
                                throw TypeError(".google.protobuf.FeatureSetDefaults.defaults: object expected");
                            message.defaults[i] = $root.google.protobuf.FeatureSetDefaults.FeatureSetEditionDefault.fromObject(object.defaults[i]);
                        }
                    }
                    switch (object.minimumEdition) {
                    default:
                        if (typeof object.minimumEdition === "number") {
                            message.minimumEdition = object.minimumEdition;
                            break;
                        }
                        break;
                    case "EDITION_UNKNOWN":
                    case 0:
                        message.minimumEdition = 0;
                        break;
                    case "EDITION_PROTO2":
                    case 998:
                        message.minimumEdition = 998;
                        break;
                    case "EDITION_PROTO3":
                    case 999:
                        message.minimumEdition = 999;
                        break;
                    case "EDITION_2023":
                    case 1000:
                        message.minimumEdition = 1000;
                        break;
                    case "EDITION_2024":
                    case 1001:
                        message.minimumEdition = 1001;
                        break;
                    case "EDITION_1_TEST_ONLY":
                    case 1:
                        message.minimumEdition = 1;
                        break;
                    case "EDITION_2_TEST_ONLY":
                    case 2:
                        message.minimumEdition = 2;
                        break;
                    case "EDITION_99997_TEST_ONLY":
                    case 99997:
                        message.minimumEdition = 99997;
                        break;
                    case "EDITION_99998_TEST_ONLY":
                    case 99998:
                        message.minimumEdition = 99998;
                        break;
                    case "EDITION_99999_TEST_ONLY":
                    case 99999:
                        message.minimumEdition = 99999;
                        break;
                    case "EDITION_MAX":
                    case 2147483647:
                        message.minimumEdition = 2147483647;
                        break;
                    }
                    switch (object.maximumEdition) {
                    default:
                        if (typeof object.maximumEdition === "number") {
                            message.maximumEdition = object.maximumEdition;
                            break;
                        }
                        break;
                    case "EDITION_UNKNOWN":
                    case 0:
                        message.maximumEdition = 0;
                        break;
                    case "EDITION_PROTO2":
                    case 998:
                        message.maximumEdition = 998;
                        break;
                    case "EDITION_PROTO3":
                    case 999:
                        message.maximumEdition = 999;
                        break;
                    case "EDITION_2023":
                    case 1000:
                        message.maximumEdition = 1000;
                        break;
                    case "EDITION_2024":
                    case 1001:
                        message.maximumEdition = 1001;
                        break;
                    case "EDITION_1_TEST_ONLY":
                    case 1:
                        message.maximumEdition = 1;
                        break;
                    case "EDITION_2_TEST_ONLY":
                    case 2:
                        message.maximumEdition = 2;
                        break;
                    case "EDITION_99997_TEST_ONLY":
                    case 99997:
                        message.maximumEdition = 99997;
                        break;
                    case "EDITION_99998_TEST_ONLY":
                    case 99998:
                        message.maximumEdition = 99998;
                        break;
                    case "EDITION_99999_TEST_ONLY":
                    case 99999:
                        message.maximumEdition = 99999;
                        break;
                    case "EDITION_MAX":
                    case 2147483647:
                        message.maximumEdition = 2147483647;
                        break;
                    }
                    return message;
                };
    
                /**
                 * Creates a plain object from a FeatureSetDefaults message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.protobuf.FeatureSetDefaults
                 * @static
                 * @param {google.protobuf.FeatureSetDefaults} message FeatureSetDefaults
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                FeatureSetDefaults.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (options.arrays || options.defaults)
                        object.defaults = [];
                    if (options.defaults) {
                        object.minimumEdition = options.enums === String ? "EDITION_UNKNOWN" : 0;
                        object.maximumEdition = options.enums === String ? "EDITION_UNKNOWN" : 0;
                    }
                    if (message.defaults && message.defaults.length) {
                        object.defaults = [];
                        for (var j = 0; j < message.defaults.length; ++j)
                            object.defaults[j] = $root.google.protobuf.FeatureSetDefaults.FeatureSetEditionDefault.toObject(message.defaults[j], options);
                    }
                    if (message.minimumEdition != null && message.hasOwnProperty("minimumEdition"))
                        object.minimumEdition = options.enums === String ? $root.google.protobuf.Edition[message.minimumEdition] === undefined ? message.minimumEdition : $root.google.protobuf.Edition[message.minimumEdition] : message.minimumEdition;
                    if (message.maximumEdition != null && message.hasOwnProperty("maximumEdition"))
                        object.maximumEdition = options.enums === String ? $root.google.protobuf.Edition[message.maximumEdition] === undefined ? message.maximumEdition : $root.google.protobuf.Edition[message.maximumEdition] : message.maximumEdition;
                    return object;
                };
    
                /**
                 * Converts this FeatureSetDefaults to JSON.
                 * @function toJSON
                 * @memberof google.protobuf.FeatureSetDefaults
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                FeatureSetDefaults.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for FeatureSetDefaults
                 * @function getTypeUrl
                 * @memberof google.protobuf.FeatureSetDefaults
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                FeatureSetDefaults.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.protobuf.FeatureSetDefaults";
                };
    
                FeatureSetDefaults.FeatureSetEditionDefault = (function() {
    
                    /**
                     * Properties of a FeatureSetEditionDefault.
                     * @memberof google.protobuf.FeatureSetDefaults
                     * @interface IFeatureSetEditionDefault
                     * @property {google.protobuf.Edition|null} [edition] FeatureSetEditionDefault edition
                     * @property {google.protobuf.IFeatureSet|null} [features] FeatureSetEditionDefault features
                     */
    
                    /**
                     * Constructs a new FeatureSetEditionDefault.
                     * @memberof google.protobuf.FeatureSetDefaults
                     * @classdesc Represents a FeatureSetEditionDefault.
                     * @implements IFeatureSetEditionDefault
                     * @constructor
                     * @param {google.protobuf.FeatureSetDefaults.IFeatureSetEditionDefault=} [properties] Properties to set
                     */
                    function FeatureSetEditionDefault(properties) {
                        if (properties)
                            for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                if (properties[keys[i]] != null)
                                    this[keys[i]] = properties[keys[i]];
                    }
    
                    /**
                     * FeatureSetEditionDefault edition.
                     * @member {google.protobuf.Edition} edition
                     * @memberof google.protobuf.FeatureSetDefaults.FeatureSetEditionDefault
                     * @instance
                     */
                    FeatureSetEditionDefault.prototype.edition = 0;
    
                    /**
                     * FeatureSetEditionDefault features.
                     * @member {google.protobuf.IFeatureSet|null|undefined} features
                     * @memberof google.protobuf.FeatureSetDefaults.FeatureSetEditionDefault
                     * @instance
                     */
                    FeatureSetEditionDefault.prototype.features = null;
    
                    /**
                     * Creates a new FeatureSetEditionDefault instance using the specified properties.
                     * @function create
                     * @memberof google.protobuf.FeatureSetDefaults.FeatureSetEditionDefault
                     * @static
                     * @param {google.protobuf.FeatureSetDefaults.IFeatureSetEditionDefault=} [properties] Properties to set
                     * @returns {google.protobuf.FeatureSetDefaults.FeatureSetEditionDefault} FeatureSetEditionDefault instance
                     */
                    FeatureSetEditionDefault.create = function create(properties) {
                        return new FeatureSetEditionDefault(properties);
                    };
    
                    /**
                     * Encodes the specified FeatureSetEditionDefault message. Does not implicitly {@link google.protobuf.FeatureSetDefaults.FeatureSetEditionDefault.verify|verify} messages.
                     * @function encode
                     * @memberof google.protobuf.FeatureSetDefaults.FeatureSetEditionDefault
                     * @static
                     * @param {google.protobuf.FeatureSetDefaults.IFeatureSetEditionDefault} message FeatureSetEditionDefault message or plain object to encode
                     * @param {$protobuf.Writer} [writer] Writer to encode to
                     * @returns {$protobuf.Writer} Writer
                     */
                    FeatureSetEditionDefault.encode = function encode(message, writer) {
                        if (!writer)
                            writer = $Writer.create();
                        if (message.features != null && Object.hasOwnProperty.call(message, "features"))
                            $root.google.protobuf.FeatureSet.encode(message.features, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                        if (message.edition != null && Object.hasOwnProperty.call(message, "edition"))
                            writer.uint32(/* id 3, wireType 0 =*/24).int32(message.edition);
                        return writer;
                    };
    
                    /**
                     * Encodes the specified FeatureSetEditionDefault message, length delimited. Does not implicitly {@link google.protobuf.FeatureSetDefaults.FeatureSetEditionDefault.verify|verify} messages.
                     * @function encodeDelimited
                     * @memberof google.protobuf.FeatureSetDefaults.FeatureSetEditionDefault
                     * @static
                     * @param {google.protobuf.FeatureSetDefaults.IFeatureSetEditionDefault} message FeatureSetEditionDefault message or plain object to encode
                     * @param {$protobuf.Writer} [writer] Writer to encode to
                     * @returns {$protobuf.Writer} Writer
                     */
                    FeatureSetEditionDefault.encodeDelimited = function encodeDelimited(message, writer) {
                        return this.encode(message, writer).ldelim();
                    };
    
                    /**
                     * Decodes a FeatureSetEditionDefault message from the specified reader or buffer.
                     * @function decode
                     * @memberof google.protobuf.FeatureSetDefaults.FeatureSetEditionDefault
                     * @static
                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                     * @param {number} [length] Message length if known beforehand
                     * @returns {google.protobuf.FeatureSetDefaults.FeatureSetEditionDefault} FeatureSetEditionDefault
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    FeatureSetEditionDefault.decode = function decode(reader, length) {
                        if (!(reader instanceof $Reader))
                            reader = $Reader.create(reader);
                        var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.protobuf.FeatureSetDefaults.FeatureSetEditionDefault();
                        while (reader.pos < end) {
                            var tag = reader.uint32();
                            switch (tag >>> 3) {
                            case 3: {
                                    message.edition = reader.int32();
                                    break;
                                }
                            case 2: {
                                    message.features = $root.google.protobuf.FeatureSet.decode(reader, reader.uint32());
                                    break;
                                }
                            default:
                                reader.skipType(tag & 7);
                                break;
                            }
                        }
                        return message;
                    };
    
                    /**
                     * Decodes a FeatureSetEditionDefault message from the specified reader or buffer, length delimited.
                     * @function decodeDelimited
                     * @memberof google.protobuf.FeatureSetDefaults.FeatureSetEditionDefault
                     * @static
                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                     * @returns {google.protobuf.FeatureSetDefaults.FeatureSetEditionDefault} FeatureSetEditionDefault
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    FeatureSetEditionDefault.decodeDelimited = function decodeDelimited(reader) {
                        if (!(reader instanceof $Reader))
                            reader = new $Reader(reader);
                        return this.decode(reader, reader.uint32());
                    };
    
                    /**
                     * Verifies a FeatureSetEditionDefault message.
                     * @function verify
                     * @memberof google.protobuf.FeatureSetDefaults.FeatureSetEditionDefault
                     * @static
                     * @param {Object.<string,*>} message Plain object to verify
                     * @returns {string|null} `null` if valid, otherwise the reason why it is not
                     */
                    FeatureSetEditionDefault.verify = function verify(message) {
                        if (typeof message !== "object" || message === null)
                            return "object expected";
                        if (message.edition != null && message.hasOwnProperty("edition"))
                            switch (message.edition) {
                            default:
                                return "edition: enum value expected";
                            case 0:
                            case 998:
                            case 999:
                            case 1000:
                            case 1001:
                            case 1:
                            case 2:
                            case 99997:
                            case 99998:
                            case 99999:
                            case 2147483647:
                                break;
                            }
                        if (message.features != null && message.hasOwnProperty("features")) {
                            var error = $root.google.protobuf.FeatureSet.verify(message.features);
                            if (error)
                                return "features." + error;
                        }
                        return null;
                    };
    
                    /**
                     * Creates a FeatureSetEditionDefault message from a plain object. Also converts values to their respective internal types.
                     * @function fromObject
                     * @memberof google.protobuf.FeatureSetDefaults.FeatureSetEditionDefault
                     * @static
                     * @param {Object.<string,*>} object Plain object
                     * @returns {google.protobuf.FeatureSetDefaults.FeatureSetEditionDefault} FeatureSetEditionDefault
                     */
                    FeatureSetEditionDefault.fromObject = function fromObject(object) {
                        if (object instanceof $root.google.protobuf.FeatureSetDefaults.FeatureSetEditionDefault)
                            return object;
                        var message = new $root.google.protobuf.FeatureSetDefaults.FeatureSetEditionDefault();
                        switch (object.edition) {
                        default:
                            if (typeof object.edition === "number") {
                                message.edition = object.edition;
                                break;
                            }
                            break;
                        case "EDITION_UNKNOWN":
                        case 0:
                            message.edition = 0;
                            break;
                        case "EDITION_PROTO2":
                        case 998:
                            message.edition = 998;
                            break;
                        case "EDITION_PROTO3":
                        case 999:
                            message.edition = 999;
                            break;
                        case "EDITION_2023":
                        case 1000:
                            message.edition = 1000;
                            break;
                        case "EDITION_2024":
                        case 1001:
                            message.edition = 1001;
                            break;
                        case "EDITION_1_TEST_ONLY":
                        case 1:
                            message.edition = 1;
                            break;
                        case "EDITION_2_TEST_ONLY":
                        case 2:
                            message.edition = 2;
                            break;
                        case "EDITION_99997_TEST_ONLY":
                        case 99997:
                            message.edition = 99997;
                            break;
                        case "EDITION_99998_TEST_ONLY":
                        case 99998:
                            message.edition = 99998;
                            break;
                        case "EDITION_99999_TEST_ONLY":
                        case 99999:
                            message.edition = 99999;
                            break;
                        case "EDITION_MAX":
                        case 2147483647:
                            message.edition = 2147483647;
                            break;
                        }
                        if (object.features != null) {
                            if (typeof object.features !== "object")
                                throw TypeError(".google.protobuf.FeatureSetDefaults.FeatureSetEditionDefault.features: object expected");
                            message.features = $root.google.protobuf.FeatureSet.fromObject(object.features);
                        }
                        return message;
                    };
    
                    /**
                     * Creates a plain object from a FeatureSetEditionDefault message. Also converts values to other types if specified.
                     * @function toObject
                     * @memberof google.protobuf.FeatureSetDefaults.FeatureSetEditionDefault
                     * @static
                     * @param {google.protobuf.FeatureSetDefaults.FeatureSetEditionDefault} message FeatureSetEditionDefault
                     * @param {$protobuf.IConversionOptions} [options] Conversion options
                     * @returns {Object.<string,*>} Plain object
                     */
                    FeatureSetEditionDefault.toObject = function toObject(message, options) {
                        if (!options)
                            options = {};
                        var object = {};
                        if (options.defaults) {
                            object.features = null;
                            object.edition = options.enums === String ? "EDITION_UNKNOWN" : 0;
                        }
                        if (message.features != null && message.hasOwnProperty("features"))
                            object.features = $root.google.protobuf.FeatureSet.toObject(message.features, options);
                        if (message.edition != null && message.hasOwnProperty("edition"))
                            object.edition = options.enums === String ? $root.google.protobuf.Edition[message.edition] === undefined ? message.edition : $root.google.protobuf.Edition[message.edition] : message.edition;
                        return object;
                    };
    
                    /**
                     * Converts this FeatureSetEditionDefault to JSON.
                     * @function toJSON
                     * @memberof google.protobuf.FeatureSetDefaults.FeatureSetEditionDefault
                     * @instance
                     * @returns {Object.<string,*>} JSON object
                     */
                    FeatureSetEditionDefault.prototype.toJSON = function toJSON() {
                        return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                    };
    
                    /**
                     * Gets the default type url for FeatureSetEditionDefault
                     * @function getTypeUrl
                     * @memberof google.protobuf.FeatureSetDefaults.FeatureSetEditionDefault
                     * @static
                     * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns {string} The default type url
                     */
                    FeatureSetEditionDefault.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                        if (typeUrlPrefix === undefined) {
                            typeUrlPrefix = "type.googleapis.com";
                        }
                        return typeUrlPrefix + "/google.protobuf.FeatureSetDefaults.FeatureSetEditionDefault";
                    };
    
                    return FeatureSetEditionDefault;
                })();
    
                return FeatureSetDefaults;
            })();
    
            protobuf.SourceCodeInfo = (function() {
    
                /**
                 * Properties of a SourceCodeInfo.
                 * @memberof google.protobuf
                 * @interface ISourceCodeInfo
                 * @property {Array.<google.protobuf.SourceCodeInfo.ILocation>|null} [location] SourceCodeInfo location
                 */
    
                /**
                 * Constructs a new SourceCodeInfo.
                 * @memberof google.protobuf
                 * @classdesc Represents a SourceCodeInfo.
                 * @implements ISourceCodeInfo
                 * @constructor
                 * @param {google.protobuf.ISourceCodeInfo=} [properties] Properties to set
                 */
                function SourceCodeInfo(properties) {
                    this.location = [];
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * SourceCodeInfo location.
                 * @member {Array.<google.protobuf.SourceCodeInfo.ILocation>} location
                 * @memberof google.protobuf.SourceCodeInfo
                 * @instance
                 */
                SourceCodeInfo.prototype.location = $util.emptyArray;
    
                /**
                 * Creates a new SourceCodeInfo instance using the specified properties.
                 * @function create
                 * @memberof google.protobuf.SourceCodeInfo
                 * @static
                 * @param {google.protobuf.ISourceCodeInfo=} [properties] Properties to set
                 * @returns {google.protobuf.SourceCodeInfo} SourceCodeInfo instance
                 */
                SourceCodeInfo.create = function create(properties) {
                    return new SourceCodeInfo(properties);
                };
    
                /**
                 * Encodes the specified SourceCodeInfo message. Does not implicitly {@link google.protobuf.SourceCodeInfo.verify|verify} messages.
                 * @function encode
                 * @memberof google.protobuf.SourceCodeInfo
                 * @static
                 * @param {google.protobuf.ISourceCodeInfo} message SourceCodeInfo message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                SourceCodeInfo.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.location != null && message.location.length)
                        for (var i = 0; i < message.location.length; ++i)
                            $root.google.protobuf.SourceCodeInfo.Location.encode(message.location[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                    return writer;
                };
    
                /**
                 * Encodes the specified SourceCodeInfo message, length delimited. Does not implicitly {@link google.protobuf.SourceCodeInfo.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.protobuf.SourceCodeInfo
                 * @static
                 * @param {google.protobuf.ISourceCodeInfo} message SourceCodeInfo message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                SourceCodeInfo.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes a SourceCodeInfo message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.protobuf.SourceCodeInfo
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.protobuf.SourceCodeInfo} SourceCodeInfo
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                SourceCodeInfo.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.protobuf.SourceCodeInfo();
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 1: {
                                if (!(message.location && message.location.length))
                                    message.location = [];
                                message.location.push($root.google.protobuf.SourceCodeInfo.Location.decode(reader, reader.uint32()));
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes a SourceCodeInfo message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.protobuf.SourceCodeInfo
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.protobuf.SourceCodeInfo} SourceCodeInfo
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                SourceCodeInfo.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies a SourceCodeInfo message.
                 * @function verify
                 * @memberof google.protobuf.SourceCodeInfo
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                SourceCodeInfo.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    if (message.location != null && message.hasOwnProperty("location")) {
                        if (!Array.isArray(message.location))
                            return "location: array expected";
                        for (var i = 0; i < message.location.length; ++i) {
                            var error = $root.google.protobuf.SourceCodeInfo.Location.verify(message.location[i]);
                            if (error)
                                return "location." + error;
                        }
                    }
                    return null;
                };
    
                /**
                 * Creates a SourceCodeInfo message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.protobuf.SourceCodeInfo
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.protobuf.SourceCodeInfo} SourceCodeInfo
                 */
                SourceCodeInfo.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.protobuf.SourceCodeInfo)
                        return object;
                    var message = new $root.google.protobuf.SourceCodeInfo();
                    if (object.location) {
                        if (!Array.isArray(object.location))
                            throw TypeError(".google.protobuf.SourceCodeInfo.location: array expected");
                        message.location = [];
                        for (var i = 0; i < object.location.length; ++i) {
                            if (typeof object.location[i] !== "object")
                                throw TypeError(".google.protobuf.SourceCodeInfo.location: object expected");
                            message.location[i] = $root.google.protobuf.SourceCodeInfo.Location.fromObject(object.location[i]);
                        }
                    }
                    return message;
                };
    
                /**
                 * Creates a plain object from a SourceCodeInfo message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.protobuf.SourceCodeInfo
                 * @static
                 * @param {google.protobuf.SourceCodeInfo} message SourceCodeInfo
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                SourceCodeInfo.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (options.arrays || options.defaults)
                        object.location = [];
                    if (message.location && message.location.length) {
                        object.location = [];
                        for (var j = 0; j < message.location.length; ++j)
                            object.location[j] = $root.google.protobuf.SourceCodeInfo.Location.toObject(message.location[j], options);
                    }
                    return object;
                };
    
                /**
                 * Converts this SourceCodeInfo to JSON.
                 * @function toJSON
                 * @memberof google.protobuf.SourceCodeInfo
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                SourceCodeInfo.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for SourceCodeInfo
                 * @function getTypeUrl
                 * @memberof google.protobuf.SourceCodeInfo
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                SourceCodeInfo.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.protobuf.SourceCodeInfo";
                };
    
                SourceCodeInfo.Location = (function() {
    
                    /**
                     * Properties of a Location.
                     * @memberof google.protobuf.SourceCodeInfo
                     * @interface ILocation
                     * @property {Array.<number>|null} [path] Location path
                     * @property {Array.<number>|null} [span] Location span
                     * @property {string|null} [leadingComments] Location leadingComments
                     * @property {string|null} [trailingComments] Location trailingComments
                     * @property {Array.<string>|null} [leadingDetachedComments] Location leadingDetachedComments
                     */
    
                    /**
                     * Constructs a new Location.
                     * @memberof google.protobuf.SourceCodeInfo
                     * @classdesc Represents a Location.
                     * @implements ILocation
                     * @constructor
                     * @param {google.protobuf.SourceCodeInfo.ILocation=} [properties] Properties to set
                     */
                    function Location(properties) {
                        this.path = [];
                        this.span = [];
                        this.leadingDetachedComments = [];
                        if (properties)
                            for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                if (properties[keys[i]] != null)
                                    this[keys[i]] = properties[keys[i]];
                    }
    
                    /**
                     * Location path.
                     * @member {Array.<number>} path
                     * @memberof google.protobuf.SourceCodeInfo.Location
                     * @instance
                     */
                    Location.prototype.path = $util.emptyArray;
    
                    /**
                     * Location span.
                     * @member {Array.<number>} span
                     * @memberof google.protobuf.SourceCodeInfo.Location
                     * @instance
                     */
                    Location.prototype.span = $util.emptyArray;
    
                    /**
                     * Location leadingComments.
                     * @member {string} leadingComments
                     * @memberof google.protobuf.SourceCodeInfo.Location
                     * @instance
                     */
                    Location.prototype.leadingComments = "";
    
                    /**
                     * Location trailingComments.
                     * @member {string} trailingComments
                     * @memberof google.protobuf.SourceCodeInfo.Location
                     * @instance
                     */
                    Location.prototype.trailingComments = "";
    
                    /**
                     * Location leadingDetachedComments.
                     * @member {Array.<string>} leadingDetachedComments
                     * @memberof google.protobuf.SourceCodeInfo.Location
                     * @instance
                     */
                    Location.prototype.leadingDetachedComments = $util.emptyArray;
    
                    /**
                     * Creates a new Location instance using the specified properties.
                     * @function create
                     * @memberof google.protobuf.SourceCodeInfo.Location
                     * @static
                     * @param {google.protobuf.SourceCodeInfo.ILocation=} [properties] Properties to set
                     * @returns {google.protobuf.SourceCodeInfo.Location} Location instance
                     */
                    Location.create = function create(properties) {
                        return new Location(properties);
                    };
    
                    /**
                     * Encodes the specified Location message. Does not implicitly {@link google.protobuf.SourceCodeInfo.Location.verify|verify} messages.
                     * @function encode
                     * @memberof google.protobuf.SourceCodeInfo.Location
                     * @static
                     * @param {google.protobuf.SourceCodeInfo.ILocation} message Location message or plain object to encode
                     * @param {$protobuf.Writer} [writer] Writer to encode to
                     * @returns {$protobuf.Writer} Writer
                     */
                    Location.encode = function encode(message, writer) {
                        if (!writer)
                            writer = $Writer.create();
                        if (message.path != null && message.path.length) {
                            writer.uint32(/* id 1, wireType 2 =*/10).fork();
                            for (var i = 0; i < message.path.length; ++i)
                                writer.int32(message.path[i]);
                            writer.ldelim();
                        }
                        if (message.span != null && message.span.length) {
                            writer.uint32(/* id 2, wireType 2 =*/18).fork();
                            for (var i = 0; i < message.span.length; ++i)
                                writer.int32(message.span[i]);
                            writer.ldelim();
                        }
                        if (message.leadingComments != null && Object.hasOwnProperty.call(message, "leadingComments"))
                            writer.uint32(/* id 3, wireType 2 =*/26).string(message.leadingComments);
                        if (message.trailingComments != null && Object.hasOwnProperty.call(message, "trailingComments"))
                            writer.uint32(/* id 4, wireType 2 =*/34).string(message.trailingComments);
                        if (message.leadingDetachedComments != null && message.leadingDetachedComments.length)
                            for (var i = 0; i < message.leadingDetachedComments.length; ++i)
                                writer.uint32(/* id 6, wireType 2 =*/50).string(message.leadingDetachedComments[i]);
                        return writer;
                    };
    
                    /**
                     * Encodes the specified Location message, length delimited. Does not implicitly {@link google.protobuf.SourceCodeInfo.Location.verify|verify} messages.
                     * @function encodeDelimited
                     * @memberof google.protobuf.SourceCodeInfo.Location
                     * @static
                     * @param {google.protobuf.SourceCodeInfo.ILocation} message Location message or plain object to encode
                     * @param {$protobuf.Writer} [writer] Writer to encode to
                     * @returns {$protobuf.Writer} Writer
                     */
                    Location.encodeDelimited = function encodeDelimited(message, writer) {
                        return this.encode(message, writer).ldelim();
                    };
    
                    /**
                     * Decodes a Location message from the specified reader or buffer.
                     * @function decode
                     * @memberof google.protobuf.SourceCodeInfo.Location
                     * @static
                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                     * @param {number} [length] Message length if known beforehand
                     * @returns {google.protobuf.SourceCodeInfo.Location} Location
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    Location.decode = function decode(reader, length) {
                        if (!(reader instanceof $Reader))
                            reader = $Reader.create(reader);
                        var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.protobuf.SourceCodeInfo.Location();
                        while (reader.pos < end) {
                            var tag = reader.uint32();
                            switch (tag >>> 3) {
                            case 1: {
                                    if (!(message.path && message.path.length))
                                        message.path = [];
                                    if ((tag & 7) === 2) {
                                        var end2 = reader.uint32() + reader.pos;
                                        while (reader.pos < end2)
                                            message.path.push(reader.int32());
                                    } else
                                        message.path.push(reader.int32());
                                    break;
                                }
                            case 2: {
                                    if (!(message.span && message.span.length))
                                        message.span = [];
                                    if ((tag & 7) === 2) {
                                        var end2 = reader.uint32() + reader.pos;
                                        while (reader.pos < end2)
                                            message.span.push(reader.int32());
                                    } else
                                        message.span.push(reader.int32());
                                    break;
                                }
                            case 3: {
                                    message.leadingComments = reader.string();
                                    break;
                                }
                            case 4: {
                                    message.trailingComments = reader.string();
                                    break;
                                }
                            case 6: {
                                    if (!(message.leadingDetachedComments && message.leadingDetachedComments.length))
                                        message.leadingDetachedComments = [];
                                    message.leadingDetachedComments.push(reader.string());
                                    break;
                                }
                            default:
                                reader.skipType(tag & 7);
                                break;
                            }
                        }
                        return message;
                    };
    
                    /**
                     * Decodes a Location message from the specified reader or buffer, length delimited.
                     * @function decodeDelimited
                     * @memberof google.protobuf.SourceCodeInfo.Location
                     * @static
                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                     * @returns {google.protobuf.SourceCodeInfo.Location} Location
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    Location.decodeDelimited = function decodeDelimited(reader) {
                        if (!(reader instanceof $Reader))
                            reader = new $Reader(reader);
                        return this.decode(reader, reader.uint32());
                    };
    
                    /**
                     * Verifies a Location message.
                     * @function verify
                     * @memberof google.protobuf.SourceCodeInfo.Location
                     * @static
                     * @param {Object.<string,*>} message Plain object to verify
                     * @returns {string|null} `null` if valid, otherwise the reason why it is not
                     */
                    Location.verify = function verify(message) {
                        if (typeof message !== "object" || message === null)
                            return "object expected";
                        if (message.path != null && message.hasOwnProperty("path")) {
                            if (!Array.isArray(message.path))
                                return "path: array expected";
                            for (var i = 0; i < message.path.length; ++i)
                                if (!$util.isInteger(message.path[i]))
                                    return "path: integer[] expected";
                        }
                        if (message.span != null && message.hasOwnProperty("span")) {
                            if (!Array.isArray(message.span))
                                return "span: array expected";
                            for (var i = 0; i < message.span.length; ++i)
                                if (!$util.isInteger(message.span[i]))
                                    return "span: integer[] expected";
                        }
                        if (message.leadingComments != null && message.hasOwnProperty("leadingComments"))
                            if (!$util.isString(message.leadingComments))
                                return "leadingComments: string expected";
                        if (message.trailingComments != null && message.hasOwnProperty("trailingComments"))
                            if (!$util.isString(message.trailingComments))
                                return "trailingComments: string expected";
                        if (message.leadingDetachedComments != null && message.hasOwnProperty("leadingDetachedComments")) {
                            if (!Array.isArray(message.leadingDetachedComments))
                                return "leadingDetachedComments: array expected";
                            for (var i = 0; i < message.leadingDetachedComments.length; ++i)
                                if (!$util.isString(message.leadingDetachedComments[i]))
                                    return "leadingDetachedComments: string[] expected";
                        }
                        return null;
                    };
    
                    /**
                     * Creates a Location message from a plain object. Also converts values to their respective internal types.
                     * @function fromObject
                     * @memberof google.protobuf.SourceCodeInfo.Location
                     * @static
                     * @param {Object.<string,*>} object Plain object
                     * @returns {google.protobuf.SourceCodeInfo.Location} Location
                     */
                    Location.fromObject = function fromObject(object) {
                        if (object instanceof $root.google.protobuf.SourceCodeInfo.Location)
                            return object;
                        var message = new $root.google.protobuf.SourceCodeInfo.Location();
                        if (object.path) {
                            if (!Array.isArray(object.path))
                                throw TypeError(".google.protobuf.SourceCodeInfo.Location.path: array expected");
                            message.path = [];
                            for (var i = 0; i < object.path.length; ++i)
                                message.path[i] = object.path[i] | 0;
                        }
                        if (object.span) {
                            if (!Array.isArray(object.span))
                                throw TypeError(".google.protobuf.SourceCodeInfo.Location.span: array expected");
                            message.span = [];
                            for (var i = 0; i < object.span.length; ++i)
                                message.span[i] = object.span[i] | 0;
                        }
                        if (object.leadingComments != null)
                            message.leadingComments = String(object.leadingComments);
                        if (object.trailingComments != null)
                            message.trailingComments = String(object.trailingComments);
                        if (object.leadingDetachedComments) {
                            if (!Array.isArray(object.leadingDetachedComments))
                                throw TypeError(".google.protobuf.SourceCodeInfo.Location.leadingDetachedComments: array expected");
                            message.leadingDetachedComments = [];
                            for (var i = 0; i < object.leadingDetachedComments.length; ++i)
                                message.leadingDetachedComments[i] = String(object.leadingDetachedComments[i]);
                        }
                        return message;
                    };
    
                    /**
                     * Creates a plain object from a Location message. Also converts values to other types if specified.
                     * @function toObject
                     * @memberof google.protobuf.SourceCodeInfo.Location
                     * @static
                     * @param {google.protobuf.SourceCodeInfo.Location} message Location
                     * @param {$protobuf.IConversionOptions} [options] Conversion options
                     * @returns {Object.<string,*>} Plain object
                     */
                    Location.toObject = function toObject(message, options) {
                        if (!options)
                            options = {};
                        var object = {};
                        if (options.arrays || options.defaults) {
                            object.path = [];
                            object.span = [];
                            object.leadingDetachedComments = [];
                        }
                        if (options.defaults) {
                            object.leadingComments = "";
                            object.trailingComments = "";
                        }
                        if (message.path && message.path.length) {
                            object.path = [];
                            for (var j = 0; j < message.path.length; ++j)
                                object.path[j] = message.path[j];
                        }
                        if (message.span && message.span.length) {
                            object.span = [];
                            for (var j = 0; j < message.span.length; ++j)
                                object.span[j] = message.span[j];
                        }
                        if (message.leadingComments != null && message.hasOwnProperty("leadingComments"))
                            object.leadingComments = message.leadingComments;
                        if (message.trailingComments != null && message.hasOwnProperty("trailingComments"))
                            object.trailingComments = message.trailingComments;
                        if (message.leadingDetachedComments && message.leadingDetachedComments.length) {
                            object.leadingDetachedComments = [];
                            for (var j = 0; j < message.leadingDetachedComments.length; ++j)
                                object.leadingDetachedComments[j] = message.leadingDetachedComments[j];
                        }
                        return object;
                    };
    
                    /**
                     * Converts this Location to JSON.
                     * @function toJSON
                     * @memberof google.protobuf.SourceCodeInfo.Location
                     * @instance
                     * @returns {Object.<string,*>} JSON object
                     */
                    Location.prototype.toJSON = function toJSON() {
                        return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                    };
    
                    /**
                     * Gets the default type url for Location
                     * @function getTypeUrl
                     * @memberof google.protobuf.SourceCodeInfo.Location
                     * @static
                     * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns {string} The default type url
                     */
                    Location.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                        if (typeUrlPrefix === undefined) {
                            typeUrlPrefix = "type.googleapis.com";
                        }
                        return typeUrlPrefix + "/google.protobuf.SourceCodeInfo.Location";
                    };
    
                    return Location;
                })();
    
                return SourceCodeInfo;
            })();
    
            protobuf.GeneratedCodeInfo = (function() {
    
                /**
                 * Properties of a GeneratedCodeInfo.
                 * @memberof google.protobuf
                 * @interface IGeneratedCodeInfo
                 * @property {Array.<google.protobuf.GeneratedCodeInfo.IAnnotation>|null} [annotation] GeneratedCodeInfo annotation
                 */
    
                /**
                 * Constructs a new GeneratedCodeInfo.
                 * @memberof google.protobuf
                 * @classdesc Represents a GeneratedCodeInfo.
                 * @implements IGeneratedCodeInfo
                 * @constructor
                 * @param {google.protobuf.IGeneratedCodeInfo=} [properties] Properties to set
                 */
                function GeneratedCodeInfo(properties) {
                    this.annotation = [];
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * GeneratedCodeInfo annotation.
                 * @member {Array.<google.protobuf.GeneratedCodeInfo.IAnnotation>} annotation
                 * @memberof google.protobuf.GeneratedCodeInfo
                 * @instance
                 */
                GeneratedCodeInfo.prototype.annotation = $util.emptyArray;
    
                /**
                 * Creates a new GeneratedCodeInfo instance using the specified properties.
                 * @function create
                 * @memberof google.protobuf.GeneratedCodeInfo
                 * @static
                 * @param {google.protobuf.IGeneratedCodeInfo=} [properties] Properties to set
                 * @returns {google.protobuf.GeneratedCodeInfo} GeneratedCodeInfo instance
                 */
                GeneratedCodeInfo.create = function create(properties) {
                    return new GeneratedCodeInfo(properties);
                };
    
                /**
                 * Encodes the specified GeneratedCodeInfo message. Does not implicitly {@link google.protobuf.GeneratedCodeInfo.verify|verify} messages.
                 * @function encode
                 * @memberof google.protobuf.GeneratedCodeInfo
                 * @static
                 * @param {google.protobuf.IGeneratedCodeInfo} message GeneratedCodeInfo message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                GeneratedCodeInfo.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.annotation != null && message.annotation.length)
                        for (var i = 0; i < message.annotation.length; ++i)
                            $root.google.protobuf.GeneratedCodeInfo.Annotation.encode(message.annotation[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                    return writer;
                };
    
                /**
                 * Encodes the specified GeneratedCodeInfo message, length delimited. Does not implicitly {@link google.protobuf.GeneratedCodeInfo.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.protobuf.GeneratedCodeInfo
                 * @static
                 * @param {google.protobuf.IGeneratedCodeInfo} message GeneratedCodeInfo message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                GeneratedCodeInfo.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes a GeneratedCodeInfo message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.protobuf.GeneratedCodeInfo
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.protobuf.GeneratedCodeInfo} GeneratedCodeInfo
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                GeneratedCodeInfo.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.protobuf.GeneratedCodeInfo();
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 1: {
                                if (!(message.annotation && message.annotation.length))
                                    message.annotation = [];
                                message.annotation.push($root.google.protobuf.GeneratedCodeInfo.Annotation.decode(reader, reader.uint32()));
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes a GeneratedCodeInfo message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.protobuf.GeneratedCodeInfo
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.protobuf.GeneratedCodeInfo} GeneratedCodeInfo
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                GeneratedCodeInfo.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies a GeneratedCodeInfo message.
                 * @function verify
                 * @memberof google.protobuf.GeneratedCodeInfo
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                GeneratedCodeInfo.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    if (message.annotation != null && message.hasOwnProperty("annotation")) {
                        if (!Array.isArray(message.annotation))
                            return "annotation: array expected";
                        for (var i = 0; i < message.annotation.length; ++i) {
                            var error = $root.google.protobuf.GeneratedCodeInfo.Annotation.verify(message.annotation[i]);
                            if (error)
                                return "annotation." + error;
                        }
                    }
                    return null;
                };
    
                /**
                 * Creates a GeneratedCodeInfo message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.protobuf.GeneratedCodeInfo
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.protobuf.GeneratedCodeInfo} GeneratedCodeInfo
                 */
                GeneratedCodeInfo.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.protobuf.GeneratedCodeInfo)
                        return object;
                    var message = new $root.google.protobuf.GeneratedCodeInfo();
                    if (object.annotation) {
                        if (!Array.isArray(object.annotation))
                            throw TypeError(".google.protobuf.GeneratedCodeInfo.annotation: array expected");
                        message.annotation = [];
                        for (var i = 0; i < object.annotation.length; ++i) {
                            if (typeof object.annotation[i] !== "object")
                                throw TypeError(".google.protobuf.GeneratedCodeInfo.annotation: object expected");
                            message.annotation[i] = $root.google.protobuf.GeneratedCodeInfo.Annotation.fromObject(object.annotation[i]);
                        }
                    }
                    return message;
                };
    
                /**
                 * Creates a plain object from a GeneratedCodeInfo message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.protobuf.GeneratedCodeInfo
                 * @static
                 * @param {google.protobuf.GeneratedCodeInfo} message GeneratedCodeInfo
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                GeneratedCodeInfo.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (options.arrays || options.defaults)
                        object.annotation = [];
                    if (message.annotation && message.annotation.length) {
                        object.annotation = [];
                        for (var j = 0; j < message.annotation.length; ++j)
                            object.annotation[j] = $root.google.protobuf.GeneratedCodeInfo.Annotation.toObject(message.annotation[j], options);
                    }
                    return object;
                };
    
                /**
                 * Converts this GeneratedCodeInfo to JSON.
                 * @function toJSON
                 * @memberof google.protobuf.GeneratedCodeInfo
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                GeneratedCodeInfo.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for GeneratedCodeInfo
                 * @function getTypeUrl
                 * @memberof google.protobuf.GeneratedCodeInfo
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                GeneratedCodeInfo.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.protobuf.GeneratedCodeInfo";
                };
    
                GeneratedCodeInfo.Annotation = (function() {
    
                    /**
                     * Properties of an Annotation.
                     * @memberof google.protobuf.GeneratedCodeInfo
                     * @interface IAnnotation
                     * @property {Array.<number>|null} [path] Annotation path
                     * @property {string|null} [sourceFile] Annotation sourceFile
                     * @property {number|null} [begin] Annotation begin
                     * @property {number|null} [end] Annotation end
                     * @property {google.protobuf.GeneratedCodeInfo.Annotation.Semantic|null} [semantic] Annotation semantic
                     */
    
                    /**
                     * Constructs a new Annotation.
                     * @memberof google.protobuf.GeneratedCodeInfo
                     * @classdesc Represents an Annotation.
                     * @implements IAnnotation
                     * @constructor
                     * @param {google.protobuf.GeneratedCodeInfo.IAnnotation=} [properties] Properties to set
                     */
                    function Annotation(properties) {
                        this.path = [];
                        if (properties)
                            for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                                if (properties[keys[i]] != null)
                                    this[keys[i]] = properties[keys[i]];
                    }
    
                    /**
                     * Annotation path.
                     * @member {Array.<number>} path
                     * @memberof google.protobuf.GeneratedCodeInfo.Annotation
                     * @instance
                     */
                    Annotation.prototype.path = $util.emptyArray;
    
                    /**
                     * Annotation sourceFile.
                     * @member {string} sourceFile
                     * @memberof google.protobuf.GeneratedCodeInfo.Annotation
                     * @instance
                     */
                    Annotation.prototype.sourceFile = "";
    
                    /**
                     * Annotation begin.
                     * @member {number} begin
                     * @memberof google.protobuf.GeneratedCodeInfo.Annotation
                     * @instance
                     */
                    Annotation.prototype.begin = 0;
    
                    /**
                     * Annotation end.
                     * @member {number} end
                     * @memberof google.protobuf.GeneratedCodeInfo.Annotation
                     * @instance
                     */
                    Annotation.prototype.end = 0;
    
                    /**
                     * Annotation semantic.
                     * @member {google.protobuf.GeneratedCodeInfo.Annotation.Semantic} semantic
                     * @memberof google.protobuf.GeneratedCodeInfo.Annotation
                     * @instance
                     */
                    Annotation.prototype.semantic = 0;
    
                    /**
                     * Creates a new Annotation instance using the specified properties.
                     * @function create
                     * @memberof google.protobuf.GeneratedCodeInfo.Annotation
                     * @static
                     * @param {google.protobuf.GeneratedCodeInfo.IAnnotation=} [properties] Properties to set
                     * @returns {google.protobuf.GeneratedCodeInfo.Annotation} Annotation instance
                     */
                    Annotation.create = function create(properties) {
                        return new Annotation(properties);
                    };
    
                    /**
                     * Encodes the specified Annotation message. Does not implicitly {@link google.protobuf.GeneratedCodeInfo.Annotation.verify|verify} messages.
                     * @function encode
                     * @memberof google.protobuf.GeneratedCodeInfo.Annotation
                     * @static
                     * @param {google.protobuf.GeneratedCodeInfo.IAnnotation} message Annotation message or plain object to encode
                     * @param {$protobuf.Writer} [writer] Writer to encode to
                     * @returns {$protobuf.Writer} Writer
                     */
                    Annotation.encode = function encode(message, writer) {
                        if (!writer)
                            writer = $Writer.create();
                        if (message.path != null && message.path.length) {
                            writer.uint32(/* id 1, wireType 2 =*/10).fork();
                            for (var i = 0; i < message.path.length; ++i)
                                writer.int32(message.path[i]);
                            writer.ldelim();
                        }
                        if (message.sourceFile != null && Object.hasOwnProperty.call(message, "sourceFile"))
                            writer.uint32(/* id 2, wireType 2 =*/18).string(message.sourceFile);
                        if (message.begin != null && Object.hasOwnProperty.call(message, "begin"))
                            writer.uint32(/* id 3, wireType 0 =*/24).int32(message.begin);
                        if (message.end != null && Object.hasOwnProperty.call(message, "end"))
                            writer.uint32(/* id 4, wireType 0 =*/32).int32(message.end);
                        if (message.semantic != null && Object.hasOwnProperty.call(message, "semantic"))
                            writer.uint32(/* id 5, wireType 0 =*/40).int32(message.semantic);
                        return writer;
                    };
    
                    /**
                     * Encodes the specified Annotation message, length delimited. Does not implicitly {@link google.protobuf.GeneratedCodeInfo.Annotation.verify|verify} messages.
                     * @function encodeDelimited
                     * @memberof google.protobuf.GeneratedCodeInfo.Annotation
                     * @static
                     * @param {google.protobuf.GeneratedCodeInfo.IAnnotation} message Annotation message or plain object to encode
                     * @param {$protobuf.Writer} [writer] Writer to encode to
                     * @returns {$protobuf.Writer} Writer
                     */
                    Annotation.encodeDelimited = function encodeDelimited(message, writer) {
                        return this.encode(message, writer).ldelim();
                    };
    
                    /**
                     * Decodes an Annotation message from the specified reader or buffer.
                     * @function decode
                     * @memberof google.protobuf.GeneratedCodeInfo.Annotation
                     * @static
                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                     * @param {number} [length] Message length if known beforehand
                     * @returns {google.protobuf.GeneratedCodeInfo.Annotation} Annotation
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    Annotation.decode = function decode(reader, length) {
                        if (!(reader instanceof $Reader))
                            reader = $Reader.create(reader);
                        var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.protobuf.GeneratedCodeInfo.Annotation();
                        while (reader.pos < end) {
                            var tag = reader.uint32();
                            switch (tag >>> 3) {
                            case 1: {
                                    if (!(message.path && message.path.length))
                                        message.path = [];
                                    if ((tag & 7) === 2) {
                                        var end2 = reader.uint32() + reader.pos;
                                        while (reader.pos < end2)
                                            message.path.push(reader.int32());
                                    } else
                                        message.path.push(reader.int32());
                                    break;
                                }
                            case 2: {
                                    message.sourceFile = reader.string();
                                    break;
                                }
                            case 3: {
                                    message.begin = reader.int32();
                                    break;
                                }
                            case 4: {
                                    message.end = reader.int32();
                                    break;
                                }
                            case 5: {
                                    message.semantic = reader.int32();
                                    break;
                                }
                            default:
                                reader.skipType(tag & 7);
                                break;
                            }
                        }
                        return message;
                    };
    
                    /**
                     * Decodes an Annotation message from the specified reader or buffer, length delimited.
                     * @function decodeDelimited
                     * @memberof google.protobuf.GeneratedCodeInfo.Annotation
                     * @static
                     * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                     * @returns {google.protobuf.GeneratedCodeInfo.Annotation} Annotation
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    Annotation.decodeDelimited = function decodeDelimited(reader) {
                        if (!(reader instanceof $Reader))
                            reader = new $Reader(reader);
                        return this.decode(reader, reader.uint32());
                    };
    
                    /**
                     * Verifies an Annotation message.
                     * @function verify
                     * @memberof google.protobuf.GeneratedCodeInfo.Annotation
                     * @static
                     * @param {Object.<string,*>} message Plain object to verify
                     * @returns {string|null} `null` if valid, otherwise the reason why it is not
                     */
                    Annotation.verify = function verify(message) {
                        if (typeof message !== "object" || message === null)
                            return "object expected";
                        if (message.path != null && message.hasOwnProperty("path")) {
                            if (!Array.isArray(message.path))
                                return "path: array expected";
                            for (var i = 0; i < message.path.length; ++i)
                                if (!$util.isInteger(message.path[i]))
                                    return "path: integer[] expected";
                        }
                        if (message.sourceFile != null && message.hasOwnProperty("sourceFile"))
                            if (!$util.isString(message.sourceFile))
                                return "sourceFile: string expected";
                        if (message.begin != null && message.hasOwnProperty("begin"))
                            if (!$util.isInteger(message.begin))
                                return "begin: integer expected";
                        if (message.end != null && message.hasOwnProperty("end"))
                            if (!$util.isInteger(message.end))
                                return "end: integer expected";
                        if (message.semantic != null && message.hasOwnProperty("semantic"))
                            switch (message.semantic) {
                            default:
                                return "semantic: enum value expected";
                            case 0:
                            case 1:
                            case 2:
                                break;
                            }
                        return null;
                    };
    
                    /**
                     * Creates an Annotation message from a plain object. Also converts values to their respective internal types.
                     * @function fromObject
                     * @memberof google.protobuf.GeneratedCodeInfo.Annotation
                     * @static
                     * @param {Object.<string,*>} object Plain object
                     * @returns {google.protobuf.GeneratedCodeInfo.Annotation} Annotation
                     */
                    Annotation.fromObject = function fromObject(object) {
                        if (object instanceof $root.google.protobuf.GeneratedCodeInfo.Annotation)
                            return object;
                        var message = new $root.google.protobuf.GeneratedCodeInfo.Annotation();
                        if (object.path) {
                            if (!Array.isArray(object.path))
                                throw TypeError(".google.protobuf.GeneratedCodeInfo.Annotation.path: array expected");
                            message.path = [];
                            for (var i = 0; i < object.path.length; ++i)
                                message.path[i] = object.path[i] | 0;
                        }
                        if (object.sourceFile != null)
                            message.sourceFile = String(object.sourceFile);
                        if (object.begin != null)
                            message.begin = object.begin | 0;
                        if (object.end != null)
                            message.end = object.end | 0;
                        switch (object.semantic) {
                        default:
                            if (typeof object.semantic === "number") {
                                message.semantic = object.semantic;
                                break;
                            }
                            break;
                        case "NONE":
                        case 0:
                            message.semantic = 0;
                            break;
                        case "SET":
                        case 1:
                            message.semantic = 1;
                            break;
                        case "ALIAS":
                        case 2:
                            message.semantic = 2;
                            break;
                        }
                        return message;
                    };
    
                    /**
                     * Creates a plain object from an Annotation message. Also converts values to other types if specified.
                     * @function toObject
                     * @memberof google.protobuf.GeneratedCodeInfo.Annotation
                     * @static
                     * @param {google.protobuf.GeneratedCodeInfo.Annotation} message Annotation
                     * @param {$protobuf.IConversionOptions} [options] Conversion options
                     * @returns {Object.<string,*>} Plain object
                     */
                    Annotation.toObject = function toObject(message, options) {
                        if (!options)
                            options = {};
                        var object = {};
                        if (options.arrays || options.defaults)
                            object.path = [];
                        if (options.defaults) {
                            object.sourceFile = "";
                            object.begin = 0;
                            object.end = 0;
                            object.semantic = options.enums === String ? "NONE" : 0;
                        }
                        if (message.path && message.path.length) {
                            object.path = [];
                            for (var j = 0; j < message.path.length; ++j)
                                object.path[j] = message.path[j];
                        }
                        if (message.sourceFile != null && message.hasOwnProperty("sourceFile"))
                            object.sourceFile = message.sourceFile;
                        if (message.begin != null && message.hasOwnProperty("begin"))
                            object.begin = message.begin;
                        if (message.end != null && message.hasOwnProperty("end"))
                            object.end = message.end;
                        if (message.semantic != null && message.hasOwnProperty("semantic"))
                            object.semantic = options.enums === String ? $root.google.protobuf.GeneratedCodeInfo.Annotation.Semantic[message.semantic] === undefined ? message.semantic : $root.google.protobuf.GeneratedCodeInfo.Annotation.Semantic[message.semantic] : message.semantic;
                        return object;
                    };
    
                    /**
                     * Converts this Annotation to JSON.
                     * @function toJSON
                     * @memberof google.protobuf.GeneratedCodeInfo.Annotation
                     * @instance
                     * @returns {Object.<string,*>} JSON object
                     */
                    Annotation.prototype.toJSON = function toJSON() {
                        return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                    };
    
                    /**
                     * Gets the default type url for Annotation
                     * @function getTypeUrl
                     * @memberof google.protobuf.GeneratedCodeInfo.Annotation
                     * @static
                     * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns {string} The default type url
                     */
                    Annotation.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                        if (typeUrlPrefix === undefined) {
                            typeUrlPrefix = "type.googleapis.com";
                        }
                        return typeUrlPrefix + "/google.protobuf.GeneratedCodeInfo.Annotation";
                    };
    
                    /**
                     * Semantic enum.
                     * @name google.protobuf.GeneratedCodeInfo.Annotation.Semantic
                     * @enum {number}
                     * @property {number} NONE=0 NONE value
                     * @property {number} SET=1 SET value
                     * @property {number} ALIAS=2 ALIAS value
                     */
                    Annotation.Semantic = (function() {
                        var valuesById = {}, values = Object.create(valuesById);
                        values[valuesById[0] = "NONE"] = 0;
                        values[valuesById[1] = "SET"] = 1;
                        values[valuesById[2] = "ALIAS"] = 2;
                        return values;
                    })();
    
                    return Annotation;
                })();
    
                return GeneratedCodeInfo;
            })();
    
            protobuf.Duration = (function() {
    
                /**
                 * Properties of a Duration.
                 * @memberof google.protobuf
                 * @interface IDuration
                 * @property {number|Long|null} [seconds] Duration seconds
                 * @property {number|null} [nanos] Duration nanos
                 */
    
                /**
                 * Constructs a new Duration.
                 * @memberof google.protobuf
                 * @classdesc Represents a Duration.
                 * @implements IDuration
                 * @constructor
                 * @param {google.protobuf.IDuration=} [properties] Properties to set
                 */
                function Duration(properties) {
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * Duration seconds.
                 * @member {number|Long} seconds
                 * @memberof google.protobuf.Duration
                 * @instance
                 */
                Duration.prototype.seconds = $util.Long ? $util.Long.fromBits(0,0,false) : 0;
    
                /**
                 * Duration nanos.
                 * @member {number} nanos
                 * @memberof google.protobuf.Duration
                 * @instance
                 */
                Duration.prototype.nanos = 0;
    
                /**
                 * Creates a new Duration instance using the specified properties.
                 * @function create
                 * @memberof google.protobuf.Duration
                 * @static
                 * @param {google.protobuf.IDuration=} [properties] Properties to set
                 * @returns {google.protobuf.Duration} Duration instance
                 */
                Duration.create = function create(properties) {
                    return new Duration(properties);
                };
    
                /**
                 * Encodes the specified Duration message. Does not implicitly {@link google.protobuf.Duration.verify|verify} messages.
                 * @function encode
                 * @memberof google.protobuf.Duration
                 * @static
                 * @param {google.protobuf.IDuration} message Duration message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                Duration.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.seconds != null && Object.hasOwnProperty.call(message, "seconds"))
                        writer.uint32(/* id 1, wireType 0 =*/8).int64(message.seconds);
                    if (message.nanos != null && Object.hasOwnProperty.call(message, "nanos"))
                        writer.uint32(/* id 2, wireType 0 =*/16).int32(message.nanos);
                    return writer;
                };
    
                /**
                 * Encodes the specified Duration message, length delimited. Does not implicitly {@link google.protobuf.Duration.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.protobuf.Duration
                 * @static
                 * @param {google.protobuf.IDuration} message Duration message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                Duration.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes a Duration message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.protobuf.Duration
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.protobuf.Duration} Duration
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                Duration.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.protobuf.Duration();
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 1: {
                                message.seconds = reader.int64();
                                break;
                            }
                        case 2: {
                                message.nanos = reader.int32();
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes a Duration message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.protobuf.Duration
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.protobuf.Duration} Duration
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                Duration.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies a Duration message.
                 * @function verify
                 * @memberof google.protobuf.Duration
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                Duration.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    if (message.seconds != null && message.hasOwnProperty("seconds"))
                        if (!$util.isInteger(message.seconds) && !(message.seconds && $util.isInteger(message.seconds.low) && $util.isInteger(message.seconds.high)))
                            return "seconds: integer|Long expected";
                    if (message.nanos != null && message.hasOwnProperty("nanos"))
                        if (!$util.isInteger(message.nanos))
                            return "nanos: integer expected";
                    return null;
                };
    
                /**
                 * Creates a Duration message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.protobuf.Duration
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.protobuf.Duration} Duration
                 */
                Duration.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.protobuf.Duration)
                        return object;
                    var message = new $root.google.protobuf.Duration();
                    if (object.seconds != null)
                        if ($util.Long)
                            (message.seconds = $util.Long.fromValue(object.seconds)).unsigned = false;
                        else if (typeof object.seconds === "string")
                            message.seconds = parseInt(object.seconds, 10);
                        else if (typeof object.seconds === "number")
                            message.seconds = object.seconds;
                        else if (typeof object.seconds === "object")
                            message.seconds = new $util.LongBits(object.seconds.low >>> 0, object.seconds.high >>> 0).toNumber();
                    if (object.nanos != null)
                        message.nanos = object.nanos | 0;
                    return message;
                };
    
                /**
                 * Creates a plain object from a Duration message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.protobuf.Duration
                 * @static
                 * @param {google.protobuf.Duration} message Duration
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                Duration.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (options.defaults) {
                        if ($util.Long) {
                            var long = new $util.Long(0, 0, false);
                            object.seconds = options.longs === String ? long.toString() : options.longs === Number ? long.toNumber() : long;
                        } else
                            object.seconds = options.longs === String ? "0" : 0;
                        object.nanos = 0;
                    }
                    if (message.seconds != null && message.hasOwnProperty("seconds"))
                        if (typeof message.seconds === "number")
                            object.seconds = options.longs === String ? String(message.seconds) : message.seconds;
                        else
                            object.seconds = options.longs === String ? $util.Long.prototype.toString.call(message.seconds) : options.longs === Number ? new $util.LongBits(message.seconds.low >>> 0, message.seconds.high >>> 0).toNumber() : message.seconds;
                    if (message.nanos != null && message.hasOwnProperty("nanos"))
                        object.nanos = message.nanos;
                    return object;
                };
    
                /**
                 * Converts this Duration to JSON.
                 * @function toJSON
                 * @memberof google.protobuf.Duration
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                Duration.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for Duration
                 * @function getTypeUrl
                 * @memberof google.protobuf.Duration
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                Duration.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.protobuf.Duration";
                };
    
                return Duration;
            })();
    
            protobuf.Any = (function() {
    
                /**
                 * Properties of an Any.
                 * @memberof google.protobuf
                 * @interface IAny
                 * @property {string|null} [type_url] Any type_url
                 * @property {Uint8Array|null} [value] Any value
                 */
    
                /**
                 * Constructs a new Any.
                 * @memberof google.protobuf
                 * @classdesc Represents an Any.
                 * @implements IAny
                 * @constructor
                 * @param {google.protobuf.IAny=} [properties] Properties to set
                 */
                function Any(properties) {
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * Any type_url.
                 * @member {string} type_url
                 * @memberof google.protobuf.Any
                 * @instance
                 */
                Any.prototype.type_url = "";
    
                /**
                 * Any value.
                 * @member {Uint8Array} value
                 * @memberof google.protobuf.Any
                 * @instance
                 */
                Any.prototype.value = $util.newBuffer([]);
    
                /**
                 * Creates a new Any instance using the specified properties.
                 * @function create
                 * @memberof google.protobuf.Any
                 * @static
                 * @param {google.protobuf.IAny=} [properties] Properties to set
                 * @returns {google.protobuf.Any} Any instance
                 */
                Any.create = function create(properties) {
                    return new Any(properties);
                };
    
                /**
                 * Encodes the specified Any message. Does not implicitly {@link google.protobuf.Any.verify|verify} messages.
                 * @function encode
                 * @memberof google.protobuf.Any
                 * @static
                 * @param {google.protobuf.IAny} message Any message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                Any.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.type_url != null && Object.hasOwnProperty.call(message, "type_url"))
                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.type_url);
                    if (message.value != null && Object.hasOwnProperty.call(message, "value"))
                        writer.uint32(/* id 2, wireType 2 =*/18).bytes(message.value);
                    return writer;
                };
    
                /**
                 * Encodes the specified Any message, length delimited. Does not implicitly {@link google.protobuf.Any.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.protobuf.Any
                 * @static
                 * @param {google.protobuf.IAny} message Any message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                Any.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes an Any message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.protobuf.Any
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.protobuf.Any} Any
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                Any.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.protobuf.Any();
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 1: {
                                message.type_url = reader.string();
                                break;
                            }
                        case 2: {
                                message.value = reader.bytes();
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes an Any message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.protobuf.Any
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.protobuf.Any} Any
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                Any.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies an Any message.
                 * @function verify
                 * @memberof google.protobuf.Any
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                Any.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    if (message.type_url != null && message.hasOwnProperty("type_url"))
                        if (!$util.isString(message.type_url))
                            return "type_url: string expected";
                    if (message.value != null && message.hasOwnProperty("value"))
                        if (!(message.value && typeof message.value.length === "number" || $util.isString(message.value)))
                            return "value: buffer expected";
                    return null;
                };
    
                /**
                 * Creates an Any message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.protobuf.Any
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.protobuf.Any} Any
                 */
                Any.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.protobuf.Any)
                        return object;
                    var message = new $root.google.protobuf.Any();
                    if (object.type_url != null)
                        message.type_url = String(object.type_url);
                    if (object.value != null)
                        if (typeof object.value === "string")
                            $util.base64.decode(object.value, message.value = $util.newBuffer($util.base64.length(object.value)), 0);
                        else if (object.value.length >= 0)
                            message.value = object.value;
                    return message;
                };
    
                /**
                 * Creates a plain object from an Any message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.protobuf.Any
                 * @static
                 * @param {google.protobuf.Any} message Any
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                Any.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (options.defaults) {
                        object.type_url = "";
                        if (options.bytes === String)
                            object.value = "";
                        else {
                            object.value = [];
                            if (options.bytes !== Array)
                                object.value = $util.newBuffer(object.value);
                        }
                    }
                    if (message.type_url != null && message.hasOwnProperty("type_url"))
                        object.type_url = message.type_url;
                    if (message.value != null && message.hasOwnProperty("value"))
                        object.value = options.bytes === String ? $util.base64.encode(message.value, 0, message.value.length) : options.bytes === Array ? Array.prototype.slice.call(message.value) : message.value;
                    return object;
                };
    
                /**
                 * Converts this Any to JSON.
                 * @function toJSON
                 * @memberof google.protobuf.Any
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                Any.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for Any
                 * @function getTypeUrl
                 * @memberof google.protobuf.Any
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                Any.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.protobuf.Any";
                };
    
                return Any;
            })();
    
            protobuf.Empty = (function() {
    
                /**
                 * Properties of an Empty.
                 * @memberof google.protobuf
                 * @interface IEmpty
                 */
    
                /**
                 * Constructs a new Empty.
                 * @memberof google.protobuf
                 * @classdesc Represents an Empty.
                 * @implements IEmpty
                 * @constructor
                 * @param {google.protobuf.IEmpty=} [properties] Properties to set
                 */
                function Empty(properties) {
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * Creates a new Empty instance using the specified properties.
                 * @function create
                 * @memberof google.protobuf.Empty
                 * @static
                 * @param {google.protobuf.IEmpty=} [properties] Properties to set
                 * @returns {google.protobuf.Empty} Empty instance
                 */
                Empty.create = function create(properties) {
                    return new Empty(properties);
                };
    
                /**
                 * Encodes the specified Empty message. Does not implicitly {@link google.protobuf.Empty.verify|verify} messages.
                 * @function encode
                 * @memberof google.protobuf.Empty
                 * @static
                 * @param {google.protobuf.IEmpty} message Empty message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                Empty.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    return writer;
                };
    
                /**
                 * Encodes the specified Empty message, length delimited. Does not implicitly {@link google.protobuf.Empty.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.protobuf.Empty
                 * @static
                 * @param {google.protobuf.IEmpty} message Empty message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                Empty.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes an Empty message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.protobuf.Empty
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.protobuf.Empty} Empty
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                Empty.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.protobuf.Empty();
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes an Empty message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.protobuf.Empty
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.protobuf.Empty} Empty
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                Empty.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies an Empty message.
                 * @function verify
                 * @memberof google.protobuf.Empty
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                Empty.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    return null;
                };
    
                /**
                 * Creates an Empty message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.protobuf.Empty
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.protobuf.Empty} Empty
                 */
                Empty.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.protobuf.Empty)
                        return object;
                    return new $root.google.protobuf.Empty();
                };
    
                /**
                 * Creates a plain object from an Empty message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.protobuf.Empty
                 * @static
                 * @param {google.protobuf.Empty} message Empty
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                Empty.toObject = function toObject() {
                    return {};
                };
    
                /**
                 * Converts this Empty to JSON.
                 * @function toJSON
                 * @memberof google.protobuf.Empty
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                Empty.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for Empty
                 * @function getTypeUrl
                 * @memberof google.protobuf.Empty
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                Empty.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.protobuf.Empty";
                };
    
                return Empty;
            })();
    
            protobuf.FieldMask = (function() {
    
                /**
                 * Properties of a FieldMask.
                 * @memberof google.protobuf
                 * @interface IFieldMask
                 * @property {Array.<string>|null} [paths] FieldMask paths
                 */
    
                /**
                 * Constructs a new FieldMask.
                 * @memberof google.protobuf
                 * @classdesc Represents a FieldMask.
                 * @implements IFieldMask
                 * @constructor
                 * @param {google.protobuf.IFieldMask=} [properties] Properties to set
                 */
                function FieldMask(properties) {
                    this.paths = [];
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * FieldMask paths.
                 * @member {Array.<string>} paths
                 * @memberof google.protobuf.FieldMask
                 * @instance
                 */
                FieldMask.prototype.paths = $util.emptyArray;
    
                /**
                 * Creates a new FieldMask instance using the specified properties.
                 * @function create
                 * @memberof google.protobuf.FieldMask
                 * @static
                 * @param {google.protobuf.IFieldMask=} [properties] Properties to set
                 * @returns {google.protobuf.FieldMask} FieldMask instance
                 */
                FieldMask.create = function create(properties) {
                    return new FieldMask(properties);
                };
    
                /**
                 * Encodes the specified FieldMask message. Does not implicitly {@link google.protobuf.FieldMask.verify|verify} messages.
                 * @function encode
                 * @memberof google.protobuf.FieldMask
                 * @static
                 * @param {google.protobuf.IFieldMask} message FieldMask message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                FieldMask.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.paths != null && message.paths.length)
                        for (var i = 0; i < message.paths.length; ++i)
                            writer.uint32(/* id 1, wireType 2 =*/10).string(message.paths[i]);
                    return writer;
                };
    
                /**
                 * Encodes the specified FieldMask message, length delimited. Does not implicitly {@link google.protobuf.FieldMask.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.protobuf.FieldMask
                 * @static
                 * @param {google.protobuf.IFieldMask} message FieldMask message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                FieldMask.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes a FieldMask message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.protobuf.FieldMask
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.protobuf.FieldMask} FieldMask
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                FieldMask.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.protobuf.FieldMask();
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 1: {
                                if (!(message.paths && message.paths.length))
                                    message.paths = [];
                                message.paths.push(reader.string());
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes a FieldMask message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.protobuf.FieldMask
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.protobuf.FieldMask} FieldMask
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                FieldMask.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies a FieldMask message.
                 * @function verify
                 * @memberof google.protobuf.FieldMask
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                FieldMask.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    if (message.paths != null && message.hasOwnProperty("paths")) {
                        if (!Array.isArray(message.paths))
                            return "paths: array expected";
                        for (var i = 0; i < message.paths.length; ++i)
                            if (!$util.isString(message.paths[i]))
                                return "paths: string[] expected";
                    }
                    return null;
                };
    
                /**
                 * Creates a FieldMask message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.protobuf.FieldMask
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.protobuf.FieldMask} FieldMask
                 */
                FieldMask.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.protobuf.FieldMask)
                        return object;
                    var message = new $root.google.protobuf.FieldMask();
                    if (object.paths) {
                        if (!Array.isArray(object.paths))
                            throw TypeError(".google.protobuf.FieldMask.paths: array expected");
                        message.paths = [];
                        for (var i = 0; i < object.paths.length; ++i)
                            message.paths[i] = String(object.paths[i]);
                    }
                    return message;
                };
    
                /**
                 * Creates a plain object from a FieldMask message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.protobuf.FieldMask
                 * @static
                 * @param {google.protobuf.FieldMask} message FieldMask
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                FieldMask.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (options.arrays || options.defaults)
                        object.paths = [];
                    if (message.paths && message.paths.length) {
                        object.paths = [];
                        for (var j = 0; j < message.paths.length; ++j)
                            object.paths[j] = message.paths[j];
                    }
                    return object;
                };
    
                /**
                 * Converts this FieldMask to JSON.
                 * @function toJSON
                 * @memberof google.protobuf.FieldMask
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                FieldMask.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for FieldMask
                 * @function getTypeUrl
                 * @memberof google.protobuf.FieldMask
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                FieldMask.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.protobuf.FieldMask";
                };
    
                return FieldMask;
            })();
    
            protobuf.Struct = (function() {
    
                /**
                 * Properties of a Struct.
                 * @memberof google.protobuf
                 * @interface IStruct
                 * @property {Object.<string,google.protobuf.IValue>|null} [fields] Struct fields
                 */
    
                /**
                 * Constructs a new Struct.
                 * @memberof google.protobuf
                 * @classdesc Represents a Struct.
                 * @implements IStruct
                 * @constructor
                 * @param {google.protobuf.IStruct=} [properties] Properties to set
                 */
                function Struct(properties) {
                    this.fields = {};
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * Struct fields.
                 * @member {Object.<string,google.protobuf.IValue>} fields
                 * @memberof google.protobuf.Struct
                 * @instance
                 */
                Struct.prototype.fields = $util.emptyObject;
    
                /**
                 * Creates a new Struct instance using the specified properties.
                 * @function create
                 * @memberof google.protobuf.Struct
                 * @static
                 * @param {google.protobuf.IStruct=} [properties] Properties to set
                 * @returns {google.protobuf.Struct} Struct instance
                 */
                Struct.create = function create(properties) {
                    return new Struct(properties);
                };
    
                /**
                 * Encodes the specified Struct message. Does not implicitly {@link google.protobuf.Struct.verify|verify} messages.
                 * @function encode
                 * @memberof google.protobuf.Struct
                 * @static
                 * @param {google.protobuf.IStruct} message Struct message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                Struct.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.fields != null && Object.hasOwnProperty.call(message, "fields"))
                        for (var keys = Object.keys(message.fields), i = 0; i < keys.length; ++i) {
                            writer.uint32(/* id 1, wireType 2 =*/10).fork().uint32(/* id 1, wireType 2 =*/10).string(keys[i]);
                            $root.google.protobuf.Value.encode(message.fields[keys[i]], writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim().ldelim();
                        }
                    return writer;
                };
    
                /**
                 * Encodes the specified Struct message, length delimited. Does not implicitly {@link google.protobuf.Struct.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.protobuf.Struct
                 * @static
                 * @param {google.protobuf.IStruct} message Struct message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                Struct.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes a Struct message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.protobuf.Struct
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.protobuf.Struct} Struct
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                Struct.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.protobuf.Struct(), key, value;
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 1: {
                                if (message.fields === $util.emptyObject)
                                    message.fields = {};
                                var end2 = reader.uint32() + reader.pos;
                                key = "";
                                value = null;
                                while (reader.pos < end2) {
                                    var tag2 = reader.uint32();
                                    switch (tag2 >>> 3) {
                                    case 1:
                                        key = reader.string();
                                        break;
                                    case 2:
                                        value = $root.google.protobuf.Value.decode(reader, reader.uint32());
                                        break;
                                    default:
                                        reader.skipType(tag2 & 7);
                                        break;
                                    }
                                }
                                message.fields[key] = value;
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes a Struct message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.protobuf.Struct
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.protobuf.Struct} Struct
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                Struct.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies a Struct message.
                 * @function verify
                 * @memberof google.protobuf.Struct
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                Struct.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    if (message.fields != null && message.hasOwnProperty("fields")) {
                        if (!$util.isObject(message.fields))
                            return "fields: object expected";
                        var key = Object.keys(message.fields);
                        for (var i = 0; i < key.length; ++i) {
                            var error = $root.google.protobuf.Value.verify(message.fields[key[i]]);
                            if (error)
                                return "fields." + error;
                        }
                    }
                    return null;
                };
    
                /**
                 * Creates a Struct message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.protobuf.Struct
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.protobuf.Struct} Struct
                 */
                Struct.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.protobuf.Struct)
                        return object;
                    var message = new $root.google.protobuf.Struct();
                    if (object.fields) {
                        if (typeof object.fields !== "object")
                            throw TypeError(".google.protobuf.Struct.fields: object expected");
                        message.fields = {};
                        for (var keys = Object.keys(object.fields), i = 0; i < keys.length; ++i) {
                            if (typeof object.fields[keys[i]] !== "object")
                                throw TypeError(".google.protobuf.Struct.fields: object expected");
                            message.fields[keys[i]] = $root.google.protobuf.Value.fromObject(object.fields[keys[i]]);
                        }
                    }
                    return message;
                };
    
                /**
                 * Creates a plain object from a Struct message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.protobuf.Struct
                 * @static
                 * @param {google.protobuf.Struct} message Struct
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                Struct.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (options.objects || options.defaults)
                        object.fields = {};
                    var keys2;
                    if (message.fields && (keys2 = Object.keys(message.fields)).length) {
                        object.fields = {};
                        for (var j = 0; j < keys2.length; ++j)
                            object.fields[keys2[j]] = $root.google.protobuf.Value.toObject(message.fields[keys2[j]], options);
                    }
                    return object;
                };
    
                /**
                 * Converts this Struct to JSON.
                 * @function toJSON
                 * @memberof google.protobuf.Struct
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                Struct.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for Struct
                 * @function getTypeUrl
                 * @memberof google.protobuf.Struct
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                Struct.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.protobuf.Struct";
                };
    
                return Struct;
            })();
    
            protobuf.Value = (function() {
    
                /**
                 * Properties of a Value.
                 * @memberof google.protobuf
                 * @interface IValue
                 * @property {google.protobuf.NullValue|null} [nullValue] Value nullValue
                 * @property {number|null} [numberValue] Value numberValue
                 * @property {string|null} [stringValue] Value stringValue
                 * @property {boolean|null} [boolValue] Value boolValue
                 * @property {google.protobuf.IStruct|null} [structValue] Value structValue
                 * @property {google.protobuf.IListValue|null} [listValue] Value listValue
                 */
    
                /**
                 * Constructs a new Value.
                 * @memberof google.protobuf
                 * @classdesc Represents a Value.
                 * @implements IValue
                 * @constructor
                 * @param {google.protobuf.IValue=} [properties] Properties to set
                 */
                function Value(properties) {
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * Value nullValue.
                 * @member {google.protobuf.NullValue|null|undefined} nullValue
                 * @memberof google.protobuf.Value
                 * @instance
                 */
                Value.prototype.nullValue = null;
    
                /**
                 * Value numberValue.
                 * @member {number|null|undefined} numberValue
                 * @memberof google.protobuf.Value
                 * @instance
                 */
                Value.prototype.numberValue = null;
    
                /**
                 * Value stringValue.
                 * @member {string|null|undefined} stringValue
                 * @memberof google.protobuf.Value
                 * @instance
                 */
                Value.prototype.stringValue = null;
    
                /**
                 * Value boolValue.
                 * @member {boolean|null|undefined} boolValue
                 * @memberof google.protobuf.Value
                 * @instance
                 */
                Value.prototype.boolValue = null;
    
                /**
                 * Value structValue.
                 * @member {google.protobuf.IStruct|null|undefined} structValue
                 * @memberof google.protobuf.Value
                 * @instance
                 */
                Value.prototype.structValue = null;
    
                /**
                 * Value listValue.
                 * @member {google.protobuf.IListValue|null|undefined} listValue
                 * @memberof google.protobuf.Value
                 * @instance
                 */
                Value.prototype.listValue = null;
    
                // OneOf field names bound to virtual getters and setters
                var $oneOfFields;
    
                /**
                 * Value kind.
                 * @member {"nullValue"|"numberValue"|"stringValue"|"boolValue"|"structValue"|"listValue"|undefined} kind
                 * @memberof google.protobuf.Value
                 * @instance
                 */
                Object.defineProperty(Value.prototype, "kind", {
                    get: $util.oneOfGetter($oneOfFields = ["nullValue", "numberValue", "stringValue", "boolValue", "structValue", "listValue"]),
                    set: $util.oneOfSetter($oneOfFields)
                });
    
                /**
                 * Creates a new Value instance using the specified properties.
                 * @function create
                 * @memberof google.protobuf.Value
                 * @static
                 * @param {google.protobuf.IValue=} [properties] Properties to set
                 * @returns {google.protobuf.Value} Value instance
                 */
                Value.create = function create(properties) {
                    return new Value(properties);
                };
    
                /**
                 * Encodes the specified Value message. Does not implicitly {@link google.protobuf.Value.verify|verify} messages.
                 * @function encode
                 * @memberof google.protobuf.Value
                 * @static
                 * @param {google.protobuf.IValue} message Value message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                Value.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.nullValue != null && Object.hasOwnProperty.call(message, "nullValue"))
                        writer.uint32(/* id 1, wireType 0 =*/8).int32(message.nullValue);
                    if (message.numberValue != null && Object.hasOwnProperty.call(message, "numberValue"))
                        writer.uint32(/* id 2, wireType 1 =*/17).double(message.numberValue);
                    if (message.stringValue != null && Object.hasOwnProperty.call(message, "stringValue"))
                        writer.uint32(/* id 3, wireType 2 =*/26).string(message.stringValue);
                    if (message.boolValue != null && Object.hasOwnProperty.call(message, "boolValue"))
                        writer.uint32(/* id 4, wireType 0 =*/32).bool(message.boolValue);
                    if (message.structValue != null && Object.hasOwnProperty.call(message, "structValue"))
                        $root.google.protobuf.Struct.encode(message.structValue, writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                    if (message.listValue != null && Object.hasOwnProperty.call(message, "listValue"))
                        $root.google.protobuf.ListValue.encode(message.listValue, writer.uint32(/* id 6, wireType 2 =*/50).fork()).ldelim();
                    return writer;
                };
    
                /**
                 * Encodes the specified Value message, length delimited. Does not implicitly {@link google.protobuf.Value.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.protobuf.Value
                 * @static
                 * @param {google.protobuf.IValue} message Value message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                Value.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes a Value message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.protobuf.Value
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.protobuf.Value} Value
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                Value.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.protobuf.Value();
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 1: {
                                message.nullValue = reader.int32();
                                break;
                            }
                        case 2: {
                                message.numberValue = reader.double();
                                break;
                            }
                        case 3: {
                                message.stringValue = reader.string();
                                break;
                            }
                        case 4: {
                                message.boolValue = reader.bool();
                                break;
                            }
                        case 5: {
                                message.structValue = $root.google.protobuf.Struct.decode(reader, reader.uint32());
                                break;
                            }
                        case 6: {
                                message.listValue = $root.google.protobuf.ListValue.decode(reader, reader.uint32());
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes a Value message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.protobuf.Value
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.protobuf.Value} Value
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                Value.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies a Value message.
                 * @function verify
                 * @memberof google.protobuf.Value
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                Value.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    var properties = {};
                    if (message.nullValue != null && message.hasOwnProperty("nullValue")) {
                        properties.kind = 1;
                        switch (message.nullValue) {
                        default:
                            return "nullValue: enum value expected";
                        case 0:
                            break;
                        }
                    }
                    if (message.numberValue != null && message.hasOwnProperty("numberValue")) {
                        if (properties.kind === 1)
                            return "kind: multiple values";
                        properties.kind = 1;
                        if (typeof message.numberValue !== "number")
                            return "numberValue: number expected";
                    }
                    if (message.stringValue != null && message.hasOwnProperty("stringValue")) {
                        if (properties.kind === 1)
                            return "kind: multiple values";
                        properties.kind = 1;
                        if (!$util.isString(message.stringValue))
                            return "stringValue: string expected";
                    }
                    if (message.boolValue != null && message.hasOwnProperty("boolValue")) {
                        if (properties.kind === 1)
                            return "kind: multiple values";
                        properties.kind = 1;
                        if (typeof message.boolValue !== "boolean")
                            return "boolValue: boolean expected";
                    }
                    if (message.structValue != null && message.hasOwnProperty("structValue")) {
                        if (properties.kind === 1)
                            return "kind: multiple values";
                        properties.kind = 1;
                        {
                            var error = $root.google.protobuf.Struct.verify(message.structValue);
                            if (error)
                                return "structValue." + error;
                        }
                    }
                    if (message.listValue != null && message.hasOwnProperty("listValue")) {
                        if (properties.kind === 1)
                            return "kind: multiple values";
                        properties.kind = 1;
                        {
                            var error = $root.google.protobuf.ListValue.verify(message.listValue);
                            if (error)
                                return "listValue." + error;
                        }
                    }
                    return null;
                };
    
                /**
                 * Creates a Value message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.protobuf.Value
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.protobuf.Value} Value
                 */
                Value.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.protobuf.Value)
                        return object;
                    var message = new $root.google.protobuf.Value();
                    switch (object.nullValue) {
                    default:
                        if (typeof object.nullValue === "number") {
                            message.nullValue = object.nullValue;
                            break;
                        }
                        break;
                    case "NULL_VALUE":
                    case 0:
                        message.nullValue = 0;
                        break;
                    }
                    if (object.numberValue != null)
                        message.numberValue = Number(object.numberValue);
                    if (object.stringValue != null)
                        message.stringValue = String(object.stringValue);
                    if (object.boolValue != null)
                        message.boolValue = Boolean(object.boolValue);
                    if (object.structValue != null) {
                        if (typeof object.structValue !== "object")
                            throw TypeError(".google.protobuf.Value.structValue: object expected");
                        message.structValue = $root.google.protobuf.Struct.fromObject(object.structValue);
                    }
                    if (object.listValue != null) {
                        if (typeof object.listValue !== "object")
                            throw TypeError(".google.protobuf.Value.listValue: object expected");
                        message.listValue = $root.google.protobuf.ListValue.fromObject(object.listValue);
                    }
                    return message;
                };
    
                /**
                 * Creates a plain object from a Value message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.protobuf.Value
                 * @static
                 * @param {google.protobuf.Value} message Value
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                Value.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (message.nullValue != null && message.hasOwnProperty("nullValue")) {
                        object.nullValue = options.enums === String ? $root.google.protobuf.NullValue[message.nullValue] === undefined ? message.nullValue : $root.google.protobuf.NullValue[message.nullValue] : message.nullValue;
                        if (options.oneofs)
                            object.kind = "nullValue";
                    }
                    if (message.numberValue != null && message.hasOwnProperty("numberValue")) {
                        object.numberValue = options.json && !isFinite(message.numberValue) ? String(message.numberValue) : message.numberValue;
                        if (options.oneofs)
                            object.kind = "numberValue";
                    }
                    if (message.stringValue != null && message.hasOwnProperty("stringValue")) {
                        object.stringValue = message.stringValue;
                        if (options.oneofs)
                            object.kind = "stringValue";
                    }
                    if (message.boolValue != null && message.hasOwnProperty("boolValue")) {
                        object.boolValue = message.boolValue;
                        if (options.oneofs)
                            object.kind = "boolValue";
                    }
                    if (message.structValue != null && message.hasOwnProperty("structValue")) {
                        object.structValue = $root.google.protobuf.Struct.toObject(message.structValue, options);
                        if (options.oneofs)
                            object.kind = "structValue";
                    }
                    if (message.listValue != null && message.hasOwnProperty("listValue")) {
                        object.listValue = $root.google.protobuf.ListValue.toObject(message.listValue, options);
                        if (options.oneofs)
                            object.kind = "listValue";
                    }
                    return object;
                };
    
                /**
                 * Converts this Value to JSON.
                 * @function toJSON
                 * @memberof google.protobuf.Value
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                Value.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for Value
                 * @function getTypeUrl
                 * @memberof google.protobuf.Value
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                Value.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.protobuf.Value";
                };
    
                return Value;
            })();
    
            /**
             * NullValue enum.
             * @name google.protobuf.NullValue
             * @enum {number}
             * @property {number} NULL_VALUE=0 NULL_VALUE value
             */
            protobuf.NullValue = (function() {
                var valuesById = {}, values = Object.create(valuesById);
                values[valuesById[0] = "NULL_VALUE"] = 0;
                return values;
            })();
    
            protobuf.ListValue = (function() {
    
                /**
                 * Properties of a ListValue.
                 * @memberof google.protobuf
                 * @interface IListValue
                 * @property {Array.<google.protobuf.IValue>|null} [values] ListValue values
                 */
    
                /**
                 * Constructs a new ListValue.
                 * @memberof google.protobuf
                 * @classdesc Represents a ListValue.
                 * @implements IListValue
                 * @constructor
                 * @param {google.protobuf.IListValue=} [properties] Properties to set
                 */
                function ListValue(properties) {
                    this.values = [];
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * ListValue values.
                 * @member {Array.<google.protobuf.IValue>} values
                 * @memberof google.protobuf.ListValue
                 * @instance
                 */
                ListValue.prototype.values = $util.emptyArray;
    
                /**
                 * Creates a new ListValue instance using the specified properties.
                 * @function create
                 * @memberof google.protobuf.ListValue
                 * @static
                 * @param {google.protobuf.IListValue=} [properties] Properties to set
                 * @returns {google.protobuf.ListValue} ListValue instance
                 */
                ListValue.create = function create(properties) {
                    return new ListValue(properties);
                };
    
                /**
                 * Encodes the specified ListValue message. Does not implicitly {@link google.protobuf.ListValue.verify|verify} messages.
                 * @function encode
                 * @memberof google.protobuf.ListValue
                 * @static
                 * @param {google.protobuf.IListValue} message ListValue message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                ListValue.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.values != null && message.values.length)
                        for (var i = 0; i < message.values.length; ++i)
                            $root.google.protobuf.Value.encode(message.values[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                    return writer;
                };
    
                /**
                 * Encodes the specified ListValue message, length delimited. Does not implicitly {@link google.protobuf.ListValue.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.protobuf.ListValue
                 * @static
                 * @param {google.protobuf.IListValue} message ListValue message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                ListValue.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes a ListValue message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.protobuf.ListValue
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.protobuf.ListValue} ListValue
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                ListValue.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.protobuf.ListValue();
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 1: {
                                if (!(message.values && message.values.length))
                                    message.values = [];
                                message.values.push($root.google.protobuf.Value.decode(reader, reader.uint32()));
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes a ListValue message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.protobuf.ListValue
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.protobuf.ListValue} ListValue
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                ListValue.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies a ListValue message.
                 * @function verify
                 * @memberof google.protobuf.ListValue
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                ListValue.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    if (message.values != null && message.hasOwnProperty("values")) {
                        if (!Array.isArray(message.values))
                            return "values: array expected";
                        for (var i = 0; i < message.values.length; ++i) {
                            var error = $root.google.protobuf.Value.verify(message.values[i]);
                            if (error)
                                return "values." + error;
                        }
                    }
                    return null;
                };
    
                /**
                 * Creates a ListValue message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.protobuf.ListValue
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.protobuf.ListValue} ListValue
                 */
                ListValue.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.protobuf.ListValue)
                        return object;
                    var message = new $root.google.protobuf.ListValue();
                    if (object.values) {
                        if (!Array.isArray(object.values))
                            throw TypeError(".google.protobuf.ListValue.values: array expected");
                        message.values = [];
                        for (var i = 0; i < object.values.length; ++i) {
                            if (typeof object.values[i] !== "object")
                                throw TypeError(".google.protobuf.ListValue.values: object expected");
                            message.values[i] = $root.google.protobuf.Value.fromObject(object.values[i]);
                        }
                    }
                    return message;
                };
    
                /**
                 * Creates a plain object from a ListValue message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.protobuf.ListValue
                 * @static
                 * @param {google.protobuf.ListValue} message ListValue
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                ListValue.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (options.arrays || options.defaults)
                        object.values = [];
                    if (message.values && message.values.length) {
                        object.values = [];
                        for (var j = 0; j < message.values.length; ++j)
                            object.values[j] = $root.google.protobuf.Value.toObject(message.values[j], options);
                    }
                    return object;
                };
    
                /**
                 * Converts this ListValue to JSON.
                 * @function toJSON
                 * @memberof google.protobuf.ListValue
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                ListValue.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for ListValue
                 * @function getTypeUrl
                 * @memberof google.protobuf.ListValue
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                ListValue.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.protobuf.ListValue";
                };
    
                return ListValue;
            })();
    
            protobuf.Timestamp = (function() {
    
                /**
                 * Properties of a Timestamp.
                 * @memberof google.protobuf
                 * @interface ITimestamp
                 * @property {number|Long|null} [seconds] Timestamp seconds
                 * @property {number|null} [nanos] Timestamp nanos
                 */
    
                /**
                 * Constructs a new Timestamp.
                 * @memberof google.protobuf
                 * @classdesc Represents a Timestamp.
                 * @implements ITimestamp
                 * @constructor
                 * @param {google.protobuf.ITimestamp=} [properties] Properties to set
                 */
                function Timestamp(properties) {
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * Timestamp seconds.
                 * @member {number|Long} seconds
                 * @memberof google.protobuf.Timestamp
                 * @instance
                 */
                Timestamp.prototype.seconds = $util.Long ? $util.Long.fromBits(0,0,false) : 0;
    
                /**
                 * Timestamp nanos.
                 * @member {number} nanos
                 * @memberof google.protobuf.Timestamp
                 * @instance
                 */
                Timestamp.prototype.nanos = 0;
    
                /**
                 * Creates a new Timestamp instance using the specified properties.
                 * @function create
                 * @memberof google.protobuf.Timestamp
                 * @static
                 * @param {google.protobuf.ITimestamp=} [properties] Properties to set
                 * @returns {google.protobuf.Timestamp} Timestamp instance
                 */
                Timestamp.create = function create(properties) {
                    return new Timestamp(properties);
                };
    
                /**
                 * Encodes the specified Timestamp message. Does not implicitly {@link google.protobuf.Timestamp.verify|verify} messages.
                 * @function encode
                 * @memberof google.protobuf.Timestamp
                 * @static
                 * @param {google.protobuf.ITimestamp} message Timestamp message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                Timestamp.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.seconds != null && Object.hasOwnProperty.call(message, "seconds"))
                        writer.uint32(/* id 1, wireType 0 =*/8).int64(message.seconds);
                    if (message.nanos != null && Object.hasOwnProperty.call(message, "nanos"))
                        writer.uint32(/* id 2, wireType 0 =*/16).int32(message.nanos);
                    return writer;
                };
    
                /**
                 * Encodes the specified Timestamp message, length delimited. Does not implicitly {@link google.protobuf.Timestamp.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.protobuf.Timestamp
                 * @static
                 * @param {google.protobuf.ITimestamp} message Timestamp message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                Timestamp.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes a Timestamp message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.protobuf.Timestamp
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.protobuf.Timestamp} Timestamp
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                Timestamp.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.protobuf.Timestamp();
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 1: {
                                message.seconds = reader.int64();
                                break;
                            }
                        case 2: {
                                message.nanos = reader.int32();
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes a Timestamp message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.protobuf.Timestamp
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.protobuf.Timestamp} Timestamp
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                Timestamp.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies a Timestamp message.
                 * @function verify
                 * @memberof google.protobuf.Timestamp
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                Timestamp.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    if (message.seconds != null && message.hasOwnProperty("seconds"))
                        if (!$util.isInteger(message.seconds) && !(message.seconds && $util.isInteger(message.seconds.low) && $util.isInteger(message.seconds.high)))
                            return "seconds: integer|Long expected";
                    if (message.nanos != null && message.hasOwnProperty("nanos"))
                        if (!$util.isInteger(message.nanos))
                            return "nanos: integer expected";
                    return null;
                };
    
                /**
                 * Creates a Timestamp message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.protobuf.Timestamp
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.protobuf.Timestamp} Timestamp
                 */
                Timestamp.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.protobuf.Timestamp)
                        return object;
                    var message = new $root.google.protobuf.Timestamp();
                    if (object.seconds != null)
                        if ($util.Long)
                            (message.seconds = $util.Long.fromValue(object.seconds)).unsigned = false;
                        else if (typeof object.seconds === "string")
                            message.seconds = parseInt(object.seconds, 10);
                        else if (typeof object.seconds === "number")
                            message.seconds = object.seconds;
                        else if (typeof object.seconds === "object")
                            message.seconds = new $util.LongBits(object.seconds.low >>> 0, object.seconds.high >>> 0).toNumber();
                    if (object.nanos != null)
                        message.nanos = object.nanos | 0;
                    return message;
                };
    
                /**
                 * Creates a plain object from a Timestamp message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.protobuf.Timestamp
                 * @static
                 * @param {google.protobuf.Timestamp} message Timestamp
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                Timestamp.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (options.defaults) {
                        if ($util.Long) {
                            var long = new $util.Long(0, 0, false);
                            object.seconds = options.longs === String ? long.toString() : options.longs === Number ? long.toNumber() : long;
                        } else
                            object.seconds = options.longs === String ? "0" : 0;
                        object.nanos = 0;
                    }
                    if (message.seconds != null && message.hasOwnProperty("seconds"))
                        if (typeof message.seconds === "number")
                            object.seconds = options.longs === String ? String(message.seconds) : message.seconds;
                        else
                            object.seconds = options.longs === String ? $util.Long.prototype.toString.call(message.seconds) : options.longs === Number ? new $util.LongBits(message.seconds.low >>> 0, message.seconds.high >>> 0).toNumber() : message.seconds;
                    if (message.nanos != null && message.hasOwnProperty("nanos"))
                        object.nanos = message.nanos;
                    return object;
                };
    
                /**
                 * Converts this Timestamp to JSON.
                 * @function toJSON
                 * @memberof google.protobuf.Timestamp
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                Timestamp.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for Timestamp
                 * @function getTypeUrl
                 * @memberof google.protobuf.Timestamp
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                Timestamp.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.protobuf.Timestamp";
                };
    
                return Timestamp;
            })();
    
            return protobuf;
        })();
    
        google.longrunning = (function() {
    
            /**
             * Namespace longrunning.
             * @memberof google
             * @namespace
             */
            var longrunning = {};
    
            longrunning.Operations = (function() {
    
                /**
                 * Constructs a new Operations service.
                 * @memberof google.longrunning
                 * @classdesc Represents an Operations
                 * @extends $protobuf.rpc.Service
                 * @constructor
                 * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                 * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                 * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                 */
                function Operations(rpcImpl, requestDelimited, responseDelimited) {
                    $protobuf.rpc.Service.call(this, rpcImpl, requestDelimited, responseDelimited);
                }
    
                (Operations.prototype = Object.create($protobuf.rpc.Service.prototype)).constructor = Operations;
    
                /**
                 * Creates new Operations service using the specified rpc implementation.
                 * @function create
                 * @memberof google.longrunning.Operations
                 * @static
                 * @param {$protobuf.RPCImpl} rpcImpl RPC implementation
                 * @param {boolean} [requestDelimited=false] Whether requests are length-delimited
                 * @param {boolean} [responseDelimited=false] Whether responses are length-delimited
                 * @returns {Operations} RPC service. Useful where requests and/or responses are streamed.
                 */
                Operations.create = function create(rpcImpl, requestDelimited, responseDelimited) {
                    return new this(rpcImpl, requestDelimited, responseDelimited);
                };
    
                /**
                 * Callback as used by {@link google.longrunning.Operations|listOperations}.
                 * @memberof google.longrunning.Operations
                 * @typedef ListOperationsCallback
                 * @type {function}
                 * @param {Error|null} error Error, if any
                 * @param {google.longrunning.ListOperationsResponse} [response] ListOperationsResponse
                 */
    
                /**
                 * Calls ListOperations.
                 * @function listOperations
                 * @memberof google.longrunning.Operations
                 * @instance
                 * @param {google.longrunning.IListOperationsRequest} request ListOperationsRequest message or plain object
                 * @param {google.longrunning.Operations.ListOperationsCallback} callback Node-style callback called with the error, if any, and ListOperationsResponse
                 * @returns {undefined}
                 * @variation 1
                 */
                Object.defineProperty(Operations.prototype.listOperations = function listOperations(request, callback) {
                    return this.rpcCall(listOperations, $root.google.longrunning.ListOperationsRequest, $root.google.longrunning.ListOperationsResponse, request, callback);
                }, "name", { value: "ListOperations" });
    
                /**
                 * Calls ListOperations.
                 * @function listOperations
                 * @memberof google.longrunning.Operations
                 * @instance
                 * @param {google.longrunning.IListOperationsRequest} request ListOperationsRequest message or plain object
                 * @returns {Promise<google.longrunning.ListOperationsResponse>} Promise
                 * @variation 2
                 */
    
                /**
                 * Callback as used by {@link google.longrunning.Operations|getOperation}.
                 * @memberof google.longrunning.Operations
                 * @typedef GetOperationCallback
                 * @type {function}
                 * @param {Error|null} error Error, if any
                 * @param {google.longrunning.Operation} [response] Operation
                 */
    
                /**
                 * Calls GetOperation.
                 * @function getOperation
                 * @memberof google.longrunning.Operations
                 * @instance
                 * @param {google.longrunning.IGetOperationRequest} request GetOperationRequest message or plain object
                 * @param {google.longrunning.Operations.GetOperationCallback} callback Node-style callback called with the error, if any, and Operation
                 * @returns {undefined}
                 * @variation 1
                 */
                Object.defineProperty(Operations.prototype.getOperation = function getOperation(request, callback) {
                    return this.rpcCall(getOperation, $root.google.longrunning.GetOperationRequest, $root.google.longrunning.Operation, request, callback);
                }, "name", { value: "GetOperation" });
    
                /**
                 * Calls GetOperation.
                 * @function getOperation
                 * @memberof google.longrunning.Operations
                 * @instance
                 * @param {google.longrunning.IGetOperationRequest} request GetOperationRequest message or plain object
                 * @returns {Promise<google.longrunning.Operation>} Promise
                 * @variation 2
                 */
    
                /**
                 * Callback as used by {@link google.longrunning.Operations|deleteOperation}.
                 * @memberof google.longrunning.Operations
                 * @typedef DeleteOperationCallback
                 * @type {function}
                 * @param {Error|null} error Error, if any
                 * @param {google.protobuf.Empty} [response] Empty
                 */
    
                /**
                 * Calls DeleteOperation.
                 * @function deleteOperation
                 * @memberof google.longrunning.Operations
                 * @instance
                 * @param {google.longrunning.IDeleteOperationRequest} request DeleteOperationRequest message or plain object
                 * @param {google.longrunning.Operations.DeleteOperationCallback} callback Node-style callback called with the error, if any, and Empty
                 * @returns {undefined}
                 * @variation 1
                 */
                Object.defineProperty(Operations.prototype.deleteOperation = function deleteOperation(request, callback) {
                    return this.rpcCall(deleteOperation, $root.google.longrunning.DeleteOperationRequest, $root.google.protobuf.Empty, request, callback);
                }, "name", { value: "DeleteOperation" });
    
                /**
                 * Calls DeleteOperation.
                 * @function deleteOperation
                 * @memberof google.longrunning.Operations
                 * @instance
                 * @param {google.longrunning.IDeleteOperationRequest} request DeleteOperationRequest message or plain object
                 * @returns {Promise<google.protobuf.Empty>} Promise
                 * @variation 2
                 */
    
                /**
                 * Callback as used by {@link google.longrunning.Operations|cancelOperation}.
                 * @memberof google.longrunning.Operations
                 * @typedef CancelOperationCallback
                 * @type {function}
                 * @param {Error|null} error Error, if any
                 * @param {google.protobuf.Empty} [response] Empty
                 */
    
                /**
                 * Calls CancelOperation.
                 * @function cancelOperation
                 * @memberof google.longrunning.Operations
                 * @instance
                 * @param {google.longrunning.ICancelOperationRequest} request CancelOperationRequest message or plain object
                 * @param {google.longrunning.Operations.CancelOperationCallback} callback Node-style callback called with the error, if any, and Empty
                 * @returns {undefined}
                 * @variation 1
                 */
                Object.defineProperty(Operations.prototype.cancelOperation = function cancelOperation(request, callback) {
                    return this.rpcCall(cancelOperation, $root.google.longrunning.CancelOperationRequest, $root.google.protobuf.Empty, request, callback);
                }, "name", { value: "CancelOperation" });
    
                /**
                 * Calls CancelOperation.
                 * @function cancelOperation
                 * @memberof google.longrunning.Operations
                 * @instance
                 * @param {google.longrunning.ICancelOperationRequest} request CancelOperationRequest message or plain object
                 * @returns {Promise<google.protobuf.Empty>} Promise
                 * @variation 2
                 */
    
                /**
                 * Callback as used by {@link google.longrunning.Operations|waitOperation}.
                 * @memberof google.longrunning.Operations
                 * @typedef WaitOperationCallback
                 * @type {function}
                 * @param {Error|null} error Error, if any
                 * @param {google.longrunning.Operation} [response] Operation
                 */
    
                /**
                 * Calls WaitOperation.
                 * @function waitOperation
                 * @memberof google.longrunning.Operations
                 * @instance
                 * @param {google.longrunning.IWaitOperationRequest} request WaitOperationRequest message or plain object
                 * @param {google.longrunning.Operations.WaitOperationCallback} callback Node-style callback called with the error, if any, and Operation
                 * @returns {undefined}
                 * @variation 1
                 */
                Object.defineProperty(Operations.prototype.waitOperation = function waitOperation(request, callback) {
                    return this.rpcCall(waitOperation, $root.google.longrunning.WaitOperationRequest, $root.google.longrunning.Operation, request, callback);
                }, "name", { value: "WaitOperation" });
    
                /**
                 * Calls WaitOperation.
                 * @function waitOperation
                 * @memberof google.longrunning.Operations
                 * @instance
                 * @param {google.longrunning.IWaitOperationRequest} request WaitOperationRequest message or plain object
                 * @returns {Promise<google.longrunning.Operation>} Promise
                 * @variation 2
                 */
    
                return Operations;
            })();
    
            longrunning.Operation = (function() {
    
                /**
                 * Properties of an Operation.
                 * @memberof google.longrunning
                 * @interface IOperation
                 * @property {string|null} [name] Operation name
                 * @property {google.protobuf.IAny|null} [metadata] Operation metadata
                 * @property {boolean|null} [done] Operation done
                 * @property {google.rpc.IStatus|null} [error] Operation error
                 * @property {google.protobuf.IAny|null} [response] Operation response
                 */
    
                /**
                 * Constructs a new Operation.
                 * @memberof google.longrunning
                 * @classdesc Represents an Operation.
                 * @implements IOperation
                 * @constructor
                 * @param {google.longrunning.IOperation=} [properties] Properties to set
                 */
                function Operation(properties) {
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * Operation name.
                 * @member {string} name
                 * @memberof google.longrunning.Operation
                 * @instance
                 */
                Operation.prototype.name = "";
    
                /**
                 * Operation metadata.
                 * @member {google.protobuf.IAny|null|undefined} metadata
                 * @memberof google.longrunning.Operation
                 * @instance
                 */
                Operation.prototype.metadata = null;
    
                /**
                 * Operation done.
                 * @member {boolean} done
                 * @memberof google.longrunning.Operation
                 * @instance
                 */
                Operation.prototype.done = false;
    
                /**
                 * Operation error.
                 * @member {google.rpc.IStatus|null|undefined} error
                 * @memberof google.longrunning.Operation
                 * @instance
                 */
                Operation.prototype.error = null;
    
                /**
                 * Operation response.
                 * @member {google.protobuf.IAny|null|undefined} response
                 * @memberof google.longrunning.Operation
                 * @instance
                 */
                Operation.prototype.response = null;
    
                // OneOf field names bound to virtual getters and setters
                var $oneOfFields;
    
                /**
                 * Operation result.
                 * @member {"error"|"response"|undefined} result
                 * @memberof google.longrunning.Operation
                 * @instance
                 */
                Object.defineProperty(Operation.prototype, "result", {
                    get: $util.oneOfGetter($oneOfFields = ["error", "response"]),
                    set: $util.oneOfSetter($oneOfFields)
                });
    
                /**
                 * Creates a new Operation instance using the specified properties.
                 * @function create
                 * @memberof google.longrunning.Operation
                 * @static
                 * @param {google.longrunning.IOperation=} [properties] Properties to set
                 * @returns {google.longrunning.Operation} Operation instance
                 */
                Operation.create = function create(properties) {
                    return new Operation(properties);
                };
    
                /**
                 * Encodes the specified Operation message. Does not implicitly {@link google.longrunning.Operation.verify|verify} messages.
                 * @function encode
                 * @memberof google.longrunning.Operation
                 * @static
                 * @param {google.longrunning.IOperation} message Operation message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                Operation.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                    if (message.metadata != null && Object.hasOwnProperty.call(message, "metadata"))
                        $root.google.protobuf.Any.encode(message.metadata, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                    if (message.done != null && Object.hasOwnProperty.call(message, "done"))
                        writer.uint32(/* id 3, wireType 0 =*/24).bool(message.done);
                    if (message.error != null && Object.hasOwnProperty.call(message, "error"))
                        $root.google.rpc.Status.encode(message.error, writer.uint32(/* id 4, wireType 2 =*/34).fork()).ldelim();
                    if (message.response != null && Object.hasOwnProperty.call(message, "response"))
                        $root.google.protobuf.Any.encode(message.response, writer.uint32(/* id 5, wireType 2 =*/42).fork()).ldelim();
                    return writer;
                };
    
                /**
                 * Encodes the specified Operation message, length delimited. Does not implicitly {@link google.longrunning.Operation.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.longrunning.Operation
                 * @static
                 * @param {google.longrunning.IOperation} message Operation message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                Operation.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes an Operation message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.longrunning.Operation
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.longrunning.Operation} Operation
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                Operation.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.longrunning.Operation();
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 1: {
                                message.name = reader.string();
                                break;
                            }
                        case 2: {
                                message.metadata = $root.google.protobuf.Any.decode(reader, reader.uint32());
                                break;
                            }
                        case 3: {
                                message.done = reader.bool();
                                break;
                            }
                        case 4: {
                                message.error = $root.google.rpc.Status.decode(reader, reader.uint32());
                                break;
                            }
                        case 5: {
                                message.response = $root.google.protobuf.Any.decode(reader, reader.uint32());
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes an Operation message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.longrunning.Operation
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.longrunning.Operation} Operation
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                Operation.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies an Operation message.
                 * @function verify
                 * @memberof google.longrunning.Operation
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                Operation.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    var properties = {};
                    if (message.name != null && message.hasOwnProperty("name"))
                        if (!$util.isString(message.name))
                            return "name: string expected";
                    if (message.metadata != null && message.hasOwnProperty("metadata")) {
                        var error = $root.google.protobuf.Any.verify(message.metadata);
                        if (error)
                            return "metadata." + error;
                    }
                    if (message.done != null && message.hasOwnProperty("done"))
                        if (typeof message.done !== "boolean")
                            return "done: boolean expected";
                    if (message.error != null && message.hasOwnProperty("error")) {
                        properties.result = 1;
                        {
                            var error = $root.google.rpc.Status.verify(message.error);
                            if (error)
                                return "error." + error;
                        }
                    }
                    if (message.response != null && message.hasOwnProperty("response")) {
                        if (properties.result === 1)
                            return "result: multiple values";
                        properties.result = 1;
                        {
                            var error = $root.google.protobuf.Any.verify(message.response);
                            if (error)
                                return "response." + error;
                        }
                    }
                    return null;
                };
    
                /**
                 * Creates an Operation message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.longrunning.Operation
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.longrunning.Operation} Operation
                 */
                Operation.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.longrunning.Operation)
                        return object;
                    var message = new $root.google.longrunning.Operation();
                    if (object.name != null)
                        message.name = String(object.name);
                    if (object.metadata != null) {
                        if (typeof object.metadata !== "object")
                            throw TypeError(".google.longrunning.Operation.metadata: object expected");
                        message.metadata = $root.google.protobuf.Any.fromObject(object.metadata);
                    }
                    if (object.done != null)
                        message.done = Boolean(object.done);
                    if (object.error != null) {
                        if (typeof object.error !== "object")
                            throw TypeError(".google.longrunning.Operation.error: object expected");
                        message.error = $root.google.rpc.Status.fromObject(object.error);
                    }
                    if (object.response != null) {
                        if (typeof object.response !== "object")
                            throw TypeError(".google.longrunning.Operation.response: object expected");
                        message.response = $root.google.protobuf.Any.fromObject(object.response);
                    }
                    return message;
                };
    
                /**
                 * Creates a plain object from an Operation message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.longrunning.Operation
                 * @static
                 * @param {google.longrunning.Operation} message Operation
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                Operation.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (options.defaults) {
                        object.name = "";
                        object.metadata = null;
                        object.done = false;
                    }
                    if (message.name != null && message.hasOwnProperty("name"))
                        object.name = message.name;
                    if (message.metadata != null && message.hasOwnProperty("metadata"))
                        object.metadata = $root.google.protobuf.Any.toObject(message.metadata, options);
                    if (message.done != null && message.hasOwnProperty("done"))
                        object.done = message.done;
                    if (message.error != null && message.hasOwnProperty("error")) {
                        object.error = $root.google.rpc.Status.toObject(message.error, options);
                        if (options.oneofs)
                            object.result = "error";
                    }
                    if (message.response != null && message.hasOwnProperty("response")) {
                        object.response = $root.google.protobuf.Any.toObject(message.response, options);
                        if (options.oneofs)
                            object.result = "response";
                    }
                    return object;
                };
    
                /**
                 * Converts this Operation to JSON.
                 * @function toJSON
                 * @memberof google.longrunning.Operation
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                Operation.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for Operation
                 * @function getTypeUrl
                 * @memberof google.longrunning.Operation
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                Operation.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.longrunning.Operation";
                };
    
                return Operation;
            })();
    
            longrunning.GetOperationRequest = (function() {
    
                /**
                 * Properties of a GetOperationRequest.
                 * @memberof google.longrunning
                 * @interface IGetOperationRequest
                 * @property {string|null} [name] GetOperationRequest name
                 */
    
                /**
                 * Constructs a new GetOperationRequest.
                 * @memberof google.longrunning
                 * @classdesc Represents a GetOperationRequest.
                 * @implements IGetOperationRequest
                 * @constructor
                 * @param {google.longrunning.IGetOperationRequest=} [properties] Properties to set
                 */
                function GetOperationRequest(properties) {
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * GetOperationRequest name.
                 * @member {string} name
                 * @memberof google.longrunning.GetOperationRequest
                 * @instance
                 */
                GetOperationRequest.prototype.name = "";
    
                /**
                 * Creates a new GetOperationRequest instance using the specified properties.
                 * @function create
                 * @memberof google.longrunning.GetOperationRequest
                 * @static
                 * @param {google.longrunning.IGetOperationRequest=} [properties] Properties to set
                 * @returns {google.longrunning.GetOperationRequest} GetOperationRequest instance
                 */
                GetOperationRequest.create = function create(properties) {
                    return new GetOperationRequest(properties);
                };
    
                /**
                 * Encodes the specified GetOperationRequest message. Does not implicitly {@link google.longrunning.GetOperationRequest.verify|verify} messages.
                 * @function encode
                 * @memberof google.longrunning.GetOperationRequest
                 * @static
                 * @param {google.longrunning.IGetOperationRequest} message GetOperationRequest message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                GetOperationRequest.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                    return writer;
                };
    
                /**
                 * Encodes the specified GetOperationRequest message, length delimited. Does not implicitly {@link google.longrunning.GetOperationRequest.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.longrunning.GetOperationRequest
                 * @static
                 * @param {google.longrunning.IGetOperationRequest} message GetOperationRequest message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                GetOperationRequest.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes a GetOperationRequest message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.longrunning.GetOperationRequest
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.longrunning.GetOperationRequest} GetOperationRequest
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                GetOperationRequest.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.longrunning.GetOperationRequest();
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 1: {
                                message.name = reader.string();
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes a GetOperationRequest message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.longrunning.GetOperationRequest
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.longrunning.GetOperationRequest} GetOperationRequest
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                GetOperationRequest.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies a GetOperationRequest message.
                 * @function verify
                 * @memberof google.longrunning.GetOperationRequest
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                GetOperationRequest.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    if (message.name != null && message.hasOwnProperty("name"))
                        if (!$util.isString(message.name))
                            return "name: string expected";
                    return null;
                };
    
                /**
                 * Creates a GetOperationRequest message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.longrunning.GetOperationRequest
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.longrunning.GetOperationRequest} GetOperationRequest
                 */
                GetOperationRequest.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.longrunning.GetOperationRequest)
                        return object;
                    var message = new $root.google.longrunning.GetOperationRequest();
                    if (object.name != null)
                        message.name = String(object.name);
                    return message;
                };
    
                /**
                 * Creates a plain object from a GetOperationRequest message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.longrunning.GetOperationRequest
                 * @static
                 * @param {google.longrunning.GetOperationRequest} message GetOperationRequest
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                GetOperationRequest.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (options.defaults)
                        object.name = "";
                    if (message.name != null && message.hasOwnProperty("name"))
                        object.name = message.name;
                    return object;
                };
    
                /**
                 * Converts this GetOperationRequest to JSON.
                 * @function toJSON
                 * @memberof google.longrunning.GetOperationRequest
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                GetOperationRequest.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for GetOperationRequest
                 * @function getTypeUrl
                 * @memberof google.longrunning.GetOperationRequest
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                GetOperationRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.longrunning.GetOperationRequest";
                };
    
                return GetOperationRequest;
            })();
    
            longrunning.ListOperationsRequest = (function() {
    
                /**
                 * Properties of a ListOperationsRequest.
                 * @memberof google.longrunning
                 * @interface IListOperationsRequest
                 * @property {string|null} [name] ListOperationsRequest name
                 * @property {string|null} [filter] ListOperationsRequest filter
                 * @property {number|null} [pageSize] ListOperationsRequest pageSize
                 * @property {string|null} [pageToken] ListOperationsRequest pageToken
                 */
    
                /**
                 * Constructs a new ListOperationsRequest.
                 * @memberof google.longrunning
                 * @classdesc Represents a ListOperationsRequest.
                 * @implements IListOperationsRequest
                 * @constructor
                 * @param {google.longrunning.IListOperationsRequest=} [properties] Properties to set
                 */
                function ListOperationsRequest(properties) {
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * ListOperationsRequest name.
                 * @member {string} name
                 * @memberof google.longrunning.ListOperationsRequest
                 * @instance
                 */
                ListOperationsRequest.prototype.name = "";
    
                /**
                 * ListOperationsRequest filter.
                 * @member {string} filter
                 * @memberof google.longrunning.ListOperationsRequest
                 * @instance
                 */
                ListOperationsRequest.prototype.filter = "";
    
                /**
                 * ListOperationsRequest pageSize.
                 * @member {number} pageSize
                 * @memberof google.longrunning.ListOperationsRequest
                 * @instance
                 */
                ListOperationsRequest.prototype.pageSize = 0;
    
                /**
                 * ListOperationsRequest pageToken.
                 * @member {string} pageToken
                 * @memberof google.longrunning.ListOperationsRequest
                 * @instance
                 */
                ListOperationsRequest.prototype.pageToken = "";
    
                /**
                 * Creates a new ListOperationsRequest instance using the specified properties.
                 * @function create
                 * @memberof google.longrunning.ListOperationsRequest
                 * @static
                 * @param {google.longrunning.IListOperationsRequest=} [properties] Properties to set
                 * @returns {google.longrunning.ListOperationsRequest} ListOperationsRequest instance
                 */
                ListOperationsRequest.create = function create(properties) {
                    return new ListOperationsRequest(properties);
                };
    
                /**
                 * Encodes the specified ListOperationsRequest message. Does not implicitly {@link google.longrunning.ListOperationsRequest.verify|verify} messages.
                 * @function encode
                 * @memberof google.longrunning.ListOperationsRequest
                 * @static
                 * @param {google.longrunning.IListOperationsRequest} message ListOperationsRequest message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                ListOperationsRequest.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.filter != null && Object.hasOwnProperty.call(message, "filter"))
                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.filter);
                    if (message.pageSize != null && Object.hasOwnProperty.call(message, "pageSize"))
                        writer.uint32(/* id 2, wireType 0 =*/16).int32(message.pageSize);
                    if (message.pageToken != null && Object.hasOwnProperty.call(message, "pageToken"))
                        writer.uint32(/* id 3, wireType 2 =*/26).string(message.pageToken);
                    if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                        writer.uint32(/* id 4, wireType 2 =*/34).string(message.name);
                    return writer;
                };
    
                /**
                 * Encodes the specified ListOperationsRequest message, length delimited. Does not implicitly {@link google.longrunning.ListOperationsRequest.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.longrunning.ListOperationsRequest
                 * @static
                 * @param {google.longrunning.IListOperationsRequest} message ListOperationsRequest message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                ListOperationsRequest.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes a ListOperationsRequest message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.longrunning.ListOperationsRequest
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.longrunning.ListOperationsRequest} ListOperationsRequest
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                ListOperationsRequest.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.longrunning.ListOperationsRequest();
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 4: {
                                message.name = reader.string();
                                break;
                            }
                        case 1: {
                                message.filter = reader.string();
                                break;
                            }
                        case 2: {
                                message.pageSize = reader.int32();
                                break;
                            }
                        case 3: {
                                message.pageToken = reader.string();
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes a ListOperationsRequest message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.longrunning.ListOperationsRequest
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.longrunning.ListOperationsRequest} ListOperationsRequest
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                ListOperationsRequest.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies a ListOperationsRequest message.
                 * @function verify
                 * @memberof google.longrunning.ListOperationsRequest
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                ListOperationsRequest.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    if (message.name != null && message.hasOwnProperty("name"))
                        if (!$util.isString(message.name))
                            return "name: string expected";
                    if (message.filter != null && message.hasOwnProperty("filter"))
                        if (!$util.isString(message.filter))
                            return "filter: string expected";
                    if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                        if (!$util.isInteger(message.pageSize))
                            return "pageSize: integer expected";
                    if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                        if (!$util.isString(message.pageToken))
                            return "pageToken: string expected";
                    return null;
                };
    
                /**
                 * Creates a ListOperationsRequest message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.longrunning.ListOperationsRequest
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.longrunning.ListOperationsRequest} ListOperationsRequest
                 */
                ListOperationsRequest.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.longrunning.ListOperationsRequest)
                        return object;
                    var message = new $root.google.longrunning.ListOperationsRequest();
                    if (object.name != null)
                        message.name = String(object.name);
                    if (object.filter != null)
                        message.filter = String(object.filter);
                    if (object.pageSize != null)
                        message.pageSize = object.pageSize | 0;
                    if (object.pageToken != null)
                        message.pageToken = String(object.pageToken);
                    return message;
                };
    
                /**
                 * Creates a plain object from a ListOperationsRequest message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.longrunning.ListOperationsRequest
                 * @static
                 * @param {google.longrunning.ListOperationsRequest} message ListOperationsRequest
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                ListOperationsRequest.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (options.defaults) {
                        object.filter = "";
                        object.pageSize = 0;
                        object.pageToken = "";
                        object.name = "";
                    }
                    if (message.filter != null && message.hasOwnProperty("filter"))
                        object.filter = message.filter;
                    if (message.pageSize != null && message.hasOwnProperty("pageSize"))
                        object.pageSize = message.pageSize;
                    if (message.pageToken != null && message.hasOwnProperty("pageToken"))
                        object.pageToken = message.pageToken;
                    if (message.name != null && message.hasOwnProperty("name"))
                        object.name = message.name;
                    return object;
                };
    
                /**
                 * Converts this ListOperationsRequest to JSON.
                 * @function toJSON
                 * @memberof google.longrunning.ListOperationsRequest
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                ListOperationsRequest.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for ListOperationsRequest
                 * @function getTypeUrl
                 * @memberof google.longrunning.ListOperationsRequest
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                ListOperationsRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.longrunning.ListOperationsRequest";
                };
    
                return ListOperationsRequest;
            })();
    
            longrunning.ListOperationsResponse = (function() {
    
                /**
                 * Properties of a ListOperationsResponse.
                 * @memberof google.longrunning
                 * @interface IListOperationsResponse
                 * @property {Array.<google.longrunning.IOperation>|null} [operations] ListOperationsResponse operations
                 * @property {string|null} [nextPageToken] ListOperationsResponse nextPageToken
                 */
    
                /**
                 * Constructs a new ListOperationsResponse.
                 * @memberof google.longrunning
                 * @classdesc Represents a ListOperationsResponse.
                 * @implements IListOperationsResponse
                 * @constructor
                 * @param {google.longrunning.IListOperationsResponse=} [properties] Properties to set
                 */
                function ListOperationsResponse(properties) {
                    this.operations = [];
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * ListOperationsResponse operations.
                 * @member {Array.<google.longrunning.IOperation>} operations
                 * @memberof google.longrunning.ListOperationsResponse
                 * @instance
                 */
                ListOperationsResponse.prototype.operations = $util.emptyArray;
    
                /**
                 * ListOperationsResponse nextPageToken.
                 * @member {string} nextPageToken
                 * @memberof google.longrunning.ListOperationsResponse
                 * @instance
                 */
                ListOperationsResponse.prototype.nextPageToken = "";
    
                /**
                 * Creates a new ListOperationsResponse instance using the specified properties.
                 * @function create
                 * @memberof google.longrunning.ListOperationsResponse
                 * @static
                 * @param {google.longrunning.IListOperationsResponse=} [properties] Properties to set
                 * @returns {google.longrunning.ListOperationsResponse} ListOperationsResponse instance
                 */
                ListOperationsResponse.create = function create(properties) {
                    return new ListOperationsResponse(properties);
                };
    
                /**
                 * Encodes the specified ListOperationsResponse message. Does not implicitly {@link google.longrunning.ListOperationsResponse.verify|verify} messages.
                 * @function encode
                 * @memberof google.longrunning.ListOperationsResponse
                 * @static
                 * @param {google.longrunning.IListOperationsResponse} message ListOperationsResponse message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                ListOperationsResponse.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.operations != null && message.operations.length)
                        for (var i = 0; i < message.operations.length; ++i)
                            $root.google.longrunning.Operation.encode(message.operations[i], writer.uint32(/* id 1, wireType 2 =*/10).fork()).ldelim();
                    if (message.nextPageToken != null && Object.hasOwnProperty.call(message, "nextPageToken"))
                        writer.uint32(/* id 2, wireType 2 =*/18).string(message.nextPageToken);
                    return writer;
                };
    
                /**
                 * Encodes the specified ListOperationsResponse message, length delimited. Does not implicitly {@link google.longrunning.ListOperationsResponse.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.longrunning.ListOperationsResponse
                 * @static
                 * @param {google.longrunning.IListOperationsResponse} message ListOperationsResponse message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                ListOperationsResponse.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes a ListOperationsResponse message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.longrunning.ListOperationsResponse
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.longrunning.ListOperationsResponse} ListOperationsResponse
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                ListOperationsResponse.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.longrunning.ListOperationsResponse();
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 1: {
                                if (!(message.operations && message.operations.length))
                                    message.operations = [];
                                message.operations.push($root.google.longrunning.Operation.decode(reader, reader.uint32()));
                                break;
                            }
                        case 2: {
                                message.nextPageToken = reader.string();
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes a ListOperationsResponse message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.longrunning.ListOperationsResponse
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.longrunning.ListOperationsResponse} ListOperationsResponse
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                ListOperationsResponse.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies a ListOperationsResponse message.
                 * @function verify
                 * @memberof google.longrunning.ListOperationsResponse
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                ListOperationsResponse.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    if (message.operations != null && message.hasOwnProperty("operations")) {
                        if (!Array.isArray(message.operations))
                            return "operations: array expected";
                        for (var i = 0; i < message.operations.length; ++i) {
                            var error = $root.google.longrunning.Operation.verify(message.operations[i]);
                            if (error)
                                return "operations." + error;
                        }
                    }
                    if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                        if (!$util.isString(message.nextPageToken))
                            return "nextPageToken: string expected";
                    return null;
                };
    
                /**
                 * Creates a ListOperationsResponse message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.longrunning.ListOperationsResponse
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.longrunning.ListOperationsResponse} ListOperationsResponse
                 */
                ListOperationsResponse.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.longrunning.ListOperationsResponse)
                        return object;
                    var message = new $root.google.longrunning.ListOperationsResponse();
                    if (object.operations) {
                        if (!Array.isArray(object.operations))
                            throw TypeError(".google.longrunning.ListOperationsResponse.operations: array expected");
                        message.operations = [];
                        for (var i = 0; i < object.operations.length; ++i) {
                            if (typeof object.operations[i] !== "object")
                                throw TypeError(".google.longrunning.ListOperationsResponse.operations: object expected");
                            message.operations[i] = $root.google.longrunning.Operation.fromObject(object.operations[i]);
                        }
                    }
                    if (object.nextPageToken != null)
                        message.nextPageToken = String(object.nextPageToken);
                    return message;
                };
    
                /**
                 * Creates a plain object from a ListOperationsResponse message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.longrunning.ListOperationsResponse
                 * @static
                 * @param {google.longrunning.ListOperationsResponse} message ListOperationsResponse
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                ListOperationsResponse.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (options.arrays || options.defaults)
                        object.operations = [];
                    if (options.defaults)
                        object.nextPageToken = "";
                    if (message.operations && message.operations.length) {
                        object.operations = [];
                        for (var j = 0; j < message.operations.length; ++j)
                            object.operations[j] = $root.google.longrunning.Operation.toObject(message.operations[j], options);
                    }
                    if (message.nextPageToken != null && message.hasOwnProperty("nextPageToken"))
                        object.nextPageToken = message.nextPageToken;
                    return object;
                };
    
                /**
                 * Converts this ListOperationsResponse to JSON.
                 * @function toJSON
                 * @memberof google.longrunning.ListOperationsResponse
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                ListOperationsResponse.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for ListOperationsResponse
                 * @function getTypeUrl
                 * @memberof google.longrunning.ListOperationsResponse
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                ListOperationsResponse.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.longrunning.ListOperationsResponse";
                };
    
                return ListOperationsResponse;
            })();
    
            longrunning.CancelOperationRequest = (function() {
    
                /**
                 * Properties of a CancelOperationRequest.
                 * @memberof google.longrunning
                 * @interface ICancelOperationRequest
                 * @property {string|null} [name] CancelOperationRequest name
                 */
    
                /**
                 * Constructs a new CancelOperationRequest.
                 * @memberof google.longrunning
                 * @classdesc Represents a CancelOperationRequest.
                 * @implements ICancelOperationRequest
                 * @constructor
                 * @param {google.longrunning.ICancelOperationRequest=} [properties] Properties to set
                 */
                function CancelOperationRequest(properties) {
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * CancelOperationRequest name.
                 * @member {string} name
                 * @memberof google.longrunning.CancelOperationRequest
                 * @instance
                 */
                CancelOperationRequest.prototype.name = "";
    
                /**
                 * Creates a new CancelOperationRequest instance using the specified properties.
                 * @function create
                 * @memberof google.longrunning.CancelOperationRequest
                 * @static
                 * @param {google.longrunning.ICancelOperationRequest=} [properties] Properties to set
                 * @returns {google.longrunning.CancelOperationRequest} CancelOperationRequest instance
                 */
                CancelOperationRequest.create = function create(properties) {
                    return new CancelOperationRequest(properties);
                };
    
                /**
                 * Encodes the specified CancelOperationRequest message. Does not implicitly {@link google.longrunning.CancelOperationRequest.verify|verify} messages.
                 * @function encode
                 * @memberof google.longrunning.CancelOperationRequest
                 * @static
                 * @param {google.longrunning.ICancelOperationRequest} message CancelOperationRequest message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                CancelOperationRequest.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                    return writer;
                };
    
                /**
                 * Encodes the specified CancelOperationRequest message, length delimited. Does not implicitly {@link google.longrunning.CancelOperationRequest.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.longrunning.CancelOperationRequest
                 * @static
                 * @param {google.longrunning.ICancelOperationRequest} message CancelOperationRequest message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                CancelOperationRequest.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes a CancelOperationRequest message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.longrunning.CancelOperationRequest
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.longrunning.CancelOperationRequest} CancelOperationRequest
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                CancelOperationRequest.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.longrunning.CancelOperationRequest();
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 1: {
                                message.name = reader.string();
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes a CancelOperationRequest message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.longrunning.CancelOperationRequest
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.longrunning.CancelOperationRequest} CancelOperationRequest
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                CancelOperationRequest.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies a CancelOperationRequest message.
                 * @function verify
                 * @memberof google.longrunning.CancelOperationRequest
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                CancelOperationRequest.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    if (message.name != null && message.hasOwnProperty("name"))
                        if (!$util.isString(message.name))
                            return "name: string expected";
                    return null;
                };
    
                /**
                 * Creates a CancelOperationRequest message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.longrunning.CancelOperationRequest
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.longrunning.CancelOperationRequest} CancelOperationRequest
                 */
                CancelOperationRequest.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.longrunning.CancelOperationRequest)
                        return object;
                    var message = new $root.google.longrunning.CancelOperationRequest();
                    if (object.name != null)
                        message.name = String(object.name);
                    return message;
                };
    
                /**
                 * Creates a plain object from a CancelOperationRequest message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.longrunning.CancelOperationRequest
                 * @static
                 * @param {google.longrunning.CancelOperationRequest} message CancelOperationRequest
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                CancelOperationRequest.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (options.defaults)
                        object.name = "";
                    if (message.name != null && message.hasOwnProperty("name"))
                        object.name = message.name;
                    return object;
                };
    
                /**
                 * Converts this CancelOperationRequest to JSON.
                 * @function toJSON
                 * @memberof google.longrunning.CancelOperationRequest
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                CancelOperationRequest.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for CancelOperationRequest
                 * @function getTypeUrl
                 * @memberof google.longrunning.CancelOperationRequest
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                CancelOperationRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.longrunning.CancelOperationRequest";
                };
    
                return CancelOperationRequest;
            })();
    
            longrunning.DeleteOperationRequest = (function() {
    
                /**
                 * Properties of a DeleteOperationRequest.
                 * @memberof google.longrunning
                 * @interface IDeleteOperationRequest
                 * @property {string|null} [name] DeleteOperationRequest name
                 */
    
                /**
                 * Constructs a new DeleteOperationRequest.
                 * @memberof google.longrunning
                 * @classdesc Represents a DeleteOperationRequest.
                 * @implements IDeleteOperationRequest
                 * @constructor
                 * @param {google.longrunning.IDeleteOperationRequest=} [properties] Properties to set
                 */
                function DeleteOperationRequest(properties) {
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * DeleteOperationRequest name.
                 * @member {string} name
                 * @memberof google.longrunning.DeleteOperationRequest
                 * @instance
                 */
                DeleteOperationRequest.prototype.name = "";
    
                /**
                 * Creates a new DeleteOperationRequest instance using the specified properties.
                 * @function create
                 * @memberof google.longrunning.DeleteOperationRequest
                 * @static
                 * @param {google.longrunning.IDeleteOperationRequest=} [properties] Properties to set
                 * @returns {google.longrunning.DeleteOperationRequest} DeleteOperationRequest instance
                 */
                DeleteOperationRequest.create = function create(properties) {
                    return new DeleteOperationRequest(properties);
                };
    
                /**
                 * Encodes the specified DeleteOperationRequest message. Does not implicitly {@link google.longrunning.DeleteOperationRequest.verify|verify} messages.
                 * @function encode
                 * @memberof google.longrunning.DeleteOperationRequest
                 * @static
                 * @param {google.longrunning.IDeleteOperationRequest} message DeleteOperationRequest message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                DeleteOperationRequest.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                    return writer;
                };
    
                /**
                 * Encodes the specified DeleteOperationRequest message, length delimited. Does not implicitly {@link google.longrunning.DeleteOperationRequest.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.longrunning.DeleteOperationRequest
                 * @static
                 * @param {google.longrunning.IDeleteOperationRequest} message DeleteOperationRequest message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                DeleteOperationRequest.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes a DeleteOperationRequest message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.longrunning.DeleteOperationRequest
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.longrunning.DeleteOperationRequest} DeleteOperationRequest
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                DeleteOperationRequest.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.longrunning.DeleteOperationRequest();
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 1: {
                                message.name = reader.string();
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes a DeleteOperationRequest message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.longrunning.DeleteOperationRequest
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.longrunning.DeleteOperationRequest} DeleteOperationRequest
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                DeleteOperationRequest.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies a DeleteOperationRequest message.
                 * @function verify
                 * @memberof google.longrunning.DeleteOperationRequest
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                DeleteOperationRequest.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    if (message.name != null && message.hasOwnProperty("name"))
                        if (!$util.isString(message.name))
                            return "name: string expected";
                    return null;
                };
    
                /**
                 * Creates a DeleteOperationRequest message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.longrunning.DeleteOperationRequest
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.longrunning.DeleteOperationRequest} DeleteOperationRequest
                 */
                DeleteOperationRequest.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.longrunning.DeleteOperationRequest)
                        return object;
                    var message = new $root.google.longrunning.DeleteOperationRequest();
                    if (object.name != null)
                        message.name = String(object.name);
                    return message;
                };
    
                /**
                 * Creates a plain object from a DeleteOperationRequest message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.longrunning.DeleteOperationRequest
                 * @static
                 * @param {google.longrunning.DeleteOperationRequest} message DeleteOperationRequest
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                DeleteOperationRequest.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (options.defaults)
                        object.name = "";
                    if (message.name != null && message.hasOwnProperty("name"))
                        object.name = message.name;
                    return object;
                };
    
                /**
                 * Converts this DeleteOperationRequest to JSON.
                 * @function toJSON
                 * @memberof google.longrunning.DeleteOperationRequest
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                DeleteOperationRequest.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for DeleteOperationRequest
                 * @function getTypeUrl
                 * @memberof google.longrunning.DeleteOperationRequest
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                DeleteOperationRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.longrunning.DeleteOperationRequest";
                };
    
                return DeleteOperationRequest;
            })();
    
            longrunning.WaitOperationRequest = (function() {
    
                /**
                 * Properties of a WaitOperationRequest.
                 * @memberof google.longrunning
                 * @interface IWaitOperationRequest
                 * @property {string|null} [name] WaitOperationRequest name
                 * @property {google.protobuf.IDuration|null} [timeout] WaitOperationRequest timeout
                 */
    
                /**
                 * Constructs a new WaitOperationRequest.
                 * @memberof google.longrunning
                 * @classdesc Represents a WaitOperationRequest.
                 * @implements IWaitOperationRequest
                 * @constructor
                 * @param {google.longrunning.IWaitOperationRequest=} [properties] Properties to set
                 */
                function WaitOperationRequest(properties) {
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * WaitOperationRequest name.
                 * @member {string} name
                 * @memberof google.longrunning.WaitOperationRequest
                 * @instance
                 */
                WaitOperationRequest.prototype.name = "";
    
                /**
                 * WaitOperationRequest timeout.
                 * @member {google.protobuf.IDuration|null|undefined} timeout
                 * @memberof google.longrunning.WaitOperationRequest
                 * @instance
                 */
                WaitOperationRequest.prototype.timeout = null;
    
                /**
                 * Creates a new WaitOperationRequest instance using the specified properties.
                 * @function create
                 * @memberof google.longrunning.WaitOperationRequest
                 * @static
                 * @param {google.longrunning.IWaitOperationRequest=} [properties] Properties to set
                 * @returns {google.longrunning.WaitOperationRequest} WaitOperationRequest instance
                 */
                WaitOperationRequest.create = function create(properties) {
                    return new WaitOperationRequest(properties);
                };
    
                /**
                 * Encodes the specified WaitOperationRequest message. Does not implicitly {@link google.longrunning.WaitOperationRequest.verify|verify} messages.
                 * @function encode
                 * @memberof google.longrunning.WaitOperationRequest
                 * @static
                 * @param {google.longrunning.IWaitOperationRequest} message WaitOperationRequest message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                WaitOperationRequest.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.name != null && Object.hasOwnProperty.call(message, "name"))
                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.name);
                    if (message.timeout != null && Object.hasOwnProperty.call(message, "timeout"))
                        $root.google.protobuf.Duration.encode(message.timeout, writer.uint32(/* id 2, wireType 2 =*/18).fork()).ldelim();
                    return writer;
                };
    
                /**
                 * Encodes the specified WaitOperationRequest message, length delimited. Does not implicitly {@link google.longrunning.WaitOperationRequest.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.longrunning.WaitOperationRequest
                 * @static
                 * @param {google.longrunning.IWaitOperationRequest} message WaitOperationRequest message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                WaitOperationRequest.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes a WaitOperationRequest message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.longrunning.WaitOperationRequest
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.longrunning.WaitOperationRequest} WaitOperationRequest
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                WaitOperationRequest.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.longrunning.WaitOperationRequest();
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 1: {
                                message.name = reader.string();
                                break;
                            }
                        case 2: {
                                message.timeout = $root.google.protobuf.Duration.decode(reader, reader.uint32());
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes a WaitOperationRequest message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.longrunning.WaitOperationRequest
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.longrunning.WaitOperationRequest} WaitOperationRequest
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                WaitOperationRequest.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies a WaitOperationRequest message.
                 * @function verify
                 * @memberof google.longrunning.WaitOperationRequest
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                WaitOperationRequest.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    if (message.name != null && message.hasOwnProperty("name"))
                        if (!$util.isString(message.name))
                            return "name: string expected";
                    if (message.timeout != null && message.hasOwnProperty("timeout")) {
                        var error = $root.google.protobuf.Duration.verify(message.timeout);
                        if (error)
                            return "timeout." + error;
                    }
                    return null;
                };
    
                /**
                 * Creates a WaitOperationRequest message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.longrunning.WaitOperationRequest
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.longrunning.WaitOperationRequest} WaitOperationRequest
                 */
                WaitOperationRequest.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.longrunning.WaitOperationRequest)
                        return object;
                    var message = new $root.google.longrunning.WaitOperationRequest();
                    if (object.name != null)
                        message.name = String(object.name);
                    if (object.timeout != null) {
                        if (typeof object.timeout !== "object")
                            throw TypeError(".google.longrunning.WaitOperationRequest.timeout: object expected");
                        message.timeout = $root.google.protobuf.Duration.fromObject(object.timeout);
                    }
                    return message;
                };
    
                /**
                 * Creates a plain object from a WaitOperationRequest message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.longrunning.WaitOperationRequest
                 * @static
                 * @param {google.longrunning.WaitOperationRequest} message WaitOperationRequest
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                WaitOperationRequest.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (options.defaults) {
                        object.name = "";
                        object.timeout = null;
                    }
                    if (message.name != null && message.hasOwnProperty("name"))
                        object.name = message.name;
                    if (message.timeout != null && message.hasOwnProperty("timeout"))
                        object.timeout = $root.google.protobuf.Duration.toObject(message.timeout, options);
                    return object;
                };
    
                /**
                 * Converts this WaitOperationRequest to JSON.
                 * @function toJSON
                 * @memberof google.longrunning.WaitOperationRequest
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                WaitOperationRequest.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for WaitOperationRequest
                 * @function getTypeUrl
                 * @memberof google.longrunning.WaitOperationRequest
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                WaitOperationRequest.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.longrunning.WaitOperationRequest";
                };
    
                return WaitOperationRequest;
            })();
    
            longrunning.OperationInfo = (function() {
    
                /**
                 * Properties of an OperationInfo.
                 * @memberof google.longrunning
                 * @interface IOperationInfo
                 * @property {string|null} [responseType] OperationInfo responseType
                 * @property {string|null} [metadataType] OperationInfo metadataType
                 */
    
                /**
                 * Constructs a new OperationInfo.
                 * @memberof google.longrunning
                 * @classdesc Represents an OperationInfo.
                 * @implements IOperationInfo
                 * @constructor
                 * @param {google.longrunning.IOperationInfo=} [properties] Properties to set
                 */
                function OperationInfo(properties) {
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * OperationInfo responseType.
                 * @member {string} responseType
                 * @memberof google.longrunning.OperationInfo
                 * @instance
                 */
                OperationInfo.prototype.responseType = "";
    
                /**
                 * OperationInfo metadataType.
                 * @member {string} metadataType
                 * @memberof google.longrunning.OperationInfo
                 * @instance
                 */
                OperationInfo.prototype.metadataType = "";
    
                /**
                 * Creates a new OperationInfo instance using the specified properties.
                 * @function create
                 * @memberof google.longrunning.OperationInfo
                 * @static
                 * @param {google.longrunning.IOperationInfo=} [properties] Properties to set
                 * @returns {google.longrunning.OperationInfo} OperationInfo instance
                 */
                OperationInfo.create = function create(properties) {
                    return new OperationInfo(properties);
                };
    
                /**
                 * Encodes the specified OperationInfo message. Does not implicitly {@link google.longrunning.OperationInfo.verify|verify} messages.
                 * @function encode
                 * @memberof google.longrunning.OperationInfo
                 * @static
                 * @param {google.longrunning.IOperationInfo} message OperationInfo message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                OperationInfo.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.responseType != null && Object.hasOwnProperty.call(message, "responseType"))
                        writer.uint32(/* id 1, wireType 2 =*/10).string(message.responseType);
                    if (message.metadataType != null && Object.hasOwnProperty.call(message, "metadataType"))
                        writer.uint32(/* id 2, wireType 2 =*/18).string(message.metadataType);
                    return writer;
                };
    
                /**
                 * Encodes the specified OperationInfo message, length delimited. Does not implicitly {@link google.longrunning.OperationInfo.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.longrunning.OperationInfo
                 * @static
                 * @param {google.longrunning.IOperationInfo} message OperationInfo message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                OperationInfo.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes an OperationInfo message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.longrunning.OperationInfo
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.longrunning.OperationInfo} OperationInfo
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                OperationInfo.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.longrunning.OperationInfo();
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 1: {
                                message.responseType = reader.string();
                                break;
                            }
                        case 2: {
                                message.metadataType = reader.string();
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes an OperationInfo message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.longrunning.OperationInfo
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.longrunning.OperationInfo} OperationInfo
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                OperationInfo.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies an OperationInfo message.
                 * @function verify
                 * @memberof google.longrunning.OperationInfo
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                OperationInfo.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    if (message.responseType != null && message.hasOwnProperty("responseType"))
                        if (!$util.isString(message.responseType))
                            return "responseType: string expected";
                    if (message.metadataType != null && message.hasOwnProperty("metadataType"))
                        if (!$util.isString(message.metadataType))
                            return "metadataType: string expected";
                    return null;
                };
    
                /**
                 * Creates an OperationInfo message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.longrunning.OperationInfo
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.longrunning.OperationInfo} OperationInfo
                 */
                OperationInfo.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.longrunning.OperationInfo)
                        return object;
                    var message = new $root.google.longrunning.OperationInfo();
                    if (object.responseType != null)
                        message.responseType = String(object.responseType);
                    if (object.metadataType != null)
                        message.metadataType = String(object.metadataType);
                    return message;
                };
    
                /**
                 * Creates a plain object from an OperationInfo message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.longrunning.OperationInfo
                 * @static
                 * @param {google.longrunning.OperationInfo} message OperationInfo
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                OperationInfo.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (options.defaults) {
                        object.responseType = "";
                        object.metadataType = "";
                    }
                    if (message.responseType != null && message.hasOwnProperty("responseType"))
                        object.responseType = message.responseType;
                    if (message.metadataType != null && message.hasOwnProperty("metadataType"))
                        object.metadataType = message.metadataType;
                    return object;
                };
    
                /**
                 * Converts this OperationInfo to JSON.
                 * @function toJSON
                 * @memberof google.longrunning.OperationInfo
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                OperationInfo.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for OperationInfo
                 * @function getTypeUrl
                 * @memberof google.longrunning.OperationInfo
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                OperationInfo.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.longrunning.OperationInfo";
                };
    
                return OperationInfo;
            })();
    
            return longrunning;
        })();
    
        google.rpc = (function() {
    
            /**
             * Namespace rpc.
             * @memberof google
             * @namespace
             */
            var rpc = {};
    
            rpc.Status = (function() {
    
                /**
                 * Properties of a Status.
                 * @memberof google.rpc
                 * @interface IStatus
                 * @property {number|null} [code] Status code
                 * @property {string|null} [message] Status message
                 * @property {Array.<google.protobuf.IAny>|null} [details] Status details
                 */
    
                /**
                 * Constructs a new Status.
                 * @memberof google.rpc
                 * @classdesc Represents a Status.
                 * @implements IStatus
                 * @constructor
                 * @param {google.rpc.IStatus=} [properties] Properties to set
                 */
                function Status(properties) {
                    this.details = [];
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * Status code.
                 * @member {number} code
                 * @memberof google.rpc.Status
                 * @instance
                 */
                Status.prototype.code = 0;
    
                /**
                 * Status message.
                 * @member {string} message
                 * @memberof google.rpc.Status
                 * @instance
                 */
                Status.prototype.message = "";
    
                /**
                 * Status details.
                 * @member {Array.<google.protobuf.IAny>} details
                 * @memberof google.rpc.Status
                 * @instance
                 */
                Status.prototype.details = $util.emptyArray;
    
                /**
                 * Creates a new Status instance using the specified properties.
                 * @function create
                 * @memberof google.rpc.Status
                 * @static
                 * @param {google.rpc.IStatus=} [properties] Properties to set
                 * @returns {google.rpc.Status} Status instance
                 */
                Status.create = function create(properties) {
                    return new Status(properties);
                };
    
                /**
                 * Encodes the specified Status message. Does not implicitly {@link google.rpc.Status.verify|verify} messages.
                 * @function encode
                 * @memberof google.rpc.Status
                 * @static
                 * @param {google.rpc.IStatus} message Status message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                Status.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.code != null && Object.hasOwnProperty.call(message, "code"))
                        writer.uint32(/* id 1, wireType 0 =*/8).int32(message.code);
                    if (message.message != null && Object.hasOwnProperty.call(message, "message"))
                        writer.uint32(/* id 2, wireType 2 =*/18).string(message.message);
                    if (message.details != null && message.details.length)
                        for (var i = 0; i < message.details.length; ++i)
                            $root.google.protobuf.Any.encode(message.details[i], writer.uint32(/* id 3, wireType 2 =*/26).fork()).ldelim();
                    return writer;
                };
    
                /**
                 * Encodes the specified Status message, length delimited. Does not implicitly {@link google.rpc.Status.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.rpc.Status
                 * @static
                 * @param {google.rpc.IStatus} message Status message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                Status.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes a Status message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.rpc.Status
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.rpc.Status} Status
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                Status.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.rpc.Status();
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 1: {
                                message.code = reader.int32();
                                break;
                            }
                        case 2: {
                                message.message = reader.string();
                                break;
                            }
                        case 3: {
                                if (!(message.details && message.details.length))
                                    message.details = [];
                                message.details.push($root.google.protobuf.Any.decode(reader, reader.uint32()));
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes a Status message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.rpc.Status
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.rpc.Status} Status
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                Status.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies a Status message.
                 * @function verify
                 * @memberof google.rpc.Status
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                Status.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    if (message.code != null && message.hasOwnProperty("code"))
                        if (!$util.isInteger(message.code))
                            return "code: integer expected";
                    if (message.message != null && message.hasOwnProperty("message"))
                        if (!$util.isString(message.message))
                            return "message: string expected";
                    if (message.details != null && message.hasOwnProperty("details")) {
                        if (!Array.isArray(message.details))
                            return "details: array expected";
                        for (var i = 0; i < message.details.length; ++i) {
                            var error = $root.google.protobuf.Any.verify(message.details[i]);
                            if (error)
                                return "details." + error;
                        }
                    }
                    return null;
                };
    
                /**
                 * Creates a Status message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.rpc.Status
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.rpc.Status} Status
                 */
                Status.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.rpc.Status)
                        return object;
                    var message = new $root.google.rpc.Status();
                    if (object.code != null)
                        message.code = object.code | 0;
                    if (object.message != null)
                        message.message = String(object.message);
                    if (object.details) {
                        if (!Array.isArray(object.details))
                            throw TypeError(".google.rpc.Status.details: array expected");
                        message.details = [];
                        for (var i = 0; i < object.details.length; ++i) {
                            if (typeof object.details[i] !== "object")
                                throw TypeError(".google.rpc.Status.details: object expected");
                            message.details[i] = $root.google.protobuf.Any.fromObject(object.details[i]);
                        }
                    }
                    return message;
                };
    
                /**
                 * Creates a plain object from a Status message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.rpc.Status
                 * @static
                 * @param {google.rpc.Status} message Status
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                Status.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (options.arrays || options.defaults)
                        object.details = [];
                    if (options.defaults) {
                        object.code = 0;
                        object.message = "";
                    }
                    if (message.code != null && message.hasOwnProperty("code"))
                        object.code = message.code;
                    if (message.message != null && message.hasOwnProperty("message"))
                        object.message = message.message;
                    if (message.details && message.details.length) {
                        object.details = [];
                        for (var j = 0; j < message.details.length; ++j)
                            object.details[j] = $root.google.protobuf.Any.toObject(message.details[j], options);
                    }
                    return object;
                };
    
                /**
                 * Converts this Status to JSON.
                 * @function toJSON
                 * @memberof google.rpc.Status
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                Status.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for Status
                 * @function getTypeUrl
                 * @memberof google.rpc.Status
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                Status.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.rpc.Status";
                };
    
                return Status;
            })();
    
            return rpc;
        })();
    
        google.type = (function() {
    
            /**
             * Namespace type.
             * @memberof google
             * @namespace
             */
            var type = {};
    
            type.LatLng = (function() {
    
                /**
                 * Properties of a LatLng.
                 * @memberof google.type
                 * @interface ILatLng
                 * @property {number|null} [latitude] LatLng latitude
                 * @property {number|null} [longitude] LatLng longitude
                 */
    
                /**
                 * Constructs a new LatLng.
                 * @memberof google.type
                 * @classdesc Represents a LatLng.
                 * @implements ILatLng
                 * @constructor
                 * @param {google.type.ILatLng=} [properties] Properties to set
                 */
                function LatLng(properties) {
                    if (properties)
                        for (var keys = Object.keys(properties), i = 0; i < keys.length; ++i)
                            if (properties[keys[i]] != null)
                                this[keys[i]] = properties[keys[i]];
                }
    
                /**
                 * LatLng latitude.
                 * @member {number} latitude
                 * @memberof google.type.LatLng
                 * @instance
                 */
                LatLng.prototype.latitude = 0;
    
                /**
                 * LatLng longitude.
                 * @member {number} longitude
                 * @memberof google.type.LatLng
                 * @instance
                 */
                LatLng.prototype.longitude = 0;
    
                /**
                 * Creates a new LatLng instance using the specified properties.
                 * @function create
                 * @memberof google.type.LatLng
                 * @static
                 * @param {google.type.ILatLng=} [properties] Properties to set
                 * @returns {google.type.LatLng} LatLng instance
                 */
                LatLng.create = function create(properties) {
                    return new LatLng(properties);
                };
    
                /**
                 * Encodes the specified LatLng message. Does not implicitly {@link google.type.LatLng.verify|verify} messages.
                 * @function encode
                 * @memberof google.type.LatLng
                 * @static
                 * @param {google.type.ILatLng} message LatLng message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                LatLng.encode = function encode(message, writer) {
                    if (!writer)
                        writer = $Writer.create();
                    if (message.latitude != null && Object.hasOwnProperty.call(message, "latitude"))
                        writer.uint32(/* id 1, wireType 1 =*/9).double(message.latitude);
                    if (message.longitude != null && Object.hasOwnProperty.call(message, "longitude"))
                        writer.uint32(/* id 2, wireType 1 =*/17).double(message.longitude);
                    return writer;
                };
    
                /**
                 * Encodes the specified LatLng message, length delimited. Does not implicitly {@link google.type.LatLng.verify|verify} messages.
                 * @function encodeDelimited
                 * @memberof google.type.LatLng
                 * @static
                 * @param {google.type.ILatLng} message LatLng message or plain object to encode
                 * @param {$protobuf.Writer} [writer] Writer to encode to
                 * @returns {$protobuf.Writer} Writer
                 */
                LatLng.encodeDelimited = function encodeDelimited(message, writer) {
                    return this.encode(message, writer).ldelim();
                };
    
                /**
                 * Decodes a LatLng message from the specified reader or buffer.
                 * @function decode
                 * @memberof google.type.LatLng
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @param {number} [length] Message length if known beforehand
                 * @returns {google.type.LatLng} LatLng
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                LatLng.decode = function decode(reader, length) {
                    if (!(reader instanceof $Reader))
                        reader = $Reader.create(reader);
                    var end = length === undefined ? reader.len : reader.pos + length, message = new $root.google.type.LatLng();
                    while (reader.pos < end) {
                        var tag = reader.uint32();
                        switch (tag >>> 3) {
                        case 1: {
                                message.latitude = reader.double();
                                break;
                            }
                        case 2: {
                                message.longitude = reader.double();
                                break;
                            }
                        default:
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                    return message;
                };
    
                /**
                 * Decodes a LatLng message from the specified reader or buffer, length delimited.
                 * @function decodeDelimited
                 * @memberof google.type.LatLng
                 * @static
                 * @param {$protobuf.Reader|Uint8Array} reader Reader or buffer to decode from
                 * @returns {google.type.LatLng} LatLng
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                LatLng.decodeDelimited = function decodeDelimited(reader) {
                    if (!(reader instanceof $Reader))
                        reader = new $Reader(reader);
                    return this.decode(reader, reader.uint32());
                };
    
                /**
                 * Verifies a LatLng message.
                 * @function verify
                 * @memberof google.type.LatLng
                 * @static
                 * @param {Object.<string,*>} message Plain object to verify
                 * @returns {string|null} `null` if valid, otherwise the reason why it is not
                 */
                LatLng.verify = function verify(message) {
                    if (typeof message !== "object" || message === null)
                        return "object expected";
                    if (message.latitude != null && message.hasOwnProperty("latitude"))
                        if (typeof message.latitude !== "number")
                            return "latitude: number expected";
                    if (message.longitude != null && message.hasOwnProperty("longitude"))
                        if (typeof message.longitude !== "number")
                            return "longitude: number expected";
                    return null;
                };
    
                /**
                 * Creates a LatLng message from a plain object. Also converts values to their respective internal types.
                 * @function fromObject
                 * @memberof google.type.LatLng
                 * @static
                 * @param {Object.<string,*>} object Plain object
                 * @returns {google.type.LatLng} LatLng
                 */
                LatLng.fromObject = function fromObject(object) {
                    if (object instanceof $root.google.type.LatLng)
                        return object;
                    var message = new $root.google.type.LatLng();
                    if (object.latitude != null)
                        message.latitude = Number(object.latitude);
                    if (object.longitude != null)
                        message.longitude = Number(object.longitude);
                    return message;
                };
    
                /**
                 * Creates a plain object from a LatLng message. Also converts values to other types if specified.
                 * @function toObject
                 * @memberof google.type.LatLng
                 * @static
                 * @param {google.type.LatLng} message LatLng
                 * @param {$protobuf.IConversionOptions} [options] Conversion options
                 * @returns {Object.<string,*>} Plain object
                 */
                LatLng.toObject = function toObject(message, options) {
                    if (!options)
                        options = {};
                    var object = {};
                    if (options.defaults) {
                        object.latitude = 0;
                        object.longitude = 0;
                    }
                    if (message.latitude != null && message.hasOwnProperty("latitude"))
                        object.latitude = options.json && !isFinite(message.latitude) ? String(message.latitude) : message.latitude;
                    if (message.longitude != null && message.hasOwnProperty("longitude"))
                        object.longitude = options.json && !isFinite(message.longitude) ? String(message.longitude) : message.longitude;
                    return object;
                };
    
                /**
                 * Converts this LatLng to JSON.
                 * @function toJSON
                 * @memberof google.type.LatLng
                 * @instance
                 * @returns {Object.<string,*>} JSON object
                 */
                LatLng.prototype.toJSON = function toJSON() {
                    return this.constructor.toObject(this, $protobuf.util.toJSONOptions);
                };
    
                /**
                 * Gets the default type url for LatLng
                 * @function getTypeUrl
                 * @memberof google.type.LatLng
                 * @static
                 * @param {string} [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns {string} The default type url
                 */
                LatLng.getTypeUrl = function getTypeUrl(typeUrlPrefix) {
                    if (typeUrlPrefix === undefined) {
                        typeUrlPrefix = "type.googleapis.com";
                    }
                    return typeUrlPrefix + "/google.type.LatLng";
                };
    
                return LatLng;
            })();
    
            return type;
        })();
    
        return google;
    })();

    return $root;
});
